# coding: utf8
from __future__ import unicode_literals


DETS_IRREG = {
    "aucune": ("aucun",),
    "ces": ("ce",),
    "cet": ("ce",),
    "cette": ("ce",),
    "cents": ("cent",),
    "certaines": ("certains",),
    "différentes": ("différents",),
    "diverses": ("divers",),
    "la": ("le",),
    "les": ("le",),
    "l'": ("le",),
    "laquelle": ("lequel",),
    "lesquelles": ("lequel",),
    "lesquels": ("lequel",),
    "leurs": ("leur",),
    "mainte": ("maint",),
    "maintes": ("maint",),
    "maints": ("maint",),
    "ma": ("mon",),
    "mes": ("mon",),
    "nos": ("notre",),
    "nulle": ("nul",),
    "nulles": ("nul",),
    "nuls": ("nul",),
    "quelle": ("quel",),
    "quelles": ("quel",),
    "quels": ("quel",),
    "quelqu'": ("quelque",),
    "quelques": ("quelque",),
    "sa": ("son",),
    "ses": ("son",),
    "telle": ("tel",),
    "telles": ("tel",),
    "tels": ("tel",),
    "ta": ("ton",),
    "tes": ("ton",),
    "tous": ("tout",),
    "toute": ("tout",),
    "toutes": ("tout",),
    "des": ("un",),
    "une": ("un",),
    "vingts": ("vingt",),
    "vos": ("votre",)
}
