# coding: utf8
from __future__ import unicode_literals

LOOKUP = {
    'berabad-abad': 'abad',
    'keabadian': 'abadi',
    'keabadiannya': 'abadi',
    'mengabadi': 'abadi',
    'mengabadikan': 'abadi',
    'mengabadikannya': 'abadi',
    'mengabadian': 'abadi',
    'pengabadian': 'abadi',
    'pengabadiannya': 'abadi',
    'mengabahkan': 'abah',
    'abaian': 'abai',
    'terabai': 'abai',
    'terabaikan': 'abai',
    'terabaikannya': 'abai',
    'pengabai': 'abai',
    'pengabaikan': 'abai',
    'pengabaian': 'abai',
    'mengabaikan': 'abai',
    'mengabaikannya': 'abai',
    'mengabaikanku': 'abai',
    'mengabaikanmu': 'abai',
    'penabalan': 'tabal',
    'menabalkan': 'tabal',
    'berabang': 'abang',
    'abaran': 'abar',
    'terabar': 'abar',
    'mengabar': 'abar',
    'mengabarkan': 'abar',
    'mengabarkannya': 'abar',
    'mengabari': 'abar',
    'mengabaran': 'abar',
    'abar-abar': 'abar',
    'berabarkan': 'abar',
    'berabdas': 'abdas',
    'pengabdi': 'abdi',
    'pengabdinya': 'abdi',
    'pengabdikan': 'abdi',
    'pengabdian': 'abdi',
    'mengabdi': 'abdi',
    'mengabdinya': 'abdi',
    'mengabdilah': 'abdi',
    'mengabdikan': 'abdi',
    'mengabdian': 'abdi',
    'pengabdiannya': 'abdi',
    'pengabdianlah': 'abdi',
    'pengabdianku': 'abdi',
    'pengabdianmu': 'abdi',
    'mengaben': 'aben',
    'mengabenkan': 'aben',
    'pengabenan': 'aben',
    'pengabenannya': 'aben',
    'mengabet': 'abet',
    'berabjad': 'abjad',
    'mengabjad': 'abjad',
    'mengabjadkan': 'abjad',
    'pengabjadan': 'abjad',
    'keabnormalan': 'abnormal',
    'mengabolisikan': 'abolisi',
    'berabonemen': 'abonemen',
    'seabrek': 'abrek',
    'abrit-abritan': 'abrit-abrit',
    'keabsahan': 'absah',
    'keabsahannya': 'absah',
    'pengabsahan': 'absah',
    'pengabsahannya': 'absah',
    'mengabsahkan': 'absah',
    'mengabsahkannya': 'absah',
    'mengabsen': 'absen',
    'mengabsenkan': 'absen',
    'mengabsenkannya': 'absen',
    'mengabsorb': 'absorb',
    'mengabsorpsi': 'absorpsi',
    'keabstainan': 'abstain',
    'mengabstrakkan': 'abstrak',
    'mengabu': 'abu',
    'mengabukan': 'abuk',
    'mengabukannya': 'abu',
    'perabuan': 'abu',
    'mengabui': 'abu',
    'pengabuan': 'abu',
    'memperabukan': 'abu',
    'keabu-abuan': 'abu-abu',
    'abuhan': 'abuh',
    'abuh-abuhan': 'abuh',
    'mengabuk': 'abuk',
    'mengabukkan': 'abuk',
    'mengabur': 'kabur',
    'mengaburkan': 'kabur',
    'mengaburkannya': 'kabur',
    'pengabur': 'abur',
    'pengaburkan': 'abur',
    'pengaburan': 'abur',
    'mengacah': 'acah',
    'pengacah': 'acah',
    'beracah-acah': 'acah',
    'mengacak': 'kacak',
    'mengacaknya': 'kacak',
    'acak-acak': 'acak',
    'acak-acakkan': 'acak',
    'acak-acakan': 'acak',
    'acak-acakannya': 'acak',
    'mengacan': 'acan',
    'mengacapi': 'acap',
    'acap-acap': 'acap',
    'mengacapkan': 'acap',
    'beracara': 'acara',
    'beracaranya': 'acara',
    'mengacara': 'acara',
    'mengacarakan': 'acara',
    'pengacara': 'acara',
    'pengacaranya': 'acara',
    'pengacaralah': 'acara',
    'pengacaraku': 'acara',
    'kepengacaraan': 'acara',
    'acatan': 'acat',
    'mengacau': 'kacau',
    'mengacaukan': 'kacau',
    'mengacaukannya': 'kacau',
    'mengaci': 'aci',
    'mengacikan': 'aci',
    'aci-acian': 'aci-aci',
    'aci-acinya': 'aci-aci',
    'mengaci-acikan': 'aci-aci',
    'acoan': 'aco',
    'mengaco': 'aco',
    'aco-acoan': 'aco',
    'acuan': 'acu',
    'acuannya': 'acu',
    'acuanku': 'acu',
    'acuanmu': 'acu',
    'mengacu': 'acu',
    'mengacunya': 'acu',
    'mengacukan': 'acu',
    'pengacuan': 'acu',
    'mengacu-acu': 'acu',
    'acuhan': 'acuh',
    'mengacuhkan': 'acuh',
    'mengacuhkannya': 'acuh',
    'mengacuhkanku': 'acuh',
    'acuman': 'acum',
    'pengacum': 'acum',
    'mengacum': 'acum',
    'mengacung': 'acung',
    'mengacungkan': 'acung',
    'mengacungkannya': 'acung',
    'mengacungi': 'acung',
    'adanya': 'ada',
    'adanyanya': 'ada',
    'adanyalah': 'ada',
    'berada': 'ada',
    'beradanya': 'ada',
    'beradalah': 'ada',
    'beradai': 'ada',
    'beradaan': 'ada',
    'pengada': 'ada',
    'pengadakan': 'ada',
    'pengadaan': 'ada',
    'keadaan': 'ada',
    'keadaannya': 'ada',
    'keadaanlah': 'ada',
    'keadaanku': 'ada',
    'keadaanmu': 'ada',
    'seadanya': 'ada',
    'seadanyalah': 'ada',
    'pengadaannya': 'ada',
    'berada-ada': 'ada',
    'ada-adanya': 'ada',
    'keberadaan': 'ada',
    'keberadaannya': 'ada',
    'keberadaanku': 'ada',
    'keberadaanmu': 'ada',
    'mengadakan': 'ada',
    'mengadakannya': 'ada',
    'mengada-ada': 'ada',
    'mengada-adalah': 'ada',
    'mengada-adakan': 'ada',
    'ada-ada saja': 'ada',
    'ada-adanyakah': 'ada',
    'beradab': 'adab',
    'beradabnya': 'adab',
    'beradaban': 'adab',
    'keadaban': 'adab',
    'keadabannya': 'adab',
    'mengadabi': 'adab',
    'peradaban': 'adab',
    'peradabannya': 'adab',
    'memperadabkan': 'adab',
    'adakalanya': 'adakala',
    'diadang': 'adang',
    'diadangnya': 'adang',
    'mengadang': 'kadang',
    'mengadangnya': 'kadang',
    'mengadangkan': 'kadang',
    'pengadang': 'adang',
    'pengadangnya': 'adang',
    'pengadangan': 'adang',
    'mengadangi': 'adang',
    'adang-adang': 'adang',
    'mengadang-adangi': 'adang',
    'adap-adapan': 'adap',
    'beradaptasi': 'adaptasi',
    'beradaptasinya': 'adaptasi',
    'beradaptasilah': 'adaptasi',
    'pengadaptasian': 'adaptasi',
    'mengadaptasikan': 'adaptasi',
    'mengadaptasikannya': 'adaptasi',
    'mengadar': 'kadar',
    'mengadari': 'kadar',
    'beradat': 'adat',
    'teradat': 'adat',
    'mengadat': 'adat',
    'mengadatkan': 'adat',
    'beradegan': 'adegan',
    'pengadeganan': 'adegan',
    'beradeh': 'adeh',
    'mengadem': 'adem',
    'mengademkan': 'adem',
    'beradik': 'adik',
    'beradiknya': 'adik',
    'beradiki': 'adik',
    'memperadik': 'adik',
    'adik-beradik': 'adik',
    'beradik-berkakak': 'adik',
    'keadikuasaan': 'adikuasa',
    'teradil': 'adil',
    'keadilan': 'adil',
    'keadilannya': 'adil',
    'keadilanlah': 'adil',
    'keadilan-mu': 'adil',
    'pengadil': 'adil',
    'pengadilnya': 'adil',
    'pengadilkan': 'adil',
    'pengadili': 'adil',
    'pengadilan': 'adil',
    'teradili': 'adil',
    'mengadili': 'adil',
    'mengadilinya': 'adil',
    'mengadilikan': 'adil',
    'peradilan': 'adil',
    'peradilannya': 'adil',
    'peradilanlah': 'adil',
    'peradilankan': 'adil',
    'pengadilannya': 'adil',
    'pengadilanlah': 'adil',
    'pengadilani': 'adil',
    'pengadilanan': 'adil',
    'berkeadilan': 'adil',
    'berkeadilannya': 'adil',
    'berkeadilanlah': 'adil',
    'mengadon': 'adon',
    'adonan': 'adon',
    'adonannya': 'adon',
    'pengadopsi': 'adopsi',
    'pengadopsinya': 'adopsi',
    'pengadopsian': 'adopsi',
    'mengadopsi': 'adopsi',
    'mengadopsinya': 'adopsi',
    'mengadopsikan': 'adopsi',
    'pengadopsiannya': 'adopsi',
    'mengadreskan': 'adres',
    'teradu domba': 'adu domba',
    'mengadu domba': 'adu domba',
    'pengadu domba': 'adu domba',
    'pengadudombaan': 'adu domba',
    'mengadudombakan': 'adu domba',
    'memperadudombakan': 'adu domba',
    'aduan': 'adu',
    'aduannya': 'adu',
    'aduanlah': 'adu',
    'beradu': 'radu',
    'beradunya': 'radu',
    'beradulah': 'radu',
    'beradukan': 'radu',
    'pengadu': 'adu',
    'pengadunya': 'adu',
    'pengadukan': 'aduk',
    'pengadukannya': 'aduk',
    'pengaduan': 'adu',
    'mengadu': 'adu',
    'mengadunya': 'adu',
    'mengadulah': 'adu',
    'mengadukan': 'aduk',
    'mengadukannya': 'adu',
    'mengaduan': 'adu',
    'peraduan': 'radu',
    'peraduannya': 'radu',
    'peraduanmu': 'radu',
    'pengaduannya': 'adu',
    'mengadukankan': 'adu',
    'memperadukan': 'adu',
    'pengadu untung': 'adu untung',
    'mengadu untung': 'adu untung',
    'teraduh': 'aduh',
    'mengaduh': 'aduh',
    'adukan': 'aduk',
    'adukannya': 'aduk',
    'teraduk': 'aduk',
    'mengaduk': 'aduk',
    'mengaduknya': 'aduk',
    'mengadukkan': 'aduk',
    'pengaduk': 'aduk',
    'pengaduknya': 'aduk',
    'aduk-adukan': 'aduk',
    'mengaduk-aduk': 'aduk',
    'mengaduk-aduknya': 'aduk',
    'adunan': 'adun',
    'beradun': 'adun',
    'pengadun': 'adun',
    'pengadunan': 'adun',
    'mengadunkan': 'adun',
    'beraerobatik': 'aerobatik',
    'mengafiatkan': 'afiat',
    'berafiliasi': 'afiliasi',
    'berafiliasinya': 'afiliasi',
    'beraga': 'raga',
    'beragai': 'raga',
    'keagaan': 'aga',
    'mengagakan': 'aga',
    'beragah': 'agah',
    'mengagah': 'agah',
    'mengagahi': 'agah',
    'beragah-agah': 'agah',
    'seagak': 'agak',
    'diagak': 'agak',
    'diagakan': 'agak',
    'teragak': 'agak',
    'agaknya': 'agak',
    'agak-agak': 'agak',
    'seagak-agak': 'agak',
    'mengagakkan': 'agak',
    'beragak-agak': 'agak',
    'mengagak-agak': 'agak',
    'mengagak-agihkan': 'agak-agih',
    'beragam': 'ragam',
    'beragamnya': 'ragam',
    'beragamlah': 'ragam',
    'beragaman': 'ragam',
    'beragama': 'agama',
    'beragamanya': 'agama',
    'beragamalah': 'agama',
    'beragamakan': 'agama',
    'beragamai': 'agama',
    'beragamaan': 'agama',
    'keagamaan': 'agama',
    'keagamaannya': 'agama',
    'keagamaannyalah': 'agama',
    'keberagamaan': 'agama',
    'keberagamaannya': 'agama',
    'mengagamakan': 'agama',
    'beragan': 'agan',
    'mengagan': 'agan',
    'mengagani': 'agan',
    'mengagas': 'agas',
    'mengagaskan': 'agas',
    'keagenan': 'agen',
    'keagenannya': 'agen',
    'mengageni': 'agen',
    'mengagendakan': 'agenda',
    'mengagendakannya': 'agenda',
    'beragih': 'agih',
    'peragih': 'agih',
    'mengagih': 'agih',
    'pengagihan': 'agih',
    'mengagihkan': 'agih',
    'beragitasi': 'agitasi',
    'mengagitasi': 'agitasi',
    'beragogo': 'agogo',
    'mengagresi': 'agresi',
    'keagresifan': 'agresif',
    'keagresifannya': 'agresif',
    'keagresifanku': 'agresif',
    'mengagulkan': 'agul',
    'agunan': 'agun',
    'agunannya': 'agun',
    'agunanmu': 'agun',
    'mengagunkan': 'agun',
    'keagungan': 'agung',
    'keagungannya': 'agung',
    'mengagungkan': 'agung',
    'mengagungkannya': 'agung',
    'beragustusan': 'agustus',
    'mengagut-agut': 'agut',
    'mengahadkan': 'ahad',
    'keahlian': 'ahli',
    'keahliannya': 'ahli',
    'keahlianku': 'ahli',
    'keahlianmu': 'ahli',
    'mengahlikan': 'ahli',
    'berkeahlian': 'ahli',
    'keahlinegaraan': 'ahli negara',
    'keaiban': 'aib',
    'mengaibkan': 'aib',
    'berair': 'air',
    'berairan': 'air',
    'keairan': 'air',
    'perairan': 'air',
    'perairannya': 'air',
    'perairani': 'air',
    'perairanan': 'air',
    'mengairi': 'air',
    'mengairinya': 'air',
    'pengairan': 'air',
    'pengairannya': 'air',
    'berpengairan': 'air',
    'keajaiban': 'ajaib',
    'keajaibannya': 'ajaib',
    'keajaibanlah': 'ajaib',
    'keajaibanku': 'ajaib',
    'keajaiban-mu': 'ajaib',
    'mengajaibkan': 'ajaib',
    'ajakan': 'ajak',
    'ajakannya': 'ajak',
    'ajakanlah': 'ajak',
    'ajakanku': 'ajak',
    'ajakanmu': 'ajak',
    'mengajak': 'ajak',
    'mengajaknya': 'ajak',
    'mengajakkan': 'ajak',
    'mengajakan': 'ajak',
    'mengajakku': 'ajak',
    'mengajakmu': 'ajak',
    'ajaran': 'ajar',
    'ajarannya': 'ajar',
    'ajaranku': 'ajar',
    'ajaran-ku': 'ajar',
    'belajar': 'ajar',
    'belajarnya': 'ajar',
    'belajarlah': 'ajar',
    'belajarkan': 'ajar',
    'belajari': 'ajar',
    'belajarmu': 'ajar',
    'pelajar': 'ajar',
    'pelajarnya': 'ajar',
    'pelajari': 'ajar',
    'pelajaran': 'ajar',
    'mengajar': 'ajar',
    'mengajarnya': 'ajar',
    'mengajarkan': 'ajar',
    'mengajarkannya': 'ajar',
    'mengajari': 'ajar',
    'mengajaran': 'ajar',
    'mengajarku': 'ajar',
    'mengajarmu': 'ajar',
    'pengajar': 'ajar',
    'pengajarnya': 'ajar',
    'pengajaran': 'ajar',
    'pelajarannya': 'ajar',
    'pelajaranlah': 'ajar',
    'pelajaranmu': 'ajar',
    'mengajarinya': 'ajar',
    'mengajariku': 'ajar',
    'mengajarimu': 'ajar',
    'pembelajar': 'ajar',
    'pembelajarnya': 'ajar',
    'pembelajaran': 'ajar',
    'pengajarannya': 'ajar',
    'terpelajar': 'ajar',
    'mempelajari': 'ajar',
    'mempelajarinya': 'ajar',
    'pemelajaran': 'ajar',
    'mengajarkankan': 'ajar',
    'mengajarkanku': 'ajar',
    'mengajarkanmu': 'ajar',
    'pembelajarannya': 'ajar',
    'pembelajaranku': 'ajar',
    'berpelajaran': 'ajar',
    'membelajarkan': 'ajar',
    'keterpelajaran': 'ajar',
    'keterpelajarannya': 'ajar',
    'berajojing': 'ajojing',
    'ajuan': 'aju',
    'ajuannya': 'aju',
    'pengajuan': 'aju',
    'pengajuannya': 'aju',
    'pengajuanmu': 'aju',
    'mengajukan': 'aju',
    'mengajukannya': 'aju',
    'diajuk': 'ajuk',
    'diajukkan': 'ajuk',
    'diajukkannya': 'ajuk',
    'diajukan': 'ajuk',
    'keajukan': 'ajuk',
    'mengajuk': 'ajuk',
    'mengajukkan': 'ajuk',
    'mengajukkannya': 'ajuk',
    'diajun': 'ajun',
    'terajun': 'ajun',
    'mengajun': 'ajun',
    'mengajunkan': 'ajun',
    'berakad': 'akad',
    'berakal': 'akal',
    'berakali': 'akal',
    'mengakali': 'akal',
    'mengakalinya': 'akal',
    'akal-akal': 'akal',
    'akal-akalnya': 'akal',
    'akal-akalan': 'akal',
    'seakal-akal': 'akal',
    'seakal budi': 'akal',
    'mengakalkan': 'akal',
    'akanan': 'akan',
    'berakan': 'akan',
    'keakanan': 'akan',
    'mengakan': 'akan',
    'berseakan': 'akan',
    'akan-akan': 'akan',
    'keseakanan': 'akan',
    'seakan-akan': 'akan',
    'mengakankan': 'akan',
    'berakar': 'akar',
    'berakarnya': 'akar',
    'berakarkan': 'akar',
    'mengakar': 'akar',
    'mengakarnya': 'akar',
    'mengakarkan': 'akar',
    'mengakari': 'akar',
    'perakaran': 'akar',
    'perakarannya': 'akar',
    'akar-akaran': 'akar',
    'keakasan': 'akas',
    'akhiran': 'akhir',
    'akhirannya': 'akhir',
    'berakhir': 'akhir',
    'berakhirnya': 'akhir',
    'berakhirlah': 'akhir',
    'berakhirkan': 'akhir',
    'berakhiri': 'akhir',
    'berakhiran': 'akhir',
    'terakhir': 'akhir',
    'terakhirnya': 'akhir',
    'terakhirlah': 'akhir',
    'terakhirkan': 'akhir',
    'terakhiri': 'akhir',
    'terakhirnyalah': 'akhir',
    'terakhirku': 'akhir',
    'terakhirmu': 'akhir',
    'akhirnya': 'akhir',
    'akhirnyanya': 'akhir',
    'akhirnyalah': 'akhir',
    'mengakhiri': 'akhir',
    'mengakhirinya': 'akhir',
    'mengakhirii': 'akhir',
    'pengakhiran': 'akhir',
    'mengakhirkan': 'akhir',
    'akhir-akhirnya': 'akhir',
    'aki-aki': 'aki',
    'berakibat': 'akibat',
    'berakibatnya': 'akibat',
    'berakibatkan': 'akibat',
    'berakibatan': 'akibat',
    'akibatnya': 'akibat',
    'akibatnyanya': 'akibat',
    'mengakibatkan': 'akibat',
    'mengakibatkannya': 'akibat',
    'mengakibatkani': 'akibat',
    'berakikah': 'akikah',
    'mengakikahkan': 'akikah',
    'mengakomodasi': 'akomodasi',
    'mengakomodasinya': 'akomodasi',
    'mengakomodasikan': 'akomodasi',
    'mengakomodasikannya': 'akomodasi',
    'keakraban': 'akrab',
    'keakrabannya': 'akrab',
    'keakrabanlah': 'akrab',
    'mengakrabi': 'akrab',
    'mengakrabinya': 'akrab',
    'mengakrabkan': 'akrab',
    'mengakrabkankan': 'akrab',
    'berakrobat': 'akrobat',
    'pengakroniman': 'akronim',
    'mengakronimkan': 'akronim',
    'beraksara': 'aksara',
    'keberaksaraan': 'aksara',
    'mengaksentuasi': 'aksentuasi',
    'mengaksentuasikan': 'aksentuasi',
    'mengaksep': 'aksep',
    'mengakses': 'akses',
    'mengaksesnya': 'akses',
    'mengakseskan': 'akses',
    'mengaksesi': 'akses',
    'beraksi': 'aksi',
    'beraksinya': 'aksi',
    'beraksilah': 'aksi',
    'pengaktif': 'aktif',
    'pengaktifkan': 'aktif',
    'pengaktifkannya': 'aktif',
    'pengaktifan': 'aktif',
    'keaktifan': 'aktif',
    'keaktifannya': 'aktif',
    'keaktifanku': 'aktif',
    'keaktifanmu': 'aktif',
    'pengaktifannya': 'aktif',
    'mengaktifkan': 'aktif',
    'mengaktifkannya': 'aktif',
    'aktinisme': 'aktinik',
    'pengaktualan': 'aktual',
    'mengaktualkan': 'aktual',
    'mengaktualkannya': 'aktual',
    'mengaktualisasi': 'aktualisasi',
    'mengaktualisasikan': 'aktualisasi',
    'mengaktualisasikannya': 'aktualisasi',
    'akuan': 'aku',
    'beraku': 'aku',
    'berakunya': 'aku',
    'keakuan': 'aku',
    'keakuannya': 'aku',
    'mengaku': 'aku',
    'mengakunya': 'aku',
    'mengakulah': 'aku',
    'mengakukan': 'aku',
    'mengakui': 'aku',
    'mengakuan': 'aku',
    'mengakuku': 'aku',
    'pengaku': 'aku',
    'pengakukan': 'aku',
    'pengakui': 'aku',
    'pengakuan': 'aku',
    'mengakuinya': 'aku',
    'mengakuii': 'aku',
    'mengakuiku': 'aku',
    'pengakuannya': 'aku',
    'pengakuanku': 'aku',
    'beraku-akuan': 'aku',
    'pengakuisisi': 'akuisisi',
    'pengakuisisian': 'akuisisi',
    'mengakuisisi': 'akuisisi',
    'mengakuisisinya': 'akuisisi',
    'terakuk': 'akuk',
    'berakumulasi': 'akumulasi',
    'terakumulasi': 'akumulasi',
    'terakumulasinya': 'akumulasi',
    'mengakumulasi': 'akumulasi',
    'mengakumulasinya': 'akumulasi',
    'mengakumulasikan': 'akumulasi',
    'mengakumulasikannya': 'akumulasi',
    'perakunan': 'akun',
    'perakuntanan': 'akuntan',
    'keakuran': 'akur',
    'mengakuri': 'akur',
    'mengakurkan': 'akur',
    'keakuratan': 'akurat',
    'keakuratannya': 'akurat',
    'terala': 'ala',
    'teralai': 'ala',
    'alahan': 'alah',
    'beralah': 'alah',
    'kealahan': 'alah',
    'mengalah': 'kalah',
    'mengalahnya': 'kalah',
    'mengalahlah': 'kalah',
    'mengalahkan': 'kalah',
    'mengalahkannya': 'kalah',
    'mengalahi': 'kalah',
    'mengalahan': 'kalah',
    'peralahan': 'alah',
    'teralahkan': 'alah',
    'pengalahan': 'alah',
    'mengalahkankan': 'kalah',
    'mengalahkanku': 'kalah',
    'mengalahkanmu': 'kalah',
    'alah-mengalahi': 'alah',
    'sealak-alak': 'alak',
    'beralam': 'alam',
    'beralaman': 'alam',
    'kealaman': 'alam',
    'mengalami': 'alam',
    'mengalaminya': 'alam',
    'mengalamilah': 'alam',
    'mengalamii': 'alam',
    'pengalaman': 'alam',
    'pengalamannya': 'alam',
    'pengalamanlah': 'alam',
    'pengalamankan': 'alam',
    'pengalamanan': 'alam',
    'pengalamanku': 'alam',
    'pengalamanmu': 'alam',
    'berpengalaman': 'alam',
    'berpengalamannya': 'alam',
    'berpengalamanlah': 'alam',
    'berpengalamanan': 'alam',
    'beralamat': 'alamat',
    'beralamatkan': 'alamat',
    'mengalamati': 'alamat',
    'mengalamatkan': 'alamat',
    'mengalamatkannya': 'alamat',
    'alangan': 'alang',
    'teralang': 'alang',
    'beralang': 'alang',
    'pengalang': 'alang',
    'pengalangan': 'alang',
    'mengalang': 'alang',
    'mengalangi': 'alang',
    'beralangan': 'alang',
    'mengalanginya': 'alang',
    'mengalangkan': 'alang',
    'alang-alangan': 'alang',
    'teralang-alang': 'alang',
    'mengalang-alangi': 'alang',
    'mengalap': 'alap',
    'dialas': 'alas',
    'dialaskan': 'alas',
    'dialasi': 'alas',
    'dialasan': 'alas',
    'alasan': 'alas',
    'alasannya': 'alas',
    'alasanlah': 'alas',
    'alasanku': 'alas',
    'alasanmu': 'alas',
    'beralas': 'alas',
    'beralaskan': 'alas',
    'beralasan': 'alas',
    'mengalas': 'alas',
    'mengalasi': 'alas',
    'beralasannya': 'alas',
    'beralasanlah': 'alas',
    'beralasankan': 'alas',
    'pengalasan': 'alas',
    'mengalaskan': 'alas',
    'beralat': 'alat',
    'beralatan': 'alat',
    'mengalati': 'alat',
    'peralatan': 'alat',
    'peralatannya': 'alat',
    'peralatanlah': 'alat',
    'peralatanan': 'alat',
    'memperalat': 'alat',
    'memperalatnya': 'alat',
    'memperalati': 'alat',
    'mengalatkan': 'alat',
    'memperalatkan': 'alat',
    'aleman': 'alem',
    'mengali': 'ali',
    'mengalikan': 'kali',
    'mengalikannya': 'kali',
    'pengali-ali': 'ali-ali',
    'mengali-ali': 'ali-ali',
    'beraliansi': 'aliansi',
    'teralienasi': 'alienasi',
    'teralienasinya': 'alienasi',
    'alif-alifan': 'alif',
    'pengalihaksara': 'alih aksara',
    'pengalihaksaraan': 'alih aksara',
    'mengalihaksarakan': 'alih aksara',
    'pengalih bahasa': 'alih bahasa',
    'pengalihbahasaan': 'alih bahasa',
    'mengalihbahasakan': 'alih bahasa',
    'beralih fungsi': 'alih fungsi',
    'teralih': 'alih',
    'teralihnya': 'alih',
    'teralihkan': 'alih',
    'teralihkannya': 'alih',
    'beralih': 'alih',
    'beralihnya': 'alih',
    'beralihlah': 'alih',
    'beralihkan': 'alih',
    'beralihan': 'alih',
    'mengalih': 'alih',
    'mengalihkan': 'alih',
    'mengalihkannya': 'alih',
    'mengalihan': 'alih',
    'peralihan': 'alih',
    'peralihannya': 'alih',
    'alih-alih': 'alih',
    'pengalihan': 'alih',
    'pengalihannya': 'alih',
    'pengalihanlah': 'alih',
    'mengalihkanmu': 'alih',
    'beralih tugas': 'alih tugas',
    'pengalihtugasan': 'alih tugas',
    'mengalihtugaskan': 'alih tugas',
    'kealiman': 'alim',
    'kealimannya': 'alim',
    'mengalin': 'alin',
    'mengalinkan': 'alin',
    'alingan': 'aling',
    'mengalingi': 'aling',
    'aling-aling': 'aling',
    'aling-alingan': 'aling',
    'alip-alipan': 'alip',
    'aliran': 'alir',
    'alirannya': 'alir',
    'alirani': 'alir',
    'mengalir': 'alir',
    'mengalirnya': 'alir',
    'mengalirlah': 'alir',
    'mengalirkan': 'alir',
    'mengalirkannya': 'alir',
    'mengaliri': 'alir',
    'mengaliran': 'alir',
    'mengalirinya': 'alir',
    'pengaliran': 'alir',
    'pengalirannya': 'alir',
    'mengalit': 'alit',
    'kealkalian': 'alkali',
    'pengalkoholan': 'alkohol',
    'alkoholometer': 'alkoholisme',
    'ke-allah-an': 'allah',
    'pengalokasian': 'alokasi',
    'pengalokasiannya': 'alokasi',
    'mengalokasikan': 'alokasi',
    'mengalokasikannya': 'alokasi',
    'alon-alon': 'alon',
    'teralpa': 'alpa',
    'kealpaan': 'alpa',
    'kealpaannya': 'alpa',
    'mengalpakan': 'alpa',
    'beralu-aluan': 'alu',
    'mengalum': 'alum',
    'alunan': 'alun',
    'alunannya': 'alun',
    'beralun': 'alun',
    'beralunkan': 'alun',
    'beralunan': 'alun',
    'teralun': 'alun',
    'mengalun': 'alun',
    'mengalunlah': 'alun',
    'mengalunkan': 'alun',
    'beralun-alun': 'alun',
    'mengalup': 'alup',
    'aluran': 'alur',
    'beralur': 'alur',
    'alur-aluran': 'alur',
    'mengalur-alur': 'alur',
    'mengamkan': 'am',
    'mengamkankan': 'am',
    'amai-amai': 'amai',
    'amalan': 'amal',
    'amalannya': 'amal',
    'amalanmu': 'amal',
    'beramal': 'amal',
    'pengamal': 'amal',
    'pengamalan': 'amal',
    'pengamalannya': 'amal',
    'mengamalkan': 'amal',
    'mengamalkannya': 'amal',
    'pengamalgam': 'amalgam',
    'pengamalgaman': 'amalgam',
    'keamanan': 'aman',
    'keamanannya': 'aman',
    'keamananlah': 'aman',
    'keamananan': 'aman',
    'keamananku': 'aman',
    'keamananmu': 'aman',
    'pengaman': 'aman',
    'pengamannya': 'aman',
    'pengamankan': 'aman',
    'pengamanan': 'aman',
    'pengamanku': 'aman',
    'pengamanmu': 'aman',
    'pengamanannya': 'aman',
    'pengamananan': 'aman',
    'memperaman': 'aman',
    'mengamankan': 'aman',
    'mengamankannya': 'aman',
    'mengamankankan': 'aman',
    'pengamanah': 'amanah',
    'mengamanahkan': 'amanah',
    'mengamanahkannya': 'amanah',
    'beramanat': 'amanat',
    'mengamanati': 'amanat',
    'pengamanatan': 'amanat',
    'mengamanatkan': 'amanat',
    'mengamanatkannya': 'amanat',
    'mengamang': 'amang',
    'mengamangkan': 'amang',
    'mengamangi': 'amang',
    'mengamang-amang': 'amang',
    'amaran': 'amar',
    'amarannya': 'amar',
    'mengamarkan': 'amar',
    'amatan': 'amat',
    'amatannya': 'amat',
    'teramat': 'amat',
    'teramati': 'amat',
    'pengamat': 'amat',
    'pengamatnya': 'amat',
    'pengamatan': 'amat',
    'mengamati': 'amat',
    'mengamatinya': 'amat',
    'mengamatiku': 'amat',
    'memperamat': 'amat',
    'pengamatannya': 'amat',
    'memperamatkan': 'amat',
    'mengamat-amati': 'amat',
    'memperamat-amat': 'amat',
    'memperamat-amatkan': 'amat',
    'amatir-amatiran': 'amatir',
    'ambaian': 'ambai',
    'mengambai': 'ambai',
    'mengambaikan': 'ambai',
    'berambai-ambai': 'ambai',
    'mengambai-ambaikan': 'ambai',
    'diambak': 'ambak',
    'mengambak': 'ambak',
    'ambalan': 'ambal',
    'ambalannya': 'ambal',
    'mengambal': 'ambal',
    'mengambali': 'ambal',
    'berambal-ambalan': 'ambal',
    'terambang': 'ambang',
    'mengambang': 'kambang',
    'mengambangnya': 'kambang',
    'mengambangkan': 'kambang',
    'mengambangkannya': 'kambang',
    'mengambangi': 'kambang',
    'mengambangan': 'kambang',
    'terambang-ambang': 'ambang',
    'mengambang-ambang': 'ambang',
    'terambau': 'ambau',
    'berambau': 'ambau',
    'mengambau': 'ambau',
    'ambekan': 'ambek',
    'mengambek': 'ambek',
    'pengambekparamaartaan': 'ambek paramaarta',
    'mengambekparamaartakan': 'ambek paramaarta',
    'mengambil alih': 'ambil alih',
    'pengambilalihan': 'ambil alih',
    'pengambilalihannya': 'ambil alih',
    'ambilan': 'ambil',
    'terambil': 'ambil',
    'mengambil': 'ambil',
    'mengambilnya': 'ambil',
    'mengambilkan': 'ambil',
    'mengambilkannya': 'ambil',
    'mengambili': 'ambil',
    'mengambilan': 'ambil',
    'mengambilku': 'ambil',
    'mengambilmu': 'ambil',
    'pengambil': 'ambil',
    'pengambilnya': 'ambil',
    'pengambilkan': 'ambil',
    'pengambilan': 'ambil',
    'pengambilannya': 'ambil',
    'berambil-ambil': 'ambil',
    'ambil-mengambil': 'ambil',
    'ambinan': 'ambin',
    'mengambin': 'ambin',
    'berambin': 'ambin',
    'berambisi': 'ambisi',
    'berambisinya': 'ambisi',
    'ambring-ambringan': 'ambring',
    'keambrukan': 'ambruk',
    'keambrukannya': 'ambruk',
    'pengambrukan': 'ambruk',
    'mengambrukkan': 'ambruk',
    'mengambul': 'ambul',
    'mengambulkan': 'ambul',
    'mengambung': 'ambung',
    'mengambungkan': 'ambung',
    'terambung-ambung': 'ambung',
    'mengambung-ambung': 'ambung',
    'mengambung-ambungkan': 'ambung',
    'mengambur': 'ambur',
    'mengamburkan': 'ambur',
    'pengamen': 'amen',
    'pengamennya': 'amen',
    'mengamen': 'amen',
    'mengamennya': 'amen',
    'mengamenku': 'amen',
    'mengamenmu': 'amen',
    'mengamini': 'amin',
    'mengamininya': 'amin',
    'mengaminkan': 'amin',
    'pengamitan': 'amit',
    'pengamorfan': 'amorf',
    'mengamortisasi': 'amortisasi',
    'ampaian': 'ampai',
    'berampai': 'ampai',
    'terampai': 'ampai',
    'mengampai': 'ampai',
    'mengampaikan': 'ampai',
    'mengampelas': 'ampelas',
    'pengampelas': 'ampelas',
    'pengampelasan': 'ampelas',
    'mengampelasi': 'ampelas',
    'mengamplopi': 'amplop',
    'mengamplopkan': 'amplop',
    'amprung-amprungan': 'amprung',
    'pengampu': 'ampu',
    'pengampunya': 'ampu',
    'pengampuan': 'ampu',
    'mengampu': 'ampu',
    'mengampunya': 'ampu',
    'mengampukan': 'ampu',
    'keampuhan': 'ampuh',
    'keampuhannya': 'ampuh',
    'mengampuh': 'ampuh',
    'pengampuh': 'ampuh',
    'mengampuhkan': 'ampuh',
    'mengampul': 'ampul',
    'mengampulkan': 'ampul',
    'ampuni': 'ampun',
    'ampunilah': 'ampun',
    'ampunan': 'ampun',
    'ampunannya': 'ampun',
    'ampunan-mu': 'ampun',
    'keampunan': 'ampun',
    'terampuni': 'ampun',
    'pengampun': 'ampun',
    'pengampunan': 'ampun',
    'mengampuni': 'ampun',
    'mengampuninya': 'ampun',
    'mengampuniku': 'ampun',
    'mengampunimu': 'ampun',
    'pengampunannya': 'ampun',
    'pengampunanlah': 'ampun',
    'pengampunanmu': 'ampun',
    'mengampunkan': 'ampun',
    'amputan': 'amput',
    'mengamput': 'amput',
    'teramputasi': 'amputasi',
    'mengamputasi': 'amputasi',
    'mengamputasinya': 'amputasi',
    'pengamputasian': 'amputasi',
    'amukan': 'amuk',
    'amukannya': 'amuk',
    'beramuk': 'amuk',
    'mengamuk': 'amuk',
    'mengamuknya': 'amuk',
    'mengamuklah': 'amuk',
    'mengamuki': 'amuk',
    'pengamuk': 'amuk',
    'pengamukan': 'amuk',
    'mengamukkan': 'amuk',
    'beramuk-amuk': 'amuk',
    'beramuk-amukan': 'amuk',
    'teramung': 'amung',
    'amung-amung': 'amung',
    'penganakemasan': 'anak emas',
    'menganakemaskan': 'anak emas',
    'menganakemaskannya': 'anak emas',
    'anakan': 'anak',
    'anakannya': 'anak',
    'beranak': 'anak',
    'beranaknya': 'anak',
    'anak-anak': 'anak',
    'anak-anaknya': 'anak',
    'anak-anaklah': 'anak',
    'anak-anaki': 'anak',
    'anak-anaknyalah': 'anak',
    'anak-anakku': 'anak',
    'anak-anakmu': 'anak',
    'peranakan': 'anak',
    'peranakannya': 'anak',
    'anak-anakan': 'anak',
    'anak-beranak': 'anak',
    'memperanakkan': 'anak',
    'menganak semang': 'anak semang',
    'menganak sungai': 'anak sungai',
    'penganaktirian': 'anak tiri',
    'menganaktirikan': 'anak tiri',
    'menganaktirikannya': 'anak tiri',
    'penganalisis': 'analisis',
    'menganalisis': 'analisis',
    'menganalisisnya': 'analisis',
    'menganalisisi': 'analisis',
    'penganalisisan': 'analisis',
    'menganalogikan': 'analogi',
    'menganalogikannya': 'analogi',
    'mengancaikan': 'ancai',
    'mengancai-ancaikan': 'ancai',
    'mengancak-ancak': 'ancak-ancak',
    'ancaman': 'ancam',
    'ancamannya': 'ancam',
    'ancamanlah': 'ancam',
    'ancamanan': 'ancam',
    'ancamanmu': 'ancam',
    'terancam': 'ancam',
    'terancamnya': 'ancam',
    'terancamkan': 'ancam',
    'terancaman': 'ancam',
    'mengancam': 'ancam',
    'mengancamnya': 'ancam',
    'mengancamkan': 'ancam',
    'mengancaman': 'ancam',
    'mengancamku': 'ancam',
    'pengancam': 'ancam',
    'pengancamnya': 'ancam',
    'pengancaman': 'ancam',
    'pengancamannya': 'ancam',
    'ancang ekstrinsik': 'ancang',
    'mengancar-ancar': 'ancar-ancar',
    'mengancuk': 'ancuk',
    'andaikan': 'andai',
    'seandainya': 'andai',
    'pengandaian': 'andai',
    'pengandaiannya': 'andai',
    'mengandaikan': 'andai',
    'berandai-andai': 'andai',
    'berandai-andailah': 'andai',
    'pengandak': 'andak',
    'mengandak': 'andak',
    'mengandakan': 'andak',
    'mengandakkan': 'andak',
    'andalan': 'andal',
    'andalannya': 'andal',
    'andalanan': 'andal',
    'andalanku': 'andal',
    'terandal': 'andal',
    'terandalkan': 'andal',
    'keandalan': 'andal',
    'keandalannya': 'andal',
    'mengandalkan': 'andal',
    'mengandalkannya': 'andal',
    'mengandalkanku': 'andal',
    'mengandalkanmu': 'andal',
    'keterandalan': 'andal',
    'keterandalannya': 'andal',
    'andaman': 'andam',
    'berandam': 'andam',
    'terandam': 'andam',
    'terandamnya': 'andam',
    'mengandam': 'andam',
    'pengandam': 'andam',
    'mengandamkan': 'andam',
    'mengandarkan': 'kandar',
    'anduhan': 'anduh',
    'teranduh': 'anduh',
    'menganduh': 'anduh',
    'penganduh': 'anduh',
    'menganduhkan': 'anduh',
    'keanehan': 'aneh',
    'keanehannya': 'aneh',
    'aneh-aneh': 'aneh',
    'aneh-anehnya': 'aneh',
    'aneh-anehlah': 'aneh',
    'menganehkan': 'aneh',
    'beraneh-aneh': 'aneh',
    'menganekajeniskan': 'aneka jenis',
    'beraneka': 'aneka',
    'keanekaan': 'aneka',
    'penganekaan': 'aneka',
    'menganekakan': 'aneka',
    'beraneka ragam': 'aneka ragam',
    'keanekaragaman': 'aneka ragam',
    'keanekaragamannya': 'aneka ragam',
    'penganekaragaman': 'aneka ragam',
    'menganekaragamkan': 'aneka ragam',
    'menganeksasi': 'aneksasi',
    'menganeksasinya': 'aneksasi',
    'menganeksasikan': 'aneksasi',
    'terangah': 'angah',
    'mengangan': 'angan',
    'mengangankan': 'angan',
    'mengangani': 'angan',
    'angan-angan': 'angan',
    'angan-angannya': 'angan',
    'angan-angankan': 'angan',
    'angan-anganmu': 'angan',
    'berangan-angan': 'angan',
    'mengangan-angan': 'angan',
    'mengangan-angankan': 'angan',
    'berangga': 'rangga',
    'beranggakan': 'rangga',
    'beranggaan': 'rangga',
    'menganggali': 'anggal',
    'menganggalkan': 'anggal',
    'anggapan': 'anggap',
    'anggapannya': 'anggap',
    'anggapanku': 'anggap',
    'menganggap': 'anggap',
    'menganggapnya': 'anggap',
    'menganggapkan': 'anggap',
    'menganggapi': 'anggap',
    'menganggapan': 'anggap',
    'menganggapku': 'anggap',
    'menganggapmu': 'anggap',
    'beranggapan': 'anggap',
    'beranggap-anggapan': 'anggap',
    'anggaran': 'anggar',
    'anggarannya': 'anggar',
    'anggaranlah': 'anggar',
    'anggarankan': 'anggar',
    'anggarani': 'anggar',
    'anggaranku': 'anggar',
    'peanggar': 'anggar',
    'peanggaran': 'anggar',
    'beranggar': 'anggar',
    'beranggarkan': 'anggar',
    'beranggaran': 'anggar',
    'menganggar': 'anggar',
    'menganggarkan': 'anggar',
    'menganggarkannya': 'anggar',
    'menganggaran': 'anggar',
    'penganggaran': 'anggar',
    'penganggarannya': 'anggar',
    'anggar-anggar': 'anggar',
    'teranggar-anggar': 'anggar',
    'anggitan': 'anggit',
    'anggitannya': 'anggit',
    'menganggit': 'anggit',
    'mengangglap': 'angglap',
    'pengangglapan': 'angglap',
    'beranggota': 'anggota',
    'beranggotakan': 'anggota',
    'beranggotaan': 'anggota',
    'keanggotaan': 'anggota',
    'keanggotaannya': 'anggota',
    'penganggrekan': 'anggrek',
    'menganggrekkan': 'anggrek',
    'anggukan': 'angguk',
    'anggukannya': 'angguk',
    'berangguk': 'angguk',
    'pengangguk': 'angguk',
    'mengangguk': 'angguk',
    'mengangguklah': 'angguk',
    'menganggukkan': 'angguk',
    'menganggukan': 'angguk',
    'berangguk-angguk': 'angguk',
    'terangguk-angguk': 'angguk',
    'mengangguk-angguk': 'angguk',
    'mengangguk-anggukkan': 'angguk',
    'mengangguk-anggukan': 'angguk',
    'beranggul': 'anggul',
    'menganggul': 'anggul',
    'teranggul-anggul': 'anggul',
    'keanggunan': 'anggun',
    'keanggunannya': 'anggun',
    'menganggung': 'anggung',
    'menganggungkan': 'anggung',
    'anggung gaya': 'anggung',
    'angguran': 'anggur',
    'penganggur': 'anggur',
    'pengangguran': 'anggur',
    'menganggur': 'anggur',
    'menganggurnya': 'anggur',
    'menganggurkan': 'anggur',
    'penganggurannya': 'anggur',
    'pengangguranlah': 'anggur',
    'beranggut': 'anggut',
    'menganggut': 'anggut',
    'menganggut-anggut': 'anggut',
    'seangin': 'angin',
    'terangin': 'angin',
    'berangin': 'angin',
    'mengangin': 'angin',
    'keanginan': 'angin',
    'mengangini': 'angin',
    'peranginan': 'angin',
    'angin-angin': 'angin',
    'angin-anginnya': 'angin',
    'angin-anginkan': 'angin',
    'angin-anginan': 'angin',
    'menganginkan': 'angin',
    'angin-anginannya': 'angin',
    'memperanginkan': 'angin',
    'terangin-angin': 'angin',
    'berangin-angin': 'angin',
    'mengangin-anginkan': 'angin',
    'mengangin-anginkannya': 'angin',
    'mengangka': 'angka',
    'mengangkai': 'angka',
    'perangkaan': 'angka',
    'pengangkaan': 'angka',
    'mengangkakan': 'angka',
    'berangka-angka': 'angka',
    'berangka-angkaan': 'angka',
    'keangkaraan': 'angkara',
    'mengangkasa': 'angkasa',
    'mengangkasanya': 'angkasa',
    'angkatan': 'angkat',
    'angkatannya': 'angkat',
    'perangkat': 'angkat',
    'perangkatnya': 'angkat',
    'perangkatkan': 'angkat',
    'perangkatan': 'angkat',
    'perangkatmu': 'angkat',
    'terangkat': 'angkat',
    'terangkatnya': 'angkat',
    'terangkatlah': 'angkat',
    'seangkatan': 'angkat',
    'seangkatannya': 'angkat',
    'seangkatanmu': 'angkat',
    'mengangkat': 'angkat',
    'mengangkatnya': 'angkat',
    'mengangkatkan': 'angkat',
    'mengangkati': 'angkat',
    'mengangkatan': 'angkat',
    'mengangkatku': 'angkat',
    'mengangkatmu': 'angkat',
    'pengangkat': 'angkat',
    'pengangkatnya': 'angkat',
    'pengangkatan': 'angkat',
    'seperangkat': 'perangkat',
    'pengangkatannya': 'angkat',
    'pengangkatanku': 'angkat',
    'seperangkatan': 'angkat',
    'mengangkat-angkat': 'angkat',
    'mengangkat-angkatnya': 'angkat',
    'mengangkit': 'angkit',
    'angkringan': 'angkring',
    'angkringannya': 'angkring',
    'keangkuhan': 'angkuh',
    'keangkuhannya': 'angkuh',
    'mengangkup': 'angkup',
    'angkup-angkup': 'angkup',
    'terangkup-angkup': 'angkup',
    'angkutan': 'angkut',
    'angkutannya': 'angkut',
    'angkutanlah': 'angkut',
    'angkutanku': 'angkut',
    'mengangkut': 'angkut',
    'mengangkutnya': 'angkut',
    'mengangkutkan': 'angkut',
    'mengangkuti': 'angkut',
    'pengangkut': 'angkut',
    'pengangkutnya': 'angkut',
    'pengangkutan': 'angkut',
    'mengangkutinya': 'angkut',
    'pengangkutannya': 'angkut',
    'menganglap': 'anglap',
    'menganglong': 'anglong',
    'angonan': 'angon',
    'mengangon': 'angon',
    'pengangon': 'angon',
    'pengangonan': 'angon',
    'mengangop': 'angop',
    'mengangsu': 'angsu',
    'angsuran': 'angsur',
    'angsurannya': 'angsur',
    'angsuranku': 'angsur',
    'berangsur': 'angsur',
    'mengangsur': 'angsur',
    'mengangsurnya': 'angsur',
    'mengangsurkan': 'angsur',
    'pengangsuran': 'angsur',
    'mengangut': 'angut',
    'anian': 'ani',
    'mengani': 'ani',
    'teraniaya': 'aniaya',
    'teraniayanya': 'aniaya',
    'menganiaya': 'aniaya',
    'menganiayanya': 'aniaya',
    'menganiayai': 'aniaya',
    'menganiayaan': 'aniaya',
    'menganiayaku': 'aniaya',
    'penganiaya': 'aniaya',
    'penganiayanya': 'aniaya',
    'penganiayaan': 'aniaya',
    'penganiayaannya': 'aniaya',
    'teranja-anja': 'anja',
    'beranja-anja': 'anja',
    'dianjak': 'anjak',
    'beranjak': 'anjak',
    'beranjaknya': 'anjak',
    'beranjaklah': 'anjak',
    'menganjak': 'anjak',
    'keberanjakan': 'anjak',
    'keanjalan': 'anjal',
    'menganjal': 'anjal',
    'beranjang': 'anjang',
    'beranjangkarya': 'anjangkarya',
    'beranjangsana': 'anjangsana',
    'peranjingan': 'anjing',
    'menganju': 'anju',
    'menganjukan': 'anju',
    'anjungan': 'anjung',
    'anjungannya': 'anjung',
    'beranjung': 'anjung',
    'menganjung': 'anjung',
    'anjung-anjung': 'anjung',
    'menganjungkan': 'anjung',
    'anjung-anjungan': 'anjung',
    'menganjung-anjung': 'anjung',
    'menganjung-anjungkan': 'anjung',
    'anjuran': 'anjur',
    'anjurannya': 'anjur',
    'beranjur': 'anjur',
    'teranjur': 'anjur',
    'penganjur': 'anjur',
    'penganjurnya': 'anjur',
    'penganjuran': 'anjur',
    'menganjur': 'anjur',
    'menganjurkan': 'anjur',
    'menganjurkannya': 'anjur',
    'menganjuran': 'anjur',
    'menganjuri': 'anjur',
    'menganjurian': 'anjur',
    'menganjurkanmu': 'anjur',
    'mengantamir': 'antamir',
    'mengantapkan': 'antap',
    'antaran': 'antar',
    'antarannya': 'antar',
    'antarani': 'antar',
    'terantar': 'antar',
    'berantar': 'antar',
    'mengantar': 'antar',
    'mengantarnya': 'antar',
    'mengantarkan': 'antar',
    'mengantarkannya': 'antar',
    'mengantari': 'antar',
    'mengantaran': 'antar',
    'mengantarku': 'antar',
    'mengantarmu': 'antar',
    'pengantar': 'antar',
    'pengantarnya': 'antar',
    'pengantarkan': 'antar',
    'pengantaran': 'antar',
    'pengantarannya': 'antar',
    'mengantarkankan': 'antar',
    'mengantarkanku': 'antar',
    'mengantarkanmu': 'antar',
    'antar-mengantar': 'antar',
    'perantara': 'antara',
    'perantaranya': 'antara',
    'perantaraan': 'antara',
    'berantara': 'antara',
    'berantarakan': 'antara',
    'berantarakannya': 'antara',
    'mengantara': 'antara',
    'mengantaranya': 'antara',
    'mengantarakan': 'antara',
    'mengantarai': 'antara',
    'pengantara': 'antara',
    'pengantaranya': 'antara',
    'pengantaraan': 'antara',
    'memperantarai': 'antara',
    'berantem': 'antem',
    'berantemnya': 'antem',
    'berantemlah': 'antem',
    'beranteman': 'antem',
    'mengantepi': 'antep',
    'seantero': 'antero',
    'mengantih': 'antih',
    'pengantihan': 'antih',
    'keantikan': 'antik',
    'keantikannya': 'antik',
    'mengantikkan': 'antik',
    'menganting': 'anting',
    'mengantingi': 'anting',
    'anting-anting': 'anting',
    'anting-antingnya': 'anting',
    'anting-antingan': 'anting',
    'berantisipasi': 'antisipasi',
    'mengantisipasi': 'antisipasi',
    'mengantisipasinya': 'antisipasi',
    'mengantisipasikan': 'antisipasi',
    'antrean': 'antre',
    'antreannya': 'antre',
    'antreanku': 'antre',
    'pengantre': 'antre',
    'pengantrean': 'antre',
    'mengantre': 'antre',
    'mengantrenya': 'antre',
    'mengantrekan': 'antre',
    'mengantrei': 'antre',
    'berantuk': 'antuk',
    'terantuk': 'antuk',
    'mengantuk': 'kantuk',
    'mengantuknya': 'kantuk',
    'mengantukkan': 'kantuk',
    'berantukan': 'antuk',
    'mengantul': 'antul',
    'berantun': 'antun',
    'menganugerahi': 'anugerah',
    'menganugerahinya': 'anugerah',
    'penganugerahan': 'anugerah',
    'penganugerahannya': 'anugerah',
    'menganugerahkan': 'anugerah',
    'menganugerahkannya': 'anugerah',
    'menganulir': 'anulir',
    'menganulirnya': 'anulir',
    'menganulirkan': 'anulir',
    'anutan': 'anut',
    'anutannya': 'anut',
    'penganut': 'anut',
    'penganutnya': 'anut',
    'penganutan': 'anut',
    'menganut': 'anut',
    'menganutnya': 'anut',
    'menganuti': 'anut',
    'anyaman': 'anyam',
    'anyamannya': 'anyam',
    'anyamanan': 'anyam',
    'menganyam': 'anyam',
    'menganyamnya': 'anyam',
    'anyam-menganyam': 'anyam',
    'menganyang': 'anyang',
    'menganyang hati': 'anyang',
    'teranyar': 'anyar',
    'teranyarnya': 'anyar',
    'teranyarmu': 'anyar',
    'apaan': 'apa',
    'mengapa': 'apa',
    'mengapanya': 'apa',
    'mengapalah': 'apa',
    'mengapakan': 'apa',
    'mengapakannya': 'apa',
    'mengapai': 'apa',
    'apa-apa': 'apa',
    'apa-apanya': 'apa',
    'apa-apalah': 'apa',
    'apa-apakan': 'apa',
    'apa-apaan': 'apa',
    'apa-apanyalah': 'apa',
    'mengapainya': 'apa',
    'mengapaikan': 'apa',
    'mengapa-apai': 'apa',
    'dipengapakan': 'apa',
    'mengapam': 'apam',
    'pengapartemenan': 'apartemen',
    'berapi': 'api',
    'berapinya': 'api',
    'mengapi': 'api',
    'perapian': 'api',
    'perapiannya': 'api',
    'perapianku': 'api',
    'berapi-api': 'api',
    'berapi-apinya': 'api',
    'memperapikan': 'api',
    'mengapi-apikan': 'api',
    'mengapikkan': 'apik',
    'apitan': 'apit',
    'berapit': 'apit',
    'pengapit': 'kapit',
    'pengapitnya': 'kapit',
    'mengapit': 'apit',
    'mengapitnya': 'apit',
    'mengapitkan': 'apit',
    'mengapiti': 'apit',
    'pengapitan': 'apit',
    'memperapitkan': 'apit',
    'apkiran': 'apkir',
    'apkirannya': 'apkir',
    'mengapkir': 'apkir',
    'mengaplikasikan': 'aplikasi',
    'mengaplikasikannya': 'aplikasi',
    'aplusan': 'aplus',
    'aplusannya': 'aplus',
    'mengaplus': 'aplus',
    'perapotekan': 'apotek',
    'berapresiasi': 'apresiasi',
    'mengapresiasi': 'apresiasi',
    'mengapresiasinya': 'apresiasi',
    'mengapresiasikan': 'apresiasi',
    'mengapresiasikannya': 'apresiasi',
    'mengaprit': 'aprit',
    'aprit-apritan': 'aprit',
    'terapung': 'apung',
    'terapungnya': 'apung',
    'mengapung': 'apung',
    'mengapungnya': 'apung',
    'mengapunglah': 'apung',
    'mengapungkan': 'apung',
    'berapungan': 'apung',
    'apung-apung': 'apung',
    'terapung-apung': 'apung',
    'berapung-apung': 'apung',
    'mengarabkan': 'arab',
    'kearab-araban': 'arab',
    'searah': 'arah',
    'searahnya': 'arah',
    'arahan': 'arah',
    'arahannya': 'arah',
    'berarah': 'arah',
    'terarah': 'arah',
    'terarahnya': 'arah',
    'terarahkan': 'arah',
    'pengarah': 'arah',
    'pengarahnya': 'arah',
    'pengarahlah': 'arah',
    'pengarahkan': 'arah',
    'pengarahan': 'arah',
    'mengarah': 'arah',
    'mengarahnya': 'arah',
    'mengarahlah': 'arah',
    'mengarahkan': 'arah',
    'mengarahkannya': 'arah',
    'mengarahi': 'arah',
    'mengarahan': 'arah',
    'arah-arah': 'arah',
    'arah-arahnya': 'arah',
    'arah-arahan': 'arah',
    'penyearah': 'arah',
    'pengarahannya': 'arah',
    'pengarahanan': 'arah',
    'keterarahan': 'arah',
    'mengarahkankan': 'arah',
    'mengarahkanku': 'arah',
    'mengarahkanmu': 'arah',
    'menyearahkan': 'arah',
    'mengarah-arahi': 'arah',
    'arakan': 'arak',
    'berarak': 'arak',
    'berarakan': 'rarak',
    'pengarak': 'arak',
    'pengaraknya': 'arak',
    'pengarakan': 'arak',
    'mengarak': 'arak',
    'mengaraknya': 'arak',
    'mengarakan': 'arak',
    'perarakan': 'arak',
    'arak-arakan': 'arak',
    'arak-arakannya': 'arak',
    'berarak-arakan': 'arak',
    'pengaram': 'aram',
    'aram-aram': 'aram',
    'mengarang': 'karang',
    'mengarangnya': 'karang',
    'perarangan': 'arang',
    'pengarangan': 'karang',
    'mengarangkan': 'arang',
    'pengaransemen': 'aransemen',
    'pengaransemenan': 'aransemen',
    'mengaransemen': 'aransemen',
    'mengaras': 'aras',
    'mengarasi': 'aras',
    'mengares': 'ares',
    'berargumen': 'argumen',
    'berargumentasi': 'argumentasi',
    'berargumentasinya': 'argumentasi',
    'mengari': 'ari',
    'seari-arian': 'ari',
    'kearifan': 'arif',
    'kearifannya': 'arif',
    'kearifanlah': 'arif',
    'mengarifi': 'arif',
    'mengarifkan': 'arif',
    'mengarih': 'karih',
    'mengarik': 'arik',
    'mengariknya': 'arik',
    'pengarip': 'arip',
    'beraris': 'aris',
    'berariskan': 'aris',
    'berarisan': 'arisan',
    'mengarit': 'arit',
    'mengaritnya': 'arit',
    'pengarit': 'arit',
    'aronan': 'aron',
    'mengaron': 'aron',
    'kearsipan': 'arsip',
    'kearsipannya': 'arsip',
    'pengarsip': 'arsip',
    'pengarsipan': 'arsip',
    'mengarsipkan': 'arsip',
    'mengarsipkannya': 'arsip',
    'arsiran': 'arsir',
    'mengarsir': 'arsir',
    'artian': 'arti',
    'artiannya': 'arti',
    'artiani': 'arti',
    'searti': 'arti',
    'berarti': 'arti',
    'berartinya': 'arti',
    'berartikan': 'arti',
    'berartii': 'arti',
    'pengartian': 'arti',
    'mengartikan': 'arti',
    'mengartikannya': 'arti',
    'keberartian': 'arti',
    'mengartikelkan': 'artikel',
    'berartikulasi': 'artikulasi',
    'keartisan': 'artis',
    'keartisannya': 'artis',
    'keartistikan': 'artistik',
    'aru-aru': 'aru',
    'mengaruk': 'aruk',
    'mengarukkan': 'aruk',
    'mengarukan': 'karu',
    'mengarun': 'arun',
    'mengaruni': 'arun',
    'arungan': 'arung',
    'mengarung': 'arung',
    'mengarungnya': 'arung',
    'mengarungkan': 'arung',
    'mengarungi': 'karung',
    'mengarunginya': 'karung',
    'pengarungan': 'arung',
    'arung-arungan': 'arung',
    'mengarus': 'arus',
    'mengarusnya': 'arus',
    'mengaruskan': 'arus',
    'mengarwahkan': 'arwah',
    'mengasa': 'asa',
    'mengasalah': 'asa',
    'mengasakan': 'asak',
    'mengasai': 'asa',
    'asa-asaan': 'asa',
    'asahan': 'asah',
    'asahannya': 'asah',
    'berasah': 'asah',
    'mengasah': 'asah',
    'mengasahnya': 'asah',
    'mengasahkan': 'asah',
    'pengasah': 'asah',
    'pengasahan': 'asah',
    'diasak': 'asak',
    'diasakan': 'asak',
    'terasak': 'asak',
    'terasaki': 'asak',
    'terasakan': 'rasa',
    'berasak': 'asak',
    'berasakan': 'rasa',
    'mengasak': 'asak',
    'mengasakkan': 'asak',
    'berasak-asak': 'asak',
    'berasak-asakan': 'asak',
    'berasal': 'asal',
    'berasalnya': 'asal',
    'berasalkan': 'asal',
    'berasalan': 'asal',
    'asalkan': 'asal',
    'asal-asalan': 'asal',
    'asal-asalannya': 'asal',
    'mengasalkan': 'asal',
    'asaman': 'asam',
    'mengasam': 'kasam',
    'mengasamkan': 'kasam',
    'keasaman': 'asam',
    'keasamannya': 'asam',
    'mengasami': 'asam',
    'pengasaman': 'asam',
    'asam-asaman': 'asam',
    'berasap': 'asap',
    'berasapnya': 'asap',
    'mengasap': 'asap',
    'mengasapkan': 'asap',
    'mengasapi': 'asap',
    'perasapan': 'asap',
    'mengasapinya': 'asap',
    'pengasapan': 'asap',
    'berasap-asap': 'asap',
    'berasas': 'asas',
    'berasaskan': 'asas',
    'pengasas': 'asas',
    'mengasaskan': 'asas',
    'beraset': 'aset',
    'asian': 'asi',
    'asiani': 'asi',
    'mengasi': 'asi',
    'mengasinya': 'asi',
    'mengasikan': 'asi',
    'berasimilasi': 'asimilasi',
    'asinan': 'asin',
    'asinannya': 'asin',
    'keasinan': 'asin',
    'mengasini': 'asin',
    'pengasinan': 'asin',
    'mengasinkan': 'asin',
    'terasing': 'asing',
    'terasingnya': 'asing',
    'terasingkan': 'asing',
    'terasingi': 'asing',
    'berasing': 'asing',
    'berasingan': 'asing',
    'mengasing': 'asing',
    'mengasingkan': 'asing',
    'mengasingkannya': 'asing',
    'keasingan': 'asing',
    'perasingan': 'asing',
    'perasingannya': 'asing',
    'pengasingan': 'asing',
    'pengasingannya': 'asing',
    'mengasingkanku': 'asing',
    'berasing-asingan': 'asing',
    'mengasisteni': 'asisten',
    'keaslian': 'asli',
    'keasliannya': 'asli',
    'berasmara': 'asmara',
    'mengaso': 'aso',
    'berasonansi': 'asonansi',
    'pengasong': 'asong',
    'pengasongan': 'asong',
    'mengasong': 'asong',
    'mengasongkan': 'asong',
    'berasosiasi': 'asosiasi',
    'pengasosiasian': 'asosiasi',
    'mengasosiasikan': 'asosiasi',
    'mengasosiasikannya': 'asosiasi',
    'teraspal': 'aspal',
    'teraspalkan': 'aspal',
    'beraspal': 'aspal',
    'pengaspalan': 'aspal',
    'pengaspalannya': 'aspal',
    'beraspirasi': 'aspirasi',
    'berasrama': 'asrama',
    'pengasramaan': 'asrama',
    'mengasramakan': 'asrama',
    'keasrian': 'asri',
    'keasriannya': 'asri',
    'berastakona': 'astakona',
    'asuhan': 'asuh',
    'asuhannya': 'asuh',
    'asuhannyalah': 'asuh',
    'asuhanku': 'asuh',
    'pengasuh': 'asuh',
    'pengasuhnya': 'asuh',
    'pengasuhan': 'asuh',
    'mengasuh': 'asuh',
    'mengasuhnya': 'asuh',
    'mengasuhan': 'asuh',
    'mengasuhku': 'asuh',
    'pengasuhannya': 'asuh',
    'mengasumsikan': 'asumsi',
    'mengasumsikannya': 'asumsi',
    'asungan': 'asung',
    'pengasung': 'asung',
    'mengasung': 'asung',
    'berasuransi': 'asuransi',
    'perasuransian': 'asuransi',
    'perasuransiannya': 'asuransi',
    'pengasuransian': 'asuransi',
    'mengasuransikan': 'asuransi',
    'mengasuransikannya': 'asuransi',
    'keasyikan': 'asyik',
    'keasyikannya': 'asyik',
    'mengasyiki': 'asyik',
    'mengasyikkan': 'asyik',
    'mengasyikkannya': 'asyik',
    'asyik-asyiknya': 'asyik',
    'keasyik-asyikan': 'asyik',
    'mengatak': 'atak',
    'mengatakkan': 'atak',
    'mengatakan': 'kata',
    'pengatakan': 'atak',
    'beratap': 'atap',
    'beratapkan': 'atap',
    'mengatap': 'atap',
    'mengatapkan': 'atap',
    'mengatapi': 'atap',
    'mengatapan': 'atap',
    'pengatapan': 'atap',
    'mengatari': 'atar',
    'atasan': 'atas',
    'atasannya': 'atas',
    'atasanlah': 'atas',
    'atasannyalah': 'atas',
    'atasanku': 'atas',
    'atasanmu': 'atas',
    'teratasi': 'atas',
    'teratasinya': 'atas',
    'teratasilah': 'atas',
    'mengatas': 'atas',
    'mengatasnya': 'atas',
    'mengataskan': 'atas',
    'mengatasi': 'atas',
    'mengatasinya': 'atas',
    'mengatasikan': 'atas',
    'atas-mengatasi': 'atas',
    'mengatasnamakan': 'atas nama',
    'mengatasnamakannya': 'atas nama',
    'ati-ati': 'ati',
    'pengatoman': 'atom',
    'atung-atung': 'atung',
    'aturan': 'atur',
    'aturannya': 'atur',
    'aturanlah': 'atur',
    'beratur': 'atur',
    'beraturan': 'atur',
    'teratur': 'atur',
    'teraturnya': 'atur',
    'teraturlah': 'atur',
    'teraturan': 'atur',
    'pengatur': 'atur',
    'pengaturnya': 'atur',
    'pengaturan': 'atur',
    'mengatur': 'atur',
    'mengaturnya': 'atur',
    'mengaturkan': 'atur',
    'mengaturan': 'atur',
    'peraturan': 'atur',
    'peraturannya': 'atur',
    'peraturanlah': 'atur',
    'beraturannya': 'atur',
    'pengaturannya': 'atur',
    'keteraturan': 'atur',
    'keteraturannya': 'atur',
    'mengatus': 'atus',
    'mengatuskan': 'atus',
    'pengatusan': 'atus',
    'beraudiensi': 'audiensi',
    'pengaudit': 'audit',
    'pengauditan': 'audit',
    'mengaudit': 'audit',
    'mengauditnya': 'audit',
    'mengauditkan': 'audit',
    'mengaum': 'aum',
    'mengaumlah': 'aum',
    'mengaumkan': 'aum',
    'mengaum-aum': 'aum',
    'mengaum-aumkan': 'aum',
    'mengaung': 'aung',
    'mengaungkan': 'aung',
    'mengaur': 'aur',
    'keausan': 'aus',
    'mengaus': 'aus',
    'mengausi': 'kaus',
    'mengauskan': 'aus',
    'mengautopsi': 'autopsi',
    'mengautopsinya': 'autopsi',
    'pengawaair': 'awaair',
    'pengawabau': 'awabau',
    'mengawabekukan': 'awabeku',
    'pengawabusa': 'awabusa',
    'mengawahamakan': 'awahama',
    'berawai': 'awai',
    'terawai': 'awai',
    'mengawai': 'awai',
    'berawak': 'awak',
    'berawaknya': 'awak',
    'berawakkan': 'awak',
    'berawakan': 'rawa',
    'mengawaki': 'awak',
    'mengawakinya': 'awak',
    'perawakan': 'awak',
    'perawakannya': 'awak',
    'perawakanku': 'awak',
    'memperawak': 'awak',
    'pengawakan': 'awak',
    'berperawakan': 'awak',
    'awalan': 'awal',
    'awalannya': 'awal',
    'berawal': 'awal',
    'berawalnya': 'awal',
    'berawalan': 'awal',
    'mengawali': 'kawal',
    'mengawalinya': 'kawal',
    'mengawalilah': 'kawal',
    'mengawalengaskan': 'awalengas',
    'keawaman': 'awam',
    'keawamannya': 'awam',
    'pengawam': 'awam',
    'mengawamkan': 'awam',
    'berawan': 'rawan',
    'berawannya': 'rawan',
    'berawanan': 'rawan',
    'mengawan': 'awan',
    'mengawankan': 'awan',
    'mengawani': 'kawan',
    'perawanan': 'awan',
    'perawanannya': 'awan',
    'awan-berawan': 'awan',
    'awangan': 'awang',
    'berawang': 'awang',
    'mengawang': 'kawang',
    'mengawangi': 'kawang',
    'perawangan': 'awang',
    'awang-awang': 'awang',
    'awang-gemawang': 'awang',
    'awasan': 'awas',
    'awasannya': 'awas',
    'berawas': 'awas',
    'berawasan': 'awas',
    'terawasi': 'awas',
    'terawasinya': 'awas',
    'pengawas': 'awas',
    'pengawasnya': 'awas',
    'pengawaslah': 'awas',
    'pengawasi': 'awas',
    'pengawasan': 'awas',
    'mengawasi': 'awas',
    'mengawasinya': 'awas',
    'mengawasiku': 'awas',
    'mengawasimu': 'awas',
    'pengawasannya': 'awas',
    'pengawasani': 'awas',
    'pengawasanmu': 'awas',
    'mengawaskan': 'awas',
    'berawas-awas': 'awas',
    'mengawat': 'awat',
    'mengawatkan': 'kawat',
    'mengawati': 'awat',
    'pengawawarna': 'awawarna',
    'pengawet': 'awet',
    'pengawetnya': 'awet',
    'pengawetan': 'awet',
    'keawetan': 'awet',
    'keawetannya': 'awet',
    'pengawetannya': 'awet',
    'mengawetkan': 'awet',
    'mengawetkannya': 'awet',
    'pengawinan': 'kawin',
    'mengawur': 'awur',
    'awut-awutan': 'awut',
    'berayah': 'ayah',
    'berayahkan': 'ayah',
    'keayahan': 'ayah',
    'keayahannya': 'ayah',
    'ayakan': 'ayak',
    'ayakannya': 'ayak',
    'mengayak': 'ayak',
    'mengayakan': 'ayak',
    'pengayak': 'ayak',
    'pengayakan': 'ayak',
    'berayal-ayalan': 'ayal',
    'ayam-ayam': 'ayam',
    'ayam-ayamnya': 'ayam',
    'ayam-ayaman': 'ayam',
    'ayapan': 'ayap',
    'mengayap': 'ayap',
    'seayapan': 'ayap',
    'keayapan': 'ayap',
    'ayeng-ayengan': 'ayeng',
    'terayomi': 'ayom',
    'pengayom': 'ayom',
    'pengayoman': 'ayom',
    'mengayomi': 'ayom',
    'mengayominya': 'ayom',
    'pengayomannya': 'ayom',
    'mengayum': 'ayum',
    'ayunan': 'ayun',
    'ayunannya': 'ayun',
    'ayunanan': 'ayun',
    'ayunanmu': 'ayun',
    'berayun': 'ayun',
    'berayunan': 'ayun',
    'mengayun': 'ayun',
    'mengayunnya': 'ayun',
    'mengayunkan': 'ayun',
    'mengayunkannya': 'ayun',
    'ayun-temayun': 'ayun',
    'berayun-ayun': 'ayun',
    'mengayut': 'ayut',
    'ayut-ayutan': 'ayut',
    'mengazab': 'azab',
    'mengazabkan': 'azab',
    'berazam': 'azam',
    'keazaman': 'azam',
    'mengazamkan': 'azam',
    'mengazankan': 'azan',
    'babakan': 'babak',
    'babakannya': 'babak',
    'membabak': 'babak',
    'pembabakan': 'babak',
    'membaban': 'baban',
    'membabani': 'baban',
    'terbabang': 'babang',
    'babaran': 'babar',
    'terbabar': 'babar',
    'membabar': 'babar',
    'kebabaran': 'babar',
    'pembabaran': 'babar',
    'membabarkan': 'babar',
    'membabas': 'babas',
    'membabaskan': 'babas',
    'terbabas': 'babas',
    'sebabat': 'babat',
    'membabat': 'babat',
    'membabatnya': 'babat',
    'membabatkan': 'babat',
    'membabatkannya': 'babat',
    'membabati': 'babat',
    'pembabat': 'babat',
    'pembabatan': 'babat',
    'membabi': 'babi',
    'berbabil': 'babil',
    'pembabil': 'babil',
    'perbabilan': 'babil',
    'terbabit': 'babit',
    'membabitkan': 'babit',
    'kebablasan': 'bablas',
    'kebablasannya': 'bablas',
    'memperbabu': 'babu',
    'bacaan': 'baca',
    'bacaannya': 'baca',
    'bacaanlah': 'baca',
    'pembaca': 'baca',
    'pembacanya': 'baca',
    'pembacalah': 'baca',
    'pembacakan': 'baca',
    'pembacaan': 'baca',
    'pembacaku': 'baca',
    'terbaca': 'baca',
    'terbacanya': 'baca',
    'terbacalah': 'baca',
    'terbacakan': 'baca',
    'terbacaan': 'baca',
    'membaca': 'baca',
    'membacanya': 'baca',
    'membacalah': 'baca',
    'membacakan': 'baca',
    'membacakannya': 'baca',
    'membacaan': 'baca',
    'membacai': 'baca',
    'pembacaannya': 'baca',
    'keterbacaan': 'baca',
    'keterbacaannya': 'baca',
    'membaca-baca': 'baca',
    'membacah': 'bacah',
    'membacah-bacah': 'bacah',
    'baceman': 'bacem',
    'membacem': 'bacem',
    'bacokan': 'bacok',
    'bacokannya': 'bacok',
    'membacok': 'bacok',
    'membacoknya': 'bacok',
    'membacokkan': 'bacok',
    'membacokkannya': 'bacok',
    'membacoki': 'bacok',
    'membacokan': 'bacok',
    'membacokku': 'bacok',
    'pembacok': 'bacok',
    'pembacokkan': 'bacok',
    'pembacokan': 'bacok',
    'kebacut': 'bacut',
    'terbada-bada': 'bada',
    'membadai': 'badai',
    'berbadai': 'badai',
    'terbadai': 'badai',
    'sebadan': 'badan',
    'berbadan': 'badan',
    'berbadankan': 'badan',
    'bersebadan': 'badan',
    'menyebadani': 'badan',
    'bade-bade': 'bade',
    'membadi': 'badi',
    'berbadi': 'badi',
    'membadik': 'badik',
    'kebadungan': 'badung',
    'membadut': 'badut',
    'sebagai': 'bagai',
    'sebagainya': 'bagai',
    'sebagaikan': 'bagai',
    'sebagaii': 'bagai',
    'sebagaian': 'bagai',
    'bagaikan': 'bagai',
    'berbagai': 'bagai',
    'berbagaii': 'bagai',
    'membagaikan': 'bagai',
    'keberbagaian': 'bagai',
    'keberbagaiannya': 'bagai',
    'berbagai-bagai': 'bagai',
    'memperbagai-bagaikan': 'bagai',
    'sebagaimana': 'bagaimana',
    'sebagaimananya': 'bagaimana',
    'membagar': 'bagar',
    'berbagat': 'bagat',
    'berbagati': 'bagat',
    'bagian': 'bagi',
    'bagiannya': 'bagi',
    'bagianku': 'bagi',
    'bagianmu': 'bagi',
    'membagi': 'bagi',
    'membaginya': 'bagi',
    'membagikan': 'bagi',
    'membagikannya': 'bagi',
    'membagian': 'bagi',
    'membagimu': 'bagi',
    'terbagi': 'bagi',
    'terbaginya': 'bagi',
    'terbagilah': 'bagi',
    'terbagikan': 'bagi',
    'berbagi': 'bagi',
    'berbaginya': 'bagi',
    'berbagilah': 'bagi',
    'berbagian': 'bagi',
    'pembagi': 'bagi',
    'pembaginya': 'bagi',
    'pembagikan': 'bagi',
    'pembagian': 'bagi',
    'sebagian': 'bagi',
    'sebagiannya': 'bagi',
    'sebagiani': 'bagi',
    'kebagian': 'bagi',
    'kebagiannya': 'bagi',
    'pembagiannya': 'bagi',
    'membagi-bagikan': 'bagi',
    'membagi-bagikannya': 'bagi',
    'bagongan': 'bagong',
    'membagul': 'bagul',
    'bagusan': 'bagus',
    'terbagus': 'bagus',
    'terbagusnya': 'bagus',
    'kebagusan': 'bagus',
    'membaguskan': 'bagus',
    'memperbagus': 'bagus',
    'berbahagia': 'bahagia',
    'berbahagianya': 'bahagia',
    'berbahagialah': 'bahagia',
    'kebahagiaan': 'bahagia',
    'kebahagiaannya': 'bahagia',
    'kebahagiaanlah': 'bahagia',
    'kebahagiaanku': 'bahagia',
    'kebahagiaanmu': 'bahagia',
    'membahagiakan': 'bahagia',
    'membahagiakannya': 'bahagia',
    'membahagiakanku': 'bahagia',
    'membahagiakanmu': 'bahagia',
    'terbahak-bahak': 'bahak',
    'terbahak-bahaknya': 'bahak',
    'membaham': 'baham',
    'membahami': 'baham',
    'membahan': 'bahan',
    'pembahan': 'bahan',
    'pembahanan': 'bahan',
    'perbahanan': 'bahan',
    'berbahana': 'bahana',
    'membahana': 'bahana',
    'membahananya': 'bahana',
    'membahanakan': 'bahana',
    'terbahana': 'bahana',
    'kebaharian': 'bahari',
    'baharu baru': 'baharu',
    'bahasan': 'bahas',
    'bahasannya': 'bahas',
    'membahas': 'bahas',
    'membahasnya': 'bahas',
    'membahaskan': 'bahas',
    'membahasi': 'bahas',
    'membahasan': 'bahas',
    'pembahas': 'bahas',
    'pembahasnya': 'bahas',
    'pembahasan': 'bahas',
    'pembahasannya': 'bahas',
    'pembahasanan': 'bahas',
    'berbahasan': 'bahas',
    'perbahasan': 'bahas',
    'berbahas-bahasan': 'bahas',
    'berbahasa': 'bahasa',
    'berbahasanya': 'bahasa',
    'berbahasalah': 'bahasa',
    'berbahasamu': 'bahasa',
    'perbahasa': 'bahasa',
    'kebahasaan': 'bahasa',
    'perbahasaan': 'bahasa',
    'membahasakan': 'bahasa',
    'membahasakannya': 'bahasa',
    'memperbahasakan': 'bahasa',
    'berbahasa-bahasa': 'bahasa',
    'berbahaya': 'bahaya',
    'berbahayanya': 'bahaya',
    'berbahayalah': 'bahaya',
    'berbahayakan': 'bahaya',
    'membahayakan': 'bahaya',
    'membahayakannya': 'bahaya',
    'membahu': 'bahu',
    'bahu-membahu': 'bahu',
    'bahu-membahulah': 'bahu',
    'membaiat': 'baiat',
    'membaiatnya': 'baiat',
    'membaiatkan': 'baiat',
    'sebaik': 'baik',
    'sebaiknya': 'baik',
    'sebaiklah': 'baik',
    'sebaikan': 'baik',
    'sebaiknyalah': 'baik',
    'terbaik': 'baik',
    'terbaiknya': 'baik',
    'terbaiklah': 'baik',
    'terbaiki': 'baik',
    'terbaikan': 'baik',
    'terbaiknyalah': 'baik',
    'terbaikku': 'baik',
    'terbaikmu': 'baik',
    'membaik': 'baik',
    'membaiknya': 'baik',
    'membaiklah': 'baik',
    'membaikkan': 'baik',
    'membaiki': 'baik',
    'membaikan': 'baik',
    'berbaik': 'baik',
    'berbaikkan': 'baik',
    'berbaiki': 'baik',
    'berbaikan': 'baik',
    'kebaikan': 'baik',
    'kebaikannya': 'baik',
    'kebaikanku': 'baik',
    'kebaikanmu': 'baik',
    'kebaikan-mu': 'baik',
    'membaikinya': 'baik',
    'baik-baik': 'baik',
    'baik-baiknya': 'baik',
    'baik-baiklah': 'baik',
    'baik-baiki': 'baik',
    'baik-baikan': 'baik',
    'pembaikan': 'baik',
    'perbaikan': 'baik',
    'perbaikannya': 'baik',
    'perbaikanlah': 'baik',
    'memperbaiki': 'baik',
    'memperbaikinya': 'baik',
    'memperbaikii': 'baik',
    'memperbaikian': 'baik',
    'sebaik-baiknya': 'baik',
    'sebaik-baiknyanya': 'baik',
    'berbaik-baikan': 'baik',
    'berbait': 'bait',
    'pembaitan': 'bait',
    'berbait-bait': 'bait',
    'berbaja': 'baja',
    'membaja': 'baja',
    'membajakan': 'bajak',
    'membajai': 'baja',
    'bajakan': 'bajak',
    'bajakannya': 'bajak',
    'pembajak': 'bajak',
    'pembajaknya': 'bajak',
    'pembajaklah': 'bajak',
    'pembajakkan': 'bajak',
    'pembajakkannya': 'bajak',
    'pembajakan': 'bajak',
    'membajak': 'bajak',
    'membajaknya': 'bajak',
    'pembajakannya': 'bajak',
    'membajau': 'bajau',
    'membaji': 'baji',
    'pembajian': 'baji',
    'kebajikan': 'bajik',
    'kebajikannya': 'bajik',
    'bajingan': 'bajing',
    'bajingannya': 'bajing',
    'berbaju': 'baju',
    'berbajukan': 'baju',
    'membajui': 'baju',
    'membajul': 'bajul',
    'berbakak': 'bakak',
    'bakalan': 'bakal',
    'bakalannya': 'bakal',
    'bakalanlah': 'bakal',
    'bakalanan': 'bakal',
    'membakal': 'bakal',
    'membakali': 'bakal',
    'pembakalan': 'bakal',
    'membakalkan': 'bakal',
    'dibakar': 'bakar',
    'dibakarnya': 'bakar',
    'dibakarlah': 'bakar',
    'dibakarkan': 'bakar',
    'dibakari': 'bakar',
    'membakar': 'bakar',
    'membakarnya': 'bakar',
    'membakarkan': 'bakar',
    'membakari': 'bakar',
    'membakaran': 'bakar',
    'membakarku': 'bakar',
    'membakarmu': 'bakar',
    'pembakar': 'bakar',
    'pembakarnya': 'bakar',
    'pembakaran': 'bakar',
    'terbakar': 'bakar',
    'terbakarnya': 'bakar',
    'terbakarlah': 'bakar',
    'kebakaran': 'bakar',
    'kebakarannya': 'bakar',
    'kebakaranlah': 'bakar',
    'kebakaranan': 'bakar',
    'pembakarannya': 'bakar',
    'membakat': 'bakat',
    'berbakat': 'bakat',
    'berbakatnya': 'bakat',
    'membaksi': 'baksi',
    'berbakti': 'bakti',
    'berbaktilah': 'bakti',
    'kebaktian': 'bakti',
    'kebaktiannya': 'bakti',
    'pembaktian': 'bakti',
    'membaktikan': 'bakti',
    'kebakuan': 'baku',
    'pembakuan': 'baku',
    'membakukan': 'baku',
    'berbala-bala': 'bala',
    'membalah': 'balah',
    'berbalah': 'balah',
    'perbalahan': 'balah',
    'pembalakan': 'balak',
    'pembalakannya': 'balak',
    'berbalam': 'balam',
    'membalam': 'balam',
    'balam-balam': 'balam',
    'balapan': 'balap',
    'balapannya': 'balap',
    'balapanan': 'balap',
    'balapanku': 'balap',
    'pembalap': 'balap',
    'pembalapnya': 'balap',
    'pembalaplah': 'balap',
    'pembalapan': 'balap',
    'membalap': 'balap',
    'membalapnya': 'balap',
    'membalaplah': 'balap',
    'membalapku': 'balap',
    'berbalapan': 'balap',
    'membalapkan': 'balap',
    'membalas dendam': 'balas dendam',
    'balasan': 'balas',
    'balasannya': 'balas',
    'balasanan': 'balas',
    'balasanku': 'balas',
    'balasan-mu': 'balas',
    'berbalas': 'balas',
    'berbalasnya': 'balas',
    'berbalasan': 'balas',
    'membalas': 'balas',
    'membalasnya': 'balas',
    'membalaskan': 'balas',
    'membalaskannya': 'balas',
    'membalasi': 'balas',
    'membalasan': 'balas',
    'membalasku': 'balas',
    'pembalas': 'balas',
    'pembalasnya': 'balas',
    'pembalasan': 'balas',
    'pembalasannya': 'balas',
    'pembalasanmu': 'balas',
    'balas-membalas': 'balas',
    'balas-membalasnya': 'balas',
    'balas-berbalas': 'balas',
    'berbalas-balasan': 'balas',
    'balikan': 'balik',
    'balikannya': 'balik',
    'membalik': 'balik',
    'membaliknya': 'balik',
    'membalikkan': 'balik',
    'membalikkannya': 'balik',
    'membalikan': 'balik',
    'berbalik': 'balik',
    'berbaliknya': 'balik',
    'berbaliklah': 'balik',
    'berbalikkan': 'balik',
    'berbalikan': 'balik',
    'terbalik': 'balik',
    'terbaliknya': 'balik',
    'terbalikkan': 'balik',
    'kebalikan': 'balik',
    'kebalikannya': 'balik',
    'membaliki': 'balik',
    'sebaliknya': 'balik',
    'sebaliknyalah': 'balik',
    'pembalikan': 'balik',
    'membalikkanku': 'balik',
    'keterbalikan': 'balik',
    'berbalik-balik': 'balik',
    'membalik-balik': 'balik',
    'membalik-balikkan': 'balik',
    'membalik-balikan': 'balik',
    'berbaling': 'baling',
    'baling-baling': 'baling',
    'baling-balingnya': 'baling',
    'bolang-baling': 'baling',
    'pembalokan': 'balok',
    'baluhan': 'baluh',
    'baluian': 'balui',
    'membalun': 'balun',
    'berbalun-balun': 'balun',
    'berbalung': 'balung',
    'baluran': 'balur',
    'membalur': 'balur',
    'membalurnya': 'balur',
    'membalurkan': 'balur',
    'membalurkannya': 'balur',
    'membaluri': 'balur',
    'balutan': 'balut',
    'balutannya': 'balut',
    'pembalut': 'balut',
    'pembalutnya': 'balut',
    'pembalutan': 'balut',
    'membalut': 'balut',
    'membalutnya': 'balut',
    'membalutkan': 'balut',
    'membaluti': 'balut',
    'balut-balut': 'balut',
    'sebambang': 'bambang',
    'sebambangan': 'bambang',
    'terbambang': 'bambang',
    'bersebambangan': 'bambang',
    'bambungan': 'bambung',
    'membanat': 'banat',
    'bancakan': 'bancak',
    'bancakannya': 'bancak',
    'membancang': 'bancang',
    'membancarkan': 'bancar',
    'kebancian': 'banci',
    'kebanciannya': 'banci',
    'bancuhan': 'bancuh',
    'membancuh': 'bancuh',
    'membancuhkan': 'bancuh',
    'terbancut': 'bancut',
    'bandaran': 'bandar',
    'berbandar': 'bandar',
    'membandar': 'bandar',
    'membandari': 'bandar',
    'perbandaran': 'bandar',
    'membandarkan': 'bandar',
    'kebandaraan': 'bandara',
    'membandel': 'bandel',
    'membandelnya': 'bandel',
    'membandering': 'bandering',
    'bandingan': 'banding',
    'bandingannya': 'banding',
    'bandinganlah': 'banding',
    'bandingankan': 'banding',
    'membanding': 'banding',
    'membandingkan': 'banding',
    'membandingkannya': 'banding',
    'membandingi': 'banding',
    'membandingan': 'banding',
    'pembanding': 'banding',
    'pembandingnya': 'banding',
    'pembandingkan': 'banding',
    'pembandingan': 'banding',
    'berbanding': 'banding',
    'berbandingkan': 'banding',
    'berbandingan': 'banding',
    'pembandingannya': 'banding',
    'perbandingan': 'banding',
    'perbandingannya': 'banding',
    'membandingkankan': 'banding',
    'membandingkanku': 'banding',
    'memperbandingkan': 'banding',
    'memperbandingkannya': 'banding',
    'sebanding': 'banding',
    'membandit': 'bandit',
    'kebanditan': 'bandit',
    'bandulan': 'bandul',
    'membandul': 'bandul',
    'sebandung': 'bandung',
    'membandungi': 'bandung',
    'membandut': 'bandut',
    'pembandut': 'bandut',
    'terbangai': 'bangai',
    'membangatkan': 'bangat',
    'kebangetan': 'banget',
    'kebangetanlah': 'banget',
    'berbangga': 'bangga',
    'berbanggalah': 'bangga',
    'membangga': 'bangga',
    'membanggakan': 'bangga',
    'membanggakannya': 'bangga',
    'kebanggaan': 'bangga',
    'kebanggaannya': 'bangga',
    'kebanggaanlah': 'bangga',
    'kebanggaanku': 'bangga',
    'kebanggaanmu': 'bangga',
    'membangirkan': 'bangir',
    'pembangkang': 'bangkang',
    'pembangkangnya': 'bangkang',
    'pembangkangan': 'bangkang',
    'terbangkang': 'bangkang',
    'membangkang': 'bangkang',
    'membangkangnya': 'bangkang',
    'membangkangi': 'bangkang',
    'pembangkangannya': 'bangkang',
    'membangkar': 'bangkar',
    'bangkitan': 'bangkit',
    'bangkitannya': 'bangkit',
    'berbangkit': 'bangkit',
    'terbangkit': 'bangkit',
    'terbangkitnya': 'bangkit',
    'terbangkitkan': 'bangkit',
    'pembangkit': 'bangkit',
    'pembangkitnya': 'bangkit',
    'pembangkitkan': 'bangkit',
    'pembangkiti': 'bangkit',
    'pembangkitan': 'bangkit',
    'membangkit': 'bangkit',
    'membangkitnya': 'bangkit',
    'membangkitkan': 'bangkit',
    'membangkitkannya': 'bangkit',
    'membangkitan': 'bangkit',
    'kebangkitan': 'bangkit',
    'kebangkitannya': 'bangkit',
    'kebangkitanan': 'bangkit',
    'membangkit-bangkit': 'bangkit',
    'membangkit-bangkitkan': 'bangkit',
    'bangkotan': 'bangkot',
    'kebangkrutan': 'bangkrut',
    'kebangkrutannya': 'bangkrut',
    'membangkrutkan': 'bangkrut',
    'sebangsa': 'bangsa',
    'sebangsanya': 'bangsa',
    'sebangsaku': 'bangsa',
    'membangsa': 'bangsa',
    'membangsakan': 'bangsa',
    'berbangsa': 'bangsa',
    'kebangsaan': 'bangsa',
    'kebangsaannya': 'bangsa',
    'kebangsaanlah': 'bangsa',
    'kebangsaanku': 'bangsa',
    'kebangsawanan': 'bangsawan',
    'kebangsawanannya': 'bangsawan',
    'kebangsawananan': 'bangsawan',
    'bangunan': 'bangun',
    'bangunannya': 'bangun',
    'bangunanlah': 'bangun',
    'bangunanan': 'bangun',
    'bangunanku': 'bangun',
    'membangun': 'bangun',
    'membangunnya': 'bangun',
    'membangunkan': 'bangun',
    'membangunkannya': 'bangun',
    'membanguni': 'bangun',
    'membangunan': 'bangun',
    'pembangun': 'bangun',
    'pembangunnya': 'bangun',
    'pembangunan': 'bangun',
    'kebangunan': 'bangun',
    'pembangunannya': 'bangun',
    'pembangunanlah': 'bangun',
    'pembangunankan': 'bangun',
    'pembangunanan': 'bangun',
    'membangunkanku': 'bangun',
    'membangunkanmu': 'bangun',
    'bangun-bangun': 'bangun',
    'bangun-bangunan': 'bangun',
    'membaning': 'baning',
    'berbanir': 'banir',
    'sebanjar': 'banjar',
    'banjaran': 'banjar',
    'banjarani': 'banjar',
    'berbanjar': 'banjar',
    'berbanjaran': 'banjar',
    'membanjarkan': 'banjar',
    'berbanjar-banjar': 'banjar',
    'membanjir': 'banjir',
    'membanjirnya': 'banjir',
    'membanjirlah': 'banjir',
    'membanjirkan': 'banjir',
    'membanjiri': 'banjir',
    'membanjirinya': 'banjir',
    'membanjirimu': 'banjir',
    'kebanjiran': 'banjir',
    'membanjur': 'banjur',
    'perbankan': 'bank',
    'perbankannya': 'bank',
    'perbankanlah': 'bank',
    'perbankankan': 'bank',
    'perbankanan': 'bank',
    'perbankanmu': 'bank',
    'bantahan': 'bantah',
    'bantahannya': 'bantah',
    'membantah': 'bantah',
    'membantahnya': 'bantah',
    'membantahkan': 'bantah',
    'membantahan': 'bantah',
    'membantahmu': 'bantah',
    'berbantah': 'bantah',
    'berbantahan': 'bantah',
    'pembantah': 'bantah',
    'pembantahnya': 'bantah',
    'pembantahan': 'bantah',
    'membantahi': 'bantah',
    'perbantahan': 'bantah',
    'terbantahkan': 'bantah',
    'terbantahkannya': 'bantah',
    'bantah-bantah': 'bantah',
    'bantah-bantahan': 'bantah',
    'memperbantahkan': 'bantah',
    'berbantah-bantah': 'bantah',
    'berbantah-bantahan': 'bantah',
    'bantaian': 'bantai',
    'membantai': 'bantai',
    'membantainya': 'bantai',
    'membantaimu': 'bantai',
    'pembantai': 'bantai',
    'pembantaian': 'bantai',
    'pembantaiannya': 'bantai',
    'bantalan': 'bantal',
    'bantalannya': 'bantal',
    'berbantal': 'bantal',
    'berbantalkan': 'bantal',
    'berbantalan': 'bantal',
    'membantalkan': 'bantal',
    'memperbantal': 'bantal',
    'bantal-bantal': 'bantal',
    'pembantar': 'bantar',
    'pembantaran': 'bantar',
    'membantar': 'bantar',
    'membantarkan': 'bantar',
    'membanter': 'banter',
    'bantingan': 'banting',
    'bantingannya': 'banting',
    'membanting': 'banting',
    'membantingnya': 'banting',
    'membantingkan': 'banting',
    'membantingkannya': 'banting',
    'pembantingan': 'banting',
    'bantuan': 'bantu',
    'bantuannya': 'bantu',
    'bantuanlah': 'bantu',
    'bantuanku': 'bantu',
    'bantuanmu': 'bantu',
    'pembantu': 'bantu',
    'pembantunya': 'bantu',
    'pembantukan': 'bantu',
    'pembantuan': 'bantu',
    'pembantuku': 'bantu',
    'pembantumu': 'bantu',
    'membantu': 'bantu',
    'membantunya': 'bantu',
    'membantulah': 'bantu',
    'membantukan': 'bantu',
    'membantui': 'bantu',
    'membantuan': 'bantu',
    'membantuku': 'bantu',
    'membantumu': 'bantu',
    'memperbantukan': 'bantu',
    'sebantun': 'bantun',
    'membantun': 'bantun',
    'membantunnya': 'bantun',
    'terbantun': 'bantun',
    'membantuni': 'bantun',
    'membantut': 'bantut',
    'terbantut': 'bantut',
    'sebanyak': 'banyak',
    'sebanyaknya': 'banyak',
    'sebanyaki': 'banyak',
    'sebanyakan': 'banyak',
    'banyakan': 'banyak',
    'banyakannya': 'banyak',
    'membanyak': 'banyak',
    'terbanyak': 'banyak',
    'terbanyaknya': 'banyak',
    'terbanyaklah': 'banyak',
    'terbanyaki': 'banyak',
    'berbanyak': 'banyak',
    'membanyaki': 'banyak',
    'kebanyakan': 'banyak',
    'kebanyakannya': 'banyak',
    'perbanyakan': 'banyak',
    'perbanyakannya': 'banyak',
    'membanyakkan': 'banyak',
    'memperbanyak': 'banyak',
    'memperbanyaknya': 'banyak',
    'memperbanyakan': 'banyak',
    'banyak-banyak': 'banyak',
    'banyak-banyaknya': 'banyak',
    'banyak-banyaklah': 'banyak',
    'banyak-banyakkan': 'banyak',
    'banyak-banyakan': 'banyak',
    'memperbanyakkan': 'banyak',
    'berbanyak-banyak': 'banyak',
    'banyolan': 'banyol',
    'banyolannya': 'banyol',
    'membanyol': 'banyol',
    'berbapak': 'bapak',
    'kebapakan': 'bapak',
    'kebapakannya': 'bapak',
    'pembaptis': 'baptis',
    'pembaptisan': 'baptis',
    'membaptis': 'baptis',
    'membaptisnya': 'baptis',
    'membaptiskan': 'baptis',
    'pembaptisannya': 'baptis',
    'membara': 'bara',
    'membaranya': 'bara',
    'membarakan': 'bara',
    'perbaraan': 'bara',
    'membarah': 'barah',
    'membarak': 'barak',
    'pembarap': 'barap',
    'baratan': 'barat',
    'pembarat': 'barat',
    'pembaratan': 'barat',
    'membaratkan': 'barat',
    'kebarat-baratan': 'barat',
    'berbareng': 'bareng',
    'berbarengan': 'bareng',
    'membarengi': 'bareng',
    'membarenginya': 'bareng',
    'berbarengannya': 'bareng',
    'membarengkan': 'bareng',
    'barik-barik': 'barik',
    'berbarik-barik': 'barik',
    'terbaring': 'baring',
    'terbaringnya': 'baring',
    'berbaring': 'baring',
    'berbaringnya': 'baring',
    'berbaringlah': 'baring',
    'berbaringan': 'baring',
    'pembaringan': 'baring',
    'pembaringannya': 'baring',
    'membaringkan': 'baring',
    'membaringkannya': 'baring',
    'barisan': 'baris',
    'barisannya': 'baris',
    'barisanan': 'baris',
    'sebaris': 'baris',
    'sebarisan': 'baris',
    'berbaris': 'baris',
    'berbarisnya': 'baris',
    'membaris': 'baris',
    'membariskan': 'baris',
    'membariskannya': 'baris',
    'baris-berbaris': 'baris',
    'barongan': 'barong',
    'barong tagalog': 'barong',
    'terbaru': 'baru',
    'terbarunya': 'baru',
    'terbarulah': 'baru',
    'terbarukan': 'baru',
    'terbarukannya': 'baru',
    'terbarui': 'baru',
    'terbaruku': 'baru',
    'pembaru': 'baru',
    'pembarunya': 'baru',
    'pembaruan': 'baru',
    'membaru': 'baru',
    'membarui': 'baru',
    'kebaruan': 'baru',
    'kebaruannya': 'baru',
    'membaruinya': 'baru',
    'pembaruannya': 'baru',
    'membarukan': 'baru',
    'memperbarui': 'baru',
    'memperbaruinya': 'baru',
    'baru-baru ini': 'baru',
    'pembarut': 'barut',
    'berbarut': 'barut',
    'membarut': 'barut',
    'pembarutan': 'barut',
    'membarutkan': 'barut',
    'membarut-barut': 'barut',
    'berbasa-basi': 'basa-basi',
    'basahan': 'basah',
    'basahannya': 'basah',
    'membasahi': 'basah',
    'membasahinya': 'basah',
    'pembasahan': 'basah',
    'pembasahannya': 'basah',
    'membasahkan': 'basah',
    'berbasah-basah': 'basah',
    'berbasah-basahan': 'basah',
    'kebasah-basahan': 'basah',
    'membasi': 'basi',
    'kebasian': 'basi',
    'membasikan': 'basi',
    'berbasiskan': 'basis',
    'albasit': 'basit',
    'pembasmi': 'basmi',
    'pembasmian': 'basmi',
    'terbasmi': 'basmi',
    'membasmi': 'basmi',
    'membasminya': 'basmi',
    'pembasmiannya': 'basmi',
    'basuhan': 'basuh',
    'pembasuh': 'basuh',
    'pembasuhan': 'basuh',
    'membasuh': 'basuh',
    'membasuhnya': 'basuh',
    'membasuhkan': 'basuh',
    'membasuhkannya': 'basuh',
    'membasuhi': 'basuh',
    'basungan': 'basung',
    'membasung': 'basung',
    'berbasut': 'basut',
    'membasut': 'basut',
    'terbata-bata': 'bata-bata',
    'kebata-bataan': 'bata-bata',
    'membatak': 'batak',
    'membatakkan': 'batak',
    'membatakkannya': 'batak',
    'membatakan': 'batak',
    'pembatak': 'batak',
    'pembatakan': 'batak',
    'pembatalan': 'batal',
    'pembatalannya': 'batal',
    'membatalkan': 'batal',
    'membatalkannya': 'batal',
    'membatalkankan': 'batal',
    'batangan': 'batang',
    'batangannya': 'batang',
    'batanganmu': 'batang',
    'sebatang': 'batang',
    'sebatangnya': 'batang',
    'membatang': 'batang',
    'batasan': 'batas',
    'batasannya': 'batas',
    'pembatas': 'batas',
    'pembatasnya': 'batas',
    'pembatasi': 'batas',
    'pembatasan': 'batas',
    'berbatas': 'batas',
    'berbataskan': 'batas',
    'berbatasan': 'batas',
    'membatas': 'batas',
    'membataskan': 'batas',
    'membatasi': 'batas',
    'membatasan': 'batas',
    'terbatas': 'batas',
    'terbatasnya': 'batas',
    'terbataslah': 'batas',
    'terbataskan': 'batas',
    'terbatasi': 'batas',
    'terbatasan': 'batas',
    'membatasinya': 'batas',
    'pembatasannya': 'batas',
    'pembatasanlah': 'batas',
    'perbatasan': 'batas',
    'perbatasannya': 'batas',
    'perbatasanlah': 'batas',
    'perbatasanan': 'batas',
    'keterbatasan': 'batas',
    'keterbatasannya': 'batas',
    'keterbatasanku': 'batas',
    'sebati': 'bati',
    'sebatian': 'bati',
    'batikan': 'batik',
    'batikannya': 'batik',
    'pembatik': 'batik',
    'pembatiknya': 'batik',
    'pembatikan': 'batik',
    'membatik': 'batik',
    'membatiknya': 'batik',
    'membatikkan': 'batik',
    'membatiki': 'batik',
    'pembatikannya': 'batik',
    'membatin': 'batin',
    'membatinkan': 'batin',
    'berbatin': 'batin',
    'kebatinan': 'batin',
    'kebatinannya': 'batin',
    'pembatubaraan': 'batu bara',
    'batuan': 'batu',
    'batuannya': 'batu',
    'membatu': 'batu',
    'membatunya': 'batu',
    'membatumu': 'batu',
    'berbatu': 'batu',
    'berbatuan': 'batu',
    'membatui': 'batu',
    'pembatuan': 'batu',
    'berbatu-batu': 'batu',
    'berbatu-batuan': 'batu',
    'berbatuk': 'batuk',
    'batuk-batuk': 'batuk',
    'batuk-batuknya': 'batuk',
    'membatukkan': 'batuk',
    'membatukkannya': 'batuk',
    'terbatuk-batuk': 'batuk',
    'batung-batung': 'batung',
    'sebau': 'bau',
    'berbau': 'bau',
    'berbaunya': 'bau',
    'terbau': 'bau',
    'terbaunya': 'bau',
    'terbaukan': 'bau',
    'membaui': 'bau',
    'membauinya': 'bau',
    'bau-bauan': 'bau',
    'bauksit': 'bauk',
    'bauksitnya': 'bauk',
    'membauni': 'baun',
    'bauran': 'baur',
    'baurannya': 'baur',
    'membaur': 'baur',
    'membaurnya': 'baur',
    'membaurlah': 'baur',
    'membaurkan': 'baur',
    'membaurkannya': 'baur',
    'terbaur': 'baur',
    'terbaurnya': 'baur',
    'berbaur': 'baur',
    'berbaurnya': 'baur',
    'berbaurlah': 'baur',
    'perbauran': 'baur',
    'pembauran': 'baur',
    'pembaurannya': 'baur',
    'memperbaurkan': 'baur',
    'bawaan': 'bawa',
    'bawaannya': 'bawa',
    'bawaanku': 'bawa',
    'bawaanmu': 'bawa',
    'terbawa': 'bawa',
    'terbawanya': 'bawa',
    'terbawalah': 'bawa',
    'pembawa': 'bawa',
    'pembawanya': 'bawa',
    'pembawaan': 'bawa',
    'membawa': 'bawa',
    'membawanya': 'bawa',
    'membawakan': 'bawa',
    'membawakannya': 'bawa',
    'membawai': 'bawa',
    'membawaku': 'bawa',
    'membawamu': 'bawa',
    'berbawaan': 'bawa',
    'pembawaannya': 'bawa',
    'sepembawa': 'bawa',
    'membawakanku': 'bawa',
    'membawa-bawa': 'bawa',
    'membawa-bawanya': 'bawa',
    'berpembawaan': 'bawa',
    'bawahan': 'bawah',
    'bawahannya': 'bawah',
    'bawahanlah': 'bawah',
    'bawahanku': 'bawah',
    'bawahanmu': 'bawah',
    'sebawah': 'bawah',
    'di bawah': 'bawah',
    'terbawah': 'bawah',
    'terbawahnya': 'bawah',
    'terbawahlah': 'bawah',
    'sebawahan': 'bawah',
    'membawahi': 'bawah',
    'membawahinya': 'bawah',
    'membawahkan': 'bawah',
    'membawang': 'bawang',
    'berbawang': 'bawang',
    'pembawang': 'bawang',
    'membawangi': 'bawang',
    'sebaya': 'baya',
    'sebayanya': 'baya',
    'sebayaku': 'baya',
    'terbayan': 'bayan',
    'membayankan': 'bayan',
    'bayangan': 'bayang',
    'bayangannya': 'bayang',
    'bayangankan': 'bayang',
    'bayanganku': 'bayang',
    'bayanganmu': 'bayang',
    'terbayang': 'bayangan',
    'terbayangnya': 'bayangan',
    'terbayanglah': 'bayangan',
    'terbayangkan': 'bayangan',
    'terbayangi': 'bayangan',
    'membayang': 'bayangan',
    'membayangnya': 'bayangan',
    'membayangkan': 'bayangan',
    'membayangkannya': 'bayangan',
    'membayangi': 'bayangan',
    'membayangan': 'bayangan',
    'berbayang': 'bayang',
    'membayanginya': 'bayang',
    'membayangii': 'bayang',
    'pembayangan': 'bayangan',
    'bayang-bayang': 'bayangan',
    'bayang-bayangnya': 'bayangan',
    'bayang-bayangi': 'bayangan',
    'bayang-bayangku': 'bayangan',
    'bayang-bayangmu': 'bayangan',
    'berbayang-bayang': 'bayang',
    'terbayang-bayang': 'bayangan',
    'terbayang-bayangi': 'bayangan',
    'membayang-bayangi': 'bayangan',
    'membayang-bayanginya': 'bayangan',
    'membayang-bayangkan': 'bayang',
    'bayaran': 'bayar',
    'bayarannya': 'bayar',
    'berbayar': 'bayar',
    'berbayarnya': 'bayar',
    'berbayarkan': 'bayar',
    'berbayaran': 'bayar',
    'membayar': 'bayar',
    'membayarnya': 'bayar',
    'membayarkan': 'bayar',
    'membayarkannya': 'bayar',
    'membayari': 'bayar',
    'membayaran': 'bayar',
    'membayarnyalah': 'bayar',
    'membayarku': 'bayar',
    'membayarmu': 'bayar',
    'pembayar': 'bayar',
    'pembayarnya': 'bayar',
    'pembayarkan': 'bayar',
    'pembayaran': 'bayar',
    'membayarinya': 'bayar',
    'pembayarannya': 'bayar',
    'pembayaranan': 'bayar',
    'kebayi-bayian': 'bayi',
    'membayonet': 'bayonet',
    'membayong': 'bayong',
    'bayuan': 'bayu',
    'kebayuan': 'bayu',
    'pembayun': 'bayun',
    'membea': 'bea',
    'kebebalan': 'bebal',
    'kebebalannya': 'bebal',
    'membebani': 'beban',
    'membebaninya': 'beban',
    'membebaniku': 'beban',
    'membebanimu': 'beban',
    'pembebanan': 'beban',
    'pembebanannya': 'beban',
    'membebankan': 'beban',
    'membebankannya': 'beban',
    'terbebang': 'bebang',
    'kebebangan': 'bebang',
    'berbebar': 'bebar',
    'terbebar': 'bebar',
    'pembebas': 'bebas',
    'pembebaskan': 'bebas',
    'pembebasan': 'bebas',
    'terbebas': 'bebas',
    'terbebasnya': 'bebas',
    'terbebaskan': 'bebas',
    'kebebasan': 'bebas',
    'kebebasannya': 'bebas',
    'kebebasanku': 'bebas',
    'kebebasanmu': 'bebas',
    'pembebasannya': 'bebas',
    'membebaskan': 'bebas',
    'membebaskannya': 'bebas',
    'membebaskanku': 'bebas',
    'membebaskanmu': 'bebas',
    'membebasmurnikan': 'bebas murni',
    'membebastugaskan': 'bebas tugas',
    'membebastugaskannya': 'bebas tugas',
    'membebat': 'bebat',
    'membebatnya': 'bebat',
    'membebatkan': 'bebat',
    'pembebat': 'bebat',
    'pembebatan': 'bebat',
    'pembebek': 'bebek',
    'membebek': 'bebek',
    'membebekan': 'bebek',
    'beberan': 'beber',
    'membeber': 'beber',
    'membebernya': 'beber',
    'membeberkan': 'beber',
    'membeberkannya': 'beber',
    'membeberan': 'beber',
    'pembeberan': 'beber',
    'pembeberannya': 'beber',
    'seberapa': 'beberapa',
    'seberapanya': 'beberapa',
    'buyutan': 'buyut',
    'buyutannya': 'buyut',
    'bebuyutan': 'buyut',
    'bebuyutannya': 'buyut',
    'kebuyutan': 'buyut',
    'berbecak-becak': 'becak',
    'berbeda': 'beda',
    'berbedanya': 'beda',
    'berbedalah': 'beda',
    'berbedai': 'beda',
    'berbedaan': 'beda',
    'pembeda': 'beda',
    'pembedanya': 'beda',
    'pembedakan': 'beda',
    'pembedaan': 'beda',
    'pembedaannya': 'beda',
    'berbedaannya': 'beda',
    'perbedaan': 'beda',
    'perbedaannya': 'beda',
    'perbedaanlah': 'beda',
    'membedakan': 'beda',
    'membedakannya': 'beda',
    'membedakanlah': 'beda',
    'membedakanmu': 'beda',
    'berbeda-beda': 'beda',
    'berbeda-bedanya': 'beda',
    'memperbedakan': 'beda',
    'terbeda-bedakan': 'beda',
    'membeda-bedakan': 'beda',
    'membeda-bedakannya': 'beda',
    'membeda-bedakanmu': 'beda',
    'membedah': 'bedah',
    'membedahnya': 'bedah',
    'membedahkan': 'bedah',
    'pembedah': 'bedah',
    'pembedahan': 'bedah',
    'pembedahannya': 'bedah',
    'berbedak': 'bedak',
    'membedaki': 'bedak',
    'membedakkan': 'bedak',
    'membedal': 'bedal',
    'membedel': 'bedel',
    'membedil': 'bedil',
    'membedilnya': 'bedil',
    'berbedil': 'bedil',
    'membedili': 'bedil',
    'sepembedil': 'bedil',
    'bedil-bedal': 'bedil',
    'bedil-bedilan': 'bedil',
    'berbedil-bedilan': 'bedil',
    'bedolan': 'bedol',
    'terbedol': 'bedol',
    'membedol': 'bedol',
    'pembedolan': 'bedol',
    'bedungan': 'bedung',
    'membedung': 'bedung',
    'berbega': 'bega',
    'berbegai': 'bega',
    'membega': 'bega',
    'berbega-bega': 'bega',
    'membegal': 'begal',
    'membegalnya': 'begal',
    'pembegalan': 'begal',
    'pembegalannya': 'begal',
    'membegar': 'begar',
    'kebegaran': 'begar',
    'sebegini': 'begini',
    'sebegininya': 'begini',
    'beginian': 'begini',
    'membeginikan': 'begini',
    'begituan': 'begitu',
    'begituanlah': 'begitu',
    'sebegitu': 'begitu',
    'sebegitunya': 'begitu',
    'sebegitunyalah': 'begitu',
    'membegitukan': 'begitu',
    'membehandel': 'behandel',
    'kebejatan': 'bejat',
    'kebejatannya': 'bejat',
    'membejatkan': 'bejat',
    'membeka': 'beka',
    'berbeka': 'beka',
    'terbeka': 'beka',
    'berbeka-beka': 'beka',
    'berbekal': 'bekal',
    'berbekalkan': 'bekal',
    'pembekal': 'bekal',
    'pembekalan': 'bekal',
    'membekali': 'bekal',
    'membekalinya': 'bekal',
    'membekalimu': 'bekal',
    'perbekalan': 'bekal',
    'perbekalannya': 'bekal',
    'pembekalannya': 'bekal',
    'membekalkan': 'bekal',
    'bekal-bekalan': 'bekal',
    'pembekam': 'bekam',
    'pembekaman': 'bekam',
    'membekam': 'bekam',
    'membekap': 'bekap',
    'membekapnya': 'bekap',
    'membekapkan': 'bekap',
    'berbekas': 'bekas',
    'membekas': 'bekas',
    'membekasnya': 'bekas',
    'membekaskan': 'bekas',
    'kebekenan': 'beken',
    'bekerja': 'kerja',
    'bekerjanya': 'kerja',
    'bekerjalah': 'kerja',
    'bekerjakan': 'kerja',
    'bekerjai': 'kerja',
    'bekerjaan': 'kerja',
    'bekerjamu': 'kerja',
    'pekerja': 'kerja',
    'pekerjanya': 'kerja',
    'pekerjalah': 'kerja',
    'pekerjakan': 'kerja',
    'pekerjaan': 'kerja',
    'pekerjaku': 'kerja',
    'pekerjamu': 'kerja',
    'sekerja': 'kerja',
    'sekerjanya': 'kerja',
    'pekerjaannya': 'kerja',
    'pekerjaanlah': 'kerja',
    'pekerjaanku': 'kerja',
    'pekerjaanmu': 'kerja',
    'pengerjaan': 'kerja',
    'pengerjaannya': 'kerja',
    'tekerjakan': 'kerja',
    'mengerjakan': 'kerja',
    'mengerjakannya': 'kerja',
    'mengerjakankan': 'kerja',
    'sepekerjaan': 'kerja',
    'sepekerjaannya': 'kerja',
    'mempekerjakan': 'kerja',
    'mempekerjakannya': 'kerja',
    'mempekerjakanku': 'kerja',
    'mempekerjakanmu': 'kerja',
    'bekuan': 'beku',
    'bekuannya': 'beku',
    'membeku': 'beku',
    'membekunya': 'beku',
    'membekukan': 'beku',
    'membekukannya': 'beku',
    'membekuan': 'beku',
    'pembeku': 'beku',
    'pembekukan': 'beku',
    'pembekuan': 'beku',
    'kebekuan': 'beku',
    'kebekuannya': 'beku',
    'pembekuannya': 'beku',
    'membekuk': 'bekuk',
    'membekuknya': 'bekuk',
    'membekukkan': 'bekuk',
    'mengebel': 'bel',
    'membela': 'bela',
    'membelanya': 'bela',
    'membelai': 'bela',
    'membelaku': 'bela',
    'membelamu': 'bela',
    'pembela': 'bela',
    'pembelanya': 'bela',
    'pembelakan': 'bela',
    'pembelaan': 'bela',
    'pembelamu': 'bela',
    'pembelaannya': 'bela',
    'pembelaanku': 'bela',
    'belahan': 'belah',
    'belahannya': 'belah',
    'sebelah': 'belah',
    'sebelahnya': 'belah',
    'sebelahan': 'belah',
    'sebelahku': 'belah',
    'sebelahmu': 'belah',
    'pembelah': 'belah',
    'pembelahan': 'belah',
    'membelah': 'belah',
    'membelahnya': 'belah',
    'berbelah': 'belah',
    'berbelahan': 'belah',
    'menyebelah': 'belah',
    'pembelahannya': 'belah',
    'menyebelahi': 'belah',
    'bersebelahan': 'belah',
    'bersebelahanlah': 'belah',
    'menyebelahkan': 'belah',
    'berbelah-belah': 'belah',
    'sebelah-menyebelah': 'belah',
    'terbelahak': 'belahak',
    'membelahak': 'belahak',
    'belaian': 'belai',
    'belaiannya': 'belai',
    'membelainya': 'belai',
    'membelai-belai': 'belai',
    'membelai-belainya': 'belai',
    'belakangan': 'belakang',
    'belakangannya': 'belakang',
    'belakanganlah': 'belakang',
    'belakanganan': 'belakang',
    'membelakang': 'belakang',
    'membelakangkan': 'belakang',
    'membelakangi': 'belakang',
    'terbelakang': 'belakang',
    'terbelakangnya': 'belakang',
    'terbelakangan': 'belakang',
    'ke belakang': 'belakang',
    'membelakanginya': 'belakang',
    'terkebelakang': 'belakang',
    'pembelakangan': 'belakang',
    'keterbelakangan': 'belakang',
    'keterbelakangannya': 'belakang',
    'mengebelakangkan': 'belakang',
    'memperbelakangkan': 'belakang',
    'berbelakang-belakangan': 'belakang',
    'belalakan': 'belalak',
    'membelalak': 'belalak',
    'membelalakkan': 'belalak',
    'membelalakan': 'belalak',
    'terbelalak': 'belalak',
    'membelalang': 'belalang',
    'membelalangkan': 'belalang',
    'terbelam': 'belam',
    'membelam': 'belam',
    'membelandakan': 'belanda',
    'kebelanda-belandaan': 'belanda',
    'membelandang': 'belandang',
    'membelandangkan': 'belandang',
    'belandongan': 'belandong',
    'pembelandongan': 'belandong',
    'berbelang-belang': 'belang',
    'sebelanga': 'belanga',
    'terbelangah': 'langah',
    'belangiran': 'belangir',
    'belanjaan': 'belanja',
    'belanjaannya': 'belanja',
    'belanjaanku': 'belanja',
    'belanjaanmu': 'belanja',
    'berbelanja': 'belanja',
    'berbelanjanya': 'belanja',
    'berbelanjalah': 'belanja',
    'berbelanjaan': 'belanja',
    'berbelanjaku': 'belanja',
    'membelanjai': 'belanja',
    'pembelanjaan': 'belanja',
    'pembelanjaannya': 'belanja',
    'perbelanjaan': 'belanja',
    'perbelanjaannya': 'belanja',
    'perbelanjaanlah': 'belanja',
    'perbelanjaanmu': 'belanja',
    'membelanjakan': 'belanja',
    'membelanjakannya': 'belanja',
    'membelar': 'belar',
    'selar-belar': 'belar',
    'belasan': 'belas',
    'belasannya': 'belas',
    'belasanlah': 'belas',
    'sebelas': 'belas',
    'sebelasnya': 'belas',
    'sebelasan': 'belas',
    'pembelas': 'belas',
    'pembelasan': 'belas',
    'membelaskan': 'belas',
    'kesebelasan': 'belas',
    'kesebelasannya': 'belas',
    'berbelaskasihan': 'belas',
    'membelasah': 'belasah',
    'berbelasungkawa': 'belasungkawa',
    'membelasut': 'belasut',
    'membelat': 'belat',
    'membelau': 'belau',
    'kebelauan': 'belau',
    'berbelau-belauan': 'belau',
    'membelek': 'belek',
    'terbelelang': 'belelang',
    'membelendung': 'belendung',
    'terbelenggu': 'belenggu',
    'terbelenggunya': 'belenggu',
    'membelenggu': 'belenggu',
    'membelenggunya': 'belenggu',
    'membelengketkan': 'belengket',
    'membelenting': 'belenting',
    'membelentingkan': 'belenting',
    'belian': 'beli',
    'beliannya': 'beli',
    'beliani': 'beli',
    'terbeli': 'beli',
    'terbelinya': 'beli',
    'membeli': 'beli',
    'membelinya': 'beli',
    'membelikan': 'beli',
    'membelikannya': 'beli',
    'membelian': 'beli',
    'membeliku': 'beli',
    'membelimu': 'beli',
    'pembeli': 'beli',
    'pembelinya': 'beli',
    'pembelilah': 'beli',
    'pembelikan': 'beli',
    'pembelii': 'beli',
    'pembelian': 'beli',
    'pembeliannya': 'beli',
    'pembelianku': 'beli',
    'pembelianmu': 'beli',
    'membelikanku': 'beli',
    'membelikanmu': 'beli',
    'membeli-beli': 'beli',
    'berbeli-beli': 'beli',
    'berbeli-belian': 'beli',
    'kebeliaan': 'belia',
    'terbeliak': 'beliak',
    'membeliak': 'beliak',
    'membeliakkan': 'beliak',
    'berbelian': 'belian',
    'beliau-beliau': 'beliau',
    'beliau-beliaulah': 'beliau',
    'belimbingan': 'belimbing',
    'berbelimbing': 'belimbing',
    'terbelingkang': 'belingkang',
    'belingsatan': 'belingsat',
    'terbelingut': 'belingut',
    'terbelintang': 'belintang',
    'berbelintang': 'belintang',
    'berbelintangan': 'belintang',
    'membelintangkan': 'belintang',
    'terbelit': 'belit',
    'terbelitnya': 'belit',
    'berbelit': 'belit',
    'berbelitnya': 'belit',
    'membelit': 'belit',
    'membelitnya': 'belit',
    'membelitkan': 'belit',
    'berbelit-belit': 'belit',
    'berbelit-belitnya': 'belit',
    'berbelit-belitlah': 'belit',
    'membelit-belitkan': 'belit',
    'belokan': 'belok',
    'belokannya': 'belok',
    'belokanku': 'belok',
    'membelok': 'belok',
    'membeloknya': 'belok',
    'membelokkan': 'belok',
    'membelokkannya': 'belok',
    'membelokan': 'belok',
    'berbelok': 'belok',
    'berbeloknya': 'belok',
    'berbeloklah': 'belok',
    'berbelokkan': 'belok',
    'pembelokan': 'belok',
    'berbelok-belok': 'belok',
    'berbelon': 'belon',
    'belongkotan': 'belongkot',
    'berbelongsong': 'belongsong',
    'membelongsongi': 'belongsong',
    'membelontang': 'belontang',
    'pembelot': 'belot',
    'pembelotnya': 'belot',
    'pembelotan': 'belot',
    'membelot': 'belot',
    'membelotnya': 'belot',
    'membelotkan': 'belot',
    'pembelotannya': 'belot',
    'membelu': 'belu',
    'membelu-belai': 'belu-belai',
    'membeludak': 'beludak',
    'membeludaknya': 'beludak',
    'membelukar': 'belukar',
    'berbelulang': 'belulang',
    'sebelum': 'belum',
    'sebelumnya': 'belum',
    'sebelumi': 'belum',
    'sebelumnyalah': 'belum',
    'sebelumku': 'belum',
    'sebelummu': 'belum',
    'belum-belum': 'belum',
    'membelungsing': 'belungsing',
    'berbelut': 'belut',
    'membembam': 'bembam',
    'berbenah': 'benah',
    'berbenahlah': 'benah',
    'membenahi': 'benah',
    'membenahinya': 'benah',
    'pembenahan': 'benah',
    'pembenahannya': 'benah',
    'pembenahanan': 'benah',
    'berbenak': 'benak',
    'membenalu': 'benalu',
    'benaman': 'benam',
    'berbenam': 'benam',
    'terbenam': 'benam',
    'terbenamnya': 'benam',
    'terbenamlah': 'benam',
    'terbenamkan': 'benam',
    'membenam': 'benam',
    'membenamnya': 'benam',
    'membenamkan': 'benam',
    'membenamkannya': 'benam',
    'membenami': 'benam',
    'membenaman': 'benam',
    'membenang': 'benang',
    'membenangkan': 'benang',
    'berbenang-benang': 'benang',
    'benaran': 'benar',
    'membenar': 'benar',
    'membenarnya': 'benar',
    'membenarkan': 'benar',
    'membenarkannya': 'benar',
    'membenari': 'benar',
    'membenaran': 'benar',
    'berbenar': 'benar',
    'terbenar': 'benar',
    'kebenaran': 'benar',
    'kebenarannya': 'benar',
    'kebenaranlah': 'benar',
    'kebenarankan': 'benar',
    'kebenaranan': 'benar',
    'kebenaranmu': 'benar',
    'sebenarnya': 'benar',
    'sebenarnyanya': 'benar',
    'sebenarnyalah': 'benar',
    'sebenarnyai': 'benar',
    'pembenaran': 'benar',
    'pembenarannya': 'benar',
    'benar-benar': 'benar',
    'benar-benarlah': 'benar',
    'benar-benaran': 'benar',
    'memperbenar': 'benar',
    'membenar-benar': 'benar',
    'berbenar-benar': 'benar',
    'membenar-benari': 'benar',
    'membenara': 'benara',
    'membenarakan': 'benara',
    'berbencah': 'bencah',
    'membencah': 'bencah',
    'berbencah-bencah': 'bencah',
    'membencanai': 'bencana',
    'membencanakan': 'bencana',
    'pembenci': 'benci',
    'pembencinya': 'benci',
    'pembencian': 'benci',
    'pembenciku': 'benci',
    'pembencimu': 'benci',
    'membenci': 'benci',
    'membencinya': 'benci',
    'membenciku': 'benci',
    'membencimu': 'benci',
    'kebencian': 'benci',
    'kebenciannya': 'benci',
    'kebencianlah': 'benci',
    'kebencianku': 'benci',
    'kebencianmu': 'benci',
    'kebencian-mu': 'benci',
    'membencikan': 'benci',
    'berbencol-bencol': 'bencol',
    'berbenda': 'benda',
    'kebendaan': 'benda',
    'pembendaan': 'benda',
    'perbendaan': 'benda',
    'perbendaannya': 'benda',
    'membendakan': 'benda',
    'perbendaharaan': 'bendahara',
    'membenderai': 'bendera',
    'kebenderangan': 'benderang',
    'membendi': 'bendi',
    'berbendi': 'bendi',
    'bendungan': 'bendung',
    'bendungannya': 'bendung',
    'bendunganan': 'bendung',
    'terbendung': 'bendung',
    'terbendungnya': 'bendung',
    'terbendungkan': 'bendung',
    'pembendung': 'bendung',
    'pembendungnya': 'bendung',
    'pembendungan': 'bendung',
    'membendung': 'bendung',
    'membendungnya': 'bendung',
    'terbengang': 'bengang',
    'membengang': 'bengang',
    'berbenggil-benggil': 'benggil',
    'benggolan': 'benggol',
    'benggolannya': 'benggol',
    'membengis': 'bengis',
    'kebengisan': 'bengis',
    'kebengisannya': 'bengis',
    'membengisi': 'bengis',
    'bengkahan': 'bengkah',
    'membengkak': 'bengkak',
    'membengkaknya': 'bengkak',
    'membengkakkan': 'bengkak',
    'membengkakan': 'bengkak',
    'pembengkakan': 'bengkak',
    'pembengkakannya': 'bengkak',
    'kebengkalan': 'bengkal',
    'terbengkalai': 'bengkalai',
    'terbengkalainya': 'bengkalai',
    'terbengkalaikan': 'bengkalai',
    'membengkalaikan': 'bengkalai',
    'membengkar': 'bengkar',
    'membengkel': 'bengkel',
    'membengkelkan': 'bengkel',
    'membengkeli': 'bengkel',
    'perbengkelan': 'bengkel',
    'terbengkil-bengkil': 'bengkil',
    'membengkos': 'bengkos',
    'berbengkung': 'bengkung',
    'membengkung': 'bengkung',
    'terbengong-bengong': 'bengong',
    'berbenguk': 'benguk',
    'berbenih': 'benih',
    'pembenih': 'benih',
    'pembenihan': 'benih',
    'pembenihannya': 'benih',
    'perbenihan': 'benih',
    'membenihkan': 'benih',
    'pembening': 'bening',
    'membening': 'bening',
    'membeningkan': 'bening',
    'kebeningan': 'bening',
    'kebeningannya': 'bening',
    'pembeningan': 'bening',
    'benjolan': 'benjol',
    'benjolannya': 'benjol',
    'berbenjol': 'benjol',
    'bentakan': 'bentak',
    'bentakannya': 'bentak',
    'membentak': 'bentak',
    'membentaknya': 'bentak',
    'bentangan': 'bentang',
    'bentangannya': 'bentang',
    'terbentang': 'bentang',
    'terbentangnya': 'bentang',
    'terbentanglah': 'bentang',
    'terbentangkan': 'bentang',
    'membentang': 'bentang',
    'membentangnya': 'bentang',
    'membentanglah': 'bentang',
    'membentangkan': 'bentang',
    'membentangkannya': 'bentang',
    'membentangi': 'bentang',
    'membentangan': 'bentang',
    'sebentar': 'bentar',
    'sebentarnya': 'bentar',
    'sebentarlah': 'bentar',
    'berbentar': 'bentar',
    'sesebentar': 'bentar',
    'membentari': 'bentar',
    'perbentaran': 'bentar',
    'membentarkan': 'bentar',
    'sebentar-sebentar': 'sebentar',
    'berbenteh': 'benteh',
    'membenteh': 'benteh',
    'berbenteng': 'benteng',
    'membentengi': 'benteng',
    'membentenginya': 'benteng',
    'kebentok': 'bentok',
    'berbentol-bentol': 'bentol',
    'berbentong-bentong': 'bentong',
    'bentrokan': 'bentrok',
    'bentrokannya': 'bentrok',
    'berbentrok': 'bentrok',
    'berbentrokan': 'bentrok',
    'perbentrokan': 'bentrok',
    'membentrokkan': 'bentrok',
    'bentukan': 'bentuk',
    'bentukannya': 'bentuk',
    'membentuk': 'bentuk',
    'membentuknya': 'bentuk',
    'membentukkan': 'bentuk',
    'membentukan': 'bentuk',
    'membentukku': 'bentuk',
    'terbentuk': 'bentuk',
    'terbentuknya': 'bentuk',
    'terbentuklah': 'bentuk',
    'terbentukkan': 'bentuk',
    'terbentukan': 'bentuk',
    'pembentuk': 'bentuk',
    'pembentuknya': 'bentuk',
    'pembentukkan': 'bentuk',
    'pembentukkannya': 'bentuk',
    'pembentukan': 'bentuk',
    'berbentuk': 'bentuk',
    'berbentukan': 'bentuk',
    'pembentukannya': 'bentuk',
    'benturan': 'bentur',
    'benturannya': 'bentur',
    'kebentur': 'bentur',
    'terbentur': 'bentur',
    'terbenturnya': 'bentur',
    'membentur': 'bentur',
    'membenturnya': 'bentur',
    'membenturkan': 'bentur',
    'membenturkannya': 'bentur',
    'berbenturan': 'bentur',
    'berbenturannya': 'bentur',
    'perbenturan': 'bentur',
    'terbentus': 'bentus',
    'benuman': 'benum',
    'membenum': 'benum',
    'membeo': 'beo',
    'pembeo': 'beo',
    'memberakan': 'bera',
    'meracun': 'racun',
    'meracunnya': 'racun',
    'meracunkan': 'racun',
    'meracuni': 'racun',
    'meracunan': 'racun',
    'beracun': 'racun',
    'beracunnya': 'racun',
    'peracun': 'racun',
    'peracunnya': 'racun',
    'peracunan': 'racun',
    'meracuninya': 'racun',
    'keracunan': 'racun',
    'keracunannya': 'racun',
    'keracunanan': 'racun',
    'meragi': 'ragi',
    'beragi': 'ragi',
    'beraginya': 'ragi',
    'peragian': 'ragi',
    'meragikan': 'ragi',
    'keberahian': 'berahi',
    'memberahikan': 'berahi',
    'berberaian': 'berai',
    'memberai-beraikan': 'berai',
    'terberak': 'berak',
    'berambu': 'rambu',
    'perambuan': 'rambu',
    'rambu-rambu': 'rambu',
    'rambu-rambunya': 'rambu',
    'serambut': 'rambut',
    'serambutan': 'rambut',
    'merambut': 'rambut',
    'perambut': 'rambut',
    'berambut': 'rambut',
    'memberandal': 'berandal',
    'memberang': 'berang',
    'memberangkan': 'berang',
    'memberangi': 'berang',
    'pemberang': 'berang',
    'pemberangkan': 'berang',
    'berangasan': 'berangas',
    'kerangka': 'rangka',
    'kerangkanya': 'rangka',
    'kerangkai': 'rangka',
    'berangka': 'rangka',
    'berangkai': 'rangkai',
    'merangkakan': 'rangka',
    'keberangkatan': 'berangkat',
    'keberangkatannya': 'berangkat',
    'keberangkatanku': 'berangkat',
    'keberangkatanmu': 'berangkat',
    'pemberangkatan': 'berangkat',
    'pemberangkatannya': 'berangkat',
    'pemberangkatanku': 'berangkat',
    'memberangkatkan': 'berangkat',
    'memberangkatkannya': 'berangkat',
    'merangsang': 'rangsang',
    'merangsangnya': 'rangsang',
    'merangsangan': 'rangsang',
    'berangsang': 'rangsang',
    'terangsang': 'rangsang',
    'terangsangnya': 'rangsang',
    'rangsangan': 'rangsang',
    'rangsangannya': 'rangsang',
    'rangsanganlah': 'rangsang',
    'perangsang': 'rangsang',
    'perangsangan': 'rangsang',
    'perangsangannya': 'rangsang',
    'merangsangkan': 'rangsang',
    'memberangus': 'berangus',
    'memberangusnya': 'berangus',
    'memberanguskan': 'berangus',
    'pemberangus': 'berangus',
    'pemberangusan': 'berangus',
    'pemberani': 'berani',
    'pemberaninya': 'berani',
    'keberanian': 'berani',
    'keberaniannya': 'berani',
    'keberanianlah': 'berani',
    'keberanianmu': 'berani',
    'memberanikan': 'berani',
    'memberanikannya': 'berani',
    'terberanikan': 'berani',
    'berani-berani': 'berani',
    'berani-beraninya': 'berani',
    'berani-beranian': 'berani',
    'berberani-berani': 'berani',
    'berantakan': 'berantak',
    'berantakannya': 'berantak',
    'berantakanlah': 'berantak',
    'memberantakkan': 'berantak',
    'memberantas': 'berantas',
    'memberantasnya': 'berantas',
    'memberantaskan': 'berantas',
    'memberantasi': 'berantas',
    'memberantasan': 'berantas',
    'pemberantas': 'berantas',
    'pemberantasi': 'berantas',
    'pemberantasan': 'berantas',
    'pemberantasannya': 'berantas',
    'pemberantasanan': 'berantas',
    'berasa': 'rasa',
    'berasanya': 'rasa',
    'berasalah': 'rasa',
    'berasai': 'rasa',
    'berasaan': 'rasa',
    'perasa': 'rasa',
    'perasanya': 'rasa',
    'perasaan': 'rasa',
    'terasa': 'rasa',
    'terasanya': 'rasa',
    'terasalah': 'rasa',
    'merasa': 'rasa',
    'merasanya': 'rasa',
    'merasalah': 'rasa',
    'merasakan': 'rasa',
    'merasakannya': 'rasa',
    'merasai': 'rasa',
    'merasaan': 'rasa',
    'serasa': 'rasa',
    'merasainya': 'rasa',
    'rasanya': 'rasa',
    'rasanyanya': 'rasa',
    'perasaannya': 'rasa',
    'perasaanlah': 'rasa',
    'perasaanku': 'rasa',
    'perasaanmu': 'rasa',
    'merasakankan': 'rasa',
    'merasakani': 'rasa',
    'memperasakan': 'rasa',
    'merasa-rasai': 'rasa',
    'rasa-rasanya': 'rasa',
    'rasa-rasanyanya': 'rasa',
    'pemberat': 'berat',
    'pemberatnya': 'berat',
    'pemberatan': 'berat',
    'berberat': 'berat',
    'berberati': 'berat',
    'berberatan': 'berat',
    'memberati': 'berat',
    'keberatan': 'berat',
    'keberatannya': 'berat',
    'keberatanlah': 'berat',
    'pemberatannya': 'berat',
    'memperberat': 'berat',
    'memperberatnya': 'berat',
    'memperberatkan': 'berat',
    'memperberatan': 'berat',
    'memberatkan': 'berat',
    'memberatkannya': 'berat',
    'memberatkankannya': 'berat',
    'berkeberatan': 'berat',
    'pembicara': 'bicara',
    'pembicaranya': 'bicara',
    'pembicarakan': 'bicara',
    'pembicaraan': 'bicara',
    'berbicara': 'bicara',
    'berbicaranya': 'bicara',
    'berbicaralah': 'bicara',
    'berbicarakan': 'bicara',
    'pembicaraannya': 'bicara',
    'pembicaraanku': 'bicara',
    'pembicaraanmu': 'bicara',
    'membicarakan': 'bicara',
    'membicarakannya': 'bicara',
    'membicarakankan': 'bicara',
    'membicarakanku': 'bicara',
    'membicarakanmu': 'bicara',
    'bilangan': 'bilang',
    'bilangannya': 'bilang',
    'bilanganan': 'bilang',
    'sebilang': 'bilang',
    'membilang': 'bilang',
    'terbilang': 'bilang',
    'pembilang': 'bilang',
    'pembilangan': 'bilang',
    'berbilang': 'bilang',
    'membilangi': 'bilang',
    'kebilangan': 'bilang',
    'sebilangan': 'bilang',
    'membilangkan': 'bilang',
    'berbingkai': 'bingkai',
    'membingkai': 'bingkai',
    'membingkainya': 'bingkai',
    'membingkaikan': 'bingkai',
    'berbini': 'bini',
    'berbinikan': 'bini',
    'bini-binian': 'bini',
    'memperbinikan': 'bini',
    'bintangan': 'bintang',
    'sebintang': 'bintang',
    'berbintang': 'bintang',
    'berbintangnya': 'bintang',
    'membintangi': 'bintang',
    'membintanginya': 'bintang',
    'perbintangan': 'bintang',
    'perbintangannya': 'bintang',
    'berbintang-bintang': 'bintang',
    'berbintik': 'bintik',
    'berbintik-bintik': 'bintik',
    'berbisa': 'bisa',
    'berbisanya': 'bisa',
    'kebisaan': 'bisa',
    'kebisaannya': 'bisa',
    'sebisanya': 'bisa',
    'sebisanyalah': 'bisa',
    'bisikan': 'bisik',
    'bisikannya': 'bisik',
    'berbisik': 'bisik',
    'berbisiklah': 'bisik',
    'pembisik': 'bisik',
    'pembisiknya': 'bisik',
    'membisiki': 'bisik',
    'membisikinya': 'bisik',
    'pembisikan': 'bisik',
    'membisikkan': 'bisik',
    'membisikkannya': 'bisik',
    'berbisik-bisik': 'bisik',
    'pembohong': 'bohong',
    'pembohongnya': 'bohong',
    'pembohongan': 'bohong',
    'berbohong': 'bohong',
    'berbohonglah': 'bohong',
    'berbohongan': 'bohong',
    'membohong': 'bohong',
    'membohongi': 'bohong',
    'membohonginya': 'bohong',
    'membohongiku': 'bohong',
    'kebohongan': 'bohong',
    'kebohongannya': 'bohong',
    'membohongkan': 'bohong',
    'bohong-bohongan': 'bohong',
    'bohong-bohongannya': 'bohong',
    'bualan': 'bual',
    'bualannya': 'bual',
    'membual': 'bual',
    'pembual': 'bual',
    'pembualan': 'bual',
    'berbual': 'bual',
    'perbualan': 'bual',
    'membualkan': 'bual',
    'berbual-bual': 'bual',
    'buatan': 'buat',
    'buatannya': 'buat',
    'buatanku': 'buat',
    'buatanmu': 'buat',
    'berbuat': 'buat',
    'berbuatnya': 'buat',
    'berbuatlah': 'buat',
    'berbuatan': 'buat',
    'pembuat': 'buat',
    'pembuatnya': 'buat',
    'pembuatan': 'buat',
    'terbuat': 'buat',
    'terbuatnya': 'buat',
    'terbuatlah': 'buat',
    'membuat': 'buat',
    'membuatnya': 'buat',
    'membuatkan': 'buat',
    'membuatkannya': 'buat',
    'membuati': 'buat',
    'membuatan': 'buat',
    'membuatku': 'buat',
    'membuatmu': 'buat',
    'perbuatan': 'buat',
    'perbuatannya': 'buat',
    'perbuatanku': 'buat',
    'perbuatanmu': 'buat',
    'teperbuat': 'buat',
    'pembuatannya': 'buat',
    'pembuatanan': 'buat',
    'membuatkanmu': 'buat',
    'memperbuat': 'buat',
    'buat-buatan': 'buat',
    'membuat-buat': 'buat',
    'membuat-buatnya': 'buat',
    'berbucu': 'bucu',
    'sebudi': 'budi',
    'berbudi': 'budi',
    'memperbudikan': 'budi',
    'berbuih': 'buih',
    'membuih': 'buih',
    'pembuih': 'buih',
    'berbukit': 'bukit',
    'berbukitan': 'bukit',
    'membukit': 'bukit',
    'membukitkan': 'bukit',
    'perbukitan': 'bukit',
    'perbukitannya': 'bukit',
    'berbukit-bukit': 'bukit',
    'berbukti': 'bukti',
    'berbuktian': 'bukti',
    'terbukti': 'bukti',
    'terbuktinya': 'bukti',
    'terbuktilah': 'bukti',
    'terbuktikan': 'bukti',
    'terbuktii': 'bukti',
    'pembuktian': 'bukti',
    'pembuktiannya': 'bukti',
    'pembuktiani': 'bukti',
    'membuktikan': 'bukti',
    'membuktikannya': 'bukti',
    'bulanan': 'bulan',
    'bulanannya': 'bulan',
    'bulananlah': 'bulan',
    'bulananan': 'bulan',
    'bulananmu': 'bulan',
    'bulanan-mu': 'bulan',
    'berbulan': 'bulan',
    'membulan': 'bulan',
    'bulan-bulanan': 'bulan',
    'bulan-bulanannya': 'bulan',
    'bulan-bulananan': 'bulan',
    'berbulan-bulan': 'bulan',
    'berbulan-bulanlah': 'bulan',
    'membulan-bulani': 'bulan',
    'berbulu': 'bulu',
    'berbulunya': 'bulu',
    'membului': 'bulu',
    'berbunga': 'bunga',
    'membunga': 'bunga',
    'membungakan': 'bunga',
    'membungai': 'bunga',
    'perbungaan': 'bunga',
    'bunga-bungaan': 'bunga',
    'berbunga-bunga': 'bunga',
    'berbunga-bunganya': 'bunga',
    'memperbungakan': 'bunga',
    'membunga-bungai': 'bunga',
    'sebunyi': 'bunyi',
    'berbunyi': 'bunyi',
    'berbunyinya': 'bunyi',
    'berbunyilah': 'bunyi',
    'berbunyikan': 'bunyi',
    'pembunyian': 'bunyi',
    'pembunyiannya': 'bunyi',
    'membunyikan': 'bunyi',
    'membunyikannya': 'bunyi',
    'bunyi-bunyian': 'bunyi',
    'buruan': 'buru',
    'buruannya': 'buru',
    'keburu': 'buru',
    'keburukan': 'buru',
    'keburukannya': 'buru',
    'terburu': 'buru',
    'terburuku': 'buru',
    'memburu': 'buru',
    'memburunya': 'buru',
    'memburukan': 'buru',
    'memburuku': 'buru',
    'memburumu': 'buru',
    'pemburu': 'buru',
    'pemburunya': 'buru',
    'pemburulah': 'buru',
    'pemburukan': 'buru',
    'pemburuan': 'buru',
    'berburu': 'buru',
    'berburunya': 'buru',
    'berburuan': 'buru',
    'perburuan': 'buru',
    'perburuannya': 'buru',
    'berburu-buru': 'buru',
    'terburu-buru': 'buru',
    'terburu-burunya': 'buru',
    'terburu-burulah': 'buru',
    'memburu-buru': 'buru',
    'memburu-burukan': 'buru',
    'pembusa': 'busa',
    'pembusaan': 'busa',
    'membusa': 'busa',
    'berbusa': 'busa',
    'berbusanya': 'busa',
    'membusakan': 'busa',
    'membutir': 'butir',
    'berbutir': 'butir',
    'berbutir-butir': 'butir',
    'mencabang': 'cabang',
    'bercabang': 'cabang',
    'bercabangnya': 'cabang',
    'bercabanglah': 'cabang',
    'pencabangan': 'cabang',
    'percabangan': 'cabang',
    'percabangannya': 'cabang',
    'mencabangkan': 'cabang',
    'mempercabangkan': 'cabang',
    'bercabang-cabang': 'cabang',
    'cacahan': 'cacah',
    'cacahannya': 'cacah',
    'bercacah': 'cacah',
    'pencacah': 'cacah',
    'pencacahnya': 'cacah',
    'pencacahan': 'cacah',
    'mencacah': 'cacah',
    'mencacah-cacah': 'cacah',
    'bebercak': 'bercak',
    'cakapan': 'cakap',
    'bercakap': 'cakap',
    'bercakapan': 'cakap',
    'kecakapan': 'cakap',
    'kecakapannya': 'cakap',
    'mencakapi': 'cakap',
    'percakapan': 'cakap',
    'percakapannya': 'cakap',
    'percakapanlah': 'cakap',
    'percakapanmu': 'cakap',
    'mempercakap': 'cakap',
    'mempercakapkan': 'cakap',
    'bercakap-cakap': 'cakap',
    'bercakap-cakaplah': 'cakap',
    'tercalar': 'calar',
    'bercalar': 'calar',
    'calar-balar': 'calar',
    'mencalarkan': 'calar',
    'bercanggah': 'canggah',
    'bercangkuk': 'cangkuk',
    'mencangkuk': 'cangkuk',
    'tercantum': 'cantum',
    'tercantumnya': 'cantum',
    'tercantumkan': 'cantum',
    'tercantuman': 'cantum',
    'mencantum': 'cantum',
    'mencantumkan': 'cantum',
    'mencantumkannya': 'cantum',
    'mencantuman': 'cantum',
    'bercantum': 'cantum',
    'bercantumkan': 'cantum',
    'pencantuman': 'cantum',
    'pencantumannya': 'cantum',
    'catan': 'cat',
    'catani': 'cat',
    'catanan': 'cat',
    'bercat': 'cat',
    'bercatkan': 'cat',
    'mengecat': 'cat',
    'mengecatnya': 'cat',
    'pengecatan': 'cat',
    'pengecatannya': 'cat',
    'berceloteh': 'celoteh',
    'bercendawan': 'cendawan',
    'bercengkerama': 'cengkerama',
    'bercengkeramalah': 'cengkerama',
    'berceracak': 'ceracak',
    'mencerai': 'cerai',
    'menceraikan': 'cerai',
    'menceraikannya': 'cerai',
    'menceraiku': 'cerai',
    'tercerai': 'cerai',
    'bercerai': 'cerai',
    'bercerainya': 'cerai',
    'berceraian': 'cerai',
    'perceraian': 'cerai',
    'perceraiannya': 'cerai',
    'perceraianmu': 'cerai',
    'penceraian': 'cerai',
    'penceraiannya': 'cerai',
    'bercerai-cerai': 'cerai',
    'berceramah': 'ceramah',
    'penceramah': 'ceramah',
    'penceramahnya': 'ceramah',
    'penceramahan': 'ceramah',
    'menceramahkan': 'ceramah',
    'berceranggah': 'ceranggah',
    'ceritaan': 'cerita',
    'bercerita': 'cerita',
    'berceritalah': 'cerita',
    'berceritakan': 'cerita',
    'pencerita': 'cerita',
    'penceritanya': 'cerita',
    'penceritaan': 'cerita',
    'menceritai': 'cerita',
    'penceritaannya': 'cerita',
    'menceritakan': 'cerita',
    'menceritakannya': 'cerita',
    'menceritakankan': 'cerita',
    'bercinta': 'cinta',
    'bercintanya': 'cinta',
    'bercintalah': 'cinta',
    'bercintaku': 'cinta',
    'mencinta': 'cinta',
    'mencintanya': 'cinta',
    'mencintai': 'cinta',
    'mencintaku': 'cinta',
    'mencintamu': 'cinta',
    'tercinta': 'cinta',
    'tercintanya': 'cinta',
    'tercintaku': 'cinta',
    'tercintamu': 'cinta',
    'pencinta': 'cinta',
    'pencintanya': 'cinta',
    'kecintaan': 'cinta',
    'kecintaannya': 'cinta',
    'kecintaanku': 'cinta',
    'kecintaanmu': 'cinta',
    'mencintainya': 'cinta',
    'mencintaiku': 'cinta',
    'mencintaimu': 'cinta',
    'mencintai-mu': 'cinta',
    'percintaan': 'cinta',
    'percintaannya': 'cinta',
    'bercintakan': 'cinta',
    'mencintakan': 'cinta',
    'bercinta-cintaan': 'cinta',
    'bercorak': 'corak',
    'bercorakkan': 'corak',
    'bercorakan': 'corak',
    'corak-carik': 'corak',
    'tercoreng': 'coreng',
    'tercorengnya': 'coreng',
    'tercorengkan': 'coreng',
    'tercorengi': 'coreng',
    'bercoreng': 'coreng',
    'mencoreng': 'coreng',
    'mencorengnya': 'coreng',
    'mencorengkan': 'coreng',
    'coreng-moreng': 'coreng',
    'coreng-morengnya': 'coreng',
    'bercoreng-moreng': 'coreng',
    'bercoreng-coreng': 'coreng',
    'tercoreng-moreng': 'coreng',
    'cucuran': 'cucur',
    'mencucuri': 'cucur',
    'bercucuran': 'cucur',
    'mencucurkan': 'cucur',
    'mencukur': 'cukur',
    'mencukurnya': 'cukur',
    'pencukur': 'cukur',
    'pencukurnya': 'cukur',
    'pencukuran': 'cukur',
    'bercukur': 'cukur',
    'bercukurlah': 'cukur',
    'bercuti': 'cuti',
    'berdada': 'dada',
    'mendada': 'dada',
    'mendadakan': 'dadak',
    'berdada-dadaan': 'dada',
    'sedaging': 'daging',
    'pedaging': 'daging',
    'pedagingnya': 'daging',
    'pedagingan': 'daging',
    'pendaging': 'daging',
    'mendaging': 'daging',
    'mendagingku': 'daging',
    'terdaging': 'daging',
    'berdaging': 'daging',
    'daging-dagingan': 'daging',
    'mendahak': 'dahak',
    'berdahak': 'dahak',
    'berdakwah': 'dakwah',
    'berdakwahnya': 'dakwah',
    'berdakwahlah': 'dakwah',
    'pendakwah': 'dakwah',
    'mendakwah': 'dakwah',
    'mendakwahkan': 'dakwah',
    'mendakwahkannya': 'dakwah',
    'mendakwahi': 'dakwah',
    'mendalih': 'dalih',
    'mendalihkan': 'dalih',
    'berdalih': 'dalih',
    'berdalihnya': 'dalih',
    'berdalihkan': 'dalih',
    'berdalih-dalih': 'dalih',
    'pendamai': 'damai',
    'pendamaian': 'damai',
    'berdamai': 'damai',
    'berdamainya': 'damai',
    'berdamailah': 'damai',
    'berdamaian': 'damai',
    'kedamaian': 'damai',
    'kedamaiannya': 'damai',
    'kedamaianan': 'damai',
    'perdamaian': 'damai',
    'perdamaiannya': 'damai',
    'perdamaianan': 'damai',
    'mendamaikan': 'damai',
    'mendamaikannya': 'damai',
    'terdamaikan': 'damai',
    'memperdamaikan': 'damai',
    'berdamping': 'damping',
    'berdampingi': 'damping',
    'berdampingan': 'damping',
    'pendamping': 'damping',
    'pendampingnya': 'damping',
    'pendampingi': 'damping',
    'pendampingan': 'damping',
    'pendampingku': 'damping',
    'pendampingmu': 'damping',
    'kedampingan': 'damping',
    'mendampingi': 'damping',
    'mendampinginya': 'damping',
    'mendampingii': 'damping',
    'mendampingiku': 'damping',
    'mendampingimu': 'damping',
    'pendampingannya': 'damping',
    'pendampinganan': 'damping',
    'berdampingannya': 'damping',
    'mendampingkan': 'damping',
    'dandanan': 'dandan',
    'dandanannya': 'dandan',
    'berdandan': 'dandan',
    'berdandannya': 'dandan',
    'berdandanlah': 'dandan',
    'berdandanan': 'dandan',
    'mendandani': 'dandan',
    'mendandaninya': 'dandan',
    'mendandaniku': 'dandan',
    'pedansa': 'dansa',
    'berdansa': 'dansa',
    'berdansanya': 'dansa',
    'berdansalah': 'dansa',
    'dansa-dansi': 'dansa',
    'berdasar': 'dasar',
    'berdasarnya': 'dasar',
    'berdasarkan': 'dasar',
    'berdasarkannya': 'dasar',
    'berdasari': 'dasar',
    'berdasaran': 'dasar',
    'mendasar': 'dasar',
    'mendasarnya': 'dasar',
    'mendasarkan': 'dasar',
    'mendasarkannya': 'dasar',
    'mendasari': 'dasar',
    'mendasarinya': 'dasar',
    'berdasarkankan': 'dasar',
    'mendaulat': 'daulat',
    'mendaulatnya': 'daulat',
    'mendaulatkan': 'daulat',
    'berdaulat': 'daulat',
    'berdaulatnya': 'daulat',
    'berdaulatan': 'daulat',
    'pendaulat': 'daulat',
    'pendaulatan': 'daulat',
    'kedaulatan': 'daulat',
    'kedaulatannya': 'daulat',
    'kedaulatanlah': 'daulat',
    'pendaulatannya': 'daulat',
    'berdaun': 'daun',
    'berdaunkan': 'daun',
    'mendaun': 'daun',
    'dedaunan': 'daun',
    'dedaunannya': 'daun',
    'daun-daunan': 'daun',
    'berdaya': 'daya',
    'berdayanya': 'daya',
    'berdayakan': 'daya',
    'berdayaan': 'daya',
    'teperdaya': 'daya',
    'perdayaan': 'daya',
    'memperdaya': 'daya',
    'memperdayanya': 'daya',
    'memperdayakan': 'daya',
    'memperdayai': 'daya',
    'pemberdayaan': 'daya',
    'pemberdayaannya': 'daya',
    'memberdayakan': 'daya',
    'memberdayakannya': 'daya',
    'pedayung': 'dayung',
    'berdayung': 'dayung',
    'mendayung': 'dayung',
    'mendayungnya': 'dayung',
    'pendayung': 'dayung',
    'mendayungkan': 'dayung',
    'dayung-mayung': 'dayung',
    'debaran': 'debar',
    'berdebar': 'debar',
    'berdebarnya': 'debar',
    'mendebarkan': 'debar',
    'mendebarkannya': 'debar',
    'berdebar-debar': 'debar',
    'berdebu': 'debu',
    'mendebu': 'debu',
    'berdebuk': 'debuk',
    'berdebur': 'debur',
    'mendebur': 'debur',
    'mendecit': 'decit',
    'mendecitkan': 'decit',
    'berdecit': 'decit',
    'berdecitnya': 'decit',
    'berdedikasi': 'dedikasi',
    'berdedikasinya': 'dedikasi',
    'berdedikasilah': 'dedikasi',
    'deklamasian': 'deklamasi',
    'berdeklamasi': 'deklamasi',
    'pendeklamasian': 'deklamasi',
    'mendeklamasikan': 'deklamasi',
    'mendemonstrasi': 'demonstrasi',
    'mendemonstrasikan': 'demonstrasi',
    'mendemonstrasikannya': 'demonstrasi',
    'berdemonstrasi': 'demonstrasi',
    'mendengking': 'dengking',
    'berdengking': 'dengking',
    'mendengking-dengking': 'dengking',
    'dengking-mendengking': 'dengking',
    'dengkuran': 'dengkur',
    'dengkurannya': 'dengkur',
    'mendengkur': 'dengkur',
    'mendengkurnya': 'dengkur',
    'berdengkur': 'dengkur',
    'dengungan': 'dengung',
    'mendengung': 'dengung',
    'mendengungnya': 'dengung',
    'mendengungkan': 'dengung',
    'mendengungkannya': 'dengung',
    'berdengung': 'dengung',
    'berdengungnya': 'dengung',
    'dengusan': 'dengus',
    'dengusannya': 'dengus',
    'berdengus': 'dengus',
    'mendengus': 'dengus',
    'mendengus-dengus': 'dengus',
    'dentingan': 'denting',
    'mendenting': 'denting',
    'mendentingkan': 'denting',
    'berdenting': 'denting',
    'berdentingan': 'denting',
    'dentuman': 'dentum',
    'dentumannya': 'dentum',
    'berdentum': 'dentum',
    'berdentuman': 'dentum',
    'berdentumanlah': 'dentum',
    'berdentum-dentum': 'dentum',
    'denyaran': 'denyar',
    'berdenyar': 'denyar',
    'berdenyar-denyar': 'denyar',
    'menderam': 'deram',
    'berderam': 'deram',
    'berderam-deram': 'deram',
    'deretan': 'deret',
    'deretannya': 'deret',
    'berderet': 'deret',
    'berderetan': 'deret',
    'menderetkan': 'deret',
    'mendering': 'dering',
    'menderingkan': 'dering',
    'berdering': 'dering',
    'berdering-dering': 'dering',
    'menderum': 'derum',
    'berderum': 'derum',
    'menderumkan': 'derum',
    'mendesing': 'desing',
    'berdesing': 'desing',
    'berdesingan': 'desing',
    'berdesing-desing': 'desing',
    'desiran': 'desir',
    'berdesir': 'desir',
    'mendesir': 'desir',
    'detikan': 'detik',
    'mendetik': 'detik',
    'berdetik': 'detik',
    'detik-detik': 'detik',
    'detik-detiknya': 'detik',
    'pendiam': 'diam',
    'pendiamnya': 'diam',
    'pendiamlah': 'diam',
    'pendiaman': 'diam',
    'berdiam': 'diam',
    'berdiamnya': 'diam',
    'berdiamlah': 'diam',
    'terdiam': 'diam',
    'terdiamnya': 'diam',
    'terdiamlah': 'diam',
    'mendiami': 'diam',
    'mendiaminya': 'diam',
    'mendiamimu': 'diam',
    'kediaman': 'diam',
    'kediamannya': 'diam',
    'kediamanan': 'diam',
    'kediamanku': 'diam',
    'diam-diam': 'diam',
    'diam-diamnya': 'diam',
    'diam-diamkan': 'diam',
    'diam-diaman': 'diam',
    'mendiamkan': 'diam',
    'mendiamkannya': 'diam',
    'kependiaman': 'diam',
    'didiang': 'diang',
    'mendiang': 'diang',
    'berdiang': 'diang',
    'pendiangan': 'diang',
    'pendiet': 'diet',
    'berdiet': 'diet',
    'berdietnya': 'diet',
    'pendiri': 'diri',
    'pendirinya': 'diri',
    'pendirikan': 'diri',
    'pendirii': 'diri',
    'pendirian': 'diri',
    'terdiri': 'diri',
    'terdirii': 'diri',
    'berdiri': 'diri',
    'berdirinya': 'diri',
    'berdirilah': 'diri',
    'berdirikan': 'diri',
    'berdiriku': 'diri',
    'pendiriannya': 'diri',
    'pendirianku': 'diri',
    'pendirianmu': 'diri',
    'mendirikan': 'diri',
    'mendirikannya': 'diri',
    'mendirikankan': 'diri',
    'berpendirian': 'diri',
    'berpendiriannya': 'diri',
    'berdisiplin': 'disiplin',
    'berdisiplinlah': 'disiplin',
    'mendisiplinkan': 'disiplin',
    'mendisiplinkannya': 'disiplin',
    'mendoa': 'doa',
    'mendoakan': 'doa',
    'mendoakannya': 'doa',
    'mendoaan': 'doa',
    'berdoa': 'doa',
    'berdoanya': 'doa',
    'berdoalah': 'doa',
    'mendoakanlah': 'doa',
    'mendoakanku': 'doa',
    'mendoakanmu': 'doa',
    'berdosa': 'dosa',
    'berdosanya': 'dosa',
    'berdosalah': 'dosa',
    'pendosa': 'dosa',
    'seduit': 'duit',
    'berduit': 'duit',
    'berduitnya': 'duit',
    'berduitlah': 'duit',
    'berdukacita': 'dukacita',
    'berdukacitanya': 'dukacita',
    'berdukacitalah': 'dukacita',
    'mendukacitakan': 'dukacita',
    'berduri': 'duri',
    'berdurinya': 'duri',
    'menduri': 'duri',
    'berduri-duri': 'duri',
    'berdusta': 'dusta',
    'pendusta': 'dusta',
    'pendustaan': 'dusta',
    'mendusta': 'dusta',
    'mendustakan': 'dusta',
    'mendustakannya': 'dusta',
    'mendustai': 'dusta',
    'mendustainya': 'dusta',
    'mereaksi': 'reaksi',
    'mereaksinya': 'reaksi',
    'mereaksikan': 'reaksi',
    'bereaksi': 'reaksi',
    'bereaksinya': 'reaksi',
    'bereaksilah': 'reaksi',
    'pereaksi': 'reaksi',
    'memberedel': 'beredel',
    'memberedelnya': 'beredel',
    'beregu': 'regu',
    'embunan': 'embun',
    'berembun': 'embun',
    'mengembun': 'embun',
    'mengembunkan': 'embun',
    'pengembun': 'embun',
    'pengembunan': 'embun',
    'mengembuni': 'embun',
    'pengembunannya': 'embun',
    'memperembunkan': 'embun',
    'perenang': 'renang',
    'perenangnya': 'renang',
    'perenangan': 'renang',
    'berenang': 'renang',
    'berenangnya': 'renang',
    'berenanglah': 'renang',
    'merenangi': 'renang',
    'berenangan': 'renang',
    'merenangkan': 'renang',
    'merenda': 'renda',
    'merendakan': 'renda',
    'berenda': 'renda',
    'merendai': 'renda',
    'keberengsekan': 'berengsek',
    'berengsel': 'engsel',
    'memberengut': 'berengut',
    'memberentang': 'berentang',
    'memberentangkan': 'berentang',
    'memberesi': 'beres',
    'memberesinya': 'beres',
    'keberesan': 'beres',
    'pemberesan': 'beres',
    'pemberesannya': 'beres',
    'membereskan': 'beres',
    'membereskannya': 'beres',
    'berevolusi': 'revolusi',
    'berevolusinya': 'revolusi',
    'berfalsafah': 'falsafah',
    'berfalsafahkan': 'falsafah',
    'berfungsi': 'fungsi',
    'berfungsinya': 'fungsi',
    'berfungsilah': 'fungsi',
    'berfungsikan': 'fungsi',
    'berfungsii': 'fungsi',
    'memfungsikan': 'fungsi',
    'memfungsikannya': 'fungsi',
    'pegadai': 'gadai',
    'pegadainya': 'gadai',
    'pegadaian': 'gadai',
    'gadaian': 'gadai',
    'gadaiannya': 'gadai',
    'tergadai': 'gadai',
    'tergadailah': 'gadai',
    'tergadaikan': 'gadai',
    'bergadai': 'gadai',
    'menggadai': 'gadai',
    'menggadainya': 'gadai',
    'menggadaikan': 'gadai',
    'menggadaikannya': 'gadai',
    'pegadaiannya': 'gadai',
    'penggadai': 'gadai',
    'penggadaian': 'gadai',
    'bergaduh': 'gaduh',
    'penggaduh': 'gaduh',
    'menggaduh': 'gaduh',
    'menggaduhkan': 'gaduh',
    'kegaduhan': 'gaduh',
    'kegaduhannya': 'gaduh',
    'pergaduhan': 'gaduh',
    'penggaduhan': 'gaduh',
    'gambaran': 'gambar',
    'gambarannya': 'gambar',
    'gambaranku': 'gambar',
    'tergambar': 'gambar',
    'tergambarnya': 'gambar',
    'tergambarlah': 'gambar',
    'tergambarkan': 'gambar',
    'bergambar': 'gambar',
    'bergambarnya': 'gambar',
    'bergambarkan': 'gambar',
    'menggambar': 'gambar',
    'menggambarnya': 'gambar',
    'menggambarkan': 'gambar',
    'menggambarkannya': 'gambar',
    'menggambari': 'gambar',
    'menggambaran': 'gambar',
    'penggambar': 'gambar',
    'penggambarnya': 'gambar',
    'penggambarkan': 'gambar',
    'penggambaran': 'gambar',
    'menggambarinya': 'gambar',
    'penggambarannya': 'gambar',
    'menggambarkankan': 'gambar',
    'menggambarkanmu': 'gambar',
    'gambar-menggambar': 'gambar',
    'berganda': 'ganda',
    'bergandanya': 'ganda',
    'mengganda': 'ganda',
    'menggandakan': 'ganda',
    'menggandakannya': 'ganda',
    'menggandaan': 'ganda',
    'pergandaan': 'ganda',
    'penggandaan': 'ganda',
    'penggandaannya': 'ganda',
    'mempergandakan': 'ganda',
    'berganda-ganda': 'ganda',
    'ganda-berganda': 'ganda',
    'memperganda-gandakan': 'ganda',
    'berganding': 'ganding',
    'bergandingan': 'ganding',
    'mempergandingkan': 'ganding',
    'terganjak': 'ganjak',
    'berganjak': 'ganjak',
    'mengganjak': 'ganjak',
    'mengganjakkan': 'ganjak',
    'berganti': 'ganti',
    'bergantinya': 'ganti',
    'bergantilah': 'ganti',
    'bergantikan': 'ganti',
    'bergantian': 'ganti',
    'mengganti': 'ganti',
    'menggantinya': 'ganti',
    'menggantikan': 'ganti',
    'menggantikannya': 'ganti',
    'menggantii': 'ganti',
    'menggantian': 'ganti',
    'menggantiku': 'ganti',
    'menggantimu': 'ganti',
    'pengganti': 'ganti',
    'penggantinya': 'ganti',
    'penggantikan': 'ganti',
    'penggantian': 'ganti',
    'penggantinyalah': 'ganti',
    'penggantiku': 'ganti',
    'penggantimu': 'ganti',
    'pergantian': 'ganti',
    'pergantiannya': 'ganti',
    'penggantiannya': 'ganti',
    'menggantikanku': 'ganti',
    'berganti-ganti': 'ganti',
    'berganti-gantinya': 'ganti',
    'berganti-gantian': 'ganti',
    'gantungan': 'gantung',
    'gantungannya': 'gantung',
    'bergantung': 'gantung',
    'bergantungnya': 'gantung',
    'bergantunglah': 'gantung',
    'bergantungkan': 'gantung',
    'bergantungan': 'gantung',
    'tergantung': 'gantung',
    'tergantungnya': 'gantung',
    'tergantunglah': 'gantung',
    'tergantungan': 'gantung',
    'menggantung': 'gantung',
    'menggantungnya': 'gantung',
    'menggantunglah': 'gantung',
    'menggantungkan': 'gantung',
    'menggantungkannya': 'gantung',
    'menggantungi': 'gantung',
    'menggantungan': 'gantung',
    'menggantungmu': 'gantung',
    'pergantungan': 'gantung',
    'penggantungan': 'gantung',
    'ketergantungan': 'gantung',
    'ketergantungannya': 'gantung',
    'mempergantungi': 'gantung',
    'bergaul': 'gaul',
    'bergaulnya': 'gaul',
    'bergaullah': 'gaul',
    'bergaulan': 'gaul',
    'menggaul': 'gaul',
    'menggauli': 'gaul',
    'menggaulinya': 'gaul',
    'pergaulan': 'gaul',
    'pergaulannya': 'gaul',
    'pergaulanmu': 'gaul',
    'mempergauli': 'gaul',
    'menggaulkan': 'gaul',
    'mempergaulkan': 'gaul',
    'bergaung': 'gaung',
    'bergaungnya': 'gaung',
    'bergaunglah': 'gaung',
    'menggaung': 'gaung',
    'menggaungnya': 'gaung',
    'menggaungkan': 'gaung',
    'menggaungkannya': 'gaung',
    'bergaya': 'gaya',
    'bergayanya': 'gaya',
    'bergayalah': 'gaya',
    'menggaya': 'gaya',
    'menggayakan': 'gaya',
    'gaya-gayanya': 'gaya',
    'bergaya-gaya': 'gaya',
    'bergaya-gayaan': 'gaya',
    'gayutan': 'gayut',
    'bergayut': 'gayut',
    'penggayut': 'gayut',
    'menggayuti': 'gayut',
    'bergayutan': 'gayut',
    'menggayutkan': 'gayut',
    'tergegar': 'gegar',
    'bergegar': 'gegar',
    'menggegar': 'gegar',
    'menggegarkan': 'gegar',
    'tergegas': 'gegas',
    'bergegas': 'gegas',
    'bergegasnya': 'gegas',
    'bergegaslah': 'gegas',
    'menggegas': 'gegas',
    'menggegaskan': 'gegas',
    'penggegasan': 'gegas',
    'mempergegas': 'gegas',
    'tergegas-gegas': 'gegas',
    'bergegas-gegas': 'gegas',
    'bergejolak': 'gejolak',
    'bergejolaknya': 'gejolak',
    'menggejolak': 'gejolak',
    'bergelar': 'gelar',
    'bergelarnya': 'gelar',
    'menggelar': 'gelar',
    'menggelarnya': 'gelar',
    'menggelarkan': 'gelar',
    'menggelari': 'gelar',
    'menggelaran': 'gelar',
    'pegelaran': 'gelar',
    'pergelaran': 'gelar',
    'pergelarannya': 'gelar',
    'menggelarinya': 'gelar',
    'mempergelarkan': 'gelar',
    'bergelimpang': 'gelimpang',
    'bergelimpangnya': 'gelimpang',
    'bergelimpangan': 'gelimpang',
    'tergelimpang': 'gelimpang',
    'bergelombang': 'gelombang',
    'bergelombangnya': 'gelombang',
    'menggelombang': 'gelombang',
    'menggelombangkan': 'gelombang',
    'bergelora': 'gelora',
    'bergeloranya': 'gelora',
    'menggelora': 'gelora',
    'menggeloranya': 'gelora',
    'menggelorakan': 'gelora',
    'menggelorakannya': 'gelora',
    'gelungan': 'gelung',
    'bergelung': 'gelung',
    'menggelung': 'gelung',
    'menggelungnya': 'gelung',
    'menggelungkan': 'gelung',
    'tergelung-gelung': 'gelung',
    'gelutan': 'gelut',
    'bergelut': 'gelut',
    'menggelut': 'gelut',
    'menggeluti': 'gelut',
    'menggelutinya': 'gelut',
    'bergema': 'gema',
    'bergemanya': 'gema',
    'bergemalah': 'gema',
    'menggema': 'gema',
    'menggemanya': 'gema',
    'menggemalah': 'gema',
    'menggemakan': 'gema',
    'menggemakannya': 'gema',
    'menggemai': 'gema',
    'bergembira': 'gembira',
    'bergembiranya': 'gembira',
    'bergembiralah': 'gembira',
    'kegembiraan': 'gembira',
    'kegembiraannya': 'gembira',
    'kegembiraanku': 'gembira',
    'penggembira': 'gembira',
    'penggembiranya': 'gembira',
    'menggembirakan': 'gembira',
    'menggembirakannya': 'gembira',
    'menggembirakanlah': 'gembira',
    'mempergembirakan': 'gembira',
    'bergemuruh': 'gemuruh',
    'bergemuruhnya': 'gemuruh',
    'bergemuruhlah': 'gemuruh',
    'kegemuruhan': 'gemuruh',
    'menggemuruh': 'gemuruh',
    'menggemuruhkan': 'gemuruh',
    'tergenang': 'genang',
    'tergenangnya': 'genang',
    'tergenangi': 'genang',
    'tergenangan': 'genang',
    'bergenang': 'genang',
    'kegenangan': 'genang',
    'menggenang': 'genang',
    'menggenangnya': 'genang',
    'menggenangkan': 'genang',
    'menggenangi': 'genang',
    'menggenangan': 'genang',
    'menggenanginya': 'genang',
    'menggenangii': 'genang',
    'penggenangan': 'genang',
    'penggenangannya': 'genang',
    'segendang': 'gendang',
    'gendangan': 'gendang',
    'bergendang': 'gendang',
    'gendang-gendang': 'gendang',
    'gerakan': 'gerak',
    'gerakannya': 'gerak',
    'gerakanlah': 'gerak',
    'gerakani': 'gerak',
    'gerakanan': 'gerak',
    'gerakanku': 'gerak',
    'gerakanmu': 'gerak',
    'bergerak': 'gerak',
    'bergeraknya': 'gerak',
    'bergeraklah': 'gerak',
    'bergeraki': 'gerak',
    'bergerakan': 'gerak',
    'tergerak': 'gerak',
    'tergeraknya': 'gerak',
    'tergeraklah': 'gerak',
    'tergerakkan': 'gerak',
    'tergerakan': 'gerak',
    'penggerak': 'gerak',
    'penggeraknya': 'gerak',
    'penggerakkan': 'gerak',
    'penggerakan': 'gerak',
    'pergerakan': 'gerak',
    'pergerakannya': 'gerak',
    'pergerakanan': 'gerak',
    'pergerakanku': 'gerak',
    'pergerakanmu': 'gerak',
    'penggerakannya': 'gerak',
    'menggerakkan': 'gerak',
    'menggerakkannya': 'gerak',
    'menggerakkanku': 'gerak',
    'menggerak-gerakkan': 'gerak',
    'menggerak-gerakkanku': 'gerak',
    'bergerigi': 'gerigi',
    'bergerincing': 'gerincing',
    'gesekan': 'gesek',
    'gesekannya': 'gesek',
    'bergesek': 'gesek',
    'bergesekkan': 'gesek',
    'bergesekan': 'gesek',
    'menggesek': 'gesek',
    'menggeseknya': 'gesek',
    'menggesekkan': 'gesek',
    'menggesekkannya': 'gesek',
    'menggesekan': 'gesek',
    'penggesek': 'gesek',
    'penggeseknya': 'gesek',
    'penggesekan': 'gesek',
    'pergesekan': 'gesek',
    'pergesekannya': 'gesek',
    'mempergesekkan': 'gesek',
    'bergesel': 'gesel',
    'menggesel': 'gesel',
    'geseran': 'geser',
    'bergeser': 'geser',
    'bergesernya': 'geser',
    'bergeserlah': 'geser',
    'bergeseran': 'geser',
    'menggeser': 'geser',
    'menggesernya': 'geser',
    'menggeserkan': 'geser',
    'pergeseran': 'geser',
    'pergeserannya': 'geser',
    'penggeseran': 'geser',
    'penggeserannya': 'geser',
    'tergetah': 'getah',
    'bergetah': 'getah',
    'menggetah': 'getah',
    'pergetahan': 'getah',
    'penggetahan': 'getah',
    'getaran': 'getar',
    'getarannya': 'getar',
    'bergetar': 'getar',
    'bergetarnya': 'getar',
    'bergetarlah': 'getar',
    'penggetar': 'getar',
    'penggetarnya': 'getar',
    'penggetaran': 'getar',
    'menggetar': 'getar',
    'menggetarkan': 'getar',
    'menggetarkannya': 'getar',
    'bergigi': 'gigi',
    'bergiginya': 'gigi',
    'pergigian': 'gigi',
    'golakan': 'golak',
    'bergolak': 'golak',
    'bergolaknya': 'golak',
    'pergolakan': 'golak',
    'pergolakannya': 'golak',
    'bergolak-golak': 'golak',
    'bergolek': 'golek',
    'tergolek': 'golek',
    'tergoleknya': 'golek',
    'menggolek': 'golek',
    'bergolekan': 'golek',
    'menggolekkan': 'golek',
    'bergolek-golek': 'golek',
    'tergolek-golek': 'golek',
    'goresan': 'gores',
    'goresannya': 'gores',
    'bergores': 'gores',
    'bergoreskan': 'gores',
    'tergores': 'gores',
    'tergoresnya': 'gores',
    'menggores': 'gores',
    'menggoresnya': 'gores',
    'menggoreskan': 'gores',
    'menggoreskannya': 'gores',
    'penggores': 'gores',
    'penggoresan': 'gores',
    'bergores-gores': 'gores',
    'tergoyang': 'goyang',
    'tergoyangnya': 'goyang',
    'tergoyangkan': 'goyang',
    'bergoyang': 'goyang',
    'bergoyangnya': 'goyang',
    'bergoyanglah': 'goyang',
    'kegoyangan': 'goyang',
    'menggoyang': 'goyang',
    'menggoyangnya': 'goyang',
    'menggoyangkan': 'goyang',
    'menggoyangkannya': 'goyang',
    'bergoyang-goyang': 'goyang',
    'menggoyang-goyangkan': 'goyang',
    'menggoyang-goyangkannya': 'goyang',
    'berguling': 'guling',
    'bergulingnya': 'guling',
    'bergulinglah': 'guling',
    'bergulingan': 'guling',
    'terguling': 'guling',
    'tergulingnya': 'guling',
    'tergulingkan': 'guling',
    'mengguling': 'guling',
    'menggulingkan': 'guling',
    'menggulingkannya': 'guling',
    'menggulingan': 'guling',
    'terguling-guling': 'guling',
    'bergumam': 'gumam',
    'menggumam': 'gumam',
    'menggumamkan': 'gumam',
    'gumpalan': 'gumpal',
    'gumpalannya': 'gumpal',
    'bergumpal': 'gumpal',
    'bergumpalan': 'gumpal',
    'menggumpal': 'gumpal',
    'menggumpalnya': 'gumpal',
    'menggumpalkan': 'gumpal',
    'penggumpalan': 'gumpal',
    'penggumpalannya': 'gumpal',
    'bergumpal-gumpal': 'gumpal',
    'bergumpal-gumpalan': 'gumpal',
    'seguna': 'guna',
    'berguna': 'guna',
    'bergunanya': 'guna',
    'pengguna': 'guna',
    'penggunanya': 'guna',
    'penggunalah': 'guna',
    'penggunakan': 'guna',
    'penggunakannya': 'guna',
    'penggunai': 'guna',
    'penggunaan': 'guna',
    'kegunaan': 'guna',
    'kegunaannya': 'guna',
    'guna-guna': 'guna',
    'guna-gunalah': 'guna',
    'penggunaannya': 'guna',
    'penggunaanan': 'guna',
    'guna-ganah': 'guna',
    'menggunakan': 'guna',
    'menggunakannya': 'guna',
    'menggunakankan': 'guna',
    'menggunakanan': 'guna',
    'menggunakanku': 'guna',
    'mempergunakan': 'guna',
    'mempergunakannya': 'guna',
    'gurauan': 'gurau',
    'gurauannya': 'gurau',
    'bergurau': 'gurau',
    'pergurauan': 'gurau',
    'mengguraukan': 'gurau',
    'memperguraukan': 'gurau',
    'bergusti': 'gusti',
    'hajatan': 'hajat',
    'hajatannya': 'hajat',
    'berhajat': 'hajat',
    'menghajati': 'hajat',
    'menghajatkan': 'hajat',
    'berhala': 'hala',
    'berhalakan': 'hala',
    'menghalakan': 'hala',
    'hamburan': 'hambur',
    'terhambur': 'hambur',
    'terhamburnya': 'hambur',
    'terhamburkan': 'hambur',
    'terhamburan': 'hambur',
    'menghambur': 'hambur',
    'menghamburkan': 'hambur',
    'menghamburkannya': 'hambur',
    'menghamburan': 'hambur',
    'menghamburi': 'hambur',
    'berhamburan': 'hambur',
    'berhamburannya': 'hambur',
    'penghamburan': 'hambur',
    'menghambur-hamburkan': 'hambur',
    'menghambur-hamburkannya': 'hambur',
    'berhantu': 'hantu',
    'menghantu': 'hantu',
    'menghantui': 'hantu',
    'menghantuinya': 'hantu',
    'menghantuiku': 'hantu',
    'menghantuimu': 'hantu',
    'berharga': 'harga',
    'berharganya': 'harga',
    'berhargaan': 'harga',
    'berhargaku': 'harga',
    'menghargai': 'harga',
    'menghargainya': 'harga',
    'menghargailah': 'harga',
    'menghargaii': 'harga',
    'menghargaiku': 'harga',
    'menghargaimu': 'harga',
    'penghargaan': 'harga',
    'penghargaannya': 'harga',
    'penghargaanku': 'harga',
    'menghargakan': 'harga',
    'menghargakannya': 'harga',
    'berhasil': 'hasil',
    'berhasilnya': 'hasil',
    'berhasillah': 'hasil',
    'berhasilkan': 'hasil',
    'berhasilan': 'hasil',
    'penghasil': 'hasil',
    'penghasilnya': 'hasil',
    'penghasilkan': 'hasil',
    'penghasilan': 'hasil',
    'penghasilannya': 'hasil',
    'penghasilanku': 'hasil',
    'penghasilanmu': 'hasil',
    'pemberhasil': 'hasil',
    'menghasilkan': 'hasil',
    'menghasilkannya': 'hasil',
    'keberhasilan': 'hasil',
    'keberhasilannya': 'hasil',
    'keberhasilanlah': 'hasil',
    'keberhasilanan': 'hasil',
    'keberhasilanku': 'hasil',
    'keberhasilanmu': 'hasil',
    'terhasrat': 'hasrat',
    'berhasrat': 'hasrat',
    'berhasratnya': 'hasrat',
    'kehasratan': 'hasrat',
    'menghasratkan': 'hasrat',
    'berhemat': 'hemat',
    'berhematlah': 'hemat',
    'berhematan': 'hemat',
    'menghemat': 'hemat',
    'menghematnya': 'hemat',
    'menghematlah': 'hemat',
    'menghematkan': 'hemat',
    'kehematan': 'hemat',
    'kehematannya': 'hemat',
    'penghematan': 'hemat',
    'penghematannya': 'hemat',
    'hentian': 'henti',
    'terhenti': 'henti',
    'terhentinya': 'henti',
    'terhentilah': 'henti',
    'terhentikan': 'henti',
    'berhenti': 'henti',
    'berhentinya': 'henti',
    'berhentilah': 'henti',
    'berhentikan': 'henti',
    'berhentikannya': 'henti',
    'berhentii': 'henti',
    'penghenti': 'henti',
    'penghentikan': 'henti',
    'penghentikannya': 'henti',
    'penghentian': 'henti',
    'perhentian': 'henti',
    'perhentiannya': 'henti',
    'penghentiannya': 'henti',
    'menghentikan': 'henti',
    'menghentikannya': 'henti',
    'menghentikanku': 'henti',
    'menghentikanmu': 'henti',
    'pemberhentian': 'henti',
    'pemberhentiannya': 'henti',
    'memberhentikan': 'henti',
    'memberhentikannya': 'henti',
    'memperhentikan': 'henti',
    'hiasan': 'hias',
    'hiasannya': 'hias',
    'berhias': 'hias',
    'berhiaskan': 'hias',
    'berhiasi': 'hias',
    'berhiasan': 'hias',
    'terhias': 'hias',
    'menghias': 'hias',
    'menghiasnya': 'hias',
    'menghiaskan': 'hias',
    'menghiasi': 'hias',
    'penghias': 'hias',
    'penghiasnya': 'hias',
    'perhiasan': 'hias',
    'perhiasannya': 'hias',
    'perhiasanku': 'hias',
    'menghiasinya': 'hias',
    'memperhiasi': 'hias',
    'berhidung': 'hidung',
    'menghidung': 'hidung',
    'berhipotesis': 'hipotesis',
    'menghipotesiskan': 'hipotesis',
    'berhormat': 'hormat',
    'terhormat': 'hormat',
    'terhormatnya': 'hormat',
    'terhormatlah': 'hormat',
    'menghormat': 'hormat',
    'menghormati': 'hormat',
    'menghormatan': 'hormat',
    'penghormat': 'hormat',
    'penghormatan': 'hormat',
    'kehormatan': 'hormat',
    'kehormatannya': 'hormat',
    'kehormatanku': 'hormat',
    'kehormatanmu': 'hormat',
    'menghormatinya': 'hormat',
    'menghormatilah': 'hormat',
    'menghormatii': 'hormat',
    'menghormatiku': 'hormat',
    'menghormatimu': 'hormat',
    'penghormatannya': 'hormat',
    'berhormat-hormat': 'hormat',
    'hormat-menghormati': 'hormat',
    'hubungan': 'hubung',
    'hubungannya': 'hubung',
    'hubunganlah': 'hubung',
    'hubungankan': 'hubung',
    'hubungannyalah': 'hubung',
    'hubunganku': 'hubung',
    'hubunganmu': 'hubung',
    'berhubung': 'hubung',
    'berhubungnya': 'hubung',
    'berhubungkan': 'hubung',
    'berhubungan': 'hubung',
    'penghubung': 'hubung',
    'penghubungnya': 'hubung',
    'penghubungkan': 'hubung',
    'penghubungi': 'hubung',
    'penghubungan': 'hubung',
    'berhubungannya': 'hubung',
    'berhubunganlah': 'hubung',
    'berhubunganan': 'hubung',
    'perhubungan': 'hubung',
    'perhubungannya': 'hubung',
    'menghubungi': 'hubung',
    'menghubunginya': 'hubung',
    'menghubungiku': 'hubung',
    'menghubungimu': 'hubung',
    'menghubungkan': 'hubung',
    'menghubungkannya': 'hubung',
    'menghubungkanku': 'hubung',
    'memperhubungkan': 'hubung',
    'menghubung-hubungkan': 'hubung',
    'menghubung-hubungkannya': 'hubung',
    'menghubung-hubungkankan': 'hubung',
    'hunian': 'huni',
    'huniannya': 'huni',
    'hunianmu': 'huni',
    'berhuni': 'huni',
    'berhunikan': 'huni',
    'berhunian': 'huni',
    'terhuni': 'huni',
    'menghuni': 'huni',
    'menghuninya': 'huni',
    'penghuni': 'huni',
    'penghuninya': 'huni',
    'penghunian': 'huni',
    'penghuniannya': 'huni',
    'berpenghuni': 'huni',
    'berpenghuninya': 'huni',
    'berpenghunikan': 'huni',
    'menghunikan': 'huni',
    'tahu': 'beri',
    'tahunya': 'beri',
    'tahulah': 'beri',
    'tahukan': 'beri',
    'tahukannya': 'beri',
    'tahui': 'beri',
    'tahuan': 'beri',
    'tahuku': 'beri',
    'tahumu': 'beri',
    'berian': 'beri',
    'beriani': 'beri',
    'memberi': 'beri',
    'memberinya': 'beri',
    'memberikan': 'beri',
    'memberikannya': 'beri',
    'memberian': 'beri',
    'memberiku': 'beri',
    'memberimu': 'beri',
    'pemberi': 'beri',
    'pemberinya': 'beri',
    'pemberikan': 'beri',
    'pemberii': 'beri',
    'pemberian': 'beri',
    'pemberiannya': 'beri',
    'pemberianmu': 'beri',
    'memberikankan': 'beri',
    'memberikanan': 'beri',
    'memberikanku': 'beri',
    'memberikanmu': 'beri',
    'beri-memberi': 'beri',
    'memberi tahu': 'beri',
    'pemberitahuan': 'beri',
    'pemberitahuannya': 'beri',
    'pemberitahuanlah': 'beri',
    'memberitahukan': 'beri',
    'memberitahukannya': 'beri',
    'memberitahukanku': 'beri',
    'memberitahukanmu': 'beri',
    'ribuan': 'ribu',
    'ribuannya': 'ribu',
    'ribuanlah': 'ribu',
    'ribuanan': 'ribu',
    'seribu': 'ribu',
    'seribunya': 'ribu',
    'seribuan': 'ribu',
    'beribu-ribu': 'ribu',
    'menyeribu': 'ribu',
    'berikhtiar': 'ikhtiar',
    'berikhtiarlah': 'ikhtiar',
    'mengikhtiarkan': 'ikhtiar',
    'mengikhtiarkannya': 'ikhtiar',
    'berikrar': 'ikrar',
    'berikrarkan': 'ikrar',
    'pengikraran': 'ikrar',
    'mengikrarkan': 'ikrar',
    'ikutan': 'ikut',
    'ikutannya': 'ikut',
    'ikutanlah': 'ikut',
    'berikut': 'ikut',
    'berikutnya': 'ikut',
    'berikutlah': 'ikut',
    'berikutkan': 'ikut',
    'berikutkannya': 'ikut',
    'berikuti': 'ikut',
    'berikutan': 'ikut',
    'berikutku': 'ikut',
    'terikut': 'ikut',
    'terikutkan': 'ikut',
    'terikuti': 'ikut',
    'pengikut': 'ikut',
    'pengikutnya': 'ikut',
    'pengikuti': 'ikut',
    'pengikutan': 'ikut',
    'pengikutku': 'ikut',
    'pengikutmu': 'ikut',
    'mengikut': 'ikut',
    'mengikutnya': 'ikut',
    'mengikutkan': 'ikut',
    'mengikutkannya': 'ikut',
    'mengikuti': 'ikut',
    'ikut-ikut': 'ikut',
    'ikut-ikutlah': 'ikut',
    'ikut-ikutkan': 'ikut',
    'ikut-ikutan': 'ikut',
    'mengikutinya': 'ikut',
    'mengikutikan': 'ikut',
    'mengikutii': 'ikut',
    'mengikutian': 'ikut',
    'mengikutiku': 'ikut',
    'mengikutimu': 'ikut',
    'memperikut': 'ikut',
    'ikut-ikutanlah': 'ikut',
    'ikut-ikutanan': 'ikut',
    'memperikutkan': 'ikut',
    'beriman': 'iman',
    'keimanan': 'iman',
    'keimanannya': 'iman',
    'keimananan': 'iman',
    'keimananmu': 'iman',
    'mengimani': 'iman',
    'mengimaninya': 'iman',
    'berimankan': 'iman',
    'berimigrasi': 'imigrasi',
    'keimigrasian': 'imigrasi',
    'keimigrasiannya': 'imigrasi',
    'seberinda': 'berinda',
    'pemberingas': 'beringas',
    'keberingasan': 'beringas',
    'keberingasannya': 'beringas',
    'berintegrasi': 'integrasi',
    'berintegrasinya': 'integrasi',
    'berintegrasii': 'integrasi',
    'berintegrasian': 'integrasi',
    'mengintegrasikan': 'integrasi',
    'mengintegrasikannya': 'integrasi',
    'berinteraksi': 'interaksi',
    'berinteraksinya': 'interaksi',
    'berinteraksilah': 'interaksi',
    'seirama': 'irama',
    'seiramanya': 'irama',
    'berirama': 'irama',
    'mengiramakan': 'irama',
    'seisi': 'isi',
    'seisinya': 'isi',
    'isian': 'isi',
    'isiannya': 'isi',
    'isianlah': 'isi',
    'terisi': 'isi',
    'terisinya': 'isi',
    'terisikan': 'isi',
    'berisi': 'isi',
    'berisinya': 'isi',
    'berisikan': 'isi',
    'pengisi': 'isi',
    'pengisinya': 'isi',
    'pengisikan': 'isi',
    'pengisian': 'isi',
    'mengisi': 'isi',
    'mengisinya': 'isi',
    'mengisikan': 'isi',
    'mengisikannya': 'isi',
    'mengisii': 'isi',
    'mengisian': 'isi',
    'pengisiannya': 'isi',
    'berberita': 'berita',
    'pemberita': 'berita',
    'pemberitakan': 'berita',
    'pemberitaan': 'berita',
    'pemberitaannya': 'berita',
    'memberitakan': 'berita',
    'memberitakannya': 'berita',
    'penjaja': 'jaja',
    'penjajakan': 'jaja',
    'penjajakannya': 'jaja',
    'penjajaan': 'jaja',
    'menjaja': 'jaja',
    'menjajakan': 'jaja',
    'menjajakannya': 'jaja',
    'berjaja': 'jaja',
    'jaja-jajaan': 'jaja',
    'jajaran': 'jajar',
    'jajarannya': 'jajar',
    'sejajar': 'jajar',
    'sejajarnya': 'jajar',
    'sejajarlah': 'jajar',
    'sejajarkan': 'jajar',
    'sejajaran': 'jajar',
    'menjajar': 'jajar',
    'menjajarkan': 'jajar',
    'menjajarkannya': 'jajar',
    'menjajari': 'jajar',
    'menjajaran': 'jajar',
    'terjajar': 'jajar',
    'berjajar': 'jajar',
    'berjajarnya': 'jajar',
    'berjajaran': 'jajar',
    'pejajaran': 'jajar',
    'penjajaran': 'jajar',
    'persejajaran': 'jajar',
    'menyejajarkan': 'jajar',
    'menyejajarkannya': 'jajar',
    'sejalan': 'jalan',
    'sejalannya': 'jalan',
    'sejalankan': 'jalan',
    'jalanan': 'jalan',
    'jalanannya': 'jalan',
    'jalananlah': 'jalan',
    'jalananan': 'jalan',
    'jalananmu': 'jalan',
    'pejalan': 'jalan',
    'pejalanan': 'jalan',
    'berjalan': 'jalan',
    'berjalannya': 'jalan',
    'berjalanlah': 'jalan',
    'berjalankan': 'jalan',
    'berjalanan': 'jalan',
    'berjalanku': 'jalan',
    'menjalani': 'jalan',
    'menjalaninya': 'jalan',
    'menjalanikan': 'jalan',
    'menjalanii': 'jalan',
    'perjalanan': 'jalan',
    'perjalanannya': 'jalan',
    'perjalananlah': 'jalan',
    'perjalananan': 'jalan',
    'perjalananku': 'jalan',
    'perjalananmu': 'jalan',
    'kesejalanan': 'jalan',
    'menjalankan': 'jalan',
    'menjalankannya': 'jalan',
    'menjalankankan': 'jalan',
    'menjalankanan': 'jalan',
    'berjalan-jalan': 'jalan',
    'berjalan-jalannya': 'jalan',
    'berjalan-jalanlah': 'jalan',
    'jalinan': 'jalin',
    'jalinannya': 'jalin',
    'berjalin': 'jalin',
    'berjalinan': 'jalin',
    'menjalin': 'jalin',
    'menjalinnya': 'jalin',
    'menjalinkan': 'jalin',
    'menjalinkannya': 'jalin',
    'menjalini': 'jalin',
    'menjalinan': 'jalin',
    'terjalin': 'jalin',
    'terjalinnya': 'jalin',
    'terjalinlah': 'jalin',
    'terjalinkan': 'jalin',
    'terjalinan': 'jalin',
    'penjalinan': 'jalin',
    'jalin-berjalin': 'jalin',
    'berjalin-jalin': 'jalin',
    'jalin-menjalin': 'jalin',
    'jamuan': 'jamu',
    'jamuannya': 'jamu',
    'berjamu': 'jamu',
    'menjamu': 'jamu',
    'menjamunya': 'jamu',
    'menjamui': 'jamu',
    'perjamuan': 'jamu',
    'perjamuannya': 'jamu',
    'penjamuan': 'jamu',
    'memperjamu': 'jamu',
    'menjamukan': 'jamu',
    'jangkitan': 'jangkit',
    'menjangkit': 'jangkit',
    'menjangkitnya': 'jangkit',
    'menjangkiti': 'jangkit',
    'berjangkit': 'jangkit',
    'berjangkitnya': 'jangkit',
    'kejangkitan': 'jangkit',
    'terjangkiti': 'jangkit',
    'terjangkitinya': 'jangkit',
    'berjangkitan': 'jangkit',
    'penjangkitan': 'jangkit',
    'menjangkitkan': 'jangkit',
    'jongkat-jangkit': 'jangkit',
    'berjanji': 'janji',
    'berjanjinya': 'janji',
    'berjanjilah': 'janji',
    'berjanjii': 'janji',
    'berjanjian': 'janji',
    'perjanjian': 'janji',
    'perjanjiannya': 'janji',
    'perjanjianan': 'janji',
    'menjanjikan': 'janji',
    'menjanjikannya': 'janji',
    'menjanjikanlah': 'janji',
    'menjanjikanku': 'janji',
    'menjanjikanmu': 'janji',
    'menjarak': 'jarak',
    'menjarakkan': 'jarak',
    'menjarakan': 'jarak',
    'berjarak': 'jarak',
    'berjarakan': 'jarak',
    'terjarak': 'jarak',
    'menjaraki': 'jarak',
    'berjaya': 'jaya',
    'berjayanya': 'jaya',
    'berjayalah': 'jaya',
    'kejayaan': 'jaya',
    'kejayaannya': 'jaya',
    'menjayakan': 'jaya',
    'keberjayaan': 'jaya',
    'berjeda': 'jeda',
    'terjela': 'jela',
    'berjela': 'jela',
    'berjela-jela': 'jela',
    'jemuran': 'jemur',
    'jemurannya': 'jemur',
    'menjemur': 'jemur',
    'menjemurnya': 'jemur',
    'menjemurkan': 'jemur',
    'berjemur': 'jemur',
    'berjemurnya': 'jemur',
    'berjemurlah': 'jemur',
    'terjemur': 'jemur',
    'penjemuran': 'jemur',
    'penjemurannya': 'jemur',
    'berjenaka': 'jenaka',
    'kejenakaan': 'jenaka',
    'kejenakaannya': 'jenaka',
    'menjengket': 'jengket',
    'berjengket': 'jengket',
    'bersijengket': 'jengket',
    'bersejengket': 'jengket',
    'jerawatan': 'jerawat',
    'berjerawat': 'jerawat',
    'berjimat': 'jimat',
    'berjiran': 'jiran',
    'jualan': 'jual',
    'jualannya': 'jual',
    'jualanlah': 'jual',
    'jualanan': 'jual',
    'jualanku': 'jual',
    'dijual': 'jual',
    'dijualnya': 'jual',
    'dijuallah': 'jual',
    'dijualkan': 'jual',
    'dijualkannya': 'jual',
    'dijuali': 'jual',
    'dijualan': 'jual',
    'menjual': 'jual',
    'menjualnya': 'jual',
    'menjualkan': 'jual',
    'menjualkannya': 'jual',
    'menjuali': 'jual',
    'menjualan': 'jual',
    'menjualku': 'jual',
    'menjualmu': 'jual',
    'terjual': 'jual',
    'terjualnya': 'jual',
    'terjuallah': 'jual',
    'terjualan': 'jual',
    'penjual': 'jual',
    'penjualnya': 'jual',
    'penjualkan': 'jual',
    'penjualan': 'jual',
    'berjual': 'jual',
    'berjualan': 'jual',
    'penjualannya': 'jual',
    'penjualankan': 'jual',
    'penjualanan': 'jual',
    'penjualanku': 'jual',
    'penjualanmu': 'jual',
    'berjualannya': 'jual',
    'berjualanan': 'jual',
    'dijuang': 'juang',
    'dijuangkan': 'juang',
    'pejuang': 'juang',
    'pejuangnya': 'juang',
    'pejuangan': 'juang',
    'berjuang': 'juang',
    'berjuangnya': 'juang',
    'berjuanglah': 'juang',
    'berjuangkan': 'juang',
    'berjuangan': 'juang',
    'kejuangan': 'juang',
    'kejuangannya': 'juang',
    'perjuangan': 'juang',
    'perjuangannya': 'juang',
    'perjuanganlah': 'juang',
    'perjuangankan': 'juang',
    'perjuanganan': 'juang',
    'perjuanganku': 'juang',
    'perjuanganmu': 'juang',
    'kepejuangan': 'juang',
    'memperjuangkan': 'juang',
    'memperjuangkannya': 'juang',
    'pejudi': 'judi',
    'berjudi': 'judi',
    'berjudinya': 'judi',
    'perjudian': 'judi',
    'perjudiannya': 'judi',
    'penjudian': 'judi',
    'menjudikan': 'judi',
    'memperjudikan': 'judi',
    'berjujuh': 'jujuh',
    'menjujuh': 'jujuh',
    'berjumbai': 'jumbai',
    'menjumbai': 'jumbai',
    'terjumbai': 'jumbai',
    'berjumbaian': 'jumbai',
    'jumbai-jumbai': 'jumbai',
    'berjumbai-jumbai': 'jumbai',
    'terjuntai': 'juntai',
    'menjuntai': 'juntai',
    'menjuntainya': 'juntai',
    'menjuntaikan': 'juntai',
    'berjuntai': 'juntai',
    'berjuntaian': 'juntai',
    'penjuntaian': 'juntai',
    'berjuntai-juntai': 'juntai',
    'terjurai': 'jurai',
    'berjurai': 'jurai',
    'berjuraian': 'jurai',
    'jurai-jurai': 'jurai',
    'berjurai-jurai': 'jurai',
    'mengabung': 'kabung',
    'mengabungkan': 'kabung',
    'mengabungkannya': 'kabung',
    'berkabung': 'kabung',
    'berkabungnya': 'kabung',
    'berkabungmu': 'kabung',
    'perkabungan': 'kabung',
    'perkabungannya': 'kabung',
    'mengabung-ngabung': 'kabung',
    'pengabut': 'kabut',
    'pengabutan': 'kabut',
    'berkabut': 'kabut',
    'mengabutkan': 'kabut',
    'mengaki': 'kaki',
    'mengakikan': 'kaki',
    'berkaki': 'kaki',
    'berkala': 'kala',
    'berkalanya': 'kala',
    'berkala-kala': 'kala',
    'berkaliber': 'kaliber',
    'berkanji': 'kanji',
    'kaparan': 'kapar',
    'berkapar': 'kapar',
    'terkapar': 'kapar',
    'terkaparnya': 'kapar',
    'berkaparan': 'kapar',
    'mengaparkan': 'kapar',
    'karatan': 'karat',
    'berkarat': 'karat',
    'berkaratnya': 'karat',
    'berkasan': 'berkas',
    'memberkas': 'berkas',
    'memberkaskan': 'berkas',
    'terberkas': 'berkas',
    'pemberkas': 'berkas',
    'pemberkasan': 'berkas',
    'pemberkasannya': 'berkas',
    'memberkati': 'berkat',
    'memberkatinya': 'berkat',
    'memberkatiku': 'berkat',
    'memberkatimu': 'berkat',
    'keberkatan': 'berkat',
    'pemberkatan': 'berkat',
    'pemberkatannya': 'berkat',
    'mengata': 'kata',
    'mengatakannya': 'kata',
    'mengatai': 'kata',
    'mengataan': 'kata',
    'mengataku': 'kata',
    'berkata': 'kata',
    'berkatalah': 'kata',
    'mengatainya': 'kata',
    'mengataikan': 'kata',
    'mengataian': 'kata',
    'perkataan': 'kata',
    'perkataannya': 'kata',
    'perkataanku': 'kata',
    'perkataanmu': 'kata',
    'terkatakan': 'kata',
    'mengatakankan': 'kata',
    'mengatakani': 'kata',
    'mengatakanan': 'kata',
    'mengatakanku': 'kata',
    'berkata-kata': 'kata',
    'memperkatakan': 'kata',
    'mengata-ngatai': 'kata',
    'mengata-ngatainya': 'kata',
    'kawanan': 'kawan',
    'kawanannya': 'kawan',
    'kawananan': 'kawan',
    'berkawan': 'kawan',
    'berkawanan': 'kawan',
    'perkawanan': 'kawan',
    'perkawanannya': 'kawan',
    'berkayuh': 'kayuh',
    'mengayuh': 'kayuh',
    'mengayuhnya': 'kayuh',
    'mengayuhlah': 'kayuh',
    'mengayuhkan': 'kayuh',
    'pengayuh': 'kayuh',
    'pengayuhnya': 'kayuh',
    'terkayuhkan': 'kayuh',
    'pekebun': 'kebun',
    'pekebunan': 'kebun',
    'berkebun': 'kebun',
    'berkebunnya': 'kebun',
    'berkebunan': 'kebun',
    'perkebunan': 'kebun',
    'perkebunannya': 'kebun',
    'perkebunanlah': 'kebun',
    'perkebunanan': 'kebun',
    'memperkebuni': 'kebun',
    'memperkebunkan': 'kebun',
    'berkecai': 'kecai',
    'terkecai': 'kecai',
    'berkecai-kecai': 'kecai',
    'pengecambah': 'kecambah',
    'pengecambahan': 'kecambah',
    'berkecambah': 'kecambah',
    'berkecambahnya': 'kecambah',
    'perkecambahan': 'kecambah',
    'mengecambahkan': 'kecambah',
    'berkecamuk': 'kecamuk',
    'berkecamuknya': 'kecamuk',
    'berkecimpung': 'kecimpung',
    'berkecimpungnya': 'kecimpung',
    'kedaian': 'kedai',
    'pekedai': 'kedai',
    'berkedai': 'kedai',
    'terkedai': 'kedai',
    'perkedaian': 'kedai',
    'mengedaikan': 'kedai',
    'memperkedaikan': 'kedai',
    'kedutan': 'kedut',
    'kedutannya': 'kedut',
    'kedutanan': 'kedut',
    'berkedut': 'kedut',
    'berkedutan': 'kedut',
    'mengedut': 'kedut',
    'mengedutkan': 'kedut',
    'kekekalan': 'kekal',
    'berkekalan': 'kekal',
    'mengekalkan': 'kekal',
    'mengekalkannya': 'kekal',
    'berkeladak': 'keladak',
    'berkelahi': 'kelahi',
    'berkelahinya': 'kelahi',
    'berkelahian': 'kelahi',
    'perkelahian': 'kelahi',
    'perkelahiannya': 'kelahi',
    'memperkelahikan': 'kelahi',
    'berkelakar': 'kelakar',
    'berkelana': 'kelana',
    'berkelananya': 'kelana',
    'pengelana': 'kelana',
    'pengelanaan': 'kelana',
    'mengelana': 'kelana',
    'sekeliling': 'keliling',
    'sekelilingnya': 'keliling',
    'sekelilingku': 'keliling',
    'sekelilingmu': 'keliling',
    'berkeliling': 'keliling',
    'berkelilingnya': 'keliling',
    'berkelilinglah': 'keliling',
    'berkelilingi': 'keliling',
    'pengeliling': 'keliling',
    'pengelilingan': 'keliling',
    'mengelilingi': 'keliling',
    'mengelilinginya': 'keliling',
    'mengelilingiku': 'keliling',
    'mengelilingimu': 'keliling',
    'mengelilingkan': 'keliling',
    'berkelok': 'kelok',
    'mengelok': 'kelok',
    'mengelokkan': 'kelok',
    'berkelok-kelok': 'kelok',
    'berkelok-keloknya': 'kelok',
    'berkelopak': 'kelopak',
    'terkelopak': 'kelopak',
    'mengelopak': 'kelopak',
    'berkeluarga': 'keluarga',
    'kekeluargaan': 'keluarga',
    'kekeluargaannya': 'keluarga',
    'kekeluargaanlah': 'keluarga',
    'perkeluargaan': 'keluarga',
    'kemasan': 'kemas',
    'kemasannya': 'kemas',
    'kemasanlah': 'kemas',
    'kemasani': 'kemas',
    'kemasanan': 'kemas',
    'berkemas': 'kemas',
    'berkemasan': 'kemas',
    'pengemas': 'kemas',
    'pengemasnya': 'kemas',
    'pengemasan': 'kemas',
    'mengemas': 'kemas',
    'mengemasnya': 'kemas',
    'mengemaskan': 'kemas',
    'mengemaskannya': 'kemas',
    'mengemasi': 'kemas',
    'mengemasinya': 'kemas',
    'perkemasan': 'kemas',
    'pengemasannya': 'kemas',
    'kembangan': 'kembang',
    'kembangannya': 'kembang',
    'kembangankan': 'kembang',
    'berkembang': 'kembang',
    'berkembangnya': 'kembang',
    'berkembanglah': 'kembang',
    'berkembangkan': 'kembang',
    'berkembangan': 'kembang',
    'pengembang': 'kembang',
    'pengembangnya': 'kembang',
    'pengembanglah': 'kembang',
    'pengembangkan': 'kembang',
    'pengembangkannya': 'kembang',
    'pengembangan': 'kembang',
    'mengembang': 'kembang',
    'mengembangnya': 'kembang',
    'mengembangkan': 'kembang',
    'mengembangkannya': 'kembang',
    'mengembangi': 'kembang',
    'mengembangan': 'kembang',
    'pengembangannya': 'kembang',
    'pengembangankan': 'kembang',
    'pengembanganan': 'kembang',
    'perkembangan': 'kembang',
    'perkembangannya': 'kembang',
    'perkembanganlah': 'kembang',
    'perkembanganan': 'kembang',
    'perkembangannyalah': 'kembang',
    'perkembanganku': 'kembang',
    'mengembangkankan': 'kembang',
    'memperkembangkan': 'kembang',
    'kembaran': 'kembar',
    'kembarannya': 'kembar',
    'kembaranku': 'kembar',
    'berkembar': 'kembar',
    'mengembari': 'kembar',
    'mengembarkan': 'kembar',
    'pengemudi': 'kemudi',
    'pengemudinya': 'kemudi',
    'pengemudilah': 'kemudi',
    'pengemudikan': 'kemudi',
    'pengemudian': 'kemudi',
    'berkemudi': 'kemudi',
    'mengemudikan': 'kemudi',
    'mengemudikannya': 'kemudi',
    'berkenan': 'kenan',
    'berkenannya': 'kenan',
    'berkenanan': 'kenan',
    'perkenan': 'kenan',
    'perkenannya': 'kenan',
    'perkenankan': 'kenan',
    'perkenanan': 'kenan',
    'memperkenankan': 'kenan',
    'memperkenankannya': 'kenan',
    'terkepak': 'kepak',
    'berkepak': 'kepak',
    'mengepak': 'pak',
    'mengepaknya': 'pak',
    'mengepakkan': 'pak',
    'mengepakkannya': 'pak',
    'mengepaki': 'pak',
    'mengepakan': 'pak',
    'terkepak-kepak': 'kepak',
    'berkepak-kepak': 'kepak',
    'mengepak-ngepak': 'kepak',
    'mengepak-ngepakkan': 'kepak',
    'kepungan': 'kepung',
    'kepungannya': 'kepung',
    'terkepung': 'kepung',
    'terkepungnya': 'kepung',
    'pengepung': 'kepung',
    'pengepungnya': 'kepung',
    'pengepungkan': 'kepung',
    'pengepungan': 'kepung',
    'berkepung': 'kepung',
    'mengepung': 'kepung',
    'mengepungnya': 'kepung',
    'pengepungannya': 'kepung',
    'terkerak': 'kerak',
    'terkeraknya': 'kerak',
    'berkerak': 'kerak',
    'pengeras': 'keras',
    'pengerasnya': 'keras',
    'pengerasan': 'keras',
    'mengeras': 'keras',
    'mengerasnya': 'keras',
    'mengeraskan': 'keras',
    'mengeraskannya': 'keras',
    'mengerasi': 'keras',
    'mengerasan': 'keras',
    'berkeras': 'keras',
    'berkerasnya': 'keras',
    'berkerasi': 'keras',
    'mengerasikannya': 'keras',
    'kekerasan': 'keras',
    'kekerasannya': 'keras',
    'kekerasanlah': 'keras',
    'kekerasanan': 'keras',
    'bersikeras': 'sikeras',
    'bersikerasnya': 'sikeras',
    'bersikerasi': 'sikeras',
    'memperkeras': 'keras',
    'keras-mengerasi': 'keras',
    'berkeras-kerasan': 'keras',
    'berkeringat': 'keringat',
    'berkeringatlah': 'keringat',
    'berkeringatan': 'keringat',
    'mengeringatkan': 'keringat',
    'berkeriut': 'keriut',
    'berkeriutan': 'keriut',
    'kerumunan': 'kerumun',
    'kerumunannya': 'kerumun',
    'kerumunanan': 'kerumun',
    'sekerumun': 'kerumun',
    'sekerumunan': 'kerumun',
    'berkerumun': 'kerumun',
    'berkerumunnya': 'kerumun',
    'berkerumunan': 'kerumun',
    'mengerumuni': 'kerumun',
    'mengerumuninya': 'kerumun',
    'mengerumuniku': 'kerumun',
    'mengerut': 'kerut',
    'mengerutnya': 'kerut',
    'mengerutkan': 'kerut',
    'mengerutkannya': 'kerut',
    'terkerut': 'kerut',
    'berkerut': 'kerut',
    'pengerut': 'kerut',
    'pengerutan': 'kerut',
    'berkerut-kerut': 'kerut',
    'bersinambung': 'sinambung',
    'bersinambungan': 'sinambung',
    'kesinambungan': 'sinambung',
    'kesinambungannya': 'sinambung',
    'menyinambungkan': 'sinambung',
    'berkesinambungan': 'sinambung',
    'berkesinambungannya': 'sinambung',
    'berkesot': 'kesot',
    'mengesot': 'kesot',
    'terkesot-kesot': 'kesot',
    'berketak': 'ketak',
    'berketuk-ketak': 'ketak',
    'berketak-ketik': 'ketak',
    'berketak-ketak': 'ketak',
    'ketukan': 'ketuk',
    'ketukannya': 'ketuk',
    'pengetuk': 'ketuk',
    'pengetukan': 'ketuk',
    'terketuk': 'ketuk',
    'mengetuk': 'ketuk',
    'mengetuknya': 'ketuk',
    'mengetukkan': 'ketuk',
    'mengetuki': 'ketuk',
    'mengetukan': 'ketuk',
    'berketuk': 'ketuk',
    'berkhasiat': 'khasiat',
    'berkhasiatnya': 'khasiat',
    'mengkhasiati': 'khasiat',
    'berkhidmat': 'khidmat',
    'kekhidmatan': 'khidmat',
    'kekhidmatannya': 'khidmat',
    'kibaran': 'kibar',
    'pengibar': 'kibar',
    'pengibarnya': 'kibar',
    'pengibaran': 'kibar',
    'berkibar': 'kibar',
    'berkibarnya': 'kibar',
    'berkibarlah': 'kibar',
    'berkibaran': 'kibar',
    'pengibarannya': 'kibar',
    'mengibarkan': 'kibar',
    'mengibarkannya': 'kibar',
    'berkibar-kibar': 'kibar',
    'mengibar-ngibarkan': 'kibar',
    'mengibar-ngibarkannya': 'kibar',
    'kicauan': 'kicau',
    'kicauannya': 'kicau',
    'kicauanmu': 'kicau',
    'berkicau': 'kicau',
    'berkicaunya': 'kicau',
    'berkicaulah': 'kicau',
    'berkicauan': 'kicau',
    'kilatan': 'kilat',
    'kilatannya': 'kilat',
    'mengilat': 'kilat',
    'berkilat': 'kilat',
    'berkilatan': 'kilat',
    'terkilat': 'kilat',
    'mengilatkan': 'kilat',
    'berkilat-kilat': 'kilat',
    'mengilat-ngilatkan': 'kilat',
    'kilauan': 'kilau',
    'kilauannya': 'kilau',
    'mengilau': 'kilau',
    'mengilaukan': 'kilau',
    'berkilau': 'kilau',
    'berkilaunya': 'kilau',
    'berkilaulah': 'kilau',
    'berkilauan': 'kilau',
    'berkilauannya': 'kilau',
    'kilau-mengilau': 'kilau',
    'berkilau-kilauan': 'kilau',
    'kiriman': 'kirim',
    'kirimannya': 'kirim',
    'kirimanmu': 'kirim',
    'terkirim': 'kirim',
    'terkirimnya': 'kirim',
    'terkirimlah': 'kirim',
    'terkirimkan': 'kirim',
    'pengirim': 'kirim',
    'pengirimnya': 'kirim',
    'pengirimkan': 'kirim',
    'pengiriman': 'kirim',
    'mengirim': 'kirim',
    'mengirimnya': 'kirim',
    'mengirimkan': 'kirim',
    'mengirimkannya': 'kirim',
    'mengirimi': 'kirim',
    'mengiriman': 'kirim',
    'mengirimku': 'kirim',
    'mengirimmu': 'kirim',
    'berkirim': 'kirim',
    'mengiriminya': 'kirim',
    'mengirimikan': 'kirim',
    'mengirimiku': 'kirim',
    'mengirimimu': 'kirim',
    'berkiriman': 'kirim',
    'perkiriman': 'kirim',
    'pengirimannya': 'kirim',
    'pengirimanan': 'kirim',
    'mengirimkankan': 'kirim',
    'mengirimkankannya': 'kirim',
    'mengirimkanku': 'kirim',
    'mengirimkanmu': 'kirim',
    'kirim-berkirim': 'kirim',
    'berkirim-kiriman': 'kirim',
    'kisaran': 'kisar',
    'kisarannya': 'kisar',
    'berkisar': 'kisar',
    'berkisaran': 'kisar',
    'mengisar': 'kisar',
    'pengisar': 'kisar',
    'pengisaran': 'kisar',
    'perkisaran': 'kisar',
    'mengisarkan': 'kisar',
    'berkisar-kisar': 'kisar',
    'sekitar': 'kitar',
    'sekitarnya': 'kitar',
    'sekitarlah': 'kitar',
    'sekitari': 'kitar',
    'sekitaran': 'kitar',
    'sekitarnyalah': 'kitar',
    'sekitarku': 'kitar',
    'sekitarmu': 'kitar',
    'berkitar': 'kitar',
    'mengitar': 'kitar',
    'mengitarkan': 'kitar',
    'mengitari': 'kitar',
    'mengitarinya': 'kitar',
    'pengitaran': 'kitar',
    'memperkitarkan': 'kitar',
    'terkitar-kitar': 'kitar',
    'mengitar-ngitar': 'kitar',
    'kobaran': 'kobar',
    'kobarannya': 'kobar',
    'terkobar': 'kobar',
    'berkobar': 'kobar',
    'berkobarnya': 'kobar',
    'berkobarlah': 'kobar',
    'berkobaran': 'kobar',
    'pengobaran': 'kobar',
    'mengobarkan': 'kobar',
    'terkobarkan': 'kobar',
    'berkobar-kobar': 'kobar',
    'berkobar-kobarnya': 'kobar',
    'berkocak': 'kocak',
    'terkocak': 'kocak',
    'mengocak': 'kocak',
    'mengocakkan': 'kocak',
    'berkocak-kocak': 'kocak',
    'berkokok': 'kokok',
    'berkokoknya': 'kokok',
    'komplotan': 'komplot',
    'komplotannya': 'komplot',
    'berkomplot': 'komplot',
    'berkomplotan': 'komplot',
    'berkompromi': 'kompromi',
    'berkompromilah': 'kompromi',
    'kongsian': 'kongsi',
    'berkongsi': 'kongsi',
    'perkongsian': 'kongsi',
    'perkongsiannya': 'kongsi',
    'berkotek': 'kotek',
    'berkuasa': 'kuasa',
    'berkuasanya': 'kuasa',
    'berkuasalah': 'kuasa',
    'berkuasai': 'kuasa',
    'penguasa': 'kuasa',
    'penguasanya': 'kuasa',
    'penguasai': 'kuasa',
    'penguasaan': 'kuasa',
    'kekuasaan': 'kuasa',
    'kekuasaannya': 'kuasa',
    'kekuasaanlah': 'kuasa',
    'kekuasaanku': 'kuasa',
    'kekuasaanmu': 'kuasa',
    'kekuasaan-ku': 'kuasa',
    'kekuasaan-mu': 'kuasa',
    'terkuasai': 'kuasa',
    'terkuasainya': 'kuasa',
    'menguasai': 'kuasa',
    'menguasainya': 'kuasa',
    'menguasaii': 'kuasa',
    'menguasaimu': 'kuasa',
    'penguasaannya': 'kuasa',
    'sekuasanya': 'kuasa',
    'menguasakan': 'kuasa',
    'sekuasa-kuasanya': 'kuasa',
    'sekuat': 'kuat',
    'sekuatnya': 'kuat',
    'menguat': 'kuat',
    'menguatnya': 'kuat',
    'menguatlah': 'kuat',
    'menguatkan': 'kuat',
    'menguatkannya': 'kuat',
    'menguati': 'kuat',
    'menguatan': 'kuat',
    'berkuat': 'kuat',
    'berkuatan': 'kuat',
    'penguat': 'kuat',
    'penguatnya': 'kuat',
    'penguatkan': 'kuat',
    'penguatan': 'kuat',
    'kekuatan': 'kuat',
    'kekuatannya': 'kuat',
    'kekuatanan': 'kuat',
    'kekuatanku': 'kuat',
    'kekuatanmu': 'kuat',
    'kekuatan-mu': 'kuat',
    'penguatannya': 'kuat',
    'penguatanan': 'kuat',
    'kuat-kuat': 'kuat',
    'kuat-kuatnya': 'kuat',
    'kuat-kuatan': 'kuat',
    'memperkuat': 'kuat',
    'memperkuatnya': 'kuat',
    'memperkuatkan': 'kuat',
    'memperkuatan': 'kuat',
    'berkuat-kuat': 'kuat',
    'berkuat-kuatan': 'kuat',
    'sekuat-kuatnya': 'kuat',
    'berkubah': 'kubah',
    'kubangan': 'kubang',
    'kubangannya': 'kubang',
    'berkubang': 'kubang',
    'berkubangnya': 'kubang',
    'mengubangkan': 'ubang',
    'terkubu': 'kubu',
    'berkubu': 'kubu',
    'mengubui': 'kubu',
    'perkubuan': 'kubu',
    'berkuda': 'kuda',
    'berkudanya': 'kuda',
    'perkudaan': 'kuda',
    'memperkuda': 'kuda',
    'kuda-kudaan': 'kuda',
    'memperkuda-kudakan': 'kuda',
    'sekuku': 'kuku',
    'berkuku': 'kuku',
    'berkulat': 'kulat',
    'kulian': 'kuli',
    'berkuli': 'kuli',
    'menguli': 'uli',
    'berkuliah': 'kuliah',
    'menguliahi': 'kuliah',
    'kumpulan': 'kumpul',
    'kumpulannya': 'kumpul',
    'terkumpul': 'kumpul',
    'terkumpulnya': 'kumpul',
    'terkumpullah': 'kumpul',
    'terkumpulkan': 'kumpul',
    'pengumpul': 'kumpul',
    'pengumpulnya': 'kumpul',
    'pengumpulkan': 'kumpul',
    'pengumpulan': 'kumpul',
    'berkumpul': 'kumpul',
    'berkumpulnya': 'kumpul',
    'berkumpullah': 'kumpul',
    'berkumpulkan': 'kumpul',
    'berkumpulan': 'kumpul',
    'pengumpulannya': 'kumpul',
    'pengumpulanan': 'kumpul',
    'perkumpulan': 'kumpul',
    'perkumpulannya': 'kumpul',
    'perkumpulanlah': 'kumpul',
    'mengumpulkan': 'kumpul',
    'mengumpulkannya': 'kumpul',
    'berkumur': 'kumur',
    'berkumurlah': 'kumur',
    'berkumuran': 'kumur',
    'berkumur-kumur': 'kumur',
    'kunjungan': 'kunjung',
    'kunjungannya': 'kunjung',
    'kunjunganku': 'kunjung',
    'kunjunganmu': 'kunjung',
    'pengunjung': 'kunjung',
    'pengunjungnya': 'kunjung',
    'pengunjunglah': 'kunjung',
    'pengunjungi': 'kunjung',
    'pengunjungan': 'kunjung',
    'berkunjung': 'kunjung',
    'berkunjungnya': 'kunjung',
    'berkunjunglah': 'kunjung',
    'berkunjungi': 'kunjung',
    'berkunjungan': 'kunjung',
    'mengunjungi': 'kunjung',
    'mengunjunginya': 'kunjung',
    'mengunjungii': 'kunjung',
    'mengunjungiku': 'kunjung',
    'mengunjungimu': 'kunjung',
    'berkunjung-kunjungan': 'kunjung',
    'pengurang': 'kurang',
    'pengurangnya': 'kurang',
    'pengurangkan': 'kurang',
    'pengurangi': 'kurang',
    'pengurangan': 'kurang',
    'berkurang': 'kurang',
    'berkurangnya': 'kurang',
    'berkuranglah': 'kurang',
    'berkurangkan': 'kurang',
    'berkurangi': 'kurang',
    'berkurangan': 'kurang',
    'mengurang': 'kurang',
    'mengurangnya': 'kurang',
    'mengurangkan': 'kurang',
    'mengurangkannya': 'kurang',
    'mengurangi': 'kurang',
    'mengurangan': 'kurang',
    'kekurangan': 'kurang',
    'kekurangannya': 'kurang',
    'kekuranganan': 'kurang',
    'kekuranganku': 'kurang',
    'kekuranganmu': 'kurang',
    'menguranginya': 'kurang',
    'mengurangii': 'kurang',
    'pengurangannya': 'kurang',
    'kurang-kurang': 'kurang',
    'kurang-kurangnya': 'kurang',
    'kurang-kurangi': 'kurang',
    'kurang-kurangan': 'kurang',
    'berkekurangan': 'kurang',
    'sekurang-kurangnya': 'kurang',
    'sekurang-kurangnyanya': 'kurang',
    'melabuh': 'labuh',
    'melabuhkan': 'labuh',
    'melabuhkannya': 'labuh',
    'labuhan': 'labuh',
    'labuhannya': 'labuh',
    'berlabuh': 'labuh',
    'berlabuhnya': 'labuh',
    'berlabuhan': 'labuh',
    'pelabuhan': 'labuh',
    'pelabuhannya': 'labuh',
    'pelabuhanlah': 'labuh',
    'pelabuhanan': 'labuh',
    'peladang': 'ladang',
    'peladangan': 'ladang',
    'berladang': 'ladang',
    'berladangnya': 'ladang',
    'perladangan': 'ladang',
    'perladangannya': 'ladang',
    'memperladang': 'ladang',
    'memperladangi': 'ladang',
    'memperladangkan': 'ladang',
    'melaga': 'laga',
    'melagakan': 'lagak',
    'belaga': 'laga',
    'pelaga': 'laga',
    'pelagai': 'laga',
    'berlaga': 'laga',
    'berlaganya': 'laga',
    'berlagalah': 'laga',
    'berlagai': 'laga',
    'perlagaan': 'laga',
    'memperlagakan': 'laga',
    'melaini': 'lain',
    'kelainan': 'lain',
    'kelainannya': 'lain',
    'kelainanan': 'lain',
    'berlainan': 'lain',
    'berlainannya': 'lain',
    'perlainan': 'lain',
    'melainkan': 'lain',
    'melainkanan': 'lain',
    'memperlain': 'lain',
    'berkelainan': 'lain',
    'memperlainkan': 'lain',
    'berlain-lainan': 'lain',
    'lakuan': 'laku',
    'selaku': 'laku',
    'selakunya': 'laku',
    'selakukan': 'laku',
    'selakui': 'laku',
    'pelaku': 'laku',
    'pelakunya': 'laku',
    'pelakulah': 'laku',
    'pelakukan': 'laku',
    'pelakukannya': 'laku',
    'pelakui': 'laku',
    'pelakuan': 'laku',
    'berlaku': 'laku',
    'berlakunya': 'laku',
    'berlakulah': 'laku',
    'berlakukan': 'laku',
    'berlakukannya': 'laku',
    'berlakui': 'laku',
    'berlakuan': 'laku',
    'kelakuan': 'laku',
    'kelakuannya': 'laku',
    'kelakuanku': 'laku',
    'kelakuanmu': 'laku',
    'perlakuan': 'laku',
    'perlakuannya': 'laku',
    'perlakuanmu': 'laku',
    'melakukan': 'laku',
    'melakukannya': 'laku',
    'melakukankan': 'laku',
    'melakukankannya': 'laku',
    'melakukani': 'laku',
    'melakukanan': 'laku',
    'keberlakuan': 'laku',
    'keberlakuannya': 'laku',
    'pemberlakuan': 'laku',
    'pemberlakuannya': 'laku',
    'memberlakukan': 'laku',
    'memberlakukannya': 'laku',
    'memperlakukan': 'laku',
    'memperlakukannya': 'laku',
    'memperlakukanku': 'laku',
    'memperlakukanmu': 'laku',
    'laluan': 'lalu',
    'melalui': 'lalu',
    'melaluinya': 'lalu',
    'melaluii': 'lalu',
    'berlalu': 'lalu',
    'berlalunya': 'lalu',
    'berlalulah': 'lalu',
    'berlalukan': 'lalu',
    'berlaluan': 'lalu',
    'terlalu': 'lalu',
    'terlalulah': 'lalu',
    'terlalui': 'lalu',
    'kelaluan': 'lalu',
    'melalukan': 'lalu',
    'melalukannya': 'lalu',
    'keterlaluan': 'terlalu',
    'keterlaluannya': 'terlalu',
    'keterlaluanlah': 'terlalu',
    'berkelaluan': 'lalu',
    'melambak': 'lambak',
    'terlambak': 'lambak',
    'berlambak': 'lambak',
    'berlambak-lambak': 'lambak',
    'melanjut': 'lanjut',
    'melanjutnya': 'lanjut',
    'melanjutkan': 'lanjut',
    'melanjutkannya': 'lanjut',
    'melanjuti': 'lanjut',
    'melanjutan': 'lanjut',
    'lanjutan': 'lanjut',
    'lanjutannya': 'lanjut',
    'lanjutanlah': 'lanjut',
    'pelanjut': 'lanjut',
    'pelanjutnya': 'lanjut',
    'pelanjutkan': 'lanjut',
    'pelanjutan': 'lanjut',
    'berlanjut': 'lanjut',
    'berlanjutnya': 'lanjut',
    'berlanjutlah': 'lanjut',
    'berlanjutkan': 'lanjut',
    'berlanjutan': 'lanjut',
    'pelanjutannya': 'lanjut',
    'kelanjutan': 'lanjut',
    'kelanjutannya': 'lanjut',
    'kelanjutanku': 'lanjut',
    'selanjutnya': 'lanjut',
    'selanjutnyalah': 'lanjut',
    'selanjutnyai': 'lanjut',
    'melanjutkankan': 'lanjut',
    'melanjutkani': 'lanjut',
    'perlanjutan': 'lanjut',
    'berkelanjutan': 'lanjut',
    'berkelanjutannya': 'lanjut',
    'melapuk': 'lapuk',
    'melapuknya': 'lapuk',
    'melapukkan': 'lapuk',
    'berlapuk': 'lapuk',
    'pelapukan': 'lapuk',
    'pelapukannya': 'lapuk',
    'kelapukan': 'lapuk',
    'berlapuk-lapuk': 'lapuk',
    'larian': 'lari',
    'lariannya': 'lari',
    'pelari': 'lari',
    'pelarinya': 'lari',
    'pelarilah': 'lari',
    'pelarikan': 'lari',
    'pelarian': 'lari',
    'selari': 'lari',
    'berlari': 'lari',
    'berlarinya': 'lari',
    'berlarilah': 'lari',
    'berlarikan': 'lari',
    'berlarii': 'lari',
    'berlarian': 'lari',
    'pelariannya': 'lari',
    'pelarianku': 'lari',
    'berlariani': 'lari',
    'melarikan': 'lari',
    'melarikannya': 'lari',
    'lari-lari': 'lari',
    'lari-larinya': 'lari',
    'lari-larian': 'lari',
    'sepelarian': 'lari',
    'berlari-lari': 'lari',
    'berlari-larian': 'lari',
    'pelatih': 'latih',
    'pelatihnya': 'latih',
    'pelatihlah': 'latih',
    'pelatihi': 'latih',
    'pelatihan': 'latih',
    'pelatihnyalah': 'latih',
    'pelatihku': 'latih',
    'pelatihmu': 'latih',
    'latihan': 'latih',
    'latihannya': 'latih',
    'latihanlah': 'latih',
    'latihani': 'latih',
    'latihanan': 'latih',
    'latihanku': 'latih',
    'latihanmu': 'latih',
    'melatih': 'latih',
    'melatihnya': 'latih',
    'melatihkan': 'latih',
    'melatihi': 'latih',
    'melatihan': 'latih',
    'melatihku': 'latih',
    'melatihmu': 'latih',
    'terlatih': 'latih',
    'terlatihnya': 'latih',
    'terlatihlah': 'latih',
    'berlatih': 'latih',
    'berlatihnya': 'latih',
    'berlatihlah': 'latih',
    'berlatihkan': 'latih',
    'berlatihi': 'latih',
    'berlatihan': 'latih',
    'pelatihannya': 'latih',
    'pelatihanan': 'latih',
    'pelatihanku': 'latih',
    'melawan': 'lawan',
    'melawannya': 'lawan',
    'melawanlah': 'lawan',
    'melawankan': 'lawan',
    'melawani': 'lawan',
    'melawanan': 'lawan',
    'melawanku': 'lawan',
    'melawanmu': 'lawan',
    'pelawan': 'lawan',
    'pelawanan': 'lawan',
    'terlawan': 'lawan',
    'terlawankan': 'lawan',
    'terlawanan': 'lawan',
    'berlawan': 'lawan',
    'berlawanan': 'lawan',
    'kelawanan': 'lawan',
    'perlawanan': 'lawan',
    'perlawanannya': 'lawan',
    'perlawananlah': 'lawan',
    'perlawananan': 'lawan',
    'perlawananmu': 'lawan',
    'berlawanannya': 'lawan',
    'berlawananan': 'lawan',
    'memperlawankan': 'lawan',
    'berlemak': 'lemak',
    'melepas': 'lepas',
    'melepasnya': 'lepas',
    'melepaskan': 'lepas',
    'melepaskannya': 'lepas',
    'melepasi': 'lepas',
    'melepasan': 'lepas',
    'melepasku': 'lepas',
    'melepasmu': 'lepas',
    'pelepas': 'lepas',
    'pelepasnya': 'lepas',
    'pelepaskan': 'lepas',
    'pelepasan': 'lepas',
    'selepas': 'lepas',
    'selepasnya': 'lepas',
    'lepasan': 'lepas',
    'berlepas': 'lepas',
    'terlepas': 'lepas',
    'terlepasnya': 'lepas',
    'terlepaslah': 'lepas',
    'terlepaskan': 'lepas',
    'kelepasan': 'lepas',
    'pelepasannya': 'lepas',
    'melepaskankan': 'lepas',
    'melepaskanku': 'lepas',
    'melepaskanmu': 'lepas',
    'memperlepas': 'lepas',
    'selepas-lepas': 'lepas',
    'selepas-lepasnya': 'lepas',
    'liburan': 'libur',
    'liburannya': 'libur',
    'liburanlah': 'libur',
    'liburanku': 'libur',
    'liburanmu': 'libur',
    'berlibur': 'libur',
    'berliburnya': 'libur',
    'berliburlah': 'libur',
    'berliburan': 'libur',
    'meliburkan': 'libur',
    'meliburkannya': 'libur',
    'lindungan': 'lindung',
    'lindungannya': 'lindung',
    'lindunganmu': 'lindung',
    'pelindung': 'lindung',
    'pelindungnya': 'lindung',
    'pelindungi': 'lindung',
    'pelindungan': 'lindung',
    'pelindungku': 'lindung',
    'pelindungmu': 'lindung',
    'terlindung': 'lindung',
    'terlindungnya': 'lindung',
    'terlindungi': 'lindung',
    'terlindungan': 'lindung',
    'berlindung': 'lindung',
    'berlindungnya': 'lindung',
    'berlindunglah': 'lindung',
    'berlindungi': 'lindung',
    'berlindungan': 'lindung',
    'melindungi': 'lindung',
    'melindunginya': 'lindung',
    'melindungiku': 'lindung',
    'melindungimu': 'lindung',
    'kelindungan': 'lindung',
    'pelindungannya': 'lindung',
    'melindungkan': 'lindung',
    'perlindungan': 'lindung',
    'perlindungannya': 'lindung',
    'perlindungani': 'lindung',
    'perlindunganan': 'lindung',
    'memperlindungi': 'lindung',
    'longgokan': 'longgok',
    'berlonggok': 'longgok',
    'terlonggok': 'longgok',
    'melonggokkan': 'longgok',
    'berlonggoklonggok': 'longgok',
    'berlorong': 'lorong',
    'melorongkan': 'lorong',
    'pelubang': 'lubang',
    'pelubangan': 'lubang',
    'melubangi': 'lubang',
    'melubanginya': 'lubang',
    'berlubang': 'lubang',
    'berlubangnya': 'lubang',
    'berlubangi': 'lubang',
    'berlubang-lubang': 'lubang',
    'meludah': 'ludah',
    'meludahlah': 'ludah',
    'meludahkan': 'ludah',
    'meludahkannya': 'ludah',
    'meludahi': 'ludah',
    'berludah': 'ludah',
    'meludahinya': 'ludah',
    'meludahiku': 'ludah',
    'peludahan': 'ludah',
    'berlumpur': 'lumpur',
    'berlumpuran': 'lumpur',
    'pelumpuran': 'lumpur',
    'lumuran': 'lumur',
    'melumur': 'lumur',
    'melumurkan': 'lumur',
    'melumurkannya': 'lumur',
    'melumuri': 'lumur',
    'berlumur': 'lumur',
    'berlumurkan': 'lumur',
    'berlumuran': 'lumur',
    'melumurinya': 'lumur',
    'berlumut': 'lumut',
    'berlumutan': 'lumut',
    'melutut': 'lutut',
    'berlutut': 'lutut',
    'berlututlah': 'lutut',
    'bermakna': 'makna',
    'bermaknanya': 'makna',
    'memaknakan': 'makna',
    'membermaknakan': 'makna',
    'dimaksud': 'maksud',
    'dimaksudnya': 'maksud',
    'dimaksudkan': 'maksud',
    'dimaksudkannya': 'maksud',
    'dimaksudan': 'maksud',
    'termaksud': 'maksud',
    'bermaksud': 'maksud',
    'bermaksudkan': 'maksud',
    'semalam': 'malam',
    'semalamnya': 'malam',
    'semalaman': 'malam',
    'memalami': 'malam',
    'bermalam': 'malam',
    'bermalamnya': 'malam',
    'bermalamlah': 'malam',
    'kemalaman': 'malam',
    'pemalaman': 'palam',
    'permalaman': 'malam',
    'memalamkan': 'malam',
    'malam-malam': 'malam',
    'malam-malamnya': 'malam',
    'malam-malamlah': 'malam',
    'malam-malamku': 'malam',
    'bermalam-malam': 'malam',
    'mempermalamkan': 'malam',
    'semalam-malaman': 'malam',
    'bermanfaat': 'manfaat',
    'bermanfaatnya': 'manfaat',
    'bermanfaatlah': 'manfaat',
    'bermanfaatkan': 'manfaat',
    'kemanfaatan': 'manfaat',
    'kemanfaatannya': 'manfaat',
    'pemanfaatan': 'manfaat',
    'pemanfaatannya': 'manfaat',
    'pemanfaatanan': 'manfaat',
    'memanfaatkan': 'manfaat',
    'memanfaatkannya': 'manfaat',
    'memanfaatkankan': 'manfaat',
    'memanfaatkanmu': 'manfaat',
    'bermastautin': 'mastautin',
    'semata': 'mata',
    'sematanya': 'mata',
    'sematai': 'mata',
    'bermata': 'mata',
    'bermatakan': 'mata',
    'semata-mata': 'semata',
    'termata-mata': 'mata',
    'pemenung': 'menung',
    'bermenung': 'menung',
    'termenung': 'menung',
    'kemenungan': 'menung',
    'memenungkan': 'menung',
    'bermenung-menung': 'menung',
    'termenung-menung': 'menung',
    'mimpian': 'mimpi',
    'pemimpi': 'mimpi',
    'pemimpinya': 'mimpi',
    'pemimpilah': 'mimpi',
    'pemimpian': 'mimpi',
    'bermimpi': 'mimpi',
    'bermimpinya': 'mimpi',
    'bermimpilah': 'mimpi',
    'bermimpikan': 'mimpi',
    'memimpikan': 'mimpi',
    'memimpikannya': 'mimpi',
    'termimpi-mimpi': 'mimpi',
    'peminat': 'minat',
    'peminatnya': 'minat',
    'peminatan': 'minat',
    'meminati': 'minat',
    'meminatinya': 'minat',
    'meminatiku': 'minat',
    'berminat': 'minat',
    'berminatnya': 'minat',
    'berminatkan': 'minat',
    'meminyaki': 'minyak',
    'meminyakinya': 'minyak',
    'berminyak': 'minyak',
    'perminyakan': 'minyak',
    'perminyakannya': 'minyak',
    'berminyak-minyak': 'minyak',
    'bermoral': 'moral',
    'bermoralnya': 'moral',
    'memotori': 'motor',
    'memotorinya': 'motor',
    'bermotor': 'motor',
    'bermotornya': 'motor',
    'pemuka': 'muka',
    'pemukanya': 'muka',
    'pemukaan': 'muka',
    'semuka': 'muka',
    'ke muka': 'muka',
    'di muka': 'muka',
    'bermuka': 'muka',
    'mengemuka': 'muka',
    'mengemukanya': 'muka',
    'mengemukakan': 'muka',
    'mengemukakannya': 'muka',
    'mengemukaan': 'muka',
    'bersemuka': 'muka',
    'terkemuka': 'muka',
    'terkemukanya': 'muka',
    'permukaan': 'muka',
    'permukaannya': 'muka',
    'pengemukaan': 'muka',
    'bermuka-muka': 'muka',
    'menyemukakan': 'muka',
    'muka-muka': 'muka',
    'bermukah': 'mukah',
    'bermuram': 'muram',
    'kemuraman': 'muram',
    'kemuramannya': 'muram',
    'memuramkan': 'muram',
    'bermusuh': 'musuh',
    'bermusuhkan': 'musuh',
    'bermusuhan': 'musuh',
    'memusuhi': 'musuh',
    'memusuhinya': 'musuh',
    'memusuhimu': 'musuh',
    'bermusuhannya': 'musuh',
    'permusuhan': 'musuh',
    'permusuhannya': 'musuh',
    'semutu': 'mutu',
    'bermutu': 'mutu',
    'bermutunya': 'mutu',
    'bermutulah': 'mutu',
    'bernafsu': 'nafsu',
    'bernafsunya': 'nafsu',
    'bernama': 'nama',
    'bernamanya': 'nama',
    'bernamakan': 'nama',
    'bernamai': 'nama',
    'menamai': 'nama',
    'menamainya': 'nama',
    'menamaiku': 'nama',
    'menamaimu': 'nama',
    'ternama': 'nama',
    'ternamanya': 'nama',
    'kenamaan': 'nama',
    'kenamaannya': 'nama',
    'penamaan': 'nama',
    'penamaannya': 'nama',
    'menamakan': 'nama',
    'menamakannya': 'nama',
    'menanah': 'nanah',
    'menanahan': 'nanah',
    'bernanah': 'nanah',
    'bernanahnya': 'nanah',
    'senasib': 'nasib',
    'senasibnya': 'nasib',
    'senasiblah': 'nasib',
    'bernasib': 'nasib',
    'nasib-nasiban': 'nasib',
    'penaung': 'naung',
    'penaungan': 'naung',
    'naungan': 'naung',
    'naungannya': 'naung',
    'bernaung': 'naung',
    'bernaungnya': 'naung',
    'menaungi': 'taung',
    'menaunginya': 'taung',
    'bernazar': 'nazar',
    'menazarkan': 'nazar',
    'berniat': 'niat',
    'berniatnya': 'niat',
    'berniatlah': 'niat',
    'berniatan': 'niat',
    'terniat': 'niat',
    'meniatkan': 'niat',
    'meniatkannya': 'niat',
    'berniat-niat': 'niat',
    'bernitrogen': 'nitrogen',
    'menyala': 'nyala',
    'menyalanya': 'nyala',
    'menyalakan': 'salak',
    'menyalakannya': 'nyala',
    'menyalai': 'salai',
    'bernyala': 'nyala',
    'menyala-nyala': 'nyala',
    'bernyala-nyala': 'nyala',
    'nyanyian': 'nyanyi',
    'nyanyiannya': 'nyanyi',
    'nyanyianku': 'nyanyi',
    'nyanyianmu': 'nyanyi',
    'menyanyi': 'nyanyi',
    'menyanyinya': 'nyanyi',
    'menyanyilah': 'nyanyi',
    'menyanyikan': 'nyanyi',
    'menyanyikannya': 'nyanyi',
    'menyanyian': 'nyanyi',
    'penyanyi': 'nyanyi',
    'penyanyinya': 'nyanyi',
    'penyanyikan': 'nyanyi',
    'penyanyian': 'nyanyi',
    'bernyanyi': 'nyanyi',
    'bernyanyinya': 'nyanyi',
    'bernyanyilah': 'nyanyi',
    'pemberokan': 'berok',
    'berolahraga': 'olahraga',
    'berolahraganya': 'olahraga',
    'berolahragalah': 'olahraga',
    'keolahragaan': 'olahraga',
    'keolahragaannya': 'olahraga',
    'mengolahragakan': 'olahraga',
    'memberolahragakan': 'olahraga',
    'olakan': 'olak',
    'berolak': 'olak',
    'mengolak': 'olak',
    'perolakan': 'olak',
    'memberon': 'beron',
    'berondongan': 'berondong',
    'memberondong': 'berondong',
    'memberondongnya': 'berondong',
    'memberondongkan': 'berondong',
    'memberondongkannya': 'berondong',
    'memberondongan': 'berondong',
    'pemberondongan': 'berondong',
    'memberongsang': 'berongsang',
    'memberongsong': 'berongsong',
    'pemberontak': 'berontak',
    'pemberontaknya': 'berontak',
    'pemberontaklah': 'berontak',
    'pemberontakkan': 'berontak',
    'pemberontakan': 'berontak',
    'memberontak': 'berontak',
    'pemberontakannya': 'berontak',
    'memberosot': 'berosot',
    'memadu': 'padu',
    'memadunya': 'padu',
    'memadukan': 'padu',
    'memadukannya': 'padu',
    'paduan': 'padu',
    'paduannya': 'padu',
    'pemadu': 'padu',
    'pemaduan': 'padu',
    'berpadu': 'padu',
    'berpadunya': 'padu',
    'berpadukan': 'padu',
    'berpaduan': 'padu',
    'terpadu': 'padu',
    'terpadunya': 'padu',
    'terpadukan': 'padu',
    'kepaduan': 'padu',
    'perpaduan': 'padu',
    'perpaduannya': 'padu',
    'keterpaduan': 'padu',
    'keterpaduanlah': 'padu',
    'berpadu-padu': 'padu',
    'memperpadukan': 'padu',
    'pemahat': 'pahat',
    'pemahatnya': 'pahat',
    'pemahatan': 'pahat',
    'pahatan': 'pahat',
    'pahatannya': 'pahat',
    'memahat': 'pahat',
    'memahatnya': 'pahat',
    'memahatkan': 'pahat',
    'berpahat': 'pahat',
    'berpahatkan': 'pahat',
    'berpakat': 'pakat',
    'memakati': 'pakat',
    'memalit': 'palit',
    'terpalit': 'palit',
    'berpalit': 'palit',
    'terpalit-palit': 'palit',
    'pemandang': 'pandang',
    'pemandangan': 'pandang',
    'memandang': 'pandang',
    'memandangnya': 'pandang',
    'memandanglah': 'pandang',
    'memandangi': 'pandang',
    'memandangan': 'pandang',
    'memandangku': 'pandang',
    'memandangmu': 'pandang',
    'pandangan': 'pandang',
    'pandangannya': 'pandang',
    'pandanganlah': 'pandang',
    'pandanganan': 'pandang',
    'pandanganku': 'pandang',
    'pandanganmu': 'pandang',
    'terpandang': 'pandang',
    'terpandanglah': 'pandang',
    'memandanginya': 'pandang',
    'memandangiku': 'pandang',
    'pemandangannya': 'pandang',
    'pemandanganku': 'pandang',
    'berpandangan': 'pandang',
    'berpandangannya': 'pandang',
    'berpandanganlah': 'pandang',
    'sepemandangan': 'pandang',
    'pandang-memandang': 'pandang',
    'terpandang-pandang': 'pandang',
    'berpandang-pandangan': 'pandang',
    'sepangkat': 'pangkat',
    'berpangkat': 'pangkat',
    'pemangkatan': 'pangkat',
    'kepangkatan': 'pangkat',
    'kepangkatannya': 'pangkat',
    'memangkatkan': 'pangkat',
    'berpangkat-pangkat': 'pangkat',
    'memapas': 'papas',
    'papasan': 'papas',
    'pemapasan': 'papas',
    'berpapasan': 'papas',
    'memarut': 'parut',
    'memarutnya': 'parut',
    'parutan': 'parut',
    'parutannya': 'parut',
    'pemarut': 'parut',
    'pemarutnya': 'parut',
    'berparut': 'parut',
    'pautan': 'paut',
    'memaut': 'paut',
    'memautkan': 'paut',
    'berpaut': 'paut',
    'berpautan': 'paut',
    'terpaut': 'paut',
    'terpautnya': 'paut',
    'perpautan': 'paut',
    'paut-memaut': 'paut',
    'berpautan': 'paut',
    'berpaya': 'paya',
    'berpeluh': 'peluh',
    'berpeluh-peluh': 'peluh',
    'pemeluk': 'peluk',
    'pemeluknya': 'peluk',
    'pemelukan': 'peluk',
    'memeluk': 'peluk',
    'memeluknya': 'peluk',
    'memeluki': 'peluk',
    'memelukan': 'peluk',
    'memelukku': 'peluk',
    'memelukmu': 'peluk',
    'pelukan': 'peluk',
    'pelukannya': 'peluk',
    'pelukanku': 'peluk',
    'pelukanmu': 'peluk',
    'berpeluk': 'peluk',
    'berpelukkan': 'peluk',
    'berpelukan': 'peluk',
    'terpeluk': 'peluk',
    'sepemeluk': 'peluk',
    'berpelukanlah': 'peluk',
    'sepemelukan': 'peluk',
    'berpeluk-pelukan': 'peluk',
    'berpengaruh': 'pengaruh',
    'berpengaruhnya': 'pengaruh',
    'berpengaruhlah': 'pengaruh',
    'berpengaruhkan': 'pengaruh',
    'berpengaruhi': 'pengaruh',
    'terpengaruh': 'pengaruh',
    'terpengaruhnya': 'pengaruh',
    'terpengaruhi': 'pengaruh',
    'memengaruhi': 'pengaruh',
    'memengaruhinya': 'pengaruh',
    'memengaruhii': 'pengaruh',
    'memengaruhiku': 'pengaruh',
    'memengaruhimu': 'pengaruh',
    'setahu': 'tahu',
    'setahunya': 'tahu',
    'setahui': 'tahu',
    'setahuan': 'tahu',
    'setahuku': 'tahu',
    'ketahuan': 'tahu',
    'ketahuannya': 'tahu',
    'ketahuanlah': 'tahu',
    'tahu-tahu': 'tahu',
    'tahu-tahunya': 'tahu',
    'bertahuan': 'tahu',
    'bertahukan': 'tahu',
    'mengetahui': 'tahu',
    'mengetahuinya': 'tahu',
    'mengetahuilah': 'tahu',
    'mengetahuii': 'tahu',
    'mengetahuiku': 'tahu',
    'mengetahuimu': 'tahu',
    'tahu-menahu': 'tahu',
    'pengetahuan': 'tahu',
    'pengetahuannya': 'tahu',
    'pengetahuanlah': 'tahu',
    'pengetahuanku': 'tahu',
    'pengetahuanmu': 'tahu',
    'bertahu-tahu': 'tahu',
    'berpengetahuan': 'tahu',
    'berpengetahuanlah': 'tahu',
    'berperangai': 'perangai',
    'berperikemanusiaan': 'perikemanusiaan',
    'berperikemanusiaannya': 'perikemanusiaan',
    'memesan': 'pesan',
    'memesannya': 'pesan',
    'memesankan': 'pesan',
    'memesankannya': 'pesan',
    'memesanan': 'pesan',
    'pesanan': 'pesan',
    'pesanannya': 'pesan',
    'pesananan': 'pesan',
    'pesananku': 'pesan',
    'pesananmu': 'pesan',
    'sipesan': 'pesan',
    'pemesan': 'pesan',
    'pemesannya': 'pesan',
    'pemesanan': 'pesan',
    'sepesan': 'pesan',
    'memesani': 'pesan',
    'berpesan': 'pesan',
    'pemesanannya': 'pesan',
    'pemesananan': 'pesan',
    'pesan-pesan': 'pesan',
    'pesan-pesannya': 'pesan',
    'pesan-pesanan': 'pesan',
    'berpesta': 'pesta',
    'berpestanya': 'pesta',
    'berpestalah': 'pesta',
    'memestakan': 'pesta',
    'berpesta-pesta': 'pesta',
    'berpidato': 'pidato',
    'berpidatonya': 'pidato',
    'memidatokan': 'pidato',
    'memijak': 'pijak',
    'memijakkan': 'pijak',
    'memijaki': 'pijak',
    'memijakan': 'pijak',
    'pemijak': 'pijak',
    'pijakan': 'pijak',
    'pijakannya': 'pijak',
    'berpijak': 'pijak',
    'berpijaknya': 'pijak',
    'berpijaklah': 'pijak',
    'pemijakan': 'pijak',
    'pijak-pijak': 'pijak',
    'terpijak-pijak': 'pijak',
    'memijar': 'pijar',
    'memijarkan': 'pijar',
    'berpijar': 'pijar',
    'berpijaran': 'pijar',
    'pijar-pijar': 'pijar',
    'memijar-mijar': 'pijar',
    'berpijar-pijar': 'pijar',
    'memikir': 'pikir',
    'memikirnya': 'pikir',
    'memikirkan': 'pikir',
    'memikirkannya': 'pikir',
    'memikiran': 'pikir',
    'pemikir': 'pikir',
    'pemikirnya': 'pikir',
    'pemikiran': 'pikir',
    'pikiran': 'pikir',
    'pikirannya': 'pikir',
    'pikiranlah': 'pikir',
    'pikirankan': 'pikir',
    'pikiranku': 'pikir',
    'pikiranmu': 'pikir',
    'berpikir': 'pikir',
    'berpikirnya': 'pikir',
    'berpikirlah': 'pikir',
    'berpikirkan': 'pikir',
    'berpikiri': 'pikir',
    'berpikiran': 'pikir',
    'berpikirku': 'pikir',
    'berpikirmu': 'pikir',
    'terpikir': 'pikir',
    'terpikirkan': 'pikir',
    'terpikirkannya': 'pikir',
    'terpikiran': 'pikir',
    'memikiri': 'pikir',
    'memikirikan': 'pikir',
    'memikirikannya': 'pikir',
    'pemikirannya': 'pikir',
    'pemikiranku': 'pikir',
    'pemikiranmu': 'pikir',
    'sepikiran': 'pikir',
    'memikirkankan': 'pikir',
    'memikirkanku': 'pikir',
    'memikirkanmu': 'pikir',
    'berpikirannya': 'pikir',
    'berpikiranlah': 'pikir',
    'memikir-mikir': 'pikir',
    'berpikir-pikir': 'pikir',
    'berpikir-pikiran': 'pikir',
    'memikir-mikirkan': 'pikir',
    'memindah': 'pindah',
    'memindahnya': 'pindah',
    'memindahkan': 'pindah',
    'memindahkannya': 'pindah',
    'memindahan': 'pindah',
    'pindahan': 'pindah',
    'pindahannya': 'pindah',
    'memindahi': 'pindah',
    'berpindah': 'pindah',
    'berpindahnya': 'pindah',
    'berpindahlah': 'pindah',
    'berpindahan': 'pindah',
    'pemindahan': 'pindah',
    'pemindahannya': 'pindah',
    'pemindahanan': 'pindah',
    'kepindahan': 'pindah',
    'kepindahannya': 'pindah',
    'kepindahanku': 'pindah',
    'memindahkanan': 'pindah',
    'perpindahan': 'pindah',
    'perpindahannya': 'pindah',
    'perpindahanku': 'pindah',
    'berpindah-pindah': 'pindah',
    'berpindah-pindahnya': 'pindah',
    'memintal': 'pintal',
    'memintalnya': 'pintal',
    'pemintal': 'pintal',
    'pemintalan': 'pintal',
    'terpintal': 'pintal',
    'berpintal': 'pintal',
    'berpintal-pintal': 'pintal',
    'pisahan': 'pisah',
    'memisah': 'pisah',
    'memisahnya': 'pisah',
    'memisahkan': 'pisah',
    'memisahkannya': 'pisah',
    'memisahan': 'pisah',
    'pemisah': 'pisah',
    'pemisahnya': 'pisah',
    'pemisahkan': 'pisah',
    'pemisahan': 'pisah',
    'terpisah': 'pisah',
    'terpisahnya': 'pisah',
    'terpisahkan': 'pisah',
    'terpisahkannya': 'pisah',
    'berpisah': 'pisah',
    'berpisahnya': 'pisah',
    'berpisahlah': 'pisah',
    'berpisahan': 'pisah',
    'pemisahannya': 'pisah',
    'perpisahan': 'pisah',
    'perpisahannya': 'pisah',
    'memisahkanlah': 'pisah',
    'memisahkankan': 'pisah',
    'memisahkanku': 'pisah',
    'berpisah-pisah': 'pisah',
    'memisah-misahkan': 'pisah',
    'memisah-misahkannya': 'pisah',
    'berpolitik': 'politik',
    'berpolitiknya': 'politik',
    'berpolitiklah': 'politik',
    'pemolitikan': 'politik',
    'memolitikkan': 'politik',
    'memperpolitikkan': 'politik',
    'berpotensi': 'potensi',
    'berpotensinya': 'potensi',
    'berprinsip': 'prinsip',
    'berprinsiplah': 'prinsip',
    'berprinsipkan': 'prinsip',
    'berpuasa': 'puasa',
    'berpuasanya': 'puasa',
    'berpuasalah': 'puasa',
    'pusingan': 'pusing',
    'pemusing': 'pusing',
    'memusing': 'pusing',
    'memusingkan': 'pusing',
    'memusingkannya': 'pusing',
    'berpusing': 'pusing',
    'berpusingnya': 'pusing',
    'berpusingan': 'pusing',
    'pemusingan': 'pusing',
    'perpusingan': 'pusing',
    'pusing-pusing': 'pusing',
    'pusing-pusingnya': 'pusing',
    'terpusing-pusing': 'pusing',
    'berpusing-pusing': 'pusing',
    'pemutar': 'putar',
    'pemutarnya': 'putar',
    'pemutaran': 'putar',
    'putaran': 'putar',
    'putarannya': 'putar',
    'seputar': 'putar',
    'seputarnya': 'putar',
    'seputaran': 'putar',
    'memutar': 'putar',
    'memutarnya': 'putar',
    'memutarkan': 'putar',
    'memutarkannya': 'putar',
    'memutari': 'putar',
    'memutaran': 'putar',
    'berputar': 'putar',
    'berputarnya': 'putar',
    'berputarlah': 'putar',
    'terputar': 'putar',
    'terputarnya': 'putar',
    'pemutarannya': 'putar',
    'pemutaranan': 'putar',
    'perputaran': 'putar',
    'perputarannya': 'putar',
    'putar-putar': 'putar',
    'putar-putaran': 'putar',
    'memutar-mutar': 'putar',
    'memutar-mutarkan': 'putar',
    'memperputarkan': 'putar',
    'berputar-putar': 'putar',
    'menyalam': 'salam',
    'menyalami': 'salam',
    'bersalam': 'salam',
    'bersalaman': 'salam',
    'menyalaminya': 'salam',
    'persalaman': 'salam',
    'bersalamannya': 'salam',
    'bersalamanlah': 'salam',
    'bersalamanan': 'salam',
    'bersalam-salaman': 'salam',
    'salinan': 'salin',
    'salinannya': 'salin',
    'pesalin': 'salin',
    'pesalinan': 'salin',
    'sesalin': 'salin',
    'persalin': 'salin',
    'persalinan': 'salin',
    'menyalin': 'salin',
    'menyalinnya': 'salin',
    'menyalinkan': 'salin',
    'menyalinan': 'salin',
    'bersalin': 'salin',
    'bersalinnya': 'salin',
    'bersalinan': 'salin',
    'penyalin': 'salin',
    'penyalinan': 'salin',
    'menyalini': 'salin',
    'penyalinanan': 'salin',
    'persalinannya': 'salin',
    'persalinanku': 'salin',
    'persalinanmu': 'salin',
    'mempersalin': 'salin',
    'mempersalini': 'salin',
    'bersalin-salin': 'salin',
    'mempersalinkan': 'salin',
    'sesama': 'sama',
    'sesamanya': 'sama',
    'sesamalah': 'sama',
    'sesamamu': 'sama',
    'bersama': 'sama',
    'bersamanya': 'sama',
    'bersamalah': 'sama',
    'bersamai': 'sama',
    'bersamaan': 'sama',
    'bersamaku': 'sama',
    'bersamamu': 'sama',
    'menyamai': 'sama',
    'menyamainya': 'sama',
    'menyamaikan': 'sama',
    'menyamaikannya': 'sama',
    'tersamai': 'sama',
    'kesamaan': 'sama',
    'kesamaannya': 'sama',
    'persamaan': 'sama',
    'persamaannya': 'sama',
    'persamaanlah': 'sama',
    'bersamaannya': 'sama',
    'sama-sama': 'sama',
    'sama-samalah': 'sama',
    'penyamaan': 'sama',
    'menyamakan': 'samak',
    'menyamakannya': 'sama',
    'kebersamaan': 'sama',
    'kebersamaannya': 'sama',
    'kebersamaanlah': 'sama',
    'kebersamaanku': 'sama',
    'kebersamaanmu': 'sama',
    'bersama-sama': 'sama',
    'bersama-samanya': 'sama',
    'bersama-samalah': 'sama',
    'bersama-samakan': 'sama',
    'bersama-samaan': 'sama',
    'bersama-samamu': 'sama',
    'membersamakan': 'sama',
    'mempersamakan': 'sama',
    'menyama-nyama': 'sama',
    'menyama-nyamakan': 'sama',
    'menyama-nyamakannya': 'sama',
    'menyama-nyamai': 'sama',
    'mempersama-samakan': 'sama',
    'sandaran': 'sandar',
    'sandarannya': 'sandar',
    'bersandar': 'sandar',
    'bersandarnya': 'sandar',
    'bersandarlah': 'sandar',
    'bersandarkan': 'sandar',
    'bersandaran': 'sandar',
    'tersandar': 'sandar',
    'menyandar': 'sandar',
    'menyandarkan': 'sandar',
    'menyandarkannya': 'sandar',
    'menyandari': 'sandar',
    'penyandar': 'sandar',
    'penyandaran': 'sandar',
    'pesandaran': 'sandar',
    'penyandarannya': 'sandar',
    'persandaran': 'sandar',
    'sandar-menyandar': 'sandar',
    'bersarang': 'sarang',
    'bersarangnya': 'sarang',
    'menyarangkan': 'sarang',
    'menyarangkannya': 'sarang',
    'bersarang-sarang': 'sarang',
    'menyarung': 'sarung',
    'menyarungkan': 'sarung',
    'menyarungi': 'sarung',
    'tersarung': 'sarung',
    'bersarung': 'sarung',
    'bersarungkan': 'sarung',
    'bersarungan': 'sarung',
    'kesatu': 'satu',
    'kesatuan': 'satu',
    'satuan': 'satu',
    'satuannya': 'satu',
    'satuanlah': 'satu',
    'satuanmu': 'satu',
    'bersatu': 'satu',
    'bersatunya': 'satu',
    'bersatulah': 'satu',
    'bersatukan': 'satu',
    'bersatuan': 'satu',
    'penyatu': 'satu',
    'penyatukan': 'satu',
    'penyatuan': 'satu',
    'menyatu': 'satu',
    'menyatunya': 'satu',
    'menyatulah': 'satu',
    'menyatukan': 'satu',
    'menyatukannya': 'satu',
    'menyatui': 'satu',
    'menyatuan': 'satu',
    'kesatuannya': 'satu',
    'kesatuanlah': 'satu',
    'kesatuanmu': 'satu',
    'persatuan': 'satu',
    'persatuannya': 'satu',
    'persatuanlah': 'satu',
    'persatuani': 'satu',
    'penyatuannya': 'satu',
    'satu-satu': 'satu',
    'satu-satunya': 'satu',
    'satu-satulah': 'satu',
    'satu-satuan': 'satu',
    'pemersatu': 'satu',
    'pemersatunya': 'satu',
    'pemersatuan': 'satu',
    'menyatukanlah': 'satu',
    'satu-satunyanya': 'satu',
    'mempersatukan': 'satu',
    'mempersatukannya': 'satu',
    'bersaudara': 'saudara',
    'bersaudaranya': 'saudara',
    'bersaudaralah': 'saudara',
    'bersaudaraan': 'saudara',
    'bersaudaraku': 'saudara',
    'persaudaraan': 'saudara',
    'persaudaraannya': 'saudara',
    'mempersaudarakan': 'saudara',
    'sediaan': 'sedia',
    'sediaannya': 'sedia',
    'sedianya': 'sedia',
    'tersedia': 'sedia',
    'tersedianya': 'sedia',
    'tersediakan': 'sedia',
    'tersediaan': 'sedia',
    'penyedia': 'sedia',
    'penyedianya': 'sedia',
    'penyediakan': 'sedia',
    'penyediaan': 'sedia',
    'bersedia': 'sedia',
    'bersedianya': 'sedia',
    'bersedialah': 'sedia',
    'bersediaan': 'sedia',
    'kesediaan': 'sedia',
    'kesediaannya': 'sedia',
    'penyediaannya': 'sedia',
    'persediaan': 'sedia',
    'persediaannya': 'sedia',
    'menyediakan': 'sedia',
    'menyediakannya': 'sedia',
    'ketersediaan': 'sedia',
    'ketersediaannya': 'sedia',
    'mempersediakan': 'sedia',
    'bersedia-sedia': 'sedia',
    'bersejarah': 'sejarah',
    'bersejarahnya': 'sejarah',
    'menyejarah': 'sejarah',
    'kesejarahan': 'sejarah',
    'kesejarahannya': 'sejarah',
    'kesejarahanan': 'sejarah',
    'menyejarahkan': 'sejarah',
    'sekolahan': 'sekolah',
    'sekolahannya': 'sekolah',
    'bersekolah': 'sekolah',
    'bersekolahnya': 'sekolah',
    'persekolahan': 'sekolah',
    'menyekolahkan': 'sekolah',
    'menyekolahkannya': 'sekolah',
    'menyekolahkanku': 'sekolah',
    'sekongkolan': 'sekongkol',
    'bersekongkol': 'sekongkol',
    'bersekongkolnya': 'sekongkol',
    'persekongkolan': 'sekongkol',
    'persekongkolannya': 'sekongkol',
    'peselancar': 'selancar',
    'peselancarnya': 'selancar',
    'peselancaran': 'selancar',
    'berselancar': 'selancar',
    'berselancarnya': 'selancar',
    'berselancarlah': 'selancar',
    'menyelaput': 'selaput',
    'berselaput': 'selaput',
    'berselera': 'selera',
    'berselerak': 'selerak',
    'berselindung': 'selindung',
    'berselirat': 'selirat',
    'berselisih': 'selisih',
    'berselisihlah': 'selisih',
    'berselisihkan': 'selisih',
    'berselisihan': 'selisih',
    'perselisihan': 'selisih',
    'perselisihannya': 'selisih',
    'menyelisihkan': 'selisih',
    'memperselisihkan': 'selisih',
    'memperselisihkannya': 'selisih',
    'berseloroh': 'seloroh',
    'berselumu': 'selumu',
    'bersemadi': 'semadi',
    'persemadian': 'semadi',
    'menyemarak': 'semarak',
    'menyemarakkan': 'semarak',
    'menyemarakkannya': 'semarak',
    'menyemaraki': 'semarak',
    'menyemarakan': 'semarak',
    'bersemarak': 'semarak',
    'kesemarakan': 'semarak',
    'kesemarakannya': 'semarak',
    'sembahyangan': 'sembahyang',
    'bersembahyang': 'sembahyang',
    'bersembahyangan': 'sembahyang',
    'menyembahyangi': 'sembahyang',
    'persembahyangan': 'sembahyang',
    'menyembahyangkan': 'sembahyang',
    'bersembunyi': 'sembunyi',
    'bersembunyinya': 'sembunyi',
    'bersembunyilah': 'sembunyi',
    'tersembunyi': 'sembunyi',
    'tersembunyinya': 'sembunyi',
    'tersembunyikan': 'sembunyi',
    'penyembunyian': 'sembunyi',
    'penyembunyiannya': 'sembunyi',
    'persembunyian': 'sembunyi',
    'persembunyiannya': 'sembunyi',
    'persembunyianku': 'sembunyi',
    'menyembunyikan': 'sembunyi',
    'menyembunyikannya': 'sembunyi',
    'sembunyi-sembunyi': 'sembunyi',
    'sembunyi-sembunyikan': 'sembunyi',
    'sembunyi-sembunyian': 'sembunyi',
    'bersembunyi-sembunyi': 'sembunyi',
    'bersembunyi-sembunyian': 'sembunyi',
    'senandungan': 'senandung',
    'bersenandung': 'senandung',
    'bersenandunglah': 'senandung',
    'bersenandungkan': 'senandung',
    'menyenandungkan': 'senandung',
    'menyendi': 'sendi',
    'bersendi': 'sendi',
    'bersendikan': 'sendi',
    'persendian': 'sendi',
    'persendiannya': 'sendi',
    'persendianku': 'sendi',
    'menyendikan': 'sendi',
    'bersendi-sendi': 'sendi',
    'mempersendikan': 'sendi',
    'menyendi-nyendi': 'sendi',
    'senggatan': 'senggat',
    'menyenggat': 'senggat',
    'bersenggat': 'senggat',
    'bersenggayut': 'senggayut',
    'bersenggayutan': 'senggayut',
    'bersengketa': 'sengketa',
    'bersengketanya': 'sengketa',
    'persengketaan': 'sengketa',
    'persengketaannya': 'sengketa',
    'mempersengketakan': 'sengketa',
    'mempersengketakannya': 'sengketa',
    'sentuhan': 'sentuh',
    'sentuhannya': 'sentuh',
    'sentuhanku': 'sentuh',
    'menyentuh': 'sentuh',
    'menyentuhnya': 'sentuh',
    'menyentuhlah': 'sentuh',
    'menyentuhkan': 'sentuh',
    'menyentuhkannya': 'sentuh',
    'menyentuhku': 'sentuh',
    'menyentuhmu': 'sentuh',
    'bersentuh': 'sentuh',
    'bersentuhkan': 'sentuh',
    'bersentuhan': 'sentuh',
    'tersentuh': 'sentuh',
    'tersentuhnya': 'sentuh',
    'tersentuhlah': 'sentuh',
    'penyentuh': 'sentuh',
    'penyentuhan': 'sentuh',
    'kesentuhan': 'sentuh',
    'persentuhan': 'sentuh',
    'persentuhannya': 'sentuh',
    'menyentuh-nyentuh': 'sentuh',
    'tersepai': 'sepai',
    'bersepai': 'sepai',
    'bersepaian': 'sepai',
    'bersepakat': 'sepakat',
    'bersepakatan': 'sepakat',
    'kesepakatan': 'sepakat',
    'kesepakatannya': 'sepakat',
    'kesepakatanlah': 'sepakat',
    'kesepakatani': 'sepakat',
    'kesepakatanan': 'sepakat',
    'menyepakati': 'sepakat',
    'menyepakatinya': 'sepakat',
    'menyepakatii': 'sepakat',
    'persepakatan': 'sepakat',
    'bersepatu': 'sepatu',
    'menyepatui': 'sepatu',
    'persepatuan': 'sepatu',
    'bersepeda': 'sepeda',
    'bersepedanya': 'sepeda',
    'bersepedalah': 'sepeda',
    'sesepuh': 'sepuh',
    'sesepuhnya': 'sepuh',
    'sepuhan': 'sepuh',
    'penyepuh': 'sepuh',
    'penyepuhan': 'sepuh',
    'menyepuh': 'sepuh',
    'menyepuhnya': 'sepuh',
    'menyepuhkan': 'sepuh',
    'tersepuh': 'sepuh',
    'bersepuh': 'sepuh',
    'kesepuhan': 'sepuh',
    'berserabut': 'serabut',
    'berserabutan': 'serabut',
    'berserat': 'serat',
    'terserat': 'serat',
    'menyeratkan': 'serat',
    'bersiang': 'siang',
    'menyiang': 'siang',
    'menyiangi': 'siang',
    'menyiangan': 'siang',
    'menyianginya': 'siang',
    'kesiangan': 'siang',
    'kesianganlah': 'siang',
    'penyiangan': 'siang',
    'siang-siang': 'siang',
    'siang-siangan': 'siang',
    'mempersiang': 'siang',
    'mempersiangi': 'siang',
    'bersidang': 'sidang',
    'bersidangnya': 'sidang',
    'bersidangan': 'sidang',
    'persidangan': 'sidang',
    'persidangannya': 'sidang',
    'persidanganlah': 'sidang',
    'persidanganan': 'sidang',
    'penyidangan': 'sidang',
    'penyidangannya': 'sidang',
    'menyidangkan': 'sidang',
    'menyidangkannya': 'sidang',
    'bersifat': 'sifat',
    'bersifatnya': 'sifat',
    'bersifatlah': 'sifat',
    'penyifatan': 'sifat',
    'menyifatkan': 'sifat',
    'tersifatkan': 'sifat',
    'pembersih': 'bersih',
    'pembersihnya': 'bersih',
    'pembersihkan': 'bersih',
    'pembersihan': 'bersih',
    'kebersihan': 'bersih',
    'kebersihannya': 'bersih',
    'kebersihanlah': 'bersih',
    'kebersihanan': 'bersih',
    'kebersihanku': 'bersih',
    'pembersihannya': 'bersih',
    'membersihkan': 'bersih',
    'membersihkannya': 'bersih',
    'membersihkanlah': 'bersih',
    'membersihkankan': 'bersih',
    'membersil': 'bersil',
    'silangan': 'silang',
    'bersilang': 'silang',
    'bersilangan': 'silang',
    'tersilang': 'silang',
    'menyilang': 'silang',
    'menyilangnya': 'silang',
    'menyilangkan': 'silang',
    'menyilangkannya': 'silang',
    'menyilangi': 'silang',
    'penyilangan': 'silang',
    'persilangan': 'silang',
    'persilangannya': 'silang',
    'mempersilangkan': 'silang',
    'silang-menyilang': 'silang',
    'bersimbol': 'simbol',
    'bersimbolkan': 'simbol',
    'menyimbolkan': 'simbol',
    'sinaran': 'sinar',
    'sinarannya': 'sinar',
    'bersinar': 'sinar',
    'bersinarnya': 'sinar',
    'bersinarlah': 'sinar',
    'bersinari': 'sinar',
    'menyinar': 'sinar',
    'menyinarkan': 'sinar',
    'menyinarkannya': 'sinar',
    'menyinari': 'sinar',
    'menyinarinya': 'sinar',
    'penyinaran': 'sinar',
    'penyinarannya': 'sinar',
    'sinar-seminar': 'sinar',
    'sinar-suminar': 'sinar',
    'sinar-menyinar': 'sinar',
    'bersirip': 'sirip',
    'menyirip': 'sirip',
    'tebersit': 'bersit',
    'tebersitlah': 'bersit',
    'bersitan': 'bersit',
    'membersit': 'bersit',
    'membersitkan': 'bersit',
    'bersiut': 'siut',
    'pesolek': 'solek',
    'bersolek': 'solek',
    'bersoleknya': 'solek',
    'mempersolek': 'solek',
    'solek-menyolek': 'solek',
    'penyorak': 'sorak',
    'bersorak': 'sorak',
    'menyoraki': 'sorak',
    'menyorakinya': 'sorak',
    'menyorakkan': 'sorak',
    'penyuci': 'suci',
    'penyucian': 'suci',
    'bersuci': 'suci',
    'kesucian': 'suci',
    'kesuciannya': 'suci',
    'persucian': 'suci',
    'menyucikan': 'suci',
    'menyumpah': 'sumpah',
    'menyumpahnya': 'sumpah',
    'menyumpahi': 'sumpah',
    'bersumpah': 'sumpah',
    'bersumpahlah': 'sumpah',
    'penyumpah': 'sumpah',
    'penyumpahan': 'sumpah',
    'menyumpahinya': 'sumpah',
    'menyumpahimu': 'sumpah',
    'persumpahan': 'sumpah',
    'mempersumpahkan': 'sumpah',
    'bersumpah-sumpahan': 'sumpah',
    'bersungut': 'sungut',
    'sungut-sungut': 'sungut',
    'bersungut-sungut': 'sungut',
    'menyurai': 'surai',
    'bersurai': 'surai',
    'suratan': 'surat',
    'suratannya': 'surat',
    'bersurat': 'surat',
    'tersurat': 'surat',
    'menyurat': 'surat',
    'menyuratnya': 'surat',
    'menyuratkan': 'surat',
    'menyurati': 'surat',
    'menyuratinya': 'surat',
    'persuratan': 'surat',
    'persuratannya': 'surat',
    'surat-menyurat': 'surat',
    'surat-menyuratnya': 'surat',
    'bersusah payah': 'susah payah',
    'membersut': 'bersut',
    'syarahan': 'syarah',
    'pensyarah': 'syarah',
    'bersyarah': 'syarah',
    'mensyarahkan': 'syarah',
    'bersyarat': 'syarat',
    'bersyaratnya': 'syarat',
    'bersyaratkan': 'syarat',
    'bersyaratan': 'syarat',
    'persyaratan': 'syarat',
    'persyaratannya': 'syarat',
    'mensyaratkan': 'syarat',
    'mensyaratkannya': 'syarat',
    'menabur': 'tabur',
    'menaburnya': 'tabur',
    'menaburkan': 'tabur',
    'menaburkannya': 'tabur',
    'menaburi': 'tabur',
    'penabur': 'tabur',
    'penaburan': 'tabur',
    'taburan': 'tabur',
    'taburannya': 'tabur',
    'tertabur': 'tabur',
    'bertabur': 'tabur',
    'bertaburnya': 'tabur',
    'bertaburkan': 'tabur',
    'bertaburan': 'tabur',
    'menaburinya': 'tabur',
    'bertaburannya': 'tabur',
    'bertabur-tabur': 'tabur',
    'tafakuran': 'tafakur',
    'bertafakur': 'tafakur',
    'menafakurkan': 'tafakur',
    'tahanan': 'tahan',
    'tahanannya': 'tahan',
    'tahananlah': 'tahan',
    'tahananan': 'tahan',
    'tahananku': 'tahan',
    'tahananmu': 'tahan',
    'penahan': 'tahan',
    'penahannya': 'tahan',
    'penahanan': 'tahan',
    'menahan': 'tahan',
    'menahannya': 'tahan',
    'menahankan': 'tahan',
    'menahankannya': 'tahan',
    'menahanan': 'tahan',
    'menahanku': 'tahan',
    'menahanmu': 'tahan',
    'menahani': 'tahan',
    'bertahan': 'tahan',
    'bertahannya': 'tahan',
    'bertahanlah': 'tahan',
    'bertahankan': 'tahan',
    'bertahani': 'tahan',
    'bertahanan': 'tahan',
    'tertahan': 'tahan',
    'tertahannya': 'tahan',
    'tertahankan': 'tahan',
    'tertahanan': 'tahan',
    'penahanannya': 'tahan',
    'penahananan': 'tahan',
    'penahananku': 'tahan',
    'ketahanan': 'tahan',
    'ketahanannya': 'tahan',
    'ketahananan': 'tahan',
    'pertahanan': 'tahan',
    'pertahanannya': 'tahan',
    'pertahananlah': 'tahan',
    'pertahanankan': 'tahan',
    'pertahananan': 'tahan',
    'pertahananku': 'tahan',
    'mempertahankan': 'tahan',
    'mempertahankannya': 'tahan',
    'mempertahankankan': 'tahan',
    'mempertahankanku': 'tahan',
    'bertahan-tahan': 'tahan',
    'tertahan-tahan': 'tahan',
    'bertakwa': 'takwa',
    'bertakwalah': 'takwa',
    'ketakwaan': 'takwa',
    'ketakwaannya': 'takwa',
    'bertanah': 'tanah',
    'pertanahan': 'tanah',
    'pertanahannya': 'tanah',
    'pertanahanan': 'tanah',
    'mengetanahkan': 'tanah',
    'menanduk': 'tanduk',
    'menanduknya': 'tanduk',
    'menandukkan': 'tanduk',
    'menandukkannya': 'tanduk',
    'menandukan': 'tanduk',
    'menandukku': 'tanduk',
    'tandukan': 'tanduk',
    'tandukannya': 'tanduk',
    'tandukanku': 'tanduk',
    'bertanduk': 'tanduk',
    'tanganan': 'tangan',
    'tanganannya': 'tangan',
    'menangani': 'tangan',
    'menanganinya': 'tangan',
    'menanganiku': 'tangan',
    'bertangan': 'tangan',
    'tertangani': 'tangan',
    'tertanganinya': 'tangan',
    'penanganan': 'tangan',
    'penanganannya': 'tangan',
    'penangananlah': 'tangan',
    'penangananan': 'tangan',
    'tangan-tangan': 'tangan',
    'tangan-tangannya': 'tangan',
    'tangan-tanganku': 'tangan',
    'tangan-tanganmu': 'tangan',
    'tangan-menangan': 'tangan',
    'tertanggal': 'tanggal',
    'menanggali': 'tanggal',
    'bertanggal': 'tanggal',
    'bertanggalkan': 'tanggal',
    'bertanggalan': 'tanggal',
    'penanggalan': 'tanggal',
    'penanggalannya': 'tanggal',
    'menanggalkan': 'tanggal',
    'menanggalkannya': 'tanggal',
    'menanggam': 'tanggam',
    'menanggami': 'tanggam',
    'bertanggam': 'tanggam',
    'bertangguh': 'tangguh',
    'tertangguh': 'tangguh',
    'tertangguhnya': 'tangguh',
    'tertangguhkan': 'tangguh',
    'ketangguhan': 'tangguh',
    'ketangguhannya': 'tangguh',
    'penangguhan': 'tangguh',
    'penangguhannya': 'tangguh',
    'penangguhanan': 'tangguh',
    'pertangguhan': 'tangguh',
    'menangguhkan': 'tangguh',
    'menangguhkannya': 'tangguh',
    'mempertangguhkan': 'tangguh',
    'menanya': 'tanya',
    'menanyanya': 'tanya',
    'menanyakan': 'tanya',
    'menanyakannya': 'tanya',
    'menanyai': 'tanya',
    'menanyaan': 'tanya',
    'penanya': 'tanya',
    'penanyanya': 'tanya',
    'bertanya': 'tanya',
    'bertanyanya': 'tanya',
    'bertanyalah': 'tanya',
    'bertanyaan': 'tanya',
    'menanyainya': 'tanya',
    'menanyaiku': 'tanya',
    'penanyaan': 'tanya',
    'pertanyaan': 'tanya',
    'pertanyaannya': 'tanya',
    'pertanyaanlah': 'tanya',
    'pertanyaanan': 'tanya',
    'pertanyaanku': 'tanya',
    'pertanyaanmu': 'tanya',
    'menanyakanan': 'tanya',
    'menanyakanku': 'tanya',
    'menanyakanmu': 'tanya',
    'mempertanyakan': 'tanya',
    'mempertanyakannya': 'tanya',
    'bertanya-tanya': 'tanya',
    'petapa': 'tapa',
    'petapaan': 'tapa',
    'pertapa': 'tapa',
    'pertapakan': 'tapa',
    'pertapaan': 'tapa',
    'bertapa': 'tapa',
    'bertapanya': 'tapa',
    'tapa-tapa': 'tapa',
    'pertapaannya': 'tapa',
    'mempertapakan': 'tapa',
    'menapak': 'tapak',
    'menapakkan': 'tapak',
    'menapaki': 'tapak',
    'menapakan': 'tapak',
    'setapak': 'tapak',
    'setapaknya': 'tapak',
    'bertapak': 'tapak',
    'menapakinya': 'tapak',
    'ketapakan': 'tapak',
    'bertapakkan': 'tapak',
    'tapak-tapak': 'tapak',
    'menaruh': 'taruh',
    'menaruhnya': 'taruh',
    'menaruhkan': 'taruh',
    'menaruhku': 'taruh',
    'petaruh': 'taruh',
    'petaruhnya': 'taruh',
    'petaruhan': 'taruh',
    'taruhan': 'taruh',
    'taruhannya': 'taruh',
    'bertaruh': 'taruh',
    'bertaruhlah': 'taruh',
    'bertaruhan': 'taruh',
    'menaruhi': 'taruh',
    'pertaruhan': 'taruh',
    'pertaruhannya': 'taruh',
    'pertaruhanlah': 'taruh',
    'berpetaruh': 'taruh',
    'berpenaruhan': 'taruh',
    'mempertaruhkan': 'taruh',
    'mempertaruhkannya': 'taruh',
    'penarung': 'tarung',
    'penarungan': 'tarung',
    'menarung': 'tarung',
    'menarungkan': 'tarung',
    'menarungi': 'tarung',
    'bertarung': 'tarung',
    'bertarungnya': 'tarung',
    'bertarunglah': 'tarung',
    'bertarungi': 'tarung',
    'bertarungan': 'tarung',
    'tertarung': 'tarung',
    'tertarungan': 'tarung',
    'pertarungan': 'tarung',
    'pertarungannya': 'tarung',
    'pertarunganku': 'tarung',
    'mempertarungkan': 'tarung',
    'mempertarungkannya': 'tarung',
    'menatah': 'tatah',
    'tatahan': 'tatah',
    'bertatah': 'tatah',
    'bertatahnya': 'tatah',
    'bertatahkan': 'tatah',
    'tatah-tatah': 'tatah',
    'tautan': 'taut',
    'tautannya': 'taut',
    'bertaut': 'taut',
    'bertautnya': 'taut',
    'bertautkan': 'taut',
    'bertautan': 'taut',
    'menautkan': 'taut',
    'menautkannya': 'taut',
    'pertautan': 'taut',
    'mempertautkan': 'taut',
    'bertekad': 'tekad',
    'bertekadlah': 'tekad',
    'menekuni': 'tekun',
    'menekuninya': 'tekun',
    'tertekun': 'tekun',
    'bertekun': 'tekun',
    'ketekunan': 'tekun',
    'ketekunannya': 'tekun',
    'ketekunanan': 'tekun',
    'menekunkan': 'tekun',
    'bertelanjang': 'telanjang',
    'bertelanjanglah': 'telanjang',
    'menelanjangi': 'telanjang',
    'menelanjanginya': 'telanjang',
    'penelanjangan': 'telanjang',
    'ketelanjangan': 'telanjang',
    'ketelanjangannya': 'telanjang',
    'menelanjangkan': 'telanjang',
    'petelur': 'telur',
    'petelurnya': 'telur',
    'menelur': 'telur',
    'menelurkan': 'telur',
    'menelurkannya': 'telur',
    'bertelur': 'telur',
    'bertelurnya': 'telur',
    'peneluran': 'telur',
    'perteluran': 'telur',
    'menelut': 'telut',
    'menelutkan': 'telut',
    'bertelut': 'telut',
    'peneman': 'teman',
    'menemani': 'teman',
    'menemaninya': 'teman',
    'menemaniku': 'teman',
    'menemanimu': 'teman',
    'berteman': 'teman',
    'bertemannya': 'teman',
    'bertemanlah': 'teman',
    'bertemankan': 'teman',
    'bertemanan': 'teman',
    'pertemanan': 'teman',
    'pertemanannya': 'teman',
    'pertemananlah': 'teman',
    'pertemananmu': 'teman',
    'menembung': 'tembung',
    'bertembung': 'tembung',
    'pertembungan': 'tembung',
    'menempel': 'tempel',
    'menempelnya': 'tempel',
    'menempelkan': 'tempel',
    'menempelkannya': 'tempel',
    'menempeli': 'tempel',
    'tempelan': 'tempel',
    'tempelannya': 'tempel',
    'penempel': 'tempel',
    'penempelkan': 'tempel',
    'penempelan': 'tempel',
    'menempelinya': 'tempel',
    'bertempel': 'tempel',
    'bertempelan': 'tempel',
    'penempelannya': 'tempel',
    'menempur': 'tempur',
    'tempuran': 'tempur',
    'penempur': 'tempur',
    'bertempur': 'tempur',
    'bertempurnya': 'tempur',
    'bertempurlah': 'tempur',
    'bertempuran': 'tempur',
    'pertempuran': 'tempur',
    'pertempurannya': 'tempur',
    'mempertempurkan': 'tempur',
    'temuan': 'temu',
    'temuannya': 'temu',
    'temuanlah': 'temu',
    'temuanku': 'temu',
    'menemu': 'temu',
    'menemunya': 'temu',
    'menemukan': 'temu',
    'menemukannya': 'temu',
    'menemui': 'temu',
    'menemuan': 'temu',
    'penemu': 'temu',
    'penemunya': 'temu',
    'penemukan': 'temu',
    'penemui': 'temu',
    'penemuan': 'temu',
    'menemuinya': 'temu',
    'menemuikan': 'temu',
    'menemuii': 'temu',
    'menemuiku': 'temu',
    'menemuimu': 'temu',
    'bertemu': 'temu',
    'bertemunya': 'temu',
    'bertemulah': 'temu',
    'bertemui': 'temu',
    'bertemuan': 'temu',
    'penemuannya': 'temu',
    'penemuanlah': 'temu',
    'pertemuan': 'temu',
    'pertemuannya': 'temu',
    'pertemuanan': 'temu',
    'pertemuanku': 'temu',
    'pertemuanmu': 'temu',
    'menemukanlah': 'temu',
    'menemukani': 'temu',
    'menemukanan': 'temu',
    'menemukanku': 'temu',
    'menemukanmu': 'temu',
    'tertemukan': 'temu',
    'mempertemukan': 'temu',
    'mempertemukannya': 'temu',
    'mempertemukanmu': 'temu',
    'menenagai': 'tenaga',
    'bertenaga': 'tenaga',
    'bertenaganya': 'tenaga',
    'bertenagakan': 'tenaga',
    'ketenagaan': 'tenaga',
    'penenggek': 'tenggek',
    'menenggek': 'tenggek',
    'tenggekan': 'tenggek',
    'bertenggek': 'tenggek',
    'tertenggek': 'tenggek',
    'menenggekkan': 'tenggek',
    'tenggeran': 'tengger',
    'bertengger': 'tengger',
    'bertenggernya': 'tengger',
    'bertenggerlah': 'tengger',
    'bertenggeri': 'tengger',
    'penengkar': 'tengkar',
    'menengkar': 'tengkar',
    'menengkari': 'tengkar',
    'bertengkar': 'tengkar',
    'bertengkarnya': 'tengkar',
    'bertengkaran': 'tengkar',
    'menengkarkan': 'tengkar',
    'pertengkaran': 'tengkar',
    'pertengkarannya': 'tengkar',
    'mempertengkarkan': 'tengkar',
    'tentangan': 'tentang',
    'tentangannya': 'tentang',
    'setentang': 'tentang',
    'penentang': 'tentang',
    'penentangnya': 'tentang',
    'penentangan': 'tentang',
    'menentang': 'tentang',
    'menentangnya': 'tentang',
    'menentangku': 'tentang',
    'menentangmu': 'tentang',
    'menentangi': 'tentang',
    'bertentang': 'tentang',
    'bertentangan': 'tentang',
    'tertentang': 'tentang',
    'tertentangan': 'tentang',
    'penentangannya': 'tentang',
    'penentanganan': 'tentang',
    'menentangkan': 'tentang',
    'bertentangannya': 'tentang',
    'bertentanganlah': 'tentang',
    'pertentangan': 'tentang',
    'pertentangannya': 'tentang',
    'mempertentangkan': 'tentang',
    'mempertentangkannya': 'tentang',
    'menepung': 'tepung',
    'bertepung': 'tepung',
    'teriakan': 'teriak',
    'teriakannya': 'teriak',
    'teriakanlah': 'teriak',
    'teriakanku': 'teriak',
    'teriakanmu': 'teriak',
    'meneriaki': 'teriak',
    'meneriakinya': 'teriak',
    'meneriakiku': 'teriak',
    'meneriakimu': 'teriak',
    'berteriak': 'teriak',
    'berteriaknya': 'teriak',
    'berteriaklah': 'teriak',
    'berteriakan': 'teriak',
    'meneriakkan': 'teriak',
    'meneriakkannya': 'teriak',
    'berteriak-teriak': 'teriak',
    'berterus terang': 'terus terang',
    'bertetangga': 'tetangga',
    'bertetanggaan': 'tetangga',
    'bertiang': 'tiang',
    'menikai': 'tikai',
    'tikaian': 'tikai',
    'bertikai': 'tikai',
    'bertikainya': 'tikai',
    'bertikaii': 'tikai',
    'bertikaian': 'tikai',
    'pertikaian': 'tikai',
    'pertikaiannya': 'tikai',
    'mempertikaikan': 'tikai',
    'menindak': 'tindak',
    'menindaknya': 'tindak',
    'menindakkan': 'tindak',
    'menindaki': 'tindak',
    'menindakan': 'tindak',
    'tindakan': 'tindak',
    'tindakannya': 'tindak',
    'tindakanlah': 'tindak',
    'tindakankannya': 'tindak',
    'tindakanan': 'tindak',
    'tindakanku': 'tindak',
    'tindakanmu': 'tindak',
    'tindakan-ku': 'tindak',
    'bertindak': 'tindak',
    'bertindaknya': 'tindak',
    'bertindaklah': 'tindak',
    'bertindakan': 'tindak',
    'penindakan': 'tindak',
    'penindakannya': 'tindak',
    'penindakanlah': 'tindak',
    'meningkah': 'tingkah',
    'meningkahi': 'tingkah',
    'peningkah': 'tingkah',
    'bertingkah': 'tingkah',
    'bertingkah-tingkah': 'tingkah',
    'setingkat': 'tingkat',
    'setingkatnya': 'tingkat',
    'tingkatan': 'tingkat',
    'tingkatannya': 'tingkat',
    'meningkat': 'tingkat',
    'meningkatnya': 'tingkat',
    'meningkatlah': 'tingkat',
    'meningkatkan': 'tingkat',
    'meningkatkannya': 'tingkat',
    'meningkatan': 'tingkat',
    'bertingkat': 'tingkat',
    'bertingkatnya': 'tingkat',
    'bertingkatlah': 'tingkat',
    'bertingkatkan': 'tingkat',
    'peningkatan': 'tingkat',
    'peningkatannya': 'tingkat',
    'peningkatanlah': 'tingkat',
    'peningkatankan': 'tingkat',
    'peningkatanan': 'tingkat',
    'meningkatkankan': 'tingkat',
    'meningkat-ningkat': 'tingkat',
    'bertingkat-tingkat': 'tingkat',
    'menokoh': 'tokoh',
    'menokohkan': 'tokoh',
    'penokoh': 'tokoh',
    'penokohan': 'tokoh',
    'menokohi': 'tokoh',
    'bertokoh': 'tokoh',
    'bertokohkan': 'tokoh',
    'penokohannya': 'tokoh',
    'ketokohan': 'tokoh',
    'ketokohannya': 'tokoh',
    'pertokohan': 'tokoh',
    'menolak': 'tolak',
    'menolaknya': 'tolak',
    'menolaklah': 'tolak',
    'menolakkan': 'tolak',
    'menolaki': 'tolak',
    'menolakan': 'tolak',
    'menolakku': 'tolak',
    'menolakmu': 'tolak',
    'tolakan': 'tolak',
    'tolakannya': 'tolak',
    'penolak': 'tolak',
    'penolaknya': 'tolak',
    'penolakkan': 'tolak',
    'penolakkannya': 'tolak',
    'penolakan': 'tolak',
    'tertolak': 'tolak',
    'tertolaknya': 'tolak',
    'bertolak': 'tolak',
    'bertolaknya': 'tolak',
    'bertolaklah': 'tolak',
    'penolakannya': 'tolak',
    'penolakanlah': 'tolak',
    'tolak-menolak': 'tolak',
    'bertolak-tolak': 'tolak',
    'bertolak-tolakan': 'tolak',
    'menoleransi': 'toleransi',
    'menoleransinya': 'toleransi',
    'bertoleransi': 'toleransi',
    'menopengi': 'topeng',
    'bertopeng': 'topeng',
    'bertopengnya': 'topeng',
    'bertopengkan': 'topeng',
    'mempertopeng': 'topeng',
    'menuahi': 'tuah',
    'bertuah': 'tuah',
    'bertuahnya': 'tuah',
    'ketuahan': 'tuah',
    'ketuahanan': 'tuah',
    'menuahkan': 'tuah',
    'bertuhan': 'tuhan',
    'ketuhanan': 'tuhan',
    'ketuhanannya': 'tuhan',
    'ketuhananan': 'tuhan',
    'menuhankan': 'tuhan',
    'mempertuhan': 'tuhan',
    'mempertuhankan': 'tuhan',
    'bertuhankan': 'tuhan',
    'menukangi': 'tukang',
    'menukanginya': 'tukang',
    'bertukang': 'tukang',
    'ketukangan': 'tukang',
    'pertukangan': 'tukang',
    'tukang-menukang': 'tukang',
    'menukar': 'tukar',
    'menukarnya': 'tukar',
    'menukarkan': 'tukar',
    'menukarkannya': 'tukar',
    'menukaran': 'tukar',
    'penukar': 'tukar',
    'penukarnya': 'tukar',
    'penukarkan': 'tukar',
    'penukaran': 'tukar',
    'bertukar': 'tukar',
    'bertukarnya': 'tukar',
    'bertukarlah': 'tukar',
    'bertukaran': 'tukar',
    'tertukar': 'tukar',
    'tertukarnya': 'tukar',
    'menukari': 'tukar',
    'penukarannya': 'tukar',
    'pertukaran': 'tukar',
    'pertukarannya': 'tukar',
    'tukar-menukar': 'tukar',
    'mempertukarkan': 'tukar',
    'mempertukarkannya': 'tukar',
    'bertukar-tukar': 'tukar',
    'bertukar-tukaran': 'tukar',
    'penulis': 'tulis',
    'penulisnya': 'tulis',
    'penulislah': 'tulis',
    'penulisan': 'tulis',
    'tulisan': 'tulis',
    'tulisannya': 'tulis',
    'tulisanlah': 'tulis',
    'tulisanku': 'tulis',
    'tulisanmu': 'tulis',
    'menulis': 'tulis',
    'menulisnya': 'tulis',
    'menulislah': 'tulis',
    'menuliskan': 'tulis',
    'menuliskannya': 'tulis',
    'menulisi': 'tulis',
    'menulisan': 'tulis',
    'menulismu': 'tulis',
    'bertulis': 'tulis',
    'bertuliskan': 'tulis',
    'bertulisan': 'tulis',
    'menulisinya': 'tulis',
    'menulisikan': 'tulis',
    'menulisiku': 'tulis',
    'tertulis': 'tulis',
    'tertulisnya': 'tulis',
    'tertulislah': 'tulis',
    'tertuliskan': 'tulis',
    'tertulisan': 'tulis',
    'penulisannya': 'tulis',
    'penulisanmu': 'tulis',
    'menuliskankan': 'tulis',
    'tulis-menulis': 'tulis',
    'menumbuk': 'tumbuk',
    'menumbuknya': 'tumbuk',
    'menumbukkan': 'tumbuk',
    'menumbukan': 'tumbuk',
    'penumbuk': 'tumbuk',
    'penumbukan': 'tumbuk',
    'tumbukan': 'tumbuk',
    'tumbukannya': 'tumbuk',
    'tertumbuk': 'tumbuk',
    'bertumbuk': 'tumbuk',
    'bertumbuknya': 'tumbuk',
    'bertumbukkan': 'tumbuk',
    'bertumbukan': 'tumbuk',
    'ketumbukan': 'tumbuk',
    'penumpu': 'tumpu',
    'penumpukan': 'tumpuk',
    'penumpukannya': 'tumpuk',
    'setumpu': 'tumpu',
    'setumpukan': 'tumpuk',
    'menumpu': 'tumpu',
    'menumpukan': 'tumpuk',
    'tumpuan': 'tumpu',
    'tumpuannya': 'tumpu',
    'bertumpu': 'tumpu',
    'bertumpunya': 'tumpu',
    'bertumpulah': 'tumpu',
    'bertumpukan': 'tumpu',
    'tertumpu': 'tumpu',
    'bersetumpu': 'tumpu',
    'menurap': 'turap',
    'menurapnya': 'turap',
    'berturap': 'turap',
    'tuturan': 'tutur',
    'tuturannya': 'tutur',
    'penutur': 'tutur',
    'penuturnya': 'tutur',
    'penuturkan': 'tutur',
    'penuturan': 'tutur',
    'bertutur': 'tutur',
    'bertuturnya': 'tutur',
    'bertuturkan': 'tutur',
    'tertutur': 'tutur',
    'petuturan': 'tutur',
    'penuturannya': 'tutur',
    'penuturanmu': 'tutur',
    'pertuturan': 'tutur',
    'menuturkan': 'tutur',
    'menuturkannya': 'tutur',
    'menuturkankan': 'tutur',
    'bertutur-tutur': 'tutur',
    'mempertuturkan': 'tutur',
    'beruang': 'uang',
    'beruangnya': 'uang',
    'beruanglah': 'uang',
    'beruangan': 'uang',
    'keuangan': 'uang',
    'keuangannya': 'uang',
    'keuanganlah': 'uang',
    'keuanganan': 'uang',
    'keuanganku': 'uang',
    'keuanganmu': 'uang',
    'menguangi': 'uang',
    'peruangan': 'uang',
    'penguangan': 'uang',
    'penguangannya': 'uang',
    'uang-uangan': 'uang',
    'menguangkan': 'uang',
    'menguangkannya': 'uang',
    'peubah': 'ubah',
    'peubahnya': 'ubah',
    'peubahan': 'ubah',
    'ubahan': 'ubah',
    'ubahannya': 'ubah',
    'terubah': 'ubah',
    'perubah': 'ubah',
    'perubahkan': 'ubah',
    'perubahan': 'ubah',
    'berubah': 'ubah',
    'berubahnya': 'ubah',
    'berubahlah': 'ubah',
    'berubahan': 'ubah',
    'pengubah': 'ubah',
    'pengubahnya': 'ubah',
    'pengubahan': 'ubah',
    'mengubah': 'ubah',
    'mengubahnya': 'ubah',
    'mengubahkan': 'ubah',
    'mengubahan': 'ubah',
    'mengubahku': 'ubah',
    'mengubahmu': 'ubah',
    'perubahannya': 'ubah',
    'perubahanlah': 'ubah',
    'perubahanan': 'ubah',
    'perubahanku': 'ubah',
    'pengubahannya': 'ubah',
    'berubah-ubah': 'ubah',
    'berubah-ubahnya': 'ubah',
    'memperubahkan': 'ubah',
    'ubanan': 'uban',
    'beruban': 'uban',
    'berubannya': 'uban',
    'menguban': 'uban',
    'mengubani': 'uban',
    'berudu': 'udu',
    'berudunya': 'udu',
    'ukiran': 'ukir',
    'ukirannya': 'ukir',
    'terukir': 'ukir',
    'terukirnya': 'ukir',
    'terukirlah': 'ukir',
    'terukirkan': 'ukir',
    'berukir': 'ukir',
    'berukirkan': 'ukir',
    'berukiran': 'ukir',
    'mengukir': 'ukir',
    'mengukirnya': 'ukir',
    'mengukirkan': 'ukir',
    'mengukirkannya': 'ukir',
    'pengukir': 'ukir',
    'pengukiran': 'ukir',
    'mengukiri': 'ukir',
    'pengukirannya': 'ukir',
    'ukir-ukiran': 'ukir',
    'ukir-mengukir': 'ukir',
    'seukur': 'ukur',
    'seukuran': 'ukur',
    'ukuran': 'ukur',
    'ukurannya': 'ukur',
    'ukuranlah': 'ukur',
    'ukuranku': 'ukur',
    'ukuranmu': 'ukur',
    'mengukur': 'ukur',
    'mengukurnya': 'ukur',
    'mengukurlah': 'ukur',
    'mengukurkan': 'ukur',
    'mengukurkannya': 'ukur',
    'pengukur': 'ukur',
    'pengukurnya': 'ukur',
    'pengukuran': 'ukur',
    'berukuran': 'ukur',
    'berukurannya': 'ukur',
    'pengukurannya': 'ukur',
    'ulangan': 'ulang',
    'ulangannya': 'ulang',
    'ulangani': 'ulang',
    'seulang': 'ulang',
    'berulang': 'ulang',
    'berulangnya': 'ulang',
    'berulanglah': 'ulang',
    'berulangkan': 'ulang',
    'terulang': 'ulang',
    'terulangnya': 'ulang',
    'terulangkan': 'ulang',
    'terulangi': 'ulang',
    'pengulang': 'ulang',
    'pengulangan': 'ulang',
    'mengulang': 'ulang',
    'mengulangnya': 'ulang',
    'mengulangi': 'ulang',
    'mengulanginya': 'ulang',
    'perulangan': 'ulang',
    'perulangannya': 'ulang',
    'pengulangannya': 'ulang',
    'ulang-ulang': 'ulang',
    'ulang-ulangi': 'ulang',
    'berulang-ulang': 'ulang',
    'berulang-ulangnya': 'ulang',
    'mengulang-ulang': 'ulang',
    'mengulang-ulangnya': 'ulang',
    'mengulang-ulangi': 'ulang',
    'berulat': 'ulat',
    'terberumbun': 'berumbun',
    'berumput': 'umput',
    'seumur': 'umur',
    'seumurnya': 'umur',
    'seumuran': 'umur',
    'seumurmu': 'umur',
    'berumur': 'umur',
    'berumurnya': 'umur',
    'berumuran': 'umur',
    'rundingan': 'runding',
    'rundingannya': 'runding',
    'berunding': 'runding',
    'berundingnya': 'runding',
    'berundinglah': 'runding',
    'berundingan': 'runding',
    'merunding': 'runding',
    'merundingkan': 'runding',
    'merundingkannya': 'runding',
    'merundingan': 'runding',
    'perunding': 'berunding',
    'perundingnya': 'berunding',
    'perundingkan': 'berunding',
    'perundingan': 'berunding',
    'perundingannya': 'berunding',
    'perundinganlah': 'berunding',
    'perundinganan': 'berunding',
    'memperundingkan': 'runding',
    'rungutan': 'rungut',
    'merungut': 'rungut',
    'berungut': 'rungut',
    'berungutan': 'rungut',
    'merungutkan': 'rungut',
    'merungut-rungut': 'rungut',
    'berunsur': 'unsur',
    'berunsurkan': 'unsur',
    'beruntung': 'untung',
    'beruntungnya': 'untung',
    'beruntunglah': 'untung',
    'beruntungan': 'untung',
    'keuntungan': 'untung',
    'keuntungannya': 'untung',
    'keuntunganlah': 'untung',
    'keuntunganku': 'untung',
    'peruntungan': 'untung',
    'peruntungannya': 'untung',
    'peruntunganlah': 'untung',
    'peruntunganku': 'untung',
    'peruntunganmu': 'untung',
    'untung-untung': 'untung',
    'untung-untungan': 'untung',
    'menguntungkan': 'untung',
    'menguntungkannya': 'untung',
    'menguntungkanlah': 'untung',
    'menguntungkankan': 'untung',
    'menguntungkanku': 'untung',
    'menguntungkanmu': 'untung',
    'keberuntungan': 'untung',
    'keberuntungannya': 'untung',
    'keberuntunganlah': 'untung',
    'keberuntunganku': 'untung',
    'keberuntunganmu': 'untung',
    'beruntung-untung': 'untung',
    'seberuntung-beruntungnya': 'untung',
    'beruntusan': 'beruntus',
    'perupa': 'rupa',
    'perupakan': 'rupa',
    'perupaan': 'rupa',
    'serupa': 'rupa',
    'serupanya': 'rupa',
    'serupalah': 'rupa',
    'berupa': 'rupa',
    'berupanya': 'rupa',
    'berupakan': 'rupa',
    'berupai': 'rupa',
    'terupa': 'rupa',
    'terupakan': 'rupa',
    'merupa': 'rupa',
    'merupakan': 'rupa',
    'merupai': 'rupa',
    'merupaan': 'rupa',
    'rupanya': 'rupa',
    'rupanyanya': 'rupa',
    'merupakani': 'rupa',
    'merupakanan': 'rupa',
    'berserupa': 'rupa',
    'rupa-rupa': 'rupa',
    'rupa-rupanya': 'rupa',
    'menyerupa': 'rupa',
    'menyerupakan': 'rupa',
    'menyerupai': 'rupa',
    'keserupaan': 'rupa',
    'menyerupainya': 'rupa',
    'menyerupaian': 'rupa',
    'berupa-rupa': 'rupa',
    'perserupaan': 'rupa',
    'urutan': 'urut',
    'urutannya': 'urut',
    'berurut': 'urut',
    'berurutlah': 'urut',
    'berurutan': 'urut',
    'mengurut': 'urut',
    'mengurutnya': 'urut',
    'mengurutkan': 'urut',
    'mengurutkannya': 'urut',
    'menguruti': 'urut',
    'pengurutan': 'urut',
    'memperurutkan': 'urut',
    'berurut-urutan': 'urut',
    'memberus': 'berus',
    'berusaha': 'usaha',
    'berusahanya': 'usaha',
    'berusahalah': 'usaha',
    'berusahakan': 'usaha',
    'berusahaan': 'usaha',
    'pengusaha': 'usaha',
    'pengusahanya': 'usaha',
    'pengusahalah': 'usaha',
    'pengusahaan': 'usaha',
    'perusahaan': 'usaha',
    'perusahaannya': 'usaha',
    'perusahaanlah': 'usaha',
    'perusahaankan': 'usaha',
    'perusahaanku': 'usaha',
    'perusahaanmu': 'usaha',
    'pengusahaannya': 'usaha',
    'mengusahakan': 'usaha',
    'mengusahakannya': 'usaha',
    'kepengusahaan': 'usaha',
    'berusia': 'usia',
    'berusianya': 'usia',
    'berusiai': 'usia',
    'sewarna': 'warna',
    'pewarna': 'warna',
    'pewarnanya': 'warna',
    'pewarnaan': 'warna',
    'mewarnai': 'warna',
    'mewarnainya': 'warna',
    'berwarna': 'warna',
    'berwarnanya': 'warna',
    'berwarnakan': 'warna',
    'berwarnai': 'warna',
    'pewarnaannya': 'warna',
    'mewarnakan': 'warna',
    'berwarna-warna': 'warna',
    'berwarna-warnai': 'warna',
    'berwasiat': 'wasiat',
    'mewasiatkan': 'wasiat',
    'berwibawa': 'wibawa',
    'berwibawanya': 'wibawa',
    'kewibawaan': 'wibawa',
    'kewibawaannya': 'wibawa',
    'peziarah': 'ziarah',
    'peziarahnya': 'ziarah',
    'peziarahan': 'ziarah',
    'penziarah': 'ziarah',
    'penziarahnya': 'ziarah',
    'penziarahan': 'ziarah',
    'berziarah': 'ziarah',
    'berziarahlah': 'ziarah',
    'menziarahi': 'ziarah',
    'menziarahinya': 'ziarah',
    'menziarahiku': 'ziarah',
    'berzina': 'zina',
    'menzinai': 'zina',
    'perzinaan': 'zina',
    'perzinaannya': 'zina',
    'berbesan': 'besan',
    'berbesanan': 'besan',
    'berbesar hati': 'besar hati',
    'kebesar-hatian': 'besar hati',
    'terbesar': 'besar',
    'terbesarnya': 'besar',
    'terbesarlah': 'besar',
    'terbesarkan': 'besar',
    'terbesari': 'besar',
    'terbesarku': 'besar',
    'terbesarmu': 'besar',
    'pembesar': 'besar',
    'pembesarnya': 'besar',
    'pembesaran': 'besar',
    'membesar': 'besar',
    'membesarnya': 'besar',
    'membesarkan': 'besar',
    'membesarkannya': 'besar',
    'membesaran': 'besar',
    'kebesaran': 'besar',
    'kebesarannya': 'besar',
    'kebesaranmu': 'besar',
    'kebesaran-mu': 'besar',
    'pembesarannya': 'besar',
    'membesarkanku': 'besar',
    'membesarkanmu': 'besar',
    'memperbesar': 'besar',
    'memperbesarnya': 'besar',
    'memperbesarkan': 'besar',
    'besar-besaran': 'besar',
    'besar-besarannya': 'besar',
    'besar-besaranlah': 'besar',
    'besar-besaranan': 'besar',
    'membesar-besar': 'besar',
    'membesar-besarnya': 'besar',
    'membesar-besarkan': 'besar',
    'membesar-besarkannya': 'besar',
    'membesar-besaran': 'besar',
    'berbesar-besar': 'besar',
    'beselan': 'besel',
    'membeset': 'beset',
    'membesi': 'besi',
    'membesi tua': 'besi tua',
    'membesituakan': 'besi tua',
    'terbesit': 'besit',
    'terbesitlah': 'besit',
    'membesit': 'besit',
    'membesitkan': 'besit',
    'beslahan': 'beslah',
    'membeslah': 'beslah',
    'pembeslahan': 'beslah',
    'bestelan': 'bestel',
    'membestel': 'bestel',
    'pembestralan': 'bestral',
    'membesut': 'besut',
    'membesutnya': 'besut',
    'membesutkan': 'besut',
    'berbeta': 'beta',
    'membetahkan': 'betah',
    'membetas': 'betas',
    'penernak': 'ternak',
    'peternak': 'ternak',
    'peternaknya': 'ternak',
    'peternakkan': 'ternak',
    'peternakan': 'ternak',
    'beternak': 'ternak',
    'beternaknya': 'ternak',
    'peternakannya': 'ternak',
    'menernakkan': 'ternak',
    'menernakkannya': 'ternak',
    'terbeti': 'beti',
    'terbetik': 'betik',
    'terbetiknya': 'betik',
    'betik-betik': 'betik',
    'membeting': 'beting',
    'berbeting': 'beting',
    'terbeting': 'beting',
    'membeton': 'beton',
    'membetonnya': 'beton',
    'membetoni': 'beton',
    'membetot': 'betot',
    'betulan': 'betul',
    'betulannya': 'betul',
    'berbetul': 'betul',
    'kebetulan': 'betul',
    'kebetulannya': 'betul',
    'kebetulankan': 'betul',
    'membetuli': 'betul',
    'sebetulnya': 'betul',
    'berbetulan': 'betul',
    'pembetulan': 'betul',
    'pembetulannya': 'betul',
    'membetulkan': 'betul',
    'membetulkannya': 'betul',
    'betul-betul': 'betul',
    'berkebetulan': 'betul',
    'kebiadaban': 'biadab',
    'kebiadabannya': 'biadab',
    'membiadabi': 'biadab',
    'biakan': 'biak',
    'biakannya': 'biak',
    'membiak': 'biak',
    'membiaknya': 'biak',
    'membiakkan': 'biak',
    'membiakkannya': 'biak',
    'membiakan': 'biak',
    'berbiak': 'biak',
    'berbiaknya': 'biak',
    'membiaki': 'biak',
    'pembiakan': 'biak',
    'pembiakannya': 'biak',
    'biang biut': 'biang',
    'biang-biang': 'biang',
    'memperbiar': 'biar',
    'membiarkan': 'biar',
    'membiarkannya': 'biar',
    'membiarkankan': 'biar',
    'membiarkanku': 'biar',
    'membiarkanmu': 'biar',
    'membias': 'bias',
    'membiaskan': 'bias',
    'pembiasan': 'bias',
    'pembiasannya': 'bias',
    'biasanya': 'biasa',
    'biasanyanya': 'biasa',
    'biasanyalah': 'biasa',
    'biasanyakan': 'biasa',
    'terbiasa': 'biasa',
    'terbiasanya': 'biasa',
    'terbiasalah': 'biasa',
    'terbiasai': 'biasa',
    'kebiasaan': 'biasa',
    'kebiasaannya': 'biasa',
    'kebiasaanku': 'biasa',
    'kebiasaanmu': 'biasa',
    'membiasakan': 'biasa',
    'membiasakannya': 'biasa',
    'membiasakanmu': 'biasa',
    'berbiau': 'biau',
    'membiawak': 'biawak',
    'membiayai': 'biaya',
    'membiayainya': 'biaya',
    'pembiayaan': 'biaya',
    'pembiayaannya': 'biaya',
    'membiayakan': 'biaya',
    'pembibit': 'bibit',
    'pembibitan': 'bibit',
    'membibit': 'bibit',
    'membibitkan': 'bibit',
    'pembibitannya': 'bibit',
    'membicu': 'bicu',
    'bicu-bicu': 'bicu',
    'membidai': 'bidai',
    'berbidai-bidai': 'bidai',
    'berbidan': 'bidan',
    'kebidanan': 'bidan',
    'kebidananan': 'bidan',
    'membidani': 'bidan',
    'bidangan': 'bidang',
    'pembidang': 'bidang',
    'pembidangan': 'bidang',
    'membidangi': 'bidang',
    'membidanginya': 'bidang',
    'pembidangannya': 'bidang',
    'membidangkan': 'bidang',
    'bidasan': 'bidas',
    'pembidas': 'bidas',
    'membidas': 'bidas',
    'bidikan': 'bidik',
    'bidikannya': 'bidik',
    'membidik': 'bidik',
    'membidiknya': 'bidik',
    'membidiklah': 'bidik',
    'membidikkan': 'bidik',
    'membidiki': 'bidik',
    'membidikan': 'bidik',
    'membidikku': 'bidik',
    'pembidik': 'bidik',
    'pembidiknya': 'bidik',
    'pembidikan': 'bidik',
    'berbiduk': 'biduk',
    'berbiduk-biduk': 'biduk',
    'kebijakan': 'bijak',
    'kebijakannya': 'bijak',
    'kebijakanlah': 'bijak',
    'kebijakankan': 'bijak',
    'kebijakanan': 'bijak',
    'kebijakanku': 'bijak',
    'kebijakanmu': 'bijak',
    'kebijaksanaan': 'bijaksana',
    'kebijaksanaannya': 'bijaksana',
    'kebijaksanaanlah': 'bijaksana',
    'berbiji': 'biji',
    'membiji': 'biji',
    'biji-bijian': 'biji',
    'biji-bijiannya': 'biji',
    'pembikangan': 'bikang',
    'bikinan': 'bikin',
    'bikinannya': 'bikin',
    'terbikin': 'bikin',
    'membikin': 'bikin',
    'membikinnya': 'bikin',
    'membikinkan': 'bikin',
    'pembikinan': 'bikin',
    'membikin-bikin': 'bikin',
    'berbiku-biku': 'biku',
    'bila-bila': 'bila',
    'membilah-bilah': 'bilah',
    'membilai': 'bilai',
    'pembilas': 'bilas',
    'pembilasan': 'bilas',
    'membilas': 'bilas',
    'membilasnya': 'bilas',
    'berbilas': 'bilas',
    'berbilik-bilik': 'bilik',
    'kebimbangan': 'bimbang',
    'kebimbangannya': 'bimbang',
    'membimbangkan': 'bimbang',
    'bimbingan': 'bimbing',
    'bimbingannya': 'bimbing',
    'pembimbing': 'bimbing',
    'pembimbingnya': 'bimbing',
    'pembimbingan': 'bimbing',
    'pembimbingku': 'bimbing',
    'pembimbingmu': 'bimbing',
    'membimbing': 'bimbing',
    'membimbingnya': 'bimbing',
    'membimbinglah': 'bimbing',
    'membimbingku': 'bimbing',
    'membimbingmu': 'bimbing',
    'berbimbing': 'bimbing',
    'berbimbingan': 'bimbing',
    'bimbitan': 'bimbit',
    'membimbit': 'bimbit',
    'membina': 'bina',
    'membinanya': 'bina',
    'membinakan': 'bina',
    'membinaan': 'bina',
    'pembina': 'bina',
    'pembinanya': 'bina',
    'pembinaan': 'bina',
    'pembinamu': 'bina',
    'pembinaannya': 'bina',
    'pembinaanlah': 'bina',
    'berbinar-binar': 'binar',
    'kebinasaan': 'binasa',
    'kebinasaannya': 'binasa',
    'pembinasaan': 'binasa',
    'membinasakan': 'binasa',
    'membinasakannya': 'binasa',
    'kebinatangan': 'binatang',
    'kebinatangannya': 'binatang',
    'berbincang': 'bincang',
    'berbincangnya': 'bincang',
    'berbincanglah': 'bincang',
    'berbincangan': 'bincang',
    'perbincangan': 'bincang',
    'perbincangannya': 'bincang',
    'perbincanganan': 'bincang',
    'membincangkan': 'bincang',
    'membincangkannya': 'bincang',
    'berbincang-bincang': 'bincang',
    'berbincang-bincanglah': 'bincang',
    'membindu': 'bindu',
    'kebinekaan': 'bineka',
    'kebinekaannya': 'bineka',
    'membingas': 'bingas',
    'bingkahan': 'bingkah',
    'membingkah': 'bingkah',
    'membingkahi': 'bingkah',
    'bingkah-bingkah': 'bingkah',
    'berbingkah-bingkah': 'bingkah',
    'membingkas': 'bingkas',
    'bingkisan': 'bingkis',
    'bingkisannya': 'bingkis',
    'membingkis': 'bingkis',
    'membingkisnya': 'bingkis',
    'kebingungan': 'bingung',
    'kebingungannya': 'bingung',
    'membingungkan': 'bingung',
    'membingungkannya': 'bingung',
    'membinjat': 'binjat',
    'berbintil-bintil': 'bintil',
    'berbiola': 'biola',
    'perbioskopan': 'bioskop',
    'kebirahan': 'birah',
    'berbiras': 'biras',
    'terbirit': 'birit',
    'terbirit-birit': 'birit',
    'pembirokrasian': 'birokrasi',
    'membiru': 'biru',
    'membirunya': 'biru',
    'membirukan': 'biru',
    'kebiru-biruan': 'biru',
    'kebiru-biruanan': 'biru',
    'mengebiskan': 'bis',
    'kebisingan': 'bising',
    'kebisingannya': 'bising',
    'membisingkan': 'bising',
    'pebisnis': 'bisnis',
    'pebisnisnya': 'bisnis',
    'pebisnislah': 'bisnis',
    'berbisnis': 'bisnis',
    'berbisnisnya': 'bisnis',
    'berbisnislah': 'bisnis',
    'berbisniskan': 'bisnis',
    'membisu': 'bisu',
    'membisunya': 'bisu',
    'membisukan': 'bisu',
    'berbisu': 'bisu',
    'membisul': 'bisul',
    'berbisul': 'bisul',
    'biti-biti': 'biti',
    'terbius': 'bius',
    'membius': 'bius',
    'membiusnya': 'bius',
    'membiuskan': 'bius',
    'pembius': 'bius',
    'pembiusnya': 'bius',
    'pembiusan': 'bius',
    'pembiusannya': 'bius',
    'blasteran': 'blaster',
    'blasterannya': 'blaster',
    'memblaster': 'blaster',
    'berblirik': 'blirik',
    'memblokade': 'blokade',
    'memblokadenya': 'blokade',
    'pemblokadean': 'blokade',
    'memblokir': 'blokir',
    'memblokirnya': 'blokir',
    'memblokiran': 'blokir',
    'memblokirmu': 'blokir',
    'membobok': 'bobok',
    'memboboknya': 'bobok',
    'membobol': 'bobol',
    'membobolnya': 'bobol',
    'membobolkan': 'bobol',
    'pembobol': 'bobol',
    'pembobolnya': 'bobol',
    'pembobolan': 'bobol',
    'kebobolan': 'bobol',
    'kebobolannya': 'bobol',
    'pembobolannya': 'bobol',
    'membobos': 'bobos',
    'berbobot': 'bobot',
    'berbobotlah': 'bobot',
    'kebobrokan': 'bobrok',
    'kebobrokannya': 'bobrok',
    'kebocahan': 'bocah',
    'bocoran': 'bocor',
    'bocorannya': 'bocor',
    'kebocoran': 'bocor',
    'kebocorannya': 'bocor',
    'kebocoranlah': 'bocor',
    'pembocoran': 'bocor',
    'pembocorannya': 'bocor',
    'membocorkan': 'bocor',
    'membocorkannya': 'bocor',
    'kebodohan': 'bodoh',
    'kebodohannya': 'bodoh',
    'kebodohanku': 'bodoh',
    'kebodohanmu': 'bodoh',
    'pembodohan': 'bodoh',
    'pembodohanlah': 'bodoh',
    'membodohkan': 'bodoh',
    'memperbodoh': 'bodoh',
    'bodoran': 'bodor',
    'membodor': 'bodor',
    'berboga': 'boga',
    'memboikot': 'boikot',
    'memboikotnya': 'boikot',
    'pemboikot': 'boikot',
    'pemboikotkan': 'boikot',
    'pemboikotan': 'boikot',
    'pemboikotannya': 'boikot',
    'pembokong': 'bokong',
    'membokong': 'bokong',
    'pembokongan': 'bokong',
    'membola': 'bola',
    'berbolak-balik': 'bolak-balik',
    'membolak-balikkan': 'bolak-balik',
    'membolak-balikkannya': 'bolak-balik',
    'bolehan': 'boleh',
    'kebolehan': 'boleh',
    'kebolehannya': 'boleh',
    'membolehkan': 'boleh',
    'membolehkannya': 'boleh',
    'membolehkanku': 'boleh',
    'membolehkanmu': 'boleh',
    'memperbolehkan': 'boleh',
    'memperbolehkannya': 'boleh',
    'memperbolehkanku': 'boleh',
    'seboleh-bolehnya': 'boleh',
    'peboling': 'boling',
    'berbolong-bolong': 'bolong',
    'membolos': 'bolos',
    'membolosnya': 'bolos',
    'membolot': 'bolot',
    'pengebom': 'bom',
    'pengebomnya': 'bom',
    'pengeboman': 'bom',
    'mengebom': 'bom',
    'mengebomnya': 'bom',
    'mengebomi': 'bom',
    'mengeboman': 'bom',
    'pengebomannya': 'bom',
    'pengebomanan': 'bom',
    'membombardir': 'bombardir',
    'membombardirnya': 'bombardir',
    'mengebon': 'bon',
    'boncengan': 'bonceng',
    'boncengannya': 'bonceng',
    'pembonceng': 'bonceng',
    'pemboncengnya': 'bonceng',
    'pemboncengan': 'bonceng',
    'membonceng': 'bonceng',
    'memboncengnya': 'bonceng',
    'memboncengkan': 'bonceng',
    'memboncengkannya': 'bonceng',
    'memboncengi': 'bonceng',
    'memboncengan': 'bonceng',
    'berboncengan': 'bonceng',
    'berbondong-bondong': 'bondong',
    'berbondong-bondongnya': 'bondong',
    'berbondong-bondonglah': 'bondong',
    'membondot': 'bondot',
    'membonekakan': 'boneka',
    'memperboneka': 'boneka',
    'memperbonekakan': 'boneka',
    'membongak': 'bongak',
    'membonggol': 'bonggol',
    'membonggoli': 'bonggol',
    'berbongkah': 'bongkah',
    'membongkahi': 'bongkah',
    'berbongkah-bongkah': 'bongkah',
    'bongkaran': 'bongkar',
    'bongkarannya': 'bongkar',
    'terbongkar': 'bongkar',
    'terbongkarnya': 'bongkar',
    'terbongkarlah': 'bongkar',
    'terbongkarkan': 'bongkar',
    'membongkar': 'bongkar',
    'membongkarnya': 'bongkar',
    'membongkaran': 'bongkar',
    'kebongkaran': 'bongkar',
    'pembongkaran': 'bongkar',
    'pembongkarannya': 'bongkar',
    'membongkar-bongkar': 'bongkar',
    'bongkar-membongkar': 'bongkar',
    'membongkar-bangkir': 'bongkar-bangkir',
    'membongmeh': 'bongmeh',
    'membonsai': 'bonsai',
    'membonsainya': 'bonsai',
    'membonsaikan': 'bonsai',
    'pembonsaian': 'bonsai',
    'membopong': 'bopong',
    'membopongnya': 'bopong',
    'pengebor': 'bor',
    'pengebornya': 'bor',
    'pengeboran': 'bor',
    'mengebor': 'bor',
    'mengebornya': 'bor',
    'mengeboran': 'bor',
    'pengeborannya': 'bor',
    'bordiran': 'bordir',
    'bordirannya': 'bordir',
    'membordir': 'bordir',
    'membordirkan': 'bordir',
    'memborgol': 'borgol',
    'memborgolnya': 'borgol',
    'memborgolkan': 'borgol',
    'memborgolku': 'borgol',
    'pemborgolan': 'borgol',
    'borokan': 'borok',
    'berborok': 'borok',
    'memborok': 'borok',
    'memborokan': 'borok',
    'borongan': 'borong',
    'borongannya': 'borong',
    'memborong': 'borong',
    'memborongnya': 'borong',
    'memborongkan': 'borong',
    'pemborong': 'borong',
    'pemborongnya': 'borong',
    'pemborongan': 'borong',
    'pemboros': 'boros',
    'pemborosan': 'boros',
    'keborosan': 'boros',
    'pemborosannya': 'boros',
    'memboroskan': 'boros',
    'memboroskannya': 'boros',
    'pembosan': 'bosan',
    'kebosanan': 'bosan',
    'kebosanannya': 'bosan',
    'kebosananku': 'bosan',
    'membosankan': 'bosan',
    'membosankannya': 'bosan',
    'membotak': 'botak',
    'membotakkan': 'botak',
    'membotaki': 'botak',
    'membotakinya': 'botak',
    'kebotakan': 'botak',
    'kebotakannya': 'botak',
    'pembotolan': 'botol',
    'pembotolannya': 'botol',
    'memboya': 'boya',
    'keboyakan': 'boyak',
    'boyongan': 'boyong',
    'boyongannya': 'boyong',
    'berboyong': 'boyong',
    'memboyong': 'boyong',
    'memboyongnya': 'boyong',
    'memboyongkan': 'boyong',
    'memboyongan': 'boyong',
    'memboyongku': 'boyong',
    'pemboyongan': 'boyong',
    'pembriketan': 'briket',
    'kebrutalan': 'brutal',
    'kebrutalannya': 'brutal',
    'kebrutalanmu': 'brutal',
    'berbuah': 'buah',
    'berbuahnya': 'buah',
    'berbuahlah': 'buah',
    'berbuahkan': 'buah',
    'bebuahan': 'buah',
    'membuahi': 'buah',
    'membuahinya': 'buah',
    'perbuahan': 'buah',
    'pembuahan': 'buah',
    'pembuahannya': 'buah',
    'membuahkan': 'buah',
    'membuahkannya': 'buah',
    'buah-buahan': 'buah',
    'buah-buahannya': 'buah',
    'buaian': 'buai',
    'buaiannya': 'buai',
    'terbuai': 'buai',
    'terbuailah': 'buai',
    'membuai': 'buai',
    'membuainya': 'buai',
    'membuaiku': 'buai',
    'membuaimu': 'buai',
    'berbuai': 'buai',
    'berbuai-buai': 'buai',
    'terbuai-buai': 'buai',
    'membuak': 'buak',
    'membuakan': 'buak',
    'membuana': 'buana',
    'buangan': 'buang',
    'buangannya': 'buang',
    'terbuang': 'buang',
    'terbuangnya': 'buang',
    'terbuanglah': 'buang',
    'membuang': 'buang',
    'membuangnya': 'buang',
    'membuangkan': 'buang',
    'membuangan': 'buang',
    'membuangmu': 'buang',
    'pembuangan': 'buang',
    'pembuangannya': 'buang',
    'terbuang-buang': 'buang',
    'membuang-buang': 'buang',
    'membuang-buangnya': 'buang',
    'buang-buang air': 'buang',
    'membuas': 'buas',
    'membuaskan': 'buas',
    'kebuasan': 'buas',
    'kebuasannya': 'buas',
    'membuaya': 'buaya',
    'membuayai': 'buaya',
    'pembubaran': 'bubar',
    'pembubarannya': 'bubar',
    'membubarkan': 'bubar',
    'membubarkannya': 'bubar',
    'membubu': 'bubu',
    'membubukan': 'bubuk',
    'membubui': 'bubu',
    'bubuhan': 'bubuh',
    'membubuh': 'bubuh',
    'membubuhkan': 'bubuh',
    'membubuhkannya': 'bubuh',
    'membubuhi': 'bubuh',
    'membubuhan': 'bubuh',
    'membubuhinya': 'bubuh',
    'pembubuhan': 'bubuh',
    'bubukan': 'bubuk',
    'membubuk': 'bubuk',
    'pembubukan': 'bubuk',
    'membubul': 'bubul',
    'bubun-bubun': 'bubun',
    'bubungan': 'bubung',
    'membubung': 'bubung',
    'membubungnya': 'bubung',
    'membubungkan': 'bubung',
    'memperbubungkan': 'bubung',
    'membubur': 'bubur',
    'membubus': 'bubus',
    'bubutan': 'bubut',
    'membubut': 'bubut',
    'membubuti': 'bubut',
    'pembubut': 'bubut',
    'pembubutan': 'bubut',
    'membudak': 'budak',
    'membudaknya': 'budak',
    'perbudakan': 'budak',
    'perbudakannya': 'budak',
    'pembudakan': 'budak',
    'membudakkan': 'budak',
    'memperbudak': 'budak',
    'memperbudaknya': 'budak',
    'memperbudakan': 'budak',
    'berbudak-budak': 'budak',
    'kebudak-budakan': 'budak',
    'berbudaya': 'budaya',
    'berbudayalah': 'budaya',
    'membudaya': 'budaya',
    'membudayanya': 'budaya',
    'membudayakan': 'budaya',
    'membudayakannya': 'budaya',
    'kebudayaan': 'budaya',
    'kebudayaannya': 'budaya',
    'kebudayaanan': 'budaya',
    'pembudayaan': 'budaya',
    'pembudidaya': 'budi daya',
    'pembudidayanya': 'budi daya',
    'pembudidayaan': 'budi daya',
    'pembudidayaannya': 'budi daya',
    'membudidayakan': 'budi daya',
    'membudidayakannya': 'budi daya',
    'terbudur': 'budur',
    'kebugaran': 'bugar',
    'kebugarannya': 'bugar',
    'kebugaranku': 'bugar',
    'pembugaran': 'bugar',
    'membugarkan': 'bugar',
    'berbugil': 'bugil',
    'membugil': 'bugil',
    'buhulan': 'buhul',
    'membuhul': 'buhul',
    'bujangan': 'bujang',
    'bujangannya': 'bujang',
    'membujang': 'bujang',
    'membujangnya': 'bujang',
    'kebujangan': 'bujang',
    'pembujangan': 'bujang',
    'perbujangan': 'bujang',
    'kebujanggaan': 'bujangga',
    'bujukan': 'bujuk',
    'bujukannya': 'bujuk',
    'pembujuk': 'bujuk',
    'pembujukan': 'bujuk',
    'membujuk': 'bujuk',
    'membujuknya': 'bujuk',
    'membujukkan': 'bujuk',
    'membujukku': 'bujuk',
    'membujukmu': 'bujuk',
    'membujuki': 'bujuk',
    'membujur': 'bujur',
    'membujurnya': 'bujur',
    'terbujur': 'bujur',
    'dibujurkan': 'bujur',
    'membujurkan': 'bujur',
    'mengebuk': 'buk',
    'pembuka': 'buka',
    'pembukanya': 'buka',
    'pembukaan': 'buka',
    'terbuka': 'buka',
    'terbukanya': 'buka',
    'terbukalah': 'buka',
    'terbukai': 'buka',
    'terbukaan': 'buka',
    'terbukamu': 'buka',
    'berbuka': 'buka',
    'berbukanya': 'buka',
    'berbukalah': 'buka',
    'berbukaan': 'buka',
    'membuka': 'buka',
    'membukanya': 'buka',
    'membukakan': 'buka',
    'membukakannya': 'buka',
    'membukaan': 'buka',
    'membukai': 'buka',
    'pembukaannya': 'buka',
    'pembukaanku': 'buka',
    'pembukaanmu': 'buka',
    'keterbukaan': 'buka',
    'keterbukaannya': 'buka',
    'keterbukaanlah': 'buka',
    'sebukan': 'bukan',
    'bukankah': 'bukan',
    'bukantah': 'bukan',
    'berbukan': 'bukan',
    'bukan-bukan': 'bukan',
    'membukankan': 'bukan',
    'terbuku': 'buku',
    'terbukukan': 'buku',
    'membuku': 'buku',
    'membukukan': 'buku',
    'membukukannya': 'buku',
    'membukuan': 'buku',
    'berbuku': 'buku',
    'pembukuan': 'buku',
    'pembukuannya': 'buku',
    'perbukuan': 'buku',
    'membukut': 'bukut',
    'pembukut': 'bukut',
    'bulakan': 'bulak',
    'membulang': 'bulang',
    'terbulang': 'bulang',
    'berbulang': 'bulang',
    'pembulang': 'bulang',
    'bulang-bulang': 'bulang',
    'bulatan': 'bulat',
    'bulatannya': 'bulat',
    'membulat': 'bulat',
    'membulatnya': 'bulat',
    'membulatkan': 'bulat',
    'membulatkannya': 'bulat',
    'membulati': 'bulat',
    'kebulatan': 'bulat',
    'kebulatannya': 'bulat',
    'pembulatan': 'bulat',
    'pembulatannya': 'bulat',
    'memperbulat': 'bulat',
    'membuldoser': 'buldoser',
    'pembuldoseran': 'buldoser',
    'pebulu tangkis': 'bulu tangkis',
    'perbulutangkisan': 'bulu tangkis',
    'pembuluh': 'buluh',
    'pembuluhnya': 'buluh',
    'pembuluhan': 'buluh',
    'berpembuluh': 'buluh',
    'buluh-buluh': 'buluh',
    'bulukan': 'buluk',
    'kebuluran': 'bulur',
    'berbumbu': 'bumbu',
    'membumbui': 'bumbu',
    'membumbuinya': 'bumbu',
    'membumbun': 'bumbun',
    'membumihanguskan': 'bumi hangus',
    'membumihanguskannya': 'bumi hangus',
    'membumi': 'bumi',
    'membuminya': 'bumi',
    'membumilah': 'bumi',
    'membumikan': 'bumi',
    'membumikannya': 'bumi',
    'mengebumikan': 'bumi',
    'mengebumikannya': 'bumi',
    'membumiratakan': 'bumi rata',
    'membuncah': 'buncah',
    'membuncahnya': 'buncah',
    'membuncahkan': 'buncah',
    'terbuncang': 'buncang',
    'buncitan': 'buncit',
    'membuncit': 'buncit',
    'membuncitnya': 'buncit',
    'membuncitkan': 'buncit',
    'membundak': 'bundak',
    'bundaran': 'bundar',
    'membundar': 'bundar',
    'membundarkan': 'bundar',
    'bundelan': 'bundel',
    'membundel': 'bundel',
    'membundelnya': 'bundel',
    'bungaran': 'bungar',
    'bungkalan': 'bungkal',
    'membungkam': 'bungkam',
    'membungkamnya': 'bungkam',
    'membungkamkan': 'bungkam',
    'membungkamkannya': 'bungkam',
    'membungkaman': 'bungkam',
    'membungkamku': 'bungkam',
    'pembungkam': 'bungkam',
    'pembungkamnya': 'bungkam',
    'pembungkaman': 'bungkam',
    'membungkuk': 'bungkuk',
    'membungkuknya': 'bungkuk',
    'membungkuklah': 'bungkuk',
    'membungkukkan': 'bungkuk',
    'membungkukan': 'bungkuk',
    'membungkuk-bungkuk': 'bungkuk',
    'membungkuk-bungkuklah': 'bungkuk',
    'terbungkuk-bungkuk': 'bungkuk',
    'membungkus': 'bungkus',
    'membungkusnya': 'bungkus',
    'membungkuskan': 'bungkus',
    'membungkusi': 'bungkus',
    'pembungkus': 'bungkus',
    'pembungkusnya': 'bungkus',
    'pembungkusan': 'bungkus',
    'terbuni': 'buni',
    'membunikan': 'buni',
    'berbuntang': 'buntang',
    'terbuntang': 'buntang',
    'membuntang': 'buntang',
    'membuntangkan': 'buntang',
    'buntilan': 'buntil',
    'buntingan': 'bunting',
    'membunting': 'bunting',
    'membuntingkan': 'bunting',
    'kebuntingan': 'bunting',
    'membuntingi': 'bunting',
    'kebuntuan': 'buntu',
    'kebuntuannya': 'buntu',
    'membuntukan': 'buntu',
    'kebuntungan': 'buntung',
    'membuntungkan': 'buntung',
    'berbuntut': 'buntut',
    'pembuntut': 'buntut',
    'pembuntutan': 'buntut',
    'membuntut': 'buntut',
    'membuntuti': 'buntut',
    'membuntutinya': 'buntut',
    'membuntutiku': 'buntut',
    'berbuntut-buntut': 'buntut',
    'membunuh': 'bunuh',
    'membunuhnya': 'bunuh',
    'membunuhkan': 'bunuh',
    'membunuhi': 'bunuh',
    'membunuhan': 'bunuh',
    'membunuhku': 'bunuh',
    'membunuhmu': 'bunuh',
    'pembunuh': 'bunuh',
    'pembunuhnya': 'bunuh',
    'pembunuhan': 'bunuh',
    'pembunuhku': 'bunuh',
    'pembunuhannya': 'bunuh',
    'pembunuhani': 'bunuh',
    'pembunuhanan': 'bunuh',
    'pembunuhanku': 'bunuh',
    'bersibunuh': 'bunuh',
    'bunuh-membunuh': 'bunuh',
    'berbunuh-bunuhan': 'bunuh',
    'membura': 'bura',
    'memburai': 'burai',
    'memburakan': 'bura',
    'terburai': 'burai',
    'berburai': 'burai',
    'memburaikan': 'burai',
    'pemburas': 'buras',
    'memburas': 'buras',
    'memburaskan': 'buras',
    'buritan': 'burit',
    'buritannya': 'burit',
    'memburit': 'burit',
    'buronan': 'buron',
    'buronannya': 'buron',
    'buronanan': 'buron',
    'buruhan': 'buruh',
    'memburuh': 'buruh',
    'memburuhkan': 'buruh',
    'perburuhan': 'buruh',
    'perburuhannya': 'buruh',
    'burukan': 'buruk',
    'memburuk': 'buruk',
    'memburuknya': 'buruk',
    'memburukkan': 'buruk',
    'perburuk': 'buruk',
    'perburukan': 'buruk',
    'berburuk': 'buruk',
    'keburukanku': 'buruk',
    'berburuk-buruk': 'buruk',
    'memburuk-burukkan': 'buruk',
    'burung-burungan': 'burung',
    'berbusana': 'busana',
    'berbusananya': 'busana',
    'berbusanalah': 'busana',
    'berbusanaku': 'busana',
    'membusuk': 'busuk',
    'membusuknya': 'busuk',
    'membusukkan': 'busuk',
    'membusukkannya': 'busuk',
    'membusuki': 'busuk',
    'membusukan': 'busuk',
    'pembusuk': 'busuk',
    'pembusukkan': 'busuk',
    'pembusukan': 'busuk',
    'kebusukan': 'busuk',
    'kebusukannya': 'busuk',
    'pembusukannya': 'busuk',
    'membusung': 'busung',
    'membusungkan': 'busung',
    'terbusung': 'busung',
    'dibusur': 'busur',
    'dibusurkan': 'busur',
    'membusur': 'busur',
    'busur-busur': 'busur',
    'membusut': 'busut',
    'membuta': 'buta',
    'membutanya': 'buta',
    'membutakan': 'buta',
    'membutakannya': 'buta',
    'kebutaan': 'buta',
    'kebutaannya': 'buta',
    'membutakanku': 'buta',
    'kebutuhan': 'butuh',
    'kebutuhannya': 'butuh',
    'kebutuhanlah': 'butuh',
    'kebutuhanan': 'butuh',
    'kebutuhanku': 'butuh',
    'kebutuhanmu': 'butuh',
    'membutuhi': 'butuh',
    'membutuhkan': 'butuh',
    'membutuhkannya': 'butuh',
    'membutuhkanlah': 'butuh',
    'membutuhkanku': 'butuh',
    'membutuhkanmu': 'butuh',
    'membutuhkan-mu': 'butuh',
    'butulan': 'butul',
    'membuyarkan': 'buyar',
    'membuyarkannya': 'buyar',
    'membuyur': 'buyur',
    'kecabaian': 'cabai',
    'kecabaran': 'cabar',
    'mencabarkan': 'cabar',
    'mencabau': 'cabau',
    'cabikan': 'cabik',
    'tercabik': 'cabik',
    'tercabiknya': 'cabik',
    'mencabik': 'cabik',
    'mencabiknya': 'cabik',
    'pencabikan': 'cabik',
    'mencabikkan': 'cabik',
    'cabik-cabik': 'cabik',
    'mencabik-cabik': 'cabik',
    'cabik-mencabik': 'cabik',
    'mencabik-cabikkan': 'cabik',
    'bercabiran': 'cabir',
    'cobar-cabir': 'cabir',
    'kecabuhan': 'cabuh',
    'mencabul': 'cabul',
    'mencabuli': 'cabul',
    'bercabul': 'cabul',
    'kecabulan': 'cabul',
    'kecabulannya': 'cabul',
    'mencabulinya': 'cabul',
    'pencabulan': 'cabul',
    'pencabulannya': 'cabul',
    'percabulan': 'cabul',
    'kecaburan': 'cabur',
    'cabutan': 'cabut',
    'cabutannya': 'cabut',
    'tercabut': 'cabut',
    'tercabutnya': 'cabut',
    'mencabut': 'cabut',
    'mencabutnya': 'cabut',
    'mencabutlah': 'cabut',
    'mencabutkan': 'cabut',
    'mencabutkannya': 'cabut',
    'mencabuti': 'cabut',
    'mencabutan': 'cabut',
    'bercabut': 'cabut',
    'pencabut': 'cabut',
    'pencabutnya': 'cabut',
    'pencabutan': 'cabut',
    'pencabutannya': 'cabut',
    'pencacah jiwa': 'cacah jiwa',
    'mencacah jiwa': 'cacah jiwa',
    'bercacah jiwa': 'cacah jiwa',
    'pencacahjiwaan': 'cacah jiwa',
    'pencacak': 'cacak',
    'mencacak': 'cacak',
    'tercacak': 'cacak',
    'mencacakkan': 'cacak',
    'mencacap': 'cacap',
    'mencacapi': 'cacap',
    'bercacar': 'cacar',
    'pencacar': 'cacar',
    'mencacar': 'cacar',
    'pencacaran': 'cacar',
    'cacatan': 'cacat',
    'cacatannya': 'cacat',
    'bercacat': 'cacat',
    'pencacat': 'cacat',
    'pencacatan': 'cacat',
    'tercacat': 'cacat',
    'tercacatkan': 'cacat',
    'mencacat': 'cacat',
    'mencacatkan': 'cacat',
    'mencacatkannya': 'cacat',
    'mencacati': 'cacat',
    'kecacatan': 'cacat',
    'kecacatannya': 'cacat',
    'pencacatannya': 'cacat',
    'mencacau': 'cacau',
    'pencacau': 'cacau',
    'cacian': 'caci',
    'caciannya': 'caci',
    'cacianlah': 'caci',
    'pencaci': 'caci',
    'pencacinya': 'caci',
    'mencaci': 'caci',
    'mencacinya': 'caci',
    'mencaciku': 'caci',
    'bercaci-cacian': 'caci',
    'mencaci maki': 'caci maki',
    'cacingan': 'cacing',
    'mencadai': 'cadai',
    'cadangan': 'cadang',
    'cadangannya': 'cadang',
    'cadanganlah': 'cadang',
    'cadangankan': 'cadang',
    'cadanganku': 'cadang',
    'pencadang': 'cadang',
    'pencadangan': 'cadang',
    'bercadang': 'cadang',
    'bercadangan': 'cadang',
    'pencadangannya': 'cadang',
    'pencadanganan': 'cadang',
    'mencadangkan': 'cadang',
    'mencadangkannya': 'cadang',
    'mencadangkanku': 'cadang',
    'bercadar': 'cadar',
    'bercadik': 'cadik',
    'mencaduk': 'caduk',
    'bercadung': 'cadung',
    'mencadung': 'cadung',
    'tercagak': 'cagak',
    'mencagak': 'cagak',
    'bercagak': 'cagak',
    'cagaran': 'cagar',
    'pencagaran': 'cagar',
    'mencagarkan': 'cagar',
    'mencagil': 'cagil',
    'mencagun': 'cagun',
    'mencagut': 'cagut',
    'pencahar': 'cahar',
    'pencaharnya': 'cahar',
    'mencahar': 'cahar',
    'mencahari': 'cahar',
    'pencaharian': 'cahari',
    'pencahariannya': 'cahari',
    'pencaharianku': 'cahari',
    'bercahaya': 'cahaya',
    'bercahayanya': 'cahaya',
    'bercahayakan': 'cahaya',
    'mencahayai': 'cahaya',
    'pencahayaan': 'cahaya',
    'pencahayaannya': 'cahaya',
    'mencahayakan': 'cahaya',
    'caing-caing': 'caing',
    'mencaing-caing': 'caing',
    'cairan': 'cair',
    'cairannya': 'cair',
    'cairanlah': 'cair',
    'mencair': 'cair',
    'mencairnya': 'cair',
    'mencairlah': 'cair',
    'mencairkan': 'cair',
    'mencairkannya': 'cair',
    'mencairan': 'cair',
    'cecairan': 'cair',
    'pencairan': 'cair',
    'pencairannya': 'cair',
    'mencakah': 'cakah',
    'pecakak': 'cakak',
    'bercakak': 'cakak',
    'mencakar': 'cakar',
    'mencakarnya': 'cakar',
    'mencakari': 'cakar',
    'mencakarku': 'cakar',
    'pencakar': 'cakar',
    'pencakarnya': 'cakar',
    'pencakaran': 'cakar',
    'bersicakar': 'cakar',
    'cakar-mencakar': 'cakar',
    'bercakar-cakaran': 'cakar',
    'bercakrawala': 'cakrawala',
    'cakupan': 'cakup',
    'cakupannya': 'cakup',
    'cakupanan': 'cakup',
    'pencakup': 'cakup',
    'pencakupan': 'cakup',
    'tercakup': 'cakup',
    'tercakupnya': 'cakup',
    'tercakupi': 'cakup',
    'mencakup': 'cakup',
    'mencakupnya': 'cakup',
    'mencakupkan': 'cakup',
    'mencakupi': 'cakup',
    'mencakupan': 'cakup',
    'cakup-mencakup': 'cakup',
    'mencakup-cakup': 'cakup',
    'mencakus': 'cakus',
    'mencalak': 'calak',
    'calak-calak': 'calak',
    'mencalang': 'calang',
    'pencalang': 'calang',
    'mencalit': 'calit',
    'bercalit': 'calit',
    'mencalitkan': 'calit',
    'percaloan': 'calo',
    'percaloannya': 'calo',
    'pencalonan': 'calon',
    'pencalonannya': 'calon',
    'pencalonanan': 'calon',
    'pencalonanku': 'calon',
    'mencalonkan': 'calon',
    'mencalonkannya': 'calon',
    'mencalonkanlah': 'calon',
    'mencamkan': 'cam',
    'kecamatan': 'camat',
    'kecamatannya': 'camat',
    'kecamatanan': 'camat',
    'bercambang': 'cambang',
    'mencambuk': 'cambuk',
    'mencambuknya': 'cambuk',
    'mencambukkan': 'cambuk',
    'mencambuki': 'cambuk',
    'mencambukku': 'cambuk',
    'mencambukmu': 'cambuk',
    'mencambukinya': 'cambuk',
    'pencambukan': 'cambuk',
    'camilan': 'camil',
    'camilannya': 'camil',
    'camilanmu': 'camil',
    'mencampak': 'campak',
    'mencampakkan': 'campak',
    'mencampakkannya': 'campak',
    'mencampakan': 'campak',
    'tercampak': 'campak',
    'tercampakkan': 'campak',
    'tercampakan': 'campak',
    'mencampakkanku': 'campak',
    'mencampakkanmu': 'campak',
    'mencampang': 'campang',
    'secampin': 'campin',
    'campang-camping': 'camping',
    'bercamping-camping': 'camping',
    'mencampung': 'campung',
    'tercampung': 'campung',
    'kecampuradukan': 'campur aduk',
    'bercampur aduk': 'campur aduk',
    'pencampuradukan': 'campur aduk',
    'mencampuradukkan': 'campur aduk',
    'mencampuradukkannya': 'campur aduk',
    'bercampur baur': 'campur baur',
    'pencampurbauran': 'campur baur',
    'mencampurbaurkan': 'campur baur',
    'campuran': 'campur',
    'campurannya': 'campur',
    'bercampur': 'campur',
    'bercampurnya': 'campur',
    'bercampuran': 'campur',
    'tercampur': 'campur',
    'tercampurnya': 'campur',
    'tercampurlah': 'campur',
    'tercampurkan': 'campur',
    'tercampuri': 'campur',
    'mencampur': 'campur',
    'mencampurnya': 'campur',
    'mencampurkan': 'campur',
    'mencampurkannya': 'campur',
    'mencampuri': 'campur',
    'mencampurinya': 'campur',
    'percampuran': 'campur',
    'percampurannya': 'campur',
    'pencampuran': 'campur',
    'pencampurannya': 'campur',
    'bercamuk': 'camuk',
    'mencamuk': 'camuk',
    'mencamurkan': 'camur',
    'canaian': 'canai',
    'mencanai': 'canai',
    'pencanai': 'canai',
    'pencanaian': 'canai',
    'mencanak': 'canak',
    'pencanang': 'canang',
    'pencanangkan': 'canang',
    'pencanangan': 'canang',
    'tercanang': 'canang',
    'pencanangannya': 'canang',
    'pencananganan': 'canang',
    'mencanangkan': 'canang',
    'mencanangkannya': 'canang',
    'mencancang': 'cancang',
    'tercancang': 'cancang',
    'bercancut': 'cancut',
    'mencancutkan': 'cancut',
    'bercanda': 'canda',
    'bercandanya': 'canda',
    'bercandalah': 'canda',
    'bercandai': 'canda',
    'bercandaan': 'canda',
    'percandian': 'candi',
    'pencandraan': 'candra',
    'mencandrakan': 'candra',
    'pecandu': 'candu',
    'pecandunya': 'candu',
    'mencandu': 'candu',
    'pencandu': 'candu',
    'pencandunya': 'candu',
    'mencandui': 'candu',
    'kecanduan': 'candu',
    'kecanduannya': 'candu',
    'kecanduanku': 'candu',
    'percanduan': 'candu',
    'mencandukan': 'candu',
    'tercangah': 'cangah',
    'mencangah': 'cangah',
    'mencangak': 'cangak',
    'mencangakan': 'cangak',
    'tercangak-cangak': 'cangak',
    'mencangam': 'cangam',
    'bercangap': 'cangap',
    'mencangar': 'cangar',
    'mencangcang': 'cangcang',
    'kecanggihan': 'canggih',
    'kecanggihannya': 'canggih',
    'tercanggung': 'canggung',
    'kecanggungan': 'canggung',
    'kecanggungannya': 'canggung',
    'mencanggungkan': 'canggung',
    'mencangkel': 'cangkel',
    'tercangkel': 'cangkel',
    'mencangkelkan': 'cangkel',
    'cangkingan': 'cangking',
    'mencangking': 'cangking',
    'mencangklong': 'cangklong',
    'cangkolan': 'cangkol',
    'cangkulan': 'cangkul',
    'cangkulannya': 'cangkul',
    'mencangkul': 'cangkul',
    'mencangkuli': 'cangkul',
    'mencangkum': 'cangkum',
    'bercangkung': 'cangkung',
    'mencangkung': 'cangkung',
    'mencangkup': 'cangkup',
    'mencangkupi': 'cangkup',
    'mencanguk': 'canguk',
    'kecantasan': 'cantas',
    'cantelan': 'cantel',
    'cantelannya': 'cantel',
    'mencantelkan': 'cantel',
    'cantengan': 'canteng',
    'tercantik': 'cantik',
    'tercantiknya': 'cantik',
    'tercantiklah': 'cantik',
    'tercantikku': 'cantik',
    'kecantikan': 'cantik',
    'kecantikannya': 'cantik',
    'kecantikanku': 'cantik',
    'kecantikanmu': 'cantik',
    'pemercantik': 'cantik',
    'mencantikkan': 'cantik',
    'mempercantik': 'cantik',
    'mempercantiknya': 'cantik',
    'mempercantikan': 'cantik',
    'bercantik-cantik': 'cantik',
    'cantolan': 'cantol',
    'cantolannya': 'cantol',
    'kecantol': 'cantol',
    'tercantol': 'cantol',
    'mencantolkan': 'cantol',
    'bercap': 'cap',
    'bercapkan': 'cap',
    'mengecap': 'kecap',
    'mengecapnya': 'kecap',
    'mengecapkan': 'kecap',
    'mengecapi': 'kecap',
    'pengecapan': 'kecap',
    'pengecapannya': 'kecap',
    'capaian': 'capai',
    'capaiannya': 'capai',
    'tercapai': 'capai',
    'tercapainya': 'capai',
    'tercapailah': 'capai',
    'tercapaikan': 'capai',
    'tercapaian': 'capai',
    'pencapai': 'capai',
    'pencapainya': 'capai',
    'pencapaikan': 'capai',
    'pencapaian': 'capai',
    'mencapai': 'capai',
    'mencapainya': 'capai',
    'mencapaikan': 'capai',
    'mencapaii': 'capai',
    'mencapaian': 'capai',
    'kecapaian': 'capai',
    'pencapaiannya': 'capai',
    'pencapaianku': 'capai',
    'pencapaianmu': 'capai',
    'sepencapai': 'capai',
    'mencapak': 'capak',
    'mencapakkan': 'capak',
    'mencapaki': 'capak',
    'tercapak': 'capak',
    'mempercapak': 'capak',
    'mencapak-capak': 'capak',
    'pencaplok': 'caplok',
    'pencaplokan': 'caplok',
    'tercaplok': 'caplok',
    'tercaploknya': 'caplok',
    'mencaplok': 'caplok',
    'mencaploknya': 'caplok',
    'pencaplokannya': 'caplok',
    'secara': 'cara',
    'secaranya': 'cara',
    'secarai': 'cara',
    'mencarah': 'carah',
    'bercarah': 'carah',
    'mencarahkan': 'carah',
    'mencarak': 'carak',
    'pencarak': 'carak',
    'bercaran': 'caran',
    'mencarang': 'carang',
    'bercarang': 'carang',
    'carian': 'cari',
    'cariannya': 'cari',
    'mencari': 'cari',
    'mencarinya': 'cari',
    'mencarikan': 'cari',
    'mencarikannya': 'cari',
    'mencarii': 'cari',
    'mencarian': 'cari',
    'mencariku': 'cari',
    'mencarimu': 'cari',
    'tercari': 'cari',
    'pencari': 'cari',
    'pencarinya': 'cari',
    'pencarian': 'cari',
    'pencari-mu': 'cari',
    'bercari': 'cari',
    'pencariannya': 'cari',
    'pencarianlah': 'cari',
    'pencarianmu': 'cari',
    'mencarikanku': 'cari',
    'cari-carian': 'cari',
    'mencari-cari': 'cari',
    'mencari-carinya': 'cari',
    'mencari-carilah': 'cari',
    'bercari-cari': 'cari',
    'bercari-carian': 'cari',
    'carikan': 'carik',
    'carikanlah': 'carik',
    'secarik': 'carik',
    'mencarik': 'carik',
    'mencarik-carik': 'carik',
    'bercarik-carik': 'carik',
    'mencarik-carikkan': 'carik',
    'mencaring': 'caring',
    'carteran': 'carter',
    'pencarter': 'carter',
    'pencarteran': 'carter',
    'mencarter': 'carter',
    'mencaruk': 'caruk',
    'bercarut': 'carut',
    'pencarut': 'carut',
    'carut-marut': 'carut',
    'carut-marutnya': 'carut',
    'mempercaruti': 'carut',
    'mencarut-carut': 'carut',
    'bercarut-carut': 'carut',
    'mengecas': 'cas',
    'mengecasnya': 'cas',
    'mengecaskan': 'cas',
    'catatan': 'catat',
    'catatannya': 'catat',
    'catatanku': 'catat',
    'catatanmu': 'catat',
    'tercatat': 'catat',
    'tercatatnya': 'catat',
    'tercatatlah': 'catat',
    'tercatatkan': 'catat',
    'tercatatan': 'catat',
    'pencatat': 'catat',
    'pencatatnya': 'catat',
    'pencatatkan': 'catat',
    'pencatatan': 'catat',
    'mencatat': 'catat',
    'mencatatnya': 'catat',
    'mencatatkan': 'catat',
    'mencatatkannya': 'catat',
    'mencatati': 'catat',
    'mencatatan': 'catat',
    'mencatatmu': 'catat',
    'pencatatannya': 'catat',
    'mencatek': 'catek',
    'catuan': 'catu',
    'mencatu': 'catu',
    'pencatu': 'catu',
    'pencatuan': 'catu',
    'mencatuk': 'catuk',
    'tercatuk': 'catuk',
    'pecatur': 'catur',
    'pecaturnya': 'catur',
    'pecaturan': 'catur',
    'caturan': 'catur',
    'caturani': 'catur',
    'bercatur': 'catur',
    'percaturan': 'catur',
    'percaturannya': 'catur',
    'catutan': 'catut',
    'bercatut': 'catut',
    'mencatut': 'catut',
    'mencatutnya': 'catut',
    'mencatutkan': 'catut',
    'pencatut': 'catut',
    'pencatutnya': 'catut',
    'pencatutan': 'catut',
    'percatutan': 'catut',
    'bercawak': 'cawak',
    'bercawat': 'cawat',
    'mencawatkan': 'cawat',
    'cawi-cawi': 'cawi',
    'cebakan': 'cebak',
    'mencebak': 'cebak',
    'pencebak': 'cebak',
    'bercebak': 'cebak',
    'percebakan': 'cebak',
    'pencebakan': 'cebak',
    'mencebik': 'cebik',
    'mencebikkan': 'cebik',
    'mencebil': 'cebil',
    'mencebilkan': 'cebil',
    'secebir': 'cebir',
    'mencebir': 'cebir',
    'secebis': 'cebis',
    'bercebok': 'cebok',
    'menceboki': 'cebok',
    'mencebur': 'cebur',
    'menceburkan': 'cebur',
    'menceburkannya': 'cebur',
    'tercebur': 'cebur',
    'terceburnya': 'cebur',
    'cebar-cebur': 'cebur',
    'bercebar-cebur': 'cebur',
    'sececah': 'cecah',
    'tercecah': 'cecah',
    'bercecah': 'cecah',
    'mencecah': 'cecah',
    'mencecahkan': 'cecah',
    'mencecak': 'cecak',
    'pencecak': 'cecak',
    'mencecap': 'cecap',
    'mencecapnya': 'cecap',
    'mencecar': 'cecar',
    'mencecarnya': 'cecar',
    'mencecari': 'cecar',
    'mencecarmu': 'cecar',
    'tercedera': 'cedera',
    'tercederai': 'cedera',
    'mencedera': 'cedera',
    'mencederakan': 'cedera',
    'mencederai': 'cedera',
    'bercedera': 'cedera',
    'kecederaan': 'cedera',
    'kecederaannya': 'cedera',
    'mencederainya': 'cedera',
    'mencederaiku': 'cedera',
    'percederaan': 'cedera',
    'pencederaan': 'cedera',
    'mencedok': 'cedok',
    'pencedok': 'cedok',
    'tercegah': 'cegah',
    'tercegahnya': 'cegah',
    'mencegah': 'cegah',
    'mencegahnya': 'cegah',
    'mencegahlah': 'cegah',
    'mencegahkan': 'cegah',
    'mencegahan': 'cegah',
    'mencegahku': 'cegah',
    'mencegahmu': 'cegah',
    'pencegah': 'cegah',
    'pencegahnya': 'cegah',
    'pencegahan': 'cegah',
    'pencegahannya': 'cegah',
    'pencegahanlah': 'cegah',
    'pencegahanan': 'cegah',
    'mencegat': 'cegat',
    'mencegatnya': 'cegat',
    'mencegatku': 'cegat',
    'mencegatmu': 'cegat',
    'pencegatan': 'cegat',
    'pencegatannya': 'cegat',
    'cegukan': 'ceguk',
    'cegukannya': 'ceguk',
    'pengecek': 'kecek',
    'pengeceknya': 'kecek',
    'pengecekkan': 'kecek',
    'pengecekan': 'kecek',
    'mengecek': 'kecek',
    'mengeceknya': 'kecek',
    'mengecekkan': 'kecek',
    'mengeceki': 'kecek',
    'mengecekan': 'kecek',
    'pengecekannya': 'cek',
    'bercekah': 'cekah',
    'mencekah': 'cekah',
    'bercekak': 'cekak',
    'mencekak': 'cekak',
    'mencekakkan': 'cekak',
    'mempercekakkan': 'cekak',
    'bercekakakan': 'cekakak',
    'cekakak cekikik': 'cekakak',
    'bercekakak cekikik': 'cekakak',
    'cekalan': 'cekal',
    'mencekal': 'cekal',
    'mencekalnya': 'cekal',
    'pencekalan': 'cekal',
    'pencekalannya': 'cekal',
    'mencekalkan': 'cekal',
    'cekaman': 'cekam',
    'tercekam': 'cekam',
    'mencekam': 'cekam',
    'mencekamnya': 'cekam',
    'mencekamkan': 'cekam',
    'mencekamku': 'cekam',
    'cekatan': 'cekat',
    'cekatannya': 'cekat',
    'kecekatan': 'cekat',
    'kecekatannya': 'cekat',
    'mencekau': 'cekau',
    'bercekcok': 'cekcok',
    'mencekcoki': 'cekcok',
    'percekcokan': 'cekcok',
    'percekcokannya': 'cekcok',
    'mempercekcokkan': 'cekcok',
    'menceker': 'ceker',
    'mencekih': 'cekih',
    'tercekih': 'cekih',
    'cekikan': 'cekik',
    'cekikannya': 'cekik',
    'pencekik': 'cekik',
    'pencekikan': 'cekik',
    'tercekik': 'cekik',
    'tercekiklah': 'cekik',
    'bercekik': 'cekik',
    'mencekik': 'cekik',
    'mencekiknya': 'cekik',
    'mencekikku': 'cekik',
    'mencekikmu': 'cekik',
    'mempercekikkan': 'cekik',
    'cekikikan': 'cekikik',
    'bercekikikan': 'cekikik',
    'bercekit': 'cekit',
    'mencekit': 'cekit',
    'tercekluk': 'cekluk',
    'cekokan': 'cekok',
    'mencekok': 'cekok',
    'mencekokkan': 'cekok',
    'mencekoki': 'cekok',
    'mencekokinya': 'cekok',
    'menceku': 'ceku',
    'mencekukan': 'ceku',
    'mencekuh': 'cekuh',
    'kecekungan': 'cekung',
    'mencekup': 'cekup',
    'mencekut': 'cekut',
    'celaan': 'cela',
    'celaannya': 'cela',
    'bercela': 'cela',
    'tercela': 'cela',
    'tercelanya': 'cela',
    'tercelalah': 'cela',
    'pencela': 'cela',
    'pencelanya': 'cela',
    'pencelaan': 'cela',
    'mencela': 'cela',
    'mencelanya': 'cela',
    'mencelakan': 'celak',
    'kecelaan': 'cela',
    'bercelah': 'celah',
    'mencelak': 'celak',
    'bercelak': 'celak',
    'mencelaki': 'celak',
    'mencelakai': 'celaka',
    'mencelakainya': 'celaka',
    'mencelakaimu': 'celaka',
    'kecelakaan': 'celaka',
    'kecelakaannya': 'celaka',
    'kecelakaankan': 'celaka',
    'mencelakakan': 'celaka',
    'mencelakakannya': 'celaka',
    'tercelampak': 'celampak',
    'mencelampakkan': 'celampak',
    'bercelana': 'celana',
    'mencelang': 'celang',
    'mencelangakkan': 'celangak',
    'tercelapak': 'celapak',
    'mencelapaki': 'celapak',
    'mencelat': 'celat',
    'mencelatnya': 'celat',
    'mencelatlah': 'celat',
    'bercelatuk': 'celatuk',
    'celengan': 'celeng',
    'celengannya': 'celeng',
    'celenganku': 'celeng',
    'celenganmu': 'celeng',
    'mencelengi': 'celeng',
    'tercelentang': 'celentang',
    'mencelep': 'celep',
    'menceletuk': 'celetuk',
    'menceletukkan': 'celetuk',
    'mencelikkan': 'celik',
    'celingukan': 'celinguk',
    'celingak-celinguk': 'celinguk',
    'mencelis': 'celis',
    'tercelomok': 'celomok',
    'menceluk': 'celuk',
    'mencelung': 'celung',
    'mencelungkan': 'celung',
    'celung-celung': 'celung',
    'mencelup': 'celup',
    'mencelupnya': 'celup',
    'mencelupkan': 'celup',
    'mencelupkannya': 'celup',
    'pencelup': 'celup',
    'pencelupan': 'celup',
    'celuran': 'celur',
    'bercelur': 'celur',
    'mencelur': 'celur',
    'penceluran': 'celur',
    'mencelus': 'celus',
    'tercelus': 'celus',
    'celas-celus': 'celus',
    'mencema': 'cema',
    'mencemakan': 'cema',
    'tercema': 'cema',
    'cemaran': 'cemar',
    'cemarannya': 'cemar',
    'pencemar': 'cemar',
    'pencemarnya': 'cemar',
    'pencemari': 'cemar',
    'pencemaran': 'cemar',
    'tercemar': 'cemar',
    'tercemarnya': 'cemar',
    'tercemarkan': 'cemar',
    'tercemari': 'cemar',
    'bercemar': 'cemar',
    'kecemaran': 'cemar',
    'mencemari': 'cemar',
    'mencemarinya': 'cemar',
    'pencemarannya': 'cemar',
    'pencemaranan': 'cemar',
    'mencemarkan': 'cemar',
    'mencemarkannya': 'cemar',
    'pencemas': 'cemas',
    'tercemas': 'cemas',
    'bercemas': 'cemas',
    'kecemasan': 'cemas',
    'kecemasannya': 'cemas',
    'kecemasanku': 'cemas',
    'kecemasanmu': 'cemas',
    'mencemaskan': 'cemas',
    'mencemaskannya': 'cemas',
    'mencemaskanku': 'cemas',
    'cemas-cemas': 'cemas',
    'mencemat': 'cemat',
    'mencemati': 'cemat',
    'cemburuan': 'cemburu',
    'cemburuannya': 'cemburu',
    'bercemburu': 'cemburu',
    'kecemburuan': 'cemburu',
    'kecemburuannya': 'cemburu',
    'kecemburuanku': 'cemburu',
    'mencemburui': 'cemburu',
    'mencemburuinya': 'cemburu',
    'bercemburuan': 'cemburu',
    'mencemburukan': 'cemburu',
    'pencemeeh': 'cemeeh',
    'mencemeehkan': 'cemeeh',
    'kecemerlangan': 'cemerlang',
    'kecemerlangannya': 'cemerlang',
    'kecemerlanganmu': 'cemerlang',
    'mencemerlangkan': 'cemerlang',
    'mencemeti': 'cemeti',
    'bercemetuk': 'cemetuk',
    'cemoohan': 'cemooh',
    'cemoohannya': 'cemooh',
    'mencemooh': 'cemooh',
    'mencemoohnya': 'cemooh',
    'mencemoohkan': 'cemooh',
    'mencemoohkannya': 'cemooh',
    'mencemoohan': 'cemooh',
    'mencemoohku': 'cemooh',
    'bercempera': 'cempera',
    'tercemplung': 'cemplung',
    'mencemplung': 'cemplung',
    'mencemplungkan': 'cemplung',
    'mencemplungkannya': 'cemplung',
    'pencemplungan': 'cemplung',
    'mencempung': 'cempung',
    'mencempungi': 'cempung',
    'mencempungkan': 'cempung',
    'mencemuk': 'cemuk',
    'kecenaan': 'cena',
    'cencangan': 'cencang',
    'bercencang': 'cencang',
    'mencencang': 'cencang',
    'cencang latih': 'cencang',
    'kecendekiaan': 'cendekia',
    'pencendekiaan': 'cendekia',
    'mencendekiakan': 'cendekia',
    'kecendekiawanan': 'cendekiawan',
    'kecendekiawanannya': 'cendekiawan',
    'kecenderungan': 'cenderung',
    'kecenderungannya': 'cenderung',
    'kecenderunganlah': 'cenderung',
    'kecenderunganku': 'cenderung',
    'berkecenderungan': 'cenderung',
    'bercenduai': 'cenduai',
    'mencengam': 'cengam',
    'tercengang': 'cengang',
    'tercengangnya': 'cengang',
    'bersicengang': 'cengang',
    'bercengangan': 'cengang',
    'mencengangkan': 'cengang',
    'mencengangkannya': 'cengang',
    'tercengang-cengang': 'cengang',
    'mencengap': 'cengap',
    'mencengis-cengis': 'cengis-cengis',
    'cengkaman': 'cengkam',
    'mencengkam': 'cengkam',
    'mencengkamkan': 'cengkam',
    'mencengkelong': 'cengkelong',
    'cengkeraman': 'cengkeram',
    'cengkeramannya': 'cengkeram',
    'mencengkeram': 'cengkeram',
    'mencengkeramnya': 'cengkeram',
    'mencengkeramkan': 'cengkeram',
    'bercengkih': 'cengkih',
    'percengkihan': 'cengkih',
    'bercengkung': 'cengkung',
    'tercengung': 'cengung',
    'mencengut': 'cengut',
    'tercengut': 'cengut',
    'mencentang': 'centang',
    'centang-perenang': 'centang',
    'kecentang-perenangan': 'centang',
    'kecentilan': 'centil',
    'mencentong': 'centong',
    'tercenung': 'cenung',
    'mencepak-cepak': 'cepak',
    'cepalan': 'cepal',
    'secepat': 'cepat',
    'secepatnya': 'cepat',
    'secepatlah': 'cepat',
    'secepatkan': 'cepat',
    'secepatnyalah': 'cepat',
    'mencepat': 'cepat',
    'kecepatan': 'cepat',
    'kecepatannya': 'cepat',
    'kecepatanlah': 'cepat',
    'kecepatanan': 'cepat',
    'kecepatanku': 'cepat',
    'bersecepat': 'cepat',
    'percepatan': 'cepat',
    'percepatannya': 'cepat',
    'percepatanlah': 'cepat',
    'bersicepat': 'cepat',
    'pencepatan': 'cepat',
    'pemercepat': 'cepat',
    'pemercepatan': 'cepat',
    'mencepatkan': 'cepat',
    'mempercepat': 'cepat',
    'mempercepatnya': 'cepat',
    'mempercepatlah': 'cepat',
    'mempercepatan': 'cepat',
    'cepat-cepat': 'cepat',
    'cepat-cepatlah': 'cepat',
    'cepat-cepatkan': 'cepat',
    'cepat-cepatan': 'cepat',
    'berkecepatan': 'cepat',
    'berkecepatanan': 'cepat',
    'bercepat-cepat': 'cepat',
    'keceplosan': 'ceplos',
    'keceplosannya': 'ceplos',
    'menceploskan': 'ceplos',
    'menceploskannya': 'ceplos',
    'mencepol': 'cepol',
    'mencepuk': 'cepuk',
    'mencepuk-cepuk': 'cepuk',
    'mencerabih': 'cerabih',
    'tercerabut': 'cerabut',
    'tercerabutnya': 'cerabut',
    'menceracam': 'ceracam',
    'penceracau': 'ceracau',
    'menceracau': 'ceracau',
    'kecerahan': 'cerah',
    'kecerahannya': 'cerah',
    'pencerahan': 'cerah',
    'pencerahannya': 'cerah',
    'pencerahanlah': 'cerah',
    'pencerahanan': 'cerah',
    'mencerahkan': 'cerah',
    'mencerahkannya': 'cerah',
    'bercerai-berai': 'cerai-berai',
    'mencerai-beraikan': 'cerai-berai',
    'bercerak': 'cerak',
    'bercerancangan': 'cerancang',
    'cerapan': 'cerap',
    'mencerap': 'cerap',
    'tercerap': 'cerap',
    'pencerapan': 'cerap',
    'ceratan': 'cerat',
    'mencerat': 'cerat',
    'mencerati': 'cerat',
    'mencerataikan': 'ceratai',
    'berceratuk': 'ceratuk',
    'menceratuk': 'ceratuk',
    'berceratukan': 'ceratuk',
    'cercaan': 'cerca',
    'cercaannya': 'cerca',
    'mencerca': 'cerca',
    'mencercanya': 'cerca',
    'mencercaku': 'cerca',
    'mencercai': 'cerca',
    'cercahan': 'cercah',
    'secercah': 'cercah',
    'mencercah': 'cercah',
    'mencercap': 'cercap',
    'kecerdasan': 'cerdas',
    'kecerdasannya': 'cerdas',
    'kecerdasanlah': 'cerdas',
    'kecerdasanan': 'cerdas',
    'kecerdasanmu': 'cerdas',
    'pencerdasan': 'cerdas',
    'mencerdaskan': 'cerdas',
    'mencerdaskannya': 'cerdas',
    'kecerdikan': 'cerdik',
    'kecerdikannya': 'cerdik',
    'kecerewetan': 'cerewet',
    'kecerewetannya': 'cerewet',
    'mencereweti': 'cerewet',
    'mencerewetinya': 'cerewet',
    'kecergasan': 'cergas',
    'keceriaan': 'ceria',
    'keceriaannya': 'ceria',
    'keceriaanmu': 'ceria',
    'penceriaan': 'ceria',
    'menceriakan': 'ceria',
    'bercericau': 'cericau',
    'mencerkau': 'cerkau',
    'mencerlang': 'cerlang',
    'kecerlangan': 'cerlang',
    'kecerlangannya': 'cerlang',
    'mencerling': 'cerling',
    'kecermatan': 'cermat',
    'kecermatannya': 'cermat',
    'mencermati': 'cermat',
    'mencermatinya': 'cermat',
    'mencermatkan': 'cermat',
    'cerminan': 'cermin',
    'cerminannya': 'cermin',
    'cerminanan': 'cermin',
    'cerminanku': 'cermin',
    'becermin': 'cermin',
    'tercermin': 'cermin',
    'tercerminnya': 'cermin',
    'tercerminkan': 'cermin',
    'bercermin': 'cermin',
    'bercerminlah': 'cermin',
    'mencermini': 'cermin',
    'mencerminkan': 'cermin',
    'mencerminkannya': 'cermin',
    'mempercermin': 'cermin',
    'tecerna': 'cerna',
    'mencerna': 'cerna',
    'mencernanya': 'cerna',
    'mencernakan': 'cerna',
    'mencernaan': 'cerna',
    'pencernaan': 'cerna',
    'pencernaannya': 'cerna',
    'pencernaanku': 'cerna',
    'menceroboh': 'ceroboh',
    'mencerobohi': 'ceroboh',
    'kecerobohan': 'ceroboh',
    'kecerobohannya': 'ceroboh',
    'kecerobohanlah': 'ceroboh',
    'mencerocos': 'cerocos',
    'berceroteh': 'ceroteh',
    'mencerowok': 'cerowok',
    'mencerucup': 'cerucup',
    'menceruh': 'ceruh',
    'menceruk': 'ceruk',
    'ceruk-meruk': 'ceruk',
    'ceruk-menceruk': 'ceruk',
    'mencerup': 'cerup',
    'mencerut': 'cerut',
    'mencetai-cetai': 'cetai',
    'bercetai-cetai': 'cetai',
    'cetakan': 'cetak',
    'cetakannya': 'cetak',
    'bercetak': 'cetak',
    'bercetakan': 'cetak',
    'mencetak': 'cetak',
    'mencetaknya': 'cetak',
    'mencetakkan': 'cetak',
    'mencetakkannya': 'cetak',
    'mencetaki': 'cetak',
    'mencetakan': 'cetak',
    'pencetak': 'cetak',
    'pencetaknya': 'cetak',
    'pencetakkan': 'cetak',
    'pencetakkannya': 'cetak',
    'pencetakan': 'cetak',
    'pencetakannya': 'cetak',
    'percetakan': 'cetak',
    'percetakannya': 'cetak',
    'percetakanmu': 'cetak',
    'cetak-mencetak': 'cetak',
    'cetar-ceter': 'cetar',
    'menceteng': 'ceteng',
    'menceti': 'ceti',
    'mencetikan': 'ceti',
    'cetusan': 'cetus',
    'cetusannya': 'cetus',
    'mencetus': 'cetus',
    'mencetusnya': 'cetus',
    'mencetuskan': 'cetus',
    'mencetuskannya': 'cetus',
    'tercetus': 'cetus',
    'tercetusnya': 'cetus',
    'tercetuslah': 'cetus',
    'tercetuskan': 'cetus',
    'pencetus': 'cetus',
    'pencetusnya': 'cetus',
    'pencetusan': 'cetus',
    'menciak': 'ciak',
    'menciak-ciak': 'ciak',
    'seciap': 'ciap',
    'menciap-ciap': 'ciap',
    'berciap-ciap': 'ciap',
    'menciar-ciar': 'ciar',
    'mencibir': 'cibir',
    'mencibirnya': 'cibir',
    'mencibirkan': 'cibir',
    'mencibirku': 'cibir',
    'mencibit': 'cibit',
    'mencicik': 'cicik',
    'cicilan': 'cicil',
    'cicilannya': 'cicil',
    'cicilanlah': 'cicil',
    'cicilanmu': 'cicil',
    'mencicil': 'cicil',
    'mencicilnya': 'cicil',
    'pencicilan': 'cicil',
    'pencicilannya': 'cicil',
    'mencicip': 'cicip',
    'mencicipnya': 'cicip',
    'mencicipi': 'cicip',
    'mencicipinya': 'cicip',
    'mencicit': 'cicit',
    'mencicitkan': 'cicit',
    'cidukan': 'ciduk',
    'menciduk': 'ciduk',
    'menciduknya': 'ciduk',
    'menciduki': 'ciduk',
    'mencidukku': 'ciduk',
    'terciduk': 'ciduk',
    'bercikun-cikun': 'cikun',
    'cikutan': 'cikut',
    'tercilap-cilap': 'cilap',
    'mencilok': 'cilok',
    'pencilok': 'cilok',
    'mencina': 'cina',
    'mencinai': 'cina',
    'mencincang': 'cincang',
    'mencincangnya': 'cincang',
    'cingak-cinguk': 'cingak',
    'tercingangah': 'cingangah',
    'menciplak': 'ciplak',
    'cipratan': 'ciprat',
    'cipratannya': 'ciprat',
    'menciprat': 'ciprat',
    'mencipratkan': 'ciprat',
    'menciprati': 'ciprat',
    'terciprat': 'ciprat',
    'kecipratan': 'ciprat',
    'kecipratannya': 'ciprat',
    'ciptaan': 'cipta',
    'ciptaannya': 'cipta',
    'ciptaanku': 'cipta',
    'ciptaanmu': 'cipta',
    'ciptaan-ku': 'cipta',
    'ciptaan-mu': 'cipta',
    'tercipta': 'cipta',
    'terciptanya': 'cipta',
    'terciptalah': 'cipta',
    'terciptakan': 'cipta',
    'mencipta': 'cipta',
    'menciptanya': 'cipta',
    'menciptakan': 'cipta',
    'menciptakannya': 'cipta',
    'menciptai': 'cipta',
    'menciptaan': 'cipta',
    'pencipta': 'cipta',
    'penciptanya': 'cipta',
    'penciptakan': 'cipta',
    'penciptaan': 'cipta',
    'penciptaku': 'cipta',
    'penciptamu': 'cipta',
    'penciptaannya': 'cipta',
    'menciptakanku': 'cipta',
    'berciri': 'ciri',
    'bercirikan': 'ciri',
    'pencirian': 'ciri',
    'mencirikan': 'ciri',
    'mencirikannya': 'ciri',
    'mencirit': 'cirit',
    'tercirit': 'cirit',
    'menciritkan': 'cirit',
    'cirit-birit': 'cirit',
    'mencita': 'cita',
    'mencitakan': 'cita',
    'mencitakannya': 'cita',
    'mencitai': 'cita',
    'cita-cita': 'cita',
    'cita-citanya': 'cita',
    'cita-citalah': 'cita',
    'cita-citakan': 'cita',
    'cita-citaku': 'cita',
    'cita-citamu': 'cita',
    'cita-cita-mu': 'cita',
    'bercita-cita': 'cita',
    'bercita-citanya': 'cita',
    'bercita-citalah': 'cita',
    'mencita-citakan': 'cita',
    'mencita-citakannya': 'cita',
    'citraan': 'citra',
    'mencitrakan': 'citra',
    'mencitrakannya': 'citra',
    'ciuman': 'cium',
    'ciumannya': 'cium',
    'ciumanku': 'cium',
    'ciumanmu': 'cium',
    'pencium': 'cium',
    'penciumnya': 'cium',
    'penciuman': 'cium',
    'mencium': 'cium',
    'menciumnya': 'cium',
    'menciumkan': 'cium',
    'menciumi': 'cium',
    'menciumku': 'cium',
    'menciummu': 'cium',
    'tercium': 'cium',
    'terciumnya': 'cium',
    'terciumlah': 'cium',
    'menciuminya': 'cium',
    'menciumimu': 'cium',
    'berciuman': 'cium',
    'berciumannya': 'cium',
    'berciumanlah': 'cium',
    'penciumannya': 'cium',
    'penciumanan': 'cium',
    'penciumanku': 'cium',
    'mencium-cium': 'cium',
    'mencium-ciumi': 'cium',
    'menciut': 'ciut',
    'menciutnya': 'ciut',
    'menciutkan': 'ciut',
    'menciutkannya': 'ciut',
    'penciutan': 'ciut',
    'berciut-ciut': 'ciut',
    'menciut-ciut': 'ciut',
    'mencoaki': 'coak',
    'mencoang': 'coang',
    'tercoang': 'coang',
    'bercoang': 'coang',
    'bercoangan': 'coang',
    'mencoangkan': 'coang',
    'mencoang-coang': 'coang',
    'cobaan': 'coba',
    'cobaannya': 'coba',
    'cobaan-mu': 'coba',
    'mencoba': 'coba',
    'mencobanya': 'coba',
    'mencobalah': 'coba',
    'mencobakan': 'coba',
    'mencobai': 'coba',
    'percobaan': 'coba',
    'percobaannya': 'coba',
    'percobaanlah': 'coba',
    'pencobaan': 'coba',
    'pencobaannya': 'coba',
    'mencoba-coba': 'coba',
    'mencoba-cobanya': 'coba',
    'pencoblos': 'coblos',
    'pencoblosnya': 'coblos',
    'pencoblosan': 'coblos',
    'mencoblos': 'coblos',
    'mencoblosnya': 'coblos',
    'mencobloskan': 'coblos',
    'mencoblosi': 'coblos',
    'mencoblosan': 'coblos',
    'pencoblosannya': 'coblos',
    'mencocok': 'cocok',
    'mencocokkan': 'cocok',
    'mencocokkannya': 'cocok',
    'mencocoki': 'cocok',
    'mencocokan': 'cocok',
    'tercocok': 'cocok',
    'kecocokan': 'cocok',
    'kecocokannya': 'cocok',
    'pencocokan': 'cocok',
    'pencocokannya': 'cocok',
    'mencocok-cocok': 'cocok',
    'mencocok-cocokkan': 'cocok',
    'mencocok-cocokan': 'cocok',
    'bercocok tanam': 'cocok tanam',
    'mencocol': 'cocol',
    'mencocolnya': 'cocol',
    'mencocolkan': 'cocol',
    'mencocor': 'cocor',
    'mencocornya': 'cocor',
    'mencocorkan': 'cocor',
    'mencocorkannya': 'cocor',
    'mencodak': 'codak',
    'mencodakkan': 'codak',
    'tercogok': 'cogok',
    'mencogok': 'cogok',
    'cokekan': 'cokek',
    'mencokek': 'cokek',
    'kecokelatan': 'cokelat',
    'kecokelatannya': 'cokelat',
    'kecokelat-cokelatan': 'cokelat',
    'mencoket': 'coket',
    'mencokok': 'cokok',
    'mencokoknya': 'cokok',
    'mencokoki': 'cokok',
    'bercokol': 'cokol',
    'bercokolnya': 'cokol',
    'mencokolkan': 'cokol',
    'colak caling': 'colak',
    'secolek': 'colek',
    'colekan': 'colek',
    'mencolek': 'colek',
    'mencoleknya': 'colek',
    'mencolekkan': 'colek',
    'pencolek': 'colek',
    'pencolekan': 'colek',
    'mencolek-colek': 'colek',
    'mencoleng': 'coleng',
    'pencoleng': 'coleng',
    'pencolengnya': 'coleng',
    'pencolengan': 'coleng',
    'mencolok': 'colok',
    'mencoloknya': 'colok',
    'mencolokkan': 'colok',
    'mencolokkannya': 'colok',
    'mencolokan': 'colok',
    'tercolok': 'colok',
    'mencoloki': 'colok',
    'mencolong': 'colong',
    'kecolongan': 'colong',
    'kecolongannya': 'colong',
    'kecolonganlah': 'colong',
    'mencolot': 'colot',
    'comelan': 'comel',
    'mencomel': 'comel',
    'pencomel': 'comel',
    'mencomeli': 'comel',
    'pencomelan': 'comel',
    'comotan': 'comot',
    'mencomot': 'comot',
    'mencomotnya': 'comot',
    'mencomoti': 'comot',
    'comot-comot': 'comot',
    'bercompang-camping': 'compang-camping',
    'menconcong': 'concong',
    'tercondong': 'condong',
    'kecondongan': 'condong',
    'kecondongannya': 'condong',
    'mencondongkan': 'condong',
    'berkecondongan': 'condong',
    'condong-mondong': 'condong',
    'menconet': 'conet',
    'mencongak': 'congak',
    'mencongakkan': 'congak',
    'congak-cangit': 'congak',
    'tercongget-congget': 'congget',
    'terconggok': 'conggok',
    'menconggokkan': 'conggok',
    'kecongkakan': 'congkak',
    'mencongklang': 'congklang',
    'mencongkong': 'congkong',
    'mencongok': 'congok',
    'mencongol': 'congol',
    'menconteng': 'conteng',
    'terconteng': 'conteng',
    'mencontengkan': 'conteng',
    'berconteng-conteng': 'conteng',
    'menconteng-conteng': 'conteng',
    'percontoh': 'contoh',
    'percontohan': 'contoh',
    'mencontoh': 'contoh',
    'mencontohnya': 'contoh',
    'mencontohkan': 'contoh',
    'mencontohkannya': 'contoh',
    'mencontohi': 'contoh',
    'mencontohan': 'contoh',
    'pemercontoh': 'contoh',
    'percontohannya': 'contoh',
    'pemercontohan': 'contoh',
    'mempercontohkan': 'contoh',
    'mencopet': 'copet',
    'pencopet': 'copet',
    'pencopetnya': 'copet',
    'pencopetan': 'copet',
    'kecopetan': 'copet',
    'kecopetannya': 'copet',
    'pencopetannya': 'copet',
    'mencopot': 'copot',
    'mencopotnya': 'copot',
    'mencopotkan': 'copot',
    'mencopoti': 'copot',
    'mencopotinya': 'copot',
    'pencopotan': 'copot',
    'pencopotannya': 'copot',
    'pencopotanlah': 'copot',
    'coran': 'cor',
    'corannya': 'cor',
    'mengecor': 'cor',
    'mengecornya': 'cor',
    'pengecoran': 'cor',
    'pengecorannya': 'cor',
    'mencorek': 'corek',
    'mencorekan': 'corek',
    'coretan': 'coret',
    'coretannya': 'coret',
    'mencoret': 'coret',
    'mencoretnya': 'coret',
    'mencoretkan': 'coret',
    'mencoreti': 'coret',
    'mencoretinya': 'coret',
    'pencoretan': 'coret',
    'pencoretannya': 'coret',
    'coret-coret': 'coret',
    'coret-coretnya': 'coret',
    'coret-coretan': 'coret',
    'mencorong': 'corong',
    'mencorongkan': 'corong',
    'mencorotkan': 'corot',
    'mencotok': 'cotok',
    'mencuaikan': 'cuai',
    'cuang-caing': 'cuang',
    'bercuang-caing': 'cuang',
    'tercuar': 'cuar',
    'mencuar': 'cuar',
    'mencuarkan': 'cuar',
    'cuatan': 'cuat',
    'mencuat': 'cuat',
    'mencuatnya': 'cuat',
    'mencuatlah': 'cuat',
    'mencuatkan': 'cuat',
    'bercuatan': 'cuat',
    'cubitan': 'cubit',
    'cubitannya': 'cubit',
    'secubit': 'cubit',
    'mencubit': 'cubit',
    'mencubitnya': 'cubit',
    'mencubiti': 'cubit',
    'mencubitku': 'cubit',
    'mencubit-cubit': 'cubit',
    'cubung-cubung': 'cubung',
    'mencuca': 'cuca',
    'tercuci': 'cuci',
    'mencuci': 'cuci',
    'mencucinya': 'cuci',
    'mencucilah': 'cuci',
    'mencucikan': 'cuci',
    'mencucikannya': 'cuci',
    'mencucian': 'cuci',
    'pencuci': 'cuci',
    'pencucinya': 'cuci',
    'pencucian': 'cuci',
    'pencuciannya': 'cuci',
    'bercucu': 'cucu',
    'mencucuh': 'cucuh',
    'mencucuh-cucuh': 'cucuh',
    'mencucuh-cucuhkan': 'cucuh',
    'mencucup': 'cucup',
    'mencucut': 'cucut',
    'mencugatkan': 'cugat',
    'mencuik': 'cuik',
    'secuil': 'cuil',
    'secuilnya': 'cuil',
    'mencuil': 'cuil',
    'mencuili': 'cuil',
    'mencuit': 'cuit',
    'mencuitnya': 'cuit',
    'mencuitkan': 'cuit',
    'mencuitkannya': 'cuit',
    'bercuit-cuit': 'cuit',
    'bercukai': 'cukai',
    'mencukai': 'cukai',
    'bercuki': 'cuki',
    'cukilan': 'cukil',
    'cukilannya': 'cukil',
    'mencukil': 'cukil',
    'mencukilnya': 'cukil',
    'mencukongi': 'cukong',
    'percukongan': 'cukong',
    'secukup': 'cukup',
    'secukupnya': 'cukup',
    'cukupan': 'cukup',
    'kecukupan': 'cukup',
    'kecukupannya': 'cukup',
    'mencukupi': 'cukup',
    'mencukupinya': 'cukup',
    'mencukupimu': 'cukup',
    'mencukupkan': 'cukup',
    'mencukupkannya': 'cukup',
    'berkecukupan': 'cukup',
    'menculak': 'culak',
    'keculasan': 'culas',
    'penculik': 'culik',
    'penculiknya': 'culik',
    'penculikkan': 'culik',
    'penculikan': 'culik',
    'penculikku': 'culik',
    'menculik': 'culik',
    'menculiknya': 'culik',
    'menculiki': 'culik',
    'menculikan': 'culik',
    'menculikmu': 'culik',
    'penculikannya': 'culik',
    'culik-culik': 'culik',
    'percuma': 'cuma',
    'percumanya': 'cuma',
    'percumalah': 'cuma',
    'bercuma': 'cuma',
    'cuma-cuma': 'cuma',
    'mempercumakan': 'cuma',
    'cumbuan': 'cumbu',
    'cumbuannya': 'cumbu',
    'mencumbu': 'cumbu',
    'mencumbunya': 'cumbu',
    'mencumbui': 'cumbu',
    'mencumbuku': 'cumbu',
    'mencumbumu': 'cumbu',
    'bercumbu': 'cumbu',
    'bercumbulah': 'cumbu',
    'mencumbuinya': 'cumbu',
    'percumbuan': 'cumbu',
    'percumbuannya': 'cumbu',
    'bercumbu-cumbu': 'cumbu',
    'bercumbu-cumbuan': 'cumbu',
    'mencunam': 'cunam',
    'pecundang': 'cundang',
    'pecundangnya': 'cundang',
    'pecundangi': 'cundang',
    'kecundang': 'cundang',
    'kecundangi': 'cundang',
    'tercundang': 'cundang',
    'mencundang': 'cundang',
    'mencundangi': 'cundang',
    'terkecundang': 'cundang',
    'mengecundang': 'cundang',
    'mengecundangi': 'cundang',
    'mempecundang': 'cundang',
    'mempecundangi': 'cundang',
    'mempecundanginya': 'cundang',
    'mengecundanginya': 'cundang',
    'bercunduk': 'cunduk',
    'tercungap': 'cungap',
    'mencungap': 'cungap',
    'cungap-cangip': 'cungap',
    'tercungap-cungap': 'cungap',
    'cungkilan': 'cungkil',
    'cungkilannya': 'cungkil',
    'mencungkil': 'cungkil',
    'mencungkilnya': 'cungkil',
    'pencungkil': 'cungkil',
    'pencungkilan': 'cungkil',
    'mencungul': 'cungul',
    'tercupai': 'cupai',
    'mencupaikan': 'cupai',
    'mencupak': 'cupak',
    'mencupang': 'cupang',
    'mencupar': 'cupar',
    'kecupetan': 'cupet',
    'bercuping': 'cuping',
    'cuplikan': 'cuplik',
    'cuplikannya': 'cuplik',
    'mencuplik': 'cuplik',
    'mencuplikan': 'cuplik',
    'cupu-cupu': 'cupu',
    'bercura': 'cura',
    'bercura-cura': 'cura',
    'bercura-bura': 'cura',
    'curahan': 'curah',
    'tercurah': 'curah',
    'tercurahnya': 'curah',
    'tercurahkan': 'curah',
    'mencurah': 'curah',
    'mencurahkan': 'curah',
    'mencurahkannya': 'curah',
    'mencurahi': 'curah',
    'pencurahan': 'curah',
    'curaian': 'curai',
    'mencuraikan': 'curai',
    'mencuram': 'curam',
    'mencurangi': 'curang',
    'mencuranginya': 'curang',
    'kecurangan': 'curang',
    'kecurangannya': 'curang',
    'kecuranganlah': 'curang',
    'mencurat': 'curat',
    'mencureng': 'cureng',
    'curian': 'curi',
    'curiannya': 'curi',
    'mencuri': 'curi',
    'mencurinya': 'curi',
    'mencurilah': 'curi',
    'mencurikan': 'curi',
    'mencurian': 'curi',
    'pencuri': 'curi',
    'pencurinya': 'curi',
    'pencurian': 'curi',
    'kecurian': 'curi',
    'pencuriannya': 'curi',
    'mencuri-curi': 'curi',
    'bercuriga': 'curiga',
    'mencurigai': 'curiga',
    'mencurigainya': 'curiga',
    'mencurigaiku': 'curiga',
    'kecurigaan': 'curiga',
    'kecurigaannya': 'curiga',
    'mencurigakan': 'curiga',
    'mencurigakannya': 'curiga',
    'mencurigakanlah': 'curiga',
    'mencuru': 'curu',
    'mengedab': 'dab',
    'mendabak': 'dabak',
    'mendabakan': 'dabak',
    'mendabih': 'dabih',
    'pendabihan': 'dabih',
    'mendabik': 'dabik',
    'berdabung': 'dabung',
    'mendabung': 'dabung',
    'berdabus': 'dabus',
    'mendacin': 'dacin',
    'berdada ruah': 'dada ruah',
    'pendadah': 'dadah',
    'pendadahan': 'dadah',
    'dadakan': 'dadak',
    'dadakannya': 'dadak',
    'mendadak': 'dadak',
    'mendadaknya': 'dadak',
    'pendadakan': 'dadak',
    'pendadaran': 'dadar',
    'terdadek': 'dadek',
    'berdadu': 'dadu',
    'mendaduh': 'daduh',
    'mendaduhkan': 'daduh',
    'pendaduk': 'daduk',
    'mendaduk': 'daduk',
    'berdadung': 'dadung',
    'mendadung': 'dadung',
    'mendadungkan': 'dadung',
    'kedaerahan': 'daerah',
    'kedaerahannya': 'daerah',
    'mendaftarhitamkan': 'daftar hitam',
    'mendaftar': 'daftar',
    'mendaftarnya': 'daftar',
    'mendaftarlah': 'daftar',
    'mendaftarkan': 'daftar',
    'mendaftarkannya': 'daftar',
    'mendaftaran': 'daftar',
    'pendaftar': 'daftar',
    'pendaftarnya': 'daftar',
    'pendaftarkan': 'daftar',
    'pendaftaran': 'daftar',
    'terdaftar': 'daftar',
    'terdaftarnya': 'daftar',
    'terdaftarlah': 'daftar',
    'terdaftarkan': 'daftar',
    'pendaftarannya': 'daftar',
    'mendaga': 'daga',
    'mendagakan': 'daga',
    'pendaga': 'daga',
    'pendagaan': 'daga',
    'dagangan': 'dagang',
    'dagangannya': 'dagang',
    'daganganku': 'dagang',
    'pedagang': 'dagang',
    'pedagangnya': 'dagang',
    'pedaganglah': 'dagang',
    'pedagangan': 'dagang',
    'berdagang': 'dagang',
    'berdagangnya': 'dagang',
    'berdaganglah': 'dagang',
    'berdagangan': 'dagang',
    'mendagang': 'dagang',
    'mendagangkan': 'dagang',
    'pendagang': 'dagang',
    'pendagangan': 'dagang',
    'perdagangan': 'dagang',
    'perdagangannya': 'dagang',
    'perdaganganlah': 'dagang',
    'perdagangankan': 'dagang',
    'perdaganganan': 'dagang',
    'memperdagangkan': 'dagang',
    'memperdagangkannya': 'dagang',
    'berdagang': 'dagang',
    'dagelan': 'dagel',
    'mendagel': 'dagel',
    'mendagi': 'dagi',
    'pendagi': 'dagi',
    'pendagian': 'dagi',
    'mendahaga': 'dahaga',
    'berdahan': 'dahan',
    'mendahan': 'dahan',
    'berdahanam': 'dahanam',
    'mendahsyat': 'dahsyat',
    'kedahsyatan': 'dahsyat',
    'kedahsyatannya': 'dahsyat',
    'memperdahsyat': 'dahsyat',
    'mendahsyatkan': 'dahsyat',
    'pendahulu': 'dahulu',
    'pendahulunya': 'dahulu',
    'pendahuluan': 'dahulu',
    'pendahuluku': 'dahulu',
    'pendahulumu': 'dahulu',
    'terdahulu': 'dahulu',
    'terdahulunya': 'dahulu',
    'terdahului': 'dahulu',
    'mendahului': 'dahulu',
    'mendahuluinya': 'dahulu',
    'mendahuluilah': 'dahulu',
    'mendahuluiku': 'dahulu',
    'mendahuluimu': 'dahulu',
    'kedahuluan': 'dahulu',
    'bersidahulu': 'dahulu',
    'pendahuluannya': 'dahulu',
    'mendahulukan': 'dahulu',
    'mendahulukannya': 'dahulu',
    'dahulu-mendahului': 'dahulu',
    'berdahulu-dahuluan': 'dahulu',
    'kedaifan': 'daif',
    'mendaifkan': 'daif',
    'dakian': 'daki',
    'berdaki': 'daki',
    'pendaki': 'daki',
    'pendakinya': 'daki',
    'pendakian': 'daki',
    'mendaki': 'daki',
    'mendakinya': 'daki',
    'mendakian': 'daki',
    'mendakimu': 'daki',
    'terdaki': 'daki',
    'pendakiannya': 'daki',
    'pendakianku': 'daki',
    'pendakianmu': 'daki',
    'mendakikan': 'daki',
    'dakwaan': 'dakwa',
    'dakwaannya': 'dakwa',
    'terdakwa': 'dakwa',
    'terdakwanya': 'dakwa',
    'terdakwalah': 'dakwa',
    'terdakwai': 'dakwa',
    'berdakwa': 'dakwa',
    'mendakwa': 'dakwa',
    'mendakwanya': 'dakwa',
    'mendakwakan': 'dakwa',
    'pendakwa': 'dakwa',
    'pendakwaan': 'dakwa',
    'mendakwai': 'dakwa',
    'pendakwaannya': 'dakwa',
    'memperdakwakan': 'dakwa',
    'dalaman': 'dalam',
    'dalamannya': 'dalam',
    'mendalam': 'dalam',
    'mendalamnya': 'dalam',
    'mendalamkan': 'dalam',
    'mendalami': 'dalam',
    'mendalaman': 'dalam',
    'pedalaman': 'dalam',
    'pedalamannya': 'dalam',
    'kedalaman': 'dalam',
    'kedalamannya': 'dalam',
    'kedalamanan': 'dalam',
    'mendalaminya': 'dalam',
    'pendalaman': 'dalam',
    'pendalamannya': 'dalam',
    'pendalamanan': 'dalam',
    'memperdalam': 'dalam',
    'memperdalamnya': 'dalam',
    'memperdalami': 'dalam',
    'dalam-dalam': 'dalam',
    'dalam-dalamnya': 'dalam',
    'berdalam-dalam': 'dalam',
    'sedalam-dalamnya': 'dalam',
    'sedalam-dalamnyanya': 'dalam',
    'pedalang': 'dalang',
    'pedalangan': 'dalang',
    'mendalang': 'dalang',
    'mendalangnya': 'dalang',
    'mendalangi': 'dalang',
    'pedalangannya': 'dalang',
    'mendalanginya': 'dalang',
    'mendalangkan': 'dalang',
    'berdalil': 'dalil',
    'mendalilkan': 'dalil',
    'dam-dam': 'dam',
    'dam-daman': 'dam',
    'mendamak': 'damak',
    'pendamar': 'damar',
    'pendamaran': 'damar',
    'berdamar': 'damar',
    'mendamar': 'damar',
    'pedamaran': 'damar',
    'dambaan': 'damba',
    'dambaannya': 'damba',
    'mendamba': 'damba',
    'mendambakan': 'damba',
    'mendambakannya': 'damba',
    'pendamba': 'damba',
    'pendambaan': 'damba',
    'berdambin': 'dambin',
    'mendamik': 'damik',
    'mendampak': 'dampak',
    'mendampakkan': 'dampak',
    'mendampakan': 'dampak',
    'berdampak': 'dampak',
    'berdampaknya': 'dampak',
    'berdampakan': 'dampak',
    'mendampar': 'dampar',
    'mendamparkan': 'dampar',
    'mendamparkannya': 'dampar',
    'terdampar': 'dampar',
    'terdamparnya': 'dampar',
    'keterdamparan': 'dampar',
    'berdampil': 'dampil',
    'mendampilkan': 'dampil',
    'dampratan': 'damprat',
    'dampratannya': 'damprat',
    'mendamprat': 'damprat',
    'mendampratnya': 'damprat',
    'berdampung-dampung': 'dampung',
    'pendana': 'dana',
    'pendananya': 'dana',
    'pendanaan': 'dana',
    'mendanai': 'dana',
    'mendanainya': 'dana',
    'pendanaannya': 'dana',
    'mendanau': 'danau',
    'pendangdut': 'dangdut',
    'berdangdut': 'dangdut',
    'mendangir': 'dangir',
    'berdangka': 'dangka',
    'terdangka-dangka': 'dangka',
    'dangkalan': 'dangkal',
    'kedangkalan': 'dangkal',
    'kedangkalannya': 'dangkal',
    'pendangkalan': 'dangkal',
    'pendangkalannya': 'dangkal',
    'pendangkalanan': 'dangkal',
    'mendangkalkan': 'dangkal',
    'mendangkar': 'dangkar',
    'berdangkung': 'dangkung',
    'mendangkung': 'dangkung',
    'mendanguk': 'danguk',
    'berdanguk': 'danguk',
    'terdanguk': 'danguk',
    'berdansanak': 'dansanak',
    'sedapat': 'dapat',
    'sedapatnya': 'dapat',
    'dapatan': 'dapat',
    'terdapat': 'dapat',
    'terdapatnya': 'dapat',
    'terdapatlah': 'dapat',
    'terdapati': 'dapat',
    'berdapat': 'dapat',
    'berdapatan': 'dapat',
    'mendapat': 'dapat',
    'mendapatnya': 'dapat',
    'mendapatkan': 'dapat',
    'mendapatkannya': 'dapat',
    'mendapati': 'dapat',
    'mendapatan': 'dapat',
    'pendapat': 'dapat',
    'pendapatnya': 'dapat',
    'pendapatlah': 'dapat',
    'pendapatkan': 'dapat',
    'pendapatkannya': 'dapat',
    'pendapatan': 'dapat',
    'pendapatku': 'dapat',
    'pendapatmu': 'dapat',
    'mendapatinya': 'dapat',
    'mendapatikan': 'dapat',
    'mendapatiku': 'dapat',
    'kedapatan': 'dapat',
    'kedapatannya': 'dapat',
    'kedapatanlah': 'dapat',
    'kedapatanan': 'dapat',
    'pendapatannya': 'dapat',
    'pendapatanan': 'dapat',
    'pendapatanmu': 'dapat',
    'mendapatkankan': 'dapat',
    'mendapatkanan': 'dapat',
    'mendapatkanku': 'dapat',
    'memperdapat': 'dapat',
    'sedapat-dapatnya': 'dapat',
    'perdaraan': 'dara',
    'mendarab': 'darab',
    'berdarah': 'darah',
    'berdarahnya': 'darah',
    'pendarah': 'darah',
    'pendarahan': 'darah',
    'mendarah': 'darah',
    'mendarahi': 'darah',
    'mendarahan': 'darah',
    'perdarahan': 'darah',
    'perdarahannya': 'darah',
    'pendarahannya': 'darah',
    'mendaras': 'daras',
    'mendaraskan': 'daras',
    'pendarasan': 'daras',
    'daratan': 'darat',
    'daratannya': 'darat',
    'pendarat': 'darat',
    'pendaratnya': 'darat',
    'pendaratan': 'darat',
    'mendarat': 'darat',
    'mendaratnya': 'darat',
    'mendaratlah': 'darat',
    'mendaratkan': 'darat',
    'mendaratkannya': 'darat',
    'mendarati': 'darat',
    'mendaratan': 'darat',
    'pendaratannya': 'darat',
    'pendaratanmu': 'darat',
    'sedari': 'dari',
    'mendarmabaktikan': 'darmabakti',
    'berdarmawisata': 'darmawisata',
    'sedarun': 'darun',
    'mendaruratkan': 'darurat',
    'berdasi': 'dasi',
    'mendasun': 'dasun',
    'mendata': 'data',
    'mendatanya': 'data',
    'mendatakan': 'data',
    'mendatakannya': 'data',
    'mendataan': 'data',
    'pendataan': 'data',
    'pendataannya': 'data',
    'pendatang': 'datang',
    'pendatangnya': 'datang',
    'pendatangan': 'datang',
    'berdatang': 'datang',
    'berdatangnya': 'datang',
    'berdatangkan': 'datang',
    'berdatangan': 'datang',
    'mendatang': 'datang',
    'mendatangnya': 'datang',
    'mendatanglah': 'datang',
    'mendatangkan': 'datang',
    'mendatangkannya': 'datang',
    'mendatangi': 'datang',
    'mendatangan': 'datang',
    'mendatanginya': 'datang',
    'mendatangiku': 'datang',
    'mendatangimu': 'datang',
    'kedatangan': 'datang',
    'kedatangannya': 'datang',
    'kedatangani': 'datang',
    'kedatanganan': 'datang',
    'kedatanganku': 'datang',
    'kedatanganmu': 'datang',
    'pendatangannya': 'datang',
    'pendatanganan': 'datang',
    'berdatangannya': 'datang',
    'berdatanganlah': 'datang',
    'berdatanganan': 'datang',
    'mendatangkankan': 'datang',
    'mendatangkanku': 'datang',
    'mendatangkanmu': 'datang',
    'datang-datang': 'datang',
    'berdatang sembah': 'datang',
    'datang-mendatangi': 'datang',
    'sedatar': 'datar',
    'dataran': 'datar',
    'datarannya': 'datar',
    'mendatar': 'datar',
    'mendatarnya': 'datar',
    'mendatarkan': 'datar',
    'pendataran': 'datar',
    'pendatarannya': 'datar',
    'kedatuan': 'datu',
    'berdatuk': 'datuk',
    'mendaur ulang': 'daur ulang',
    'pendaurulangan': 'daur ulang',
    'berdawai': 'dawai',
    'berdawat': 'dawat',
    'berdaya guna': 'daya guna',
    'kedayagunaan': 'daya guna',
    'pendayagunaan': 'daya guna',
    'pendayagunaannya': 'daya guna',
    'mendayagunakan': 'daya guna',
    'mendayagunakannya': 'daya guna',
    'berdaya upaya': 'daya upaya',
    'pendayaupayaan': 'daya upaya',
    'pendayang': 'dayang',
    'pendayangan': 'dayang',
    'perdayangan': 'dayang',
    'dayang-dayang': 'dayang',
    'dayang-dayangnya': 'dayang',
    'mendayu': 'dayu',
    'terdayuh': 'dayuh',
    'terdayuk': 'dayuk',
    'mendayus': 'dayus',
    'mendebah': 'debah',
    'debak-debuk': 'debak',
    'berdebat': 'debat',
    'berdebatnya': 'debat',
    'berdebatlah': 'debat',
    'berdebatan': 'debat',
    'pendebat': 'debat',
    'mendebat': 'debat',
    'mendebatnya': 'debat',
    'mendebatkan': 'debat',
    'mendebatkannya': 'debat',
    'mendebatmu': 'debat',
    'perdebatan': 'debat',
    'perdebatannya': 'debat',
    'perdebatankan': 'debat',
    'memperdebatkan': 'debat',
    'memperdebatkannya': 'debat',
    'mendebik': 'debik',
    'pendebitan': 'debit',
    'mendebitkan': 'debit',
    'berdebum': 'debum',
    'berdebus': 'debus',
    'berdebut': 'debut',
    'berdecak-decak': 'decak',
    'mendecap-decap': 'decap',
    'berdecap-decap': 'decap',
    'berdecup': 'decup',
    'berdecup-decup': 'decup',
    'mendecur': 'decur',
    'berdecut': 'decut',
    'berdecut-decut': 'decut',
    'terdedah': 'dedah',
    'pendedahan': 'dedah',
    'mendedahkan': 'dedah',
    'keterdedahan': 'dedah',
    'berdedai-dedai': 'dedai',
    'berdedak': 'dedak',
    'mendedas': 'dedas',
    'mendedau': 'dedau',
    'mendedel': 'dedel',
    'mendeder': 'deder',
    'mendederkan': 'deder',
    'pendederan': 'deder',
    'mendedes': 'dedes',
    'berdefile': 'defile',
    'pendefinisian': 'definisi',
    'mendefinisikan': 'definisi',
    'mendefinisikannya': 'definisi',
    'mendefinisikanku': 'definisi',
    'deg-degan': 'deg',
    'deg-degannya': 'deg',
    'deg-deganku': 'deg',
    'mendegam': 'degam',
    'berdegam': 'degam',
    'mendegam-degam': 'degam',
    'berdegap': 'degap',
    'degap-degap': 'degap',
    'berdegap-degap': 'degap',
    'berdegar-degar': 'degar',
    'mendegil': 'degil',
    'mendegilkan': 'degil',
    'kedegilan': 'degil',
    'kedegilannya': 'degil',
    'berdeging': 'deging',
    'berdegum': 'degum',
    'mendeham': 'deham',
    'berdeham': 'deham',
    'berdeham-deham': 'deham',
    'berdekah-dekah': 'dekah',
    'berdekak-dekak': 'dekak',
    'berdekam': 'dekam',
    'mendekam': 'dekam',
    'mendekamnya': 'dekam',
    'mendekamkan': 'dekam',
    'dekapan': 'dekap',
    'dekapannya': 'dekap',
    'dekapanku': 'dekap',
    'mendekap': 'dekap',
    'mendekapnya': 'dekap',
    'mendekapkan': 'dekap',
    'mendekapku': 'dekap',
    'berdekap': 'dekap',
    'berdekapan': 'dekap',
    'sedekapan': 'dekap',
    'sependekap': 'dekap',
    'memperdekap': 'dekap',
    'berdekap-dekapan': 'dekap',
    'pendekar': 'dekar',
    'pendekarnya': 'dekar',
    'pendekaran': 'dekar',
    'mendekar': 'dekar',
    'mendekari': 'dekar',
    'mendekat': 'dekat',
    'mendekatnya': 'dekat',
    'mendekatlah': 'dekat',
    'mendekatkan': 'dekat',
    'mendekatkannya': 'dekat',
    'mendekati': 'dekat',
    'mendekatan': 'dekat',
    'berdekat': 'dekat',
    'berdekati': 'dekat',
    'berdekatan': 'dekat',
    'terdekat': 'dekat',
    'terdekatnya': 'dekat',
    'terdekatlah': 'dekat',
    'terdekatan': 'dekat',
    'terdekatku': 'dekat',
    'terdekatmu': 'dekat',
    'kedekatan': 'dekat',
    'kedekatannya': 'dekat',
    'kedekatanku': 'dekat',
    'mendekatinya': 'dekat',
    'mendekatilah': 'dekat',
    'mendekatian': 'dekat',
    'mendekatiku': 'dekat',
    'mendekatimu': 'dekat',
    'berdekatannya': 'dekat',
    'pendekatan': 'dekat',
    'pendekatannya': 'dekat',
    'pendekatanan': 'dekat',
    'pendekatanku': 'dekat',
    'pendekatanmu': 'dekat',
    'dekat-dekat': 'dekat',
    'dekat-dekatlah': 'dekat',
    'dekat-dekatan': 'dekat',
    'memperdekat': 'dekat',
    'memperdekatkan': 'dekat',
    'berdekat-dekat': 'dekat',
    'berdekat-dekatan': 'dekat',
    'mendeklarasikan': 'deklarasi',
    'mendeklarasikannya': 'deklarasi',
    'mendekolonisasi': 'dekolonisasi',
    'pendekorasian': 'dekorasi',
    'mendekretkan': 'dekret',
    'berdeku': 'deku',
    'berdekus': 'dekus',
    'mendekus': 'dekus',
    'berdekut': 'dekut',
    'mendekut': 'dekut',
    'berdelan': 'delan',
    'berdelat-delat': 'delat',
    'pendelegasian': 'delegasi',
    'pendelegasiannya': 'delegasi',
    'mendelegasikan': 'delegasi',
    'mendelegasikannya': 'delegasi',
    'mendelik': 'delik',
    'mendelong': 'delong',
    'mendemah': 'demah',
    'berdembai-dembai': 'dembai',
    'berdembam': 'dembam',
    'berdembun': 'dembun',
    'berdembun-dembun': 'dembun',
    'mendemik': 'demik',
    'sedemikian': 'demikian',
    'sedemikianlah': 'demikian',
    'mendemiliterisasi': 'demiliterisasi',
    'pedemo': 'demo',
    'mendemo': 'demo',
    'mendemonya': 'demo',
    'mendemokan': 'demo',
    'mendemokannya': 'demo',
    'mendemobilisasi': 'demobilisasi',
    'pendemokrasian': 'demokrasi',
    'mendemokrasikan': 'demokrasi',
    'berdempak': 'dempak',
    'berdempang-dempang': 'dempang',
    'berdempet': 'dempet',
    'berdempetan': 'dempet',
    'mendempetkan': 'dempet',
    'berdempet-dempet': 'dempet',
    'berdempet-dempetan': 'dempet',
    'berdempok': 'dempok',
    'terdempok': 'dempok',
    'dempulan': 'dempul',
    'mendempul': 'dempul',
    'berdencing-dencing': 'dencing',
    'dendaan': 'denda',
    'mendenda': 'denda',
    'mendendanya': 'denda',
    'pendendaan': 'denda',
    'pendendam': 'dendam',
    'mendendam': 'dendam',
    'berdendam': 'dendam',
    'mendendami': 'dendam',
    'kedendaman': 'dendam',
    'mendendamkan': 'dendam',
    'berdendam-dendaman': 'dendam',
    'pendendang': 'dendang',
    'berdendang': 'dendang',
    'mendendangkan': 'dendang',
    'mendendangkannya': 'dendang',
    'mendendeng': 'dendeng',
    'berdengap': 'dengap',
    'berdengar': 'dengar',
    'terdengar': 'dengar',
    'terdengarnya': 'dengar',
    'terdengarlah': 'dengar',
    'mendengar': 'dengar',
    'mendengarnya': 'dengar',
    'mendengarkan': 'dengar',
    'mendengarkannya': 'dengar',
    'mendengari': 'dengar',
    'mendengaran': 'dengar',
    'mendengarku': 'dengar',
    'mendengarmu': 'dengar',
    'pendengar': 'dengar',
    'pendengarnya': 'dengar',
    'pendengaran': 'dengar',
    'pendengarku': 'dengar',
    'kedengaran': 'dengar',
    'kedengarannya': 'dengar',
    'pendengarannya': 'dengar',
    'pendengaranlah': 'dengar',
    'pendengaranan': 'dengar',
    'pendengaranku': 'dengar',
    'pendengaranmu': 'dengar',
    'mendengarkankan': 'dengar',
    'mendengarkanku': 'dengar',
    'mendengarkanmu': 'dengar',
    'dengar-dengaran': 'dengar',
    'memperdengarkan': 'dengar',
    'memperdengarkannya': 'dengar',
    'mendengar-dengar': 'dengar',
    'terdengih-dengih': 'dengih',
    'mendenging': 'denging',
    'berdenging': 'denging',
    'berdengkang-dengkang': 'dengkang',
    'mendengki': 'dengki',
    'berdengki': 'dengki',
    'pendengki': 'dengki',
    'pendengkinya': 'dengki',
    'kedengkian': 'dengki',
    'kedengkiannya': 'dengki',
    'kedengkik': 'dengkik',
    'mendengkul': 'dengkul',
    'berdengkung': 'dengkung',
    'mendengkung': 'dengkung',
    'mendengkus': 'dengkus',
    'berdengkus': 'dengkus',
    'mendengu': 'dengu',
    'berdengu': 'dengu',
    'terdenguk': 'denguk',
    'mendenguk': 'denguk',
    'berdengut': 'dengut',
    'mendengut': 'dengut',
    'berdengut-dengut': 'dengut',
    'mendengut-dengut': 'dengut',
    'dentaman': 'dentam',
    'berdentam': 'dentam',
    'berdentang': 'dentang',
    'berdentang-dentang': 'dentang',
    'berdentung': 'dentung',
    'berdentung-dentung': 'dentung',
    'denyitan': 'denyit',
    'berdenyit': 'denyit',
    'denyutan': 'denyut',
    'denyutannya': 'denyut',
    'mendenyut': 'denyut',
    'mendenyutkan': 'denyut',
    'berdenyut': 'denyut',
    'berdenyutnya': 'denyut',
    'berdenyut-denyut': 'denyut',
    'mengedep': 'dep',
    'mengedepkan': 'dep',
    'mengedepan': 'dep',
    'mendepa': 'depa',
    'mendepakan': 'depa',
    'berdepak-depak': 'depak',
    'mendepakkan': 'depak',
    'terdepan': 'depan',
    'terdepannya': 'depan',
    'pengedepanan': 'depan',
    'mengedepankan': 'depan',
    'mengedepankannya': 'depan',
    'mengedepankankan': 'depan',
    'berdepan-depan': 'depan',
    'mendepang': 'depang',
    'mendepangkan': 'depang',
    'mendepolitisasi': 'depolitisasi',
    'mendeponir': 'deponir',
    'mendeponirnya': 'deponir',
    'mendeponirkannya': 'deponir',
    'mendeponiran': 'deponir',
    'mendeportasi': 'deportasi',
    'mendeportasinya': 'deportasi',
    'mendeportasikan': 'deportasi',
    'pendepositoan': 'deposito',
    'mendepositokan': 'deposito',
    'mendepositokannya': 'deposito',
    'mendeprok': 'deprok',
    'mendepun': 'depun',
    'mendera': 'dera',
    'menderanya': 'dera',
    'menderai': 'dera',
    'menderaku': 'dera',
    'deraian': 'derai',
    'berderai': 'derai',
    'menderaikan': 'derai',
    'berderai-derai': 'derai',
    'menderai-deraikan': 'derai',
    'sederajat': 'derajat',
    'sederajatnya': 'derajat',
    'menyederajatkan': 'derajat',
    'derakan': 'derak',
    'berderak': 'derak',
    'berderaknya': 'derak',
    'berderak-derak': 'derak',
    'menderak-derakkan': 'derak',
    'menderang': 'derang',
    'berderang': 'derang',
    'sederap': 'derap',
    'berderap': 'derap',
    'berderaplah': 'derap',
    'menderap': 'derap',
    'menderapkan': 'derap',
    'menderas': 'deras',
    'menderasnya': 'deras',
    'penderas': 'deras',
    'penderasan': 'deras',
    'berderau': 'derau',
    'menderau': 'derau',
    'menderau-derau': 'derau',
    'berderau-derau': 'derau',
    'menderek': 'derek',
    'mendereknya': 'derek',
    'penderekan': 'derek',
    'menderes': 'deres',
    'penderes': 'deres',
    'penderesan': 'deres',
    'berderik': 'derik',
    'berderik-derik': 'derik',
    'berderis': 'deris',
    'menderis': 'deris',
    'menderit': 'derit',
    'berderit': 'derit',
    'deritaan': 'derita',
    'penderita': 'derita',
    'penderitanya': 'derita',
    'penderitaan': 'derita',
    'terderita': 'derita',
    'menderita': 'derita',
    'menderitanya': 'derita',
    'menderitalah': 'derita',
    'menderitakan': 'derita',
    'penderitaannya': 'derita',
    'penderitaanku': 'derita',
    'penderitaanmu': 'derita',
    'bederma': 'derma',
    'penderma': 'derma',
    'pendermanya': 'derma',
    'pendermaan': 'derma',
    'mendermakan': 'derma',
    'mendermakannya': 'derma',
    'kedermawanan': 'dermawan',
    'kedermawanannya': 'dermawan',
    'menderu': 'deru',
    'menderu-deru': 'deru',
    'menderu-derukan': 'deru',
    'berderuk': 'deruk',
    'berderung-derung': 'derung',
    'berderus-derus': 'derus',
    'pedesaan': 'desa',
    'pedesaannya': 'desa',
    'kedesaan': 'desa',
    'perdesaan': 'desa',
    'perdesaannya': 'desa',
    'kedesa-desaan': 'desa',
    'mendesah': 'desah',
    'berdesah': 'desah',
    'mendesain': 'desain',
    'mendesainnya': 'desain',
    'mendesainkan': 'desain',
    'berdesain': 'desain',
    'pendesain': 'desain',
    'pendesainnya': 'desain',
    'pendesainan': 'desain',
    'desakan': 'desak',
    'desakannya': 'desak',
    'desakanan': 'desak',
    'terdesak': 'desak',
    'terdesaknya': 'desak',
    'berdesak': 'desak',
    'berdesakkan': 'desak',
    'berdesakkannya': 'desak',
    'berdesakan': 'desak',
    'mendesak': 'desak',
    'mendesaknya': 'desak',
    'mendesaklah': 'desak',
    'mendesakkan': 'desak',
    'mendesakkannya': 'desak',
    'mendesakan': 'desak',
    'mendesakku': 'desak',
    'pendesakan': 'desak',
    'berdesak-desakan': 'desak',
    'berdesak-desakannya': 'desak',
    'mendesar': 'desar',
    'berdesar': 'desar',
    'berdesarkan': 'desar',
    'mendesas-desuskan': 'desas-desus',
    'mendesau': 'desau',
    'berdesau': 'desau',
    'berdesik-desik': 'desik',
    'mendesis': 'desis',
    'mendesiskan': 'desis',
    'mendeskripsikan': 'deskripsi',
    'mendeskripsikannya': 'deskripsi',
    'mendestabilisasi': 'destabilisasi',
    'mendestabilisasikan': 'destabilisasi',
    'berdesus': 'desus',
    'mendesuskan': 'desus',
    'berdesus-desus': 'desus',
    'mendesus-desus': 'desus',
    'mendesut': 'desut',
    'mendetail': 'detail',
    'mendetailnya': 'detail',
    'mendetailkan': 'detail',
    'mendetailkannya': 'detail',
    'mendetailan': 'detail',
    'mendetak': 'detak',
    'mendetakkan': 'detak',
    'berdetak': 'detak',
    'berdetaknya': 'detak',
    'mendetap-detap': 'detap',
    'mendetar': 'detar',
    'berdetar': 'detar',
    'berdetas': 'detas',
    'mendetasir': 'detasir',
    'mendeteksi': 'deteksi',
    'mendeteksinya': 'deteksi',
    'terdeteksi': 'deteksi',
    'terdeteksinya': 'deteksi',
    'terdeteksilah': 'deteksi',
    'pendeteksian': 'deteksi',
    'pendeteksiannya': 'deteksi',
    'berdetus': 'detus',
    'mendevaluasi': 'devaluasi',
    'mendevaluasikan': 'devaluasi',
    'pendevaluasian': 'devaluasi',
    'kedewaan': 'dewa',
    'pendewaan': 'dewa',
    'memperdewa': 'dewa',
    'mendewakan': 'dewa',
    'mendewakannya': 'dewa',
    'memperdewakan': 'dewa',
    'mendewa-dewakan': 'dewa',
    'kedewasaan': 'dewasa',
    'kedewasaannya': 'dewasa',
    'kedewasaanku': 'dewasa',
    'pendewasaan': 'dewasa',
    'pendewasaannya': 'dewasa',
    'mendewasakan': 'dewasa',
    'mendewasakannya': 'dewasa',
    'mendewasakanku': 'dewasa',
    'kedewataan': 'dewata',
    'mendewatakan': 'dewata',
    'mendiakan': 'dia',
    'mendiagnosis': 'diagnosis',
    'mendiagnosisnya': 'diagnosis',
    'mendiagnosisi': 'diagnosis',
    'berdialog': 'dialog',
    'berdialognya': 'dialog',
    'berdialoglah': 'dialog',
    'mendiani': 'dian',
    'memperdiarkan': 'diar',
    'mendiatkan': 'diat',
    'mendidih': 'didih',
    'mendidihnya': 'didih',
    'mendidihlah': 'didih',
    'mendidihkan': 'didih',
    'mendidihkannya': 'didih',
    'didikan': 'didik',
    'didikannya': 'didik',
    'mendidik': 'didik',
    'mendidiknya': 'didik',
    'mendidiki': 'didik',
    'mendidikan': 'didik',
    'mendidikmu': 'didik',
    'pendidik': 'didik',
    'pendidiknya': 'didik',
    'pendidiklah': 'didik',
    'pendidikkan': 'didik',
    'pendidikan': 'didik',
    'pendidikmu': 'didik',
    'mendidis': 'didis',
    'kedigdayaan': 'digdaya',
    'kedigdayaannya': 'digdaya',
    'pendigulan': 'digul',
    'mendigulkan': 'digul',
    'berdikit-dikit': 'dikit',
    'sedikit-dikitnya': 'sedikit',
    'berdiksa': 'diksa',
    'kediktatoran': 'diktator',
    'kediktatorannya': 'diktator',
    'mendikte': 'dikte',
    'mendiktenya': 'dikte',
    'mendiktekan': 'dikte',
    'mendiktekannya': 'dikte',
    'mendilak': 'dilak',
    'makanan': 'makan',
    'makanannya': 'makan',
    'makananlah': 'makan',
    'makananan': 'makan',
    'makananku': 'makan',
    'makananmu': 'makan',
    'memakan': 'makan',
    'memakannya': 'makan',
    'memakankan': 'makan',
    'memakani': 'makan',
    'memakanan': 'makan',
    'memakanmu': 'makan',
    'dimakan': 'makan',
    'dimakannya': 'makan',
    'dimakanlah': 'makan',
    'dimakankan': 'makan',
    'dimakani': 'makan',
    'dimakanan': 'makan',
    'pemakan': 'makan',
    'pemakannya': 'makan',
    'pemakanan': 'makan',
    'termakan': 'makan',
    'termakannya': 'makan',
    'sepemakan': 'makan',
    'makan-makan': 'makan',
    'makan-makannya': 'makan',
    'makan-makanlah': 'makan',
    'makan-makanan': 'makan',
    'makan-makanannya': 'makan',
    'pendinamis': 'dinamis',
    'kedinamisan': 'dinamis',
    'mendinamiskan': 'dinamis',
    'mendinamit': 'dinamit',
    'mendinamitnya': 'dinamit',
    'pendinamitan': 'dinamit',
    'berdinas': 'dinas',
    'kedinasan': 'dinas',
    'kedinasannya': 'dinas',
    'mendinaskan': 'dinas',
    'berdinding': 'dinding',
    'berdindingkan': 'dinding',
    'pendinding': 'dinding',
    'terdinding': 'dinding',
    'mendinding': 'dinding',
    'mendindingi': 'dinding',
    'pendindingan': 'dinding',
    'mendingin': 'dingin',
    'mendinginnya': 'dingin',
    'mendinginkan': 'dingin',
    'mendinginkannya': 'dingin',
    'pendingin': 'dingin',
    'pendinginnya': 'dingin',
    'pendinginan': 'dingin',
    'kedinginan': 'dingin',
    'kedinginannya': 'dingin',
    'pendinginannya': 'dingin',
    'berdingkit-dingkit': 'dingkit',
    'sedini-dininya': 'dini',
    'pemanggang': 'panggang',
    'pemanggangnya': 'panggang',
    'pemanggangan': 'panggang',
    'panggangan': 'panggang',
    'panggangannya': 'panggang',
    'memanggang': 'panggang',
    'memanggangnya': 'panggang',
    'dipanggang': 'panggang',
    'dipanggangnya': 'panggang',
    'pemanggangannya': 'panggang',
    'berdiplomasi': 'diplomasi',
    'berdiplomasinya': 'diplomasi',
    'kedirgantaraan': 'dirgantara',
    'kedirgantaraannya': 'dirgantara',
    'mendiris': 'diris',
    'pendiris': 'diris',
    'mendirus': 'dirus',
    'pendirusan': 'dirus',
    'mendiruskan': 'dirus',
    'pendisko': 'disko',
    'mendiskreditkan': 'diskredit',
    'mendiskreditkannya': 'diskredit',
    'mendiskriminasi': 'diskriminasi',
    'mendiskriminasinya': 'diskriminasi',
    'mendiskriminasikan': 'diskriminasi',
    'mendiskriminasikannya': 'diskriminasi',
    'mendiskualifikasikan': 'diskualifikasi',
    'berdiskusi': 'diskusi',
    'berdiskusinya': 'diskusi',
    'berdiskusilah': 'diskusi',
    'berdiskusikan': 'diskusi',
    'mendiskusikan': 'diskusi',
    'mendiskusikannya': 'diskusi',
    'mendistribusi': 'distribusi',
    'mendistribusinya': 'distribusi',
    'mendistribusikan': 'distribusi',
    'mendistribusikannya': 'distribusi',
    'mendistribusian': 'distribusi',
    'terdistribusi': 'distribusi',
    'terdistribusinya': 'distribusi',
    'terdistribusilah': 'distribusi',
    'terdistribusikan': 'distribusi',
    'terdistribusikannya': 'distribusi',
    'pendistribusian': 'distribusi',
    'pendistribusiannya': 'distribusi',
    'penanam': 'tanam',
    'penanamnya': 'tanam',
    'penanamkan': 'tanam',
    'penanaman': 'tanam',
    'menanam': 'tanam',
    'menanamnya': 'tanam',
    'menanamlah': 'tanam',
    'menanamkan': 'tanam',
    'menanamkannya': 'tanam',
    'menanami': 'tanam',
    'menanaman': 'tanam',
    'tanaman': 'tanam',
    'tanamannya': 'tanam',
    'tanamanan': 'tanam',
    'tanamanku': 'tanam',
    'ditanam': 'tanam',
    'ditanamnya': 'tanam',
    'ditanamlah': 'tanam',
    'ditanamkan': 'tanam',
    'ditanamkannya': 'tanam',
    'ditanami': 'tanam',
    'ditanaman': 'tanam',
    'tertanam': 'tanam',
    'tertanamnya': 'tanam',
    'tertanamlah': 'tanam',
    'tertanamkan': 'tanam',
    'tertanami': 'tanam',
    'menanaminya': 'tanam',
    'bertanam': 'tanam',
    'bertanamnya': 'tanam',
    'bertanaman': 'tanam',
    'penanamannya': 'tanam',
    'penanamanan': 'tanam',
    'menanamkankan': 'tanam',
    'pertanaman': 'tanam',
    'tanam-menanam': 'tanam',
    'tanam-menanamnya': 'tanam',
    'tanam-tanaman': 'tanam',
    'mendiversifikasi': 'diversifikasi',
    'mendiversifikasinya': 'diversifikasi',
    'mendiversifikasikan': 'diversifikasi',
    'mendiversifikasikannya': 'diversifikasi',
    'pendiversifikasian': 'diversifikasi',
    'mendobrak': 'dobrak',
    'mendobraknya': 'dobrak',
    'mendobrakkan': 'dobrak',
    'pendobrak': 'dobrak',
    'pendobraknya': 'dobrak',
    'pendobrakkan': 'dobrak',
    'pendobrakan': 'dobrak',
    'mendodet': 'dodet',
    'terdodong': 'dodong',
    'kedodoran': 'dodor',
    'kedodorannya': 'dodor',
    'mendodos': 'dodos',
    'berdogol': 'dogol',
    'kedogolan': 'dogol',
    'terdohok': 'dohok',
    'berdokar': 'dokar',
    'kedokteran': 'dokter',
    'kedokterannya': 'dokter',
    'kedokteranlah': 'dokter',
    'kedokteranan': 'dokter',
    'pendokumentasian': 'dokumentasi',
    'pendokumentasiannya': 'dokumentasi',
    'mendokumentasikan': 'dokumentasi',
    'mendokumentasikannya': 'dokumentasi',
    'dolanan': 'dolan',
    'pendolaran': 'dolar',
    'mendolarkan': 'dolar',
    'mendominasi': 'dominasi',
    'mendominasinya': 'dominasi',
    'mendominasikan': 'dominasi',
    'berdomisili': 'domisili',
    'berdomisilinya': 'domisili',
    'mendompak': 'dompak',
    'berdompak': 'dompak',
    'domplangan': 'domplang',
    'domplengan': 'dompleng',
    'pendompleng': 'dompleng',
    'pendomplengan': 'dompleng',
    'mendompleng': 'dompleng',
    'mendomplengnya': 'dompleng',
    'mendomplengkan': 'dompleng',
    'mendomplengi': 'dompleng',
    'pendomplengannya': 'dompleng',
    'sedompol': 'dompol',
    'dompolan': 'dompol',
    'berdompol': 'dompol',
    'mendoncang': 'doncang',
    'dondangan': 'dondang',
    'mendondangkan': 'dondang',
    'mendonder': 'donder',
    'sedondon': 'dondon',
    'mendondon': 'dondon',
    'mendongak': 'dongak',
    'mendongakkan': 'dongak',
    'mendongakkannya': 'dongak',
    'dongengan': 'dongeng',
    'mendongeng': 'dongeng',
    'mendongengnya': 'dongeng',
    'mendongengkan': 'dongeng',
    'mendongengi': 'dongeng',
    'pendongeng': 'dongeng',
    'pendongengnya': 'dongeng',
    'mendongkak': 'dongkak',
    'mendongkakkan': 'dongkak',
    'dongkelan': 'dongkel',
    'mendongkel': 'dongkel',
    'mendongkelnya': 'dongkel',
    'pendongkok': 'dongkok',
    'pendongkol': 'dongkol',
    'mendongkol': 'dongkol',
    'mendongkolkan': 'dongkol',
    'mendongkrak': 'dongkrak',
    'mendongkraknya': 'dongkrak',
    'mendongkrakkan': 'dongkrak',
    'mendongkrakan': 'dongkrak',
    'pendongkrak': 'dongkrak',
    'pendongkraknya': 'dongkrak',
    'pendongkrakan': 'dongkrak',
    'terdongkrak': 'dongkrak',
    'terdongkraknya': 'dongkrak',
    'mendongsok': 'dongsok',
    'mengedor': 'dor',
    'dor-doran': 'dor',
    'mendornai': 'dorna',
    'dorongan': 'dorong',
    'dorongannya': 'dorong',
    'terdorong': 'dorong',
    'terdorongnya': 'dorong',
    'mendorong': 'dorong',
    'mendorongnya': 'dorong',
    'mendoronglah': 'dorong',
    'mendorongkan': 'dorong',
    'mendorongan': 'dorong',
    'mendorongku': 'dorong',
    'mendorongmu': 'dorong',
    'pendorong': 'dorong',
    'pendorongnya': 'dorong',
    'pendorongan': 'dorong',
    'pendorongmu': 'dorong',
    'mendosir': 'dosir',
    'berdosis': 'dosis',
    'berdosisi': 'dosis',
    'mengedot': 'dot',
    'kedoyanan': 'doyan',
    'pendramaan': 'drama',
    'mengedrel': 'drel',
    'pengedrelan': 'drel',
    'mendribel': 'dribel',
    'mendribelnya': 'dribel',
    'mengedril': 'dril',
    'mengedrop': 'drop',
    'pengedropan': 'drop',
    'sedua': 'dua',
    'seduanya': 'dua',
    'seduai': 'dua',
    'kedua': 'dua',
    'keduanya': 'dua',
    'kedualah': 'dua',
    'keduaan': 'dua',
    'keduanyalah': 'dua',
    'keduaku': 'dua',
    'keduamu': 'dua',
    'kedua-ku': 'dua',
    'mendua': 'dua',
    'menduanya': 'dua',
    'menduakan': 'dua',
    'menduakannya': 'dua',
    'pendua': 'dua',
    'perdua': 'dua',
    'perduaan': 'dua',
    'berdua': 'dua',
    'berduanya': 'dua',
    'berdualah': 'dua',
    'berduakan': 'dua',
    'berduaan': 'dua',
    'dua-dua': 'dua',
    'dua-duanya': 'dua',
    'dua-duaan': 'dua',
    'dua-duanyalah': 'dua',
    'menduai': 'dua',
    'seperdua': 'dua',
    'penduaan': 'dua',
    'berduaannya': 'dua',
    'menyedua': 'dua',
    'menyeduakan': 'dua',
    'memperdua': 'dua',
    'menyeduai': 'dua',
    'berdua-dua': 'dua',
    'berdua-duanya': 'dua',
    'berdua-duaan': 'dua',
    'memperduai': 'dua',
    'dua-duanyanya': 'dua',
    'memperduakan': 'dua',
    'mengedub': 'dub',
    'pengeduban': 'dub',
    'mendubeskan': 'dubes',
    'dubilah': 'dubila',
    'mendublir': 'dublir',
    'mendudu': 'dudu',
    'mendudukan': 'dudu',
    'mendudukannya': 'dudu',
    'mendudui': 'dudu',
    'menduduku': 'dudu',
    'mendudu-dudu': 'dudu',
    'penduduk': 'duduk',
    'penduduknya': 'duduk',
    'pendudukkan': 'duduk',
    'penduduki': 'duduk',
    'pendudukan': 'duduk',
    'pendudukmu': 'duduk',
    'terduduk': 'duduk',
    'terduduki': 'duduk',
    'kedudukan': 'duduk',
    'kedudukannya': 'duduk',
    'kedudukanku': 'duduk',
    'kedudukanmu': 'duduk',
    'menduduki': 'duduk',
    'mendudukinya': 'duduk',
    'pendudukannya': 'duduk',
    'duduk-duduk': 'duduk',
    'duduk-duduknya': 'duduk',
    'duduk-dudukan': 'duduk',
    'mendudukkan': 'duduk',
    'mendudukkannya': 'duduk',
    'sekedudukan': 'duduk',
    'berkedudukan': 'duduk',
    'mendudur': 'dudur',
    'berduel': 'duel',
    'berduet': 'duet',
    'berduetnya': 'duet',
    'dugaan': 'duga',
    'dugaannya': 'duga',
    'dugaanku': 'duga',
    'penduga': 'duga',
    'pendugaan': 'duga',
    'menduga': 'duga',
    'menduganya': 'duga',
    'mendugalah': 'duga',
    'mendugakan': 'duga',
    'mendugaan': 'duga',
    'terduga': 'duga',
    'terduganya': 'duga',
    'terduga-duga': 'duga',
    'menduga-duga': 'duga',
    'menduga-duganya': 'duga',
    'mendugalkan': 'dugal',
    'mendugang': 'dugang',
    'mendugas': 'dugas',
    'berduka': 'duka',
    'berdukanya': 'duka',
    'kedukaan': 'duka',
    'kedukaannya': 'duka',
    'mendukai': 'duka',
    'mendukakan': 'duka',
    'pedukuhan': 'dukuh',
    'berdukun': 'dukun',
    'perdukunan': 'dukun',
    'perdukunannya': 'dukun',
    'pendukunan': 'dukun',
    'mendukunkan': 'dukun',
    'dukungan': 'dukung',
    'dukungannya': 'dukung',
    'dukunganlah': 'dukung',
    'dukunganan': 'dukung',
    'dukunganku': 'dukung',
    'dukunganmu': 'dukung',
    'mendukung': 'dukung',
    'mendukungnya': 'dukung',
    'mendukunglah': 'dukung',
    'mendukungi': 'dukung',
    'mendukungan': 'dukung',
    'mendukungku': 'dukung',
    'mendukungmu': 'dukung',
    'berdukung': 'dukung',
    'pendukung': 'dukung',
    'pendukungnya': 'dukung',
    'pendukungkan': 'dukung',
    'pendukungan': 'dukung',
    'pendukungku': 'dukung',
    'pendukungmu': 'dukung',
    'pendukungannya': 'dukung',
    'mendulag': 'dulag',
    'pendulang': 'dulang',
    'pendulangan': 'dulang',
    'mendulang': 'dulang',
    'dulang-dulang': 'dulang',
    'dulang-dulangan': 'dulang',
    'berduli': 'duli',
    'mengedumkan': 'dum',
    'mendungas': 'dungas',
    'kedunguan': 'dungu',
    'kedunguannya': 'dungu',
    'kedunguanku': 'dungu',
    'sedunia': 'dunia',
    'mendunia': 'dunia',
    'mendunianya': 'dunia',
    'menduniakan': 'dunia',
    'keduniaan': 'dunia',
    'keduniaannya': 'dunia',
    'keduniawian': 'duniawi',
    'keduniawiannya': 'duniawi',
    'mengedup': 'dup',
    'pedupaan': 'dupa',
    'mendupai': 'dupa',
    'mendupak': 'dupak',
    'berdurasi': 'durasi',
    'berdurasikan': 'durasi',
    'pendurhaka': 'durhaka',
    'pendurhakaan': 'durhaka',
    'berdurhaka': 'durhaka',
    'mendurhaka': 'durhaka',
    'mendurhakakan': 'durhaka',
    'mendurhakai': 'durhaka',
    'kedurjanaan': 'durjana',
    'berduru': 'duru',
    'berduru-duru': 'duru',
    'mendusin': 'dusin',
    'pedusunan': 'dusun',
    'kedutaan': 'duta',
    'kedutaannya': 'duta',
    'berduyun-duyun': 'duyun',
    'berduyun-duyunnya': 'duyun',
    'kedwiartian': 'dwiarti',
    'kedwibahasaan': 'dwibahasa',
    'berdwifungsi': 'dwifungsi',
    'mendwigandakan': 'dwiganda',
    'dwimingguan': 'dwiminggu',
    'kedwimukaan': 'dwimuka',
    'dwiperanan': 'dwiperan',
    'dieban': 'eban',
    'mengeban': 'eban',
    'ecek-ecek': 'ecek',
    'ecek-eceknya': 'ecek',
    'eceran': 'ecer',
    'ecerannya': 'ecer',
    'mengecer': 'ecer',
    'mengecernya': 'ecer',
    'mengecerkan': 'ecer',
    'pengecer': 'ecer',
    'pengecernya': 'ecer',
    'pengeceran': 'ecer',
    'keedanan': 'edan',
    'edan-edanan': 'edan',
    'edaran': 'edar',
    'edarannya': 'edar',
    'beredar': 'edar',
    'beredarnya': 'edar',
    'beredarlah': 'edar',
    'beredarkan': 'edar',
    'beredari': 'edar',
    'beredaran': 'edar',
    'mengedar': 'edar',
    'mengedarnya': 'edar',
    'mengedarkan': 'edar',
    'mengedarkannya': 'edar',
    'mengedari': 'edar',
    'pengedar': 'edar',
    'pengedarnya': 'edar',
    'pengedaran': 'edar',
    'peredaran': 'edar',
    'peredarannya': 'edar',
    'peredaranan': 'edar',
    'mengedarinya': 'edar',
    'mengedarian': 'edar',
    'memperedarkan': 'edar',
    'pengedit': 'edit',
    'pengeditan': 'edit',
    'mengedit': 'edit',
    'mengeditnya': 'edit',
    'mengeditkan': 'edit',
    'pengeditannya': 'edit',
    'keefektifan': 'efektif',
    'keefektifannya': 'efektif',
    'mengefektifkan': 'efektif',
    'mengefisienkan': 'efisien',
    'mengegah': 'egah',
    'mengegatkan': 'egat',
    'mengegol': 'egol',
    'mengegolkan': 'gol',
    'mengegos': 'egos',
    'mengegosi': 'egos',
    'mengegoskan': 'egos',
    'keegosentrisan': 'egosentris',
    'ejaan': 'eja',
    'ejaannya': 'eja',
    'mengeja': 'eja',
    'mengejanya': 'eja',
    'mengejakan': 'eja',
    'mengejakannya': 'eja',
    'pengejaan': 'eja',
    'pengejaannya': 'eja',
    'mengejan': 'kejan',
    'mengejan-ejan': 'ejan',
    'mengejawantah': 'ejawantah',
    'mengejawantahkan': 'ejawantah',
    'mengejawantahkannya': 'ejawantah',
    'pengejawantahan': 'ejawantah',
    'pengejawantahannya': 'ejawantah',
    'ejekan': 'ejek',
    'ejekannya': 'ejek',
    'mengejek': 'ejek',
    'mengejeknya': 'ejek',
    'mengejeklah': 'ejek',
    'mengejekku': 'ejek',
    'mengejekmu': 'ejek',
    'keekabahasaan': 'ekabahasa',
    'terekeh-ekeh': 'ekeh',
    'berekonomi': 'ekonomi',
    'berekonomian': 'ekonomi',
    'keekonomian': 'ekonomi',
    'keekonomiannya': 'ekonomi',
    'perekonomian': 'ekonomi',
    'perekonomiannya': 'ekonomi',
    'keekonomisan': 'ekonomis',
    'keekonomisannya': 'ekonomis',
    'berekor': 'ekor',
    'mengekor': 'ekor',
    'mengekornya': 'ekor',
    'mengekori': 'ekor',
    'pengekor': 'ekor',
    'pengekornya': 'ekor',
    'mengeksamen': 'eksamen',
    'keeksentrikan': 'eksentrik',
    'keeksentrikannya': 'eksentrik',
    'mengeksklusifkan': 'eksklusif',
    'mengeksklusifkannya': 'eksklusif',
    'berekskursi': 'ekskursi',
    'keeksotisan': 'eksotis',
    'keeksotisannya': 'eksotis',
    'berekspansi': 'ekspansi',
    'mengeksploitasi': 'eksploitasi',
    'mengeksploitasinya': 'eksploitasi',
    'mengeksploitasikan': 'eksploitasi',
    'pengeksploitasi': 'eksploitasi',
    'pengeksploitasian': 'eksploitasi',
    'mengeksplorasi': 'eksplorasi',
    'mengeksplorasinya': 'eksplorasi',
    'mengeksplorasikan': 'eksplorasi',
    'mengeksplorasikannya': 'eksplorasi',
    'pengekspor': 'ekspor',
    'pengekspornya': 'ekspor',
    'pengeksporan': 'ekspor',
    'mengekspor': 'ekspor',
    'mengekspornya': 'ekspor',
    'mengeksporkan': 'ekspor',
    'terekspos': 'ekspos',
    'tereksposnya': 'ekspos',
    'mengekspos': 'ekspos',
    'mengeksposnya': 'ekspos',
    'mengeksposmu': 'ekspos',
    'pengeksposan': 'ekspos',
    'mengekspresikan': 'ekspresi',
    'mengekspresikannya': 'ekspresi',
    'mengekstrak': 'ekstrak',
    'mengekstraknya': 'ekstrak',
    'mengekstraksi': 'ekstraksi',
    'mengekstraksinya': 'ekstraksi',
    'pengekstraksi': 'ekstraksi',
    'keekstreman': 'ekstrem',
    'mengelaborasi': 'elaborasi',
    'mengelaborasinya': 'elaborasi',
    'mengelaborasikan': 'elaborasi',
    'mengelaborasikannya': 'elaborasi',
    'mengelak': 'lak',
    'mengelaknya': 'lak',
    'mengelakkan': 'lak',
    'mengelakkannya': 'lak',
    'mengelaki': 'lak',
    'mengelakan': 'lak',
    'pengelakan': 'elak',
    'terelakkan': 'elak',
    'terelakkannya': 'elak',
    'keelastikan': 'elastik',
    'keelastisan': 'elastis',
    'keelastisannya': 'elastis',
    'keeleganan': 'elegan',
    'keeleganannya': 'elegan',
    'mengelektrifikasi': 'elektrifikasi',
    'mengeliminasi': 'eliminasi',
    'mengeliminasinya': 'eliminasi',
    'mengelite': 'elite',
    'seelok': 'elok',
    'keelokan': 'elok',
    'keelokannya': 'elok',
    'memperelok': 'elok',
    'mempereloknya': 'elok',
    'seelok-eloknya': 'elok',
    'mengelon': 'elon',
    'mengeloni': 'kelon',
    'mengelukan': 'elu',
    'mengelukannya': 'elu',
    'mengelu-elukan': 'elu',
    'mengelu-elukannya': 'elu',
    'elusan': 'elus',
    'mengelus': 'elus',
    'mengelusnya': 'elus',
    'mengeluskan': 'elus',
    'mengelus-elus': 'elus',
    'mengelus-elusnya': 'elus',
    'beremas': 'emas',
    'keemasan': 'emas',
    'keemasannya': 'emas',
    'peremasan': 'emas',
    'mengemat': 'emat',
    'mengemban': 'emban',
    'mengembannya': 'emban',
    'mengembankan': 'emban',
    'embaran': 'embar',
    'pengembara': 'embara',
    'pengembaraan': 'embara',
    'mengembara': 'embara',
    'mengembaranya': 'embara',
    'mengembarai': 'embara',
    'pengembaraannya': 'embara',
    'pengembaraanku': 'embara',
    'mengembargo': 'embargo',
    'mengembat': 'embat',
    'mengembatkan': 'embat',
    'mengembik': 'embik',
    'mengembol': 'kembol',
    'embuh-embuhan': 'embuh',
    'embusan': 'embus',
    'embusannya': 'embus',
    'berembus': 'embus',
    'berembusnya': 'embus',
    'pengembus': 'embus',
    'mengembus': 'embus',
    'mengembuskan': 'embus',
    'mengembuskannya': 'embus',
    'mengembut': 'embut',
    'terembut-embut': 'embut',
    'mengembut-embut': 'embut',
    'beremigrasi': 'emigrasi',
    'keemiratan': 'emirat',
    'pengemis': 'emis',
    'pengemisnya': 'emis',
    'pengemisi': 'emis',
    'pengemisan': 'emis',
    'mengemis': 'emis',
    'mengemisnya': 'emis',
    'mengemislah': 'emis',
    'mengemisi': 'emis',
    'mengemohi': 'emoh',
    'mengemol': 'emol',
    'paemong': 'emong',
    'mengemong': 'emong',
    'keemosian': 'emosi',
    'empangan': 'empang',
    'terempang': 'empang',
    'pengempang': 'empang',
    'pengempangan': 'empang',
    'mengempang': 'empang',
    'terempap': 'empap',
    'berempap': 'empap',
    'mengempap': 'empap',
    'mengempapkan': 'empap',
    'mengempar': 'empar',
    'mengemparkan': 'empar',
    'empasan': 'empas',
    'terempas': 'empas',
    'mengempas': 'empas',
    'mengempasnya': 'empas',
    'mengempaskan': 'empas',
    'mengempaskannya': 'empas',
    'terempas-empas': 'empas',
    'mengempas-empaskan': 'empas',
    'perempat': 'empat',
    'perempatnya': 'empat',
    'perempatlah': 'empat',
    'perempati': 'empat',
    'perempatan': 'empat',
    'berempat': 'empat',
    'berempati': 'empat',
    'perempatanan': 'empat',
    'seperempat': 'empat',
    'seperempatnya': 'empat',
    'seperempatan': 'empat',
    'memperempat': 'empat',
    'empat-empat': 'empat',
    'empat-empatnya': 'empat',
    'berempat-empat': 'empat',
    'keempat-empatnya': 'empat',
    'mengempat puluh hari': 'empat',
    'berempatilah': 'empati',
    'empek-empek': 'empek',
    'mengempenak': 'empenak',
    'emperan': 'emper',
    'empet-empetan': 'empet',
    'mengempik': 'empik',
    'mengemping': 'emping',
    'memperemping': 'emping',
    'mengempo': 'empo',
    'mengempoh': 'empoh',
    'keempohan': 'empoh',
    'mengempohi': 'empoh',
    'pengempohan': 'empoh',
    'empok-empok': 'empok',
    'emposan': 'empos',
    'mengempos': 'empos',
    'empot-empotan': 'empot',
    'mengempu': 'empu',
    'mengempukkan': 'empuk',
    'mengempul': 'empul',
    'mengempulkan': 'empul',
    'mengemut': 'kemut',
    'mengemutnya': 'kemut',
    'mengemuti': 'kemut',
    'terenak': 'enak',
    'keenakan': 'enak',
    'keenakannya': 'enak',
    'keenakanlah': 'enak',
    'enak-enak': 'enak',
    'enak-enaknya': 'enak',
    'enak-enakkan': 'enak',
    'enak-enakan': 'enak',
    'seenaknya': 'enak',
    'memperenak': 'enak',
    'mengenakkan': 'enak',
    'mengenakkannya': 'enak',
    'berenak-enak': 'enak',
    'berenam': 'enam',
    'mengenap': 'enap',
    'mengenapkan': 'enap',
    'mengenapi': 'enap',
    'mengenap-enapkan': 'enap',
    'mengenaskan': 'ngenas',
    'mengenaskannya': 'ngenas',
    'encal-encal': 'encal',
    'mengencang': 'encang',
    'mengencangnya': 'encang',
    'mengencangkan': 'kencang',
    'mengencangkannya': 'kencang',
    'berencel-encel': 'encel',
    'enceran': 'encer',
    'pengencer': 'encer',
    'pengenceran': 'encer',
    'pengencerannya': 'encer',
    'mengencerkan': 'encer',
    'mengencerkannya': 'encer',
    'mengendal': 'endal',
    'mengendalkan': 'endal',
    'mengendali': 'endal',
    'endapan': 'endap',
    'endapannya': 'endap',
    'mengendap': 'endap',
    'mengendapnya': 'endap',
    'mengendapkan': 'endap',
    'mengendapkannya': 'endap',
    'terendapkan': 'endap',
    'endap-endap': 'endap',
    'pengendapan': 'endap',
    'pengendapannya': 'endap',
    'mengendap-endap': 'endap',
    'endonan': 'endon',
    'mengendon': 'endon',
    'mengendonkan': 'endon',
    'mengendong': 'kendong',
    'mengendongnya': 'kendong',
    'mengendus': 'endus',
    'mengendusnya': 'endus',
    'mengenduskan': 'endus',
    'mengendusku': 'endus',
    'endut-endut': 'endut',
    'endut-endutan': 'endut',
    'mengenes': 'enes',
    'mengeneskan': 'enes',
    'engah-engah': 'engah',
    'terperengah': 'engah',
    'terengah-engah': 'engah',
    'keengganan': 'enggan',
    'keengganannya': 'enggan',
    'mengenggankan': 'enggan',
    'enggan-enggan': 'enggan',
    'berenggan-enggan': 'enggan',
    'mengengget': 'engget',
    'berenggil': 'enggil',
    'enggokan': 'enggok',
    'engkah-engkah': 'engkah',
    'mengengkang': 'engkang',
    'berengkau': 'engkau',
    'mengenjak': 'enjak',
    'mengenjak-enjak': 'enjak',
    'mengenjal': 'enjal',
    'mengenjut': 'enjut',
    'mengenjutkan': 'enjut',
    'mengenkripsi': 'enkripsi',
    'mengenkripsinya': 'enkripsi',
    'entah-berentah': 'entah',
    'pengentak': 'entak',
    'mengentak': 'entak',
    'mengentakkan': 'entak',
    'mengentak-entak': 'entak',
    'mengentak-entakkan': 'entak',
    'terentas': 'entas',
    'terentaskan': 'entas',
    'terentaskannya': 'entas',
    'mengentas': 'entas',
    'mengentaskan': 'entas',
    'mengentaskannya': 'entas',
    'mengentasi': 'entas',
    'mengentasan': 'entas',
    'pengentasan': 'entas',
    'pengentasannya': 'entas',
    'mengenten': 'enten',
    'enten-enten': 'enten',
    'mengentengkan': 'enteng',
    'mengentit': 'entit',
    'mengentot': 'entot',
    'mengenyahkan': 'enyah',
    'mengenyahkannya': 'enyah',
    'mengenyak': 'enyak',
    'terperenyak': 'perenyak',
    'mengenyakkan': 'enyak',
    'pengepak': 'pak',
    'pengepakkan': 'pak',
    'pengepakan': 'pak',
    'pengepakannya': 'pak',
    'mengeram': 'eram',
    'mengeramkan': 'eram',
    'mengerami': 'eram',
    'pengeram': 'eram',
    'pengeraman': 'eram',
    'mengeraminya': 'eram',
    'pengeramannya': 'eram',
    'erangan': 'erang',
    'erangannya': 'erang',
    'mengerang': 'erang',
    'mengeranglah': 'erang',
    'erang-erot': 'erang',
    'erat-erat': 'erat',
    'mempererat': 'erat',
    'mempereratnya': 'erat',
    'mengeratkan': 'erat',
    'mengeratkannya': 'erat',
    'pengereh': 'ereh',
    'mengereh': 'ereh',
    'berereksi': 'ereksi',
    'terereng': 'ereng',
    'mengereng': 'ereng',
    'ereng-ereng': 'ereng',
    'eretan': 'eret',
    'mengeret': 'eret',
    'pengeret': 'eret',
    'pengeretan': 'eret',
    'mengerik': 'kerik',
    'mengeriknya': 'kerik',
    'mengerikan': 'ngeri',
    'erong-erong': 'erong',
    'erotan': 'erot',
    'bererot': 'rerot',
    'bererotan': 'erot',
    'mengerotkan': 'erot',
    'mengerti': 'erti',
    'mengertinya': 'erti',
    'mengertilah': 'erti',
    'mengertikan': 'erti',
    'mengertii': 'erti',
    'mengertian': 'erti',
    'pengertian': 'erti',
    'pengertiannya': 'erti',
    'pengertianku': 'erti',
    'keesaan': 'esa',
    'mengesakan': 'kesak',
    'beresa-esaan': 'esa',
    'teresak': 'esak',
    'mengesak': 'kesak',
    'teresak-esak': 'esak',
    'beresok': 'esok',
    'keesokan': 'esok',
    'keesokannya': 'esok',
    'mengesokkan': 'esok',
    'mengesot-esot': 'esot',
    'mengetsa': 'etsa',
    'pengetsaan': 'etsa',
    'berevakuasi': 'evakuasi',
    'mengevakuasi': 'evakuasi',
    'mengevakuasinya': 'evakuasi',
    'mengevakuasikan': 'evakuasi',
    'mengevaluasi': 'evaluasi',
    'mengevaluasinya': 'evaluasi',
    'mengevaluasikan': 'evaluasi',
    'keevolusian': 'evolusi',
    'mengeyel': 'eyel',
    'memfaalkan': 'faal',
    'memfadihatkan': 'fadihat',
    'berfaedah': 'faedah',
    'berfaedahnya': 'faedah',
    'kefakiran': 'fakir',
    'kefanaan': 'fana',
    'memfanakan': 'fana',
    'kefanatikan': 'fanatik',
    'kefanatikannya': 'fanatik',
    'memfanatiki': 'fanatik',
    'berfantasi': 'fantasi',
    'berfantasinya': 'fantasi',
    'berfantasilah': 'fantasi',
    'memfantasikan': 'fantasi',
    'kefarmasian': 'farmasi',
    'memfasakh': 'fasakh',
    'kefasihan': 'fasih',
    'kefasihannya': 'fasih',
    'memperfasih': 'fasih',
    'memfasihkan': 'fasih',
    'kefasikan': 'fasik',
    'memfasilitasi': 'fasilitas',
    'memfasilitasinya': 'fasilitas',
    'memfasilitasikan': 'fasilitas',
    'memfasilitasiku': 'fasilitas',
    'berfatwa': 'fatwa',
    'memfatwakan': 'fatwa',
    'kefemininan': 'feminin',
    'kefemininannya': 'feminin',
    'memfestivalkan': 'festival',
    'memfiat': 'fiat',
    'perfilman': 'film',
    'perfilmannya': 'film',
    'memfilmkan': 'film',
    'memfilmkannya': 'film',
    'memfilter': 'filter',
    'memfilternya': 'filter',
    'berfirman': 'firman',
    'difirmankan': 'firman',
    'memfitnah': 'fitnah',
    'memfitnahnya': 'fitnah',
    'memfitnahkan': 'fitnah',
    'berfitrah': 'fitrah',
    'memfitrahkan': 'fitrah',
    'berfluktuasi': 'fluktuasi',
    'berfluktuasinya': 'fluktuasi',
    'terfokus': 'fokus',
    'terfokusnya': 'fokus',
    'terfokuskan': 'fokus',
    'memfokus': 'fokus',
    'memfokuskan': 'fokus',
    'memfokuskannya': 'fokus',
    'berfokus': 'fokus',
    'berfokuslah': 'fokus',
    'berfokuskan': 'fokus',
    'pemfokusan': 'fokus',
    'memformulasikan': 'formulasi',
    'memformulasikannya': 'formulasi',
    'memforsir': 'forsir',
    'memforsirnya': 'forsir',
    'memfosil': 'fosil',
    'pemfosilan': 'fosil',
    'berfoto': 'foto',
    'berfotonya': 'foto',
    'berfotolah': 'foto',
    'berfotokan': 'foto',
    'memfotokopi': 'fotokopi',
    'memfotokopinya': 'fotokopi',
    'berfoya-foya': 'foya',
    'kefrustrasian': 'frustrasi',
    'berfusi': 'fusi',
    'memfusikan': 'fusi',
    'menggaba-gabai': 'gaba-gaba',
    'menggabai': 'gabai',
    'menggabaikan': 'gabai',
    'gabai-gabai': 'gabai',
    'menggabak': 'gabak',
    'tergabas': 'gabas',
    'menggabas': 'gabas',
    'menggabrukkan': 'gabruk',
    'gabungan': 'gabung',
    'gabungannya': 'gabung',
    'segabung': 'gabung',
    'bergabung': 'gabung',
    'bergabungnya': 'gabung',
    'bergabunglah': 'gabung',
    'bergabungkan': 'gabung',
    'bergabungan': 'gabung',
    'tergabung': 'gabung',
    'tergabungnya': 'gabung',
    'tergabungan': 'gabung',
    'menggabung': 'gabung',
    'menggabungnya': 'gabung',
    'menggabungkan': 'gabung',
    'menggabungkannya': 'gabung',
    'menggabungan': 'gabung',
    'pergabungan': 'gabung',
    'penggabungan': 'gabung',
    'penggabungannya': 'gabung',
    'ketergabungan': 'gabung',
    'ketergabungannya': 'gabung',
    'menggabungkankan': 'gabung',
    'penggabus': 'gabus',
    'menggabus': 'gabus',
    'gacoan': 'gaco',
    'gacoannya': 'gaco',
    'menggacok': 'gacok',
    'penggada': 'gada',
    'penggadaan': 'gada',
    'menggada': 'gada',
    'menggadakan': 'gada',
    'menggadakannya': 'gada',
    'bergadang': 'gadang',
    'menggadang': 'gadang',
    'menggadangkan': 'gadang',
    'bergading': 'gading',
    'menggading': 'gading',
    'menggadis': 'gadis',
    'kegadisan': 'gadis',
    'kegadisannya': 'gadis',
    'kegadis-gadisan': 'gadis',
    'menggado': 'gado',
    'bergaduk': 'gaduk',
    'menggaduk': 'gaduk',
    'menggaduki': 'gaduk',
    'menggaet': 'gaet',
    'menggaetnya': 'gaet',
    'menggaetkan': 'gaet',
    'menggaetku': 'gaet',
    'kegagahan': 'gagah',
    'kegagahannya': 'gagah',
    'menggagah': 'gagah',
    'menggagahi': 'gagah',
    'menggagahinya': 'gagah',
    'menggagahkan': 'gagah',
    'bergagah-gagahan': 'gagah',
    'menggagai': 'gagai',
    'penggagal': 'gagal',
    'penggagalan': 'gagal',
    'kegagalan': 'gagal',
    'kegagalannya': 'gagal',
    'kegagalanlah': 'gagal',
    'kegagalanan': 'gagal',
    'kegagalanku': 'gagal',
    'kegagalanmu': 'gagal',
    'menggagalkan': 'gagal',
    'menggagalkannya': 'gagal',
    'menggagap': 'gagap',
    'menggagapnya': 'gagap',
    'tergagap-gagap': 'gagap',
    'bergagap-gagap': 'gagap',
    'gagasan': 'gagas',
    'gagasannya': 'gagas',
    'gagasanmu': 'gagas',
    'menggagas': 'gagas',
    'menggagasnya': 'gagas',
    'menggagaskan': 'gagas',
    'penggagas': 'gagas',
    'penggagasnya': 'gagas',
    'penggagasan': 'gagas',
    'tergagau': 'gagau',
    'menggagau': 'gagau',
    'bergagau-gagau': 'gagau',
    'tergagau-gagau': 'gagau',
    'tergaguk-gaguk': 'gaguk',
    'menggaham': 'gaham',
    'menggahar': 'gahar',
    'menggaib': 'gaib',
    'kegaiban': 'gaib',
    'gail-gail': 'gail',
    'bergairah': 'gairah',
    'bergairahnya': 'gairah',
    'bergairahlah': 'gairah',
    'kegairahan': 'gairah',
    'kegairahannya': 'gairah',
    'menggairahkan': 'gairah',
    'menggairahkannya': 'gairah',
    'gaitan': 'gait',
    'menggait': 'gait',
    'penggait': 'gait',
    'menggajah': 'gajah',
    'gajah-gajahan': 'gajah',
    'gajian': 'gaji',
    'gajiannya': 'gaji',
    'menggaji': 'gaji',
    'menggajinya': 'gaji',
    'menggajiku': 'gaji',
    'penggajian': 'gaji',
    'penggajiannya': 'gaji',
    'bergajul': 'gajul',
    'bergala': 'gala',
    'gala-gala': 'gala',
    'bergalah': 'galah',
    'sepenggalah': 'galah',
    'menggalahkan': 'galah',
    'penggalak': 'galak',
    'penggalakkan': 'galak',
    'penggalakan': 'galak',
    'kegalakan': 'galak',
    'kegalakannya': 'galak',
    'menggalak': 'galak',
    'menggalakkan': 'galak',
    'menggalakkannya': 'galak',
    'menggalakan': 'galak',
    'galangan': 'galang',
    'galangannya': 'galang',
    'tergalang': 'galang',
    'bergalang': 'galang',
    'bergalangan': 'galang',
    'menggalang': 'galang',
    'menggalangnya': 'galang',
    'menggalangkan': 'galang',
    'menggalangi': 'galang',
    'menggalangan': 'galang',
    'penggalang': 'galang',
    'penggalangan': 'galang',
    'penggalangannya': 'galang',
    'penggalas': 'galas',
    'menggalas': 'galas',
    'penggalasan': 'galas',
    'bergalat': 'galat',
    'bergalau': 'galau',
    'kegalauan': 'galau',
    'kegalauannya': 'galau',
    'galengan': 'galeng',
    'galian': 'gali',
    'galiannya': 'gali',
    'galiani': 'gali',
    'penggali': 'gali',
    'penggalinya': 'gali',
    'penggalian': 'gali',
    'menggali': 'gali',
    'menggalinya': 'gali',
    'menggalikan': 'gali',
    'penggaliannya': 'gali',
    'gali-galian': 'gali',
    'menggali-gali': 'gali',
    'kegaliban': 'galib',
    'menggalibkan': 'galib',
    'menggalurkan': 'galur',
    'bergalur-galur': 'galur',
    'menggalur-galur': 'galur',
    'tergamak': 'gamak',
    'gamak-gamak': 'gamak',
    'menggamak-gamak': 'gamak',
    'tergamang': 'gamang',
    'penggamang': 'gamang',
    'bergamat': 'gamat',
    'menggamat': 'gamat',
    'kegamblangan': 'gamblang',
    'bergambuh': 'gambuh',
    'menggamik': 'gamik',
    'gamitan': 'gamit',
    'bergamit': 'gamit',
    'menggamit': 'gamit',
    'bergamitan': 'gamit',
    'gamit-gamitan': 'gamit',
    'menggamit-gamitkan': 'gamit',
    'gampangan': 'gampang',
    'gampangannya': 'gampang',
    'menggampangkan': 'gampang',
    'gampang-gampangan': 'gampang',
    'tergampar': 'gampar',
    'menggampar': 'gampar',
    'menggamparku': 'gampar',
    'ganal-ganal': 'ganal',
    'keganasan': 'ganas',
    'keganasannya': 'ganas',
    'mengganas': 'ganas',
    'mengganasnya': 'ganas',
    'pengganas': 'ganas',
    'gancaran': 'gancar',
    'menggancu': 'gancu',
    'gandalan': 'gandal',
    'penggandal': 'gandal',
    'gandaran': 'gandar',
    'penggandar': 'gandar',
    'menggandar': 'gandar',
    'gandengan': 'gandeng',
    'gandengannya': 'gandeng',
    'bergandeng': 'gandeng',
    'bergandengnya': 'gandeng',
    'bergandengan': 'gandeng',
    'menggandeng': 'gandeng',
    'menggandengnya': 'gandeng',
    'menggandengkan': 'gandeng',
    'menggandengkannya': 'gandeng',
    'menggandengan': 'gandeng',
    'pergandengan': 'gandeng',
    'penggandengan': 'gandeng',
    'mempergandengkan': 'gandeng',
    'kegandrungan': 'gandrung',
    'kegandrungannya': 'gandrung',
    'menggandrungi': 'gandrung',
    'menggandrunginya': 'gandrung',
    'menggandrungiku': 'gandrung',
    'menggandrungkan': 'gandrung',
    'berganduh': 'ganduh',
    'memperganduhkan': 'ganduh',
    'memperganduh-ganduhkan': 'ganduh',
    'gandulan': 'gandul',
    'menggandul': 'gandul',
    'mengganduli': 'gandul',
    'bergandung': 'gandung',
    'menggandung': 'gandung',
    'berganggang': 'ganggang',
    'mengganggang': 'ganggang',
    'mengganggangkan': 'ganggang',
    'mengganggu gugat': 'ganggu gugat',
    'gangguan': 'ganggu',
    'gangguannya': 'ganggu',
    'gangguanlah': 'ganggu',
    'terganggu': 'ganggu',
    'terganggunya': 'ganggu',
    'terganggulah': 'ganggu',
    'terganggukan': 'ganggu',
    'terganggui': 'ganggu',
    'mengganggu': 'ganggu',
    'mengganggunya': 'ganggu',
    'mengganggulah': 'ganggu',
    'mengganggui': 'ganggu',
    'menggangguan': 'ganggu',
    'menggangguku': 'ganggu',
    'mengganggumu': 'ganggu',
    'pengganggu': 'ganggu',
    'pengganggunya': 'ganggu',
    'penggangguan': 'ganggu',
    'mengganggut': 'ganggut',
    'pegangsaan': 'gangsa',
    'menggangsi': 'gangsi',
    'gangsiran': 'gangsir',
    'menggangsir': 'gangsir',
    'penggangsir': 'gangsir',
    'penggangsiran': 'gangsir',
    'ganjalan': 'ganjal',
    'ganjalannya': 'ganjal',
    'berganjal': 'ganjal',
    'terganjal': 'ganjal',
    'terganjalnya': 'ganjal',
    'pengganjal': 'ganjal',
    'pengganjalnya': 'ganjal',
    'pengganjalan': 'ganjal',
    'mengganjal': 'ganjal',
    'mengganjalnya': 'ganjal',
    'mengganjali': 'ganjal',
    'ganjal-mengganjal': 'ganjal',
    'ganjaran': 'ganjar',
    'ganjarannya': 'ganjar',
    'ganjaranmu': 'ganjar',
    'ganjaran-mu': 'ganjar',
    'mengganjar': 'ganjar',
    'mengganjarnya': 'ganjar',
    'mengganjari': 'ganjar',
    'mengganjarkan': 'ganjar',
    'mengganjil': 'ganjil',
    'mengganjilkan': 'ganjil',
    'keganjilan': 'ganjil',
    'keganjilannya': 'ganjil',
    'berganjur': 'ganjur',
    'mengganjur': 'ganjur',
    'mengganjuri': 'ganjur',
    'berganjur-ganjur': 'ganjur',
    'segantang': 'gantang',
    'menggantang': 'gantang',
    'gantelan': 'gantel',
    'menggantelkan': 'gantel',
    'menggantih': 'gantih',
    'menggantol': 'gantol',
    'mengganyah': 'ganyah',
    'mengganyang': 'ganyang',
    'mengganyangnya': 'ganyang',
    'menggaok': 'gaok',
    'kegapahan': 'gapah',
    'tergapai': 'gapai',
    'menggapai': 'gapai',
    'menggapainya': 'gapai',
    'menggapaikan': 'gapai',
    'bergapaian': 'gapai',
    'tergapai-gapai': 'gapai',
    'menggapai-gapai': 'gapai',
    'menggapai-gapaikan': 'gapai',
    'menggapil': 'gapil',
    'menggapit': 'gapit',
    'gaplokan': 'gaplok',
    'menggaplok': 'gaplok',
    'menggaploki': 'gaplok',
    'bergarah': 'garah',
    'menggarah': 'garah',
    'menggarahkan': 'garah',
    'garah-garah': 'garah',
    'bergarah-garah': 'garah',
    'mempergarahkan': 'garah',
    'bergaram': 'garam',
    'menggaram': 'garam',
    'menggarami': 'garam',
    'pegaraman': 'garam',
    'menggaraminya': 'garam',
    'penggaraman': 'garam',
    'menggaramkan': 'garam',
    'garangan': 'garang',
    'menggarang': 'garang',
    'menggarangi': 'garang',
    'penggarang': 'garang',
    'kegarangan': 'garang',
    'kegarangannya': 'garang',
    'menggarangkan': 'garang',
    'bergaransi': 'garansi',
    'bergaransinya': 'garansi',
    'garapan': 'garap',
    'garapannya': 'garap',
    'tergarap': 'garap',
    'tergarapnya': 'garap',
    'menggarap': 'garap',
    'menggarapnya': 'garap',
    'menggarapkan': 'garap',
    'penggarap': 'garap',
    'penggarapnya': 'garap',
    'penggarapan': 'garap',
    'penggarapannya': 'garap',
    'bergarau': 'garau',
    'menggari': 'gari',
    'menggarisbawahi': 'garis bawah',
    'menggarisbawahinya': 'garis bawah',
    'segaris': 'garis',
    'bergaris': 'garis',
    'menggaris': 'garis',
    'menggariskan': 'garis',
    'menggarisi': 'garis',
    'penggaris': 'garis',
    'penggarisan': 'garis',
    'garitan': 'garit',
    'menggarit': 'garit',
    'menggaritkan': 'garit',
    'penggarong': 'garong',
    'penggarongan': 'garong',
    'menggarong': 'garong',
    'penggaru': 'garu',
    'penggarukan': 'garu',
    'penggaruan': 'garu',
    'menggaru': 'garu',
    'garukan': 'garuk',
    'garukannya': 'garuk',
    'tergaruk': 'garuk',
    'menggaruk': 'garuk',
    'menggaruknya': 'garuk',
    'menggarukkan': 'garuk',
    'menggaruki': 'garuk',
    'penggaruk': 'garuk',
    'bergaruk-garuk': 'garuk',
    'menggaruk-garuk': 'garuk',
    'menggaruk-garukkan': 'garuk',
    'menggaruk-garukan': 'garuk',
    'menggarung': 'garung',
    'menggarut': 'garut',
    'menggasab': 'gasab',
    'gasakan': 'gasak',
    'menggasak': 'gasak',
    'menggasaknya': 'gasak',
    'menggasakan': 'gasak',
    'menggasakkan': 'gasak',
    'gasak-gasakan': 'gasak',
    'bergasing': 'gasing',
    'kegatalan': 'gatal',
    'menggatalkan': 'gatal',
    'menggatra': 'gatra',
    'bergaun': 'gaun',
    'pegawai': 'gawai',
    'pegawainya': 'gawai',
    'pegawaian': 'gawai',
    'pegawaiku': 'gawai',
    'pegawaimu': 'gawai',
    'gawangan': 'gawang',
    'gawar-gawar': 'gawar',
    'gawatan': 'gawat',
    'kegawatan': 'gawat',
    'kegawatannya': 'gawat',
    'menggawat': 'gawat',
    'menggawatkan': 'gawat',
    'bergayuh': 'gayuh',
    'menggayuh': 'gayuh',
    'menggayuk': 'gayuk',
    'menggayun': 'gayun',
    'bergayung': 'gayung',
    'menggayung': 'gayung',
    'menggebah': 'gebah',
    'gebaran': 'gebar',
    'menggeblak': 'geblak',
    'geblokan': 'geblok',
    'segeblok': 'geblok',
    'menggebok': 'gebok',
    'menggebos': 'gebos',
    'menggebosi': 'gebos',
    'menggebot': 'gebot',
    'gebrakan': 'gebrak',
    'gebrakannya': 'gebrak',
    'menggebrak': 'gebrak',
    'menggebu': 'gebu',
    'menggebunya': 'gebu',
    'menggebu-gebu': 'gebu',
    'menggebu-gebunya': 'gebu',
    'gebukan': 'gebuk',
    'menggebuk': 'gebuk',
    'menggebuki': 'gebuk',
    'menggebukinya': 'gebuk',
    'menggebyah-uyah': 'gebyah-uyah',
    'gebyar-gebyar': 'gebyar',
    'gebyuran': 'gebyur',
    'menggebyur': 'gebyur',
    'menggecarkan': 'gecar',
    'menggecek': 'gecek',
    'gedean': 'gede',
    'penggede': 'gede',
    'gedokan': 'gedok',
    'gedongan': 'gedong',
    'gedoran': 'gedor',
    'tergedor': 'gedor',
    'penggedor': 'gedor',
    'penggedornya': 'gedor',
    'penggedoran': 'gedor',
    'menggedor': 'gedor',
    'menggedornya': 'gedor',
    'bergeduyut': 'geduyut',
    'tergegap-gegap': 'gegap',
    'tergegau': 'gegau',
    'kegegeran': 'geger',
    'menggeger': 'geger',
    'menggegerkan': 'geger',
    'menggejala': 'gejala',
    'menggejalanya': 'gejala',
    'menggejos': 'gejos',
    'menggejoskan': 'gejos',
    'menggejuju': 'gejuju',
    'menggelabur': 'gelabur',
    'menggeladrah': 'geladrah',
    'gelagapan': 'gelagap',
    'bergelagar': 'gelagar',
    'bergelagaran': 'gelagar',
    'tergelak': 'gelak',
    'menggelakkan': 'gelak',
    'tergelak-gelak': 'gelak',
    'menggelalar': 'gelalar',
    'menggelamai': 'gelamai',
    'bergelambir': 'gelambir',
    'bergelambirku': 'gelambir',
    'gelandangan': 'gelandang',
    'menggelandang': 'gelandang',
    'menggelandangnya': 'gelandang',
    'menggelandangan': 'gelandang',
    'bergelandangan': 'gelandang',
    'menggelandoti': 'gelandot',
    'pergelangan': 'gelang',
    'pergelangannya': 'gelang',
    'pergelanganan': 'gelang',
    'gelang-gelang': 'gelang',
    'tergelang-gelang': 'gelang',
    'bergelang-gelang': 'gelang',
    'bergelanggang': 'gelanggang',
    'menggelanggang': 'gelanggang',
    'tergelangsar': 'gelangsar',
    'menggelangsar': 'gelangsar',
    'menggelantang': 'gelantang',
    'menggelanting': 'gelanting',
    'bergelantung': 'gelantung',
    'bergelantungan': 'gelantung',
    'menggelantung': 'gelantung',
    'menggelantungkan': 'gelantung',
    'menggelap': 'gelap',
    'menggelapnya': 'gelap',
    'menggelapkan': 'gelap',
    'menggelapkannya': 'gelap',
    'menggelapan': 'gelap',
    'kegelapan': 'gelap',
    'kegelapannya': 'gelap',
    'penggelapan': 'gelap',
    'penggelapannya': 'gelap',
    'penggelapanlah': 'gelap',
    'penggelapanan': 'gelap',
    'gelap-gelapan': 'gelap',
    'bergelap-gelap': 'gelap',
    'bergelap-gelapan': 'gelap',
    'kegelap-gelapan': 'gelap',
    'gelasan': 'gelas',
    'menggelas': 'gelas',
    'bergelas-gelasan': 'gelas',
    'menggelasir': 'gelasir',
    'menggelatak': 'gelatak',
    'menggelatuk': 'gelatuk',
    'bergelayangan': 'gelayangan',
    'gelayaran': 'gelayar',
    'bergelayut': 'gelayut',
    'bergelayutan': 'gelayut',
    'tergelebar': 'gelebar',
    'menggeleber': 'geleber',
    'bergeleberan': 'geleber',
    'tergelecik': 'gelecik',
    'menggelecik': 'gelecik',
    'menggeledah': 'geledah',
    'menggeledahnya': 'geledah',
    'menggeledahkan': 'geledah',
    'menggeledahi': 'geledah',
    'menggeledahan': 'geledah',
    'menggeledahku': 'geledah',
    'penggeledahan': 'geledah',
    'penggeledahannya': 'geledah',
    'menggeledang': 'geledang',
    'menggeledek': 'geledek',
    'menggeleding': 'geleding',
    'menggeledur': 'geledur',
    'bergelegak': 'gelegak',
    'menggelegak': 'gelegak',
    'menggelegakkan': 'gelegak',
    'bergelegar': 'gelegar',
    'menggelegar': 'gelegar',
    'menggelegarnya': 'gelegar',
    'menggelegarkan': 'gelegar',
    'menggelek': 'gelek',
    'menggelekkan': 'gelek',
    'menggelekak': 'gelekak',
    'menggelekek': 'gelekek',
    'bergelembung': 'gelembung',
    'menggelembung': 'gelembung',
    'menggelembungnya': 'gelembung',
    'menggelembungkan': 'gelembung',
    'menggelembungan': 'gelembung',
    'gelembung-gelembungan': 'gelembung',
    'menggelembur': 'gelembur',
    'bergelemprang': 'gelemprang',
    'tergelenang': 'gelenang',
    'menggelendong': 'gelendong',
    'bergelendot': 'gelendot',
    'menggelendot': 'gelendot',
    'bergelendotan': 'gelendot',
    'bergeleng': 'geleng',
    'menggeleng': 'geleng',
    'menggelengkan': 'geleng',
    'bergeleng-geleng': 'geleng',
    'tergeleng-geleng': 'geleng',
    'menggeleng-gelengkan': 'geleng',
    'menggelenting': 'gelenting',
    'menggelenyar': 'gelenyar',
    'menggelepai': 'gelepai',
    'menggelepar': 'gelepar',
    'bergeleparan': 'gelepar',
    'menggelepar-gelepar': 'gelepar',
    'menggelepar-geleparkan': 'gelepar',
    'menggelepek': 'gelepek',
    'menggelepur': 'gelepur',
    'menggeleser': 'geleser',
    'menggeleserkan': 'geleser',
    'menggelesot': 'gelesot',
    'tergeletak': 'geletak',
    'tergeletaknya': 'geletak',
    'menggeletak': 'geletak',
    'menggeletakkan': 'geletak',
    'menggeletakkannya': 'geletak',
    'menggeletakan': 'geletak',
    'menggeletar': 'geletar',
    'menggeletarkan': 'geletar',
    'menggeletik': 'geletik',
    'menggeletis': 'geletis',
    'gemeletuk': 'geletuk',
    'menggeletuk': 'geletuk',
    'kegelian': 'geli',
    'kegeliannya': 'geli',
    'penggeli': 'geli',
    'menggeli': 'geli',
    'menggelikan': 'geli',
    'menggelikannya': 'geli',
    'geli-geli': 'geli',
    'menggeliang': 'geliang',
    'geliang-geliut': 'geliang',
    'menggeliang-geliutkan': 'geliang',
    'tergeliat': 'geliat',
    'menggeliat': 'geliat',
    'menggeliatnya': 'geliat',
    'menggeliatkan': 'geliat',
    'geliat-geliut': 'geliat',
    'menggelibir': 'gelibir',
    'tergelicik': 'gelicik',
    'menggelicikkan': 'gelicik',
    'menggeligi': 'geligi',
    'menggeligis': 'geligis',
    'menggeligit': 'geligit',
    'bergelimang': 'gelimang',
    'bergelimangnya': 'gelimang',
    'bergelimangan': 'gelimang',
    'menggelimangi': 'gelimang',
    'menggelimantang': 'gelimantang',
    'gelimbiran': 'gelimbir',
    'bergelimun': 'gelimun',
    'menggelimuni': 'gelimun',
    'tergelincir': 'gelincir',
    'tergelincirnya': 'gelincir',
    'tergelinciri': 'gelincir',
    'menggelincir': 'gelincir',
    'menggelincirkan': 'gelincir',
    'tergelincuh': 'gelincuh',
    'gelindingan': 'gelinding',
    'menggelinding': 'gelinding',
    'menggelindingnya': 'gelinding',
    'menggelindingkan': 'gelinding',
    'menggelindingkannya': 'gelinding',
    'bergelindingan': 'gelinding',
    'menggelinding-gelinding': 'gelinding',
    'bergelingsir': 'gelingsir',
    'tergelingsir': 'gelingsir',
    'menggelingsir': 'gelingsir',
    'menggelinjang': 'gelinjang',
    'tergelintang': 'gelintang',
    'menggelintar': 'gelintar',
    'bergelintin': 'gelintin',
    'menggelinting': 'gelinting',
    'gelintiran': 'gelintir',
    'segelintir': 'gelintir',
    'segelintirnya': 'gelintir',
    'segelintiran': 'gelintir',
    'kegelisahan': 'gelisah',
    'kegelisahannya': 'gelisah',
    'kegelisahanku': 'gelisah',
    'menggelisahi': 'gelisah',
    'menggelisahkan': 'gelisah',
    'kegelitaan': 'gelita',
    'menggelitar': 'gelitar',
    'gelitikan': 'gelitik',
    'tergelitik': 'gelitik',
    'tergelitiklah': 'gelitik',
    'menggelitik': 'gelitik',
    'menggelitiknya': 'gelitik',
    'menggelitikkan': 'gelitik',
    'menggelitiki': 'gelitik',
    'menggelitikku': 'gelitik',
    'menggelobok': 'gelobok',
    'menggelodar': 'gelodar',
    'menggelogok': 'gelogok',
    'tergelohok': 'gelohok',
    'menggelompar': 'gelompar',
    'gelondongan': 'gelondong',
    'gelondongannya': 'gelondong',
    'bergelonggong': 'gelonggong',
    'menggelongsor': 'gelongsor',
    'menggelontor': 'gelontor',
    'menggelontornya': 'gelontor',
    'menggelontorkan': 'gelontor',
    'menggelontorkannya': 'gelontor',
    'menggelontori': 'gelontor',
    'menggelontoran': 'gelontor',
    'penggelontoran': 'gelontor',
    'penggelontorannya': 'gelontor',
    'menggelopak': 'gelopak',
    'menggelosang': 'gelosang',
    'menggeloso': 'geloso',
    'menggelosok': 'gelosok',
    'menggelotak': 'gelotak',
    'bergelugut': 'gelugut',
    'menggelugut': 'gelugut',
    'menggelulur': 'gelulur',
    'tergeluncur': 'geluncur',
    'menggelundung': 'gelundung',
    'bergelundungan': 'gelundung',
    'menggelundungkan': 'gelundung',
    'menggelup': 'gelup',
    'menggelupur': 'gelupur',
    'menggemak': 'gemak',
    'menggemak-gemak': 'gemak',
    'segemal': 'gemal',
    'menggemal': 'gemal',
    'bergemal-gemal': 'gemal',
    'penggemang': 'gemang',
    'tergemap': 'gemap',
    'bergemar': 'gemar',
    'penggemar': 'gemar',
    'penggemarnya': 'gemar',
    'penggemarlah': 'gemar',
    'penggemarku': 'gemar',
    'penggemarmu': 'gemar',
    'kegemaran': 'gemar',
    'kegemarannya': 'gemar',
    'kegemaranku': 'gemar',
    'menggemari': 'gemar',
    'menggemarinya': 'gemar',
    'menggemarii': 'gemar',
    'menggemarkan': 'gemar',
    'kegemasan': 'gemas',
    'menggemaskan': 'gemas',
    'menggemaskannya': 'gemas',
    'penggembala': 'gembala',
    'penggembalanya': 'gembala',
    'penggembalaan': 'gembala',
    'penggembalaannya': 'gembala',
    'menggembalakan': 'gembala',
    'menggembalakannya': 'gembala',
    'bergembar-gembor': 'gembar-gembor',
    'penggembar-gemboran': 'gembar-gembor',
    'menggembar-gemborkan': 'gembar-gembor',
    'menggembar-gemborkannya': 'gembar-gembor',
    'tergembleng': 'gembleng',
    'bergembleng': 'gembleng',
    'penggemblengan': 'gembleng',
    'bergembok': 'gembok',
    'tergembok': 'gembok',
    'menggembok': 'gembok',
    'menggemboknya': 'gembok',
    'menggembokkannya': 'gembok',
    'menggembokan': 'gembok',
    'penggembok': 'gembok',
    'penggembokan': 'gembok',
    'menggembol': 'gembol',
    'menggembos': 'gembos',
    'menggemboskan': 'gembos',
    'menggembosi': 'gembos',
    'penggembosan': 'gembos',
    'bergembung': 'gembung',
    'penggembungan': 'gembung',
    'menggembungkan': 'gembung',
    'menggemburkan': 'gembur',
    'gembusan': 'gembus',
    'menggembut': 'gembut',
    'bergembut-gembut': 'gembut',
    'menggemeretakkan': 'gemeretak',
    'menggemeretakkannya': 'gemeretak',
    'gemerlapan': 'gemerlap',
    'gemerlapannya': 'gemerlap',
    'menggemik': 'gemik',
    'kegemilangan': 'gemilang',
    'kegemilangannya': 'gemilang',
    'tergeming': 'geming',
    'bergeming': 'geming',
    'bergemingnya': 'geming',
    'bergempa': 'gempa',
    'menggempakan': 'gempa',
    'kegemparan': 'gempar',
    'kegemparannya': 'gempar',
    'menggemparkan': 'gempar',
    'menggempita': 'gempita',
    'penggempur': 'gempur',
    'penggempurnya': 'gempur',
    'penggempuran': 'gempur',
    'menggempur': 'gempur',
    'menggempurnya': 'gempur',
    'menggempurkan': 'gempur',
    'menggempuri': 'gempur',
    'penggempurannya': 'gempur',
    'gempur-menggempur': 'gempur',
    'penggemuk': 'gemuk',
    'penggemukkan': 'gemuk',
    'penggemukan': 'gemuk',
    'kegemukan': 'gemuk',
    'kegemukannya': 'gemuk',
    'kegemukanku': 'gemuk',
    'penggemukannya': 'gemuk',
    'menggemukkan': 'gemuk',
    'menggemukkannya': 'gemuk',
    'menggemulai': 'gemulai',
    'segenap': 'genap',
    'penggenap': 'genap',
    'penggenapan': 'genap',
    'kegenapan': 'genap',
    'menggenapi': 'genap',
    'menggenapinya': 'genap',
    'menggenapkan': 'genap',
    'menggenapkannya': 'genap',
    'menggencar': 'gencar',
    'menggencarkan': 'gencar',
    'menggencarkannya': 'gencar',
    'gencatan': 'gencat',
    'menggencat': 'gencat',
    'gencetan': 'gencet',
    'tergencet': 'gencet',
    'tergencetnya': 'gencet',
    'menggencet': 'gencet',
    'menggencetnya': 'gencet',
    'bergendak': 'gendak',
    'bergendakan': 'gendak',
    'menggendaki': 'gendak',
    'menggendalakan': 'gendala',
    'gendaman': 'gendam',
    'gendongan': 'gendong',
    'gendongannya': 'gendong',
    'gendonganku': 'gendong',
    'menggendong': 'gendong',
    'menggendongnya': 'gendong',
    'menggendongkan': 'gendong',
    'menggendongku': 'gendong',
    'kegendutan': 'gendut',
    'menggendut': 'gendut',
    'menggendutkan': 'gendut',
    'menggenduti': 'gendut',
    'menggeneralisasi': 'generalisasi',
    'menggeneralisasinya': 'generalisasi',
    'menggeneralisasikan': 'generalisasi',
    'menggeneralisasikannya': 'generalisasi',
    'genggaman': 'genggam',
    'genggamannya': 'genggam',
    'genggamanku': 'genggam',
    'genggamanmu': 'genggam',
    'segenggam': 'genggam',
    'segenggaman': 'genggam',
    'tergenggam': 'genggam',
    'bergenggam': 'genggam',
    'bergenggaman': 'genggam',
    'menggenggam': 'genggam',
    'menggenggamnya': 'genggam',
    'menggenggamkan': 'genggam',
    'bergengsi': 'gengsi',
    'bergengsinya': 'gengsi',
    'bergengsii': 'gengsi',
    'bergengsimu': 'gengsi',
    'gengsi-gengsian': 'gengsi',
    'kegenialan': 'genial',
    'genjotan': 'genjot',
    'penggenjot': 'genjot',
    'penggenjotan': 'genjot',
    'menggenjot': 'genjot',
    'menggenjotnya': 'genjot',
    'genjot-genjotan': 'genjot',
    'genjrang-genjreng': 'genjrang',
    'bergenre': 'genre',
    'menggenta': 'genta',
    'bergentar': 'gentar',
    'menggentar': 'gentar',
    'menggentarkan': 'gentar',
    'menggentarkannya': 'gentar',
    'kegentaran': 'gentar',
    'penggentar': 'gentar',
    'penggentaran': 'gentar',
    'menggentari': 'gentar',
    'menggentas': 'gentas',
    'gentayangan': 'gentayang',
    'gentayangannya': 'gentayang',
    'bergentayangan': 'gentayangan',
    'bergentayangannya': 'gentayangan',
    'menggentel': 'gentel',
    'menggenteli': 'gentel',
    'kegentingan': 'genting',
    'kegentingannya': 'genting',
    'menggenting': 'genting',
    'penggentingan': 'genting',
    'menggentingkan': 'genting',
    'gentusan': 'gentus',
    'menggepit': 'gepit',
    'segepok': 'gepok',
    'gepokan': 'gepok',
    'bergepok-gepok': 'gepok',
    'menggeprak': 'geprak',
    'menggera': 'gera',
    'menggerakan': 'gera',
    'menggerakannya': 'gera',
    'menggerai': 'gera',
    'penggera': 'gera',
    'menggerabak': 'gerabak',
    'menggerabakkan': 'gerabak',
    'gerabak-gerubuk': 'gerabak',
    'menggeragai': 'geragai',
    'geragapan': 'geragap',
    'menggeragap': 'geragap',
    'menggeragas': 'geragas',
    'menggeragau': 'geragau',
    'kegerahan': 'gerah',
    'kegerahannya': 'gerah',
    'kegerahanku': 'gerah',
    'tergerai': 'gerai',
    'menggerainya': 'gerai',
    'menggeraikan': 'gerai',
    'tergerai-gerai': 'gerai',
    'geraman': 'geram',
    'kegeraman': 'geram',
    'kegeramannya': 'geram',
    'menggeram': 'geram',
    'menggeramkan': 'geram',
    'menggeramus': 'geramus',
    'menggerang': 'gerang',
    'menggerantak': 'gerantak',
    'menggerantang': 'gerantang',
    'menggeranyam': 'geranyam',
    'menggerapai': 'gerapai',
    'bergerapu': 'gerapu',
    'menggerat': 'gerat',
    'menggerawat': 'gerawat',
    'menggerawatkan': 'gerawat',
    'menggerayah': 'gerayah',
    'gerayangan': 'gerayang',
    'gerayangannya': 'gerayang',
    'menggerayang': 'gerayang',
    'menggerayangi': 'gerayang',
    'bergerayangan': 'gerayang',
    'menggerayanginya': 'gerayang',
    'penggerayangan': 'gerayang',
    'menggerbak': 'gerbak',
    'menggerbang': 'gerbang',
    'menggerbangkan': 'gerbang',
    'tegerbang-gerbang': 'gerbang',
    'menggerbus': 'gerbus',
    'menggerebek': 'gerebek',
    'menggerebeknya': 'gerebek',
    'penggerebekan': 'gerebek',
    'penggerebekannya': 'gerebek',
    'menggerecak-gerecak': 'gerecak',
    'menggerecok': 'gerecok',
    'menggerecoki': 'gerecok',
    'geregetan': 'gereget',
    'geregetannya': 'gereget',
    'kegerejaan': 'gereja',
    'kegerejaannya': 'gereja',
    'menggerek': 'gerek',
    'menggerekkan': 'gerek',
    'menggerekan': 'gerek',
    'penggerek': 'gerek',
    'penggereknya': 'gerek',
    'penggerekkan': 'gerek',
    'penggerekan': 'gerek',
    'bergerek-gerek': 'gerek',
    'menggeremet': 'geremet',
    'menggerendel': 'gerendel',
    'gerenengan': 'gereneng',
    'menggerenik': 'gerenik',
    'tergerenyeng-gerenyeng': 'gerenyeng',
    'menggerenyet': 'gerenyet',
    'menggerepe': 'gerepe',
    'menggerepek': 'gerepek',
    'bergerepes': 'gerepes',
    'menggerepes': 'gerepes',
    'menggeresek': 'geresek',
    'geretan': 'geret',
    'menggeret': 'geret',
    'menggeretnya': 'geret',
    'bergeretak': 'geretak',
    'menggeretang': 'geretang',
    'gergajian': 'gergaji',
    'gergajiannya': 'gergaji',
    'menggergaji': 'gergaji',
    'menggergajinya': 'gergaji',
    'menggergajikan': 'gergaji',
    'penggergaji': 'gergaji',
    'penggergajian': 'gergaji',
    'penggergajiannya': 'gergaji',
    'menggeriak': 'geriak',
    'geriak-geriuk': 'geriak',
    'menggeriap': 'geriap',
    'menggericau': 'gericau',
    'menggeridip': 'geridip',
    'bergerilya': 'gerilya',
    'bergerilyanya': 'gerilya',
    'bergerilyalah': 'gerilya',
    'menggerinda': 'gerinda',
    'penggering': 'gering',
    'geringgingan': 'geringging',
    'menggerinjam': 'gerinjam',
    'menggerinyau': 'gerinyau',
    'menggerisik': 'gerisik',
    'gerit-gerit': 'gerit',
    'menggerlap': 'gerlap',
    'menggerlip': 'gerlip',
    'menggermang': 'germang',
    'menggermut': 'germut',
    'menggermuti': 'germut',
    'menggero': 'gero',
    'bergerobok': 'gerobok',
    'menggerobok': 'gerobok',
    'gerobyakan': 'gerobyak',
    'bergerocok': 'gerocok',
    'menggerodak': 'gerodak',
    'menggerogoti': 'gerogot',
    'menggerogotinya': 'gerogot',
    'penggerogotan': 'gerogot',
    'menggerojok': 'gerojok',
    'menggerojokkan': 'gerojok',
    'gerombolan': 'gerombol',
    'gerombolannya': 'gerombol',
    'bergerombol': 'gerombol',
    'bergerombolan': 'gerombol',
    'gerombongan': 'gerombong',
    'menggerompok': 'gerompok',
    'menggeronggang': 'geronggang',
    'menggeropyok': 'geropyok',
    'penggeropyokan': 'geropyok',
    'menggeros': 'geros',
    'menggerowot': 'gerowot',
    'menggerpol': 'gerpol',
    'kegersangan': 'gersang',
    'gertakan': 'gertak',
    'gertakannya': 'gertak',
    'menggertak': 'gertak',
    'menggertaknya': 'gertak',
    'menggertakkan': 'gertak',
    'menggertakan': 'gertak',
    'menggertakku': 'gertak',
    'penggertak': 'gertak',
    'penggertakan': 'gertak',
    'menggeru': 'geru',
    'menggerugut': 'gerugut',
    'menggeruh': 'geruh',
    'kegeruhan': 'geruh',
    'geruh-gerah': 'geruh',
    'menggeruit': 'geruit',
    'menggerumit': 'gerumit',
    'menggerumuk': 'gerumuk',
    'menggerumuti': 'gerumut',
    'menggerumutinya': 'gerumut',
    'menggerunkan': 'gerun',
    'menggerundel': 'gerundel',
    'tergerung': 'gerung',
    'menggerung': 'gerung',
    'menggerunyam': 'gerunyam',
    'menggerupis': 'gerupis',
    'menggerupuk': 'gerupuk',
    'menggerupukkan': 'gerupuk',
    'gerusan': 'gerus',
    'gerusannya': 'gerus',
    'tergerus': 'gerus',
    'tergerusnya': 'gerus',
    'menggerus': 'gerus',
    'menggerusnya': 'gerus',
    'menggerutu': 'gerutu',
    'penggerutu': 'gerutu',
    'menggesa': 'gesa',
    'tergesa-gesa': 'gesa',
    'tergesa-gesanya': 'gesa',
    'bergesa-gesa': 'gesa',
    'ketergesa-gesaan': 'gesa',
    'menggesa-gesakan': 'gesa',
    'penggetang': 'getang',
    'menggetang': 'getang',
    'getapan': 'getap',
    'menggetap': 'getap',
    'menggetik': 'getik',
    'segetil': 'getil',
    'menggetil': 'getil',
    'kegetiran': 'getir',
    'kegetirannya': 'getir',
    'menggetok': 'getok',
    'menggetoknya': 'getok',
    'kegetolan': 'getol',
    'kegetolannya': 'getol',
    'menggetu': 'getu',
    'getak-getuk': 'getuk',
    'tergial': 'gial',
    'gial-giul': 'gial',
    'gial-gial': 'gial',
    'pegiat': 'giat',
    'pegiatnya': 'giat',
    'pegiatan': 'giat',
    'bergiat': 'giat',
    'kegiatan': 'giat',
    'kegiatannya': 'giat',
    'kegiatanlah': 'giat',
    'kegiatankan': 'giat',
    'kegiatanan': 'giat',
    'kegiatanku': 'giat',
    'kegiatanmu': 'giat',
    'penggiat': 'giat',
    'penggiatnya': 'giat',
    'penggiatan': 'giat',
    'mempergiat': 'giat',
    'penggiatannya': 'giat',
    'menggiatkan': 'giat',
    'menggiatkannya': 'giat',
    'berkegiatan': 'giat',
    'berkegiatanlah': 'giat',
    'mempergiatkan': 'giat',
    'menggibang': 'gibang',
    'bergidik': 'gidik',
    'menggidikkan': 'gidik',
    'kegigihan': 'gigih',
    'kegigihannya': 'gigih',
    'kegigihannyalah': 'gigih',
    'kegigihanku': 'gigih',
    'kegigihanmu': 'gigih',
    'menggigih': 'gigih',
    'menggigil': 'gigil',
    'menggigilnya': 'gigil',
    'menggigilkan': 'gigil',
    'menggigis': 'gigis',
    'gigitan': 'gigit',
    'gigitannya': 'gigit',
    'gigitanku': 'gigit',
    'tergigit': 'gigit',
    'tergigitnya': 'gigit',
    'menggigit': 'gigit',
    'menggigitnya': 'gigit',
    'menggigiti': 'gigit',
    'menggigitku': 'gigit',
    'menggigitmu': 'gigit',
    'menggigitinya': 'gigit',
    'kegilaan': 'gila',
    'kegilaannya': 'gila',
    'kegilaanmu': 'gila',
    'menggila': 'gila',
    'menggilanya': 'gila',
    'menggilalah': 'gila',
    'menggilakan': 'gila',
    'menggilai': 'gila',
    'penggila': 'gila',
    'penggilanya': 'gila',
    'gila-gila': 'gila',
    'gila-gilanya': 'gila',
    'gila-gilai': 'gila',
    'gila-gilaan': 'gila',
    'gila-gilaannya': 'gila',
    'tergila-gila': 'gila',
    'tergila-gilanya': 'gila',
    'kegila-gilaan': 'gila',
    'gilang-gemilang': 'gilang',
    'gilang-gemilangnya': 'gilang',
    'penggilap': 'gilap',
    'menggilapkan': 'gilap',
    'gilap-gemilap': 'gilap',
    'gilasan': 'gilas',
    'tergilas': 'gilas',
    'tergilasnya': 'gilas',
    'menggilas': 'gilas',
    'menggilasnya': 'gilas',
    'penggilas': 'gilas',
    'penggilasan': 'gilas',
    'gilian': 'gili',
    'giliani': 'gili',
    'menggili': 'gili',
    'menggili-gili': 'gili',
    'gilingan': 'giling',
    'gilingannya': 'giling',
    'tergiling': 'giling',
    'penggiling': 'giling',
    'penggilingnya': 'giling',
    'penggilingan': 'giling',
    'menggiling': 'giling',
    'menggilingnya': 'giling',
    'menggilingkan': 'giling',
    'penggilingannya': 'giling',
    'giling-giling': 'giling',
    'giliran': 'gilir',
    'gilirannya': 'gilir',
    'giliranku': 'gilir',
    'giliranmu': 'gilir',
    'bergilir': 'gilir',
    'bergilirnya': 'gilir',
    'bergiliran': 'gilir',
    'mempergilirkan': 'gilir',
    'gilir-bergilir': 'gilir',
    'bergilir-gilir': 'gilir',
    'ginang-ginang': 'ginang',
    'bergincu': 'gincu',
    'menggincu': 'gincu',
    'penggirang': 'girang',
    'kegirangan': 'girang',
    'kegirangannya': 'girang',
    'menggirangkan': 'girang',
    'kegirang-girangan': 'girang',
    'girik-girik': 'girik',
    'menggiring': 'giring',
    'menggiringnya': 'giring',
    'menggiringi': 'giring',
    'menggisar': 'gisar',
    'menggisil': 'gisil',
    'menggites': 'gites',
    'menggitik': 'gitik',
    'tergiur': 'giur',
    'tergiurnya': 'giur',
    'menggiurkan': 'giur',
    'menggiurkannya': 'giur',
    'bergiwang': 'giwang',
    'bergizi': 'gizi',
    'bergizinya': 'gizi',
    'keglamoran': 'glamor',
    'keglamorannya': 'glamor',
    'mengglasir': 'glasir',
    'mengglobal': 'global',
    'mengglobalnya': 'global',
    'mengglobalkan': 'global',
    'mengglobalkannya': 'global',
    'gegoakan': 'goak',
    'goak-goak': 'goak',
    'menggobek': 'gobek',
    'kegoblokan': 'goblok',
    'gocekan': 'gocek',
    'gocekannya': 'gocek',
    'menggocek': 'gocek',
    'menggoceknya': 'gocek',
    'bergocoh': 'gocoh',
    'menggocoh': 'gocoh',
    'pergocohan': 'gocoh',
    'godaan': 'goda',
    'godaannya': 'goda',
    'tergoda': 'goda',
    'tergodanya': 'goda',
    'menggoda': 'goda',
    'menggodanya': 'goda',
    'menggodaku': 'goda',
    'menggodamu': 'goda',
    'penggoda': 'goda',
    'penggodanya': 'goda',
    'penggodakan': 'goda',
    'menggodai': 'goda',
    'menggodainya': 'goda',
    'penggodaan': 'goda',
    'menggodak': 'godak',
    'menggodam': 'godam',
    'penggodam': 'godam',
    'godokan': 'godok',
    'menggodok': 'godok',
    'menggodoknya': 'godok',
    'penggodokan': 'godok',
    'penggodokannya': 'godok',
    'menggodot': 'godot',
    'menggodot-godot': 'godot',
    'menggoel': 'goel',
    'menggogoh': 'gogoh',
    'menggogok': 'gogok',
    'bergojek': 'gojek',
    'gojlokan': 'gojlok',
    'gojlokannya': 'gojlok',
    'menggojlok': 'gojlok',
    'menggojloki': 'gojlok',
    'penggojlokan': 'gojlok',
    'menggolak-galikkan': 'golak-galik',
    'menggoleng': 'goleng',
    'bergoler': 'goler',
    'pegolf': 'golf',
    'pegolfnya': 'golf',
    'bergolok': 'golok',
    'tergolok': 'golok',
    'menggolok': 'golok',
    'golongan': 'golong',
    'golongannya': 'golong',
    'golonganku': 'golong',
    'golonganmu': 'golong',
    'tergolong': 'golong',
    'tergolongkan': 'golong',
    'tergolongan': 'golong',
    'penggolong': 'golong',
    'penggolongkan': 'golong',
    'penggolongan': 'golong',
    'menggolong': 'golong',
    'menggolongkan': 'golong',
    'menggolongkannya': 'golong',
    'menggolongan': 'golong',
    'penggolongannya': 'golong',
    'bergolong-golong': 'golong',
    'gombalan': 'gombal',
    'gombalannya': 'gombal',
    'menggombeng': 'gombeng',
    'menggondokkan': 'gondok',
    'menggondol': 'gondol',
    'menggondolnya': 'gondol',
    'menggondolkan': 'gondol',
    'kegondrongan': 'gondrong',
    'gonggongan': 'gonggong',
    'gonggongannya': 'gonggong',
    'menggonggong': 'gonggong',
    'menggonggongi': 'gonggong',
    'pergonglian': 'gongli',
    'menggongseng': 'gongseng',
    'penggongsengan': 'gongseng',
    'menggonjakkan': 'gonjak',
    'gonjang-ganjing': 'gonjang',
    'gonjang-ganjingnya': 'gonjang',
    'gonjlang-ganjling': 'gonjlang',
    'menggonjokkan': 'gonjok',
    'bergonjong': 'gonjong',
    'bergontai': 'gontai',
    'menggontai': 'gontai',
    'mempergontai': 'gontai',
    'tergontai-gontai': 'gontai',
    'bergontok': 'gontok',
    'bergontokan': 'gontok',
    'gontok-gontokan': 'gontok',
    'menggonyakkan': 'gonyak',
    'menggonyeh': 'gonyeh',
    'menggonyel': 'gonyel',
    'menggonyoh': 'gonyoh',
    'tergopoh': 'gopoh',
    'gorap-gorap': 'gorap',
    'menggorek-gorek': 'gorek',
    'gorengan': 'goreng',
    'gorengannya': 'goreng',
    'menggoreng': 'goreng',
    'menggorengnya': 'goreng',
    'penggorengan': 'goreng',
    'penggorengannya': 'goreng',
    'menggoreng-goreng': 'goreng',
    'menggoroh': 'goroh',
    'menggorok': 'gorok',
    'menggoroknya': 'gorok',
    'menggorokkan': 'gorok',
    'menggorokan': 'gorok',
    'menggorokmu': 'gorok',
    'penggorokan': 'gorok',
    'penggorokannya': 'gorok',
    'bergosip': 'gosip',
    'bergosiplah': 'gosip',
    'penggosip': 'gosip',
    'pergosipan': 'gosip',
    'menggosipkan': 'gosip',
    'menggosipkannya': 'gosip',
    'gosokan': 'gosok',
    'gosokannya': 'gosok',
    'bergosok': 'gosok',
    'menggosok': 'gosok',
    'menggosoknya': 'gosok',
    'menggosokkan': 'gosok',
    'menggosokkannya': 'gosok',
    'menggosoki': 'gosok',
    'menggosokan': 'gosok',
    'penggosok': 'gosok',
    'penggosoknya': 'gosok',
    'penggosokan': 'gosok',
    'bergosokan': 'gosok',
    'penggosokannya': 'gosok',
    'mempergosokkan': 'gosok',
    'menggosok-gosok': 'gosok',
    'menggosok-gosoknya': 'gosok',
    'menggosok-gosokkan': 'gosok',
    'menggosok-gosokkannya': 'gosok',
    'menggosok-gosokan': 'gosok',
    'bergosong': 'gosong',
    'menggotes': 'gotes',
    'menggotong': 'gotong',
    'menggotongnya': 'gotong',
    'bergotong royong': 'gotong royong',
    'kegotongroyongan': 'gotong royong',
    'kegotongroyongannya': 'gotong royong',
    'bergoyah': 'goyah',
    'kegoyahan': 'goyah',
    'tergoyahkan': 'goyah',
    'tergoyahkannya': 'goyah',
    'menggoyahkan': 'goyah',
    'menggoyahkannya': 'goyah',
    'menggoyak': 'goyak',
    'menggoyakan': 'goyak',
    'kegramatikalan': 'gramatikal',
    'menggranat': 'granat',
    'penggranatan': 'granat',
    'bergranula': 'granula',
    'menggrataki': 'gratak',
    'menggratiskan': 'gratis',
    'menggratiskannya': 'gratis',
    'menggraver': 'graver',
    'grempelan': 'grempel',
    'menggual': 'gual',
    'gual-gail': 'gual',
    'peguam': 'guam',
    'berguam': 'guam',
    'perguaman': 'guam',
    'mengguar': 'guar',
    'gubahan': 'gubah',
    'gubahannya': 'gubah',
    'penggubah': 'gubah',
    'penggubahnya': 'gubah',
    'penggubahan': 'gubah',
    'menggubah': 'gubah',
    'menggubahnya': 'gubah',
    'penggubahannya': 'gubah',
    'menggubal': 'gubal',
    'menggubel': 'gubel',
    'kegubernuran': 'gubernur',
    'kegubernurannya': 'gubernur',
    'menggubit': 'gubit',
    'gubrisan': 'gubris',
    'menggubris': 'gubris',
    'menggubrisnya': 'gubris',
    'menggubrislah': 'gubris',
    'menggubriskan': 'gubris',
    'pergudangan': 'gudang',
    'pergudangannya': 'gudang',
    'penggudangan': 'gudang',
    'menggudangkan': 'gudang',
    'menggudangkannya': 'gudang',
    'tergudik-gudik': 'gudik',
    'gugahan': 'gugah',
    'tergugah': 'gugah',
    'tergugahnya': 'gugah',
    'tergugahkan': 'gugah',
    'menggugah': 'gugah',
    'menggugahnya': 'gugah',
    'menggugahkan': 'gugah',
    'penggugah': 'gugah',
    'penggugahan': 'gugah',
    'gugatan': 'gugat',
    'gugatannya': 'gugat',
    'tergugat': 'gugat',
    'tergugatnya': 'gugat',
    'penggugat': 'gugat',
    'penggugatnya': 'gugat',
    'penggugatan': 'gugat',
    'menggugat': 'gugat',
    'menggugatnya': 'gugat',
    'menggugatkan': 'gugat',
    'menggugatan': 'gugat',
    'penggugatannya': 'gugat',
    'menggugu': 'gugu',
    'menggugukan': 'guguk',
    'tergugu-gugu': 'gugu',
    'mengguguh': 'guguh',
    'terguguk': 'guguk',
    'mengguguk': 'guguk',
    'penggugup': 'gugup',
    'kegugupan': 'gugup',
    'kegugupannya': 'gugup',
    'kegugupanmu': 'gugup',
    'menggugupkan': 'gugup',
    'guguran': 'gugur',
    'gugurannya': 'gugur',
    'keguguran': 'gugur',
    'kegugurannya': 'gugur',
    'berguguran': 'gugur',
    'bergugurannya': 'gugur',
    'pengguguran': 'gugur',
    'menggugurkan': 'gugur',
    'menggugurkannya': 'gugur',
    'menggugurkanmu': 'gugur',
    'gugusan': 'gugus',
    'gugusannya': 'gugus',
    'bergugus-gugus': 'gugus',
    'mengguit': 'guit',
    'mengguit-guit': 'guit',
    'bergula': 'gula',
    'menggula': 'gula',
    'menggulai': 'gulai',
    'pergulaan': 'gula',
    'gula-gula': 'gula',
    'gula-gulanya': 'gula',
    'kegulanaan': 'gulana',
    'pegulat': 'gulat',
    'pegulatnya': 'gulat',
    'pegulatku': 'gulat',
    'bergulat': 'gulat',
    'pergulatan': 'gulat',
    'pergulatannya': 'gulat',
    'bergulir': 'gulir',
    'bergulirnya': 'gulir',
    'bergulirlah': 'gulir',
    'bergulirkan': 'gulir',
    'berguliran': 'gulir',
    'tergulir': 'gulir',
    'menggulir': 'gulir',
    'menggulirnya': 'gulir',
    'menggulirkan': 'gulir',
    'menggulirkannya': 'gulir',
    'mengguliran': 'gulir',
    'pengguliran': 'gulir',
    'guludan': 'gulud',
    'gulungan': 'gulung',
    'gulungannya': 'gulung',
    'tergulung': 'gulung',
    'bergulung': 'gulung',
    'menggulung': 'gulung',
    'menggulungnya': 'gulung',
    'menggulungkan': 'gulung',
    'menggulungku': 'gulung',
    'penggulungan': 'gulung',
    'bergulung-gulung': 'gulung',
    'gulung-menggulung': 'gulung',
    'tergulut': 'gulut',
    'bergulut': 'gulut',
    'menggulut': 'gulut',
    'tergulut-gulut': 'gulut',
    'bergulut-gulut': 'gulut',
    'menggumalkan': 'gumal',
    'menggumbuk': 'gumbuk',
    'segumpal': 'gumpa',
    'segumpalan': 'gumpa',
    'bergumul': 'gumul',
    'bergumulnya': 'gumul',
    'bergumulan': 'gumul',
    'menggumuli': 'gumul',
    'pergumulan': 'gumul',
    'pergumulannya': 'gumul',
    'guncangan': 'guncang',
    'guncangannya': 'guncang',
    'terguncang': 'guncang',
    'terguncangnya': 'guncang',
    'terguncanglah': 'guncang',
    'terguncangkan': 'guncang',
    'berguncang': 'guncang',
    'berguncangan': 'guncang',
    'keguncangan': 'guncang',
    'mengguncangkan': 'guncang',
    'mengguncangkannya': 'guncang',
    'kegundahan': 'gundah',
    'kegundahannya': 'gundah',
    'mempergundah': 'gundah',
    'menggundahkan': 'gundah',
    'gundalan': 'gundal',
    'pergundalan': 'gundal',
    'gundala-gundala': 'gundala',
    'pergundikan': 'gundik',
    'mempergundik': 'gundik',
    'mempergundikkan': 'gundik',
    'bergundu': 'gundu',
    'gundukan': 'gunduk',
    'gundukannya': 'gunduk',
    'bergunduk-gunduk': 'gunduk',
    'bergundul': 'gundul',
    'menggundul': 'gundul',
    'menggundulkan': 'gundul',
    'menggunduli': 'gundul',
    'menggundulinya': 'gundul',
    'penggundulan': 'gundul',
    'penggundulannya': 'gundul',
    'mengegungkan': 'gung',
    'menggunggung': 'gunggung',
    'gunjingan': 'gunjing',
    'gunjingannya': 'gunjing',
    'bergunjing': 'gunjing',
    'menggunjing': 'gunjing',
    'menggunjingnya': 'gunjing',
    'menggunjingkan': 'gunjing',
    'menggunjingkannya': 'gunjing',
    'pergunjingan': 'gunjing',
    'pergunjingannya': 'gunjing',
    'mempergunjingkan': 'gunjing',
    'mempergunjingkannya': 'gunjing',
    'guntang-guntang': 'guntang',
    'guntingan': 'gunting',
    'guntingannya': 'gunting',
    'penggunting': 'gunting',
    'pengguntingan': 'gunting',
    'menggunting': 'gunting',
    'mengguntingnya': 'gunting',
    'mengguntingkan': 'gunting',
    'mengguntung': 'guntung',
    'mengguntungkan': 'guntung',
    'mengguntur': 'guntur',
    'menggunturkan': 'guntur',
    'gunungan': 'gunung',
    'gunungannya': 'gunung',
    'pegunungan': 'gunung',
    'pegunungannya': 'gunung',
    'menggunung': 'gunung',
    'menggunungnya': 'gunung',
    'menggununglah': 'gunung',
    'gunung-ganang': 'gunung',
    'gunung-gemunung': 'gunung',
    'gunung-gunungan': 'gunung',
    'bergunung-gunung': 'gunung',
    'menggunyam': 'gunyam',
    'bergurah': 'gurah',
    'menggurah': 'gurah',
    'mengguram': 'guram',
    'keguraman': 'guram',
    'guratan': 'gurat',
    'guratannya': 'gurat',
    'tergurat': 'gurat',
    'menggurat': 'gurat',
    'mengguratnya': 'gurat',
    'mengguratkan': 'gurat',
    'menggurdi': 'gurdi',
    'menggurik': 'gurik',
    'bergurindam': 'gurindam',
    'guritan': 'gurit',
    'menggurit': 'gurit',
    'menggurita': 'gurita',
    'mengguritanya': 'gurita',
    'berguru': 'guru',
    'bergurunya': 'guru',
    'bergurulah': 'guru',
    'keguruan': 'guru',
    'menggurui': 'guru',
    'mengguruinya': 'guru',
    'perguruan': 'guru',
    'perguruannya': 'guru',
    'mengguruh': 'guruh',
    'menggusah': 'gusah',
    'kegusaran': 'gusar',
    'kegusarannya': 'gusar',
    'menggusari': 'gusar',
    'menggusarkan': 'gusar',
    'menggusel': 'gusel',
    'menggusrek': 'gusrek',
    'gusuran': 'gusur',
    'gusurannya': 'gusur',
    'tergusur': 'gusur',
    'tergusurnya': 'gusur',
    'menggusur': 'gusur',
    'menggusurnya': 'gusur',
    'pergusuran': 'gusur',
    'penggusuran': 'gusur',
    'penggusurannya': 'gusur',
    'menggutik': 'gutik',
    'guyonan': 'guyon',
    'guyonannya': 'guyon',
    'guyonannyalah': 'guyon',
    'guyonanmu': 'guyon',
    'berguyub': 'guyub',
    'peguyuban': 'guyub',
    'terguyur': 'guyur',
    'mengguyur': 'guyur',
    'mengguyurnya': 'guyur',
    'mengguyurkan': 'guyur',
    'mengguyurkannya': 'guyur',
    'mengguyuri': 'guyur',
    'sehabis': 'habis',
    'sehabisnya': 'habis',
    'berhabis': 'habis',
    'kehabisan': 'habis',
    'kehabisanlah': 'habis',
    'menghabisi': 'habis',
    'menghabisinya': 'habis',
    'menghabisikan': 'habis',
    'menghabisiku': 'habis',
    'menghabisimu': 'habis',
    'habis-habis': 'habis',
    'habis-habisnya': 'habis',
    'habis-habiskan': 'habis',
    'habis-habisan': 'habis',
    'terhabiskan': 'habis',
    'penghabisan': 'habis',
    'penghabisannya': 'habis',
    'menghabiskan': 'habis',
    'menghabiskannya': 'habis',
    'menghabiskankan': 'habis',
    'sehabis-habisnya': 'habis',
    'menghablur': 'hablur',
    'penghabluran': 'hablur',
    'menghablurkan': 'hablur',
    'berhad': 'had',
    'berhadan': 'had',
    'terhad': 'had',
    'terhadi': 'had',
    'terhadan': 'had',
    'menghadkan': 'had',
    'hadapan': 'hadap',
    'hadapannya': 'hadap',
    'hadapanku': 'hadap',
    'hadapanmu': 'hadap',
    'terhadap': 'hadap',
    'terhadapnya': 'hadap',
    'terhadapi': 'hadap',
    'terhadapan': 'hadap',
    'terhadapku': 'hadap',
    'terhadapmu': 'hadap',
    'terhadap-mu': 'hadap',
    'menghadap': 'hadap',
    'menghadapnya': 'hadap',
    'menghadaplah': 'hadap',
    'menghadapkan': 'hadap',
    'menghadapkannya': 'hadap',
    'menghadapi': 'hadap',
    'menghadapan': 'hadap',
    'menghadapku': 'hadap',
    'menghadapmu': 'hadap',
    'bersehadap': 'hadap',
    'menghadapinya': 'hadap',
    'menghadapii': 'hadap',
    'menghadapiku': 'hadap',
    'menghadapimu': 'hadap',
    'penghadapan': 'hadap',
    'memperhadapkan': 'hadap',
    'berhadap-hadapan': 'hadap',
    'berhadapan': 'hadap',
    'berhadiah': 'hadiah',
    'berhadiahkan': 'hadiah',
    'menghadiahkan': 'hadiah',
    'menghadiahkannya': 'hadiah',
    'berhadir': 'hadir',
    'berhadirkan': 'hadir',
    'kehadiran': 'hadir',
    'kehadirannya': 'hadir',
    'kehadiranan': 'hadir',
    'kehadiranku': 'hadir',
    'kehadiranmu': 'hadir',
    'menghadiri': 'hadir',
    'menghadirinya': 'hadir',
    'menghadirikan': 'hadir',
    'menghadirkan': 'hadir',
    'menghadirkannya': 'hadir',
    'menghadirkanku': 'hadir',
    'hafalan': 'hafal',
    'hafalannya': 'hafal',
    'menghafal': 'hafal',
    'menghafalnya': 'hafal',
    'menghafalkan': 'hafal',
    'menghafalkannya': 'hafal',
    'menghafalan': 'hafal',
    'menghajar': 'hajar',
    'menghajarnya': 'hajar',
    'menghajarkan': 'hajar',
    'menghajari': 'hajar',
    'menghajarmu': 'hajar',
    'berhaji': 'haji',
    'berhajinya': 'haji',
    'kehajian': 'haji',
    'perhajian': 'haji',
    'menghajikan': 'haji',
    'berhak': 'hak',
    'berhaknya': 'hak',
    'berhaklah': 'hak',
    'menghaki': 'hak',
    'menghakikan': 'hak',
    'menghakkan': 'hak',
    'berhakim': 'hakim',
    'kehakiman': 'hakim',
    'kehakimannya': 'hakim',
    'menghakimi': 'hakim',
    'menghakiminya': 'hakim',
    'menghakimilah': 'hakim',
    'menghakimiku': 'hakim',
    'menghakimimu': 'hakim',
    'penghakiman': 'hakim',
    'penghakimannya': 'hakim',
    'berhal': 'hal',
    'berhalan': 'hal',
    'terhal': 'hal',
    'terhalan': 'hal',
    'menghalai-balaikan': 'halai-balai',
    'penghalal': 'halal',
    'penghalalan': 'halal',
    'kehalalan': 'halal',
    'kehalalannya': 'halal',
    'menghalalkan': 'halal',
    'berhalalbihalal': 'halalbihalal',
    'halangan': 'halang',
    'halangannya': 'halang',
    'terhalang': 'halang',
    'terhalangnya': 'halang',
    'terhalangi': 'halang',
    'penghalang': 'halang',
    'penghalangnya': 'halang',
    'penghalangan': 'halang',
    'menghalang': 'halang',
    'menghalangnya': 'halang',
    'menghalangkan': 'halang',
    'menghalangi': 'halang',
    'menghalangan': 'halang',
    'berhalangan': 'halang',
    'berhalangannya': 'halang',
    'menghalanginya': 'halang',
    'menghalangiku': 'halang',
    'menghalangimu': 'halang',
    'menghalang-halangi': 'halang',
    'menghalang-halanginya': 'halang',
    'menghalau': 'halau',
    'menghalaunya': 'halau',
    'menghalaukan': 'halau',
    'penghalau': 'halau',
    'penghalauan': 'halau',
    'sehaluan': 'haluan',
    'berhaluan': 'haluan',
    'kehalusan': 'halus',
    'kehalusannya': 'halus',
    'menghalusi': 'halus',
    'memperhalus': 'halus',
    'memperhalusnya': 'halus',
    'menghaluskan': 'halus',
    'menghaluskannya': 'halus',
    'berhamba': 'hamba',
    'menghamba': 'hamba',
    'menghambakan': 'hamba',
    'menghambai': 'hamba',
    'perhambaan': 'hamba',
    'penghambaan': 'hamba',
    'penghambaannya': 'hamba',
    'memperhamba': 'hamba',
    'memperhambakan': 'hamba',
    'kehambaran': 'hambar',
    'hambatan': 'hambat',
    'hambatannya': 'hambat',
    'hambatanmu': 'hambat',
    'terhambat': 'hambat',
    'terhambatnya': 'hambat',
    'terhambatlah': 'hambat',
    'terhambatan': 'hambat',
    'menghambat': 'hambat',
    'menghambatnya': 'hambat',
    'menghambatkan': 'hambat',
    'menghambatku': 'hambat',
    'menghambatmu': 'hambat',
    'penghambat': 'hambat',
    'penghambatnya': 'hambat',
    'penghambatan': 'hambat',
    'penghambatannya': 'hambat',
    'memperhambat': 'hambat',
    'terhambat-hambat': 'hambat',
    'kehamilan': 'hamil',
    'kehamilannya': 'hamil',
    'kehamilanlah': 'hamil',
    'kehamilanan': 'hamil',
    'kehamilanku': 'hamil',
    'menghamili': 'hamil',
    'menghamilinya': 'hamil',
    'menghamiliku': 'hamil',
    'penghamilan': 'hamil',
    'menghamilkan': 'hamil',
    'kehampaan': 'hampa',
    'kehampaannya': 'hampa',
    'menghampakan': 'hampa',
    'hamparan': 'hampar',
    'hamparannya': 'hampar',
    'terhampar': 'hampar',
    'sehamparan': 'hampar',
    'menghampar': 'hampar',
    'menghamparkan': 'hampar',
    'menghampari': 'hampar',
    'hampirkan': 'hampir',
    'menghampiri': 'hampir',
    'menghampirinya': 'hampir',
    'menghampiriku': 'hampir',
    'menghampirimu': 'hampir',
    'hampir-hampir': 'hampir',
    'hampir-hampiran': 'hampir',
    'menghampirkan': 'hampir',
    'berhampiran': 'hampir',
    'menghamuni': 'hamun',
    'berhamun-hamun': 'hamun',
    'kehancuran': 'hancur',
    'kehancurannya': 'hancur',
    'penghancuran': 'hancur',
    'penghancurannya': 'hancur',
    'menghancurkan': 'hancur',
    'menghancurkannya': 'hancur',
    'menghancurkanku': 'hancur',
    'menghancurkanmu': 'hancur',
    'hancur-hancuran': 'hancur',
    'hancur-menghancurkan': 'hancur',
    'penghancurleburan': 'hancur lebur',
    'menghancurleburkan': 'hancur lebur',
    'menghancurluluhkan': 'hancur luluh',
    'berhandai-handai': 'handai',
    'menghangat': 'hangat',
    'menghangatnya': 'hangat',
    'menghangatkan': 'hangat',
    'menghangatkannya': 'hangat',
    'menghangati': 'hangat',
    'penghangat': 'hangat',
    'penghangatan': 'hangat',
    'kehangatan': 'hangat',
    'kehangatannya': 'hangat',
    'menghangatinya': 'hangat',
    'menghangatkanku': 'hangat',
    'kehangusan': 'hangus',
    'menghangus': 'hangus',
    'menghangusnya': 'hangus',
    'menghanguskan': 'hangus',
    'menghanguskannya': 'hangus',
    'menghangusan': 'hangus',
    'hantaman': 'hantam',
    'hantamannya': 'hantam',
    'berhantam': 'hantam',
    'berhantaman': 'hantam',
    'menghantam': 'hantam',
    'menghantamnya': 'hantam',
    'menghantamkan': 'hantam',
    'menghantamkannya': 'hantam',
    'menghantami': 'hantam',
    'menghantamku': 'hantam',
    'menghantammu': 'hantam',
    'hantaran': 'hantar',
    'hantarannya': 'hantar',
    'terhantar': 'hantar',
    'terhantarkan': 'hantar',
    'berhantar': 'hantar',
    'menghantar': 'hantar',
    'menghantarnya': 'hantar',
    'menghantarkan': 'hantar',
    'menghantarkannya': 'hantar',
    'penghantar': 'hantar',
    'penghantarnya': 'hantar',
    'penghantaran': 'hantar',
    'berhantaran': 'hantar',
    'menghantarkankan': 'hantar',
    'menghantarkanku': 'hantar',
    'menghantarkanmu': 'hantar',
    'berhanyut': 'hanyut',
    'berhanyutan': 'hanyut',
    'terhanyut': 'hanyut',
    'penghanyutan': 'hanyut',
    'menghanyutkan': 'hanyut',
    'menghanyutkannya': 'hanyut',
    'menghanyutkankan': 'hanyut',
    'berhanyut-hanyut': 'hanyut',
    'terhapus': 'hapus',
    'terhapusnya': 'hapus',
    'terhapuskan': 'hapus',
    'penghapus': 'hapus',
    'penghapusnya': 'hapus',
    'penghapuskan': 'hapus',
    'penghapusan': 'hapus',
    'menghapus': 'hapus',
    'menghapusnya': 'hapus',
    'menghapuskan': 'hapus',
    'menghapuskannya': 'hapus',
    'menghapusan': 'hapus',
    'menghapusmu': 'hapus',
    'penghapusannya': 'hapus',
    'terharak-harak': 'harak',
    'pengharaman': 'haram',
    'mengharamkan': 'haram',
    'mengharamkannya': 'haram',
    'harapan': 'harap',
    'harapannya': 'harap',
    'harapanlah': 'harap',
    'harapankan': 'harap',
    'harapanku': 'harap',
    'harapanmu': 'harap',
    'berharap': 'harap',
    'berharapnya': 'harap',
    'berharaplah': 'harap',
    'berharapkan': 'harap',
    'berharapan': 'harap',
    'mengharap': 'harap',
    'mengharapnya': 'harap',
    'mengharaplah': 'harap',
    'mengharapkan': 'harap',
    'mengharapkannya': 'harap',
    'mengharapi': 'harap',
    'mengharapan': 'harap',
    'harap-harap': 'harap',
    'pengharapan': 'harap',
    'pengharapannya': 'harap',
    'mengharapkanku': 'harap',
    'harap-harapan': 'harap',
    'berpengharapan': 'harap',
    'terharap-harap': 'harap',
    'harap-harap cemas': 'harap',
    'hardikan': 'hardik',
    'hardikannya': 'hardik',
    'menghardik': 'hardik',
    'menghardiknya': 'hardik',
    'harian': 'hari',
    'hariannya': 'hari',
    'harianlah': 'hari',
    'hariani': 'hari',
    'harianku': 'hari',
    'harianmu': 'hari',
    'sehari': 'hari',
    'seharinya': 'hari',
    'seharian': 'hari',
    'berhari': 'hari',
    'sehariannya': 'hari',
    'keseharian': 'hari',
    'kesehariannya': 'hari',
    'keseharianku': 'hari',
    'keseharianmu': 'hari',
    'sehari-hari': 'hari',
    'sehari-harinya': 'hari',
    'sehari-harilah': 'hari',
    'sehari-hariku': 'hari',
    'sehari-harimu': 'hari',
    'berhari-hari': 'hari',
    'sehari-harian': 'hari',
    'mengharimau': 'harimau',
    'pengharit': 'harit',
    'pengharkatan': 'harkat',
    'mengharmonikan': 'harmoni',
    'keharmonisan': 'harmonis',
    'keharmonisannya': 'harmonis',
    'pengharmonisan': 'harmonis',
    'mengharmoniskan': 'harmonis',
    'mengharmoniskannya': 'harmonis',
    'berharta': 'harta',
    'terharu biru': 'haru biru',
    'mengharu biru': 'haru biru',
    'mengharubirukan': 'haru biru',
    'terharu': 'haru',
    'terharunya': 'haru',
    'terharulah': 'haru',
    'pengharu': 'haru',
    'keharuan': 'haru',
    'keharuannya': 'haru',
    'mengharu': 'haru',
    'mengharukan': 'haru',
    'mengharukannya': 'haru',
    'mengharukanku': 'haru',
    'keterharuan': 'haru',
    'keterharuannya': 'haru',
    'mengharum': 'harum',
    'mengharumkan': 'harum',
    'mengharumi': 'harum',
    'keharuman': 'harum',
    'keharumannya': 'harum',
    'harum-haruman': 'harum',
    'keharusan': 'harus',
    'keharusannya': 'harus',
    'seharusnya': 'harus',
    'seharusnyanya': 'harus',
    'seharusnyalah': 'harus',
    'seharusnyakan': 'harus',
    'mengharuskan': 'harus',
    'mengharuskannya': 'harus',
    'mengharuskanku': 'harus',
    'mengharuskanmu': 'harus',
    'sehasta': 'hasta',
    'menghasta': 'hasta',
    'menghasud': 'hasud',
    'terhasut': 'hasut',
    'penghasut': 'hasut',
    'penghasutnya': 'hasut',
    'penghasutan': 'hasut',
    'menghasut': 'hasut',
    'menghasutnya': 'hasut',
    'penghasutannya': 'hasut',
    'penghasutani': 'hasut',
    'sehati': 'hati',
    'sehatinya': 'hati',
    'berhati': 'hati',
    'berhatian': 'hati',
    'hati-hati': 'hati',
    'hati-hatinya': 'hati',
    'hati-hatilah': 'hati',
    'hati-hatian': 'hati',
    'berhati-hati': 'hati',
    'berhati-hatinya': 'hati',
    'berhati-hatilah': 'hati',
    'berhati-hatii': 'hati',
    'berhati-hatian': 'hati',
    'kehati-hatian': 'hati',
    'kehati-hatiannya': 'hati',
    'kehausan': 'haus',
    'kehausannya': 'haus',
    'menghauskan': 'haus',
    'berhawa': 'hawa',
    'menghawa': 'hawa',
    'penghawaan': 'hawa',
    'menghawakan': 'hawa',
    'penghayat': 'hayat',
    'penghayatnya': 'hayat',
    'penghayatan': 'hayat',
    'menghayati': 'hayat',
    'menghayatinya': 'hayat',
    'penghayatannya': 'hayat',
    'mengheban': 'heban',
    'kehebatan': 'hebat',
    'kehebatannya': 'hebat',
    'kehebatanku': 'hebat',
    'kehebatanmu': 'hebat',
    'menghebat': 'hebat',
    'menghebatnya': 'hebat',
    'menghebatkan': 'hebat',
    'memperhebat': 'hebat',
    'hebat-hebatan': 'hebat',
    'kehebohan': 'heboh',
    'kehebohannya': 'heboh',
    'menghebohkan': 'heboh',
    'menghebohkannya': 'heboh',
    'berhektare-hektare': 'hektare',
    'helaan': 'hela',
    'menghela': 'hela',
    'menghelanya': 'hela',
    'menghelakan': 'hela',
    'penghela': 'hela',
    'penghelanya': 'hela',
    'sehelai': 'helai',
    'sehelainya': 'helai',
    'berhelai': 'helai',
    'berhelat': 'helat',
    'berhelatan': 'helat',
    'menghelat': 'helat',
    'menghelatnya': 'helat',
    'perhelatan': 'helat',
    'perhelatannya': 'helat',
    'perhelatanan': 'helat',
    'terhembalang': 'hembalang',
    'berhembalang': 'hembalang',
    'menghembalang': 'hembalang',
    'menghembalangkan': 'hembalang',
    'terhempap': 'hempap',
    'menghempap': 'hempap',
    'menghempapkan': 'hempap',
    'hempasan': 'hempas',
    'hempasannya': 'hempas',
    'terhempas': 'hempas',
    'terhempasnya': 'hempas',
    'menghempas': 'hempas',
    'menghempasnya': 'hempas',
    'menghempaskan': 'hempas',
    'menghempaskannya': 'hempas',
    'penghempasan': 'hempas',
    'kehendak': 'hendak',
    'kehendaknya': 'hendak',
    'kehendakkan': 'hendak',
    'kehendaki': 'hendak',
    'kehendakku': 'hendak',
    'kehendakmu': 'hendak',
    'kehendak-mu': 'hendak',
    'hendaklah': 'hendak',
    'sekehendak': 'hendak',
    'sekehendaknya': 'hendak',
    'menghendaki': 'hendak',
    'menghendakinya': 'hendak',
    'berkehendak': 'hendak',
    'terhengit-hengit': 'hengit',
    'keheningan': 'hening',
    'keheningannya': 'hening',
    'pengheningan': 'hening',
    'mengheningkan': 'hening',
    'penghentar': 'hentar',
    'keheranan': 'heran',
    'keheranannya': 'heran',
    'keherananan': 'heran',
    'keherananku': 'heran',
    'mengherani': 'heran',
    'mengherankan': 'heran',
    'mengherankannya': 'heran',
    'mengherankankan': 'heran',
    'mengherankanku': 'heran',
    'terheran-heran': 'heran',
    'keheran-heranan': 'heran',
    'keheroikan': 'heroik',
    'keheterogenan': 'heterogen',
    'kehewanan': 'hewan',
    'kehewanannya': 'hewan',
    'hibahan': 'hibah',
    'penghibahan': 'hibah',
    'menghibahkan': 'hibah',
    'menghibahkannya': 'hibah',
    'kehibukan': 'hibuk',
    'hiburan': 'hibur',
    'hiburannya': 'hibur',
    'hiburanmu': 'hibur',
    'terhibur': 'hibur',
    'terhiburnya': 'hibur',
    'terhiburlah': 'hibur',
    'penghibur': 'hibur',
    'penghiburnya': 'hibur',
    'penghiburan': 'hibur',
    'penghiburku': 'hibur',
    'menghibur': 'hibur',
    'menghiburnya': 'hibur',
    'menghiburlah': 'hibur',
    'menghiburkan': 'hibur',
    'menghiburan': 'hibur',
    'menghiburku': 'hibur',
    'menghiburmu': 'hibur',
    'penghiburannya': 'hibur',
    'hidangan': 'hidang',
    'hidangannya': 'hidang',
    'hidanganmu': 'hidang',
    'terhidang': 'hidang',
    'sehidangan': 'hidang',
    'berhidangan': 'hidang',
    'penghidangan': 'hidang',
    'menghidangkan': 'hidang',
    'menghidangkannya': 'hidang',
    'menghidrogenasi': 'hidrogenasi',
    'menghidrolisis': 'hidrolisis',
    'menghidroponikkan': 'hidroponik',
    'penghidu': 'hidu',
    'menghidu': 'hidu',
    'menghidukan': 'hidu',
    'penghiduan': 'hidu',
    'kehidupan': 'hidup',
    'kehidupannya': 'hidup',
    'kehidupanan': 'hidup',
    'kehidupanku': 'hidup',
    'kehidupanmu': 'hidup',
    'menghidupi': 'hidup',
    'menghidupinya': 'hidup',
    'menghidupimu': 'hidup',
    'memperhidup': 'hidup',
    'penghidupan': 'hidup',
    'penghidupannya': 'hidup',
    'menghidupkan': 'hidup',
    'menghidupkannya': 'hidup',
    'menghierarkikan': 'hierarki',
    'berhijau daun': 'hijau daun',
    'hijauan': 'hijau',
    'hijauannya': 'hijau',
    'penghijau': 'hijau',
    'penghijauan': 'hijau',
    'menghijau': 'hijau',
    'menghijaunya': 'hijau',
    'menghijaukan': 'hijau',
    'penghijauannya': 'hijau',
    'kehijau-hijauan': 'hijau',
    'penghijrahan': 'hijrah',
    'menghijrahkan': 'hijrah',
    'menghijrahkannya': 'hijrah',
    'berhikayat': 'hikayat',
    'menghikayatkan': 'hikayat',
    'berhikmah': 'hikmah',
    'menghilang': 'hilang',
    'menghilangnya': 'hilang',
    'menghilanglah': 'hilang',
    'menghilangkan': 'hilang',
    'menghilangkannya': 'hilang',
    'menghilangi': 'hilang',
    'menghilangan': 'hilang',
    'kehilangan': 'hilang',
    'kehilangannya': 'hilang',
    'kehilanganlah': 'hilang',
    'kehilanganan': 'hilang',
    'kehilanganku': 'hilang',
    'kehilanganmu': 'hilang',
    'penghilangan': 'hilang',
    'penghilangannya': 'hilang',
    'hilang-hilang': 'hilang',
    'hilang-hilangan': 'hilang',
    'menghilangkani': 'hilang',
    'berhilau': 'hilau',
    'berhilau-hilau': 'hilau',
    'sehilir': 'hilir',
    'menghilir': 'hilir',
    'menghilirkan': 'hilir',
    'berhiliran': 'hilir',
    'menghiliri': 'hilir',
    'himpunan': 'himpun',
    'himpunanan': 'himpun',
    'berhimpun': 'himpun',
    'berhimpunnya': 'himpun',
    'berhimpunan': 'himpun',
    'terhimpun': 'himpun',
    'terhimpunnya': 'himpun',
    'terhimpunlah': 'himpun',
    'menghimpun': 'himpun',
    'menghimpunnya': 'himpun',
    'menghimpunan': 'himpun',
    'perhimpunan': 'himpun',
    'perhimpunannya': 'himpun',
    'penghimpunan': 'himpun',
    'penghimpunannya': 'himpun',
    'menghimpunkan': 'himpun',
    'menghinadinakan': 'hina dina',
    'hinaan': 'hina',
    'hinaannya': 'hina',
    'sehina': 'hina',
    'terhina': 'hina',
    'terhinanya': 'hina',
    'terhinakan': 'hina',
    'berhina': 'hina',
    'menghina': 'hina',
    'menghinanya': 'hina',
    'menghinalah': 'hina',
    'menghinakan': 'hina',
    'menghinakannya': 'hina',
    'menghinaku': 'hina',
    'menghinamu': 'hina',
    'kehinaan': 'hina',
    'penghinaan': 'hina',
    'penghinaannya': 'hina',
    'penghinaanlah': 'hina',
    'hina-menghinakan': 'hina',
    'menghinap-hinap': 'hinap',
    'terhindar': 'hindar',
    'terhindarnya': 'hindar',
    'terhindarlah': 'hindar',
    'terhindarkan': 'hindar',
    'terhindarkannya': 'hindar',
    'terhindari': 'hindar',
    'menghindar': 'hindar',
    'menghindarnya': 'hindar',
    'menghindarlah': 'hindar',
    'menghindarkan': 'hindar',
    'menghindarkannya': 'hindar',
    'menghindari': 'hindar',
    'menghindarinya': 'hindar',
    'menghindarikan': 'hindar',
    'menghindariku': 'hindar',
    'menghindarimu': 'hindar',
    'penghindaran': 'hindar',
    'penghindarannya': 'hindar',
    'berhindu': 'hindu',
    'berhingga': 'hingga',
    'terhingga': 'hingga',
    'perhinggaan': 'hingga',
    'menghinggakan': 'hingga',
    'menghinggakannya': 'hingga',
    'memperhinggakan': 'hingga',
    'menghinggapi': 'hinggap',
    'menghinggapinya': 'hinggap',
    'menghinggapiku': 'hinggap',
    'menghinggut': 'hinggut',
    'terhinggut-hinggut': 'hinggut',
    'menghipnosis': 'hipnosis',
    'menghipnosisnya': 'hipnosis',
    'kehiponiman': 'hiponim',
    'menghirap': 'hirap',
    'menghiraukan': 'hirau',
    'menghiraukannya': 'hirau',
    'menghiraukanku': 'hirau',
    'menghiruk': 'hiruk',
    'penghiruk': 'hiruk',
    'menghirukkan': 'hiruk',
    'menghirup': 'hirup',
    'menghirupnya': 'hirup',
    'penghirupan': 'hirup',
    'terhisab': 'hisab',
    'menghisab': 'hisab',
    'menghisabkan': 'hisab',
    'menghitam': 'hitam',
    'menghitamnya': 'hitam',
    'menghitamkan': 'hitam',
    'menghitamkannya': 'hitam',
    'penghitam': 'hitam',
    'penghitaman': 'hitam',
    'kehitaman': 'hitam',
    'menghitami': 'hitam',
    'kehitam-hitaman': 'hitam',
    'kehitam-hitamanan': 'hitam',
    'menghitamputihkan': 'hitam putih',
    'menghitam-memutihkan': 'hitam putih',
    'hitungan': 'hitung',
    'hitungannya': 'hitung',
    'hitungannyalah': 'hitung',
    'hitunganku': 'hitung',
    'terhitung': 'hitung',
    'terhitungnya': 'hitung',
    'terhitunglah': 'hitung',
    'terhitungkan': 'hitung',
    'terhitungan': 'hitung',
    'berhitung': 'hitung',
    'berhitungnya': 'hitung',
    'menghitung': 'hitung',
    'menghitungnya': 'hitung',
    'menghitungkan': 'hitung',
    'menghitungi': 'hitung',
    'menghitungan': 'hitung',
    'perhitungan': 'hitung',
    'perhitungannya': 'hitung',
    'perhitunganku': 'hitung',
    'perhitunganmu': 'hitung',
    'penghitungan': 'hitung',
    'penghitungannya': 'hitung',
    'hitung-hitung': 'hitung',
    'hitung-hitungnya': 'hitung',
    'hitung-hitungan': 'hitung',
    'hitung-hitungannya': 'hitung',
    'hitung-hitunganan': 'hitung',
    'memperhitungkan': 'hitung',
    'memperhitungkannya': 'hitung',
    'memperhitungkanku': 'hitung',
    'menghitung-hitung': 'hitung',
    'menghitung-hitungnya': 'hitung',
    'penghobi': 'hobi',
    'penghobinya': 'hobi',
    'berhoki': 'hoki',
    'menghomoi': 'homo',
    'kehomofonan': 'homofon',
    'kehomogenan': 'homogen',
    'kehomografan': 'homograf',
    'kehomoniman': 'homonim',
    'menghonori': 'honor',
    'perhotelan': 'hotel',
    'perhotelannya': 'hotel',
    'berhujah': 'hujah',
    'menghujananginkan': 'hujan angin',
    'berhujan': 'hujan',
    'kehujanan': 'hujan',
    'kehujananan': 'hujan',
    'menghujan': 'hujan',
    'menghujankan': 'hujan',
    'menghujani': 'hujan',
    'menghujaninya': 'hujan',
    'menghujaniku': 'hujan',
    'memperhujankan': 'hujan',
    'berhujan-hujan': 'hujan',
    'berhujan-hujanan': 'hujan',
    'menghujan-hujankan': 'hujan',
    'menghujanpanaskan': 'hujan panas',
    'hujatan': 'hujat',
    'hujatannya': 'hujat',
    'hujatanmu': 'hujat',
    'menghujat': 'hujat',
    'menghujatnya': 'hujat',
    'penghujat': 'hujat',
    'penghujatnya': 'hujat',
    'penghujatan': 'hujat',
    'penghujung': 'hujung',
    'penghujungnya': 'hujung',
    'kehujungan': 'hujung',
    'hukuman': 'hukum',
    'hukumannya': 'hukum',
    'hukumanan': 'hukum',
    'hukumanku': 'hukum',
    'hukumanmu': 'hukum',
    'hukuman-mu': 'hukum',
    'berhukum': 'hukum',
    'terhukum': 'hukum',
    'terhukumnya': 'hukum',
    'menghukum': 'hukum',
    'menghukumnya': 'hukum',
    'menghukumi': 'hukum',
    'menghukuman': 'hukum',
    'menghukumku': 'hukum',
    'menghukummu': 'hukum',
    'kehukuman': 'hukum',
    'menghukumkan': 'hukum',
    'berhulu': 'hulu',
    'menghulu': 'hulu',
    'penghuluan': 'hulu',
    'berhulukan': 'hulu',
    'menghulukan': 'hulu',
    'berhuma': 'huma',
    'perhumaan': 'huma',
    'memperhuma': 'huma',
    'dihumasi': 'humas',
    'kehumasan': 'humas',
    'kehumasannya': 'humas',
    'perhumasan': 'humas',
    'terhunjam': 'hunjam',
    'menghunjam': 'hunjam',
    'menghunjamnya': 'hunjam',
    'menghunjamkan': 'hunjam',
    'menghunjamkannya': 'hunjam',
    'menghunjami': 'hunjam',
    'terhunus': 'hunus',
    'terhunusnya': 'hunus',
    'menghunus': 'hunus',
    'menghunuskan': 'hunus',
    'menghunuskannya': 'hunus',
    'berhura-hura': 'hura-hura',
    'berhuruf': 'huruf',
    'menghutan': 'hutan',
    'menghutankan': 'hutan',
    'menghutani': 'hutan',
    'kehutanan': 'hutan',
    'kehutanannya': 'hutan',
    'kehutananlah': 'hutan',
    'kehutananan': 'hutan',
    'perhutanan': 'hutan',
    'penghutanan': 'hutan',
    'terhuyung': 'huyung',
    'seia': 'ia',
    'seiaku': 'ia',
    'beria': 'ria',
    'beriakan': 'riak',
    'beriaku': 'ria',
    'beria-ia': 'ia',
    'mengiakan': 'ia',
    'mengiakannya': 'ia',
    'pengiba': 'iba',
    'keibaan': 'iba',
    'keibaannya': 'iba',
    'mengibai': 'iba',
    'mengibakan': 'iba',
    'beriba-iba': 'iba',
    'beribadah': 'ibadah',
    'beribadahnya': 'ibadah',
    'peribadahan': 'ibadah',
    'peribadahannya': 'ibadah',
    'beribadat': 'ibadat',
    'beribadatan': 'ibadat',
    'peribadatan': 'ibadat',
    'peribadatannya': 'ibadat',
    'beribarat': 'ibarat',
    'pengibaratan': 'ibarat',
    'mengibaratkan': 'ibarat',
    'mengibaratkannya': 'ibarat',
    'mengibing': 'ibing',
    'mengibrit': 'ibrit',
    'beribu': 'ibu',
    'beribukan': 'ibu',
    'keibuan': 'ibu',
    'keibuannya': 'ibu',
    'mengicip': 'icip',
    'mengicipi': 'icip',
    'mengidah': 'idah',
    'mengidahkan': 'idah',
    'idaman': 'idam',
    'idamannya': 'idam',
    'idamanku': 'idam',
    'idamanmu': 'idam',
    'mengidam': 'idam',
    'mengidamnya': 'idam',
    'mengidamkan': 'idam',
    'mengidamkannya': 'idam',
    'idam-idam': 'idam',
    'idam-idamkan': 'idam',
    'idam-idamkannya': 'idam',
    'idam-idaman': 'idam',
    'mengidam-idamkan': 'idam',
    'mengidam-idamkannya': 'idam',
    'idapan': 'idap',
    'pengidap': 'idap',
    'pengidapnya': 'idap',
    'pengidapan': 'idap',
    'mengidap': 'idap',
    'mengidapnya': 'idap',
    'mengidapkan': 'idap',
    'seidas': 'idas',
    'mengidas': 'idas',
    'mengidealkan': 'ideal',
    'mengidealisasikan': 'idealisasi',
    'mengidentifikasi': 'identifikasi',
    'mengidentifikasinya': 'identifikasi',
    'mengidentifikasikan': 'identifikasi',
    'mengidentifikasikannya': 'identifikasi',
    'mengidentifikasii': 'identifikasi',
    'mengidentikkan': 'identik',
    'mengidentikkannya': 'identik',
    'beridentitas': 'identitas',
    'beridentitaskan': 'identitas',
    'berideologi': 'ideologi',
    'berideologikan': 'ideologi',
    'pengidolaan': 'idola',
    'mengidolakan': 'idola',
    'mengidolakannya': 'idola',
    'mengidolakanmu': 'idola',
    'periduan': 'ridu',
    'mengigal': 'igal',
    'igauan': 'igau',
    'igauannya': 'igau',
    'terigau': 'igau',
    'mengigau': 'igau',
    'mengigaunya': 'igau',
    'pengigau': 'igau',
    'mengigaukan': 'igau',
    'igau-igauan': 'igau',
    'terigau-igau': 'igau',
    'berihram': 'ihram',
    'mengihtimalkan': 'ihtimal',
    'berijab': 'ijab',
    'mengijabkan': 'ijab',
    'berijazah': 'ijazah',
    'berijazahkan': 'ijazah',
    'berijmak': 'ijmak',
    'mengijmalkan': 'ijmal',
    'pengijon': 'ijon',
    'pengijonan': 'ijon',
    'berijtihad': 'ijtihad',
    'terijuk': 'ijuk',
    'mengijuk': 'ijuk',
    'ikalan': 'ikal',
    'mengikal': 'ikal',
    'ikanan': 'ikan',
    'berikan': 'ikan',
    'berikannya': 'ikan',
    'berikanlah': 'ikan',
    'berikanan': 'ikan',
    'berikanku': 'ikan',
    'pengikan': 'ikan',
    'perikanan': 'ikan',
    'perikanannya': 'ikan',
    'perikananan': 'ikan',
    'ikatan': 'ikat',
    'ikatannya': 'ikat',
    'ikatanmu': 'ikat',
    'terikat': 'ikat',
    'terikatnya': 'ikat',
    'terikati': 'ikat',
    'terikatan': 'ikat',
    'berikat': 'ikat',
    'berikatnya': 'ikat',
    'berikatan': 'ikat',
    'pengikat': 'ikat',
    'pengikatnya': 'ikat',
    'pengikatan': 'ikat',
    'pengikatmu': 'ikat',
    'mengikat': 'ikat',
    'mengikatnya': 'ikat',
    'mengikatkan': 'ikat',
    'mengikatkannya': 'ikat',
    'mengikatku': 'ikat',
    'mengikatmu': 'ikat',
    'perikatan': 'ikat',
    'perikatannya': 'ikat',
    'keterikatan': 'ikat',
    'keterikatannya': 'ikat',
    'keikhlasan': 'ikhlas',
    'keikhlasannya': 'ikhlas',
    'keikhlasanmu': 'ikhlas',
    'mengikhlaskan': 'ikhlas',
    'mengikhlaskannya': 'ikhlas',
    'mengikhtisarkan': 'ikhtisar',
    'seikhwan': 'ikhwan',
    'pengiklan': 'iklan',
    'pengiklannya': 'iklan',
    'pengiklanan': 'iklan',
    'periklanan': 'iklan',
    'periklanannya': 'iklan',
    'pengiklanannya': 'iklan',
    'mengiklankan': 'iklan',
    'mengiklankannya': 'iklan',
    'beriklim': 'iklim',
    'keikliman': 'iklim',
    'beriktikad': 'iktikad',
    'mengiktikadkan': 'iktikad',
    'keikutsertaan': 'ikut serta',
    'keikutsertaannya': 'ikut serta',
    'keikutsertaanku': 'ikut serta',
    'pengikutsertaan': 'ikut serta',
    'mengikutsertakan': 'ikut serta',
    'mengikutsertakannya': 'ikut serta',
    'berilah': 'ilah',
    'keilahan': 'ilah',
    'keilahian': 'ilahi',
    'mengilai': 'ilai',
    'mengilai-ilai': 'ilai',
    'mengilar': 'ilar',
    'mengilas': 'kilas',
    'mengiler': 'iler',
    'mengiles': 'iles',
    'mengilhami': 'ilham',
    'mengilhaminya': 'ilham',
    'mengilhamiku': 'ilham',
    'pengilhaman': 'ilham',
    'mengilhamkan': 'ilham',
    'mengili': 'kili',
    'ilingan': 'iling',
    'mengiling': 'iling',
    'mengilingi': 'iling',
    'pengilingan': 'iling',
    'mengilmiahkan': 'ilmiah',
    'berilmu': 'ilmu',
    'keilmuan': 'ilmu',
    'keilmuannya': 'ilmu',
    'keilmuanan': 'ilmu',
    'mengilmukan': 'ilmu',
    'mengilustrasikan': 'ilustrasi',
    'mengilustrasikannya': 'ilustrasi',
    'mengimak': 'imak',
    'mengimak-imak': 'imak',
    'keimaman': 'imam',
    'keimamannya': 'imam',
    'mengimami': 'imam',
    'mengimbak-imbak': 'imbak',
    'imbalan': 'imbal',
    'imbalannya': 'imbal',
    'imbalani': 'imbal',
    'pengimbal': 'imbal',
    'mengimbal': 'imbal',
    'mengimbali': 'imbal',
    'pengimbalan': 'imbal',
    'mengimbalkan': 'imbal',
    'imbangan': 'imbang',
    'imbangannya': 'imbang',
    'seimbang': 'imbang',
    'seimbangnya': 'imbang',
    'seimbanglah': 'imbang',
    'seimbangkan': 'imbang',
    'seimbangi': 'imbang',
    'seimbangan': 'imbang',
    'berimbang': 'imbang',
    'berimbangnya': 'imbang',
    'berimbanglah': 'imbang',
    'berimbangan': 'imbang',
    'mengimbang': 'imbang',
    'mengimbangkan': 'imbang',
    'mengimbangi': 'imbang',
    'keimbangan': 'imbang',
    'pengimbang': 'imbang',
    'pengimbangnya': 'imbang',
    'pengimbangi': 'imbang',
    'pengimbangan': 'imbang',
    'perimbangan': 'imbang',
    'perimbangannya': 'imbang',
    'mengimbanginya': 'imbang',
    'mengimbangiku': 'imbang',
    'keseimbangan': 'imbang',
    'keseimbangannya': 'imbang',
    'keseimbanganlah': 'imbang',
    'keseimbanganmu': 'imbang',
    'memperimbang': 'imbang',
    'memperimbangkan': 'imbang',
    'memperimbangan': 'imbang',
    'menyeimbangkan': 'imbang',
    'menyeimbangkannya': 'imbang',
    'imbang-imbangan': 'imbang',
    'memperseimbangkan': 'imbang',
    'terimbas': 'imbas',
    'terimbasnya': 'imbas',
    'terimbasi': 'imbas',
    'berimbas': 'imbas',
    'berimbasnya': 'imbas',
    'mengimbas': 'imbas',
    'mengimbasi': 'imbas',
    'imbauan': 'imbau',
    'imbauannya': 'imbau',
    'imbauanlah': 'imbau',
    'terimbau': 'imbau',
    'mengimbau': 'imbau',
    'mengimbaunya': 'imbau',
    'mengimbaukan': 'imbau',
    'mengimbaui': 'imbau',
    'mengimbauan': 'imbau',
    'pengimbauan': 'imbau',
    'mengimbit': 'imbit',
    'imbuhan': 'imbuh',
    'mengimbuh': 'imbuh',
    'mengimbuhkan': 'imbuh',
    'mengimbuhi': 'imbuh',
    'mengimbuhinya': 'imbuh',
    'mengiming-iming': 'iming-iming',
    'mengiming-imingnya': 'iming-iming',
    'mengiming-imingkan': 'iming-iming',
    'mengiming-imingi': 'iming-iming',
    'mengiming-imingan': 'iming-iming',
    'mengimitasi': 'imitasi',
    'mengimitasinya': 'imitasi',
    'mengimkan': 'imkan',
    'mengimlakan': 'imla',
    'mengimpas': 'impas',
    'mengimpaskan': 'impas',
    'impian': 'impi',
    'impiannya': 'impi',
    'impianku': 'impi',
    'impianmu': 'impi',
    'mengimpikan': 'impi',
    'mengimpikannya': 'impi',
    'terimpi-impi': 'impi',
    'impitan': 'impit',
    'berimpit': 'impit',
    'berimpitan': 'impit',
    'terimpit': 'impit',
    'mengimpit': 'impit',
    'mengimpitnya': 'impit',
    'memperimpit': 'impit',
    'mengimpitkan': 'impit',
    'berimpit-impit': 'impit',
    'berimpit-impitan': 'impit',
    'memperimpit-impitkan': 'impit',
    'mengimplementasikan': 'implementasi',
    'mengimplementasikannya': 'implementasi',
    'berimplikasi': 'implikasi',
    'terimplikasi': 'implikasi',
    'mengimplikasikan': 'implikasi',
    'mengimplisitkan': 'implisit',
    'mengimpor': 'impor',
    'mengimpornya': 'impor',
    'pengimpor': 'impor',
    'pengimpornya': 'impor',
    'pengimporan': 'impor',
    'berimprovisasi': 'improvisasi',
    'berimprovisasinya': 'improvisasi',
    'mengimprovisasikan': 'improvisasi',
    'keimunan': 'imun',
    'pengimunan': 'imun',
    'berinai': 'inai',
    'menginai': 'inai',
    'menginang': 'kinang',
    'inang-inang': 'inang',
    'menginap': 'inap',
    'menginapnya': 'inap',
    'menginaplah': 'inap',
    'menginapkan': 'inap',
    'menginapkannya': 'inap',
    'menginapan': 'inap',
    'penginapan': 'inap',
    'penginapannya': 'inap',
    'penginapanan': 'inap',
    'inca-binca': 'inca',
    'incaran': 'incar',
    'incarannya': 'incar',
    'incaranku': 'incar',
    'incaranmu': 'incar',
    'mengincar': 'incar',
    'mengincarnya': 'incar',
    'mengincarkan': 'incar',
    'mengincarkannya': 'incar',
    'mengincari': 'incar',
    'mengincarku': 'incar',
    'mengincarmu': 'incar',
    'terincit': 'incit',
    'mengincitkan': 'incit',
    'mengincrit-incrit': 'incrit',
    'terincut-incut': 'incut',
    'terindah': 'indah',
    'terindahnya': 'indah',
    'terindahku': 'indah',
    'keindahan': 'indah',
    'keindahannya': 'indah',
    'keindahanmu': 'indah',
    'pengindah': 'indah',
    'pengindahan': 'indah',
    'memperindah': 'indah',
    'memperindahnya': 'indah',
    'mengindahkan': 'indah',
    'mengindahkannya': 'indah',
    'terindang': 'indang',
    'mengindang': 'indang',
    'berindap-indap': 'indap',
    'mengindekoskan': 'indekos',
    'mengindik': 'indik',
    'berindikasi': 'indikasi',
    'berindikasikan': 'indikasi',
    'mengindikasikan': 'indikasi',
    'mengindikasikannya': 'indikasi',
    'menginding': 'inding',
    'mengindoktrinasi': 'indoktrinasi',
    'keindonesiaan': 'indonesia',
    'keindonesiaannya': 'indonesia',
    'pengindonesiaan': 'indonesia',
    'mengindonesiakan': 'indonesia',
    'pengindra': 'indra',
    'pengindranya': 'indra',
    'pengindraan': 'indra',
    'mengindra': 'indra',
    'keindraan': 'indra',
    'perinduan': 'indu',
    'seperinduan': 'indu',
    'berinduk': 'induk',
    'berindukkan': 'induk',
    'berinduki': 'induk',
    'menginduk': 'induk',
    'menginduki': 'induk',
    'keindukan': 'induk',
    'seperinduk': 'induk',
    'menginduksi': 'induksi',
    'menginduksikan': 'induksi',
    'perindustrian': 'industri',
    'perindustriannya': 'industri',
    'mengindustrikan': 'industri',
    'inefisiensi': 'inefisien',
    'inefisiensinya': 'inefisien',
    'menginfakkan': 'infak',
    'menginfakkannya': 'infak',
    'terinfeksi': 'infeksi',
    'terinfeksinya': 'infeksi',
    'menginfeksi': 'infeksi',
    'menginfeksinya': 'infeksi',
    'menginfeksikan': 'infeksi',
    'berinfiltrasi': 'infiltrasi',
    'menginfiltrasi': 'infiltrasi',
    'menginfiltrasikan': 'infiltrasi',
    'berinfleksi': 'infleksi',
    'menginformasikan': 'informasi',
    'menginformasikannya': 'informasi',
    'menginformasikankan': 'informasi',
    'menginformasikanku': 'informasi',
    'menginfus': 'infus',
    'teringa-inga': 'inga',
    'mengingari': 'ingar',
    'ingar-ingar': 'ingar',
    'mengingarkan': 'ingar',
    'ingar-bingar': 'ingar',
    'ingar-bingarnya': 'ingar',
    'ingatan': 'ingat',
    'ingatannya': 'ingat',
    'ingatanku': 'ingat',
    'seingat': 'ingat',
    'seingatnya': 'ingat',
    'seingatku': 'ingat',
    'beringat': 'ingat',
    'teringat': 'ingat',
    'teringatlah': 'ingat',
    'mengingat': 'ingat',
    'mengingatnya': 'ingat',
    'mengingatkan': 'ingat',
    'mengingatkannya': 'ingat',
    'mengingati': 'ingat',
    'mengingatan': 'ingat',
    'mengingatku': 'ingat',
    'mengingatmu': 'ingat',
    'mengingat-ku': 'ingat',
    'peringatan': 'ingat',
    'peringatannya': 'ingat',
    'peringatani': 'ingat',
    'peringatanan': 'ingat',
    'mengingatinya': 'ingat',
    'ingat-ingat': 'ingat',
    'ingat-ingatlah': 'ingat',
    'memperingati': 'ingat',
    'memperingatinya': 'ingat',
    'memperingatikan': 'ingat',
    'memperingatian': 'ingat',
    'mengingatkanlah': 'ingat',
    'mengingatkankan': 'ingat',
    'mengingatkanku': 'ingat',
    'mengingatkanmu': 'ingat',
    'ingat-ingatan': 'ingat',
    'memperingatkan': 'ingat',
    'memperingatkannya': 'ingat',
    'memperingatkankan': 'ingat',
    'memperingatkanku': 'ingat',
    'memperingatkanmu': 'ingat',
    'beringat-ingat': 'ingat',
    'teringat-ingat': 'ingat',
    'mengingat-ingat': 'ingatan',
    'mengingat-ingatnya': 'ingatan',
    'mengingat-ingatkan': 'ingatan',
    'mengingau': 'ingau',
    'mengingaukan': 'ingau',
    'ingau-ingauan': 'ingau',
    'menginggriskan': 'inggris',
    'keinggris-inggrisan': 'inggris',
    'keinginan': 'ingin',
    'keinginannya': 'ingin',
    'keinginanan': 'ingin',
    'keinginanku': 'ingin',
    'keinginanmu': 'ingin',
    'mengingini': 'ingin',
    'memperingin': 'ingin',
    'berkeinginan': 'ingin',
    'berkeinginannya': 'ingin',
    'menginginkan': 'ingin',
    'menginginkannya': 'ingin',
    'menginginkankan': 'ingin',
    'menginginkanku': 'ingin',
    'menginginkanmu': 'ingin',
    'keingintahuan': 'ingin tahu',
    'keingintahuannya': 'ingin tahu',
    'keingintahuanku': 'ingin tahu',
    'keingkaran': 'ingkar',
    'keingkarannya': 'ingkar',
    'mengingkari': 'ingkar',
    'mengingkarinya': 'ingkar',
    'pengingkaran': 'ingkar',
    'mengingsar': 'ingsar',
    'ingsutan': 'ingsut',
    'beringsut': 'ingsut',
    'beringsutnya': 'ingsut',
    'mengingsut': 'ingsut',
    'mengingsutkan': 'ingsut',
    'ingusan': 'ingus',
    'mengingusi': 'ingus',
    'berinisial': 'inisial',
    'berinisialnya': 'inisial',
    'berinisialkan': 'inisial',
    'menginisiasikan': 'inisiasi',
    'menginisiasikannya': 'inisiasi',
    'berinisiatif': 'inisiatif',
    'berinisiatiflah': 'inisiatif',
    'injakan': 'injak',
    'injakannya': 'injak',
    'terinjak': 'injak',
    'terinjaknya': 'injak',
    'menginjak': 'injak',
    'menginjaknya': 'injak',
    'menginjakkan': 'injak',
    'menginjaki': 'injak',
    'menginjakan': 'injak',
    'injak-injak': 'injak',
    'injak-injaklah': 'injak',
    'injak-injakan': 'injak',
    'terinjak-injak': 'injak',
    'terinjak-injaknya': 'injak',
    'menginjak-injak': 'injak',
    'menginjak-injaknya': 'injak',
    'menginjak-injakkan': 'injak',
    'menginjap': 'injap',
    'menginjeksi': 'injeksi',
    'menginjeksinya': 'injeksi',
    'menginjeksikan': 'injeksi',
    'menginjil': 'injil',
    'menginjili': 'injil',
    'penginjil': 'injil',
    'penginjilan': 'injil',
    'penginjilannya': 'injil',
    'berinkarnasi': 'inkarnasi',
    'menginkorporasikan': 'inkorporasi',
    'menginovasikan': 'inovasi',
    'keinsafan': 'insaf',
    'menginsafi': 'insaf',
    'menginsafkan': 'insaf',
    'berinsang': 'insang',
    'menginsinuasi': 'insinuasi',
    'menginspeksi': 'inspeksi',
    'menginspeksinya': 'inspeksi',
    'menginspeksiku': 'inspeksi',
    'terinspirasi': 'inspirasi',
    'terinspirasinya': 'inspirasi',
    'menginspirasi': 'inspirasi',
    'menginspirasinya': 'inspirasi',
    'menginspirasikan': 'inspirasi',
    'menginspirasiku': 'inspirasi',
    'menginspirasimu': 'inspirasi',
    'menginstruksikan': 'instruksi',
    'menginstruksikannya': 'instruksi',
    'mengintai': 'intai',
    'mengintainya': 'intai',
    'mengintaian': 'intai',
    'pengintai': 'intai',
    'pengintainya': 'intai',
    'pengintaian': 'intai',
    'pengintaiannya': 'intai',
    'mengintaikan': 'intai',
    'pengintensifan': 'intensif',
    'pengintensifannya': 'intensif',
    'mengintensifkan': 'intensif',
    'mengintensifkannya': 'intensif',
    'pengintensifikasian': 'intensifikasi',
    'menginterlokal': 'interlokal',
    'menginternasional': 'internasional',
    'menginternasionalkan': 'internasional',
    'penginternasionalan': 'internasional',
    'interniran': 'internir',
    'menginternir': 'internir',
    'menginternirnya': 'internir',
    'menginterogasi': 'interogasi',
    'menginterogasinya': 'interogasi',
    'menginterogasiku': 'interogasi',
    'penginterpretasi': 'interpretasi',
    'penginterpretasian': 'interpretasi',
    'menginterpretasikan': 'interpretasi',
    'menginterpretasikannya': 'interpretasi',
    'menginterupsi': 'interupsi',
    'menginterupsinya': 'interupsi',
    'terintervensi': 'intervensi',
    'mengintervensi': 'intervensi',
    'mengintervensinya': 'intervensi',
    'menginterviu': 'interviu',
    'penginti': 'inti',
    'pengintian': 'inti',
    'perintian': 'inti',
    'keintiman': 'intim',
    'keintimannya': 'intim',
    'mengintimi': 'intim',
    'mengintiminya': 'intim',
    'mengintimidasi': 'intimidasi',
    'mengintimidasinya': 'intimidasi',
    'mengintimidasimu': 'intimidasi',
    'mengintip': 'intip',
    'mengintipnya': 'intip',
    'mengintipkan': 'intip',
    'mengintroduksi': 'introduksi',
    'mengintroduksikan': 'introduksi',
    'berintrospeksi': 'introspeksi',
    'mengintrospeksi': 'introspeksi',
    'mengintrospeksikan': 'introspeksi',
    'terintrusi': 'intrusi',
    'berinvasi': 'invasi',
    'menginvasi': 'invasi',
    'menginvasinya': 'invasi',
    'menginventarisasi': 'inventarisasi',
    'menginventarisasinya': 'inventarisasi',
    'menginventarisasikan': 'inventarisasi',
    'berinvestasi': 'investasi',
    'berinvestasinya': 'investasi',
    'berinvestasilah': 'investasi',
    'berinvestasikan': 'investasi',
    'menginvestasikan': 'investasi',
    'menginvestasikannya': 'investasi',
    'terion': 'ion',
    'terionkan': 'ion',
    'pengionan': 'ion',
    'mengionkan': 'ion',
    'terionisasi': 'ionisasi',
    'beripar': 'ipar',
    'mengiprit': 'iprit',
    'beripuh': 'ipuh',
    'ipukan': 'ipuk',
    'mengipuk': 'ipuk',
    'pengipukan': 'ipuk',
    'seiras': 'iras',
    'irasan': 'iras',
    'mengiras': 'iras',
    'iras-iras': 'iras',
    'mengiras-iras': 'iras',
    'mengiras-irasi': 'iras',
    'keirihatian': 'iri hati',
    'mengiri': 'kiri',
    'mengirinya': 'kiri',
    'mengirikan': 'kirik',
    'mengirikannya': 'kiri',
    'mengirimu': 'kiri',
    'keirian': 'iri',
    'keiriannya': 'iri',
    'pengiri': 'iri',
    'pengirinya': 'iri',
    'pengirian': 'iri',
    'pengirik': 'irik',
    'mengirik': 'kirik',
    'seiring': 'iring',
    'seiringnya': 'iring',
    'seiringi': 'iring',
    'seiringan': 'iring',
    'iringan': 'iring',
    'iringannya': 'iring',
    'beriring': 'iring',
    'beriringnya': 'iring',
    'beriringan': 'iring',
    'mengiring': 'iring',
    'mengiringnya': 'iring',
    'mengiringkan': 'iring',
    'mengiringi': 'iring',
    'mengiringan': 'iring',
    'pengiring': 'iring',
    'pengiringnya': 'iring',
    'pengiringi': 'iring',
    'pengiringan': 'iring',
    'mengiringinya': 'iring',
    'mengiringinyalah': 'iring',
    'mengiringimu': 'iring',
    'diiringkan': 'iring',
    'iring-iringan': 'iring',
    'iring-iringannya': 'iring',
    'beriring-iring': 'iring',
    'beriring-iringan': 'iring',
    'irisan': 'iris',
    'irisannya': 'iris',
    'mengiris': 'iris',
    'mengirisnya': 'iris',
    'iris-irisan': 'iris',
    'mengiriskan': 'iris',
    'mengiris-iris': 'iris',
    'mengiris-irisnya': 'iris',
    'mengiris-iriskan': 'iris',
    'mengirit': 'irit',
    'mengiritnya': 'irit',
    'mengiritkan': 'irit',
    'pengiritan': 'irit',
    'pengiritannya': 'irit',
    'terisak-isak': 'isak',
    'isapan': 'isap',
    'isapannya': 'isap',
    'mengisap': 'isap',
    'mengisapnya': 'isap',
    'pengisap': 'isap',
    'pengisapnya': 'isap',
    'pengisapan': 'isap',
    'mengisapkan': 'isap',
    'mengisbatkan': 'isbat',
    'mengisengi': 'iseng',
    'mengisenginya': 'iseng',
    'iseng-iseng': 'iseng',
    'iseng-isengnya': 'iseng',
    'iseng-isengan': 'iseng',
    'mengislahkan': 'islah',
    'keislaman': 'islam',
    'keislamannya': 'islam',
    'keislamanan': 'islam',
    'keislamanku': 'islam',
    'pengislaman': 'islam',
    'mengislamkan': 'islam',
    'terisolasi': 'isolasi',
    'terisolasinya': 'isolasi',
    'pengisolasi': 'isolasi',
    'pengisolasian': 'isolasi',
    'mengisolasi': 'isolasi',
    'mengisolasinya': 'isolasi',
    'mengisolasikan': 'isolasi',
    'pengisolasiannya': 'isolasi',
    'mengistiadatkan': 'istiadat',
    'beristibdad': 'istibdad',
    'beristigfar': 'istigfar',
    'beristikharah': 'istikharah',
    'mengistikmalkan': 'istikmal',
    'peristilahan': 'istilah',
    'pengistilahan': 'istilah',
    'mengistilahkan': 'istilah',
    'mengistilahkannya': 'istilah',
    'teristimewa': 'istimewa',
    'teristimewanya': 'istimewa',
    'teristimewaku': 'istimewa',
    'keistimewaan': 'istimewa',
    'keistimewaannya': 'istimewa',
    'mengistimewakan': 'istimewa',
    'mengistimewakannya': 'istimewa',
    'beristinja': 'istinja',
    'beristirahat': 'istirahat',
    'beristirahatnya': 'istirahat',
    'beristirahatlah': 'istirahat',
    'peristirahatan': 'istirahat',
    'peristirahatannya': 'istirahat',
    'peristirahatanmu': 'istirahat',
    'mengistirahatkan': 'istirahat',
    'mengistirahatkannya': 'istirahat',
    'beristri': 'istri',
    'beristrikan': 'istri',
    'memperistri': 'istri',
    'memperistrinya': 'istri',
    'memperistrikan': 'istri',
    'mengisukan': 'isu',
    'mengisyaratkan': 'isyarat',
    'mengisyaratkannya': 'isyarat',
    'itulah': 'itu',
    'itulahnya': 'itu',
    'itulahlah': 'itu',
    'iuran': 'iur',
    'iurannya': 'iur',
    'iuranmu': 'iur',
    'beriuran': 'iur',
    'seizin': 'izin',
    'seizinnya': 'izin',
    'seizinkan': 'izin',
    'seizini': 'izin',
    'seizinmu': 'izin',
    'keizinan': 'izin',
    'perizinan': 'izin',
    'perizinannya': 'izin',
    'perizinanan': 'izin',
    'perizinanku': 'izin',
    'terizinkan': 'izin',
    'mengizinkan': 'izin',
    'mengizinkannya': 'izin',
    'mengizinkankan': 'izin',
    'mengizinkanku': 'izin',
    'mengizinkanmu': 'izin',
    'menjabal': 'jabal',
    'penjabalan': 'jabal',
    'jabaran': 'jabar',
    'jabarannya': 'jabar',
    'penjabaran': 'jabar',
    'penjabarannya': 'jabar',
    'menjabarkan': 'jabar',
    'menjabarkannya': 'jabar',
    'terjabarkan': 'jabar',
    'sejabat': 'jabat',
    'sejabatnya': 'jabat',
    'pejabat': 'jabat',
    'pejabatnya': 'jabat',
    'pejabatlah': 'jabat',
    'pejabati': 'jabat',
    'pejabatan': 'jabat',
    'pejabatku': 'jabat',
    'jabatan': 'jabat',
    'jabatannya': 'jabat',
    'jabatani': 'jabat',
    'jabatanku': 'jabat',
    'jabatanmu': 'jabat',
    'penjabat': 'jabat',
    'penjabatnya': 'jabat',
    'penjabatan': 'jabat',
    'menjabat': 'jabat',
    'menjabatnya': 'jabat',
    'menjabatkan': 'jabat',
    'menjabati': 'jabat',
    'menjabatan': 'jabat',
    'berjabat tangan': 'jabat tangan',
    'berjabir-jabir': 'jabir',
    'menjadi': 'jadi',
    'menjadinya': 'jadi',
    'menjadilah': 'jadi',
    'menjadikan': 'jadi',
    'menjadikannya': 'jadi',
    'menjadii': 'jadi',
    'menjadian': 'jadi',
    'terjadi': 'jadi',
    'terjadinya': 'jadi',
    'terjadilah': 'jadi',
    'terjadikan': 'jadi',
    'terjadii': 'jadi',
    'terjadian': 'jadi',
    'penjadi': 'jadi',
    'kejadian': 'jadi',
    'kejadiannya': 'jadi',
    'kejadianlah': 'jadi',
    'kejadiani': 'jadi',
    'kejadianan': 'jadi',
    'penjadian': 'jadi',
    'menjadikankan': 'jadi',
    'menjadikanku': 'jadi',
    'menjadikanmu': 'jadi',
    'jadi-jadian': 'jadi',
    'jadi-jadiannya': 'jadi',
    'menjadi-jadi': 'jadi',
    'menjadi-jadinya': 'jadi',
    'sejadi-jadinya': 'jadi',
    'menjadi-jadikan': 'jadi',
    'terjadwal': 'jadwal',
    'terjadwalnya': 'jadwal',
    'terjadwalkan': 'jadwal',
    'penjadwalan': 'jadwal',
    'penjadwalannya': 'jadwal',
    'menjadwalkan': 'jadwal',
    'menjadwalkannya': 'jadwal',
    'terjaga': 'jaga',
    'terjaganya': 'jaga',
    'terjagalah': 'jaga',
    'penjaga': 'jaga',
    'penjaganya': 'jaga',
    'penjagaan': 'jaga',
    'penjagaku': 'jaga',
    'penjagamu': 'jaga',
    'berjaga': 'jaga',
    'berjaganya': 'jaga',
    'berjagalah': 'jaga',
    'berjagai': 'jaga',
    'menjaga': 'jaga',
    'menjaganya': 'jaga',
    'menjagalah': 'jaga',
    'menjagakan': 'jaga',
    'menjagai': 'jaga',
    'menjagaan': 'jaga',
    'menjagaku': 'jaga',
    'menjagamu': 'jaga',
    'penjagaannya': 'jaga',
    'berjaga-jaga': 'jaga',
    'berjaga-jagalah': 'jaga',
    'kejaga-jagaan': 'jaga',
    'jagalan': 'jagal',
    'berjagal': 'jagal',
    'menjagal': 'jagal',
    'menjagalnya': 'jagal',
    'pejagalan': 'jagal',
    'penjagalan': 'jagal',
    'penjagalannya': 'jagal',
    'sejagat': 'jagat',
    'jagoan': 'jago',
    'jagoannya': 'jago',
    'jagoanku': 'jago',
    'jagoanmu': 'jago',
    'menjagoi': 'jago',
    'menjagokan': 'jago',
    'menjagokannya': 'jago',
    'menjagung': 'jagung',
    'berjagung-jagung': 'jagung',
    'menjahanamkan': 'jahanam',
    'menjahar': 'jahar',
    'berjahat': 'jahat',
    'penjahat': 'jahat',
    'penjahatnya': 'jahat',
    'menjahati': 'jahat',
    'menjahatinya': 'jahat',
    'kejahatan': 'jahat',
    'kejahatannya': 'jahat',
    'kejahatanlah': 'jahat',
    'kejahatanan': 'jahat',
    'kejahatanku': 'jahat',
    'menjahatkan': 'jahat',
    'menjahili': 'jahil',
    'menjahilinya': 'jahil',
    'kejahilan': 'jahil',
    'kejahilannya': 'jahil',
    'jahitan': 'jahit',
    'jahitannya': 'jahit',
    'menjahit': 'jahit',
    'menjahitnya': 'jahit',
    'menjahitkan': 'jahit',
    'menjahitkannya': 'jahit',
    'menjahiti': 'jahit',
    'penjahit': 'jahit',
    'penjahitnya': 'jahit',
    'penjahitan': 'jahit',
    'menjaili': 'jail',
    'kejailan': 'jail',
    'jaipongan': 'jaipong',
    'berjaipong': 'jaipong',
    'jajahan': 'jajah',
    'jajahannya': 'jajah',
    'menjajah': 'jajah',
    'menjajahnya': 'jajah',
    'menjajahkan': 'jajah',
    'penjajah': 'jajah',
    'penjajahnya': 'jajah',
    'penjajahan': 'jajah',
    'terjajah': 'jajah',
    'terjajahnya': 'jajah',
    'menjajahi': 'jajah',
    'penjajahannya': 'jajah',
    'penjajahanlah': 'jajah',
    'menjajaki': 'jajak',
    'menjajakinya': 'jajak',
    'menjajal': 'jajal',
    'menjajalnya': 'jajal',
    'menjajalkan': 'jajal',
    'menjajali': 'jajal',
    'jajanan': 'jajan',
    'jajanannya': 'jajan',
    'jajananlah': 'jajan',
    'jajananan': 'jajan',
    'berjajan': 'jajan',
    'kejaksaan': 'jaksa',
    'kejaksaannya': 'jaksa',
    'kejaksaanlah': 'jaksa',
    'kejaksaannyalah': 'jaksa',
    'penjala': 'jala',
    'penjalaan': 'jala',
    'menjala': 'jala',
    'menjalakan': 'jala',
    'menjalakannya': 'jala',
    'menjalai': 'jala',
    'terjala': 'jala',
    'jala-jala': 'jala',
    'jala-jalanya': 'jala',
    'menjalakankan': 'jala',
    'menjalang': 'jalang',
    'menjalangi': 'jalang',
    'kejalangan': 'jalang',
    'menjalar': 'jalar',
    'menjalarnya': 'jalar',
    'menjalarkan': 'jalar',
    'menjalari': 'jalar',
    'berjalaran': 'jalar',
    'penjalaran': 'jalar',
    'penjalarannya': 'jalar',
    'berjalar-jalar': 'jalar',
    'terjali': 'jali',
    'terjalinya': 'jali',
    'menjalu': 'jalu',
    'berjalur': 'jalur',
    'berjalur-jalur': 'jalur',
    'berjam-jam': 'jam',
    'jamahan': 'jamah',
    'menjamah': 'jamah',
    'menjamahnya': 'jamah',
    'menjamahi': 'jamah',
    'menjamahku': 'jamah',
    'terjamah': 'jamah',
    'terjamahnya': 'jamah',
    'terjamahkan': 'jamah',
    'penjamah': 'jamah',
    'penjamahan': 'jamah',
    'jamah-jamahan': 'jamah',
    'menjamak': 'jamak',
    'kejamakan': 'jamak',
    'sejamaknya': 'jamak',
    'penjamakan': 'jamak',
    'menjamakkan': 'jamak',
    'sejambak': 'jambak',
    'penjambak': 'jambak',
    'penjambakan': 'jambak',
    'menjambak': 'jambak',
    'menjambaknya': 'jambak',
    'menjambaki': 'jambak',
    'jambak-jambakan': 'jambak',
    'jambangan': 'jambang',
    'sejambar': 'jambar',
    'berjambar': 'jambar',
    'jambatan': 'jambat',
    'jambatannya': 'jambat',
    'jambretan': 'jambret',
    'jambretannya': 'jambret',
    'menjambret': 'jambret',
    'menjambretnya': 'jambret',
    'penjambret': 'jambret',
    'penjambretnya': 'jambret',
    'penjambretan': 'jambret',
    'penjambretannya': 'jambret',
    'jambu-jambu': 'jambu',
    'berjambul': 'jambul',
    'jaminan': 'jamin',
    'jaminannya': 'jamin',
    'jaminanlah': 'jamin',
    'jaminanan': 'jamin',
    'penjamin': 'jamin',
    'penjaminnya': 'jamin',
    'penjaminan': 'jamin',
    'terjamin': 'jamin',
    'terjaminnya': 'jamin',
    'terjaminan': 'jamin',
    'menjamin': 'jamin',
    'menjaminnya': 'jamin',
    'menjaminlah': 'jamin',
    'menjaminkan': 'jamin',
    'menjaminkannya': 'jamin',
    'menjaminan': 'jamin',
    'menjaminku': 'jamin',
    'penjaminannya': 'jamin',
    'penjaminanan': 'jamin',
    'keterjaminan': 'jaminan',
    'jampian': 'jampi',
    'berjampi': 'jampi',
    'menjampi': 'jampi',
    'jampi-jampi': 'jampi',
    'jampi-jampinya': 'jampi',
    'menjampikan': 'jampi',
    'menjampuk': 'jampuk',
    'berjamrah': 'jamrah',
    'menjamur': 'jamur',
    'menjamurnya': 'jamur',
    'menjamurlah': 'jamur',
    'menjamurkan': 'jamur',
    'menjamuri': 'jamur',
    'berjamur': 'jamur',
    'berjamurnya': 'jamur',
    'berjamurlah': 'jamur',
    'berjamuran': 'jamur',
    'menjanda': 'janda',
    'penjangak': 'jangak',
    'menjangak': 'jangak',
    'jangankan': 'jangan',
    'jangankankan': 'jangan',
    'menjangankan': 'jangan',
    'jangan-jangan': 'jangan',
    'penjangat': 'jangat',
    'menjangat': 'jangat',
    'menjangati': 'jangat',
    'kejanggalan': 'janggal',
    'kejanggalannya': 'janggal',
    'kejanggalanan': 'janggal',
    'menjanggalkan': 'janggal',
    'berjangka': 'jangka',
    'berjangkanya': 'jangka',
    'menjangka': 'jangka',
    'menjangkakan': 'jangka',
    'menjangkai': 'jangka',
    'menjangkah': 'jangkah',
    'menjangkang': 'jangkang',
    'terjangkang': 'jangkang',
    'menjangkar': 'jangkar',
    'menjangkarkan': 'jangkar',
    'jangkauan': 'jangkau',
    'jangkauannya': 'jangkau',
    'jangkauanku': 'jangkau',
    'jangkauanmu': 'jangkau',
    'menjangkau': 'jangkau',
    'menjangkaunya': 'jangkau',
    'menjangkauan': 'jangkau',
    'terjangkau': 'jangkau',
    'terjangkaunya': 'jangkau',
    'terjangkaulah': 'jangkau',
    'terjangkaui': 'jangkau',
    'terjangkauan': 'jangkau',
    'sejangkauan': 'jangkau',
    'sepenjangkauan': 'jangkau',
    'menjangki': 'jangki',
    'jangkih mangkih': 'jangkih',
    'jongkar-jangkir': 'jangkir',
    'jangkungan': 'jangkung',
    'menjangol': 'jangol',
    'berjanguk': 'janguk',
    'berjanjang': 'janjang',
    'pejantan': 'jantan',
    'pejantannya': 'jantan',
    'pejantanan': 'jantan',
    'berjantan': 'jantan',
    'kejantanan': 'jantan',
    'kejantanannya': 'jantan',
    'kejantananmu': 'jantan',
    'menjantani': 'jantan',
    'perjantanan': 'jantan',
    'terjantang': 'jantang',
    'menjantang': 'jantang',
    'berjantang': 'jantang',
    'jantungan': 'jantung',
    'berjantung': 'jantung',
    'menjantung': 'jantung',
    'terjantur': 'jantur',
    'menjantur': 'jantur',
    'menjara': 'jara',
    'menjarai': 'jara',
    'jarahan': 'jarah',
    'jarahannya': 'jarah',
    'penjarah': 'jarah',
    'penjarahnya': 'jarah',
    'penjarahan': 'jarah',
    'menjarah': 'jarah',
    'menjarahnya': 'jarah',
    'menjarahi': 'jarah',
    'menjarahan': 'jarah',
    'penjarahannya': 'jarah',
    'penjaram': 'jaram',
    'berjaram': 'jaram',
    'menjaram': 'jaram',
    'menjarang': 'jarang',
    'menjarangkan': 'jarang',
    'penjarangan': 'jarang',
    'memperjarang': 'jarang',
    'jarang-jarang': 'jarang',
    'jarang-jarangnya': 'jarang',
    'jarang-jarangkan': 'jarang',
    'sejaras': 'jaras',
    'menjaras': 'jaras',
    'menjari': 'jari',
    'menjarikan': 'jari',
    'penjarian': 'jari',
    'jari-jari': 'jari',
    'jari-jarinya': 'jari',
    'jari-jariku': 'jari',
    'berjari-jari': 'jari',
    'jaringan': 'jaring',
    'jaringannya': 'jaring',
    'jaringanlah': 'jaring',
    'jaringani': 'jaring',
    'jaringanan': 'jaring',
    'jaringanmu': 'jaring',
    'menjaring': 'jaring',
    'menjaringnya': 'jaring',
    'menjaringkan': 'jaring',
    'menjaringkannya': 'jaring',
    'menjaringan': 'jaring',
    'terjaring': 'jaring',
    'terjaringnya': 'jaring',
    'terjaringlah': 'jaring',
    'terjaringan': 'jaring',
    'jaring-jaring': 'jaring',
    'jaring-jaringnya': 'jaring',
    'jaring-jaringan': 'jaring',
    'jaruman': 'jarum',
    'menjarum': 'jarum',
    'berjarum': 'jarum',
    'jarum-jarum': 'jarum',
    'pejasaboga': 'jasa boga',
    'berjasa': 'jasa',
    'berjasanya': 'jasa',
    'berjasad': 'jasad',
    'kejasmanian': 'jasmani',
    'menjatah': 'jatah',
    'menjatahnya': 'jatah',
    'menjatahkan': 'jatah',
    'menjatahi': 'jatah',
    'penjatahan': 'jatah',
    'penjatahannya': 'jatah',
    'sejati': 'jati',
    'sejatinya': 'jati',
    'sejatilah': 'jati',
    'sejatii': 'jati',
    'sejatinyalah': 'jati',
    'sejatiku': 'jati',
    'sejatimu': 'jati',
    'sejati-ku': 'jati',
    'kesejatian': 'jati',
    'kesejatiannya': 'jati',
    'kejatmikaan': 'jatmika',
    'jatuhan': 'jatuh',
    'berjatuh': 'jatuh',
    'berjatuhnya': 'jatuh',
    'berjatuhkan': 'jatuh',
    'berjatuhan': 'jatuh',
    'terjatuh': 'jatuh',
    'terjatuhnya': 'jatuh',
    'terjatuhi': 'jatuh',
    'kejatuhan': 'jatuh',
    'kejatuhannya': 'jatuh',
    'menjatuhi': 'jatuh',
    'menjatuhinya': 'jatuh',
    'berjatuhannya': 'jatuh',
    'penjatuhan': 'jatuh',
    'penjatuhannya': 'jatuh',
    'menjatuhkan': 'jatuh',
    'menjatuhkannya': 'jatuh',
    'menjatuhkankan': 'jatuh',
    'menjatuhkani': 'jatuh',
    'menjatuhkanku': 'jatuh',
    'menjatuhkanmu': 'jatuh',
    'sejauh': 'jauh',
    'sejauhnya': 'jauh',
    'sejauhi': 'jauh',
    'berjauh': 'jauh',
    'berjauhan': 'jauh',
    'menjauh': 'jauh',
    'menjauhnya': 'jauh',
    'menjauhlah': 'jauh',
    'menjauhkan': 'jauh',
    'menjauhkannya': 'jauh',
    'menjauhi': 'jauh',
    'kejauhan': 'jauh',
    'menjauhinya': 'jauh',
    'menjauhiku': 'jauh',
    'menjauhkankan': 'jauh',
    'menjauhkanmu': 'jauh',
    'berjauh-jauhan': 'jauh',
    'jawaban': 'jawab',
    'jawabannya': 'jawab',
    'jawabanlah': 'jawab',
    'jawabankan': 'jawab',
    'jawabanku': 'jawab',
    'jawabanmu': 'jawab',
    'menjawab': 'jawab',
    'menjawabnya': 'jawab',
    'menjawabi': 'jawab',
    'menjawaban': 'jawab',
    'berjawab': 'jawab',
    'jawatan': 'jawat',
    'sejawat': 'jawat',
    'sejawatnya': 'jawat',
    'menjawat': 'jawat',
    'penjawat': 'jawat',
    'berjawat': 'jawat',
    'jawi-jawi': 'jawi',
    'menjawikan': 'jawi',
    'menjawil': 'jawil',
    'berjebah': 'jebah',
    'berjebai': 'jebai',
    'jebakan': 'jebak',
    'jebakannya': 'jebak',
    'jebakanmu': 'jebak',
    'penjebak': 'jebak',
    'penjebaknya': 'jebak',
    'penjebakkan': 'jebak',
    'penjebakan': 'jebak',
    'menjebak': 'jebak',
    'menjebaknya': 'jebak',
    'terjebak': 'jebak',
    'terjebaknya': 'jebak',
    'terjebaklah': 'jebak',
    'terjebakan': 'jebak',
    'penjebakannya': 'jebak',
    'jebar-jebur': 'jebar',
    'jebat-jebatan': 'jebat',
    'terjeblok': 'jeblok',
    'kejeblos': 'jeblos',
    'terjeblos': 'jeblos',
    'menjebloskan': 'jeblos',
    'menjebloskannya': 'jeblos',
    'menjebluk': 'jebluk',
    'jebolan': 'jebol',
    'jebolannya': 'jebol',
    'menjebol': 'jebol',
    'menjebolnya': 'jebol',
    'menjebolkan': 'jebol',
    'menjeboli': 'jebol',
    'menjebrolkan': 'jebrol',
    'menjebur': 'jebur',
    'menjeburkan': 'jebur',
    'menjedotkan': 'jedot',
    'menjedotkannya': 'jedot',
    'menjedot-jedotkan': 'jedot',
    'menjegal': 'jegal',
    'menjegalnya': 'jegal',
    'jegal-jegalan': 'penjegalan',
    'berjegal-jegalan': 'penjegalan',
    'menjegil': 'jegil',
    'terjegil': 'jegil',
    'menjejak': 'jejak',
    'menjejaknya': 'jejak',
    'menjejakkan': 'jejak',
    'menjejaki': 'jejak',
    'menjejakan': 'jejak',
    'berjejak': 'jejak',
    'penjejak': 'jejak',
    'penjejakkan': 'jejak',
    'penjejakan': 'jejak',
    'menjejakinya': 'jejak',
    'menjejal': 'jejal',
    'menjejalnya': 'jejal',
    'menjejalkan': 'jejal',
    'menjejalkannya': 'jejal',
    'menjejali': 'jejal',
    'berjejal': 'jejal',
    'berjejalnya': 'jejal',
    'berjejalan': 'jejal',
    'menjejalinya': 'jejal',
    'penjejalan': 'jejal',
    'berjejal-jejal': 'jejal',
    'berjejal-jejalan': 'jejal',
    'jejeran': 'jejer',
    'jejerannya': 'jejer',
    'terjelabak': 'jelabak',
    'berjelaga': 'jelaga',
    'menjelajah': 'jelajah',
    'menjelajahnya': 'jelajah',
    'menjelajahkan': 'jelajah',
    'menjelajahi': 'jelajah',
    'penjelajah': 'jelajah',
    'penjelajahnya': 'jelajah',
    'penjelajahan': 'jelajah',
    'menjelajahinya': 'jelajah',
    'penjelajahannya': 'jelajah',
    'terjelak': 'jelak',
    'jelalatan': 'jelalat',
    'menjelanak': 'jelanak',
    'menjelang': 'jelang',
    'menjelangnya': 'jelang',
    'menjelangi': 'jelang',
    'jelang-menjelang': 'jelang',
    'menjelangak': 'jelangak',
    'berjelapak': 'jelapak',
    'terjelapak': 'jelapak',
    'berjelapakan': 'jelapak',
    'menjelar': 'jelar',
    'penjelas': 'jelas',
    'penjelasnya': 'jelas',
    'penjelaskan': 'jelas',
    'penjelasan': 'jelas',
    'kejelasan': 'jelas',
    'kejelasannya': 'jelas',
    'kejelasanan': 'jelas',
    'penjelasannya': 'jelas',
    'penjelasanlah': 'jelas',
    'penjelasanan': 'jelas',
    'penjelasanku': 'jelas',
    'memperjelas': 'jelas',
    'memperjelasnya': 'jelas',
    'memperjelaskan': 'jelas',
    'terjelaskan': 'jelas',
    'menjelaskan': 'jelas',
    'menjelaskannya': 'jelas',
    'menjelaskankan': 'jelas',
    'menjelaskanan': 'jelas',
    'menjelau': 'jelau',
    'menjelejeh': 'jelejeh',
    'berjelejehan': 'jelejeh',
    'kejelekan': 'jelek',
    'kejelekannya': 'jelek',
    'menjelekkan': 'jelek',
    'menjelekkannya': 'jelek',
    'menjelek-jelekkan': 'jelek',
    'menjelek-jelekkannya': 'jelek',
    'menjelempah': 'jelempah',
    'menjelengar': 'jelengar',
    'terjelengar': 'jelengar',
    'menjelepak': 'jelepak',
    'menjelepok': 'jelepok',
    'terjelepok': 'jelepok',
    'kejelian': 'jeli',
    'kejeliannya': 'jeli',
    'menjelihkan': 'jelih',
    'menjelijih': 'jelijih',
    'menjelimet': 'jelimet',
    'menjelimpat': 'jelimpat',
    'menjeling': 'jeling',
    'menjelirkan': 'jelir',
    'menjelitkan': 'jelit',
    'terjelma': 'jelma',
    'menjelma': 'jelma',
    'menjelmanya': 'jelma',
    'menjelmakan': 'jelma',
    'menjelmakannya': 'jelma',
    'penjelmaan': 'jelma',
    'penjelmaannya': 'jelma',
    'menjeluak': 'jeluak',
    'jelujuran': 'jelujur',
    'menjelujur': 'jelujur',
    'menjelujuri': 'jelujur',
    'berjeluk': 'jeluk',
    'berjelum': 'jelum',
    'menjelum': 'jelum',
    'menjelungkap': 'jelungkap',
    'menjelunut': 'jelunut',
    'kejelusan': 'jelus',
    'menjeluskan': 'jelus',
    'menjelut': 'jelut',
    'berjemaah': 'jemaah',
    'berjemaahnya': 'jemaah',
    'menjemaahkan': 'jemaah',
    'sejemang': 'jemang',
    'kejemawaan': 'jemawa',
    'jembaan': 'jemba',
    'menjemba': 'jemba',
    'menjembak': 'jembak',
    'terjembak-jembak': 'jembak',
    'terjembatani': 'jembatan',
    'menjembatani': 'jembatan',
    'menjembataninya': 'jembatan',
    'penjembatanan': 'jembatan',
    'jempalitan': 'jempalit',
    'menjempalit': 'jempalit',
    'berjempalitan': 'jempalit',
    'jempolan': 'jempol',
    'jempolannya': 'jempol',
    'kejempolan': 'jempol',
    'jemputan': 'jemput',
    'jemputannya': 'jemput',
    'sejemput': 'jemput',
    'berjemput': 'jemput',
    'menjemput': 'jemput',
    'menjemputnya': 'jemput',
    'menjemputku': 'jemput',
    'menjemputmu': 'jemput',
    'penjemput': 'jemput',
    'penjemputnya': 'jemput',
    'penjemputan': 'jemput',
    'penjemputannya': 'jemput',
    'jemuan': 'jemu',
    'kejemuan': 'jemu',
    'kejemuanmu': 'jemu',
    'menjemukan': 'jemu',
    'menjemukannya': 'jemu',
    'sejenak': 'jenak',
    'sejenaknya': 'jenak',
    'menjenaki': 'jenak',
    'jenangan': 'jenang',
    'jejenang': 'jenang',
    'sejenang': 'jenang',
    'penjenang': 'jenang',
    'penjenangan': 'jenang',
    'menjenangi': 'jenang',
    'jendal-jendul': 'jendal',
    'jendelan': 'jendel',
    'berjendul': 'jendul',
    'menjenengkan': 'jeneng',
    'jengekan': 'jengek',
    'menjengek': 'jengek',
    'menjengeki': 'jengek',
    'menjengek-jengek': 'jengek',
    'jenggar-jenggur': 'jenggar',
    'jenggotan': 'jenggot',
    'menjengguk': 'jengguk',
    'menjenggut': 'jenggut',
    'menjengit': 'jengit',
    'menjengit-jengit': 'jengit',
    'menjengkal': 'jengkal',
    'menjengkalkan': 'jengkal',
    'menjengkali': 'jengkal',
    'menjengkang': 'jengkang',
    'terjengkang': 'jengkang',
    'terjengkangnya': 'jengkang',
    'penjengkekan': 'jengkek',
    'berjengkek-jengkek': 'jengkek',
    'menjengkeli': 'jengkel',
    'kejengkelan': 'jengkel',
    'kejengkelannya': 'jengkel',
    'menjengkelkan': 'jengkel',
    'menjengkelkannya': 'jengkel',
    'menjengkelit': 'jengkelit',
    'berjengkeng': 'jengkeng',
    'menjengkeng': 'jengkeng',
    'berjengkengan': 'jengkeng',
    'menjengking': 'jengking',
    'menjengkit': 'jengkit',
    'kejengkolan': 'jengkol',
    'jengkoletan': 'jengkolet',
    'menjengkolet': 'jengkolet',
    'berjengkot': 'jengkot',
    'menjengkot': 'jengkot',
    'menjenguk': 'jenguk',
    'menjenguknya': 'jenguk',
    'menjengukku': 'jenguk',
    'menjengukmu': 'jenguk',
    'menjengukkan': 'jenguk',
    'menjengul': 'jengul',
    'sejenis': 'jenis',
    'sejenisnya': 'jenis',
    'sejenisnyalah': 'jenis',
    'menjenis': 'jenis',
    'penjenisan': 'jenis',
    'berjenis-jenis': 'jenis',
    'berjenjang': 'jenjang',
    'berjenjang-jenjang': 'jenjang',
    'berjentera': 'jentera',
    'jentikan': 'jentik',
    'menjentik': 'jentik',
    'menjentikkan': 'jentik',
    'menjentikkannya': 'jentik',
    'menjentikan': 'jentik',
    'kejenuhan': 'jenuh',
    'kejenuhannya': 'jenuh',
    'kejenuhanmu': 'jenuh',
    'penjenuhan': 'jenuh',
    'menjenuhkan': 'jenuh',
    'menjenuhkannya': 'jenuh',
    'menjepit': 'jepit',
    'menjepitnya': 'jepit',
    'menjepitkan': 'jepit',
    'menjepitku': 'jepit',
    'penjepit': 'jepit',
    'penjepitnya': 'jepit',
    'penjepitan': 'jepit',
    'menjeprat': 'jeprat',
    'jepretan': 'jepret',
    'jepretannya': 'jepret',
    'jepretanku': 'jepret',
    'jepretanmu': 'jepret',
    'menjepret': 'jepret',
    'menjepretnya': 'jepret',
    'menjepretkan': 'jepret',
    'terjepret': 'jepret',
    'penjepretan': 'jepret',
    'penjepretannya': 'jepret',
    'sejeput': 'jeput',
    'menjeput': 'jeput',
    'menjeputnya': 'jeput',
    'menjerakan': 'jera',
    'berjerabai': 'jerabai',
    'jerah-jerih': 'jerah',
    'terjerahak': 'jerahak',
    'menjerahap': 'jerahap',
    'terjerahap': 'jerahap',
    'berjerait': 'jerait',
    'berjeramah': 'jeramah',
    'menjeramah': 'jeramah',
    'menjerambah': 'jerambah',
    'berjerambai': 'jerambai',
    'terjerang': 'jerang',
    'menjerang': 'jerang',
    'menjerangkak': 'jerangkak',
    'menjerangkang': 'jerangkang',
    'terjerangkang': 'jerangkang',
    'berjerangkang': 'jerangkang',
    'menjerap': 'jerap',
    'penjerapan': 'jerap',
    'sejerat': 'jerat',
    'terjerat': 'jerat',
    'terjeratnya': 'jerat',
    'menjerat': 'jerat',
    'menjeratnya': 'jerat',
    'menjeratkan': 'jerat',
    'menjerauskan': 'jeraus',
    'menjerba': 'jerba',
    'menjerbak': 'jerbak',
    'menjeremba': 'jeremba',
    'terjerembap': 'jerembap',
    'menjerembapkan': 'jerembap',
    'terjerembat': 'jerembat',
    'terjerembun': 'jerembun',
    'menjerempak': 'jerempak',
    'terjerempak': 'jerempak',
    'berjerempak': 'jerempak',
    'menjereng': 'jereng',
    'menjeriau': 'jeriau',
    'berjerih': 'jerih',
    'kejerihan': 'jerih',
    'menjerihkan': 'jerih',
    'memperjerihkan': 'jerih',
    'jeritan': 'jerit',
    'jeritannya': 'jerit',
    'menjerit': 'jerit',
    'menjeritlah': 'jerit',
    'menjeritkan': 'jerit',
    'terjerit-jerit': 'jerit',
    'menjerit-jerit': 'jerit',
    'menjerkah': 'jerkah',
    'berjermang': 'jermang',
    'penjernih': 'jernih',
    'penjernihnya': 'jernih',
    'penjernihan': 'jernih',
    'kejernihan': 'jernih',
    'kejernihannya': 'jernih',
    'penjernihannya': 'jernih',
    'menjernihkan': 'jernih',
    'menjernihkannya': 'jernih',
    'terjerohok': 'jerohok',
    'terjerojol': 'jerojol',
    'menjerojol': 'jerojol',
    'menjerongkok': 'jerongkok',
    'menjerongkong': 'jerongkong',
    'terjerongkong': 'jerongkong',
    'menjeruki': 'jeruk',
    'menjerukun': 'jerukun',
    'menjerukup': 'jerukup',
    'menjerum': 'jerum',
    'berjerumat': 'jerumat',
    'penjerumat': 'jerumat',
    'menjerumat': 'jerumat',
    'terjerumus': 'jerumus',
    'terjerumusnya': 'jerumus',
    'menjerumuskan': 'jerumus',
    'menjerumuskannya': 'jerumus',
    'menjerumuskanku': 'jerumus',
    'menjerumuskanmu': 'jerumus',
    'menjerungkau': 'jerungkau',
    'menjerungkis': 'jerungkis',
    'menjerungkung': 'jerungkung',
    'terjerunuk': 'jerunuk',
    'menjetis': 'jetis',
    'jeweran': 'jewer',
    'jewerannya': 'jewer',
    'menjewer': 'jewer',
    'menjewernya': 'jewer',
    'berjibaku': 'jibaku',
    'sejibun': 'jibun',
    'berjibun': 'jibun',
    'berjibunnya': 'jibun',
    'menjidari': 'jidar',
    'berjihad': 'jihad',
    'berjihadlah': 'jihad',
    'kejijikan': 'jijik',
    'menjijikkan': 'jijik',
    'menjijikkannya': 'jijik',
    'menjijit': 'jijit',
    'terjila': 'jila',
    'menjilami': 'jilam',
    'jilatan': 'jilat',
    'jilatannya': 'jilat',
    'menjilat': 'jilat',
    'menjilatnya': 'jilat',
    'menjilatkan': 'jilat',
    'menjilatkannya': 'jilat',
    'menjilati': 'jilat',
    'penjilat': 'jilat',
    'penjilatnya': 'jilat',
    'penjilatan': 'jilat',
    'menjilat-jilat': 'jilat',
    'menjilat-jilati': 'jilat',
    'penjilid': 'jilid',
    'penjilidan': 'jilid',
    'berjilid': 'jilid',
    'menjilid': 'jilid',
    'penjilidannya': 'jilid',
    'berjilid-jilid': 'jilid',
    'menjimak': 'jimak',
    'berjimak': 'jimak',
    'menjimbit': 'jimbit',
    'jimpitan': 'jimpit',
    'sejimpit': 'jimpit',
    'menjimpit': 'jimpit',
    'penjinak': 'jinak',
    'penjinakkan': 'jinak',
    'penjinakan': 'jinak',
    'menjinaki': 'jinak',
    'jinak-jinak': 'jinak',
    'menjinakkan': 'jinak',
    'menjinakkannya': 'jinak',
    'berjinak-jinak': 'jinak',
    'penjinayah': 'jinayah',
    'menjingap': 'jingap',
    'menjingau': 'jingau',
    'kejingga-jinggaan': 'jingga',
    'berjingkat': 'jingkat',
    'berjingkat-jingkat': 'jingkat',
    'berjingkik': 'jingkik',
    'berjingkik-jingkik': 'jingkik',
    'berjingkrak': 'jingkrak',
    'berjingkraknya': 'jingkrak',
    'berjingkrakkan': 'jingkrak',
    'berjingkrakan': 'jingkrak',
    'berjingkrak-jingkrak': 'jingkrak',
    'menjingu': 'jingu',
    'jinjangan': 'jinjang',
    'berjinjang': 'jinjang',
    'jinjingan': 'jinjing',
    'terjinjing': 'jinjing',
    'menjinjing': 'jinjing',
    'menjinjingnya': 'jinjing',
    'menjinjingkan': 'jinjing',
    'berjinjit': 'jinjit',
    'menjinjit': 'jinjit',
    'menjinjitkan': 'jinjit',
    'jiplakan': 'jiplak',
    'jiplakannya': 'jiplak',
    'menjiplak': 'jiplak',
    'menjiplaknya': 'jiplak',
    'penjiplakan': 'jiplak',
    'dijiplakkan': 'jiplak',
    'menjirus': 'jirus',
    'menjitak': 'jitak',
    'menjitaki': 'jitak',
    'kejituan': 'jitu',
    'kejituannya': 'jitu',
    'menjitukan': 'jitu',
    'berjiwa': 'jiwa',
    'berjiwalah': 'jiwa',
    'kejiwaan': 'jiwa',
    'kejiwaannya': 'jiwa',
    'menjiwai': 'jiwa',
    'menjiwainya': 'jiwa',
    'menjiwit': 'jiwit',
    'berjobak': 'jobak',
    'sejodoh': 'jodoh',
    'penjodoh': 'jodoh',
    'penjodohan': 'jodoh',
    'berjodoh': 'jodoh',
    'berjodohnya': 'jodoh',
    'perjodohan': 'jodoh',
    'perjodohannya': 'jodoh',
    'menjodohkan': 'jodoh',
    'menjodohkannya': 'jodoh',
    'menjodohkanku': 'jodoh',
    'menjodohkanmu': 'jodoh',
    'memperjodohkan': 'jodoh',
    'menjodongkan': 'jodong',
    'berjogar': 'jogar',
    'menjoget': 'joget',
    'berjoget': 'joget',
    'berjogetnya': 'joget',
    'kejohanan': 'johan',
    'menjojol': 'jojol',
    'jolakan': 'jolak',
    'menjolak': 'jolak',
    'berjolak': 'jolak',
    'menjolek': 'jolek',
    'sejoli': 'joli',
    'sejolinya': 'joli',
    'joli-joli': 'joli',
    'penjolok': 'jolok',
    'menjolok': 'jolok',
    'menjolong': 'jolong',
    'jolong-jolong': 'jolong',
    'menjolor': 'jolor',
    'kejombangan': 'jombang',
    'menjompak': 'jompak',
    'berjompak': 'jompak',
    'berjompakan': 'jompak',
    'menjonget': 'jonget',
    'jonggolan': 'jonggol',
    'jonggol karang': 'jonggol',
    'menjongkang': 'jongkang',
    'jongkang-jangking': 'jongkang',
    'berjongkok': 'jongkok',
    'berjongkoklah': 'jongkok',
    'berjongkok-jongkok': 'jongkok',
    'selonjot': 'jonjot',
    'menjonjot': 'jonjot',
    'berjoran': 'joran',
    'sejoreng': 'joreng',
    'menjoreng': 'joreng',
    'penjorok': 'jorok',
    'menjorok': 'jorok',
    'menjorokkan': 'jorok',
    'kejorokan': 'jorok',
    'kejorokannya': 'jorok',
    'jotosan': 'jotos',
    'jotosannya': 'jotos',
    'menjotos': 'jotos',
    'terjotos': 'jotos',
    'berjotos': 'jotos',
    'jotos-jotosan': 'jotos',
    'berjuak': 'juak',
    'berjuakan': 'juak',
    'penjuak': 'juak',
    'penjuaknya': 'juak',
    'penjuakan': 'juak',
    'menjuak': 'juak',
    'juak-juak': 'juak',
    'menjuakkan': 'juak',
    'berjual beli': 'jual beli',
    'menjualbelikan': 'jual beli',
    'menjualbelikannya': 'jual beli',
    'memperjualbelikan': 'jual beli',
    'memperjualbelikannya': 'jual beli',
    'menjuarai': 'juara',
    'menjuarainya': 'juara',
    'kejuaraan': 'juara',
    'kejuaraannya': 'juara',
    'kejuaraanlah': 'juara',
    'berjubel': 'jubel',
    'berjubelnya': 'jubel',
    'berjubelan': 'jubel',
    'menjubeli': 'jubel',
    'berjubel-jubel': 'jubel',
    'berjubel-jubelan': 'jubel',
    'menjublek': 'jublek',
    'pejudo': 'judo',
    'berjudul': 'judul',
    'berjudulkan': 'judul',
    'menjujah': 'jujah',
    'berjujai': 'jujai',
    'menjuju': 'juju',
    'kejujuran': 'jujur',
    'kejujurannya': 'jujur',
    'kejujuranlah': 'jujur',
    'kejujuranmu': 'jujur',
    'menjujuri': 'jujur',
    'menjujut': 'jujut',
    'berjujut-jujutan': 'jujut',
    'berjulai': 'julai',
    'terjulai': 'julai',
    'menjulai': 'julai',
    'berjulai-julai': 'julai',
    'menjulang': 'julang',
    'menjulangnya': 'julang',
    'menjulangkan': 'julang',
    'berjulat': 'julat',
    'menjulat': 'julat',
    'sepenjulat': 'julat',
    'menjuling': 'juling',
    'menjulingkan': 'juling',
    'julo-julo': 'julo',
    'julukan': 'juluk',
    'julukannya': 'juluk',
    'menjuluk': 'juluk',
    'menjuluki': 'juluk',
    'menjulukinya': 'juluk',
    'penjulukan': 'juluk',
    'julung asar': 'julung',
    'julung-julung': 'julung',
    'menjulur': 'julur',
    'menjulurnya': 'julur',
    'menjulurkan': 'julur',
    'terjulur': 'julur',
    'penjuluran': 'julur',
    'julur-julur': 'julur',
    'jumatan': 'jumat',
    'berjumat': 'jumat',
    'berjumatan': 'jumat',
    'kejumbuhan': 'jumbuh',
    'berjumbul-jumbul': 'jumbul',
    'jumenengan': 'jumeneng',
    'sejumlah': 'jumlah',
    'sejumlahnya': 'jumlah',
    'sejumlahkan': 'jumlah',
    'sejumlahan': 'jumlah',
    'menjumlah': 'jumlah',
    'menjumlahkan': 'jumlah',
    'menjumlahkannya': 'jumlah',
    'terjumlah': 'jumlah',
    'berjumlah': 'jumlah',
    'berjumlahnya': 'jumlah',
    'berjumlahkan': 'jumlah',
    'penjumlahan': 'jumlah',
    'berjumpa': 'jumpa',
    'berjumpanya': 'jumpa',
    'terjumpa': 'jumpa',
    'menjumpai': 'jumpa',
    'menjumpainya': 'jumpa',
    'perjumpaan': 'jumpa',
    'perjumpaannya': 'jumpa',
    'jumpalitan': 'jumpalit',
    'berjumpalit': 'jumpalit',
    'berjumpalitan': 'jumpalit',
    'jumputan': 'jumput',
    'sejumput': 'jumput',
    'menjumput': 'jumput',
    'menjumputnya': 'jumput',
    'menjumputi': 'jumput',
    'kejumudan': 'jumud',
    'menjunam': 'junam',
    'terjunam': 'junam',
    'sijundai': 'jundai',
    'bersijundai': 'jundai',
    'menjungat': 'jungat',
    'terjungkal': 'jungkal',
    'terjungkalnya': 'jungkal',
    'menjungkalkan': 'jungkal',
    'menjungkalkannya': 'jungkal',
    'jungkang-jungkit': 'jungkang',
    'menjungkar': 'jungkar',
    'terjungkat': 'jungkat',
    'jungkat-jungkit': 'jungkat',
    'jungkat-jungkitnya': 'jungkat',
    'menjungkat-jungkit': 'jungkat',
    'berjungkir balik': 'jungkir balik',
    'penjungkirbalikan': 'jungkir balik',
    'menjungkirbalikkan': 'jungkir balik',
    'menjungkirbalikkannya': 'jungkir balik',
    'terjungkir': 'jungkir',
    'terjungkirnya': 'jungkir',
    'menjungkir': 'jungkir',
    'menjungkirkan': 'jungkir',
    'berjungkir': 'jungkir',
    'menjungkit': 'jungkit',
    'terjungkit': 'jungkit',
    'menjungur': 'jungur',
    'junjungan': 'junjung',
    'junjungannya': 'junjung',
    'junjunganku': 'junjung',
    'menjunjung': 'junjung',
    'menjunjungi': 'junjung',
    'berjunjungan': 'junjung',
    'menjunjungkan': 'junjung',
    'juntrungan': 'juntrung',
    'juntrungannya': 'juntrung',
    'berjupang': 'jupang',
    'menjura': 'jura',
    'menjurai': 'jura',
    'penjurian': 'juri',
    'penjuriannya': 'juri',
    'juringan': 'juring',
    'menjurubicarai': 'juru bicara',
    'menjuru': 'juru',
    'penjuru': 'juru',
    'penjurunya': 'juru',
    'kejuruan': 'juru',
    'kejuruannya': 'juru',
    'jurusan': 'jurus',
    'jurusannya': 'jurus',
    'jurusanku': 'jurus',
    'jurusanmu': 'jurus',
    'sejurus': 'jurus',
    'sejurusan': 'jurus',
    'menjurus': 'jurus',
    'menjurusnya': 'jurus',
    'menjuruskan': 'jurus',
    'penjurus': 'jurus',
    'penjurusan': 'jurus',
    'berjurus-jurus': 'jurus',
    'menjustifikasikan': 'justifikasi',
    'sejuta': 'juta',
    'sejutanya': 'juta',
    'sejutalah': 'juta',
    'sejutaan': 'juta',
    'jutaan': 'juta',
    'jutaannya': 'juta',
    'jutaanlah': 'juta',
    'berjuta-juta': 'juta',
    'berjuta-jutaan': 'juta',
    'pengabar': 'kabar',
    'pengabaran': 'kabar',
    'berkabar': 'kabar',
    'terkabar': 'kabar',
    'terkabarnya': 'kabar',
    'mengabarinya': 'kabar',
    'mengabariku': 'kabar',
    'perkabaran': 'kabar',
    'mengabat': 'kabat',
    'berkabilan': 'kabil',
    'mengabir': 'kabir',
    'kabir-kabiran': 'kabir',
    'mengabit': 'kabit',
    'kabruk-kabrukan': 'kabruk',
    'berkabu-kabu': 'kabu-kabu',
    'terkabul': 'kabul',
    'terkabulnya': 'kabul',
    'terkabulkan': 'kabul',
    'terkabulkannya': 'kabul',
    'pengabulan': 'kabul',
    'pengabulannya': 'kabul',
    'mengabulkan': 'kabul',
    'mengabulkannya': 'kabul',
    'mengabulkanmu': 'kabul',
    'kekaburan': 'kabur',
    'kekabur-kaburan': 'kabur',
    'mengaca': 'kaca',
    'mengacanya': 'kaca',
    'berkaca': 'kaca',
    'berkacalah': 'kaca',
    'kekacaan': 'kaca',
    'memperkaca': 'kaca',
    'berkaca-kaca': 'kaca',
    'pengacak': 'kacak',
    'pengacakan': 'kacak',
    'berkacak': 'kacak',
    'berkacamata': 'kacamata',
    'kacangan': 'kacang',
    'mengacang': 'kacang',
    'memperkacang': 'kacang',
    'kacang-kacangan': 'kacang',
    'kacang-kacangannya': 'kacang',
    'mengacar': 'kacar',
    'kacar lakum': 'kacar',
    'kacauan': 'kacau',
    'berkacau': 'kacau',
    'terkacau': 'kacau',
    'pengacau': 'kacau',
    'pengacaunya': 'kacau',
    'pengacauan': 'kacau',
    'kekacauan': 'kacau',
    'kekacauannya': 'kacau',
    'mengacaukankannya': 'kacau',
    'memperkacaukan': 'kacau',
    'mengacaubalaukan': 'kacau-balau',
    'mengacip': 'kacip',
    'mengacir': 'kacir',
    'mengada': 'kada',
    'mengadaan': 'kada',
    'dikadang': 'kadang',
    'dikadangnya': 'kadang',
    'dikadangkan': 'kadang',
    'terkadang': 'kadang',
    'terkadangkan': 'kadang',
    'terkadangan': 'kadang',
    'kadang-kadang': 'kadang',
    'kadang-kadangnya': 'kadang',
    'kadang-kadangkan': 'kadang',
    'kadang-kadangan': 'kadang',
    'terkadang-kadang': 'kadang',
    'sekadar': 'kadar',
    'sekadarnya': 'kadar',
    'sekadari': 'kadar',
    'mengadas': 'kadas',
    'mengadaskan': 'kadas',
    'mengadasi': 'kadas',
    'pengaderan': 'kader',
    'sekadim': 'kadim',
    'mengadimkan': 'kadim',
    'kadok api': 'kadok',
    'berkafan': 'kafan',
    'mengafani': 'kafan',
    'kekafiran': 'kafir',
    'kekafirannya': 'kafir',
    'mengafirkan': 'kafir',
    'mengafirkannya': 'kafir',
    'kekagetan': 'kaget',
    'kekagetannya': 'kaget',
    'mengagetkan': 'kaget',
    'mengagetkannya': 'kaget',
    'mengagetkanku': 'kaget',
    'pengagum': 'kagum',
    'pengagumnya': 'kagum',
    'mengagumi': 'kagum',
    'mengaguminya': 'kagum',
    'mengagumiku': 'kagum',
    'mengagumimu': 'kagum',
    'kekaguman': 'kagum',
    'kekagumannya': 'kagum',
    'kekagumanku': 'kagum',
    'mengagumkan': 'kagum',
    'mengagumkannya': 'kagum',
    'terkagum-kagum': 'kagum',
    'kekahatan': 'kahat',
    'terkail': 'kail',
    'mengail': 'kail',
    'pengail': 'kail',
    'pengailan': 'kail',
    'kail-kail': 'kail',
    'berkain': 'kain',
    'berkaing-kaing': 'kaing',
    'terkaing-kaing': 'kaing',
    'mengais': 'kais',
    'mengaisnya': 'kais',
    'mengaiskan': 'kais',
    'mengais-ngais': 'kais',
    'kekaisaran': 'kaisar',
    'kekaisarannya': 'kaisar',
    'sekait': 'kait',
    'sekaitan': 'kait',
    'kaitan': 'kait',
    'kaitannya': 'kait',
    'pengait': 'kait',
    'pengaitnya': 'kait',
    'pengaitan': 'kait',
    'mengait': 'kait',
    'mengaitnya': 'kait',
    'mengaitkan': 'kait',
    'mengaitkannya': 'kait',
    'mengaitan': 'kait',
    'berkait': 'kait',
    'berkaitkan': 'kait',
    'berkaitan': 'kait',
    'terkait': 'kait',
    'terkaitnya': 'kait',
    'terkaitlah': 'kait',
    'terkaitkan': 'kait',
    'terkaitan': 'kait',
    'kait-kait': 'kait',
    'kait-kaitkan': 'kait',
    'kait-kaitan': 'kait',
    'berkaitannya': 'kait',
    'keterkaitan': 'kait',
    'keterkaitannya': 'kait',
    'berkait-kaitan': 'kait',
    'berkajang': 'kajang',
    'dikajangi': 'kajang',
    'pekajangan': 'kajang',
    'mengajangi': 'kajang',
    'kajian': 'kaji',
    'kajiannya': 'kaji',
    'kajiani': 'kaji',
    'terkaji': 'kaji',
    'mengaji': 'kaji',
    'mengajinya': 'kaji',
    'mengajikan': 'kaji',
    'mengkaji': 'kaji',
    'mengkajinya': 'kaji',
    'mengkajii': 'kaji',
    'mengkajian': 'kaji',
    'pengajian': 'kaji',
    'pengajiannya': 'kaji',
    'pengajiannyalah': 'kaji',
    'pengkajian': 'kaji',
    'pengkajiannya': 'kaji',
    'terkakah-kakah': 'kakah',
    'mengakak': 'kakak',
    'mengakakan': 'kakak',
    'berkakak': 'kakak',
    'berkakakan': 'kakak',
    'terkakak-kakak': 'kakak',
    'mengakap': 'kakap',
    'mengakapi': 'kakap',
    'pengakap': 'kakap',
    'pengakapan': 'kakap',
    'mengakas': 'kakas',
    'kakek-kakek': 'kakek',
    'kakek-kakeknya': 'kakek',
    'mengakok': 'kakok',
    'kekakuan': 'kaku',
    'kekakuannya': 'kaku',
    'kekalahan': 'kalah',
    'kekalahannya': 'kalah',
    'kekalahanan': 'kalah',
    'kekalahanku': 'kalah',
    'kekalahanmu': 'kalah',
    'terkalahkan': 'kalah',
    'terkalahkannya': 'kalah',
    'mengalai': 'kalai',
    'mengalaikan': 'kalai',
    'kalangan': 'kalang',
    'kalangannya': 'kalang',
    'kalangani': 'kalang',
    'kalanganmu': 'kalang',
    'terkalang': 'kalang',
    'berkalang': 'kalang',
    'berkalangan': 'kalang',
    'kalang kabut': 'kalang',
    'kekalapan': 'kalap',
    'kalengan': 'kaleng',
    'pengalengan': 'kaleng',
    'mengalengkan': 'kaleng',
    'kaleng-kalengan': 'kaleng',
    'sekali': 'kali',
    'sekalinya': 'kali',
    'sekalilah': 'kali',
    'sekalikan': 'kali',
    'sekalii': 'kali',
    'sekalian': 'kali',
    'pengali': 'kali',
    'pengalinya': 'kali',
    'pengalilah': 'kali',
    'pengalian': 'kali',
    'sekalianlah': 'kali',
    'sesekali': 'sekali',
    'sesekalinya': 'sekali',
    'perkalian': 'kali',
    'perkaliannya': 'kali',
    'kali-kalian': 'kali',
    'kali-kaliannya': 'kali',
    'sekali-kali': 'kali',
    'sekali-kalinya': 'kali',
    'sekali-sekali': 'kali',
    'sekali-sekalinya': 'kali',
    'berka-li-kali': 'kali',
    'memperkalikan': 'kali',
    'mengalicau': 'kalicau',
    'mengalicaukan': 'kalicau',
    'berkalih': 'kalih',
    'mengalimantang': 'kalimantang',
    'mengalkulasi': 'kalkulasi',
    'mengalkulasinya': 'kalkulasi',
    'mengalkulasikan': 'kalkulasi',
    'mengalkulasikannya': 'kalkulasi',
    'sekalung': 'kalung',
    'berkalung': 'kalung',
    'berkalungkan': 'kalung',
    'mengalungkan': 'kalung',
    'mengalungkannya': 'kalung',
    'kekalutan': 'kalut',
    'kekalutannya': 'kalut',
    'mengalutkan': 'kalut',
    'mengalutmalutkan': 'kalut-malut',
    'berkamar': 'kamar',
    'mengamban': 'kamban',
    'mengambi': 'kambi',
    'mengambilah': 'kambi',
    'berkambi': 'kambi',
    'mengambinghitamkan': 'kambing hitam',
    'mengambinghitamkankan': 'kambing hitam',
    'kambuhan': 'kambuh',
    'kambuhannya': 'kambuh',
    'terkambus': 'kambus',
    'mengamitkan': 'kamit',
    'kamit-kamit': 'kamit',
    'berkamit-kamit': 'kamit',
    'mengamit-ngamitkan': 'kamit',
    'berkampai': 'kampai',
    'terkampai': 'kampai',
    'berkampaian': 'kampai',
    'berkampanye': 'kampanye',
    'berkampanyenya': 'kampanye',
    'berkampanyelah': 'kampanye',
    'mengampanyekan': 'kampanye',
    'mengampanyekannya': 'kampanye',
    'mengampas': 'kampas',
    'berkampuh': 'kampuh',
    'terkampul-kampul': 'kampul',
    'kampungan': 'kampung',
    'berkampung': 'kampung',
    'mengampung': 'kampung',
    'mengampungi': 'kampung',
    'perkampungan': 'kampung',
    'perkampungannya': 'kampung',
    'berkamu': 'kamu',
    'mengamuflase': 'kamuflase',
    'mengamuflasekan': 'kamuflase',
    'berkamuflase': 'kamuflase',
    'pekamus': 'kamus',
    'mengamus': 'kamus',
    'pengamusan': 'kamus',
    'perkamusan': 'kamus',
    'mengamuskan': 'kamus',
    'kekanak-kanakan': 'kanak-kanak',
    'kekanak-kanakannya': 'kanak-kanak',
    'kekanak-kanakanan': 'kanak-kanak',
    'penganalan': 'kanal',
    'menganan': 'kanan',
    'menganankan': 'kanan',
    'menganani': 'kanan',
    'terkanan': 'kanan',
    'terkanannya': 'kanan',
    'sekancah': 'kancah',
    'terkancah': 'kancah',
    'terkanceh': 'kanceh',
    'pengancing': 'kancing',
    'pengancingan': 'kancing',
    'terkancing': 'kancing',
    'mengancing': 'kancing',
    'mengancingkan': 'kancing',
    'mengancingkannya': 'kancing',
    'mengancingi': 'kancing',
    'sekandang': 'kandang',
    'sekandangnya': 'kandang',
    'perkandangan': 'kandang',
    'mengandangkan': 'kandang',
    'mengandangkannya': 'kandang',
    'kandaran': 'kandar',
    'kandarani': 'kandar',
    'mengandar': 'kandar',
    'pengandar': 'kandar',
    'pengandaran': 'kandar',
    'terkandas': 'kandas',
    'mengandaskan': 'kandas',
    'mengandaskannya': 'kandas',
    'mengandidatkan': 'kandidat',
    'mengandul': 'kandul',
    'berkandul': 'kandul',
    'dikandung': 'kandung',
    'dikandungnya': 'kandung',
    'dikandungan': 'kandung',
    'kandungan': 'kandung',
    'kandungannya': 'kandung',
    'kandunganku': 'kandung',
    'kandunganmu': 'kandung',
    'mengandung': 'kandung',
    'mengandungnya': 'kandung',
    'mengandungi': 'kandung',
    'mengandungan': 'kandung',
    'mengandungmu': 'kandung',
    'pengandung': 'kandung',
    'terkandung': 'kandung',
    'terkandungnya': 'kandung',
    'terkandungan': 'kandung',
    'berkandung': 'kandung',
    'berkandungan': 'kandung',
    'berkandungankan': 'kandung',
    'kandutan': 'kandut',
    'mengandut': 'kandut',
    'berkang': 'kang',
    'mengangeni': 'kangen',
    'kangen-kangenan': 'kangen',
    'mengangkang': 'kangkang',
    'mengangkangkan': 'kangkang',
    'mengangkangi': 'kangkang',
    'terkangkang': 'kangkang',
    'mengangkanginya': 'kangkang',
    'penganibalan': 'kanibal',
    'berkanjang': 'kanjang',
    'berkanjar': 'kanjar',
    'terkanjar-kanjar': 'kanjar',
    'berkanjar-kanjar': 'kanjar',
    'mengansel': 'kansel',
    'kekanseliran': 'kanselir',
    'mengantang': 'kantang',
    'berkantaran': 'kantar',
    'penganti': 'kanti',
    'pengantinya': 'kanti',
    'pengantian': 'kanti',
    'berkantong': 'kantong',
    'mengantongi': 'kantong',
    'mengantonginya': 'kantong',
    'pengantongan': 'kantong',
    'berkantor': 'kantor',
    'berkantornya': 'kantor',
    'perkantoran': 'kantor',
    'perkantorannya': 'kantor',
    'terkantuk': 'kantuk',
    'terkantuk-kantuk': 'kantuk',
    'menganvaskan': 'kanvas',
    'menganvaskannya': 'kanvas',
    'mengaoki': 'kaok',
    'berkaok-kaok': 'kaok',
    'kapa-kapa': 'kapa',
    'terkapah-kapah': 'kapah',
    'terkapai-kapai': 'kapai',
    'berkapak': 'kapak',
    'kapalan': 'kapal',
    'berkapal': 'kapal',
    'perkapalan': 'kapal',
    'perkapalannya': 'kapal',
    'pengapalan': 'kapal',
    'pengapalannya': 'kapal',
    'mengapalkan': 'kapal',
    'mengapalkannya': 'kapal',
    'kapan-kapan': 'kapan',
    'kapan-kapannya': 'kapan',
    'kapangan': 'kapang',
    'berkapang': 'kapang',
    'berkapas': 'kapas',
    'berkapasitas': 'kapasitas',
    'berkapitulasi': 'kapitulasi',
    'mengapokkan': 'kapok',
    'mengapteni': 'kapten',
    'kapu-kapu': 'kapu',
    'terkapung-kapung': 'kapung',
    'mengapur': 'kapur',
    'mengapurkan': 'kapur',
    'pekapuran': 'kapur',
    'pengapuran': 'kapur',
    'perkapuran': 'kapur',
    'sekapur sirih': 'kapur sirih',
    'berkarakter': 'karakter',
    'berkarakternya': 'karakter',
    'berkarakterlah': 'karakter',
    'mengaram': 'karam',
    'mengaramkan': 'karam',
    'mengarami': 'karam',
    'karangan': 'karang',
    'karangannya': 'karang',
    'karanganan': 'karang',
    'karanganku': 'karang',
    'pengarang': 'karang',
    'pengarangnya': 'karang',
    'berkarang': 'karang',
    'pekarangan': 'karang',
    'pekarangannya': 'karang',
    'pekaranganku': 'karang',
    'pekaranganmu': 'karang',
    'kepengarangan': 'karang',
    'karang-karangan': 'karang',
    'karang-karangannya': 'karang',
    'karang-mengarang': 'karang',
    'mengarang-ngarang': 'karang',
    'mengarantinakan': 'karantina',
    'berkaraoke': 'karaoke',
    'karas hati': 'karatan',
    'berkarau': 'karau',
    'mengarau': 'karau',
    'pengarauan': 'karau',
    'karbidan': 'karbida',
    'mengarbida': 'karbida',
    'mengarbol': 'karbol',
    'dikarenakan': 'karena',
    'dikarenakannya': 'karena',
    'mengaret': 'karet',
    'mengareti': 'karet',
    'perkaretan': 'karet',
    'mengarib': 'karib',
    'berkarib': 'karib',
    'mengaribi': 'karib',
    'kekariban': 'karib',
    'perkariban': 'karib',
    'mengaribkan': 'karib',
    'berkarier': 'karier',
    'berkariernya': 'karier',
    'berkarierlah': 'karier',
    'pengarih': 'karih',
    'berkarpet': 'karpet',
    'pengartuan': 'kartu',
    'perkartuan': 'kartu',
    'mengartukan': 'kartu',
    'mengartumerahkan': 'kartu merah',
    'berkaru': 'karu',
    'mengaru': 'karu',
    'berkarung': 'karung',
    'berkarung-karung': 'karung',
    'mengaruniai': 'karunia',
    'mengaruniainya': 'karunia',
    'mengaruniakan': 'karunia',
    'mengarut': 'karut',
    'berkarut': 'karut',
    'karut-marut': 'karut',
    'karut-marutnya': 'karut',
    'berkarya': 'karya',
    'berkaryanya': 'karya',
    'berkaryalah': 'karya',
    'kekaryaan': 'karya',
    'kekaryaannya': 'karya',
    'pengaryaan': 'karya',
    'mengaryakan': 'karya',
    'mengasadkan': 'kasad',
    'berkasak-kusuk': 'kasak-kusuk',
    'kasap jantan': 'kasap',
    'kekasaran': 'kasar',
    'kekasarannya': 'kasar',
    'mengasari': 'kasar',
    'mengasarinya': 'kasar',
    'mengasariku': 'kasar',
    'memperkasar': 'kasar',
    'mengasarkan': 'kasar',
    'perkasetan': 'kaset',
    'mengasetkan': 'kaset',
    'berkasidah': 'kasidah',
    'mengasidahkan': 'kasidah',
    'pekasih': 'kasih',
    'kekasih': 'kasih',
    'kekasihnya': 'kasih',
    'kekasihkan': 'kasih',
    'kekasihku': 'kasih',
    'kekasihmu': 'kasih',
    'kekasih-ku': 'kasih',
    'berkasih': 'kasih',
    'mengasih': 'kasih',
    'mengasihnya': 'kasih',
    'mengasihkan': 'kasih',
    'mengasihkannya': 'kasih',
    'mengasihi': 'kasih',
    'pengasih': 'kasih',
    'pengasihan': 'kasih',
    'mengasihinya': 'kasih',
    'mengasihiku': 'kasih',
    'mengasihimu': 'kasih',
    'berkasih-kasihan': 'kasih',
    'mengasihani': 'kasihan',
    'mengasihaninya': 'kasihan',
    'mengasim': 'kasim',
    'mengastrasi': 'kastrasi',
    'terkatah-katah': 'katah',
    'berkatak-katak': 'katak',
    'mengatalisasi': 'katalisasi',
    'mengatalisis': 'katalisis',
    'mengatalisit': 'katalisit',
    'pengatalog': 'katalog',
    'perkatalogan': 'katalog',
    'pengatalogan': 'katalog',
    'mengatalogkan': 'katalog',
    'berkategori': 'kategori',
    'terkategori': 'kategori',
    'terkategorikan': 'kategori',
    'mengategorikan': 'kategori',
    'mengategorikannya': 'kategori',
    'sekati': 'kati',
    'sekatinya': 'kati',
    'katian': 'kati',
    'katiannya': 'kati',
    'dikati': 'kati',
    'dikatikan': 'kati',
    'mengati': 'kati',
    'mengatikan': 'kati',
    'mengatikannya': 'kati',
    'mengatrol': 'katrol',
    'mengatrolnya': 'katrol',
    'terkatung-katung': 'katung',
    'terkatung-katungnya': 'katung',
    'terkatup': 'katup',
    'terkatupnya': 'katup',
    'mengatup': 'katup',
    'mengatupnya': 'katup',
    'mengatupkan': 'katup',
    'mengatupkannya': 'katup',
    'memperkatupkan': 'katup',
    'mengatup-ngatupkan': 'katup',
    'kaulan': 'kaul',
    'berkaul': 'kaul',
    'mengaulkan': 'kaul',
    'kauman': 'kaum',
    'berkaum': 'kaum',
    'perkauman': 'kaum',
    'berkaus': 'kaus',
    'mengaut': 'kaut',
    'mengautkan': 'kaut',
    'mengaveling': 'kaveling',
    'berkaveling': 'kaveling',
    'pengavelingan': 'kaveling',
    'mengkaver': 'kaver',
    'kawakan': 'kawak',
    'kawakannya': 'kawak',
    'kawalan': 'kawal',
    'kawalannya': 'kawal',
    'kawalanan': 'kawal',
    'berkawal': 'kawal',
    'pengawal': 'kawal',
    'pengawalnya': 'kawal',
    'pengawali': 'kawal',
    'pengawalan': 'kawal',
    'mengawal': 'kawal',
    'mengawalnya': 'kawal',
    'mengawallah': 'kawal',
    'mengawalkan': 'kawal',
    'mengawalan': 'kawal',
    'mengawalku': 'kawal',
    'mengawalmu': 'kawal',
    'pengawalannya': 'kawal',
    'pengawalanlah': 'kawal',
    'pengawalanan': 'kawal',
    'mengawih': 'kawih',
    'berkawin': 'kawin',
    'pengawin': 'kawin',
    'mengawin': 'kawin',
    'mengawinkan': 'kawin',
    'mengawinkannya': 'kawin',
    'mengawini': 'kawin',
    'mengawininya': 'kawin',
    'mengawinimu': 'kawin',
    'perkawinan': 'kawin',
    'perkawinannya': 'kawin',
    'perkawinanan': 'kawin',
    'perkawinanku': 'kawin',
    'mengawinkankan': 'kawin',
    'kawin-mawin': 'kawin',
    'terkaya': 'kaya',
    'terkayanya': 'kaya',
    'terkayakan': 'kaya',
    'kekayaan': 'kaya',
    'kekayaannya': 'kaya',
    'kekayaanan': 'kaya',
    'kekayaanmu': 'kaya',
    'pengayaan': 'kaya',
    'pengayaannya': 'kaya',
    'memperkaya': 'kaya',
    'memperkayanya': 'kaya',
    'terkayai': 'kayai',
    'mengayaikan': 'kayai',
    'pengayau': 'kayau',
    'pengayauan': 'kayau',
    'mengayau': 'kayau',
    'berkayau': 'kayau',
    'berkayu': 'kayu',
    'berkayunya': 'kayu',
    'kekayuan': 'kayu',
    'perkayuan': 'kayu',
    'kayu-kayu': 'kayu',
    'kayu-kayunya': 'kayu',
    'kayu-kayuan': 'kayu',
    'mengebal': 'kebal',
    'mengebalkan': 'kebal',
    'kekebalan': 'kebal',
    'kekebalannya': 'kebal',
    'pengebalan': 'kebal',
    'mengebas': 'kebas',
    'mengebaskan': 'kebas',
    'sekebat': 'kebat',
    'pengebat': 'kebat',
    'mengebat': 'kebat',
    'terkebat': 'kebat',
    'mengebatkan': 'kebat',
    'kebat-kebit': 'kebat',
    'terkebiri': 'kebiri',
    'terkebirinya': 'kebiri',
    'mengebiri': 'kebiri',
    'mengebirinya': 'kebiri',
    'pengebirian': 'kebiri',
    'pengebiriannya': 'kebiri',
    'mengebur': 'kebur',
    'pengebut': 'kebut',
    'pengebutan': 'kebut',
    'mengebut': 'kebut',
    'mengebutkan': 'kebut',
    'mengebuti': 'kebut',
    'kebut-kebutan': 'kebut',
    'kebut-kebutannya': 'kebut',
    'kebut-kebutanan': 'kebut',
    'berkebyaran': 'kebyar',
    'berkecak pinggang': 'kecak pinggang',
    'kecaman': 'kecam',
    'kecamannya': 'kecam',
    'kecamanan': 'kecam',
    'mengecam': 'kecam',
    'mengecamnya': 'kecam',
    'mengecamkan': 'kecam',
    'mengecaman': 'kecam',
    'mengecamku': 'kecam',
    'pengecam': 'kecam',
    'pengecamnya': 'kecam',
    'pengecaman': 'kecam',
    'berkecandan': 'kecandan',
    'kecapan': 'kecap',
    'pengecap': 'kecap',
    'pengecapnya': 'kecap',
    'terkecap-kecap': 'kecap',
    'dikecek': 'kecek',
    'berkecek-kecek': 'kecek',
    'sekeceng': 'keceng',
    'mengeceng': 'keceng',
    'mengecengkan': 'keceng',
    'terkecewa': 'kecewa',
    'kekecewaan': 'kecewa',
    'kekecewaannya': 'kecewa',
    'kekecewaanlah': 'kecewa',
    'mengecewakan': 'kecewa',
    'mengecewakannya': 'kecewa',
    'mengecewakanku': 'kecewa',
    'mengecewakanmu': 'kecewa',
    'berkeciak': 'keciak',
    'berkecibakan': 'kecibak',
    'berkecil hati': 'kecil hati',
    'sekecil': 'kecil',
    'sekecilnya': 'kecil',
    'kecilan': 'kecil',
    'mengecil': 'kecil',
    'mengecilnya': 'kecil',
    'mengecilkan': 'kecil',
    'mengecilkannya': 'kecil',
    'kekecilan': 'kecil',
    'kekecilannya': 'kecil',
    'kekecilanlah': 'kecil',
    'pengecilan': 'kecil',
    'memperkecil': 'kecil',
    'memperkecilnya': 'kecil',
    'memperkecilkan': 'kecil',
    'kecil-kecilan': 'kecil',
    'kecil-kecilannya': 'kecil',
    'kecil-mengecil': 'kecil',
    'berkecil-kecil': 'kecil',
    'berkecil-kecilan': 'kecil',
    'kecomak-kecimik': 'kecimik',
    'mengecimus': 'kecimus',
    'berkecipak': 'kecipak',
    'pengecoh': 'kecoh',
    'pengecohan': 'kecoh',
    'terkecoh': 'kecoh',
    'terkecohnya': 'kecoh',
    'mengecoh': 'kecoh',
    'mengecohnya': 'kecoh',
    'mengecohkan': 'kecoh',
    'mengecohku': 'kecoh',
    'mengecu': 'kecu',
    'berkecuali': 'kecuali',
    'mengecuali': 'kecuali',
    'mengecualikan': 'kecuali',
    'mengecualikannya': 'kecuali',
    'mengecualian': 'kecuali',
    'terkecuali': 'kecuali',
    'terkecualikan': 'kecuali',
    'kekecualian': 'kecuali',
    'perkecualian': 'kecuali',
    'perkecualiannya': 'kecuali',
    'pengecualian': 'kecuali',
    'pengecualiannya': 'kecuali',
    'memperkecualikan': 'kecuali',
    'berkecumik': 'kecumik',
    'kecupan': 'kecup',
    'kecupannya': 'kecup',
    'mengecup': 'kecup',
    'mengecupnya': 'kecup',
    'mengecupkan': 'kecup',
    'pengecut': 'kecut',
    'pengecutnya': 'kecut',
    'mengecut': 'kecut',
    'mengecutkan': 'kecut',
    'kekecutan': 'kecut',
    'kepengecutan': 'kecut',
    'berkedal': 'kedal',
    'pengedang': 'kedang',
    'mengedang': 'kedang',
    'mengedangkan': 'kedang',
    'mengedau': 'kedau',
    'kedek-kedek': 'kedek',
    'terkedek-kedek': 'kedek',
    'kedekak-kedekik': 'kedekik',
    'kedewaga': 'kedewas',
    'mengedik': 'kedik',
    'mengedikkan': 'kedik',
    'terkedik': 'kedik',
    'berkedip': 'kedip',
    'berkediplah': 'kedip',
    'terkedip': 'kedip',
    'mengedipkan': 'kedip',
    'mengedipkannya': 'kedip',
    'terkedip-kedip': 'kedip',
    'berkedip-kedip': 'kedip',
    'berkedok': 'kedok',
    'berkedokkan': 'kedok',
    'memperkedok': 'kedok',
    'kekedotan': 'kedot',
    'mengeduk': 'keduk',
    'terkehel': 'kehel',
    'mengejai': 'kejai',
    'berkejai': 'kejai',
    'terkejam': 'kejam',
    'mengejam': 'kejam',
    'kekejaman': 'kejam',
    'kekejamannya': 'kejam',
    'kekejamanan': 'kejam',
    'mengejami': 'kejam',
    'mengejamkan': 'kejam',
    'berkejang': 'kejang',
    'mengejang': 'kejang',
    'mengejangnya': 'kejang',
    'mengejangkan': 'kejang',
    'kekejangan': 'kejang',
    'berkejang-kejang': 'kejang',
    'kejang-kejang': 'mengejang',
    'kejang-kejangnya': 'mengejang',
    'kejapan': 'kejap',
    'kejapanan': 'kejap',
    'sekejap': 'kejap',
    'berkejap': 'kejap',
    'mengejap': 'kejap',
    'mengejapkan': 'kejap',
    'berkejap-kejap': 'kejap',
    'dikejar': 'kejar',
    'dikejarnya': 'kejar',
    'dikejarkan': 'kejar',
    'kejaran': 'kejar',
    'kejarannya': 'kejar',
    'mengejar': 'kejar',
    'mengejarnya': 'kejar',
    'mengejarkan': 'kejar',
    'mengejari': 'kejar',
    'mengejaran': 'kejar',
    'mengejarku': 'kejar',
    'mengejarmu': 'kejar',
    'terkejar': 'kejar',
    'berkejaran': 'kejar',
    'bersikejar': 'kejar',
    'pengejaran': 'kejar',
    'pengejarannya': 'kejar',
    'kejar-mengejar': 'kejar',
    'terkejar-kejar': 'kejar',
    'mengejar-ngejar': 'kejar',
    'mengejar-ngejarnya': 'kejar',
    'berkejar-kejaran': 'kejar',
    'berkeji': 'keji',
    'kekejian': 'keji',
    'kekejiannya': 'keji',
    'mengejikan': 'keji',
    'mengejuju': 'kejuju',
    'kejutan': 'kejut',
    'kejutannya': 'kejut',
    'terkejut': 'kejut',
    'terkejutnya': 'kejut',
    'terkejutlah': 'kejut',
    'terkejutkan': 'kejut',
    'terkejutan': 'kejut',
    'berkejut': 'kejut',
    'mengejut': 'kejut',
    'mengejutnya': 'kejut',
    'mengejutkan': 'kejut',
    'mengejutkannya': 'kejut',
    'mengejutan': 'kejut',
    'pengejut': 'kejut',
    'pengejutkan': 'kejut',
    'mengejuti': 'kejut',
    'kekejutan': 'kejut',
    'kekejutannya': 'kejut',
    'berkejutan': 'kejut',
    'mengejutkanlah': 'kejut',
    'mengejutkankan': 'kejut',
    'mengejutkanku': 'kejut',
    'kejut-kejut': 'kejut',
    'kejut-kejutan': 'kejut',
    'keterkejutan': 'kejut',
    'keterkejutannya': 'kejut',
    'berkejut telinga': 'kejut',
    'mengejut-ngejuti': 'kejut',
    'mengekah': 'kekah',
    'kekangan': 'kekang',
    'terkekang': 'kekang',
    'terkekangnya': 'kekang',
    'mengekang': 'kekang',
    'mengekangnya': 'kekang',
    'mengekangi': 'kekang',
    'mengekangan': 'kekang',
    'pengekangan': 'kekang',
    'mengekar': 'kekar',
    'mengekarkan': 'kekar',
    'mengekas': 'kekas',
    'terkekau-kekau': 'kekau',
    'terkekeh-kekeh': 'kekeh',
    'mengekek': 'kekek',
    'terkekek-kekek': 'kekek',
    'mengelam': 'kelam',
    'mengelamkan': 'kelam',
    'mengelami': 'kelam',
    'berkelam': 'kelam',
    'kekelaman': 'kelam',
    'pengelaman': 'kelam',
    'pengelamannya': 'kelam',
    'mengenyal': 'kenyal',
    'mengenyalkan': 'kenyal',
    'kekenyalan': 'kenyal',
    'kekenyalannya': 'kenyal',
    'kekenyangan': 'kenyang',
    'kekenyangannya': 'kenyang',
    'sekenyangnya': 'kenyang',
    'mengenyangkan': 'kenyang',
    'sekenyang-kenyangnya': 'kenyang',
    'mengeker': 'keker',
    'kikiran': 'kikir',
    'kikirannya': 'kikir',
    'mengikir': 'kikir',
    'berkikir': 'kikir',
    'kekikiran': 'kikir',
    'mengekol': 'kol',
    'berkukuh': 'kukuh',
    'berkukuhnya': 'kukuh',
    'mengukuhi': 'kukuh',
    'kekukuhan': 'kukuh',
    'kekukuhannya': 'kukuh',
    'pengukuhan': 'kukuh',
    'pengukuhannya': 'kukuh',
    'memperkukuh': 'kukuh',
    'memperkukuhkan': 'kukuh',
    'mengukuhkan': 'kukuh',
    'mengukuhkannya': 'kukuh',
    'menguning': 'kuning',
    'menguningnya': 'kuning',
    'menguningkan': 'kuning',
    'kekuningan': 'kuning',
    'kekuning-kuningan': 'kuning',
    'kekunoan': 'kuno',
    'kekunoannya': 'kuno',
    'kurusan': 'kurus',
    'mengurus': 'urus',
    'mengurusnya': 'urus',
    'menguruskan': 'urus',
    'menguruskannya': 'urus',
    'mengurusi': 'urus',
    'mengurusan': 'urus',
    'mengurusmu': 'urus',
    'kekurusan': 'kurus',
    'pengurusan': 'urus',
    'pengurusannya': 'urus',
    'mengusut': 'usut',
    'mengusutnya': 'usut',
    'mengusutkan': 'usut',
    'mengusuti': 'usut',
    'mengusutan': 'usut',
    'kekusutan': 'kusut',
    'kekusutannya': 'kusut',
    'berkusut-kusut': 'kusut',
    'kelabakan': 'kelabak',
    'kelabangan': 'kelabang',
    'berkelabang': 'kelabang',
    'mengelabang': 'kelabang',
    'mengelabui': 'kelabu',
    'mengelabuinya': 'kelabu',
    'pengelabuan': 'kelabu',
    'pengelabuannya': 'kelabu',
    'mengeladau': 'keladau',
    'mengelah': 'kelah',
    'mengelahkan': 'kelah',
    'mengelai': 'kelai',
    'mengelai-ngelai': 'kelai',
    'pelalai': 'lalai',
    'pelalaian': 'lalai',
    'terlalai': 'lalai',
    'terlalaikan': 'lalai',
    'kelalaian': 'lalai',
    'kelalaiannya': 'lalai',
    'melalaikan': 'lalai',
    'melalaikannya': 'lalai',
    'memperlalaikan': 'lalai',
    'berlalai-lalai': 'lalai',
    'berkelambu': 'kelambu',
    'sekelamin': 'kelamin',
    'berkelamin': 'kelamin',
    'mengelamini': 'kelamin',
    'berlancang': 'lancang',
    'kelancangan': 'lancang',
    'kelancangannya': 'lancang',
    'lancang-lancang': 'lancang',
    'lancaran': 'lancar',
    'pelancar': 'lancar',
    'pelancarkan': 'lancar',
    'pelancaran': 'lancar',
    'melancar': 'lancar',
    'melancarkan': 'lancar',
    'melancarkannya': 'lancar',
    'melancaran': 'lancar',
    'kelancaran': 'lancar',
    'kelancarannya': 'lancar',
    'kelancaranan': 'lancar',
    'kelancaranmu': 'lancar',
    'memperlancar': 'lancar',
    'memperlancarnya': 'lancar',
    'memperlancarkan': 'lancar',
    'memperlancaran': 'lancar',
    'mengelanjar': 'kelanjar',
    'berkelanjaran': 'kelanjar',
    'mengelantang': 'kelantang',
    'sekelap': 'kelap',
    'kelap-kelip': 'terkelap',
    'mengelapkan': 'lap',
    'berlapar': 'lapar',
    'kelaparan': 'lapar',
    'kelaparannya': 'lapar',
    'kelaparanlah': 'lapar',
    'melaparkan': 'lapar',
    'berkelar': 'kelar',
    'mengelar': 'kelar',
    'mengelarkan': 'kelar',
    'berkelar-kelar': 'kelar',
    'mengelarai': 'kelarai',
    'melarut': 'larut',
    'melarutnya': 'larut',
    'melarutkan': 'larut',
    'melarutkannya': 'larut',
    'pelarut': 'larut',
    'pelarutnya': 'larut',
    'pelarutan': 'larut',
    'larutan': 'larut',
    'larutannya': 'larut',
    'terlarut': 'larut',
    'terlarutnya': 'larut',
    'terlarutkan': 'larut',
    'kelarutan': 'larut',
    'kelarutannya': 'larut',
    'pelarutannya': 'larut',
    'berlarut-larut': 'larut',
    'berlarut-larutnya': 'larut',
    'keberlarut-larutan': 'larut',
    'mengelas': 'las',
    'mengelasnya': 'las',
    'berkelas': 'kelas',
    'berkelasnya': 'kelas',
    'mengelaskan': 'kelas',
    'kelasah-kelusuh': 'kelasah',
    'pengelat': 'kelat',
    'pelaut': 'laut',
    'pelautnya': 'laut',
    'lautan': 'laut',
    'lautannya': 'laut',
    'melaut': 'laut',
    'melautnya': 'laut',
    'melauti': 'laut',
    'pelautan': 'laut',
    'kelautan': 'laut',
    'kelautannya': 'laut',
    'kelautanlah': 'laut',
    'kelautanan': 'laut',
    'melautkan': 'laut',
    'melayak': 'layak',
    'melayakkan': 'layak',
    'melayakan': 'layak',
    'layaknya': 'layak',
    'terlayak': 'layak',
    'kelayakan': 'layak',
    'kelayakannya': 'layak',
    'kelayakanan': 'layak',
    'kelayakanku': 'layak',
    'kelayakanmu': 'layak',
    'selayaknya': 'layak',
    'selayaknyalah': 'layak',
    'melayu': 'layu',
    'melayunya': 'layu',
    'pelayuan': 'layu',
    'pelayuanan': 'layu',
    'kelayuan': 'layu',
    'layu-layuan': 'layu',
    'kelebatan': 'kelebat',
    'sekelebat': 'kelebat',
    'sekelebatan': 'kelebat',
    'berkelebat': 'kelebat',
    'berkelebatnya': 'kelebat',
    'berkelebatan': 'kelebat',
    'mengelebatkan': 'kelebat',
    'mengelebekkan': 'kelebek',
    'mengelebukan': 'kelebu',
    'berkeledar': 'keledar',
    'berkelejat': 'kelejat',
    'kelek-kelek': 'kelek',
    'kelek-kelekan': 'kelek',
    'berkelelot': 'kelelot',
    'mengelelotkan': 'kelelot',
    'kelembaman': 'lembam',
    'berkelemban': 'kelemban',
    'pelembap': 'lembap',
    'pelembapnya': 'lembap',
    'pelembapan': 'lembap',
    'kelembapan': 'lembap',
    'kelembapannya': 'lembap',
    'melembapkan': 'lembap',
    'melembapkannya': 'lembap',
    'berkelembapan': 'lembap',
    'pelembut': 'lembut',
    'pelembutnya': 'lembut',
    'pelembutan': 'lembut',
    'terlembut': 'lembut',
    'kelembutan': 'lembut',
    'kelembutannya': 'lembut',
    'melembutkan': 'lembut',
    'melembutkannya': 'lembut',
    'terkelempai': 'kelempai',
    'kelengangan': 'lengang',
    'melengangkan': 'lengang',
    'mengelenggarakan': 'kelenggara',
    'kelenyapan': 'lenyap',
    'melenyapkan': 'lenyap',
    'melenyapkannya': 'lenyap',
    'melenyapkanku': 'lenyap',
    'terkelepai': 'kelepai',
    'mengelepai': 'kelepai',
    'berkelepai': 'kelepai',
    'berkelepai-kelepai': 'kelepai',
    'mengelepat': 'kelepat',
    'terkelepek': 'kelepek',
    'terkelepet': 'kelepet',
    'mengelepik-ngelepik': 'kelepik',
    'mengelepur': 'kelepur',
    'mengelesot': 'kelesot',
    'kelesuan': 'lesu',
    'kelesuannya': 'lesu',
    'berkeletah': 'keletah',
    'berletih': 'letih',
    'keletihan': 'letih',
    'keletihannya': 'letih',
    'meletihkan': 'letih',
    'berletih-letih': 'letih',
    'melewah': 'lewah',
    'kelewahan': 'lewah',
    'kelewat': 'lewat',
    'kelewatan': 'lewat',
    'selewat': 'lewat',
    'selewatnya': 'lewat',
    'selewatan': 'lewat',
    'terlewat': 'lewat',
    'terlewatnya': 'lewat',
    'terlewatkan': 'lewat',
    'terlewatkannya': 'lewat',
    'terlewati': 'lewat',
    'melewati': 'lewat',
    'melewatinya': 'lewat',
    'melewatiku': 'lewat',
    'melewatimu': 'lewat',
    'terlewatinya': 'lewat',
    'terlewatikan': 'lewat',
    'berlewatan': 'lewat',
    'melewatkan': 'lewat',
    'melewatkannya': 'lewat',
    'melewatkanmu': 'lewat',
    'berkeliaran': 'keliar',
    'berkeliarannya': 'keliar',
    'berkelibang': 'kelibang',
    'berkelibangan': 'kelibang',
    'mengelibat': 'kelibat',
    'kelicikan': 'licik',
    'kelicikannya': 'licik',
    'mengelih': 'kelih',
    'pelihat': 'lihat',
    'pelihatan': 'lihat',
    'melihat': 'lihat',
    'melihatnya': 'lihat',
    'melihatlah': 'lihat',
    'melihatkan': 'lihat',
    'melihati': 'lihat',
    'melihatan': 'lihat',
    'melihatku': 'lihat',
    'melihatmu': 'lihat',
    'terlihat': 'lihat',
    'terlihatnya': 'lihat',
    'terlihatlah': 'lihat',
    'terlihatan': 'lihat',
    'kelihatan': 'lihat',
    'kelihatannya': 'lihat',
    'kelihatanlah': 'lihat',
    'penglihat': 'lihat',
    'penglihatnya': 'lihat',
    'penglihatan': 'lihat',
    'penglihatannya': 'lihat',
    'penglihatani': 'lihat',
    'penglihatanku': 'lihat',
    'penglihatanmu': 'lihat',
    'melihat-lihat': 'lihat',
    'melihat-lihatnya': 'lihat',
    'memperlihatkan': 'lihat',
    'memperlihatkannya': 'lihat',
    'memperlihatkanlah': 'lihat',
    'berkelijak': 'kelijak',
    'terkelik': 'kelik',
    'mengelik': 'kelik',
    'mengelikan': 'kelik',
    'mengelikkan': 'lik',
    'mengelikik': 'kelikik',
    'kelilipan': 'kelilip',
    'berkelim': 'kelim',
    'mengelim': 'kelim',
    'pengelim': 'kelim',
    'kelincahan': 'lincah',
    'kelincahannya': 'lincah',
    'melincah-lincah': 'lincah',
    'terlincah-lincah': 'lincah',
    'berkelindan': 'kelindan',
    'berkelindannya': 'kelindan',
    'mengeling': 'keling',
    'mengelingi': 'keling',
    'terkelinjat-kelinjat': 'kelinjat',
    'kelintaran': 'kelintar',
    'berkelintaran': 'kelintar',
    'kelintingan': 'kelinting',
    'berkelip': 'kelip',
    'kelip-kelip': 'kelip',
    'berkelip-kelip': 'kelip',
    'terkelip-kelip': 'kelip',
    'mengelip-ngelip': 'kelip',
    'kekeliruan': 'keliru',
    'kekeliruannya': 'keliru',
    'pengeliruan': 'keliru',
    'mengelirukan': 'keliru',
    'mengelis': 'kelis',
    'berkelit': 'kelit',
    'berkelitnya': 'kelit',
    'berkelitlah': 'kelit',
    'mengelit': 'kelit',
    'mengelitkan': 'kelit',
    'mengeliti': 'kelit',
    'berkelit-kelit': 'kelit',
    'kelobaan': 'loba',
    'berkelocak': 'kelocak',
    'mengelocak': 'kelocak',
    'mengelodan': 'kelodan',
    'terkelola': 'kelola',
    'terkelolanya': 'kelola',
    'pengelola': 'kelola',
    'pengelolanya': 'kelola',
    'pengelolaan': 'kelola',
    'mengelola': 'kelola',
    'mengelolanya': 'kelola',
    'mengelolakan': 'kelola',
    'mengelolaan': 'kelola',
    'pengelolaannya': 'kelola',
    'terkelolong': 'kelolong',
    'kelompokan': 'kelompok',
    'mengelompok': 'kelompok',
    'mengelompokkan': 'kelompok',
    'mengelompokkannya': 'kelompok',
    'mengelompokan': 'kelompok',
    'berkelompok': 'kelompok',
    'berkelompoknya': 'kelompok',
    'pengelompokan': 'kelompok',
    'pengelompokannya': 'kelompok',
    'berkelompok-kelompok': 'kelompok',
    'sekelonet': 'kelonet',
    'berkelong': 'kelong',
    'melonggari': 'longgar',
    'kelonggaran': 'longgar',
    'kelonggarannya': 'longgar',
    'melonggarkan': 'longgar',
    'melonggarkannya': 'longgar',
    'memperlonggar': 'longgar',
    'memperlonggari': 'longgar',
    'mengelosok': 'kelosok',
    'mengelotok': 'kelotok',
    'berkeloyak': 'keloyak',
    'terkeloyak': 'keloyak',
    'mengeloyor': 'keloyor',
    'terkelu': 'kelu',
    'mengeluani': 'keluan',
    'keluaran': 'keluar',
    'keluarannya': 'keluar',
    'mengeluari': 'keluar',
    'pengeluaran': 'keluar',
    'pengeluarannya': 'keluar',
    'pengeluaranku': 'keluar',
    'pengeluaranmu': 'keluar',
    'mengeluarkan': 'keluar',
    'mengeluarkannya': 'keluar',
    'mengeluarkankan': 'keluar',
    'mengeluarkanku': 'keluar',
    'mengeluarkanmu': 'keluar',
    'keluarbiasaan': 'luar biasa',
    'keluarbiasaannya': 'luar biasa',
    'meluas': 'luas',
    'meluasnya': 'luas',
    'meluaslah': 'luas',
    'meluaskan': 'luas',
    'meluaskannya': 'luas',
    'meluasi': 'luas',
    'luasan': 'luas',
    'luasannya': 'luas',
    'keluasan': 'luas',
    'peluasan': 'luas',
    'peluasannya': 'luas',
    'peluasanan': 'luas',
    'perluasan': 'luas',
    'perluasannya': 'luas',
    'memperluas': 'luas',
    'memperluasnya': 'luas',
    'memperluaskan': 'luas',
    'memperluaskannya': 'luas',
    'terkelubak': 'kelubak',
    'kelucahan': 'lucah',
    'keluhan': 'keluh',
    'keluhannya': 'keluh',
    'keluhanlah': 'keluh',
    'keluhanan': 'keluh',
    'keluhanku': 'keluh',
    'keluhanmu': 'keluh',
    'terkeluh': 'keluh',
    'berkeluh': 'keluh',
    'mengeluh': 'keluh',
    'mengeluhnya': 'keluh',
    'mengeluhlah': 'keluh',
    'mengeluhkan': 'keluh',
    'mengeluhkannya': 'keluh',
    'mengeluhan': 'keluh',
    'pengeluh': 'keluh',
    'pengeluhan': 'keluh',
    'terkeluk': 'keluk',
    'berkeluk': 'keluk',
    'berkelukur': 'kelukur',
    'berkelukuran': 'kelukur',
    'sekelumit': 'kelumit',
    'kelumpuhan': 'lumpuh',
    'kelumpuhannya': 'lumpuh',
    'melumpuhkan': 'lumpuh',
    'melumpuhkannya': 'lumpuh',
    'berkelumun': 'kelumun',
    'mengelumuni': 'kelumun',
    'berkelun-kelun': 'kelun',
    'mengelupas': 'kelupas',
    'mengelupasnya': 'kelupas',
    'mengelupaskan': 'kelupas',
    'mengelupasi': 'kelupas',
    'terkelupas': 'kelupas',
    'terkelupasnya': 'kelupas',
    'mengelupur': 'kelupur',
    'melurus': 'lurus',
    'meluruskan': 'lurus',
    'meluruskannya': 'lurus',
    'melurusan': 'lurus',
    'kelurusan': 'lurus',
    'selurusan': 'lurus',
    'berselurus': 'lurus',
    'meluruskanlah': 'lurus',
    'selurusnya': 'lurus',
    'kelut-melut': 'kelut',
    'berkeluyuran': 'keluyur',
    'kemagnetan': 'magnet',
    'berkemah': 'kemah',
    'berkemahnya': 'kemah',
    'berkemahlah': 'kemah',
    'perkemahan': 'kemah',
    'perkemahannya': 'kemah',
    'perkemahanan': 'kemah',
    'memahiri': 'mahir',
    'kemahiran': 'mahir',
    'kemahirannya': 'mahir',
    'memahirkan': 'mahir',
    'mempermahir': 'mahir',
    'memaju': 'maju',
    'memajukan': 'maju',
    'memajukannya': 'maju',
    'kemajuan': 'maju',
    'kemajuannya': 'maju',
    'kemajuanlah': 'maju',
    'kemajuanmu': 'maju',
    'pemajuan': 'maju',
    'kemakmuran': 'makmur',
    'kemakmurannya': 'makmur',
    'memakmurkan': 'makmur',
    'memakmurkannya': 'makmur',
    'persemakmuran': 'makmur',
    'persemakmurannya': 'makmur',
    'berkemal': 'kemal',
    'pemalas': 'malas',
    'pemalasnya': 'malas',
    'pemalasan': 'malas',
    'kemalasan': 'malas',
    'kemalasannya': 'malas',
    'memalaskan': 'malas',
    'malas-malasan': 'malas',
    'bermalas-malas': 'malas',
    'bermalas-malasan': 'malas',
    'mengemam': 'kemam',
    'kemangkatan': 'mangkat',
    'kemangkatannya': 'mangkat',
    'kemanjuran': 'manjur',
    'kemanjurannya': 'manjur',
    'kemanusiaan': 'manusia',
    'kemanusiaannya': 'manusia',
    'kemanusiaanlah': 'manusia',
    'kemanusiaanmu': 'manusia',
    'pemanusiaan': 'manusia',
    'memanusiakan': 'manusia',
    'dikemarikan': 'kemari',
    'masukan': 'masuk',
    'masukannya': 'masuk',
    'masukanlah': 'masuk',
    'memasuki': 'masuk',
    'memasukinya': 'masuk',
    'memasukii': 'masuk',
    'termasuk': 'masuk',
    'termasuknya': 'masuk',
    'termasuklah': 'masuk',
    'termasuki': 'masuk',
    'termasukan': 'masuk',
    'pemasukan': 'masuk',
    'pemasukannya': 'masuk',
    'pemasukanan': 'masuk',
    'pemasukanku': 'masuk',
    'pemasukanmu': 'masuk',
    'kemasukan': 'masuk',
    'kemasukannya': 'masuk',
    'memasukkan': 'masuk',
    'memasukkannya': 'masuk',
    'memasukkanku': 'masuk',
    'termasyhur': 'masyhur',
    'kemasyhuran': 'masyhur',
    'kemasyhurannya': 'masyhur',
    'pemasyhuran': 'masyhur',
    'memasyhurkan': 'masyhur',
    'kematangan': 'matang',
    'kematangannya': 'matang',
    'kematanganlah': 'matang',
    'pematangan': 'matang',
    'pematangannya': 'matang',
    'mematangkan': 'matang',
    'mematangkannya': 'matang',
    'kembalian': 'kembali',
    'kembaliannya': 'kembali',
    'pengembalian': 'kembali',
    'pengembaliannya': 'kembali',
    'mengembalikan': 'kembali',
    'mengembalikannya': 'kembali',
    'mengembalikankan': 'kembali',
    'mengembalikanku': 'kembali',
    'mengembalikanmu': 'kembali',
    'berkemban': 'kemban',
    'berkembannya': 'kemban',
    'berkembang biak': 'kembang biak',
    'pengembangbiakan': 'kembang biak',
    'pengembangbiakannya': 'kembang biak',
    'perkembangbiakan': 'kembang biak',
    'perkembangbiakannya': 'kembang biak',
    'mengembangbiakkan': 'kembang biak',
    'mengembangbiakkannya': 'kembang biak',
    'mengembeng': 'kembeng',
    'mengembengkan': 'kembeng',
    'mengembungkan': 'kembung',
    'mengembur': 'kembur',
    'mengemburkan': 'kembur',
    'berkembur': 'kembur',
    'berkembur-kembur': 'kembur',
    'bermegah': 'megah',
    'kemegahan': 'megah',
    'kemegahannya': 'megah',
    'memegahkan': 'megah',
    'bermegah-megah': 'megah',
    'bermegah-megahan': 'megah',
    'berkemeja': 'kemeja',
    'kemelaratan': 'melarat',
    'kemelaratannya': 'melarat',
    'memeleset': 'peleset',
    'memelesetkan': 'peleset',
    'memelesetkannya': 'peleset',
    'memelesetan': 'peleset',
    'pelesetan': 'peleset',
    'pelesetannya': 'peleset',
    'terpeleset': 'peleset',
    'terpelesetnya': 'peleset',
    'kemelesetan': 'peleset',
    'pemelesetan': 'peleset',
    'berkemendang': 'kemendang',
    'mengemendang': 'kemendang',
    'berkementam': 'kementam',
    'kementerian': 'menteri',
    'kementeriannya': 'menteri',
    'kementeriani': 'menteri',
    'pemerdeka': 'merdeka',
    'pemerdekaan': 'merdeka',
    'kemerdekaan': 'merdeka',
    'kemerdekaannya': 'merdeka',
    'kemerdekaanlah': 'merdeka',
    'kemerdekaanku': 'merdeka',
    'memerdekakan': 'merdeka',
    'memerdekakannya': 'merdeka',
    'semerdeka-merdekanya': 'merdeka',
    'kemerduan': 'merdu',
    'termesra': 'mesra',
    'kemesraan': 'mesra',
    'kemesraannya': 'mesra',
    'bermesraan': 'mesra',
    'bermesraanlah': 'mesra',
    'memesrakan': 'mesra',
    'bermesra-mesraan': 'mesra',
    'berkemih': 'kemih',
    'berkemihnya': 'kemih',
    'berkemihlah': 'kemih',
    'kemak-kemik': 'kemik',
    'kemiringan': 'miring',
    'kemiringannya': 'miring',
    'memiringkan': 'miring',
    'kemiripan': 'mirip',
    'kemiripannya': 'mirip',
    'kemiripanku': 'mirip',
    'bermiripan': 'mirip',
    'pemiskinan': 'miskin',
    'kemiskinan': 'miskin',
    'kemiskinannya': 'miskin',
    'kemiskinanlah': 'miskin',
    'kemiskinanan': 'miskin',
    'kemiskinanku': 'miskin',
    'memiskinkan': 'miskin',
    'memiskinkannya': 'miskin',
    'kemontokan': 'montok',
    'kempaan': 'kempa',
    'mengempa': 'kempa',
    'terkempa': 'kempa',
    'pengempaan': 'kempa',
    'kempang-kempis': 'kempang',
    'mengempis': 'kempis',
    'mengempisnya': 'kempis',
    'mengempiskan': 'kempis',
    'mengempiskannya': 'kempis',
    'pengempisan': 'kempis',
    'kempas-kempis': 'kempis',
    'mengempit': 'kempit',
    'kemplangan': 'kemplang',
    'mengemplang': 'kemplang',
    'mengemplangan': 'kemplang',
    'berkempul-kempul': 'kempul',
    'terkempul-kempul': 'kempul',
    'mengemu': 'kemu',
    'mengemukan': 'kemu',
    'mengemui': 'kemu',
    'berkemu': 'kemu',
    'bermudarat': 'mudarat',
    'kemudaratan': 'mudarat',
    'kemudaratannya': 'mudarat',
    'terkemudian': 'kemudian',
    'mengemudiankan': 'kemudian',
    'kemujaraban': 'mujarab',
    'kemujarabannya': 'mujarab',
    'mengemuli': 'kemul',
    'pemulia': 'mulia',
    'pemuliaan': 'mulia',
    'termulia': 'mulia',
    'kemuliaan': 'mulia',
    'kemuliaannya': 'mulia',
    'kemuliaanan': 'mulia',
    'kemuliaanku': 'mulia',
    'pemuliaannya': 'mulia',
    'memuliakan': 'mulia',
    'memuliakannya': 'mulia',
    'mempermulia': 'mulia',
    'kemunafikan': 'munafik',
    'kemunafikannya': 'munafik',
    'kemunafikanlah': 'munafik',
    'kemungkinan': 'mungkin',
    'kemungkinannya': 'mungkin',
    'kemungkinanlah': 'mungkin',
    'kemungkinankan': 'mungkin',
    'kemungkinanan': 'mungkin',
    'kemungkinanku': 'mungkin',
    'memungkinkan': 'mungkin',
    'memungkinkannya': 'mungkin',
    'memungkinkanlah': 'mungkin',
    'memungkinkankan': 'mungkin',
    'memungkinkanku': 'mungkin',
    'memungkinkanmu': 'mungkin',
    'memurkai': 'murka',
    'kemurkaan': 'murka',
    'kemurkaannya': 'murka',
    'kemurkaan-mu': 'murka',
    'kemurnian': 'murni',
    'kemurniannya': 'murni',
    'pemurnian': 'murni',
    'pemurniannya': 'murni',
    'memurnikan': 'murni',
    'memurnikannya': 'murni',
    'kemurtadan': 'murtad',
    'kemurtadannya': 'murtad',
    'pemurtadan': 'murtad',
    'memurtadkan': 'murtad',
    'kemurungan': 'murung',
    'kemurungannya': 'murung',
    'kemustajaban': 'mustajab',
    'terkemut-kemut': 'kemut',
    'mengena': 'kena',
    'mengenakan': 'kena',
    'mengenakannya': 'kena',
    'mengenai': 'kena',
    'mengenaan': 'kena',
    'terkena': 'kena',
    'terkenanya': 'kena',
    'terkenakan': 'kena',
    'terkenai': 'kena',
    'mengenainya': 'kena',
    'mengenaikan': 'kena',
    'mengenaii': 'kena',
    'mengenaiku': 'kena',
    'mengenaimu': 'kena',
    'pengenaan': 'kena',
    'pengenaannya': 'kena',
    'berkenaan': 'kena',
    'berkenaannya': 'kena',
    'perkenaan': 'kena',
    'perkenaannya': 'kena',
    'kena-mengena': 'kena',
    'berkena-kenaan': 'kena',
    'kenaifan': 'naif',
    'kenaifanku': 'naif',
    'kenalan': 'kenal',
    'kenalannya': 'kenal',
    'kenalanan': 'kenal',
    'kenalanmu': 'kenal',
    'terkenal': 'kenal',
    'terkenalnya': 'kenal',
    'terkenallah': 'kenal',
    'terkenali': 'kenal',
    'terkenalan': 'kenal',
    'pengenal': 'kenal',
    'pengenalnya': 'kenal',
    'pengenalan': 'kenal',
    'pengenalku': 'kenal',
    'mengenal': 'kenal',
    'mengenalnya': 'kenal',
    'mengenalkan': 'kenal',
    'mengenalkannya': 'kenal',
    'mengenali': 'kenal',
    'mengenalan': 'kenal',
    'mengenalku': 'kenal',
    'mengenalmu': 'kenal',
    'mengenalinya': 'kenal',
    'mengenalikan': 'kenal',
    'mengenaliku': 'kenal',
    'mengenalimu': 'kenal',
    'pengenalannya': 'kenal',
    'pengenalanan': 'kenal',
    'berkenalan': 'kenal',
    'berkenalannya': 'kenal',
    'berkenalanlah': 'kenal',
    'perkenalan': 'kenal',
    'perkenalannya': 'kenal',
    'perkenalanan': 'kenal',
    'perkenalanku': 'kenal',
    'perkenalanmu': 'kenal',
    'kenal-mengenal': 'kenal',
    'memperkenalkan': 'kenal',
    'memperkenalkannya': 'kenal',
    'memperkenalkankan': 'kenal',
    'memperkenalkanku': 'kenal',
    'memperkenalkanmu': 'kenal',
    'berkenal-kenalan': 'kenal',
    'kenangan': 'kenang',
    'kenangannya': 'kenang',
    'kenangani': 'kenang',
    'kenanganan': 'kenang',
    'kenanganku': 'kenang',
    'kenanganmu': 'kenang',
    'mengenang': 'kenang',
    'mengenangnya': 'kenang',
    'mengenangkan': 'kenang',
    'mengenangkannya': 'kenang',
    'mengenangi': 'kenang',
    'mengenangan': 'kenang',
    'mengenangmu': 'kenang',
    'terkenang': 'kenang',
    'terkenangnya': 'kenang',
    'kenang-kenangan': 'kenang',
    'kenang-kenangannya': 'kenang',
    'kenang-kenanganan': 'kenang',
    'menasional': 'nasional',
    'menasionalkan': 'nasional',
    'penasionalan': 'nasional',
    'kenasionalan': 'nasional',
    'berkencan': 'kencan',
    'berkencannya': 'kencan',
    'berkencanlah': 'kencan',
    'mengencani': 'kencan',
    'mengencaninya': 'kencan',
    'mengencaniku': 'kencan',
    'kekencangan': 'kencang',
    'kekencangannya': 'kencang',
    'pengencangan': 'kencang',
    'memperkencang': 'kencang',
    'kencang-kencung': 'kencang',
    'terkencar-kencar': 'kencar',
    'terkencing': 'kencing',
    'mengencingi': 'kencing',
    'mengencinginya': 'kencing',
    'perkencingan': 'kencing',
    'pengencingan': 'kencing',
    'terkencing-kencing': 'kencing',
    'kencing-mengencingi': 'kencing',
    'mengencongkan': 'kencong',
    'mengencreng': 'kencreng',
    'mengendalakan': 'kendala',
    'kendalian': 'kendali',
    'terkendali': 'kendali',
    'terkendalinya': 'kendali',
    'terkendalilah': 'kendali',
    'terkendalikan': 'kendali',
    'pengendali': 'kendali',
    'pengendalinya': 'kendali',
    'pengendalikan': 'kendali',
    'pengendalian': 'kendali',
    'pengendaliannya': 'kendali',
    'pengendalianlah': 'kendali',
    'mengendalikan': 'kendali',
    'mengendalikannya': 'kendali',
    'mengendalikanku': 'kendali',
    'mengendalikanmu': 'kendali',
    'mengendanai': 'kendana',
    'sekendang': 'kendang',
    'kendangan': 'kendang',
    'kendang-kendang': 'kendang',
    'kendang-kendangmu': 'kendang',
    'kendang-kendangan': 'kendang',
    'kendaraan': 'kendara',
    'kendaraannya': 'kendara',
    'kendaraanlah': 'kendara',
    'kendaraanku': 'kendara',
    'kendaraanmu': 'kendara',
    'pengendara': 'kendara',
    'pengendaranya': 'kendara',
    'pengendaralah': 'kendara',
    'pengendarai': 'kendara',
    'pengendaraan': 'kendara',
    'berkendara': 'kendara',
    'berkendaranya': 'kendara',
    'berkendaralah': 'kendara',
    'berkendarakan': 'kendara',
    'berkendarai': 'kendara',
    'berkendaraan': 'kendara',
    'mengendarai': 'kendara',
    'mengendarainya': 'kendara',
    'berkendaraannya': 'kendara',
    'kendatipun': 'kendati',
    'kendungan': 'kendung',
    'mengendur': 'kendur',
    'mengendurnya': 'kendur',
    'mengendurkan': 'kendur',
    'mengendurkannya': 'kendur',
    'kekenduran': 'kendur',
    'kekendurannya': 'kendur',
    'pengenduran': 'kendur',
    'berkendur-kendur': 'kendur',
    'berkenduri': 'kenduri',
    'mengendurikan': 'kenduri',
    'penekat': 'nekat',
    'penekatan': 'nekat',
    'kenekatan': 'nekat',
    'kenekatannya': 'nekat',
    'nekat-nekat': 'nekat',
    'nekat-nekatan': 'nekat',
    'kekenesan': 'kenes',
    'kengerian': 'ngeri',
    'kengeriannya': 'ngeri',
    'kengerianku': 'ngeri',
    'mengerikannya': 'ngeri',
    'mengengkeng': 'kengkeng',
    'mengensel': 'kensel',
    'mengental': 'kental',
    'mengentalnya': 'kental',
    'mengentalkan': 'kental',
    'mengentalkannya': 'kental',
    'pengental': 'kental',
    'pengentalan': 'kental',
    'kekentalan': 'kental',
    'kekentalannya': 'kental',
    'mengentarakan': 'kentara',
    'kentungan': 'kentung',
    'kentung-kentung': 'kentung',
    'kentutan': 'kentut',
    'terkentut': 'kentut',
    'berkentut': 'kentut',
    'mengentuti': 'kentut',
    'terkentut-kentut': 'kentut',
    'mengenyam': 'kenyam',
    'kenyaringan': 'nyaring',
    'kenyaringannya': 'nyaring',
    'menyaringkan': 'saring',
    'kenyat-kenyit': 'kenyat',
    'ternyata': 'nyata',
    'ternyatanya': 'nyata',
    'ternyataan': 'nyata',
    'kenyataan': 'nyata',
    'kenyataannya': 'nyata',
    'kenyataanlah': 'nyata',
    'pernyataan': 'nyata',
    'pernyataannya': 'nyata',
    'pernyataanku': 'nyata',
    'pernyataanmu': 'nyata',
    'menyatakan': 'nyata',
    'menyatakannya': 'nyata',
    'menyatakankan': 'nyata',
    'menyatakani': 'nyata',
    'menyatakanan': 'nyata',
    'ternyatakan': 'nyata',
    'kenyitan': 'kenyit',
    'mengenyit': 'kenyit',
    'mengenyitkan': 'kenyit',
    'kenyutan': 'kenyut',
    'mengenyut': 'kenyut',
    'berkeokan': 'keok',
    'berkeok-keok': 'keok',
    'pemadat': 'padat',
    'pemadati': 'padat',
    'pemadatan': 'padat',
    'padatan': 'padat',
    'padatannya': 'padat',
    'memadat': 'padat',
    'memadatnya': 'padat',
    'memadatkan': 'padat',
    'memadatkannya': 'padat',
    'memadati': 'padat',
    'memadatinya': 'padat',
    'memadatii': 'padat',
    'pemadatannya': 'padat',
    'kepadatan': 'padat',
    'kepadatannya': 'padat',
    'mengepah': 'kepah',
    'kepahlawanan': 'pahlawan',
    'kepahlawanannya': 'pahlawan',
    'kepahlawananan': 'pahlawan',
    'kepahlawananmu': 'pahlawan',
    'kepakaran': 'pakar',
    'kepakarannya': 'pakar',
    'kepalan': 'kepal',
    'kepalannya': 'kepal',
    'sekepal': 'kepal',
    'sekepalan': 'kepal',
    'terkepal': 'kepal',
    'mengepal': 'kepal',
    'mengepalkan': 'kepal',
    'berkepal-kepal': 'kepal',
    'mengepal-ngepalkan': 'kepal',
    'berkepala': 'kepala',
    'berkepalanya': 'kepala',
    'mengepalai': 'kepala',
    'mengepalainya': 'kepala',
    'mengepalakan': 'kepala',
    'kepala-kepalaan': 'kepala',
    'pemalsu': 'palsu',
    'pemalsunya': 'palsu',
    'pemalsukan': 'palsu',
    'pemalsuan': 'palsu',
    'memalsu': 'palsu',
    'memalsukan': 'palsu',
    'memalsukannya': 'palsu',
    'memalsuan': 'palsu',
    'kepalsuan': 'palsu',
    'kepalsuannya': 'palsu',
    'pemalsuannya': 'palsu',
    'pemanas': 'panas',
    'pemanasnya': 'panas',
    'pemanasan': 'panas',
    'memanas': 'panas',
    'memanasnya': 'panas',
    'memanaskan': 'panas',
    'memanaskannya': 'panas',
    'memanasi': 'panas',
    'memanasan': 'panas',
    'berpanas': 'panas',
    'berpanasan': 'panas',
    'kepanasan': 'panas',
    'kepanasannya': 'panas',
    'kepanasankan': 'panas',
    'terpanasi': 'panas',
    'pemanasannya': 'panas',
    'pemanasanan': 'panas',
    'panas-panas': 'panas',
    'panas-panasnya': 'panas',
    'panas-panaskan': 'panas',
    'panas-panasi': 'panas',
    'panas-panasan': 'panas',
    'memanas-manasi': 'panas',
    'memanas-manasinya': 'panas',
    'berpanas-panas': 'panas',
    'berpanas-panasan': 'panas',
    'memandai': 'pandai',
    'memandainya': 'pandai',
    'kepandaian': 'pandai',
    'kepandaiannya': 'pandai',
    'memandaikan': 'pandai',
    'sepandai-pandai': 'pandai',
    'sepandai-pandainya': 'pandai',
    'memandai-mandai': 'pandai',
    'berpandai-pandai': 'pandai',
    'kepangan': 'kepang',
    'kepanganan': 'kepang',
    'berkepang': 'kepang',
    'mengepang': 'kepang',
    'mengepangnya': 'kepang',
    'kepang-kepot': 'kepang',
    'kepapaan': 'papa',
    'kepayahan': 'payah',
    'kepayahannya': 'payah',
    'memayahkan': 'payah',
    'berpayah-payah': 'payah',
    'memayah-mayahkan': 'payah',
    'kepedaran': 'pedar',
    'kepedasan': 'pedas',
    'kepedasannya': 'pedas',
    'memedaskan': 'pedas',
    'kepejalan': 'pejal',
    'memejalkan': 'pejal',
    'memeka': 'peka',
    'memekakan': 'peka',
    'memekai': 'peka',
    'kepekaan': 'peka',
    'kepekaannya': 'peka',
    'kepekaanku': 'peka',
    'pelikan': 'pelik',
    'kepelikan': 'pelik',
    'pimpinan': 'pimpin',
    'pimpinannya': 'pimpin',
    'pimpinanlah': 'pimpin',
    'pimpinanan': 'pimpin',
    'pimpinannyalah': 'pimpin',
    'pimpinanku': 'pimpin',
    'pimpinanmu': 'pimpin',
    'pemimpin': 'pimpin',
    'pemimpinnya': 'pimpin',
    'pemimpinlah': 'pimpin',
    'pemimpinan': 'pimpin',
    'pemimpinku': 'pimpin',
    'pemimpinmu': 'pimpin',
    'memimpin': 'pimpin',
    'memimpinnya': 'pimpin',
    'memimpinlah': 'pimpin',
    'memimpinkan': 'pimpin',
    'memimpinan': 'pimpin',
    'berpimpin': 'pimpin',
    'terpimpin': 'pimpin',
    'terpimpinnya': 'pimpin',
    'kepemimpinan': 'pimpin',
    'kepemimpinannya': 'pimpin',
    'kepemimpinanlah': 'pimpin',
    'kepemimpinanan': 'pimpin',
    'kepemimpinanku': 'pimpin',
    'kepemimpinanmu': 'pimpin',
    'kepenatan': 'penat',
    'kepenatannya': 'penat',
    'memenatkan': 'penat',
    'berpenat-penat': 'penat',
    'mementing': 'penting',
    'mementingnya': 'penting',
    'mementingkan': 'penting',
    'mementingkannya': 'penting',
    'mementingan': 'penting',
    'terpenting': 'penting',
    'terpentingnya': 'penting',
    'terpentingkan': 'penting',
    'terpentingan': 'penting',
    'terpentingku': 'penting',
    'kepentingan': 'penting',
    'kepentingannya': 'penting',
    'kepentinganlah': 'penting',
    'kepentinganku': 'penting',
    'kepentinganmu': 'penting',
    'berpentingan': 'penting',
    'berkepentingan': 'penting',
    'berkepentinganlah': 'penting',
    'tepercaya': 'percaya',
    'memercayai': 'percaya',
    'memercayainya': 'percaya',
    'memercayaiku': 'percaya',
    'memercayaimu': 'percaya',
    'kepercayaan': 'percaya',
    'kepercayaannya': 'percaya',
    'kepercayaanlah': 'percaya',
    'kepercayaanan': 'percaya',
    'kepercayaanku': 'percaya',
    'kepercayaanmu': 'percaya',
    'memercayakan': 'percaya',
    'memercayakannya': 'percaya',
    'bepergian': 'pergi',
    'bepergiannya': 'pergi',
    'bepergianlah': 'pergi',
    'kepergian': 'pergi',
    'kepergiannya': 'pergi',
    'kepergianku': 'pergi',
    'kepergianmu': 'pergi',
    'keperkasaan': 'perkasa',
    'keperkasaannya': 'perkasa',
    'keperluan': 'perlu',
    'keperluannya': 'perlu',
    'keperluanku': 'perlu',
    'keperluanmu': 'perlu',
    'seperlunya': 'perlu',
    'memerlukan': 'perlu',
    'memerlukannya': 'perlu',
    'memerlukankan': 'perlu',
    'memerlukanan': 'perlu',
    'memerlukanku': 'perlu',
    'memerlukanmu': 'perlu',
    'keperwiraan': 'perwira',
    'keperwiraannya': 'perwira',
    'kepetahan': 'petah',
    'memetahkan': 'petah',
    'mengepil': 'kepil',
    'terkepil': 'kepil',
    'mengepilkan': 'kepil',
    'berpilu': 'pilu',
    'kepiluan': 'pilu',
    'kepiluannya': 'pilu',
    'memilukan': 'pilu',
    'memilukannya': 'pilu',
    'kepilu-piluan': 'pilu',
    'sepincang': 'pincang',
    'pemincangan': 'pincang',
    'kepincangan': 'pincang',
    'kepincangannya': 'pincang',
    'sekeping': 'keping',
    'kepingan': 'keping',
    'kepingannya': 'keping',
    'mengeping': 'keping',
    'pengepingan': 'keping',
    'berkeping-keping': 'keping',
    'kepitan': 'kepit',
    'berkepit': 'kepit',
    'mengepit': 'kepit',
    'mengeplak': 'keplak',
    'keplokan': 'keplok',
    'terkepoh': 'kepoh',
    'mengepohkan': 'kepoh',
    'memompong': 'pompong',
    'kepompong': 'pompong',
    'kepompongan': 'pompong',
    'memongahi': 'pongah',
    'kepongahan': 'pongah',
    'kepongahannya': 'pongah',
    'memongahkan': 'pongah',
    'berpongah-pongah': 'pongah',
    'mengepot': 'kepot',
    'mengeprek': 'keprek',
    'kepribadian': 'pribadi',
    'kepribadiannya': 'pribadi',
    'kepribadianku': 'pribadi',
    'kepribadianmu': 'pribadi',
    'mempribadikan': 'pribadi',
    'mengepris': 'kepris',
    'mengepruk': 'kepruk',
    'memucat': 'pucat',
    'kepucatan': 'pucat',
    'pemucatan': 'pucat',
    'kepucat-pucatan': 'pucat',
    'pengepuh': 'kepuh',
    'mengepuh': 'kepuh',
    'kepuh-kepuh': 'kepuh',
    'memuji': 'puji',
    'memujinya': 'puji',
    'memujilah': 'puji',
    'memujikan': 'puji',
    'memujiku': 'puji',
    'memujimu': 'puji',
    'memuji-mu': 'puji',
    'pujian': 'puji',
    'pujiannya': 'puji',
    'pujiani': 'puji',
    'pujianku': 'puji',
    'pujianmu': 'puji',
    'pemuji': 'puji',
    'terpuji': 'puji',
    'terpujinya': 'puji',
    'terpujilah': 'puji',
    'kepujian': 'puji',
    'pemujian': 'puji',
    'puji-pujian': 'puji',
    'berkepuk': 'kepuk',
    'mengepukkan': 'kepuk',
    'kepulan': 'kepul',
    'kepulannya': 'kepul',
    'kepulanan': 'kepul',
    'berkepul': 'kepul',
    'mengepul': 'pul',
    'mengepulnya': 'pul',
    'mengepulkan': 'pul',
    'pengepulan': 'pul',
    'berkepul-kepul': 'kepul',
    'pulangan': 'pulang',
    'sepulang': 'pulang',
    'sepulangnya': 'pulang',
    'berpulang': 'pulang',
    'berpulangnya': 'pulang',
    'berpulangan': 'pulang',
    'memulangi': 'pulang',
    'terpulang': 'pulang',
    'pemulangan': 'pulang',
    'pemulangannya': 'pulang',
    'kepulangan': 'pulang',
    'kepulangannya': 'pulang',
    'kepulanganmu': 'pulang',
    'memulangkan': 'pulang',
    'memulangkannya': 'pulang',
    'memulangkanku': 'pulang',
    'kepulauan': 'pulau',
    'kepulauannya': 'pulau',
    'pemulauan': 'pulau',
    'memulaukan': 'pulau',
    'pemutih': 'putih',
    'pemutihnya': 'putih',
    'pemutihkan': 'putih',
    'pemutihan': 'putih',
    'memutih': 'putih',
    'memutihnya': 'putih',
    'memutihkan': 'putih',
    'memutihkannya': 'putih',
    'memutihan': 'putih',
    'keputihan': 'putih',
    'keputihannya': 'putih',
    'pemutihannya': 'putih',
    'keputih-putihan': 'putih',
    'pemutus': 'putus',
    'pemutusnya': 'putus',
    'pemutuskan': 'putus',
    'pemutusan': 'putus',
    'putusan': 'putus',
    'putusannya': 'putus',
    'putusanku': 'putus',
    'putusanmu': 'putus',
    'memutus': 'putus',
    'memutusnya': 'putus',
    'memutuskan': 'putus',
    'memutuskannya': 'putus',
    'memutusan': 'putus',
    'terputus': 'putus',
    'terputusnya': 'putus',
    'terputuslah': 'putus',
    'terputuskan': 'putus',
    'keputusan': 'putus',
    'keputusannya': 'putus',
    'keputusanku': 'putus',
    'keputusanmu': 'putus',
    'pemutusannya': 'putus',
    'memutuskankan': 'putus',
    'memutuskanku': 'putus',
    'memutuskanmu': 'putus',
    'berputusan': 'putus',
    'putus-putus': 'putus',
    'putus-putusnya': 'putus',
    'berkeputusan': 'putus',
    'terputus-putus': 'putus',
    'berkerabat': 'kerabat',
    'berkerabatan': 'kerabat',
    'kekerabatan': 'kerabat',
    'kekerabatannya': 'kerabat',
    'mengerabik': 'kerabik',
    'mengerabikkan': 'kerabik',
    'mengerabit': 'kerabit',
    'mengerabu': 'kerabu',
    'berkerabu': 'kerabu',
    'meragu': 'ragu',
    'meragunya': 'ragu',
    'meragukan': 'raguk',
    'meragukannya': 'ragu',
    'meraguan': 'ragu',
    'keraguan': 'ragu',
    'keraguannya': 'ragu',
    'keraguanku': 'ragu',
    'keraguanmu': 'ragu',
    'meragukanlah': 'ragu',
    'meragukanku': 'ragu',
    'ragu-ragu': 'ragu',
    'ragu-ragunya': 'ragu',
    'ragu-ragulah': 'ragu',
    'kerahan': 'kerah',
    'kerahanan': 'kerah',
    'pengerah': 'kerah',
    'pengerahnya': 'kerah',
    'pengerahkan': 'kerah',
    'pengerahan': 'kerah',
    'berkerah': 'kerah',
    'berkerahnya': 'kerah',
    'pengerahannya': 'kerah',
    'pengerahanan': 'kerah',
    'mengerahkan': 'kerah',
    'mengerahkannya': 'kerah',
    'mengerahkankan': 'kerah',
    'kerah-kerahan': 'kerah',
    'mengeraikan': 'kerai',
    'beraja': 'raja',
    'meraja': 'raja',
    'merajanya': 'raja',
    'merajakan': 'raja',
    'merajai': 'raja',
    'merajainya': 'raja',
    'kerajaan': 'raja',
    'kerajaannya': 'raja',
    'kerajaanlah': 'raja',
    'kerajaanku': 'raja',
    'beraja-raja': 'raja',
    'perajin': 'rajin',
    'perajinnya': 'rajin',
    'perajinan': 'rajin',
    'kerajinan': 'rajin',
    'kerajinannya': 'rajin',
    'kerajinanan': 'rajin',
    'kerajinanmu': 'rajin',
    'pengrajin': 'rajin',
    'pengrajinnya': 'rajin',
    'pengrajinan': 'rajin',
    'merajinkan': 'rajin',
    'mengerakah': 'kerakah',
    'mengerakahi': 'kerakah',
    'mengerakali': 'kerakal',
    'kerakusan': 'rakus',
    'kerakusannya': 'rakus',
    'keraman': 'keram',
    'peramah': 'ramah',
    'peramahan': 'ramah',
    'meramahi': 'ramah',
    'keramahan': 'ramah',
    'keramahannya': 'ramah',
    'keramahanmu': 'ramah',
    'beramah-ramah': 'ramah',
    'beramah-ramahan': 'ramah',
    'berkeramas': 'keramas',
    'mengeramasi': 'keramas',
    'kekeramatan': 'keramat',
    'mengeramatkan': 'keramat',
    'mengeramatkannya': 'keramat',
    'pekeramik': 'keramik',
    'berkerang': 'kerang',
    'perkerangan': 'kerang',
    'kerang-keruk': 'kerang',
    'kerang-kerung': 'kerang',
    'kerang-kerangan': 'kerang',
    'terkeranjat': 'keranjat',
    'kekerapan': 'kerap',
    'kekerapannya': 'kerap',
    'mengerapkan': 'kerap',
    'kerap-kerap': 'kerap',
    'kerapian': 'rapi',
    'kerapiannya': 'rapi',
    'merapikan': 'rapik',
    'merapikannya': 'rapi',
    'keratan': 'kerat',
    'mengerat': 'kerat',
    'mengeratnya': 'kerat',
    'terkerat': 'kerat',
    'pengerat': 'kerat',
    'pengeratan': 'kerat',
    'kerawangan': 'kerawang',
    'mengerawang': 'kerawang',
    'mengerbat': 'kerbat',
    'mengerbuk': 'kerbuk',
    'mengercingkan': 'kercing',
    'mengercitkan': 'kercit',
    'kekerdilan': 'kerdil',
    'kekerdilannya': 'kerdil',
    'mengerdomkan': 'kerdom',
    'bekerdom-kerdom': 'kerdom',
    'mengerebok': 'kerebok',
    'mengerecengkan': 'kereceng',
    'berkeredong': 'keredong',
    'sekerek': 'kerek',
    'mengerek': 'kerek',
    'mengereknya': 'kerek',
    'berkereket': 'kereket',
    'seremeh': 'remeh',
    'keremehan': 'remeh',
    'meremehkan': 'remeh',
    'meremehkannya': 'remeh',
    'meremehkankan': 'remeh',
    'meremehkanku': 'remeh',
    'meremehkanmu': 'remeh',
    'remeh-temeh': 'remeh',
    'remeh-cemeh': 'remeh',
    'meremeh-temehkan': 'remeh',
    'mengeremus': 'keremus',
    'rendahan': 'rendah',
    'rendahannya': 'rendah',
    'rendahanan': 'rendah',
    'merendah': 'rendah',
    'merendahnya': 'rendah',
    'merendahkan': 'rendah',
    'merendahkannya': 'rendah',
    'merendahan': 'rendah',
    'kerendahan': 'rendah',
    'kerendahannya': 'rendah',
    'kerendahanmu': 'rendah',
    'merendahkankan': 'rendah',
    'merendahkanku': 'rendah',
    'merendahkanmu': 'rendah',
    'merenggang': 'renggang',
    'merenggangnya': 'renggang',
    'merenggangkan': 'renggang',
    'perenggang': 'renggang',
    'perenggangkan': 'renggang',
    'perenggangan': 'renggang',
    'renggangan': 'renggang',
    'merenggangi': 'renggang',
    'kerenggangan': 'renggang',
    'kerenggangannya': 'renggang',
    'memperenggang': 'renggang',
    'merenggang gawai': 'renggang',
    'mengerenyot': 'kerenyot',
    'mengerepas': 'kerepas',
    'mengerepes': 'kerepes',
    'meresah': 'resah',
    'meresahkan': 'resah',
    'meresahkannya': 'resah',
    'meresahan': 'resah',
    'keresahan': 'resah',
    'keresahannya': 'resah',
    'keresahanan': 'resah',
    'keresahanmu': 'resah',
    'meresahkani': 'resah',
    'meresahkanku': 'resah',
    'beresah-resah': 'resah',
    'terkereseng': 'kereseng',
    'berkereta api': 'kereta api',
    'perkeretaapian': 'kereta api',
    'perkeretaapiannya': 'kereta api',
    'berkereta': 'kereta',
    'mengeri': 'keri',
    'periang': 'riang',
    'periangnya': 'riang',
    'periangan': 'riang',
    'keriangan': 'riang',
    'keriangannya': 'riang',
    'meriangkan': 'riang',
    'mengeriap': 'keriap',
    'berkeriapan': 'keriap',
    'berkeriau': 'keriau',
    'meribut': 'ribut',
    'meributkan': 'ribut',
    'meributkannya': 'ribut',
    'meributi': 'ribut',
    'keributan': 'ribut',
    'keributannya': 'ribut',
    'mengericau': 'kericau',
    'berkericau': 'kericau',
    'berkericauan': 'kericau',
    'mengerih': 'kerih',
    'mengerihkan': 'kerih',
    'kerikan': 'kerik',
    'kerik api': 'kerik',
    'mengerikil': 'kerikil',
    'mengerikili': 'kerikil',
    'pengerikilan': 'kerikil',
    'mengerikiti': 'kerikit',
    'berkering': 'kering',
    'berkeringan': 'kering',
    'pengering': 'kering',
    'pengeringnya': 'kering',
    'pengeringan': 'kering',
    'mengering': 'kering',
    'mengeringnya': 'kering',
    'mengeringkan': 'kering',
    'mengeringkannya': 'kering',
    'mengeringan': 'kering',
    'mengeringi': 'kering',
    'mengeringinya': 'kering',
    'kekeringan': 'kering',
    'kekeringannya': 'kering',
    'pengeringannya': 'kering',
    'pengeringanan': 'kering',
    'berkering-kering': 'kering',
    'kering-kering air': 'kering',
    'peringanan': 'ringan',
    'keringanan': 'ringan',
    'keringanannya': 'ringan',
    'keringananlah': 'ringan',
    'meringankan': 'ringan',
    'meringankannya': 'ringan',
    'meringankanlah': 'ringan',
    'memperingankan': 'ringan',
    'mengerinjang': 'kerinjang',
    'mengerip': 'kerip',
    'berkeriput': 'keriput',
    'berkeris': 'keris',
    'mengeris': 'keris',
    'perkerisan': 'keris',
    'perisau': 'risau',
    'merisau': 'risau',
    'merisaukan': 'risau',
    'merisaukannya': 'risau',
    'kerisauan': 'risau',
    'kerisauannya': 'risau',
    'kerisikan': 'kerisik',
    'berkerisik': 'kerisik',
    'mengerisik': 'kerisik',
    'mengerising': 'kerising',
    'mengerit': 'kerit',
    'mengeritkan': 'kerit',
    'berkeritik-keritik': 'keritik',
    'mengeriting': 'keriting',
    'mengeritingnya': 'keriting',
    'mengeritingkannya': 'keriting',
    'mengeritingi': 'keriting',
    'pengeritingan': 'keriting',
    'mengeritingkan': 'keriting',
    'berkeriuk': 'keriuk',
    'mengerjang': 'kerjang',
    'mengerjap': 'kerjap',
    'mengerjapkan': 'kerjap',
    'mengerjap-ngerjap': 'kerjap',
    'dikerkah': 'kerkah',
    'mengerkah': 'kerkah',
    'mengerkau': 'kerkau',
    'tekerlap': 'kerlap',
    'mengerlap': 'kerlap',
    'bekerlapan': 'kerlap',
    'kerlingan': 'kerling',
    'mengerling': 'kerling',
    'mengerlingkan': 'kerling',
    'mengerlingku': 'kerling',
    'mengerling-ngerling': 'kerling',
    'sekerlip': 'kerlip',
    'bekerlip': 'kerlip',
    'bekerlipan': 'kerlip',
    'mengerlip': 'kerlip',
    'kermian': 'kermi',
    'mengernai': 'kernai',
    'mengerneti': 'kernet',
    'mengernyih': 'kernyih',
    'mengernying': 'kernying',
    'mengernyit': 'kernyit',
    'mengernyitkan': 'kernyit',
    'bekernyut': 'kernyut',
    'mengernyut': 'kernyut',
    'mengernyutkan': 'kernyut',
    'bekernyutan': 'kernyut',
    'kerobak-kerobik': 'kerobak',
    'kerobak-kerabit': 'kerobak',
    'kerobak-kerobek': 'kerobak',
    'kerobat-kerabit': 'kerobat',
    'mengerobek': 'kerobek',
    'kerokan': 'kerok',
    'mengerok': 'kerok',
    'mengeroki': 'kerok',
    'mengerokoti': 'kerokot',
    'pengerokotan': 'kerokot',
    'keroncongan': 'keroncong',
    'berkeroncongan': 'keroncong',
    'mengeroncongkan': 'keroncong',
    'kerong-kerong': 'kerong',
    'rongkongan': 'rongos',
    'kerongkongan': 'rongkong',
    'kerongkongannya': 'rongkong',
    'kerongkonganku': 'rongkong',
    'mengeropeng': 'keropeng',
    'sekeropok': 'keropok',
    'mengerosi': 'kerosi',
    'mengerosong': 'kerosong',
    'kerang-kerot': 'kerot',
    'berkerotak': 'kerotak',
    'keroyokan': 'keroyok',
    'keroyokanlah': 'keroyok',
    'pengeroyok': 'keroyok',
    'pengeroyoknya': 'keroyok',
    'pengeroyokkan': 'keroyok',
    'pengeroyokan': 'keroyok',
    'mengeroyok': 'keroyok',
    'mengeroyoknya': 'keroyok',
    'mengeroyokan': 'keroyok',
    'pengeroyokannya': 'keroyok',
    'mengerpus': 'kerpus',
    'bekersik': 'kersik',
    'tekersik': 'kersik',
    'mengersik': 'kersik',
    'bekertak': 'kertak',
    'kertak-kertuk': 'kertak',
    'bekertak-kertak': 'kertak',
    'mengertak-ngertakkan': 'kertak',
    'mengertangkan': 'kertang',
    'kertap-kertap': 'kertap',
    'kerubinan': 'kerubin',
    'kerubungan': 'kerubung',
    'berkerubung': 'kerubung',
    'mengerubungi': 'kerubung',
    'mengerubunginya': 'kerubung',
    'mengerubungiku': 'kerubung',
    'mengerubuti': 'kerubut',
    'mengerubutinya': 'kerubut',
    'mengerucut': 'kerucut',
    'mengerucutnya': 'kerucut',
    'mengerucutlah': 'kerucut',
    'mengerucutkan': 'kerucut',
    'mengerucutkannya': 'kerucut',
    'berkerudung': 'kerudung',
    'mengerudungi': 'kerudung',
    'merugi': 'rugi',
    'meruginya': 'rugi',
    'merugilah': 'rugi',
    'merugikan': 'rugi',
    'merugikannya': 'rugi',
    'merugian': 'rugi',
    'berugi': 'rugi',
    'berugikan': 'rugi',
    'kerugian': 'rugi',
    'kerugiannya': 'rugi',
    'kerugianku': 'rugi',
    'kerugianmu': 'rugi',
    'merugikanku': 'rugi',
    'merugikanmu': 'rugi',
    'mengeruh': 'keruh',
    'mengeruhkan': 'keruh',
    'berkeruh': 'keruh',
    'kekeruhan': 'keruh',
    'kekeruhannya': 'keruh',
    'berkeruit-keruit': 'keruit',
    'mengeruk': 'keruk',
    'mengeruknya': 'keruk',
    'mengeruki': 'keruk',
    'mengerukan': 'keruk',
    'pengerukan': 'keruk',
    'pengerukannya': 'keruk',
    'mengerukkan': 'keruk',
    'mengerukut': 'kerukut',
    'mengerukutkan': 'kerukut',
    'mengerul': 'kerul',
    'mengerumit': 'kerumit',
    'berkerumuk': 'kerumuk',
    'mengerumukkan': 'kerumuk',
    'mengerumus': 'kerumus',
    'meruncing': 'runcing',
    'meruncingnya': 'runcing',
    'meruncingkan': 'runcing',
    'keruncingan': 'runcing',
    'memperuncing': 'runcing',
    'meruntuh': 'runtuh',
    'meruntuhnya': 'runtuh',
    'meruntuhkan': 'runtuh',
    'meruntuhkannya': 'runtuh',
    'meruntuhan': 'runtuh',
    'runtuhan': 'runtuh',
    'runtuhannya': 'runtuh',
    'reruntuhan': 'runtuh',
    'reruntuhannya': 'runtuh',
    'keruntuhan': 'runtuh',
    'keruntuhannya': 'runtuh',
    'mengeruntungkan': 'keruntung',
    'berkerunyut': 'kerunyut',
    'terkerunyut': 'kerunyut',
    'kerupukan': 'kerupuk',
    'mengerutak': 'kerutak',
    'berkeruyuk': 'keruyuk',
    'mengesah': 'kesah',
    'mengesahkan': 'sah',
    'mengesahkannya': 'sah',
    'mengesahan': 'kesah',
    'mengesakkan': 'kesak',
    'penyakit': 'sakit',
    'penyakitnya': 'sakit',
    'penyakitlah': 'sakit',
    'penyakitkan': 'sakit',
    'penyakiti': 'sakit',
    'penyakitan': 'sakit',
    'penyakitku': 'sakit',
    'penyakitmu': 'sakit',
    'menyakiti': 'sakit',
    'menyakitinya': 'sakit',
    'menyakitii': 'sakit',
    'menyakitiku': 'sakit',
    'menyakitimu': 'sakit',
    'kesakitan': 'sakit',
    'kesakitannya': 'sakit',
    'kesakitanku': 'sakit',
    'pesakitan': 'sakit',
    'pesakitannya': 'sakit',
    'menyakitkan': 'sakit',
    'menyakitkannya': 'sakit',
    'menyakitkanku': 'sakit',
    'mempersakiti': 'sakit',
    'berpenyakitan': 'sakit',
    'sakit-sakitan': 'sakit',
    'bersakit-sakit': 'sakit',
    'bersakit-sakitan': 'sakit',
    'kesaksamaan': 'saksama',
    'kesaktian': 'sakti',
    'kesaktiannya': 'sakti',
    'menyaktikan': 'sakti',
    'kekesalan': 'kesal',
    'kekesalannya': 'kesal',
    'mengesalkan': 'kesal',
    'mengesalkannya': 'kesal',
    'menyalah': 'salah',
    'menyalahkan': 'salah',
    'menyalahkannya': 'salah',
    'menyalahi': 'salah',
    'menyalahan': 'salah',
    'bersalah': 'salah',
    'bersalahnya': 'salah',
    'bersalahlah': 'salah',
    'bersalahan': 'salah',
    'tersalah': 'salah',
    'kesalahan': 'salah',
    'kesalahannya': 'salah',
    'kesalahanan': 'salah',
    'kesalahanku': 'salah',
    'kesalahanmu': 'salah',
    'salah-salah': 'salah',
    'salah-salahnya': 'salah',
    'salah-salahan': 'salah',
    'salah-salahku': 'salah',
    'menyalahkankan': 'salah',
    'menyalahkanku': 'salah',
    'menyalahkanmu': 'salah',
    'mempersalahkan': 'salah',
    'mempersalahkannya': 'salah',
    'bersalah-salahan': 'salah',
    'berkesam': 'kesam',
    'samaran': 'samar',
    'samarannya': 'samar',
    'penyamar': 'samar',
    'penyamarlah': 'samar',
    'penyamaran': 'samar',
    'menyamar': 'samar',
    'menyamarnya': 'samar',
    'menyamarkan': 'samar',
    'menyamarkannya': 'samar',
    'kesamaran': 'samar',
    'penyamarannya': 'samar',
    'samar-samar': 'samar',
    'terkesan': 'kesan',
    'terkesannya': 'kesan',
    'berkesan': 'kesan',
    'berkesannya': 'kesan',
    'mengesan': 'kesan',
    'mengesankan': 'kesan',
    'mengesankannya': 'kesan',
    'mengesani': 'kesan',
    'mengesang': 'kesang',
    'penyangsi': 'sangsi',
    'kesangsian': 'sangsi',
    'kesangsiannya': 'sangsi',
    'menyangsikan': 'sangsi',
    'menyangsikannya': 'sangsi',
    'kesasar': 'sasar',
    'kesasaran': 'sasar',
    'sasaran': 'sasar',
    'sasarannya': 'sasar',
    'sasaranan': 'sasar',
    'sasaranku': 'sasar',
    'menyasar': 'sasar',
    'menyasarnya': 'sasar',
    'menyasarkan': 'sasar',
    'menyasarkannya': 'sasar',
    'tersasar': 'sasar',
    'tersasarnya': 'sasar',
    'tersasarkan': 'sasar',
    'sasarannyakan': 'sasar',
    'bersasaran': 'sasar',
    'pengesat': 'kesat',
    'mengesat': 'kesat',
    'sayangkan': 'sayang',
    'penyayang': 'sayang',
    'penyayangnya': 'sayang',
    'penyayanglah': 'sayang',
    'menyayang': 'sayang',
    'menyayangkan': 'sayang',
    'menyayangkannya': 'sayang',
    'menyayangi': 'sayang',
    'menyayangan': 'sayang',
    'menyayanginya': 'sayang',
    'menyayangiku': 'sayang',
    'menyayangimu': 'sayang',
    'kesayangan': 'sayang',
    'kesayangannya': 'sayang',
    'kesayanganku': 'sayang',
    'kesayanganmu': 'sayang',
    'menyayangkankan': 'sayang',
    'tersayang': 'sayang',
    'sedapan': 'sedap',
    'penyedap': 'sedap',
    'penyedapnya': 'sedap',
    'penyedapan': 'sedap',
    'kesedapan': 'sedap',
    'menyedapkan': 'sedap',
    'sedap-sedapan': 'sedap',
    'penyegar': 'segar',
    'penyegaran': 'segar',
    'kesegaran': 'segar',
    'kesegarannya': 'segar',
    'penyegarannya': 'segar',
    'menyegarkan': 'segar',
    'menyegarkannya': 'segar',
    'menyegarkankan': 'segar',
    'mempersegar': 'segar',
    'penyehat': 'sehat',
    'penyehatan': 'sehat',
    'kesehatan': 'sehat',
    'kesehatannya': 'sehat',
    'kesehatanlah': 'sehat',
    'kesehatani': 'sehat',
    'kesehatanan': 'sehat',
    'kesehatanku': 'sehat',
    'kesehatanmu': 'sehat',
    'penyehatannya': 'sehat',
    'menyehatkan': 'sehat',
    'menyehatkannya': 'sehat',
    'mengesek': 'kesek',
    'mengesekkan': 'kesek',
    'mengesekan': 'kesek',
    'mengesel': 'kesel',
    'selamatan': 'selamat',
    'selamatannya': 'selamat',
    'penyelamat': 'selamat',
    'penyelamatnya': 'selamat',
    'penyelamatkan': 'selamat',
    'penyelamatan': 'selamat',
    'penyelamatku': 'selamat',
    'keselamatan': 'selamat',
    'keselamatannya': 'selamat',
    'keselamatanlah': 'selamat',
    'keselamatanan': 'selamat',
    'keselamatanku': 'selamat',
    'keselamatanmu': 'selamat',
    'menyelamati': 'selamat',
    'menyelamatinya': 'selamat',
    'menyelamatikan': 'selamat',
    'menyelamatiku': 'selamat',
    'berselamatan': 'selamat',
    'penyelamatannya': 'selamat',
    'penyelamatanan': 'selamat',
    'penyelamatanku': 'selamat',
    'penyelamatanmu': 'selamat',
    'penyelamatan-mu': 'selamat',
    'menyelamatkan': 'selamat',
    'menyelamatkannya': 'selamat',
    'menyelamatkanku': 'selamat',
    'menyelamatkanmu': 'selamat',
    'menyempat': 'sempat',
    'menyempatkan': 'sempat',
    'menyempati': 'sempat',
    'menyempatan': 'sempat',
    'kesempatan': 'sempat',
    'kesempatannya': 'sempat',
    'kesempatanlah': 'sempat',
    'kesempatanan': 'sempat',
    'kesempatanku': 'sempat',
    'kesempatanmu': 'sempat',
    'berkesempatan': 'sempat',
    'sempat-sempatnya': 'sempat',
    'sempitan': 'sempit',
    'menyempit': 'sempit',
    'menyempitnya': 'sempit',
    'menyempitkan': 'sempit',
    'menyempitkannya': 'sempit',
    'kesempitan': 'sempit',
    'penyempitan': 'sempit',
    'penyempitannya': 'sempit',
    'persempitan': 'sempit',
    'mempersempit': 'sempit',
    'mempersempitnya': 'sempit',
    'bersempit-sempit': 'sempit',
    'kesempurnaan': 'sempurna',
    'kesempurnaannya': 'sempurna',
    'penyempurnaan': 'sempurna',
    'penyempurnaannya': 'sempurna',
    'menyempurnakan': 'sempurna',
    'menyempurnakannya': 'sempurna',
    'menyempurnakanlah': 'sempurna',
    'kesengsaraan': 'sengsara',
    'kesengsaraannya': 'sengsara',
    'menyengsarakan': 'sengsara',
    'menyengsarakannya': 'sengsara',
    'kesenyapan': 'senyap',
    'menyepi': 'sepi',
    'menyepikan': 'sepi',
    'penyepi': 'sepi',
    'penyepian': 'sepi',
    'kesepian': 'sepi',
    'kesepiannya': 'sepi',
    'kesepianmu': 'sepi',
    'bersepi-sepi': 'sepi',
    'berseragam': 'seragam',
    'berseragamnya': 'seragam',
    'berseragamkan': 'seragam',
    'berseragaman': 'seragam',
    'keseragaman': 'seragam',
    'keseragamannya': 'seragam',
    'penyeragaman': 'seragam',
    'penyeragamannya': 'seragam',
    'menyeragamkan': 'seragam',
    'menyeragamkannya': 'seragam',
    'keserakahan': 'serakah',
    'keserakahannya': 'serakah',
    'keserakahanku': 'serakah',
    'keserakahanmu': 'serakah',
    'keserasian': 'serasi',
    'keserasiannya': 'serasi',
    'penyerasian': 'serasi',
    'menyerasikan': 'serasi',
    'menyerasikannya': 'serasi',
    'keseriusan': 'serius',
    'keseriusannya': 'serius',
    'keseriusanmu': 'serius',
    'menyeriusi': 'serius',
    'menyeriusinya': 'serius',
    'menyerong': 'serong',
    'menyerongkan': 'serong',
    'keserongan': 'serong',
    'serong-menyerong': 'serong',
    'mengeset': 'set',
    'berkeset': 'keset',
    'terkesiap': 'kesiap',
    'kesik-kesik': 'kesik',
    'terkesima': 'kesima',
    'terkesimanya': 'kesima',
    'simpulan': 'simpul',
    'simpulannya': 'simpul',
    'menyimpul': 'simpul',
    'menyimpulkan': 'simpul',
    'menyimpulkannya': 'simpul',
    'menyimpulan': 'simpul',
    'tersimpul': 'simpul',
    'tersimpulkan': 'simpul',
    'kesimpulan': 'simpul',
    'kesimpulannya': 'simpul',
    'kesimpulanku': 'simpul',
    'berkesimpulan': 'simpul',
    'kesinisan': 'sinis',
    'kesinisannya': 'sinis',
    'mengesip': 'kesip',
    'berkesiur': 'kesiur',
    'menyombong': 'sombong',
    'menyombongkan': 'sombong',
    'menyombongkannya': 'sombong',
    'penyombong': 'sombong',
    'bersombong': 'sombong',
    'menyombongi': 'sombong',
    'kesombongan': 'sombong',
    'kesombongannya': 'sombong',
    'menyopani': 'sopan',
    'kesopanan': 'sopan',
    'kesopanannya': 'sopan',
    'menyopankan': 'sopan',
    'bersopan-sopan': 'sopan',
    'penyubur': 'subur',
    'penyuburan': 'subur',
    'kesuburan': 'subur',
    'kesuburannya': 'subur',
    'menyuburkan': 'subur',
    'menyuburkannya': 'subur',
    'sesuka': 'suka',
    'sesukanya': 'suka',
    'sesukaku': 'suka',
    'sesukamu': 'suka',
    'sukaan': 'suka',
    'sukaannya': 'suka',
    'kesukaan': 'suka',
    'kesukaannya': 'suka',
    'kesukaanku': 'suka',
    'kesukaanmu': 'suka',
    'menyukai': 'suka',
    'menyukainya': 'suka',
    'menyukaiku': 'suka',
    'menyukaimu': 'suka',
    'suka-suka': 'suka',
    'suka-sukanya': 'suka',
    'suka-sukaan': 'suka',
    'menyukakan': 'suka',
    'sesuka-suka': 'suka',
    'sesuka-sukanya': 'suka',
    'bersuka-suka': 'suka',
    'bersuka-sukaan': 'suka',
    'kesukaran': 'sukar',
    'kesukarannya': 'sukar',
    'menyukarkan': 'sukar',
    'menyukarkannya': 'sukar',
    'mempersukar': 'sukar',
    'sesuku': 'suku',
    'sesukunya': 'suku',
    'bersuku': 'suku',
    'pesukuan': 'suku',
    'kesukuan': 'suku',
    'kesukuannya': 'suku',
    'persukuan': 'suku',
    'sepersukuan': 'suku',
    'bersuku-suku': 'suku',
    'penyulit': 'sulit',
    'penyulitnya': 'sulit',
    'penyulitan': 'sulit',
    'kesulitan': 'sulit',
    'kesulitannya': 'sulit',
    'kesulitanlah': 'sulit',
    'kesulitanan': 'sulit',
    'kesulitanku': 'sulit',
    'kesulitanmu': 'sulit',
    'mempersulit': 'sulit',
    'mempersulitnya': 'sulit',
    'mempersulitkan': 'sulit',
    'menyulitkan': 'sulit',
    'menyulitkannya': 'sulit',
    'menyulitkanku': 'sulit',
    'menyulitkanmu': 'sulit',
    'mengesumba': 'kesumba',
    'menyunyi': 'sunyi',
    'bersunyi': 'sunyi',
    'kesunyian': 'sunyi',
    'kesunyiannya': 'sunyi',
    'bersunyi-sunyi': 'sunyi',
    'mengesup': 'kesup',
    'menyuram': 'suram',
    'menyuramkan': 'suram',
    'kesuraman': 'suram',
    'kesuramannya': 'suram',
    'suram-suram': 'suram',
    'bersusila': 'susila',
    'kesusilaan': 'susila',
    'kesusilaannya': 'susila',
    'terkesut-kesut': 'kesut',
    'ketabahan': 'tabah',
    'ketabahannya': 'tabah',
    'menabahkan': 'tabah',
    'penagih': 'tagih',
    'penagihnya': 'tagih',
    'penagihan': 'tagih',
    'tagihan': 'tagih',
    'tagihannya': 'tagih',
    'tagihanmu': 'tagih',
    'menagih': 'tagih',
    'menagihnya': 'tagih',
    'menagihkan': 'tagih',
    'menagihkannya': 'tagih',
    'tertagih': 'tagih',
    'tertagihnya': 'tagih',
    'tertagihkan': 'tagih',
    'penagihannya': 'tagih',
    'ketagihan': 'tagih',
    'ketagihannya': 'tagih',
    'berketai-ketai': 'ketai',
    'menakut': 'takut',
    'menakutnya': 'takut',
    'menakutkan': 'takut',
    'menakutkannya': 'takut',
    'menakuti': 'takut',
    'menakutan': 'takut',
    'penakut': 'takut',
    'penakutkan': 'takut',
    'menakutinya': 'takut',
    'ketakutan': 'takut',
    'ketakutannya': 'takut',
    'ketakutanlah': 'takut',
    'ketakutannyalah': 'takut',
    'ketakutanku': 'takut',
    'ketakutanmu': 'takut',
    'menakutkanlah': 'takut',
    'menakutkanku': 'takut',
    'takut-takut': 'takut',
    'takut-takutnya': 'takut',
    'takut-takuti': 'takut',
    'mempertakut': 'takut',
    'berketakutan': 'takut',
    'takut-takutan': 'takut',
    'menakut-nakuti': 'takut',
    'menakut-nakutinya': 'takut',
    'menakut-nakutii': 'takut',
    'menakut-nakutimu': 'takut',
    'mengetam': 'ketam',
    'pengetam': 'ketam',
    'pengetaman': 'ketam',
    'berketam': 'ketam',
    'mengetamkan': 'ketam',
    'ketamakan': 'tamak',
    'ketamakannya': 'tamak',
    'ketangkasan': 'tangkas',
    'ketangkasannya': 'tangkas',
    'ketangkasanlah': 'tangkas',
    'ketangkasanan': 'tangkas',
    'menangkaskan': 'tangkas',
    'mengetap': 'tap',
    'berketap-ketap': 'ketap-ketap',
    'berketar-ketar': 'ketar',
    'pengetatan': 'ketat',
    'pengetatannya': 'ketat',
    'memperketat': 'ketat',
    'memperketatnya': 'ketat',
    'mengetatkan': 'ketat',
    'mengetatkannya': 'ketat',
    'ketawa': 'tawa',
    'ketawanya': 'tawa',
    'ketawalah': 'tawa',
    'ketawai': 'tawa',
    'ketawaan': 'tawa',
    'ketawamu': 'tawa',
    'tertawa': 'tawa',
    'tertawanya': 'tawa',
    'tertawalah': 'tawa',
    'tertawakan': 'tawa',
    'tertawai': 'tawa',
    'tertawaan': 'tawa',
    'tertawamu': 'tawa',
    'menertawai': 'tawa',
    'menertawainya': 'tawa',
    'menertawaiku': 'tawa',
    'penertawaan': 'tawa',
    'menertawakan': 'tawa',
    'menertawakannya': 'tawa',
    'menertawakanku': 'tawa',
    'menebal': 'tebal',
    'menebalnya': 'tebal',
    'menebalkan': 'tebal',
    'menebalkannya': 'tebal',
    'setebal': 'tebal',
    'ketebalan': 'tebal',
    'ketebalannya': 'tebal',
    'tebal bibir': 'tebal',
    'mempertebal': 'tebal',
    'mempertebalnya': 'tebal',
    'mempertebalkan': 'tebal',
    'penegang': 'tegang',
    'penegangan': 'tegang',
    'menegang': 'tegang',
    'menegangnya': 'tegang',
    'menegangkan': 'tegang',
    'menegangkannya': 'tegang',
    'tegangan': 'tegang',
    'tegangannya': 'tegang',
    'menegangi': 'tegang',
    'ketegangan': 'tegang',
    'ketegangannya': 'tegang',
    'bersitegang': 'tegang',
    'bersitegangnya': 'tegang',
    'bersitegangan': 'tegang',
    'ketegaran': 'tegar',
    'ketegarannya': 'tegar',
    'menegarkan': 'tegar',
    'berteguh': 'teguh',
    'peneguhan': 'teguh',
    'keteguhan': 'teguh',
    'keteguhannya': 'teguh',
    'bersiteguh': 'teguh',
    'meneguhkan': 'teguh',
    'meneguhkannya': 'teguh',
    'memperteguh': 'teguh',
    'memperteguhkan': 'teguh',
    'berteguh-teguh': 'teguh',
    'berteguh-teguhan': 'teguh',
    'seketek': 'ketek',
    'mengeteki': 'ketek',
    'mengetemui': 'ketemu',
    'mengetemukan': 'ketemu',
    'penenang': 'tenang',
    'penenangnya': 'tenang',
    'penenangkan': 'tenang',
    'penenangan': 'tenang',
    'menenang': 'tenang',
    'menenangnya': 'tenang',
    'menenangkan': 'tenang',
    'menenangkannya': 'tenang',
    'menenangi': 'tenang',
    'menenangan': 'tenang',
    'ketenangan': 'tenang',
    'ketenangannya': 'tenang',
    'ketenanganku': 'tenang',
    'menenangkanku': 'tenang',
    'menenangkanmu': 'tenang',
    'bertenang-tenang': 'tenang',
    'ketengan': 'keteng',
    'ketengannya': 'keteng',
    'ketenganan': 'keteng',
    'seketeng': 'keteng',
    'mengeteng': 'keteng',
    'mengetengi': 'keteng',
    'mengetengkan': 'keteng',
    'terlanjur': 'lanjur',
    'melanjurkan': 'lanjur',
    'keterlanjuran': 'lanjur',
    'bertertib': 'tertib',
    'ketertiban': 'tertib',
    'ketertibannya': 'tertib',
    'penertiban': 'tertib',
    'penertibannya': 'tertib',
    'penertibankan': 'tertib',
    'menertibkan': 'tertib',
    'menertibkannya': 'tertib',
    'mengetesi': 'ketes',
    'keteteran': 'keteter',
    'mengeti': 'keti',
    'mengetikan': 'tik',
    'keti-keti': 'keti',
    'berketi-keti': 'keti',
    'ketiga': 'tiga',
    'ketiganya': 'tiga',
    'ketigalah': 'tiga',
    'ketigakan': 'tiga',
    'ketigaku': 'tiga',
    'meniga': 'tiga',
    'bertiga': 'tiga',
    'bertigalah': 'tiga',
    'bertigaan': 'tiga',
    'pertiga': 'tiga',
    'pertiganya': 'tiga',
    'pertigaan': 'tiga',
    'pertigaanan': 'tiga',
    'sepertiga': 'tiga',
    'sepertiganya': 'tiga',
    'ketiganyanya': 'tiga',
    'mempertiga': 'tiga',
    'tiga-tiganya': 'tiga',
    'tiga-tiganyanya': 'tiga',
    'ketiga-tiganya': 'tiga',
    'seketika': 'ketika',
    'seketikanya': 'ketika',
    'seketil': 'ketil',
    'mengetil': 'ketil',
    'berketil-ketil': 'ketil',
    'mengeting': 'keting',
    'petinggi': 'tinggi',
    'petingginya': 'tinggi',
    'meninggi': 'tinggi',
    'meningginya': 'tinggi',
    'meninggikan': 'tinggi',
    'meninggikannya': 'tinggi',
    'tertinggi': 'tinggi',
    'tertingginya': 'tinggi',
    'tertinggilah': 'tinggi',
    'tertinggimu': 'tinggi',
    'peninggian': 'tinggi',
    'ketinggian': 'tinggi',
    'ketinggiannya': 'tinggi',
    'mempertinggi': 'tinggi',
    'seketip': 'ketip',
    'pengetip': 'ketip',
    'mengetip': 'tip',
    'mengetipnya': 'tip',
    'ketap-ketip': 'ketip',
    'berketap-ketip': 'ketip',
    'mengetis': 'ketis',
    'ketitiran': 'ketitir',
    'ketokan': 'ketok',
    'mengetok': 'ketok',
    'mengetoknya': 'ketok',
    'mengetokkan': 'ketok',
    'mengetokan': 'ketok',
    'pengetok': 'ketok',
    'pengetokan': 'ketok',
    'ketololan': 'tolol',
    'ketololannya': 'tolol',
    'ketololanmu': 'tolol',
    'mengetrek': 'trek',
    'berketua': 'ketua',
    'mengetuai': 'ketua',
    'mengetuainya': 'ketua',
    'pengetul': 'ketul',
    'mengetulkan': 'ketul',
    'berketul-ketul': 'ketul',
    'ketulenan': 'tulen',
    'ketulian': 'tuli',
    'ketuliannya': 'tuli',
    'menulikan': 'tuli',
    'tuli-tuli': 'tuli',
    'tumbuhan': 'tumbuh',
    'tumbuhannya': 'tumbuh',
    'tumbuhanan': 'tumbuh',
    'penumbuh': 'tumbuh',
    'penumbuhkan': 'tumbuh',
    'penumbuhan': 'tumbuh',
    'menumbuh': 'tumbuh',
    'menumbuhkan': 'tumbuh',
    'menumbuhkannya': 'tumbuh',
    'menumbuhan': 'tumbuh',
    'bertumbuh': 'tumbuh',
    'bertumbuhnya': 'tumbuh',
    'bertumbuhan': 'tumbuh',
    'menumbuhi': 'tumbuh',
    'ketumbuhan': 'tumbuh',
    'tetumbuhan': 'tumbuh',
    'pertumbuhan': 'tumbuh',
    'pertumbuhannya': 'tumbuh',
    'bertumbuhannya': 'tumbuh',
    'mempertumbuhkan': 'tumbuh',
    'tumbuh-tumbuhan': 'tumbuh',
    'tumbuh-tumbuhannya': 'tumbuh',
    'tumbuh-tumbuhanan': 'tumbuh',
    'berketur': 'ketur',
    'penurun': 'turun',
    'penurunnya': 'turun',
    'penurunkan': 'turun',
    'penurunan': 'turun',
    'turunan': 'turun',
    'turunannya': 'turun',
    'turunanan': 'turun',
    'turunannyalah': 'turun',
    'menurun': 'turun',
    'menurunnya': 'turun',
    'menurunlah': 'turun',
    'menurunkan': 'turun',
    'menurunkannya': 'turun',
    'menuruni': 'turun',
    'menurunan': 'turun',
    'menuruninya': 'turun',
    'berturun': 'turun',
    'berturunan': 'turun',
    'keturunan': 'turun',
    'keturunannya': 'turun',
    'keturunanan': 'turun',
    'keturunannyalah': 'turun',
    'keturunanku': 'turun',
    'penurunannya': 'turun',
    'penurunanan': 'turun',
    'menurunkanlah': 'turun',
    'menurunkankan': 'turun',
    'menurunkanku': 'turun',
    'menurunkanmu': 'turun',
    'turun-temurun': 'turun',
    'turun-temurunnya': 'turun',
    'memperturunkan': 'turun',
    'unggulan': 'unggul',
    'unggulannya': 'unggul',
    'keunggulan': 'unggul',
    'keunggulannya': 'unggul',
    'keunggulani': 'unggul',
    'keunggulanmu': 'unggul',
    'mengungguli': 'unggul',
    'mengunggulinya': 'unggul',
    'unggul-mengungguli': 'unggul',
    'keunikan': 'unik',
    'keunikannya': 'unik',
    'keusahawanan': 'usahawan',
    'mengusang': 'usang',
    'keusangan': 'usang',
    'keusangannya': 'usang',
    'keuskupan': 'uskup',
    'keuskupannya': 'uskup',
    'seutuh': 'utuh',
    'seutuhnya': 'utuh',
    'seutuhkan': 'utuh',
    'keutuhan': 'utuh',
    'keutuhannya': 'utuh',
    'keseutuhan': 'utuh',
    'pengutuhan': 'utuh',
    'mengutuhkan': 'utuh',
    'sewajar': 'wajar',
    'sewajarnya': 'wajar',
    'sewajarnyalah': 'wajar',
    'kewajaran': 'wajar',
    'kewajarannya': 'wajar',
    'berwajib': 'wajib',
    'berwajibnya': 'wajib',
    'berwajiblah': 'wajib',
    'berwajiban': 'wajib',
    'kewajiban': 'wajib',
    'kewajibannya': 'wajib',
    'kewajibanku': 'wajib',
    'kewajibanmu': 'wajib',
    'sewajibnya': 'wajib',
    'mewajibkan': 'wajib',
    'mewajibkannya': 'wajib',
    'berkewajiban': 'wajib',
    'kewalahan': 'walah',
    'kewalahannya': 'walah',
    'kewalahanan': 'walah',
    'mewangi': 'wangi',
    'mewangikan': 'wangi',
    'mewangian': 'wangi',
    'pewangi': 'wangi',
    'pewanginya': 'wangi',
    'kewangian': 'wangi',
    'wewangian': 'wangi',
    'wewangiannya': 'wangi',
    'wangi-wangian': 'wangi',
    'wangi-wangiannya': 'wangi',
    'kewangi-wangian': 'wangi',
    'kewanitaan': 'wanita',
    'kewanitaannya': 'wanita',
    'kewanitaanku': 'wanita',
    'kewarasan': 'waras',
    'kewarasannya': 'waras',
    'kewarasanku': 'waras',
    'kewartawanan': 'wartawan',
    'kewartawanannya': 'wartawan',
    'mengewuhkan': 'kewuh',
    'menzalimi': 'zalim',
    'menzaliminya': 'zalim',
    'kezaliman': 'zalim',
    'kezalimannya': 'zalim',
    'menzalimkan': 'zalim',
    'mengkhalayak': 'khalayak',
    'berkhalwat': 'khalwat',
    'berkhamir': 'khamir',
    'kekhasan': 'khas',
    'kekhasannya': 'khas',
    'kekhasanmu': 'khas',
    'mengkhaskan': 'khas',
    'khataman': 'khatam',
    'khatamannya': 'khatam',
    'mengkhatamkan': 'khatam',
    'kekhawatiran': 'khawatir',
    'kekhawatirannya': 'khawatir',
    'kekhawatiranku': 'khawatir',
    'mengkhawatirkan': 'khawatir',
    'mengkhawatirkannya': 'khawatir',
    'mengkhawatirkanku': 'khawatir',
    'mengkhawatirkanmu': 'khawatir',
    'khayalan': 'khayal',
    'khayalannya': 'khayal',
    'khayalanku': 'khayal',
    'berkhayal': 'khayal',
    'berkhayalnya': 'khayal',
    'mengkhayal': 'khayal',
    'mengkhayalkan': 'khayal',
    'pengkhayal': 'khayal',
    'pengkhayalan': 'khayal',
    'berkhianat': 'khianat',
    'berkhianatnya': 'khianat',
    'mengkhianat': 'khianat',
    'mengkhianati': 'khianat',
    'pengkhianat': 'khianat',
    'pengkhianatnya': 'khianat',
    'pengkhianatlah': 'khianat',
    'pengkhianatan': 'khianat',
    'mengkhianatinya': 'khianat',
    'mengkhianatiku': 'khianat',
    'mengkhianatimu': 'khianat',
    'pengkhianatannya': 'khianat',
    'kekhilafan': 'khilaf',
    'kekhilafannya': 'khilaf',
    'khitanan': 'khitan',
    'berkhitan': 'khitan',
    'mengkhitan': 'khitan',
    'mengkhitankan': 'khitan',
    'berkhotbah': 'khotbah',
    'berkhotbahnya': 'khotbah',
    'pengkhotbah': 'khotbah',
    'pengkhotbahnya': 'khotbah',
    'pengkhotbahan': 'khotbah',
    'mengkhotbahkan': 'khotbah',
    'terkhusus': 'khusus',
    'terkhususnya': 'khusus',
    'kekhususan': 'khusus',
    'kekhususannya': 'khusus',
    'mengkhusus': 'khusus',
    'mengkhususnya': 'khusus',
    'mengkhususkan': 'khusus',
    'mengkhususkannya': 'khusus',
    'pengkhususan': 'khusus',
    'kia-kia': 'kia',
    'kia-kiai': 'kia',
    'kia bunga sambu': 'kia',
    'mengiah': 'kiah',
    'pengiah': 'kiah',
    'mengiahkan': 'kiah',
    'pengiah sepatu': 'kiah',
    'kiak-kiak': 'kiak',
    'kialan': 'kial',
    'pengial': 'kial',
    'berkial': 'kial',
    'perkialan': 'kial',
    'kial-kial': 'kial',
    'mengialkan': 'kial',
    'terkial-kial': 'kial',
    'berkial-kial': 'kial',
    'sekian': 'kian',
    'sekianlah': 'kian',
    'sekiankan': 'kian',
    'berkian-kian': 'kian',
    'kiasan': 'kias',
    'kiasannya': 'kias',
    'kiasanlah': 'kias',
    'berkias': 'kias',
    'mengias': 'kias',
    'mengiaskan': 'kias',
    'mengiasi': 'kias',
    'pengias': 'kias',
    'pengiasan': 'kias',
    'berkias-kias': 'kias',
    'berkias-kiasan': 'kias',
    'mengiat': 'kiat',
    'mengiatkan': 'kiat',
    'berkiat': 'kiat',
    'berkiatan': 'kiat',
    'kibasan': 'kibas',
    'mengibas': 'kibas',
    'mengibasnya': 'kibas',
    'mengibaskan': 'kibas',
    'mengibaskannya': 'kibas',
    'mengibas-ngibas': 'kibas',
    'mengibas-ngibaskan': 'kibas',
    'berkiblat': 'kiblat',
    'berkiblatnya': 'kiblat',
    'mengiblatkan': 'kiblat',
    'pengibul': 'kibul',
    'pengibulan': 'kibul',
    'terkibuli': 'kibul',
    'mengibuli': 'kibul',
    'mengibulinya': 'kibul',
    'terkicu': 'kicu',
    'pengicu': 'kicu',
    'mengicu': 'kicu',
    'pengicuan': 'kicu',
    'berkicuh': 'kicuh',
    'berkicut': 'kicut',
    'kidungan': 'kidung',
    'mengidung': 'kidung',
    'mengidungkan': 'kidung',
    'terkijai-kijai': 'kijai',
    'mengijing': 'kijing',
    'terkikih-kikih': 'kikih',
    'mengikik': 'kikik',
    'berkikikan': 'kikik',
    'terkikik-kikik': 'kikik',
    'kikisan': 'kikis',
    'terkikis': 'kikis',
    'terkikisnya': 'kikis',
    'pengikis': 'kikis',
    'pengikisan': 'kikis',
    'mengikis': 'kikis',
    'mengikisnya': 'kikis',
    'mengikiskan': 'kikis',
    'mengikisi': 'kikis',
    'mengikisan': 'kikis',
    'pengikisannya': 'kikis',
    'kekikukan': 'kikuk',
    'kekikukannya': 'kikuk',
    'mengilah': 'kilah',
    'berkilah': 'kilah',
    'berkilah-kilah': 'kilah',
    'mengilah-ngilahkan': 'kilah',
    'mengilan': 'kilan',
    'terkilan': 'kilan',
    'kilangan': 'kilang',
    'mengilang': 'kilang',
    'mengilangnya': 'kilang',
    'mengilangkan': 'kilang',
    'pengilang': 'kilang',
    'pengilangan': 'kilang',
    'perkilangan': 'kilang',
    'pengilangannya': 'kilang',
    'sekilap': 'kilap',
    'mengilap': 'kilap',
    'mengilapnya': 'kilap',
    'mengilapkan': 'kilap',
    'berkilap': 'kilap',
    'berkilapnya': 'kilap',
    'pengilapan': 'kilap',
    'berkilap-kilap': 'kilap',
    'sekilas': 'kilas',
    'sekilasnya': 'kilas',
    'sekilasi': 'kilas',
    'terkilas': 'kilas',
    'kili-kili': 'kili',
    'kilik-kilik': 'kilikan',
    'mengilik-ngilik': 'kilikan',
    'kiliran': 'kilir',
    'mengilir': 'kilir',
    'terkilir': 'kilir',
    'terkilirnya': 'kilir',
    'kiloan': 'kilo',
    'kiloannya': 'kilo',
    'mengilo': 'kilo',
    'mengilokan': 'kilo',
    'berkilo-kilo': 'kilo',
    'terkimah': 'kimah',
    'mengimbah': 'kimbah',
    'berkimbang-kimbang': 'kimbang',
    'mengimpal': 'kimpal',
    'terkimpus': 'kimpus',
    'kinangan': 'kinang',
    'penginangan': 'kinang',
    'mengincah': 'kincah',
    'terkincak-kincak': 'kincak',
    'mengincau': 'kincau',
    'kinciran': 'kincir',
    'berkincir': 'kincir',
    'mengincup': 'kincup',
    'terkindap-kindap': 'kindap',
    'berkinerja': 'kinerja',
    'berkinerjanya': 'kinerja',
    'kekinian': 'kini',
    'kekiniannya': 'kini',
    'kekinianlah': 'kini',
    'berkinja-kinja': 'kinja',
    'terkinja-kinja': 'kinja',
    'terkinjat': 'kinjat',
    'perkintakaan': 'kintaka',
    'berkinte': 'kinte',
    'mengintil': 'kintil',
    'mengintili': 'kintil',
    'mengipaikan': 'kipai',
    'kipasan': 'kipas',
    'berkipas': 'kipas',
    'mengipas': 'kipas',
    'mengipasnya': 'kipas',
    'mengipaskan': 'kipas',
    'mengipasi': 'kipas',
    'pengipas': 'kipas',
    'mengipasinya': 'kipas',
    'pengipasan': 'kipas',
    'berkipas-kipas': 'kipas',
    'mengipas-ngipas': 'kipas',
    'mengipas-ngipaskan': 'kipas',
    'mengipas-ngipasi': 'kipas',
    'berkiprah': 'kiprah',
    'berkiprahnya': 'kiprah',
    'berkiprahlah': 'kiprah',
    'mengipratkan': 'kiprat',
    'mengekir': 'kir',
    'mengekirkan': 'kir',
    'kiraan': 'kira',
    'kiraannya': 'kira',
    'terkira': 'kira',
    'terkirakan': 'kira',
    'kiranya': 'kira',
    'mengira': 'kira',
    'mengiranya': 'kira',
    'mengirakan': 'kira',
    'mengiraku': 'kira',
    'perkiraan': 'kira',
    'perkiraannya': 'kira',
    'perkiraankan': 'kira',
    'perkiraanku': 'kira',
    'perkiraanmu': 'kira',
    'kira-kira': 'kira',
    'kira-kiranya': 'kira',
    'kira-kiralah': 'kira',
    'pengiraan': 'kira',
    'sekiranya': 'sekira',
    'sekira-kira': 'kira',
    'sekira-kiranya': 'kira',
    'kira-kiraan': 'kira',
    'berkira-kira': 'kira',
    'mengira-ngira': 'kira',
    'memperkirakan': 'kira',
    'memperkirakannya': 'kira',
    'mengira-ngirakan': 'kira',
    'mengirabkan': 'kirab',
    'berkirai': 'kirai',
    'mengirai': 'kirai',
    'mengiraikan': 'kirai',
    'terkirai-kirai': 'kirai',
    'mengirap': 'kirap',
    'mengirapkan': 'kirap',
    'memperkirapkan': 'kirap',
    'berkirung': 'kirung',
    'mengisa': 'kisa',
    'mengisakan': 'kisa',
    'mengisai': 'kisai',
    'kisahan': 'kisah',
    'terkisah': 'kisah',
    'terkisahkan': 'kisah',
    'berkisah': 'kisah',
    'berkisahlah': 'kisah',
    'berkisahkan': 'kisah',
    'pengisahan': 'kisah',
    'pengisahannya': 'kisah',
    'mengisahkan': 'kisah',
    'mengisahkannya': 'kisah',
    'kisaian': 'kisai',
    'mengisas': 'kisas',
    'pengisat': 'kisat',
    'pengisatan': 'kisat',
    'mengisatkan': 'kisat',
    'berkisi': 'kisi',
    'kisi-kisi': 'kisi',
    'kisi-kisinya': 'kisi',
    'kisi-kisilah': 'kisi',
    'kisikan': 'kisik',
    'mengisik': 'kisik',
    'kekisruhan': 'kisruh',
    'kekisruhannya': 'kisruh',
    'mengisruhkan': 'kisruh',
    'pengisut': 'kisut',
    'mengisut': 'kisut',
    'mengisutkan': 'kisut',
    'kekitaan': 'kita',
    'berkitab': 'kitab',
    'pengitaban': 'kitab',
    'kitang-kitang': 'kitang',
    'mengitik': 'kitik',
    'mengitik-ngitik': 'kitik',
    'kitiran': 'kitir',
    'terkiuk': 'kiuk',
    'pengklaim': 'klaim',
    'pengklaiman': 'klaim',
    'mengklaim': 'klaim',
    'mengklaimnya': 'klaim',
    'mengklaimlah': 'klaim',
    'mengklaimkan': 'klaim',
    'mengklaimi': 'klaim',
    'pengklaimannya': 'klaim',
    'mengklakson': 'klakson',
    'mengklaksonnya': 'klakson',
    'mengklaksonkan': 'klakson',
    'mengklarifikasi': 'klarifikasi',
    'mengklarifikasinya': 'klarifikasi',
    'mengklarifikasikan': 'klarifikasi',
    'mengklarifikasikannya': 'klarifikasi',
    'mengklasifikasi': 'klasifikasi',
    'mengklasifikasinya': 'klasifikasi',
    'mengklasifikasikan': 'klasifikasi',
    'mengklasifikasikannya': 'klasifikasi',
    'pengklasifikasi': 'klasifikasi',
    'pengklasifikasian': 'klasifikasi',
    'pengklasifikasiannya': 'klasifikasi',
    'klik-klikan': 'klik',
    'mengeklirkan': 'klir',
    'mengkliring': 'kliring',
    'mengkliringkan': 'kliring',
    'mengklise': 'klise',
    'keklisean': 'klise',
    'pengklonaan': 'klona',
    'mengklonakan': 'klona',
    'keklorinan': 'klorin',
    'pengklorinan': 'klorin',
    'koak-koak': 'koak',
    'berkoak-koak': 'koak',
    'berkoalisi': 'koalisi',
    'berkoalisinya': 'koalisi',
    'berkoalisilah': 'koalisi',
    'berkoalisii': 'koalisi',
    'berkoar': 'koar',
    'berkoar-koar': 'koar',
    'berkoar-koarnya': 'koar',
    'kobakan': 'kobak',
    'koboi-koboian': 'koboi',
    'kekoboi-koboian': 'koboi',
    'kobokan': 'kobok',
    'berkobok': 'kobok',
    'mengobok': 'kobok',
    'berkobok-kobok': 'kobok',
    'terkocoh-kocoh': 'kocoh',
    'mengocok': 'kocok',
    'mengocoknya': 'kocok',
    'pengocok': 'kocok',
    'pengocokkan': 'kocok',
    'pengocokan': 'kocok',
    'mengocong': 'kocong',
    'mengocongkan': 'kocong',
    'kocoran': 'kocor',
    'mengocor': 'kocor',
    'mengocorkan': 'kocor',
    'mengodekan': 'kode',
    'mengodekannya': 'kode',
    'sekodi': 'kodi',
    'kodian': 'kodi',
    'berkodi-kodi': 'kodi',
    'pengodifikasian': 'kodifikasi',
    'mengodifikasikan': 'kodifikasi',
    'mengodok': 'kodok',
    'kekohesifan': 'kohesif',
    'terkojol-kojol': 'kojol',
    'mengokang': 'kokang',
    'mengokangnya': 'kokang',
    'mengokol': 'kokol',
    'terkokol': 'kokol',
    'terkokol-kokol': 'kokol',
    'terkokot': 'kokot',
    'mengokot': 'kokot',
    'berkolaborasi': 'kolaborasi',
    'berkolek-kolek': 'kolek',
    'mengoleksi': 'koleksi',
    'mengoleksinya': 'koleksi',
    'kekolektifan': 'kolektif',
    'kolokan': 'kolok',
    'berkolokasi': 'kolokasi',
    'kolongan': 'kolong',
    'kolong-kolong': 'kolong',
    'kekolotan': 'kolot',
    'berkolusi': 'kolusi',
    'koma-koma': 'koma',
    'mengomando': 'komando',
    'mengomandokan': 'komando',
    'mengomandoi': 'komando',
    'pengomandoan': 'komando',
    'berkomat-kamit': 'komat-kamit',
    'berkombinasi': 'kombinasi',
    'mengombinasikan': 'kombinasi',
    'mengombinasikannya': 'kombinasi',
    'sekomeng': 'komeng',
    'berkomentar': 'komentar',
    'berkomentarlah': 'komentar',
    'mengomentari': 'komentar',
    'mengomentarinya': 'komentar',
    'mengomersialkan': 'komersial',
    'mengomersialkannya': 'komersial',
    'mengomidikan': 'komidi',
    'mengomisi': 'komisi',
    'mengomisikan': 'komisi',
    'mengomit': 'komit',
    'berkompanyon': 'kompanyon',
    'mengompas': 'kompas',
    'kompenian': 'kompeni',
    'mengompes': 'kompes',
    'mengompori': 'kompor',
    'mengomporinya': 'kompor',
    'pengomporan': 'kompor',
    'mengompos': 'kompos',
    'mengomposkan': 'kompos',
    'mengompres': 'kompres',
    'mengompresnya': 'kompres',
    'mengompresi': 'kompres',
    'mengomputerkan': 'komputer',
    'berkomunikasi': 'komunikasi',
    'berkomunikasinya': 'komunikasi',
    'berkomunikasilah': 'komunikasi',
    'berkomunikasikan': 'komunikasi',
    'mengomunikasikan': 'komunikasi',
    'mengomunikasikannya': 'komunikasi',
    'mengomuniskan': 'komunis',
    'mengonan': 'konan',
    'mengonani': 'konan',
    'perkoncoan': 'konco',
    'mengonde': 'konde',
    'mengondensasikan': 'kondensasi',
    'mengondisikan': 'kondisi',
    'mengondisikannya': 'kondisi',
    'mengonferensikan': 'konferensi',
    'mengonfirmasikan': 'konfirmasi',
    'mengonfirmasikannya': 'konfirmasi',
    'berkongkalikong': 'kongkalikong',
    'kongko-kongko': 'kongko',
    'kongkongan': 'kongkong',
    'mengongkong': 'kongkong',
    'terkongkong': 'kongkong',
    'memperkonon': 'konon',
    'mengononkan': 'konon',
    'mengonsentrasikan': 'konsentrasi',
    'mengonsep': 'konsep',
    'mengonsepkan': 'konsep',
    'pengonsep': 'konsep',
    'pengonsepan': 'konsep',
    'mengonsolidasikan': 'konsolidasi',
    'mengonsolidasikannya': 'konsolidasi',
    'mengonstatir': 'konstatir',
    'berkonsultasi': 'konsultasi',
    'berkonsultasilah': 'konsultasi',
    'berkonsultasikan': 'konsultasi',
    'mengonsumsi': 'konsumsi',
    'mengonsumsinya': 'konsumsi',
    'mengonsumsikan': 'konsumsi',
    'pengonsumsian': 'konsumsi',
    'pengonsumsiannya': 'konsumsi',
    'berkontak': 'kontak',
    'mengontak': 'kontak',
    'mengontaknya': 'kontak',
    'mengontakku': 'kontak',
    'terkontaminasi': 'kontaminasi',
    'terkontaminasinya': 'kontaminasi',
    'mengontaminasi': 'kontaminasi',
    'mengontaminasinya': 'kontaminasi',
    'mengontaminasikan': 'kontaminasi',
    'mengontan': 'kontan',
    'berkontemplasi': 'kontemplasi',
    'mengonter': 'konter',
    'kontrakan': 'kontrak',
    'kontrakannya': 'kontrak',
    'kontrakanku': 'kontrak',
    'mengontrak': 'kontrak',
    'mengontraknya': 'kontrak',
    'mengontrakkan': 'kontrak',
    'mengontrakkannya': 'kontrak',
    'mengontrakan': 'kontrak',
    'mengontrakku': 'kontrak',
    'pengontrak': 'kontrak',
    'pengontraknya': 'kontrak',
    'pengontrakan': 'kontrak',
    'berkontraksi': 'kontraksi',
    'berkontraksinya': 'kontraksi',
    'kekontrasan': 'kontras',
    'kekontrasannya': 'kontras',
    'pengontrasan': 'kontras',
    'mengontraskan': 'kontras',
    'mengontrol': 'kontrol',
    'mengontrolnya': 'kontrol',
    'mengontrolkan': 'kontrol',
    'mengontrolan': 'kontrol',
    'pengontrol': 'kontrol',
    'pengontrolnya': 'kontrol',
    'pengontrolan': 'kontrol',
    'terkontrol': 'kontrol',
    'terkontrolnya': 'kontrol',
    'terkontrollah': 'kontrol',
    'pengontrolannya': 'kontrol',
    'mengonvergensikan': 'konvergensi',
    'mengonversikan': 'konversi',
    'mengonversikannya': 'konversi',
    'kekonyolan': 'konyol',
    'kekonyolannya': 'konyol',
    'berkooperasi': 'kooperasi',
    'terkooptasi': 'kooptasi',
    'terkooptasinya': 'kooptasi',
    'mengooptasi': 'kooptasi',
    'pengooptasian': 'kooptasi',
    'mengoordinasi': 'koordinasi',
    'mengoordinasinya': 'koordinasi',
    'mengoordinasikan': 'koordinasi',
    'mengoordinasikannya': 'koordinasi',
    'terkoordinasi': 'koordinasi',
    'terkoordinasinya': 'koordinasi',
    'terkoordinasikan': 'koordinasi',
    'terkoordinasikannya': 'koordinasi',
    'berkoordinasi': 'koordinasi',
    'berkoordinasilah': 'koordinasi',
    'berkoordinasikan': 'koordinasi',
    'pengoordinasian': 'koordinasi',
    'berkop': 'kop',
    'mengekop': 'kop',
    'berkopah-kopah': 'kopah',
    'mengopak': 'opak',
    'mengopek': 'kopek',
    'berkoper-koper': 'koper',
    'berkoperasi': 'koperasi',
    'perkoperasian': 'koperasi',
    'perkoperasiannya': 'koperasi',
    'mengopi': 'kopi',
    'mengopinya': 'kopi',
    'pengopi': 'kopi',
    'pengopian': 'kopi',
    'perkopian': 'kopi',
    'kopokan': 'kopok',
    'perkopraan': 'kopra',
    'koprakan': 'koprak',
    'mengopyok': 'kopyok',
    'berkoran': 'koran',
    'mengorankan': 'koran',
    'berkorban': 'korban',
    'berkorbannya': 'korban',
    'berkorbanlah': 'korban',
    'berkorbanan': 'korban',
    'pengorbanan': 'korban',
    'pengorbanannya': 'korban',
    'pengorbananlah': 'korban',
    'pengorbananan': 'korban',
    'pengorbananku': 'korban',
    'pengorbananmu': 'korban',
    'mengorbankan': 'korban',
    'mengorbankannya': 'korban',
    'mengorbankanku': 'korban',
    'mengored': 'kored',
    'korekan': 'korek',
    'mengorek': 'korek',
    'mengoreknya': 'korek',
    'pengorek': 'korek',
    'pengorekan': 'korek',
    'mengorek-ngorek': 'korek',
    'mengorek-ngoreknya': 'korek',
    'koreksian': 'koreksi',
    'koreksiannya': 'koreksi',
    'mengoreksi': 'koreksi',
    'mengoreksinya': 'koreksi',
    'mengoreksimu': 'koreksi',
    'pengoreksi': 'koreksi',
    'pengoreksian': 'koreksi',
    'berkorelasi': 'korelasi',
    'mengorelasikan': 'korelasi',
    'korengan': 'koreng',
    'berkoreng': 'koreng',
    'koreng-koreng': 'koreng',
    'berkorespondensi': 'korespondensi',
    'koretan': 'koret',
    'mengorok': 'orok',
    'berkorong': 'korong',
    'mengorting': 'korting',
    'mengorup': 'korup',
    'mengorupsi': 'korupsi',
    'mengosek': 'kosek',
    'terkosel-kosel': 'kosel',
    'kekosenan': 'kosen',
    'kekosongan': 'kosong',
    'kekosongannya': 'kosong',
    'pengosongan': 'kosong',
    'pengosongannya': 'kosong',
    'mengosongkan': 'kosong',
    'mengosongkannya': 'kosong',
    'sekosong-kosongnya': 'kosong',
    'berkostum': 'kostum',
    'berkostumkan': 'kostum',
    'berkota': 'kota',
    'mengota': 'kota',
    'mengotakan': 'kotak',
    'mengotai': 'kota',
    'kekotaan': 'kota',
    'perkotaan': 'kota',
    'perkotaannya': 'kota',
    'pengotaan': 'kota',
    'kekota-kotaan': 'kota',
    'sekotah': 'kotah',
    'mengotak-ngatikkan': 'kotak katik',
    'terkotak': 'kotak',
    'terkotakan': 'kotak',
    'mengotak': 'kotak',
    'mengotakkan': 'kotak',
    'mengotaki': 'otak',
    'pengotakan': 'kotak',
    'berkotak-kotak': 'kotak',
    'berkotak-kotakkan': 'kotak',
    'berkotak-kotakan': 'kotak',
    'terkotak-kotak': 'kotak',
    'terkotak-kotaknya': 'kotak',
    'terkotak-kotakkan': 'kotak',
    'terkotak-kotakan': 'kotak',
    'pengotak-ngotakan': 'kotak',
    'mengotak-ngotakkan': 'kotak',
    'terkoteng-koteng': 'koteng',
    'sekotes': 'kotes',
    'mengotes': 'kotes',
    'kotoran': 'kotor',
    'kotorannya': 'kotor',
    'pengotor': 'kotor',
    'pengotornya': 'kotor',
    'pengotoran': 'kotor',
    'mengotori': 'kotor',
    'mengotorinya': 'kotor',
    'kekotoran': 'kotor',
    'kekotorannya': 'kotor',
    'mengotorkan': 'kotor',
    'mengover': 'kover',
    'kowekan': 'kowek',
    'mengoyak': 'oyak',
    'mengoyaknya': 'oyak',
    'mengoyakkan': 'oyak',
    'mengoyaki': 'oyak',
    'mengoyakan': 'oyak',
    'koyak-koyak': 'koyak',
    'mengoyak-ngoyak': 'koyak',
    'mengoyak-ngoyaknya': 'koyak',
    'mengoyak-ngoyakkan': 'koyak',
    'berkreasi': 'kreasi',
    'berkreasinya': 'kreasi',
    'berkreasilah': 'kreasi',
    'kekreatifan': 'kreatif',
    'kekreatifannya': 'kreatif',
    'kreditan': 'kredit',
    'kreditannya': 'kredit',
    'mengkredit': 'kredit',
    'mengkreditnya': 'kredit',
    'mengkreditkan': 'kredit',
    'pengkredit': 'kredit',
    'pengkreditan': 'kredit',
    'perkreditan': 'kredit',
    'mengkrisis': 'krisis',
    'mengkristal': 'kristal',
    'mengkristalnya': 'kristal',
    'mengkristalkan': 'kristal',
    'pengkristalan': 'kristal',
    'kekristenan': 'kristen',
    'kekristenannya': 'kristen',
    'mengkristenkan': 'kristen',
    'pengkritik': 'kritik',
    'pengkritiknya': 'kritik',
    'mengkritik': 'kritik',
    'mengkritiknya': 'kritik',
    'mengkritiklah': 'kritik',
    'mengkritiki': 'kritik',
    'mengkritikan': 'kritik',
    'mengkritikku': 'kritik',
    'mengkritikmu': 'kritik',
    'mengkritis': 'kritis',
    'mengkritisnya': 'kritis',
    'mengkritisi': 'kritis',
    'kekritisan': 'kritis',
    'kekritisannya': 'kritis',
    'berkuah': 'kuah',
    'berkuahkan': 'kuah',
    'menguahi': 'kuah',
    'menguahkan': 'kuah',
    'terkuai-kuai': 'kuai',
    'terkuak': 'kuak',
    'terkuaknya': 'kuak',
    'terkuaklah': 'kuak',
    'menguak': 'uak',
    'menguaknya': 'uak',
    'menguakkan': 'uak',
    'menguakan': 'uak',
    'berkuala': 'kuala',
    'berkualifikasi': 'kualifikasi',
    'mengualifikasikan': 'kualifikasi',
    'berkualitas': 'kualitas',
    'berkualitasnya': 'kualitas',
    'berkualitaslah': 'kualitas',
    'berkualitasi': 'kualitas',
    'menguap': 'uap',
    'menguapnya': 'uap',
    'menguaplah': 'uap',
    'menguapkan': 'uap',
    'menguapkannya': 'uap',
    'menguapi': 'uap',
    'kuaran': 'kuar',
    'menguarkan': 'uar',
    'menguar-nguarkan': 'kuar',
    'kuas-kuas': 'kuas',
    'berkubak': 'kubak',
    'mengubak': 'kubak',
    'terkubak': 'kubak',
    'mengubik': 'kubik',
    'sekubit': 'kubit',
    'mengubit': 'kubit',
    'mengubrakan': 'kubra',
    'kuburan': 'kubur',
    'kuburannya': 'kubur',
    'kuburanlah': 'kubur',
    'kuburanku': 'kubur',
    'kuburanmu': 'kubur',
    'terkubur': 'kubur',
    'terkuburnya': 'kubur',
    'terkuburlah': 'kubur',
    'mengubur': 'kubur',
    'menguburnya': 'kubur',
    'menguburkan': 'kubur',
    'menguburkannya': 'kubur',
    'menguburi': 'kubur',
    'menguburku': 'kubur',
    'menguburmu': 'kubur',
    'berkubur': 'kubur',
    'pekuburan': 'kubur',
    'penguburan': 'kubur',
    'penguburannya': 'kubur',
    'penguburanku': 'kubur',
    'menguburkanmu': 'kubur',
    'terkucai': 'kucai',
    'mengucai': 'kucai',
    'berkucak': 'kucak',
    'mengucak': 'kucak',
    'mengucakan': 'kucak',
    'terkucak': 'kucak',
    'mengucar-ngacirkan': 'kucar-kacir',
    'mengucek-ngucek': 'kucek',
    'terkucil': 'kucil',
    'terkucilnya': 'kucil',
    'terkucilkan': 'kucil',
    'mengucil': 'kucil',
    'mengucilkan': 'kucil',
    'mengucilkannya': 'kucil',
    'kucing-kucing': 'kucing',
    'kucing-kucingnya': 'kucing',
    'kucing-kucingan': 'kucing',
    'kucing-kucingku': 'kucing',
    'kucing-kucingannya': 'kucing',
    'kucing-kucinganlah': 'kucing',
    'mengucup': 'kucup',
    'mengucupkan': 'kucup',
    'kucuran': 'kucur',
    'kucurannya': 'kucur',
    'mengucur': 'kucur',
    'mengucurnya': 'kucur',
    'mengucurlah': 'kucur',
    'mengucurkan': 'kucur',
    'mengucurkannya': 'kucur',
    'mengucuri': 'kucur',
    'berkucur': 'kucur',
    'berkucuran': 'kucur',
    'kudangan': 'kudang',
    'kudapan': 'kudap',
    'kudapannya': 'kudap',
    'mengudap': 'kudap',
    'mengudapnya': 'kudap',
    'pengudap': 'kudap',
    'kudap-kudap': 'kudap',
    'mengudeta': 'kudeta',
    'mengudian': 'kudian',
    'terkudian': 'kudian',
    'mengudiankan': 'kudian',
    'kudisan': 'kudis',
    'berkudis': 'kudis',
    'sekudung': 'kudung',
    'berkudung': 'kudung',
    'pengudung': 'kudung',
    'mengudung': 'kudung',
    'pengudungan': 'kudung',
    'mengudungkan': 'kudung',
    'kekudusan': 'kudus',
    'kekudusannya': 'kudus',
    'pengudusan': 'kudus',
    'menguduskan': 'kudus',
    'kue-kue': 'kue',
    'kue-kuenya': 'kue',
    'sekufu': 'kufu',
    'kekufuran': 'kufur',
    'kekufurannya': 'kufur',
    'mengufurkan': 'kufur',
    'menguis': 'kuis',
    'menguit': 'uit',
    'sekujur': 'kujur',
    'sekujurnya': 'kujur',
    'pengujut': 'kujut',
    'terkujut': 'kujut',
    'mengujut': 'kujut',
    'mengujutkan': 'kujut',
    'berkujut': 'kujut',
    'kukuran': 'kukur',
    'kukusan': 'kukus',
    'mengukus': 'kukus',
    'mengukusnya': 'kukus',
    'berkukus': 'kukus',
    'kulah-kulah': 'kulah',
    'terkulai': 'kulai',
    'terkulainya': 'kulai',
    'berkulai': 'kulai',
    'berkulaian': 'kulai',
    'perkulakan': 'kulak',
    'kulak-kulak tangan': 'kulak',
    'berkulimat': 'kulimat',
    'mengulit': 'ulit',
    'menguliti': 'ulit',
    'pengulit': 'kulit',
    'pengulitan': 'kulit',
    'berkulit': 'kulit',
    'mengulitinya': 'kulit',
    'perkulitan': 'kulit',
    'pengultusan': 'kultus',
    'pengultusannya': 'kultus',
    'mengultuskan': 'kultus',
    'mengulub': 'kulub',
    'mengulum': 'kulum',
    'mengulumnya': 'kulum',
    'kulum-kulum': 'kulum',
    'mengulum-ngulum': 'kulum',
    'berkulup': 'kulup',
    'kumaian': 'kumai',
    'berkumai': 'kumai',
    'mengumai': 'kumai',
    'mengumaikan': 'kumai',
    'mengumalkan': 'kumal',
    'mengumandang': 'kumandang',
    'mengumandangkan': 'kumandang',
    'mengumandangkannya': 'kumandang',
    'berkumandang': 'kumandang',
    'berkumandangnya': 'kumandang',
    'berkumandangkan': 'kumandang',
    'kumat-kamit': 'kumat',
    'mengumbah': 'kumbah',
    'mengumbang': 'umbang',
    'mengumbangkan': 'umbang',
    'mengumbangi': 'umbang',
    'berkumis': 'kumis',
    'berkumisan': 'kumis',
    'berkumpai': 'kumpai',
    'terkumpal-kumpal': 'kumpal',
    'kumparan': 'kumpar',
    'kumparannya': 'kumpar',
    'mengumpar': 'kumpar',
    'kekumuhan': 'kumuh',
    'kekumuhannya': 'kumuh',
    'mengumuhkan': 'kumuh',
    'berkumut': 'kumut',
    'berkunang-kunang': 'kunang-kunang',
    'berkunar-kunar': 'kunar-kunar',
    'mengunci': 'kunci',
    'menguncinya': 'kunci',
    'menguncikan': 'kunci',
    'terkunci': 'kunci',
    'terkuncinya': 'kunci',
    'pengunci': 'kunci',
    'penguncinya': 'kunci',
    'penguncian': 'kunci',
    'menguncup': 'kuncup',
    'penguncupan': 'kuncup',
    'menguncupkan': 'kuncup',
    'mengundai': 'kundai',
    'kundangan': 'kundang',
    'mengundang': 'undang',
    'mengundangnya': 'undang',
    'mengundangkan': 'undang',
    'mengundangkannya': 'undang',
    'mengundangan': 'undang',
    'mengundangku': 'undang',
    'mengundangmu': 'undang',
    'berkundang': 'kundang',
    'mengungkang': 'kungkang',
    'kungkungan': 'kungkung',
    'kungkungannya': 'kungkung',
    'terkungkung': 'kungkung',
    'mengungkung': 'kungkung',
    'mengungkungnya': 'kungkung',
    'menguntit': 'kuntit',
    'menguntitnya': 'kuntit',
    'menguntiti': 'kuntit',
    'terkuntum': 'kuntum',
    'menguntum': 'kuntum',
    'kunyahan': 'kunyah',
    'kunyahannya': 'kunyah',
    'mengunyah': 'kunyah',
    'mengunyahnya': 'kunyah',
    'mengunyahlah': 'kunyah',
    'mengunyahkan': 'kunyah',
    'mengunyahkannya': 'kunyah',
    'terkunyah': 'kunyah',
    'kupakan': 'kupak',
    'berkupak': 'kupak',
    'mengupak': 'upak',
    'mengupakan': 'upak',
    'kupasan': 'kupas',
    'kupasannya': 'kupas',
    'terkupas': 'kupas',
    'mengupas': 'kupas',
    'mengupasnya': 'kupas',
    'mengupaskan': 'kupas',
    'pengupas': 'kupas',
    'pengupasan': 'kupas',
    'pengupasannya': 'kupas',
    'mengupil': 'upil',
    'menguping': 'kuping',
    'berkuping': 'kuping',
    'mengupingi': 'kuping',
    'berkurai': 'kurai',
    'berkurap': 'kurap',
    'terkuras': 'kuras',
    'terkurasnya': 'kuras',
    'terkurasi': 'kuras',
    'menguras': 'uras',
    'mengurasnya': 'uras',
    'mengurasi': 'uras',
    'pengurasan': 'kuras',
    'pengurasannya': 'kuras',
    'kekuratoran': 'kurator',
    'berkurban': 'kurban',
    'berkurbannya': 'kurban',
    'mengurbankan': 'kurban',
    'mengurbankannya': 'kurban',
    'menguret': 'kuret',
    'penguretan': 'kuret',
    'kuricakan': 'kuricak',
    'berkurik-kurik': 'kurik',
    'mengursus': 'kursus',
    'mengursuskan': 'kursus',
    'berkurun-kurun': 'kurun',
    'kurungan': 'kurung',
    'kurungannya': 'kurung',
    'mengurung': 'kurung',
    'mengurungnya': 'kurung',
    'mengurungkan': 'urung',
    'mengurungkannya': 'urung',
    'mengurungi': 'kurung',
    'mengurungmu': 'kurung',
    'terkurung': 'kurung',
    'terkurungnya': 'kurung',
    'berkurung': 'kurung',
    'pengurungan': 'kurung',
    'pengurungannya': 'kurung',
    'mengusa': 'kusa',
    'mengusakannya': 'kusa',
    'mengusai': 'usai',
    'mengusal': 'kusal',
    'mengusalkan': 'kusal',
    'berkusau-kusau': 'kusau',
    'berkusik': 'kusik',
    'mengusruk': 'kusruk',
    'mengusrukkan': 'kusruk',
    'berkusu-kusu': 'kusu',
    'mengusuk': 'kusuk',
    'mengusukkan': 'kusuk',
    'mengusukan': 'kusuk',
    'berkusuk': 'kusuk',
    'berkuta': 'kuta',
    'mengutak-ngatikkan': 'kutak',
    'berkutat': 'kutat',
    'berkutatnya': 'kutat',
    'berkuteks': 'kuteks',
    'menguti': 'kuti',
    'kuti-kuti': 'kuti',
    'kutikan': 'kutik',
    'mengutik': 'kutik',
    'berkutik': 'kutik',
    'berkutiknya': 'kutik',
    'mengutik-ngutik': 'kutik',
    'sekutil': 'kutil',
    'mengutil': 'kutil',
    'pengutil': 'kutil',
    'pengutilan': 'kutil',
    'berkuting-kuting': 'kuting',
    'kutipan': 'kutip',
    'kutipannya': 'kutip',
    'mengutip': 'kutip',
    'mengutipnya': 'kutip',
    'mengutipkan': 'kutip',
    'pengutip': 'kutip',
    'pengutipan': 'kutip',
    'berkutu': 'kutu',
    'berkutuan': 'kutu',
    'mengutui': 'kutu',
    'berkutu-kutuan': 'kutu',
    'berkutub': 'kutub',
    'kutukan': 'kutuk',
    'kutukannya': 'kutuk',
    'sekutuk': 'kutuk',
    'terkutuk': 'kutuk',
    'terkutuknya': 'kutuk',
    'terkutuklah': 'kutuk',
    'mengutuk': 'kutuk',
    'mengutuknya': 'kutuk',
    'mengutuki': 'kutuk',
    'mengutukan': 'kutuk',
    'mengutukku': 'kutuk',
    'mengutukmu': 'kutuk',
    'mengutukinya': 'kutuk',
    'keterkutukan': 'kutuk',
    'keterkutukannya': 'kutuk',
    'sekutuk tipe unggul': 'kutuk',
    'menguyup': 'kuyup',
    'menguyupkan': 'kuyup',
    'berlaba': 'laba',
    'melabai': 'laba',
    'melabaikan': 'laba',
    'melabakan': 'laba',
    'melabang': 'labang',
    'berlabel': 'label',
    'berlabelkan': 'label',
    'pelabelan': 'label',
    'pelabelannya': 'label',
    'melabelkan': 'label',
    'melabelkannya': 'label',
    'labilitas': 'labi-labi',
    'kelabilan': 'labil',
    'melabrak': 'labrak',
    'melabraknya': 'labrak',
    'melabrakku': 'labrak',
    'melabu': 'labu',
    'melabukan': 'labu',
    'melabui': 'labu',
    'labu-labu': 'labu',
    'labu-labuan': 'labu',
    'berlabun-labun': 'labun',
    'melabur': 'labur',
    'melaburnya': 'labur',
    'pelabur': 'labur',
    'pelaburan': 'labur',
    'kelaburan': 'labur',
    'melacak': 'lacak',
    'melacaknya': 'lacak',
    'melacakan': 'lacak',
    'pelacak': 'lacak',
    'pelacaknya': 'lacak',
    'pelacakkan': 'lacak',
    'pelacakan': 'lacak',
    'belacak': 'lacak',
    'terlacak': 'lacak',
    'terlacaknya': 'lacak',
    'terlacaklah': 'lacak',
    'pelacakannya': 'lacak',
    'melacur': 'lacur',
    'melacurkan': 'lacur',
    'melacurkannya': 'lacur',
    'pelacur': 'lacur',
    'pelacurnya': 'lacur',
    'pelacuran': 'lacur',
    'pelacurmu': 'lacur',
    'pelacurannya': 'lacur',
    'melacut': 'lacut',
    'meladai': 'lada',
    'peladen': 'laden',
    'ladenan': 'laden',
    'meladeni': 'laden',
    'meladeninya': 'laden',
    'peladenan': 'laden',
    'berladung': 'ladung',
    'meladungkan': 'ladung',
    'melafalkan': 'lafal',
    'melafalkannya': 'lafal',
    'pelagak': 'lagak',
    'melagak': 'lagak',
    'berlagak': 'lagak',
    'melagakkan': 'lagak',
    'melagang': 'lagang',
    'melagangkan': 'lagang',
    'lagian': 'lagi',
    'selagi': 'lagi',
    'lagi-lagi': 'lagi',
    'laguan': 'lagu',
    'pelagu': 'lagu',
    'belagu': 'lagu',
    'belagunya': 'lagu',
    'belagulah': 'lagu',
    'melagu': 'lagu',
    'melagukan': 'lagu',
    'melagukannya': 'lagu',
    'berlagu': 'lagu',
    'melagui': 'lagu',
    'pelahap': 'lahap',
    'melahap': 'lahap',
    'melahapnya': 'lahap',
    'berlahar': 'lahar',
    'terlahir': 'lahir',
    'terlahirnya': 'lahir',
    'terlahirlah': 'lahir',
    'terlahirkan': 'lahir',
    'kelahiran': 'lahir',
    'kelahirannya': 'lahir',
    'kelahiranku': 'lahir',
    'kelahiranmu': 'lahir',
    'melahirkan': 'lahir',
    'melahirkannya': 'lahir',
    'melahirkankan': 'lahir',
    'melahirkanku': 'lahir',
    'melahirkanmu': 'lahir',
    'kelaikan': 'laik',
    'kelaikannya': 'laik',
    'melais': 'lais',
    'melajang': 'lajang',
    'melaju': 'laju',
    'melajunya': 'laju',
    'melajulah': 'laju',
    'melajukan': 'laju',
    'melajukannya': 'laju',
    'kelajuan': 'laju',
    'perlajuan': 'laju',
    'bersilaju': 'laju',
    'berlaju-laju': 'laju',
    'berlajur': 'lajur',
    'melakabkan': 'lakab',
    'melakak': 'lakak',
    'melakakan': 'lakak',
    'berlaki': 'laki',
    'laki-laki': 'laki',
    'laki-lakinya': 'laki',
    'laki-lakilah': 'laki',
    'laki-lakinyalah': 'laki',
    'laki-lakiku': 'laki',
    'laki-lakimu': 'laki',
    'memperlaki': 'laki',
    'kelaki-lakian': 'laki',
    'kelaki-lakiannya': 'laki',
    'memperlakikan': 'laki',
    'melaknat': 'laknat',
    'melaknatnya': 'laknat',
    'melaknati': 'laknat',
    'melaknatkan': 'laknat',
    'lelakon': 'lakon',
    'pelakon': 'lakon',
    'pelakonnya': 'lakon',
    'melakoni': 'lakon',
    'melakoninya': 'lakon',
    'melakonii': 'lakon',
    'berlakon': 'lakon',
    'melakonkan': 'lakon',
    'melakonkannya': 'lakon',
    'pelaksana': 'laksana',
    'pelaksananya': 'laksana',
    'pelaksanakan': 'laksana',
    'pelaksanakannya': 'laksana',
    'pelaksanaan': 'laksana',
    'terlaksana': 'laksana',
    'terlaksananya': 'laksana',
    'terlaksanalah': 'laksana',
    'terlaksanakan': 'laksana',
    'pelaksanaannya': 'laksana',
    'pelaksanaanan': 'laksana',
    'melaksanakan': 'laksana',
    'melaksanakannya': 'laksana',
    'melaksanakanan': 'laksana',
    'berlaku lajak': 'laku lajak',
    'melakurkan': 'lakur',
    'melala': 'lala',
    'melalai': 'lala',
    'pelalah': 'lalah',
    'pelalahan': 'lalah',
    'melalah': 'lalah',
    'terlalah': 'lalah',
    'melalak': 'lalak',
    'melalap': 'lalap',
    'melalapnya': 'lalap',
    'melalapkan': 'lalap',
    'melalau': 'lalau',
    'melalaui': 'lalau',
    'pelalau': 'lalau',
    'pelalauan': 'lalau',
    'melali': 'lali',
    'melalikan': 'lali',
    'melalii': 'lali',
    'berlalu lintas': 'lalu lintas',
    'perlalulintasan': 'lalu lintas',
    'selama': 'lama',
    'selamanya': 'lama',
    'selamai': 'lama',
    'kelamaan': 'lama',
    'lama-lama': 'lama',
    'lama-lamalah': 'lama',
    'lama-lamaan': 'lama',
    'memperlama': 'lama',
    'berlama-lama': 'lama',
    'berlama-lamanya': 'lama',
    'berlama-lamalah': 'lama',
    'berlama-lamaan': 'lama',
    'lama-kelamaan': 'lama',
    'memperlamakan': 'lama',
    'selama-lamanya': 'lama',
    'selama-lamanyanya': 'lama',
    'pelamar': 'lamar',
    'pelamarnya': 'lamar',
    'pelamaran': 'lamar',
    'melamar': 'lamar',
    'melamarnya': 'lamar',
    'melamarkan': 'lamar',
    'melamarku': 'lamar',
    'melamarmu': 'lamar',
    'lamaran': 'lamar',
    'lamarannya': 'lamar',
    'lamaranku': 'lamar',
    'lamaranmu': 'lamar',
    'lambaian': 'lambai',
    'melambai': 'lambai',
    'melambailah': 'lambai',
    'melambaikan': 'lambai',
    'melambaikannya': 'lambai',
    'melambai-lambai': 'lambai',
    'melambai-lambaikan': 'lambai',
    'melambai-lambaikannya': 'lambai',
    'berlambai-lambai': 'lambai',
    'kelambanan': 'lamban',
    'kelambanannya': 'lamban',
    'kelambananan': 'lamban',
    'melambankan': 'lamban',
    'berlambang': 'lambang',
    'berlambangkan': 'lambang',
    'berlambangan': 'lambang',
    'pelambangan': 'lambang',
    'melambangkan': 'lambang',
    'melambangkannya': 'lambang',
    'melambari': 'lambar',
    'terlambat': 'lambat',
    'terlambatnya': 'lambat',
    'terlambatan': 'lambat',
    'berlambat': 'lambat',
    'kelambatan': 'lambat',
    'kelambatannya': 'lambat',
    'melambatkan': 'lambat',
    'melambatkannya': 'lambat',
    'memperlambat': 'lambat',
    'memperlambatnya': 'lambat',
    'memperlambatkan': 'lambat',
    'lambat-lambat': 'lambat',
    'lambat-lambatkan': 'lambat',
    'keterlambatan': 'lambat',
    'keterlambatannya': 'lambat',
    'keterlambatanku': 'lambat',
    'melambat-lambatkan': 'lambat',
    'pelambuk': 'lambuk',
    'melambuk': 'lambuk',
    'melambung': 'lambung',
    'melambungnya': 'lambung',
    'melambungkan': 'lambung',
    'melambungkannya': 'lambung',
    'melambungan': 'lambung',
    'melambungi': 'lambung',
    'pelamin': 'lamin',
    'pelaminan': 'lamin',
    'melamin': 'lamin',
    'pelaminannya': 'lamin',
    'melampai': 'lampai',
    'melampaikan': 'lampai',
    'terlampai': 'lampai',
    'melampam': 'lampam',
    'melampan': 'lampan',
    'melampang': 'lampang',
    'melampangkan': 'lampang',
    'berlampang': 'lampang',
    'berlampang-lampang': 'lampang',
    'berlampar': 'lampar',
    'berlamparan': 'lampar',
    'melampas': 'lampas',
    'melampau': 'lampau',
    'melampaui': 'lampau',
    'melampauinya': 'lampau',
    'melampauiku': 'lampau',
    'melampauimu': 'lampau',
    'terlampau': 'lampau',
    'terlampaunya': 'lampau',
    'terlampaui': 'lampau',
    'terlampauinya': 'lampau',
    'kelampauan': 'lampau',
    'pelampiasan': 'lampias',
    'pelampiasannya': 'lampias',
    'melampiaskan': 'lampias',
    'melampiaskannya': 'lampias',
    'melampini': 'lampin',
    'lampiran': 'lampir',
    'lampirannya': 'lampir',
    'terlampir': 'lampir',
    'terlampirnya': 'lampir',
    'melampiri': 'lampir',
    'melampirinya': 'lampir',
    'melampirkan': 'lampir',
    'melampirkannya': 'lampir',
    'berlampu': 'lampu',
    'berlampukan': 'lampu',
    'perlampuan': 'lampu',
    'pelampung': 'lampung',
    'pelampungnya': 'lampung',
    'pelampungku': 'lampung',
    'melampung': 'lampung',
    'melamun': 'lamun',
    'melamunkan': 'lamun',
    'lamunan': 'lamun',
    'lamunannya': 'lamun',
    'lamunanku': 'lamun',
    'dilamun': 'lamun',
    'melanang': 'lanang',
    'terlancap': 'lancap',
    'lancingan': 'lancing',
    'berlancing': 'lancing',
    'melancip': 'lancip',
    'melancipkan': 'lancip',
    'melancong': 'lancong',
    'melancongnya': 'lancong',
    'melancongi': 'lancong',
    'pelancong': 'lancong',
    'pelancongnya': 'lancong',
    'pelancongan': 'lancong',
    'perpelancongan': 'lancong',
    'lancungan': 'lancung',
    'melancung': 'lancung',
    'kelancungan': 'lancung',
    'melancungkan': 'lancung',
    'melancur': 'lancur',
    'melancut': 'lancut',
    'pelanda': 'landa',
    'pelandakan': 'landa',
    'melanda': 'landa',
    'melandanya': 'landa',
    'melandai': 'landai',
    'melandaku': 'landa',
    'melandamu': 'landa',
    'terlanda': 'landa',
    'terlandai': 'landa',
    'melandakan': 'landa',
    'landaian': 'landai',
    'melandainya': 'landai',
    'melandaikan': 'landai',
    'landasan': 'landas',
    'landasannya': 'landas',
    'landasanan': 'landas',
    'melandas': 'landas',
    'melandaskan': 'landas',
    'melandaskannya': 'landas',
    'melandasi': 'landas',
    'melandasinya': 'landas',
    'berlandasan': 'landas',
    'berlandaskan': 'landas',
    'melandau': 'landau',
    'melandung': 'landung',
    'melangah': 'langah',
    'terlangah': 'langah',
    'melangahkan': 'langah',
    'berlangau': 'langau',
    'langganan': 'langgan',
    'langganannya': 'langgan',
    'langgananan': 'langgan',
    'pelanggan': 'langgan',
    'pelanggannya': 'langgan',
    'pelangganlah': 'langgan',
    'pelangganan': 'langgan',
    'pelangganku': 'langgan',
    'pelangganmu': 'langgan',
    'melanggani': 'langgan',
    'berlanggan': 'langgan',
    'berlanggannya': 'langgan',
    'berlangganan': 'langgan',
    'berlangganannya': 'langgan',
    'berlanggananan': 'langgan',
    'pelanggar': 'langgar',
    'pelanggarnya': 'langgar',
    'pelanggaran': 'langgar',
    'melanggar': 'langgar',
    'melanggarnya': 'langgar',
    'melanggarlah': 'langgar',
    'melanggarkan': 'langgar',
    'melanggaran': 'langgar',
    'terlanggar': 'langgar',
    'terlanggarnya': 'langgar',
    'terlanggarkan': 'langgar',
    'pelanggarannya': 'langgar',
    'pelanggaranmu': 'langgar',
    'berlanggaran': 'langgar',
    'perlanggaran': 'langgar',
    'langgar-melanggar': 'langgar',
    'berlanggar-langgar': 'langgar',
    'kelanggengan': 'langgeng',
    'kelanggengannya': 'langgeng',
    'melanggungkan': 'langgung',
    'melangir': 'langir',
    'berlangir': 'langir',
    'selangit': 'langit',
    'selangitnya': 'langit',
    'melangit': 'langit',
    'melangitnya': 'langit',
    'melangitkan': 'langit',
    'kelangkaan': 'langka',
    'kelangkaannya': 'langka',
    'melangkah': 'langkah',
    'melangkahnya': 'langkah',
    'melangkahlah': 'langkah',
    'melangkahkan': 'langkah',
    'melangkahi': 'langkah',
    'selangkah': 'langkah',
    'pelangkah': 'langkah',
    'pelangkahi': 'langkah',
    'pelangkahan': 'langkah',
    'berlangkah': 'langkah',
    'berlangkahlah': 'langkah',
    'melangkahinya': 'langkah',
    'kelangkahan': 'langkah',
    'perlangkahan': 'langkah',
    'terlangkahkan': 'langkah',
    'memperlangkangkan': 'langkang',
    'melangkapkan': 'langkap',
    'selangkas': 'langkas',
    'melangkaui': 'langkau',
    'terlangkaui': 'langkau',
    'langkupan': 'langkup',
    'terlangkup': 'langkup',
    'melanglang': 'langlang',
    'berlanglang': 'langlang',
    'melangsamkan': 'langsam',
    'melangsar': 'langsar',
    'melangsi': 'langsi',
    'berlangsi': 'langsi',
    'pelangsing': 'langsing',
    'pelangsingnya': 'langsing',
    'pelangsingan': 'langsing',
    'kelangsingan': 'langsing',
    'kelangsingannya': 'langsing',
    'melangsingkan': 'langsing',
    'melangsingkannya': 'langsing',
    'melangsir': 'langsir',
    'melangsirnya': 'langsir',
    'melangsirkan': 'langsir',
    'berlangsung': 'langsung',
    'berlangsungnya': 'langsung',
    'berlangsunglah': 'langsung',
    'berlangsungkan': 'langsung',
    'berlangsungi': 'langsung',
    'berlangsungan': 'langsung',
    'terlangsung': 'langsung',
    'terlangsungnya': 'langsung',
    'kelangsungan': 'langsung',
    'kelangsungannya': 'langsung',
    'melangsungkan': 'langsung',
    'melangsungkannya': 'langsung',
    'perlangsungan': 'langsung',
    'keberlangsungan': 'langsung',
    'keberlangsungannya': 'langsung',
    'melangut': 'langut',
    'melanja': 'lanja',
    'lanja-lanjaan': 'lanja',
    'melanjai': 'lanjai',
    'lanjaran': 'lanjar',
    'melanjar': 'lanjar',
    'terlanjau': 'lanjau',
    'telanjuk': 'lanjuk',
    'melansir': 'lansir',
    'melansirnya': 'lansir',
    'melansirkan': 'lansir',
    'melansiri': 'lansir',
    'melantah': 'lantah',
    'melantai': 'lantai',
    'melantainya': 'lantai',
    'melantaikan': 'lantai',
    'berlantai': 'lantai',
    'berlantaikan': 'lantai',
    'pelantak': 'lantak',
    'melantak': 'lantak',
    'melantakkan': 'lantak',
    'lantakan': 'lantak',
    'kelantaman': 'lantam',
    'melantamkan': 'lantam',
    'melantan': 'lantan',
    'terlantan': 'lantan',
    'melantang': 'lantang',
    'melantangkan': 'lantang',
    'kelantangan': 'lantang',
    'lantaran': 'lantar',
    'lantarannya': 'lantar',
    'lantaranan': 'lantar',
    'pelantar': 'lantar',
    'pelantarnya': 'lantar',
    'pelantaran': 'pelantar',
    'melantarkan': 'lantar',
    'melantarkannya': 'lantar',
    'melantas': 'lantas',
    'berlantas': 'lantas',
    'terlantas': 'lantas',
    'berlantasan': 'lantas',
    'melantaskan': 'lantas',
    'melantik': 'lantik',
    'melantiknya': 'lantik',
    'melantikan': 'lantik',
    'pelantik': 'lantik',
    'pelantiknya': 'lantik',
    'pelantikkan': 'lantik',
    'pelantikkannya': 'lantik',
    'pelantikan': 'lantik',
    'pelantikannya': 'lantik',
    'melanting': 'lanting',
    'terlanting': 'lanting',
    'berlanting': 'lanting',
    'melantingkan': 'lanting',
    'lantunan': 'lantun',
    'lantunannya': 'lantun',
    'melantun': 'lantun',
    'melantunkan': 'lantun',
    'melantunkannya': 'lantun',
    'melantunan': 'lantun',
    'luntang': 'lantung',
    'peluntang': 'lantung',
    'meluntang': 'lantung',
    'lanturan': 'lantur',
    'melantur': 'lantur',
    'melanturkan': 'lantur',
    'pelanturan': 'lantur',
    'melanus': 'lanus',
    'melanyah': 'lanyah',
    'melanyak': 'lanyak',
    'melanyau': 'lanyau',
    'mengelap': 'lap',
    'mengelapnya': 'lap',
    'mengelapi': 'lap',
    'dilapah': 'lapah',
    'melapah': 'lapah',
    '2 lapak': 'lapak',
    'berlapak': 'lapak',
    'lapangan': 'lapang',
    'lapangannya': 'lapang',
    'lapanganlah': 'lapang',
    'lapanganan': 'lapang',
    'melapangi': 'lapang',
    'melapangkan': 'lapang',
    'memperlapang': 'lapang',
    'memperlapangkan': 'lapang',
    'berlapang-lapang': 'lapang',
    'dilapih': 'lapih',
    'melapih': 'lapih',
    'berlapih': 'lapih',
    'melapik': 'lapik',
    'selapik': 'lapik',
    'melapiki': 'lapik',
    'berlapik': 'lapik',
    'melapikkan': 'lapik',
    'melapis': 'lapis',
    'melapisnya': 'lapis',
    'melapiskan': 'lapis',
    'melapisi': 'lapis',
    'lapisan': 'lapis',
    'lapisannya': 'lapis',
    'pelapis': 'lapis',
    'pelapisnya': 'lapis',
    'pelapisan': 'lapis',
    'melapisinya': 'lapis',
    'berlapis': 'lapis',
    'berlapisnya': 'lapis',
    'berlapiskan': 'lapis',
    'berlapisan': 'lapis',
    'berlapis-lapis': 'lapis',
    'laporan': 'lapor',
    'laporannya': 'lapor',
    'laporankan': 'lapor',
    'laporanan': 'lapor',
    'laporanku': 'lapor',
    'laporanmu': 'lapor',
    'pelapor': 'lapor',
    'pelapornya': 'lapor',
    'pelaporlah': 'lapor',
    'pelaporkan': 'lapor',
    'pelaporan': 'lapor',
    'melapor': 'lapor',
    'melapornya': 'lapor',
    'melaporlah': 'lapor',
    'melaporkan': 'lapor',
    'melaporkannya': 'lapor',
    'melapori': 'lapor',
    'melaporan': 'lapor',
    'pelaporannya': 'lapor',
    'melaporkankan': 'lapor',
    'melapun': 'lapun',
    'melapur': 'lapur',
    'berlapur': 'lapur',
    'terlara-lara': 'lara',
    'melarah': 'larah',
    'berlarah-larah': 'larah',
    'pelarai': 'larai',
    'melarai': 'larai',
    'melaraikan': 'larai',
    'melaram': 'laram',
    'larangan': 'larang',
    'larangannya': 'larang',
    'laranganku': 'larang',
    'melarang': 'larang',
    'melarangnya': 'larang',
    'melarangan': 'larang',
    'melarangku': 'larang',
    'melarangmu': 'larang',
    'terlarang': 'larang',
    'terlarangnya': 'larang',
    'terlarangan': 'larang',
    'pelarangan': 'larang',
    'pelarangannya': 'larang',
    'melarangkan': 'larang',
    'selarap': 'larap',
    'melarapkan': 'larap',
    'selaras': 'laras',
    'selarasnya': 'laras',
    'selaraskan': 'laras',
    'selarasan': 'laras',
    'melarasi': 'laras',
    'pelarasan': 'laras',
    'kelarasan': 'laras',
    'berlarasan': 'laras',
    'melaraskan': 'laras',
    'melaraskannya': 'laras',
    'keselarasan': 'laras',
    'keselarasannya': 'laras',
    'penyelarasan': 'laras',
    'menyelaraskan': 'laras',
    'menyelaraskannya': 'laras',
    'melarat': 'larat',
    'melaratnya': 'larat',
    'melaratkan': 'larat',
    'memperlarat': 'larat',
    'berlarat-larat': 'larat',
    'berlarat-laratnya': 'larat',
    'melarau': 'larau',
    'melarih': 'larih',
    'melarihi': 'larih',
    'berlarih-larih': 'larih',
    'selarik': 'larik',
    'pelarik': 'larik',
    'melarik': 'larik',
    'larikan': 'larik',
    'berlarik': 'larik',
    'melarikkan': 'larik',
    'berlarik-larik': 'larik',
    'pelaris': 'laris',
    'pelarisan': 'laris',
    'terlaris': 'laris',
    'terlarisnya': 'laris',
    'melariskan': 'laris',
    'melaru': 'laru',
    'melarui': 'laru',
    'melarungkan': 'larung',
    'pengelasan': 'las',
    'melasah': 'lasah',
    'pelasah': 'lasah',
    'melasahkan': 'lasah',
    'memperlasah': 'lasah',
    'pelasak': 'lasak',
    'pelasakan': 'lasak',
    'pelasi': 'lasi',
    'lasian': 'lasi',
    'melasikan': 'lasi',
    'kelaskaran': 'laskar',
    'selat-latnya': 'lat',
    'melata': 'lata',
    'pelatah': 'latah',
    'pelatahan': 'latah',
    'kelatahan': 'latah',
    'melatahkan': 'latah',
    'melatam': 'latam',
    'melatamkan': 'latam',
    'melatarbelakangi': 'latar belakang',
    'melatarbelakanginya': 'latar belakang',
    'melatari': 'latar',
    'melatarinya': 'latar',
    'pelataran': 'latar',
    'pelatarannya': 'latar',
    'melatas': 'latas',
    'melating': 'lating',
    'latisan': 'latis',
    'melatis': 'latis',
    'melatur': 'latur',
    'berlauk': 'lauk',
    'lauk-pauk': 'lauk',
    'lauk-pauknya': 'lauk',
    'laun-laun': 'laun',
    'melaun-laun': 'laun',
    'melaung': 'laung',
    'pelaung': 'laung',
    'sepelaung': 'laung',
    'melaungkan': 'laung',
    'selaur': 'laur',
    'melaur': 'laur',
    'melawa': 'lawa',
    'melawanya': 'lawa',
    'melawai': 'lawa',
    'melawaan': 'lawa',
    'pelawa': 'lawa',
    'lawah': 'lawai',
    'lawahan': 'lawai',
    'lawah-lawah': 'lawai',
    'melawak': 'lawak',
    'melawaknya': 'lawak',
    'pelawak': 'lawak',
    'pelawaknya': 'lawak',
    'lawakan': 'lawak',
    'lawakannya': 'lawak',
    'lawak-lawak': 'lawak',
    'melawak-lawak': 'lawak',
    'berlawak-lawak': 'lawak',
    'berlawalata': 'lawalata',
    'pelawang': 'lawang',
    'pelawangan': 'lawang',
    'melawar': 'lawar',
    'melawas': 'lawas',
    'lawatan': 'lawat',
    'lawatannya': 'lawat',
    'melawat': 'lawat',
    'melawatnya': 'lawat',
    'melawatkan': 'lawat',
    'melawati': 'lawat',
    'pelawat': 'lawat',
    'pelawati': 'lawat',
    'pelawatan': 'lawat',
    'perlawatan': 'lawat',
    'perlawatannya': 'lawat',
    'selawe': 'lawe',
    'penglawe': 'lawe',
    'lawi-lawi': 'lawi',
    'melayah': 'layah',
    'terlayah': 'layah',
    'melayahkan': 'layah',
    'melayam': 'layam',
    'layanan': 'layan',
    'layanannya': 'layan',
    'layanani': 'layan',
    'layananan': 'layan',
    'pelayan': 'layan',
    'pelayannya': 'layan',
    'pelayani': 'layan',
    'pelayanan': 'layan',
    'melayani': 'layan',
    'melayaninya': 'layan',
    'melayanilah': 'layan',
    'melayanii': 'layan',
    'melayanimu': 'layan',
    'pelayanannya': 'layan',
    'pelayananan': 'layan',
    'pelayananmu': 'layan',
    'melayankan': 'layan',
    'dilayang': 'layang',
    'dilayangkan': 'layang',
    'dilayangkannya': 'layang',
    'dilayangi': 'layang',
    'dilayangan': 'layang',
    'melayang': 'layang',
    'melayangnya': 'layang',
    'melayanglah': 'layang',
    'melayangkan': 'layang',
    'melayangkannya': 'layang',
    'melayangan': 'layang',
    'selayang': 'layang',
    'layangan': 'layang',
    'layangannya': 'layang',
    'terlayang': 'layang',
    'pelayangan': 'layang',
    'pelayangannya': 'layang',
    'layang-layang': 'layang',
    'layang-layangnya': 'layang',
    'layang-layangan': 'layang',
    'layang-layangku': 'layang',
    'melayang-layang': 'layang',
    'terlayang-layang': 'layang',
    'melayap': 'layap',
    'melayapi': 'layap',
    'terlayap': 'layap',
    'kelayapan': 'layap',
    'melayapkan': 'layap',
    'berlayapan': 'layap',
    'melayap-layap': 'layap',
    'berlayap-layapan': 'layap',
    'melayap-layapkan': 'layap',
    'pelayar': 'layar',
    'pelayaran': 'layar',
    'melayari': 'layar',
    'melayarinya': 'layar',
    'berlayar': 'layar',
    'berlayarnya': 'layar',
    'pelayarannya': 'layar',
    'pelayaranan': 'layar',
    'melayarkan': 'layar',
    'berpelayaran': 'layar',
    'melayas': 'layas',
    'melayaskan': 'layas',
    'pelayat': 'layat',
    'pelayatnya': 'layat',
    'pelayatan': 'layat',
    'melayat': 'layat',
    'melayatlah': 'layat',
    'melayuk': 'layuk',
    'melayur': 'layur',
    'melayut': 'layut',
    'kelaziman': 'lazim',
    'kelazimannya': 'lazim',
    'melazimkan': 'lazim',
    'melebar': 'lebar',
    'melebarnya': 'lebar',
    'melebarkan': 'lebar',
    'melebarkannya': 'lebar',
    'melebari': 'lebar',
    'selebar': 'lebar',
    'selebarnya': 'lebar',
    'selebari': 'lebar',
    'selebaran': 'lebar',
    'pelebaran': 'lebar',
    'pelebarannya': 'lebar',
    'memperlebar': 'lebar',
    'memperlebarnya': 'lebar',
    'berlebaran': 'lebaran',
    'berlebaranlah': 'lebaran',
    'melebas': 'lebas',
    'melebat': 'lebat',
    'melebatnya': 'lebat',
    'melebatkan': 'lebat',
    'melebih': 'lebih',
    'melebihkan': 'lebih',
    'melebihkannya': 'lebih',
    'melebihi': 'lebih',
    'terlebih': 'lebih',
    'terlebihi': 'lebih',
    'terlebihan': 'lebih',
    'melebihinya': 'lebih',
    'melebihiku': 'lebih',
    'berlebih': 'lebih',
    'berlebihnya': 'lebih',
    'berlebihkan': 'lebih',
    'berlebihi': 'lebih',
    'berlebihan': 'lebih',
    'kelebihan': 'lebih',
    'kelebihannya': 'lebih',
    'kelebihanku': 'lebih',
    'kelebihanmu': 'lebih',
    'berlebihannya': 'lebih',
    'berlebihanlah': 'lebih',
    'berlebihanan': 'lebih',
    'selebihnya': 'lebih',
    'lebih-lebih': 'lebih',
    'lebih-lebihkan': 'lebih',
    'berkelebihan': 'lebih',
    'melebih-lebihi': 'lebih',
    'berlebih-lebih': 'lebih',
    'berlebih-lebihkan': 'lebih',
    'berlebih-lebihan': 'lebih',
    'terlebih-lebih': 'lebih',
    'berlebih-lebihannya': 'lebih',
    'melebih-lebihkan': 'lebih',
    'melebih-lebihkannya': 'lebih',
    'melebuhkan': 'lebuh',
    'melebuk': 'lebuk',
    'melebun': 'lebun',
    'leburan': 'lebur',
    'melebur': 'lebur',
    'meleburnya': 'lebur',
    'meleburkan': 'lebur',
    'meleburkannya': 'lebur',
    'terlebur': 'lebur',
    'peleburan': 'lebur',
    'peleburannya': 'lebur',
    'keleburan': 'lebur',
    'berlecah': 'lecah',
    'terlecah': 'lecah',
    'meleceh': 'leceh',
    'melecehkan': 'leceh',
    'melecehkannya': 'leceh',
    'melecehan': 'leceh',
    'peleceh': 'leceh',
    'pelecehan': 'leceh',
    'pelecehannya': 'leceh',
    'melecek': 'lecek',
    'melecekkan': 'lecek',
    'melecekan': 'lecek',
    'melecit': 'lecit',
    'melecun': 'lecun',
    'melecur': 'lecur',
    'melecurkan': 'lecur',
    'pelecut': 'lecut',
    'pelecutnya': 'lecut',
    'pelecutan': 'lecut',
    'melecut': 'lecut',
    'melecutnya': 'lecut',
    'melecutkan': 'lecut',
    'melecuti': 'lecut',
    'peledak': 'ledak',
    'peledaknya': 'ledak',
    'peledakkan': 'ledak',
    'peledakan': 'ledak',
    'ledakan': 'ledak',
    'ledakannya': 'ledak',
    'meledak': 'ledak',
    'meledaknya': 'ledak',
    'meledaklah': 'ledak',
    'meledakkan': 'ledak',
    'meledakkannya': 'ledak',
    'meledakan': 'ledak',
    'peledakannya': 'ledak',
    'meledakkanku': 'ledak',
    'terledakkan': 'ledak',
    'meledang': 'ledang',
    'meledek': 'ledek',
    'meledeknya': 'ledek',
    'meledekkan': 'ledek',
    'meledekku': 'ledek',
    'meledeki': 'ledek',
    'meledekiku': 'ledek',
    'meleding': 'leding',
    'meledos': 'ledos',
    'meleduk': 'leduk',
    'meledung': 'ledung',
    'meledungkan': 'ledung',
    'kelegaan': 'lega',
    'kelegaannya': 'lega',
    'melegakan': 'lega',
    'melegakannya': 'lega',
    'melegalkan': 'legal',
    'melegalkannya': 'legal',
    'melegalisasi': 'legalisasi',
    'melegalisasinya': 'legalisasi',
    'melegalisasikan': 'legalisasi',
    'melegalisasikannya': 'legalisasi',
    'melegenda': 'legenda',
    'melegendanya': 'legenda',
    'melegendakan': 'legenda',
    'melegendaris': 'legendaris',
    'melegitimasikan': 'legitimasi',
    'melego': 'lego',
    'melegonya': 'lego',
    'melegu': 'legu',
    'legum-legum': 'legum',
    'berlegung': 'legung',
    'berleha-leha': 'leha-leha',
    'meleja': 'leja',
    'pelejang': 'lejang',
    'melejang': 'lejang',
    'selejang': 'lejang',
    'melejangkan': 'lejang',
    'melejang-lejangkan': 'lejang',
    'melejit': 'lejit',
    'melejitnya': 'lejit',
    'melejitkan': 'lejit',
    'terleka': 'leka',
    'melekam': 'lekam',
    'melekang': 'lekang',
    'melekangkan': 'lekang',
    'melekap': 'lekap',
    'melekapkan': 'lekap',
    'melekari': 'lekar',
    'melekaskan': 'lekas',
    'selekasnya': 'lekas',
    'selekasnyalah': 'lekas',
    'lekas-lekas': 'lekas',
    'memperlekas': 'lekas',
    'berlekas-lekas': 'lekas',
    'selekas-lekasnya': 'lekas',
    'berlekas-lekasan': 'lekas',
    'lekatan': 'lekat',
    'lekatannya': 'lekat',
    'melekat': 'lekat',
    'melekatnya': 'lekat',
    'melekatlah': 'lekat',
    'melekatkan': 'lekat',
    'melekatkannya': 'lekat',
    'melekati': 'lekat',
    'terlekat': 'lekat',
    'melekatinya': 'lekat',
    'berlekat': 'lekat',
    'berlekatan': 'lekat',
    'pelekatan': 'lekat',
    'pelekatannya': 'lekat',
    'lekat-lekat': 'lekat',
    'berlekat-lekat': 'lekat',
    'melekokkan': 'lekok',
    'meleku': 'leku',
    'melekukan': 'lekuk',
    'melekuk': 'lekuk',
    'melekukkan': 'lekuk',
    'berlekuk': 'lekuk',
    'berlekuk-lekuk': 'lekuk',
    'melela': 'lela',
    'melelakan': 'lela',
    'berlela': 'lela',
    'melelah': 'lelah',
    'melelahkan': 'lelah',
    'melelahkannya': 'lelah',
    'kelelahan': 'lelah',
    'kelelahannya': 'lelah',
    'kelelahankan': 'lelah',
    'memperlelah': 'lelah',
    'melelai': 'lelai',
    'melelaikan': 'lelai',
    'melelang': 'lelang',
    'melelangnya': 'lelang',
    'melelangkan': 'lelang',
    'pelelangan': 'lelang',
    'pelelangannya': 'lelang',
    'perlelangan': 'lelang',
    'memperlelangkan': 'lelang',
    'terlelap': 'lelap',
    'terlelapnya': 'lelap',
    'melelapkan': 'lelap',
    'memperlelar': 'lelar',
    'diperlelarkan': 'lelar',
    'memperlelarkan': 'lelar',
    'melelas': 'lelas',
    'meleleh': 'leleh',
    'melelehnya': 'leleh',
    'melelehkan': 'leleh',
    'melelehkannya': 'leleh',
    'berlelehan': 'leleh',
    'meleleh-leleh': 'leleh',
    'melelepkan': 'lelep',
    'meleler': 'leler',
    'keleleran': 'leler',
    'berleleran': 'leler',
    'berlelewa': 'lelewa',
    'berleluasa': 'leluasa',
    'keleluasaan': 'leluasa',
    'keleluasaannya': 'leluasa',
    'meleluasakan': 'leluasa',
    'berlelucon': 'lelucon',
    'mengelem': 'lem',
    'mengelemnya': 'lem',
    'kelemahan': 'lemah',
    'kelemahannya': 'lemah',
    'kelemahanan': 'lemah',
    'kelemahanku': 'lemah',
    'kelemahanmu': 'lemah',
    'melemahkan': 'lemah',
    'melemahkannya': 'lemah',
    'melemahkankan': 'lemah',
    'melemahkan-mu': 'lemah',
    'memperlemahkan': 'lemah',
    'melemang': 'lemang',
    'melemaskan': 'lemas',
    'melemaskannya': 'lemas',
    'melembaga': 'lembaga',
    'melembaganya': 'lembaga',
    'melembagakan': 'lembaga',
    'melembagakannya': 'lembaga',
    'berlembaga': 'lembaga',
    'pelembagaan': 'lembaga',
    'pelembagaannya': 'lembaga',
    'kelembagaan': 'lembaga',
    'kelembagaannya': 'lembaga',
    'perlembagaan': 'lembaga',
    'melembai': 'lembai',
    'melembak': 'lembak',
    'melembakan': 'lembak',
    'melembang': 'lembang',
    'lembaran': 'lembar',
    'lembarannya': 'lembar',
    'melembarkan': 'lembar',
    'melembek': 'lembek',
    'melembekkan': 'lembek',
    'kelembekan': 'lembek',
    'melembing': 'lembing',
    'melembung': 'lembung',
    'melembungnya': 'lembung',
    'pelembungan': 'lembung',
    'melembungkan': 'lembung',
    'melembur': 'lembur',
    'melemburkan': 'lembur',
    'melempai': 'lempai',
    'terlempai': 'lempai',
    'berlempaian': 'lempai',
    'melempang': 'lempang',
    'melempangkan': 'lempang',
    'melempap': 'lempap',
    'lemparan': 'lempar',
    'lemparannya': 'lempar',
    'melempar': 'lempar',
    'melemparnya': 'lempar',
    'melemparlah': 'lempar',
    'melemparkan': 'lempar',
    'melemparkannya': 'lempar',
    'melempari': 'lempar',
    'melemparan': 'lempar',
    'melemparku': 'lempar',
    'melemparmu': 'lempar',
    'pelempar': 'lempar',
    'pelemparnya': 'lempar',
    'pelemparan': 'lempar',
    'sepelempar': 'lempar',
    'sepelemparan': 'lempar',
    'melemparkanku': 'lempar',
    'melemparkanmu': 'lempar',
    'lempar-lemparan': 'lempar',
    'berlempar-lemparan': 'lempar',
    'melempem': 'lempem',
    'melempemnya': 'lempem',
    'melempengkan': 'lempeng',
    'lemping': 'lempit',
    'melempit': 'lempit',
    'melemping': 'lempit',
    'melempuh': 'lempuh',
    'berlempuk': 'lempuk',
    'berlena': 'lena',
    'terlena': 'lena',
    'terlenanya': 'lena',
    'terlenakan': 'lena',
    'kelenaan': 'lena',
    'berlena-lena': 'lena',
    'melencangkan': 'lencang',
    'melencit': 'lencit',
    'melenda': 'lenda',
    'melendeh': 'lendeh',
    'melendot': 'lendot',
    'lendotan': 'lendot',
    'melendoti': 'lendot',
    'lendungan': 'lendung',
    'melendung': 'lendung',
    'lendutan': 'lendut',
    'melendut': 'lendut',
    'pelengah': 'lengah',
    'melengah': 'lengah',
    'melengahkan': 'lengah',
    'terlengah': 'lengah',
    'kelengahan': 'lengah',
    'kelengahannya': 'lengah',
    'memperlengah': 'lengah',
    'melengah-lengah': 'lengah',
    'berlengah-lengah': 'lengah',
    'memperlengah-lengah': 'lengah',
    'memperlengah-lengahkan': 'lengah',
    'melengak': 'lengak',
    'terlengar': 'lengar',
    'melengas': 'lengas',
    'melengaskan': 'lengas',
    'melengat': 'lengat',
    'melenge': 'lenge',
    'melenggak': 'lenggak',
    'melenggakan': 'lenggak',
    'melenggakkan': 'lenggak',
    'berlenggek': 'lenggek',
    'memperlenggekkan': 'lenggek',
    'berlenggek-lenggek': 'lenggek',
    'lenggak-lenggok': 'lenggok',
    'lenggak-lenggoknya': 'lenggok',
    'lenggok-lenggok': 'lenggok',
    'berlenggok-lenggok': 'lenggok',
    'berlenggak-lenggok': 'lenggok',
    'melenggong': 'lenggong',
    'melenggor': 'lenggor',
    'melenggut': 'lenggut',
    'lenggut-lenggut': 'lenggut',
    'pelengkap': 'lengkap',
    'pelengkapnya': 'lengkap',
    'pelengkapan': 'lengkap',
    'selengkap': 'lengkap',
    'selengkapnya': 'lengkap',
    'selengkapkan': 'lengkap',
    'melengkapi': 'lengkap',
    'melengkapinya': 'lengkap',
    'melengkapiku': 'lengkap',
    'melengkapimu': 'lengkap',
    'berlengkap': 'lengkap',
    'kelengkapan': 'lengkap',
    'kelengkapannya': 'lengkap',
    'kelengkapanan': 'lengkap',
    'pelengkapannya': 'lengkap',
    'perlengkapan': 'lengkap',
    'perlengkapannya': 'lengkap',
    'perlengkapanmu': 'lengkap',
    'berlengkapan': 'lengkap',
    'melengkapkan': 'lengkap',
    'memperlengkapi': 'lengkap',
    'memperlengkapinya': 'lengkap',
    'berlengkesa': 'lengkesa',
    'melengket': 'lengket',
    'melengketkan': 'lengket',
    'berlengket': 'lengket',
    'terlengket': 'lengket',
    'lengket-lengket': 'lengket',
    'melengking': 'lengking',
    'belengkok': 'lengkok',
    'berlengkok': 'lengkok',
    'belengkokan': 'lengkok',
    'berlengkokan': 'lengkok',
    'lengkungan': 'lengkung',
    'lengkungannya': 'lengkung',
    'melengkung': 'lengkung',
    'melengkungnya': 'lengkung',
    'melengkungkan': 'lengkung',
    'pelengkung': 'lengkung',
    'pelengkungan': 'lengkung',
    'melengkungi': 'lengkung',
    'terlengkung': 'lengkung',
    'kelengkungan': 'lengkung',
    'kelengkungannya': 'lengkung',
    'melengkur': 'lengkur',
    'melengos': 'lengos',
    'melengser': 'lengser',
    'melengserkan': 'lengser',
    'melengserkannya': 'lengser',
    'belengset': 'lengset',
    'melenguh': 'lenguh',
    'melengung': 'lengung',
    'melenja': 'lenja',
    'melenjan': 'lenjan',
    'berlenso': 'lenso',
    'melentang': 'lentang',
    'terlentang': 'lentang',
    'terlentangnya': 'lentang',
    'lentang-lentung': 'lentang',
    'melentik': 'lentik',
    'melentikkan': 'lentik',
    'melentikkannya': 'lentik',
    'melentikan': 'lentik',
    'melenting': 'lenting',
    'melentingnya': 'lenting',
    'melentingkan': 'lenting',
    'berlenting': 'lenting',
    'kelentingan': 'lenting',
    'lentang-lentok': 'lentok',
    'melentuk': 'lentuk',
    'terlentuk': 'lentuk',
    'melentukkan': 'lentuk',
    'melentung': 'lentung',
    'telentung': 'lentung',
    'melentur': 'lentur',
    'melenturnya': 'lentur',
    'melenturkan': 'lentur',
    'melenturkannya': 'lentur',
    'pelenturan': 'lentur',
    'pelenturannya': 'lentur',
    'kelenturan': 'lentur',
    'kelenturannya': 'lentur',
    'melenyeh': 'lenyeh',
    'melenyut': 'lenyut',
    'meleot': 'leot',
    'melepa': 'lepa',
    'melepakan': 'lepa',
    'terlepa': 'lepa',
    'lepa-lepa': 'lepa',
    'melepak': 'lepak',
    'terlepap': 'lepap',
    'melepek': 'lepek',
    'melepes': 'lepes',
    'melepih': 'lepih',
    'melepit': 'lepit',
    'melepoh': 'lepoh',
    'terlepoh': 'lepoh',
    'melepoti': 'lepot',
    'berlepotan': 'lepot',
    'melepuh': 'lepuh',
    'melepuhnya': 'lepuh',
    'melepuhkan': 'lepuh',
    'pelepuhan': 'lepuh',
    'melepur': 'lepur',
    'pelerai': 'lerai',
    'peleraian': 'lerai',
    'leraian': 'lerai',
    'meleraikan': 'lerai',
    'meleraikannya': 'lerai',
    'terleraikan': 'lerai',
    'melerak': 'lerak',
    'melerakan': 'lerak',
    'melerakkan': 'lerak',
    'lerang-lerang': 'lerang',
    'melereng': 'lereng',
    'lerengan': 'lereng',
    'berlereng': 'lereng',
    'lereng-lereng': 'lereng',
    'lereng-lerengnya': 'lereng',
    'leret': 'leri',
    'leretan': 'leri',
    'seleret': 'leri',
    'meleret': 'leri',
    'berleret': 'leri',
    'meleretkan': 'leri',
    'berleret-leret': 'leri',
    'melerok': 'lerok',
    'berlerot': 'lerot',
    'melesak': 'lesak',
    'melesakkan': 'lesak',
    'melesakkannya': 'lesak',
    'melesakan': 'lesak',
    'melesang': 'lesang',
    'pelesapan': 'lesap',
    'pelesapannya': 'lesap',
    'melesapkan': 'lesap',
    'lesehan': 'leseh',
    'lesehannya': 'leseh',
    'berlesehan': 'leseh',
    'melesing': 'lesing',
    'belesir': 'lesir',
    'berlesir': 'lesir',
    'melesit': 'lesit',
    'pelesit': 'lesit',
    'melesot': 'lesot',
    'pelestari': 'lestari',
    'pelestarikan': 'lestari',
    'pelestarian': 'lestari',
    'kelestarian': 'lestari',
    'kelestariannya': 'lestari',
    'pelestariannya': 'lestari',
    'melestarikan': 'lestari',
    'melestarikannya': 'lestari',
    'meletakan': 'letak',
    'meletakannya': 'leta',
    'letah-letai': 'letai',
    'meletak': 'letak',
    'meletakkan': 'letak',
    'meletakkannya': 'letak',
    'terletak': 'letak',
    'terletaknya': 'letak',
    'terletaklah': 'letak',
    'terletakan': 'letak',
    'peletakan': 'letak',
    'peletakannya': 'letak',
    'meletakkanku': 'letak',
    'meletakkanmu': 'letak',
    'beleter': 'leter',
    'peleter': 'leter',
    'meleter': 'leter',
    'meleterkan': 'leter',
    'meletik': 'letik',
    'meleting': 'leting',
    'berleting': 'leting',
    'meletis': 'letis',
    'meletos': 'letos',
    'letuk-letuk': 'letuk',
    'letum-letum': 'letum',
    'letupan': 'letup',
    'letupannya': 'letup',
    'meletup': 'letup',
    'meletupnya': 'letup',
    'meletuplah': 'letup',
    'meletupkan': 'letup',
    'meletupkannya': 'letup',
    'peletup': 'letup',
    'peletupan': 'letup',
    'letup-letup': 'letup',
    'letusan': 'letus',
    'letusannya': 'letus',
    'meletus': 'letus',
    'meletusnya': 'letus',
    'meletuslah': 'letus',
    'meletuskan': 'letus',
    'meletuskannya': 'letus',
    'meletusi': 'letus',
    'meletusan': 'letus',
    'peletusan': 'letus',
    'melever': 'lever',
    'melewa': 'lewa',
    'melewakan': 'lewa',
    'melewai': 'lewa',
    'melewar': 'lewar',
    'melewari': 'lewar',
    'melewarkan': 'lewar',
    'lewat waktu': 'terlewat',
    'leyeh-leyeh': 'leyeh',
    'meleyot': 'leyot',
    'berlezat': 'lezat',
    'kelezatan': 'lezat',
    'kelezatannya': 'lezat',
    'melezatkan': 'lezat',
    'liang-liut': 'liang',
    'liang-liuk': 'liang',
    'berliang-liuk': 'liang',
    'liaran': 'liar',
    'liarannya': 'liar',
    'meliat': 'liat',
    'meliatkan': 'liat',
    'meliau': 'liau',
    'melibas': 'libas',
    'melibasnya': 'libas',
    'pelibasan': 'libas',
    'melibat': 'libat',
    'melibatnya': 'libat',
    'melibatkan': 'libat',
    'melibatkannya': 'libat',
    'melibati': 'libat',
    'melibatan': 'libat',
    'berlibat': 'libat',
    'terlibat': 'libat',
    'terlibatnya': 'libat',
    'terlibatlah': 'libat',
    'terlibatkan': 'libat',
    'terlibatan': 'libat',
    'pelibatan': 'libat',
    'pelibatannya': 'libat',
    'melibatkankan': 'libat',
    'melibatkanku': 'libat',
    'keterlibatan': 'libat',
    'keterlibatannya': 'libat',
    'keterlibatanan': 'libat',
    'keterlibatanku': 'libat',
    'keterlibatanmu': 'libat',
    'berlibat-libat': 'libat',
    'peliberalan': 'liberal',
    'meliberalisasi': 'liberalisasi',
    'meliberalisasikan': 'liberalisasi',
    'pelicin': 'licin',
    'pelicinnya': 'licin',
    'kelicinan': 'licin',
    'kelicinannya': 'licin',
    'melicinkan': 'licin',
    'melicinkannya': 'licin',
    'berlidah': 'lidah',
    'melidahkan': 'lidah',
    'berligar-ligar': 'ligar',
    'meligas': 'ligas',
    'meligat': 'ligat',
    'meligih': 'ligih',
    'kelihaian': 'lihai',
    'kelihaiannya': 'lihai',
    'berlik': 'lik',
    'melikas': 'likas',
    'berliku-liku': 'liku',
    'berliku-likunya': 'liku',
    'melikuidasi': 'likuidasi',
    'melikuidasinya': 'likuidasi',
    'melikuidasikan': 'likuidasi',
    'likuran': 'likur',
    'berlikur-likur': 'likur',
    'melikut': 'likut',
    'melikuti': 'likut',
    'berlikut': 'likut',
    'melilah': 'lilah',
    'melilau': 'lilau',
    'melilin': 'lilin',
    'lilitan': 'lilit',
    'lilitannya': 'lilit',
    'melilit': 'lilit',
    'melilitnya': 'lilit',
    'melilitkan': 'lilit',
    'melilitkannya': 'lilit',
    'meliliti': 'lilit',
    'melilitku': 'lilit',
    'selilit': 'lilit',
    'selilitan': 'lilit',
    'berlilit': 'lilit',
    'berlilitkan': 'lilit',
    'berlima': 'lima',
    'seperlima': 'lima',
    'seperlimanya': 'lima',
    'limasan': 'limas',
    'pelimau': 'limau',
    'berlimau': 'limau',
    'melimaui': 'limau',
    'pelimbahan': 'limbah',
    'melimbai': 'limbai',
    'melimbaikan': 'limbai',
    'berlimbak-limbak': 'limbak',
    'melimbang': 'limbang',
    'pelimbang': 'limbang',
    'limbukan': 'limbuk',
    'limbungan': 'limbung',
    'melimbur': 'limbur',
    'dilimbur': 'limbur',
    'berlimpa': 'limpa',
    'limpahan': 'limpah',
    'limpahannya': 'limpah',
    'melimpah': 'limpah',
    'melimpahnya': 'limpah',
    'melimpahlah': 'limpah',
    'melimpahkan': 'limpah',
    'melimpahkannya': 'limpah',
    'melimpahi': 'limpah',
    'melimpahan': 'limpah',
    'melimpahinya': 'limpah',
    'kelimpahan': 'limpah',
    'kelimpahannya': 'limpah',
    'pelimpahan': 'limpah',
    'pelimpahannya': 'limpah',
    'melimpah-limpah': 'limpah',
    'berlimpah-limpah': 'limpah',
    'berlimpap': 'limpap',
    'berlimpap-limpap': 'limpap',
    'terlimpas': 'limpas',
    'melimpaui': 'limpau',
    'memperlimpitkan': 'limpit',
    'berlimpit-limpit': 'limpit',
    'limunan': 'limun',
    'melimut': 'limut',
    'berlinang': 'linang',
    'berlinangnya': 'linang',
    'berlinangkan': 'linang',
    'berlinangan': 'linang',
    'berlinang-linang': 'linang',
    'selincam': 'lincam',
    'melincam': 'lincam',
    'terlincir': 'lincir',
    'melincirkan': 'lincir',
    'berlindak-lindak': 'lindak',
    'melindang': 'lindang',
    'melindangkan': 'lindang',
    'melindap': 'lindap',
    'lindas': 'lindi',
    'lindasan': 'lindi',
    'pelindas': 'lindi',
    'pelindasan': 'lindi',
    'melindas': 'lindi',
    'melindasnya': 'lindi',
    'melindaskan': 'lindi',
    'melindasi': 'lindi',
    'melindasku': 'lindi',
    'melindik': 'lindik',
    'melindis': 'lindis',
    'pelindis': 'lindis',
    'melindur': 'lindur',
    'melingar': 'lingar',
    'melingarkan': 'lingar',
    'melingari': 'lingar',
    'linggisan': 'linggis',
    'melinggis': 'linggis',
    'lingkaran': 'lingkar',
    'lingkarannya': 'lingkar',
    'melingkar': 'lingkar',
    'melingkarnya': 'lingkar',
    'melingkarkan': 'lingkar',
    'melingkarkannya': 'lingkar',
    'melingkari': 'lingkar',
    'melingkarinya': 'lingkar',
    'terlingkar': 'lingkar',
    'berlingkar': 'lingkar',
    'melingkis': 'lingkis',
    'selingkung': 'lingkung',
    'selingkungan': 'lingkung',
    'melingkung': 'lingkung',
    'melingkungi': 'lingkung',
    'lingkungan': 'lingkung',
    'lingkungannya': 'lingkung',
    'lingkunganlah': 'lingkung',
    'lingkunganan': 'lingkung',
    'lingkunganku': 'lingkung',
    'lingkunganmu': 'lingkung',
    'terlingkung': 'lingkung',
    'melingkunginya': 'lingkung',
    'melingkup': 'lingkup',
    'melingkupi': 'lingkup',
    'melingkupinya': 'lingkup',
    'melingkupiku': 'lingkup',
    'terlingkup': 'lingkup',
    'terlingkupi': 'lingkup',
    'kelinglungan': 'linglung',
    'melinglungkan': 'linglung',
    'melingsirkan': 'lingsir',
    'kelinieran': 'linier',
    'melinjak': 'linjak',
    'melinjaknya': 'linjak',
    'melintah': 'lintah',
    'lintangan': 'lintang',
    'melintang': 'lintang',
    'melintangnya': 'lintang',
    'melintangkan': 'lintang',
    'melintangkannya': 'lintang',
    'melintangi': 'lintang',
    'terlintang': 'lintang',
    'lintang pukang': 'lintangan',
    'selintas': 'lintas',
    'selintasan': 'lintas',
    'lintasan': 'lintas',
    'lintasannya': 'lintas',
    'pelintas': 'lintas',
    'pelintasan': 'lintas',
    'melintas': 'lintas',
    'melintasnya': 'lintas',
    'melintaslah': 'lintas',
    'melintaskan': 'lintas',
    'melintasi': 'lintas',
    'melintasinya': 'lintas',
    'terlintas': 'lintas',
    'terlintasnya': 'lintas',
    'terlintaslah': 'lintas',
    'terlintasi': 'lintas',
    'pelintasannya': 'lintas',
    'kelintasan': 'lintas',
    'perlintasan': 'lintas',
    'perlintasannya': 'lintas',
    'melinting': 'linting',
    'lintingan': 'linting',
    'lintingannya': 'linting',
    'pelintingan': 'linting',
    'melintir': 'lintir',
    'melintirnya': 'lintir',
    'pelintuh': 'lintuh',
    'melintup': 'lintup',
    'melinyak': 'linyak',
    'berlinyak': 'linyak',
    'melinyar': 'linyar',
    'berlipat ganda': 'lipat ganda',
    'melipatgandakan': 'lipat ganda',
    'melipatgandakannya': 'lipat ganda',
    'lipatan': 'lipat',
    'lipatannya': 'lipat',
    'melipat': 'lipat',
    'melipatnya': 'lipat',
    'melipatkan': 'lipat',
    'melipati': 'lipat',
    'melipatan': 'lipat',
    'pelipat': 'lipat',
    'pelipatnya': 'lipat',
    'pelipatan': 'lipat',
    'berlipat': 'lipat',
    'berlipatnya': 'lipat',
    'berlipatlah': 'lipat',
    'kelipatan': 'lipat',
    'kelipatannya': 'lipat',
    'peliputan': 'lipat',
    'peliputannya': 'lipat',
    'perlipatan': 'lipat',
    'lipat-melipat': 'lipat',
    'berlipat-lipat': 'lipat',
    'pelipit': 'lipit',
    'pelipitan': 'lipit',
    'melipit': 'lipit',
    'melipitnya': 'lipit',
    'melipiti': 'lipit',
    'melipur': 'lipur',
    'pelipur': 'lipur',
    'melipurkan': 'lipur',
    'meliput': 'liput',
    'meliputnya': 'liput',
    'meliputi': 'liput',
    'meliputan': 'liput',
    'liputan': 'liput',
    'liputannya': 'liput',
    'meliputinya': 'liput',
    'meliputii': 'liput',
    'terliput': 'liput',
    'terliputi': 'liput',
    'lirikan': 'lirik',
    'lirikannya': 'lirik',
    'melirik': 'lirik',
    'meliriknya': 'lirik',
    'melirikkan': 'lirik',
    'melirikan': 'lirik',
    'melirikmu': 'lirik',
    'selirik': 'lirik',
    'melisankan': 'lisan',
    'berlistrik': 'listrik',
    'kelistrikan': 'listrik',
    'kelistrikannya': 'listrik',
    'perlistrikan': 'listrik',
    'perlistrikannya': 'listrik',
    'melisutkan': 'lisut',
    'literan': 'liter',
    'literannya': 'liter',
    'literanlah': 'liter',
    'melitsus': 'litsus',
    'meliuk': 'liuk',
    'meliuknya': 'liuk',
    'meliuklah': 'liuk',
    'meliukkan': 'liuk',
    'meliukan': 'liuk',
    'terliuk': 'liuk',
    'meliuki': 'liuk',
    'sepeliuk': 'liuk',
    'meliuk-liuk': 'liuk',
    'meliuk-liukkan': 'liuk',
    'meliuk-liukkannya': 'liuk',
    'meliuk-liukan': 'liuk',
    'terliuk-liuk': 'liuk',
    'meliuri': 'liur',
    'berliur': 'liur',
    'liat-liut': 'liut',
    'meloak': 'loak',
    'meloakkannya': 'loak',
    'loakan': 'loak',
    'meloakkan': 'loak',
    'pelobi': 'lobi',
    'pelobinya': 'lobi',
    'pelobian': 'lobi',
    'melobi': 'lobi',
    'melobinya': 'lobi',
    'melocok': 'locok',
    'pelocok': 'locok',
    'melocot': 'locot',
    'loh jinawi': 'loh',
    'meloka': 'loka',
    'berlokakarya': 'lokakarya',
    'melokalkan': 'lokal',
    'melokalisasi': 'lokalisasi',
    'melokalisasikan': 'lokalisasi',
    'terlokalisasi': 'lokalisasi',
    'terlokalisasikan': 'lokalisasi',
    'melokap': 'lokap',
    'berlokasi': 'lokasi',
    'berlokasinya': 'lokasi',
    'berlokasikan': 'lokasi',
    'meloloh': 'loloh',
    'melolong': 'lolong',
    'terlolong': 'lolong',
    'melolong-lolong': 'lolong',
    'terlolong-lolong': 'lolong',
    'meloloskan': 'lolos',
    'meloloskannya': 'lolos',
    'berlomba': 'lomba',
    'berlombanya': 'lomba',
    'berlombalah': 'lomba',
    'perlombaan': 'lomba',
    'perlombaannya': 'lomba',
    'berlomba-lomba': 'lomba',
    'berlomba-lombalah': 'lomba',
    'memperlombakan': 'lomba',
    'melombar': 'lombar',
    'melombong': 'lombong',
    'pelombongan': 'lombong',
    'melomot': 'lomot',
    'melompat': 'lompat',
    'melompatnya': 'lompat',
    'melompatlah': 'lompat',
    'melompatkan': 'lompat',
    'melompati': 'lompat',
    'pelompat': 'lompat',
    'pelompatan': 'lompat',
    'lompatan': 'lompat',
    'lompatannya': 'lompat',
    'lompatanku': 'lompat',
    'lompatanmu': 'lompat',
    'melompatinya': 'lompat',
    'terlompat': 'lompat',
    'terlompati': 'lompat',
    'sepelompat': 'lompat',
    'berlompatan': 'lompat',
    'sepelompatan': 'lompat',
    'melompat-lompat': 'lompat',
    'melompat-lompatlah': 'lompat',
    'berlompok-lompok': 'lompok',
    'melompong': 'lompong',
    'melompongnya': 'lompong',
    'meloncat': 'loncat',
    'meloncatnya': 'loncat',
    'meloncatlah': 'loncat',
    'meloncati': 'loncat',
    'loncatan': 'loncat',
    'loncatannya': 'loncat',
    'loncatanku': 'loncat',
    'meloncatkan': 'loncat',
    'berloncatan': 'loncat',
    'meloncat-loncat': 'loncat',
    'berloncat-loncatan': 'loncat',
    'melonceng': 'lonceng',
    'meloncer': 'loncer',
    'melonco-lonco': 'lonco',
    'melondong': 'londong',
    'melondongkan': 'londong',
    'meloneng': 'loneng',
    'melongak-longok': 'longak-longok',
    'longitudinal': 'longmars',
    'melongo': 'longo',
    'melongokan': 'longo',
    'melongok': 'longok',
    'melongoknya': 'longok',
    'melongokkan': 'longok',
    'terlongong-longong': 'longong',
    'melonjak': 'lonjak',
    'melonjaknya': 'lonjak',
    'melonjaklah': 'lonjak',
    'melonjakkan': 'lonjak',
    'melonjakan': 'lonjak',
    'terlonjak': 'lonjak',
    'pelonjakan': 'lonjak',
    'melonjak-lonjak': 'lonjak',
    'melonjak-lonjakkan': 'lonjak',
    'lonjoran': 'lonjor',
    'terlonsong': 'lonsong',
    'melontai': 'lontai',
    'melontar': 'lontar',
    'melontarnya': 'lontar',
    'melontarkan': 'lontar',
    'melontarkannya': 'lontar',
    'melontari': 'lontar',
    'lontaran': 'lontar',
    'lontarannya': 'lontar',
    'pelontar': 'lontar',
    'pelontarnya': 'lontar',
    'pelontaran': 'lontar',
    'sepelontar': 'lontar',
    'berlontaran': 'lontar',
    'melontarkankan': 'lontar',
    'berlopak': 'lopak',
    'lopak-lopak': 'lopak',
    'lopak-lapik': 'lopak',
    'berlopak-lopak': 'lopak',
    'melorot': 'lorot',
    'melorotnya': 'lorot',
    'melorotkan': 'lorot',
    'meloroti': 'lorot',
    'mengeloskan': 'los',
    'meloso': 'loso',
    'melotrekan': 'lotre',
    'melotrekannya': 'lotre',
    'lowongan': 'lowong',
    'lowongannya': 'lowong',
    'melowongkan': 'lowong',
    'meloya': 'loya',
    'keloyoan': 'loyo',
    'meloyong': 'loyong',
    'meluah': 'luah',
    'meluahkan': 'luah',
    'meluaki': 'luak',
    'meluang': 'luang',
    'meluangkan': 'luang',
    'meluangkannya': 'luang',
    'meluangan': 'luang',
    'peluang': 'luang',
    'peluangnya': 'luang',
    'peluanglah': 'luang',
    'peluangan': 'luang',
    'peluangku': 'luang',
    'peluangmu': 'luang',
    'terluang': 'luang',
    'keluangan': 'luang',
    'meluangkankan': 'luang',
    'meluap': 'luap',
    'meluapnya': 'luap',
    'meluaplah': 'luap',
    'meluapkan': 'luap',
    'meluapkannya': 'luap',
    'meluapi': 'luap',
    'luapan': 'luap',
    'luapannya': 'luap',
    'luaran': 'luar',
    'luarannya': 'luar',
    'meluar': 'luar',
    'meluarkan': 'luar',
    'meluarkannya': 'luar',
    'meluat': 'luat',
    'meluber': 'luber',
    'melubernya': 'luber',
    'meluberkan': 'luber',
    'meluberi': 'luber',
    'melucu': 'lucu',
    'melucunya': 'lucu',
    'berlucu': 'lucu',
    'kelucuan': 'lucu',
    'kelucuannya': 'lucu',
    'melucup': 'lucup',
    'melucut': 'lucut',
    'melucuti': 'lucut',
    'lucutan': 'lucut',
    'terlucut': 'lucut',
    'terlucuti': 'lucut',
    'melucutinya': 'lucut',
    'melucutkan': 'lucut',
    'perlucutan': 'lucut',
    'kelugasan': 'lugas',
    'kelugasannya': 'lugas',
    'keluguan': 'lugu',
    'keluguannya': 'lugu',
    'keluhuran': 'luhur',
    'keluhurannya': 'luhur',
    'meluhurkan': 'luhur',
    'meluik': 'luik',
    'berluk': 'luk',
    'melukai': 'luka',
    'melukainya': 'luka',
    'melukaiku': 'luka',
    'melukaimu': 'luka',
    'terluka': 'luka',
    'terlukanya': 'luka',
    'terlukai': 'luka',
    'pelukaan': 'luka',
    'perlukaan': 'luka',
    'melukah': 'lukah',
    'melukat': 'lukat',
    'lukisan': 'lukis',
    'lukisannya': 'lukis',
    'lukisanku': 'lukis',
    'lukisanmu': 'lukis',
    'pelukis': 'lukis',
    'pelukisnya': 'lukis',
    'pelukisan': 'lukis',
    'pelukismu': 'lukis',
    'melukis': 'lukis',
    'melukisnya': 'lukis',
    'melukiskan': 'lukis',
    'melukiskannya': 'lukis',
    'melukisi': 'lukis',
    'melukisan': 'lukis',
    'terlukis': 'lukis',
    'terlukiskan': 'lukis',
    'meluku': 'luku',
    'melukukan': 'luku',
    'meluli': 'luli',
    'luluhan': 'luluh',
    'meluluhkan': 'luluh',
    'meluluhkannya': 'luluh',
    'meluluhlantakkan': 'luluh lantak',
    'meluluhlantakkannya': 'luluh lantak',
    'meluluk': 'luluk',
    'melulukan': 'luluk',
    'peluluk': 'luluk',
    'pelulukan': 'luluk',
    'terluluk': 'luluk',
    'berluluk': 'luluk',
    'melulum': 'lulum',
    'melulur': 'lulur',
    'melulurkan': 'lulur',
    'meluluri': 'lulur',
    'selulus': 'lulus',
    'selulusnya': 'lulus',
    'lulusan': 'lulus',
    'lulusannya': 'lulus',
    'melulusi': 'lulus',
    'kelulusan': 'lulus',
    'kelulusannya': 'lulus',
    'kelulusanmu': 'lulus',
    'selulusan': 'lulus',
    'meluluskan': 'lulus',
    'meluluskannya': 'lulus',
    'melulut': 'lulut',
    'pelulut': 'lulut',
    'berlulut': 'lulut',
    'berlumang': 'lumang',
    'melumangkan': 'lumang',
    'melumari': 'lumar',
    'berlumar': 'lumar',
    'pelumas': 'lumas',
    'pelumasnya': 'lumas',
    'pelumaslah': 'lumas',
    'pelumasan': 'lumas',
    'melumas': 'lumas',
    'melumaskan': 'lumas',
    'melumasi': 'lumas',
    'lumatan': 'lumat',
    'pelumat': 'lumat',
    'melumatkan': 'lumat',
    'melumatkannya': 'lumat',
    'lumayan': 'lumbago',
    'lumayanlah': 'lumbago',
    'melumer': 'lumer',
    'melumerkan': 'lumer',
    'melumeri': 'lumer',
    'pelumer': 'lumer',
    'pelumeran': 'lumer',
    'melumpukkan': 'lumpuk',
    'kelumrahan': 'lumrah',
    'berlumus': 'lumus',
    'pelunak': 'lunak',
    'pelunakan': 'lunak',
    'melunak': 'lunak',
    'melunaknya': 'lunak',
    'melunakkan': 'lunak',
    'melunakkannya': 'lunak',
    'melunakan': 'lunak',
    'melunaki': 'lunak',
    'kelunakan': 'lunak',
    'memperlunak': 'lunak',
    'lunasan': 'lunas',
    'melunasi': 'lunas',
    'melunasinya': 'lunas',
    'melunaskan': 'lunas',
    'melunaskannya': 'lunas',
    'pelunauan': 'lunau',
    'meluncungkan': 'luncung',
    'peluncur': 'luncur',
    'peluncurnya': 'luncur',
    'peluncurkan': 'luncur',
    'peluncurkannya': 'luncur',
    'peluncuran': 'luncur',
    'meluncur': 'luncur',
    'meluncurnya': 'luncur',
    'meluncurlah': 'luncur',
    'meluncurkan': 'luncur',
    'meluncurkannya': 'luncur',
    'meluncuran': 'luncur',
    'meluncuri': 'luncur',
    'terluncur': 'luncur',
    'peluncurannya': 'luncur',
    'berseluncur': 'luncur',
    'meluncurkankan': 'luncur',
    'pelungguh': 'lungguh',
    'melungguh': 'lungguh',
    'terlungsar': 'lungsar',
    'lungsungan': 'lungsung',
    'melungsung': 'lungsung',
    'lungsuran': 'lungsur',
    'melungsur': 'lungsur',
    'melungsurkan': 'lungsur',
    'terlunjur': 'lunjur',
    'berlunjur': 'lunjur',
    'melunjurkan': 'lunjur',
    'terlunta': 'lunta',
    'terluntanya': 'lunta',
    'terlunta-lunta': 'lunta',
    'terlunta-luntanya': 'lunta',
    'peluntur': 'luntur',
    'pelunturan': 'luntur',
    'meluntur': 'luntur',
    'melunturnya': 'luntur',
    'melunturkan': 'luntur',
    'melunturi': 'luntur',
    'kelunturan': 'luntur',
    'melunyah': 'lunyah',
    'pelupa': 'lupa',
    'pelupanya': 'lupa',
    'terlupa': 'lupa',
    'terlupakan': 'lupa',
    'terlupakannya': 'lupa',
    'melupai': 'lupa',
    'kelupaan': 'lupa',
    'melupakan': 'lupa',
    'melupakannya': 'lupa',
    'melupakanku': 'lupa',
    'melupakanmu': 'lupa',
    'lupa-lupaan': 'lupa',
    'lupa-lupa ingat': 'lupa',
    'pelupuh': 'lupuh',
    'melupuh': 'lupuh',
    'melupuhkan': 'lupuh',
    'terluput': 'luput',
    'terluputkan': 'luput',
    'meluputkan': 'luput',
    'berlurah': 'lurah',
    'kelurahan': 'lurah',
    'kelurahannya': 'lurah',
    'kelurahani': 'lurah',
    'kelurahanan': 'lurah',
    'meluru': 'luru',
    'melurukan': 'luru',
    'luruban': 'lurub',
    'melurubi': 'lurub',
    'meluruh': 'luruh',
    'meluruhnya': 'luruh',
    'meluruhkan': 'luruh',
    'meluruhkannya': 'luruh',
    'peluruh': 'luruh',
    'peluruhnya': 'luruh',
    'peluruhan': 'luruh',
    'peluruhannya': 'luruh',
    'melurut': 'lurut',
    'berlusin': 'lusin',
    'berlusin-lusin': 'lusin',
    'melusuh': 'lusuh',
    'kelusuhan': 'lusuh',
    'kelusuhannya': 'lusuh',
    'melusuhkan': 'lusuh',
    'meluti': 'luti',
    'melutu': 'lutu',
    'berlutu': 'lutu',
    'bersilutu': 'lutu',
    'meluwengkan': 'luweng',
    'keluwesan': 'luwes',
    'keluwesannya': 'luwes',
    'meluweskan': 'luwes',
    'meluyut': 'luyut',
    'berluyutan': 'luyut',
    'pemaaf': 'maaf',
    'pemaafnya': 'maaf',
    'pemaafan': 'maaf',
    'memaafi': 'maaf',
    'pemaafannya': 'maaf',
    'permaafan': 'maaf',
    'memaafkan': 'maaf',
    'memaafkannya': 'maaf',
    'memaafkanlah': 'maaf',
    'memaafkanku': 'maaf',
    'memaafkanmu': 'maaf',
    'maaf-memaafkan': 'maaf',
    'bermaaf-maafan': 'maaf',
    'dimabuk': 'mabuk',
    'dimabukkan': 'mabuk',
    'pemabuk': 'mabuk',
    'memabukkan': 'mabuk',
    'mabuk-mabukan': 'mabuk',
    'mabuk-mabukannya': 'mabuk',
    'bermabuk-mabukan': 'mabuk',
    'mabul-mabul': 'mabul',
    'semacam': 'macam',
    'semacamnya': 'macam',
    'semacaman': 'macam',
    'semacamnyalah': 'macam',
    'bermacam': 'macam',
    'macam-macam': 'macam',
    'macam-macamnya': 'macam',
    'macam-macamlah': 'macam',
    'bermacam-macam': 'macam',
    'bermacam-macamlah': 'macam',
    'mempermacam-macamkan': 'macam',
    'memacani': 'macan',
    'macan-macanan': 'macan',
    'pemacet': 'macet',
    'kemacetan': 'macet',
    'kemacetannya': 'macet',
    'kemacetanlah': 'macet',
    'kemacetankan': 'macet',
    'kemacetanan': 'macet',
    'memacetkan': 'macet',
    'pemadah': 'madah',
    'bermadah': 'madah',
    'memadahkan': 'madah',
    'bermadat': 'madat',
    'bermadu': 'madu',
    'memadui': 'madu',
    'permaduan': 'madu',
    'mempermadukan': 'madu',
    'memafhumi': 'mafhum',
    'pemafiaan': 'mafia',
    'bermagang': 'magang',
    'permahadutaan': 'mahaduta',
    'kemahalan': 'mahal',
    'kemahalannya': 'mahal',
    'memahalkan': 'mahal',
    'kemaharajaan': 'maharaja',
    'bersimaharajalela': 'maharajalela',
    'kemahasiswaan': 'mahasiswa',
    'kemahasiswaannya': 'mahasiswa',
    'memahfuzkan': 'mahfuz',
    'memahkotai': 'mahkota',
    'memahkotainya': 'mahkota',
    'bermahkota': 'mahkota',
    'bermahkotakan': 'mahkota',
    'pemahkotaan': 'mahkota',
    'mainan': 'main',
    'mainannya': 'main',
    'mainanlah': 'main',
    'mainani': 'main',
    'mainanan': 'main',
    'mainanku': 'main',
    'mainanmu': 'main',
    'pemain': 'main',
    'pemainnya': 'main',
    'pemainlah': 'main',
    'pemaini': 'main',
    'pemainan': 'main',
    'pemainku': 'main',
    'pemainmu': 'main',
    'bermain': 'main',
    'bermainnya': 'main',
    'bermainlah': 'main',
    'bermainkan': 'main',
    'bermaini': 'main',
    'bermainan': 'main',
    'bermainku': 'main',
    'bermainmu': 'main',
    'memainkan': 'main',
    'memainkannya': 'main',
    'memainkankan': 'main',
    'memainkannyalah': 'main',
    'memainkanku': 'main',
    'memainkanmu': 'main',
    'main-main': 'main',
    'main-mainnya': 'main',
    'main-mainlah': 'main',
    'main-mainkan': 'main',
    'main-mainan': 'main',
    'permainan': 'main',
    'permainannya': 'main',
    'permainanlah': 'main',
    'permainani': 'main',
    'permainanan': 'main',
    'permainannyalah': 'main',
    'permainanku': 'main',
    'permainanmu': 'main',
    'sepermainan': 'main',
    'sepermainannya': 'main',
    'bermain-main': 'main',
    'bermain-mainlah': 'main',
    'mempermainkan': 'main',
    'mempermainkannya': 'main',
    'mempermainkanku': 'main',
    'memajalkan': 'majal',
    'kemajemukan': 'majemuk',
    'kemajemukannya': 'majemuk',
    'kemajiran': 'majir',
    'memajuh': 'pajuh',
    'pemakalah': 'makalah',
    'bermakam': 'makam',
    'pemakaman': 'makam',
    'pemakamannya': 'makam',
    'pemakamanlah': 'makam',
    'pemakamanan': 'makam',
    'pemakamanku': 'makam',
    'permakaman': 'makam',
    'permakamannya': 'makam',
    'memakamkan': 'makam',
    'memakamkannya': 'makam',
    'memakbulkan': 'makbul',
    'memaki': 'maki',
    'memakinya': 'maki',
    'memakilah': 'maki',
    'memakian': 'maki',
    'memakiku': 'maki',
    'memakimu': 'maki',
    'makian': 'maki',
    'makiannya': 'maki',
    'memaki-maki': 'maki',
    'memaki-makinya': 'maki',
    'maki-makian': 'maki',
    'semakin': 'makin',
    'semakini': 'makin',
    'memaklumi': 'maklum',
    'memakluminya': 'maklum',
    'pemakluman': 'maklum',
    'pemaklumannya': 'maklum',
    'memaklumkan': 'maklum',
    'mempermaklumkan': 'maklum',
    'memaklumatkan': 'maklumat',
    'bermakmum': 'makmum',
    'memakmumi': 'makmum',
    'bermakrifat': 'makrifat',
    'kemaksiatan': 'maksiat',
    'kemaksiatannya': 'maksiat',
    'kemaksimalan': 'maksimal',
    'semaksimalnya': 'maksimal',
    'memaksimalkan': 'maksimal',
    'memaksimalkannya': 'maksimal',
    'semaksimal mungkin': 'maksimal',
    'semaksimal-maksimalnya': 'maksimal',
    'termaktub': 'maktub',
    'termaktubkan': 'maktub',
    'pemakzulan': 'makzul',
    'pemakzulannya': 'makzul',
    'memakzulkan': 'makzul',
    'memakzulkannya': 'makzul',
    'termala': 'mala',
    'malahan': 'malah',
    'memalai': 'palai',
    'malai-malai': 'malai',
    'bermalaikan': 'malai',
    'memalangi': 'palang',
    'kemalangan': 'malang',
    'kemalangannya': 'malang',
    'malaran': 'malar',
    'malar-malar': 'malar',
    'pemaling': 'maling',
    'memaling': 'maling',
    'memalingkan': 'paling',
    'memalingkannya': 'paling',
    'kemalingan': 'maling',
    'pemalu': 'malu',
    'pemalunya': 'malu',
    'pemaluan': 'malu',
    'pemalumu': 'malu',
    'memalui': 'palu',
    'bermalu': 'malu',
    'kemaluan': 'malu',
    'kemaluannya': 'malu',
    'kemaluanku': 'malu',
    'kemaluanmu': 'malu',
    'memalukan': 'palu',
    'memalukannya': 'palu',
    'malu-malu': 'malu',
    'malu-malunya': 'malu',
    'malu-malui': 'malu',
    'kemalu-maluan': 'malu',
    'mempermalukan': 'malu',
    'mempermalukannya': 'malu',
    'mamahan': 'mamah',
    'mamahani': 'mamah',
    'memamah': 'mamah',
    'memamahi': 'mamah',
    'pemamah': 'mamah',
    'pemamahan': 'mamah',
    'memamahkan': 'mamah',
    'bermamai': 'mamai',
    'semampu': 'mampu',
    'semampunya': 'mampu',
    'semampuku': 'mampu',
    'semampumu': 'mampu',
    'kemampuan': 'mampu',
    'kemampuannya': 'mampu',
    'kemampuanlah': 'mampu',
    'kemampuanku': 'mampu',
    'kemampuanmu': 'mampu',
    'berkemampuan': 'mampu',
    'mana-mana': 'mana',
    'mana-mananya': 'mana',
    'bermanah': 'manah',
    'memanajemeni': 'manajemen',
    'memanau': 'manau',
    'termandam': 'mandam',
    'kemandekan': 'mandek',
    'kemandekannya': 'mandek',
    'memandekkan': 'mandek',
    'bermandi': 'mandi',
    'bermandikan': 'mandi',
    'bermandian': 'mandi',
    'pemandian': 'mandi',
    'pemandiannya': 'mandi',
    'memandikan': 'mandi',
    'memandikannya': 'mandi',
    'memandikanku': 'mandi',
    'permandian': 'mandi',
    'mempermandikan': 'mandi',
    'kemandirian': 'mandiri',
    'kemandiriannya': 'mandiri',
    'kemandirianmu': 'mandiri',
    'memandori': 'mandor',
    'kemandulan': 'mandul',
    'kemandulannya': 'mandul',
    'pemandulan': 'mandul',
    'pemandulannya': 'mandul',
    'memandulkan': 'mandul',
    'memandulkannya': 'mandul',
    'termangau': 'mangau',
    'pemangkir': 'mangkir',
    'pemangkiran': 'mangkir',
    'semangkuk': 'mangkuk',
    'memangsa': 'mangsa',
    'memangsanya': 'mangsa',
    'pemangsa': 'mangsa',
    'pemangsanya': 'mangsa',
    'pemangsaan': 'mangsa',
    'termangu': 'mangu',
    'termangu-mangu': 'mangu',
    'termanifestasi': 'manifestasi',
    'termanifestasikan': 'manifestasi',
    'memanifestasikan': 'manifestasi',
    'memanifestasikannya': 'manifestasi',
    'manik-manik': 'manik',
    'manik-maniknya': 'manik',
    'bermanik-manik': 'manik',
    'memanipulasi': 'manipulasi',
    'memanipulasinya': 'manipulasi',
    'memanipulasikan': 'manipulasi',
    'memanipulasiku': 'manipulasi',
    'pemanipulasian': 'manipulasi',
    'memanis': 'manis',
    'memaniskan': 'manis',
    'semanis': 'manis',
    'manisan': 'manis',
    'manisannya': 'manis',
    'pemanis': 'manis',
    'pemanisnya': 'manis',
    'bermanis': 'manis',
    'memanisi': 'manis',
    'kemanisan': 'manis',
    'kemanisannya': 'manis',
    'mempermanis': 'manis',
    'mempermanisnya': 'manis',
    'manis-manisan': 'manis',
    'memanis-manis': 'manis',
    'memanis-maniskan': 'manis',
    'bermanis-manis': 'manis',
    'semanis-manisnya': 'manis',
    'kemanjaan': 'manja',
    'kemanjaannya': 'manja',
    'memanjakan': 'manja',
    'memanjakannya': 'manja',
    'memanjakanan': 'manja',
    'memanjakanku': 'manja',
    'memanjakanmu': 'manja',
    'bermanja-manja': 'manja',
    'bermanja-manjaan': 'manja',
    'termanja-manja': 'manja',
    'mempermanjakan': 'manja',
    'kemanja-manjaan': 'manja',
    'bermanjau': 'manjau',
    'manjungan': 'manjung',
    'permanjungan': 'manjung',
    'memansukhkan': 'mansukh',
    'pemantapan': 'mantap',
    'pemantapannya': 'mantap',
    'kemantapan': 'mantap',
    'kemantapannya': 'mantap',
    'memantapkan': 'mantap',
    'memantapkannya': 'mantap',
    'bermantel': 'mantel',
    'memantrai': 'mantra',
    'memantrakan': 'mantra',
    'kemanunggalan': 'manunggal',
    'memanusiawikan': 'manusiawi',
    'manutan': 'manut',
    'bermanuver': 'manuver',
    'bermanuvernya': 'manuver',
    'bermanuverlah': 'manuver',
    'kemapanan': 'mapan',
    'kemapanannya': 'mapan',
    'bermara': 'mara',
    'kemaraan': 'mara',
    'memarakan': 'marak',
    'pemarah': 'marah',
    'pemarahnya': 'marah',
    'pemarahku': 'marah',
    'marahan': 'marah',
    'memarahi': 'marah',
    'memarahinya': 'marah',
    'memarahiku': 'marah',
    'kemarahan': 'marah',
    'kemarahannya': 'marah',
    'kemarahanan': 'marah',
    'kemarahanku': 'marah',
    'kemarahanmu': 'marah',
    'memarahkan': 'marah',
    'marah-marah': 'marah',
    'marah-marahnya': 'marah',
    'marah-marahlah': 'marah',
    'marah-marahi': 'marah',
    'marah-marahan': 'marah',
    'kemarah-marahan': 'marah',
    'memarak': 'marak',
    'memarakkan': 'parak',
    'semarak': 'marak',
    'semaraknya': 'marak',
    'semarakkan': 'marak',
    'semarakan': 'marak',
    'memarginalkan': 'marginal',
    'memarinade': 'marinade',
    'kemaritiman': 'maritim',
    'kemaritimannya': 'maritim',
    'kemaritimanan': 'maritim',
    'pemarkah': 'markah',
    'memarkahi': 'markah',
    'pemarkahan': 'markah',
    'bermarkas': 'markas',
    'bermarkasnya': 'markas',
    'bermarkaskan': 'markas',
    'bermarkasi': 'markas',
    'bermartabat': 'martabat',
    'bermartabatnya': 'martabat',
    'bermartabatlah': 'martabat',
    'kemasabodohan': 'masa bodoh',
    'memasabodohkan': 'masa bodoh',
    'semasa': 'masa',
    'semasanya': 'masa',
    'termasa': 'masa',
    'semasa-masa': 'masa',
    'memasak': 'pasak',
    'memasaknya': 'pasak',
    'memasaklah': 'pasak',
    'memasakkan': 'pasak',
    'memasakkannya': 'pasak',
    'memasaki': 'pasak',
    'memasakan': 'pasak',
    'memasakku': 'pasak',
    'memasakmu': 'pasak',
    'masakan': 'masak',
    'masakannya': 'masak',
    'masakanan': 'masak',
    'masakanku': 'masak',
    'masakanmu': 'masak',
    'pemasak': 'masak',
    'pemasaknya': 'masak',
    'pemasakan': 'masak',
    'pemasakannya': 'masak',
    'kemasakan': 'masak',
    'kemasakannya': 'masak',
    'masak-masak': 'masak',
    'masak-masaknya': 'masak',
    'masak-masakan': 'masak',
    'memasak-masak': 'masak',
    'bermasak-masak': 'masak',
    'memasalahkan': 'masalah',
    'memasalahkannya': 'masalah',
    'permasalahan': 'masalah',
    'permasalahannya': 'masalah',
    'permasalahanku': 'masalah',
    'mempermasalahkan': 'masalah',
    'mempermasalahkannya': 'masalah',
    'memasam': 'masam',
    'memasamkan': 'masam',
    'kemasam-masaman': 'masam',
    'bermasam muka': 'masam muka',
    'memasap': 'masap',
    'memaserasi': 'maserasi',
    'semasih': 'masih',
    'kemasinan': 'masin',
    'permasjidan': 'masjid',
    'memaskotkan': 'maskot',
    'kemaslahatan': 'maslahat',
    'kemaslahatannya': 'maslahat',
    'memasyarakat': 'masyarakat',
    'memasyarakatnya': 'masyarakat',
    'memasyarakatkan': 'masyarakat',
    'memasyarakatkannya': 'masyarakat',
    'memasyarakatan': 'masyarakat',
    'bermasyarakat': 'masyarakat',
    'bermasyarakatnya': 'masyarakat',
    'pemasyarakatan': 'masyarakat',
    'pemasyarakatannya': 'masyarakat',
    'kemasyarakatan': 'masyarakat',
    'kemasyarakatannya': 'masyarakat',
    'kemasyarakatanlah': 'masyarakat',
    'permasyarakatan': 'masyarakat',
    'permasyarakatannya': 'masyarakat',
    'kemasygulan': 'masygul',
    'memasygulkan': 'masygul',
    'mat-matan': 'mat',
    'memata-matai': 'mata-mata',
    'memata-matainya': 'mata-mata',
    'pemata-mataan': 'mata-mata',
    'termateri': 'materi',
    'semati': 'mati',
    'kematian': 'mati',
    'kematiannya': 'mati',
    'kematianku': 'mati',
    'kematianmu': 'mati',
    'bermatian': 'mati',
    'mematikan': 'patik',
    'mematikannya': 'mati',
    'mati-mati': 'mati',
    'mati-matian': 'mati',
    'bermatikan': 'mati',
    'mati-matianlah': 'mati',
    'bermati-mati': 'mati',
    'kemati-matian': 'mati',
    'kematraan': 'matra',
    'mematukan': 'matu',
    'semau': 'mau',
    'semaunya': 'mau',
    'semaumu': 'mau',
    'memaui': 'mau',
    'maupun': 'mau',
    'maupunnya': 'mau',
    'kemauan': 'mau',
    'kemauannya': 'mau',
    'kemauanlah': 'mau',
    'kemauanan': 'mau',
    'kemauanku': 'mau',
    'kemauanmu': 'mau',
    'memaukan': 'mau',
    'memau-mau': 'mau',
    'semau-maunya': 'mau',
    'maupun': 'mau',
    'bermaulid': 'maulid',
    'bermaulidurasul': 'maulidurasul',
    'mauludan': 'maulud',
    'permautan': 'maut',
    'kemayaan': 'maya',
    'maya-maya': 'maya',
    'pemayang': 'mayang',
    'semayang': 'mayang',
    'bermayang': 'mayang',
    'bermazhab': 'mazhab',
    'termazkur': 'mazkur',
    'bermazmur': 'mazmur',
    'bermeditasi': 'meditasi',
    'bermeditasilah': 'meditasi',
    'meger-meger': 'meger',
    'dimejahijaukan': 'meja hijau',
    'dimejahijaukannya': 'meja hijau',
    'pemekaran': 'mekar',
    'pemekarannya': 'mekar',
    'bermekaran': 'mekar',
    'bermekarannya': 'mekar',
    'memekarkan': 'mekar',
    'memelas': 'pelas',
    'memelasnya': 'pelas',
    'melek-melekan': 'melek',
    'kemelikan': 'melik',
    'memacak': 'pacak',
    'terpacak': 'pacak',
    'memacakkan': 'pacak',
    'memacak-macak': 'pacak',
    'memagar': 'pagar',
    'memagarnya': 'pagar',
    'memagarkan': 'pagar',
    'memagari': 'pagar',
    'berpagar': 'pagar',
    'berpagarkan': 'pagar',
    'memagarinya': 'pagar',
    'pagutan': 'pagut',
    'pagutannya': 'pagut',
    'memagut': 'pagut',
    'berpagut': 'pagut',
    'berpagutan': 'pagut',
    'sepemagutan': 'pagut',
    'pakaian': 'pakai',
    'pakaiannya': 'pakai',
    'pakaianlah': 'pakai',
    'pakaianku': 'pakai',
    'pakaianmu': 'pakai',
    'memakai': 'pakai',
    'memakainya': 'pakai',
    'memakaikan': 'pakai',
    'memakaikannya': 'pakai',
    'memakaian': 'pakai',
    'pemakai': 'pakai',
    'pemakainya': 'pakai',
    'pemakaikan': 'pakai',
    'pemakaian': 'pakai',
    'terpakai': 'pakai',
    'terpakainya': 'pakai',
    'sepemakai': 'pakai',
    'pemakaiannya': 'pakai',
    'memakaikanku': 'pakai',
    'berpakaian': 'pakai',
    'berpakaiannya': 'pakai',
    'berpakaianlah': 'pakai',
    'berpakaianan': 'pakai',
    'berpakaianmu': 'pakai',
    'pemakal': 'pakal',
    'memakal': 'pakal',
    'memaku': 'paku',
    'memakunya': 'paku',
    'memakukan': 'paku',
    'berpaku': 'paku',
    'terpaku': 'paku',
    'terpakunya': 'paku',
    'keterpakuan': 'paku',
    'memampang': 'pampang',
    'memampangnya': 'pampang',
    'memampangkan': 'pampang',
    'memampangkannya': 'pampang',
    'terpampang': 'pampang',
    'terpampangnya': 'pampang',
    'terpampanglah': 'pampang',
    'pemanah': 'panah',
    'pemanahnya': 'panah',
    'pemanahan': 'panah',
    'memanah': 'panah',
    'memanahnya': 'panah',
    'memanahkan': 'panah',
    'panahan': 'panah',
    'panahannya': 'panah',
    'panahanan': 'panah',
    'memanahi': 'panah',
    'sepemanah': 'panah',
    'pancangan': 'pancang',
    'memancang': 'pancang',
    'memancangnya': 'pancang',
    'memancangkan': 'pancang',
    'terpancang': 'pancang',
    'pemancar': 'pancar',
    'pemancarnya': 'pancar',
    'pemancaran': 'pancar',
    'sepancar': 'pancar',
    'pancaran': 'pancar',
    'pancarannya': 'pancar',
    'memancar': 'pancar',
    'memancarnya': 'pancar',
    'memancarkan': 'pancar',
    'memancarkannya': 'pancar',
    'memancaran': 'pancar',
    'terpancar': 'pancar',
    'terpancarnya': 'pancar',
    'terpancarkan': 'pancar',
    'berpancaran': 'pancar',
    'pancingan': 'pancing',
    'pancingannya': 'pancing',
    'memancing': 'pancing',
    'memancingnya': 'pancing',
    'memancinglah': 'pancing',
    'memancingan': 'pancing',
    'pemancing': 'pancing',
    'pemancingan': 'pancing',
    'terpancing': 'pancing',
    'terpancinglah': 'pancing',
    'kepancingan': 'pancing',
    'pemancingannya': 'pancing',
    'memancung': 'pancung',
    'memancungnya': 'pancung',
    'memancungkan': 'pancung',
    'pemancung': 'pancung',
    'pemancungan': 'pancung',
    'memancur': 'pancur',
    'memancurkan': 'pancur',
    'pancuran': 'pancur',
    'pancurannya': 'pancur',
    'berpancuran': 'pancur',
    'memancut': 'pancut',
    'sememangnya': 'memang',
    'pemanggil': 'panggil',
    'pemanggilan': 'panggil',
    'panggilan': 'panggil',
    'panggilannya': 'panggil',
    'panggilanku': 'panggil',
    'panggilanmu': 'panggil',
    'memanggil': 'panggil',
    'memanggilnya': 'panggil',
    'memanggilkan': 'panggil',
    'memanggilkannya': 'panggil',
    'memanggili': 'panggil',
    'memanggilan': 'panggil',
    'memanggilku': 'panggil',
    'memanggilmu': 'panggil',
    'terpanggil': 'panggil',
    'terpanggilnya': 'panggil',
    'pemanggilannya': 'panggil',
    'sepemanggil': 'panggil',
    'memanggil-manggil': 'panggil',
    'memanggil-manggilnya': 'panggil',
    'memanggil-manggilku': 'panggil',
    'memangkas': 'pangkas',
    'memangkasnya': 'pangkas',
    'memangkaskan': 'pangkas',
    'memangkasi': 'pangkas',
    'memangkasan': 'pangkas',
    'pemangkas': 'pangkas',
    'pemangkasan': 'pangkas',
    'pangkasan': 'pangkas',
    'berpangkas': 'pangkas',
    'pemangkasannya': 'pangkas',
    'memantak': 'pantak',
    'memantakkan': 'pantak',
    'pantangan': 'pantang',
    'pantangannya': 'pantang',
    'pantanganku': 'pantang',
    'pantanganmu': 'pantang',
    'memantang': 'pantang',
    'memantangkan': 'pantang',
    'memantangi': 'pantang',
    'berpantang': 'pantang',
    'berpantangan': 'pantang',
    'pantulan': 'pantul',
    'pantulannya': 'pantul',
    'memantul': 'pantul',
    'memantulnya': 'pantul',
    'memantulkan': 'pantul',
    'memantulkannya': 'pantul',
    'pemantulan': 'pantul',
    'memantulkanku': 'pantul',
    'memapar': 'papar',
    'memaparkan': 'papar',
    'memaparkannya': 'papar',
    'memaparan': 'papar',
    'paparan': 'papar',
    'paparannya': 'papar',
    'pemaparan': 'papar',
    'pemaparannya': 'papar',
    'pemaparankan': 'papar',
    'berparak': 'parak',
    'terpasak': 'pasak',
    'pasangan': 'pasang',
    'pasangannya': 'pasang',
    'pasanganlah': 'pasang',
    'pasanganan': 'pasang',
    'pasangannyalah': 'pasang',
    'pasanganku': 'pasang',
    'pasanganmu': 'pasang',
    'pemasang': 'pasang',
    'pemasangnya': 'pasang',
    'pemasangan': 'pasang',
    'memasang': 'pasang',
    'memasangnya': 'pasang',
    'memasangkan': 'pasang',
    'memasangkannya': 'pasang',
    'memasangi': 'pasang',
    'memasangan': 'pasang',
    'sepasang': 'pasang',
    'sepasangnya': 'pasang',
    'sepasangan': 'pasang',
    'berpasang': 'pasang',
    'berpasangkan': 'pasang',
    'berpasangan': 'pasang',
    'terpasang': 'pasang',
    'terpasangnya': 'pasang',
    'terpasanglah': 'pasang',
    'terpasangkan': 'pasang',
    'terpasangi': 'pasang',
    'terpasangan': 'pasang',
    'pemasangannya': 'pasang',
    'pasang-memasang': 'pasang',
    'berpasang-pasang': 'pasang',
    'berpasang-pasangan': 'pasang',
    'pemasar': 'pasar',
    'pemasarnya': 'pasar',
    'pemasarkan': 'pasar',
    'pemasaran': 'pasar',
    'pasaran': 'pasar',
    'pasarannya': 'pasar',
    'pasaranan': 'pasar',
    'pemasarannya': 'pasar',
    'memasarkan': 'pasar',
    'memasarkannya': 'pasar',
    'pematah': 'patah',
    'pematahan': 'patah',
    'patahan': 'patah',
    'patahannya': 'patah',
    'mematahkan': 'patah',
    'mematahkannya': 'patah',
    'mematahkankan': 'patah',
    'mematahkanmu': 'patah',
    'mematah-matah': 'patah',
    'mematuk': 'patuk',
    'mematuknya': 'patuk',
    'mematukkan': 'patuk',
    'mematuki': 'patuk',
    'mematukku': 'patuk',
    'mematuk-matuk': 'patuk',
    'berangsangan': 'berangsang',
    'pemberangsang': 'berangsang',
    'memberangsang': 'berangsang',
    'memberangsangkan': 'berangsang',
    'memecah belah': 'pecah belah',
    'pemecah belah': 'pecah belah',
    'berpecah belah': 'pecah belah',
    'memecahbelahkan': 'pecah belah',
    'memecah': 'pecah',
    'memecahnya': 'pecah',
    'memecahkan': 'pecah',
    'memecahkannya': 'pecah',
    'memecahi': 'pecah',
    'memecahan': 'pecah',
    'pemecah': 'pecah',
    'pemecahan': 'pecah',
    'pecahan': 'pecah',
    'pecahannya': 'pecah',
    'pecahanan': 'pecah',
    'berpecah': 'pecah',
    'berpecahan': 'pecah',
    'terpecah': 'pecah',
    'terpecahnya': 'pecah',
    'terpecahlah': 'pecah',
    'terpecahkan': 'pecah',
    'terpecahkannya': 'pecah',
    'pemecahannya': 'pecah',
    'pemecahanan': 'pecah',
    'pemecahanku': 'pecah',
    'kepecahan': 'pecah',
    'kepecahannya': 'pecah',
    'memecahkankan': 'pecah',
    'perpecahan': 'pecah',
    'perpecahannya': 'pecah',
    'perpecahanan': 'pecah',
    'terpecah-pecah': 'pecah',
    'terpecah-pecahnya': 'pecah',
    'memecat': 'pecat',
    'memecatnya': 'pecat',
    'memecati': 'pecat',
    'memecatku': 'pecat',
    'memecatmu': 'pecat',
    'pemecatan': 'pecat',
    'pemecatannya': 'pecat',
    'pemecatanku': 'pecat',
    'pemecatanmu': 'pecat',
    'memecatkan': 'pecat',
    'memecut': 'pecut',
    'memecutnya': 'pecut',
    'memecutkan': 'pecut',
    'pemegang': 'pegang',
    'pemegangnya': 'pegang',
    'pemegangan': 'pegang',
    'pegangan': 'pegang',
    'pegangannya': 'pegang',
    'peganganan': 'pegang',
    'peganganku': 'pegang',
    'memegang': 'pegang',
    'memegangnya': 'pegang',
    'memegangkan': 'pegang',
    'memegangi': 'pegang',
    'memegangan': 'pegang',
    'memegangmu': 'pegang',
    'perpegangan': 'pegang',
    'berpegangan': 'pegang',
    'berpegang': 'pegang',
    'bermemek-memek': 'memek',
    'terpekak': 'pekak',
    'memekakkan': 'pekak',
    'pekak-pekak': 'pekak',
    'memekik': 'pekik',
    'memekiknya': 'pekik',
    'memekikkan': 'pekik',
    'memekikan': 'pekik',
    'pekikan': 'pekik',
    'pekikannya': 'pekik',
    'terpekik': 'pekik',
    'pekik-pekuk': 'pekik',
    'terpekik-pekik': 'pekik',
    'memencar': 'pencar',
    'memencarkan': 'pencar',
    'memencari': 'pencar',
    'berpencar': 'pencar',
    'berpencarnya': 'pencar',
    'berpencaran': 'pencar',
    'terpencar': 'pencar',
    'terpencarnya': 'pencar',
    'terpencarkan': 'pencar',
    'pemencaran': 'pencar',
    'memencar-mencar': 'pencar',
    'terpencar-pencar': 'pencar',
    'terpencar-pencari': 'pencar',
    'berpencar-pencar': 'pencar',
    'memencil': 'pencil',
    'memencilkan': 'pencil',
    'terpencil': 'pencil',
    'terpencilnya': 'pencil',
    'pemencilan': 'pencil',
    'keterpencilan': 'pencil',
    'keterpencilannya': 'pencil',
    'memendam': 'pendam',
    'memendamnya': 'pendam',
    'terpendam': 'pendam',
    'terpendamnya': 'pendam',
    'terpendamkan': 'pendam',
    'memendamkan': 'pendam',
    'sepenggal': 'penggal',
    'sepenggalan': 'penggal',
    'penggalan': 'penggal',
    'penggalannya': 'penggal',
    'penggalanan': 'penggal',
    'memenggal': 'penggal',
    'memenggalnya': 'penggal',
    'memenggalku': 'penggal',
    'pemenggal': 'penggal',
    'pemenggalan': 'penggal',
    'terpenggal': 'penggal',
    'terpenggalnya': 'penggal',
    'pemenggalannya': 'penggal',
    'berpenggalan': 'penggal',
    'berpenggal-penggal': 'penggal',
    'kepeningan': 'pening',
    'memeningkan': 'pening',
    'memenjara': 'penjara',
    'memenjarakan': 'penjara',
    'memenjarakannya': 'penjara',
    'terpenjara': 'penjara',
    'terpenjarakan': 'penjara',
    'kepenjaraan': 'penjara',
    'memenjarakanku': 'penjara',
    'sepenuh': 'penuh',
    'sepenuhnya': 'penuh',
    'sepenuhkan': 'penuh',
    'sepenuhi': 'penuh',
    'sepenuhnyalah': 'penuh',
    'memenuhi': 'penuh',
    'memenuhinya': 'penuh',
    'memenuhii': 'penuh',
    'pemenuhan': 'penuh',
    'pemenuhannya': 'penuh',
    'pemenuhanan': 'penuh',
    'terpenuhi': 'penuh',
    'terpenuhinya': 'penuh',
    'terpenuhilah': 'penuh',
    'terpenuhikan': 'penuh',
    'perahan': 'perah',
    'perahannya': 'perah',
    'perahanan': 'perah',
    'pemerah': 'perah',
    'pemerahan': 'perah',
    'memerah': 'perah',
    'memerahnya': 'perah',
    'memerahkan': 'perah',
    'memerahi': 'perah',
    'pemerahannya': 'perah',
    'kemerahan': 'merah',
    'kemerahannya': 'merah',
    'kemerah-merahan': 'merah',
    'pemeram': 'peram',
    'pemeraman': 'peram',
    'peraman': 'peram',
    'memeram': 'peram',
    'memerami': 'peram',
    'berperam': 'peram',
    'memerangkap': 'perangkap',
    'memerangkapnya': 'perangkap',
    'memerangkapkan': 'perangkap',
    'terperangkap': 'perangkap',
    'terperangkapnya': 'perangkap',
    'terperanjat': 'peranjat',
    'memeranjatkan': 'peranjat',
    'memeras': 'peras',
    'memerasnya': 'peras',
    'memeraskannya': 'peras',
    'memerasan': 'peras',
    'memerasku': 'peras',
    'pemeras': 'peras',
    'pemerasnya': 'peras',
    'pemerasan': 'peras',
    'perasan': 'peras',
    'perasannya': 'peras',
    'perasanku': 'peras',
    'pemerasannya': 'peras',
    'tepercik': 'percik',
    'percikan': 'percik',
    'percikannya': 'percik',
    'memercik': 'percik',
    'memercikkan': 'percik',
    'memercikkannya': 'percik',
    'memerciki': 'percik',
    'memercikan': 'percik',
    'bepercikan': 'percik',
    'memercik-mercik': 'percik',
    'memercik-mercikkan': 'percik',
    'pemerhati': 'perhati',
    'pemerhatian': 'perhati',
    'perhatian': 'perhati',
    'perhatiannya': 'perhati',
    'perhatianlah': 'perhati',
    'perhatianku': 'perhati',
    'perhatianmu': 'perhati',
    'memerhatikan': 'perhati',
    'memerhatikannya': 'perhati',
    'memerhatikanku': 'perhati',
    'berperhatian': 'perhati',
    'keperihan': 'perih',
    'memerihkan': 'perih',
    'periksaan': 'periksa',
    'memeriksa': 'periksa',
    'memeriksanya': 'periksa',
    'memeriksakan': 'periksa',
    'memeriksakannya': 'periksa',
    'memeriksai': 'periksa',
    'memeriksaan': 'periksa',
    'memeriksaku': 'periksa',
    'pemeriksa': 'periksa',
    'pemeriksanya': 'periksa',
    'pemeriksakan': 'periksa',
    'pemeriksaan': 'periksa',
    'terperiksa': 'periksa',
    'terperiksanya': 'periksa',
    'pemeriksaannya': 'periksa',
    'pemeriksaanlah': 'periksa',
    'pemeriksaani': 'periksa',
    'pemeriksaanan': 'periksa',
    'memesat': 'pesat',
    'memesatkan': 'pesat',
    'kepesatan': 'pesat',
    'memesong': 'pesong',
    'pemesong': 'pesong',
    'terpesong': 'pesong',
    'memesongkan': 'pesong',
    'memesukkan': 'pesuk',
    'berpesuk-pesuk': 'pesuk',
    'memetik': 'petik',
    'memetiknya': 'petik',
    'memetikkan': 'petik',
    'memetiki': 'petik',
    'memetikan': 'petik',
    'petikan': 'petik',
    'petikannya': 'petik',
    'petikanan': 'petik',
    'pemetik': 'petik',
    'pemetiknya': 'petik',
    'pemetikan': 'petik',
    'terpetik': 'petik',
    'terpetiklah': 'petik',
    'pemetikannya': 'petik',
    'picitan': 'picit',
    'memicit': 'picit',
    'terpicit': 'picit',
    'memihak': 'pihak',
    'memihaknya': 'pihak',
    'memihakmu': 'pihak',
    'sepihak': 'pihak',
    'sepihaknya': 'pihak',
    'memihaki': 'pihak',
    'berpihak': 'pihak',
    'berpihaknya': 'pihak',
    'berpihaklah': 'pihak',
    'berpihakan': 'pihak',
    'pemihakan': 'pihak',
    'pemihakannya': 'pihak',
    'memihakkan': 'pihak',
    'keberpihakan': 'pihak',
    'keberpihakannya': 'pihak',
    'keberpihakanlah': 'pihak',
    'keberpihakanmu': 'pihak',
    'berpihak-pihak': 'pihak',
    'pemikat': 'pikat',
    'pemikatnya': 'pikat',
    'pemikatan': 'pikat',
    'memikat': 'pikat',
    'memikatnya': 'pikat',
    'memikatku': 'pikat',
    'pikatan': 'pikat',
    'terpikat': 'pikat',
    'terpikatnya': 'pikat',
    'keterpikatan': 'pikat',
    'memilih': 'pilih',
    'memilihnya': 'pilih',
    'memilihlah': 'pilih',
    'memilihkan': 'pilih',
    'memilihkannya': 'pilih',
    'memilihi': 'pilih',
    'memilihan': 'pilih',
    'memilihku': 'pilih',
    'memilihmu': 'pilih',
    'pilihan': 'pilih',
    'pilihannya': 'pilih',
    'pilihanlah': 'pilih',
    'pilihanan': 'pilih',
    'pilihanku': 'pilih',
    'pilihanmu': 'pilih',
    'pemilih': 'pilih',
    'pemilihnya': 'pilih',
    'pemilihlah': 'pilih',
    'pemilihkan': 'pilih',
    'pemilihan': 'pilih',
    'pemilihmu': 'pilih',
    'terpilih': 'pilih',
    'terpilihnya': 'pilih',
    'terpilihlah': 'pilih',
    'terpilihkan': 'pilih',
    'terpilihan': 'pilih',
    'pemilihannya': 'pilih',
    'pemilihanan': 'pilih',
    'pemilihanku': 'pilih',
    'pilih-pilih': 'pilih',
    'pilih-pilihnya': 'pilih',
    'pilih-pilihlah': 'pilih',
    'pilih-pilihan': 'pilih',
    'memilih-milih': 'pilih',
    'berpilih-pilih': 'pilih',
    'pemilik': 'milik',
    'pemiliknya': 'milik',
    'pemiliklah': 'milik',
    'pemiliki': 'milik',
    'pemilikan': 'milik',
    'pemiliknyalah': 'milik',
    'pemilikku': 'milik',
    'termilik': 'milik',
    'termiliki': 'milik',
    'memiliki': 'milik',
    'memilikinya': 'milik',
    'memilikii': 'milik',
    'memilikiku': 'milik',
    'memilikimu': 'milik',
    'memiliki-mu': 'milik',
    'pemilikannya': 'milik',
    'kemilikan': 'milik',
    'kepemilikan': 'milik',
    'kepemilikannya': 'milik',
    'kepemilikanku': 'milik',
    'memilin': 'pilin',
    'memilinnya': 'pilin',
    'pilinan': 'pilin',
    'pilinannya': 'pilin',
    'berpilin': 'pilin',
    'pemilinan': 'pilin',
    'pilin-memilin': 'pilin',
    'memilin-milin': 'pilin',
    'berpilin-pilin': 'pilin',
    'meminang': 'pinang',
    'meminangnya': 'pinang',
    'meminangkan': 'pinang',
    'meminangku': 'pinang',
    'peminang': 'pinang',
    'peminangnya': 'pinang',
    'peminangan': 'pinang',
    'pinangan': 'pinang',
    'pinangannya': 'pinang',
    'pinanganku': 'pinang',
    'meminang-minang': 'pinang',
    'pinjaman': 'pinjam',
    'pinjamannya': 'pinjam',
    'pinjamanan': 'pinjam',
    'pinjamanku': 'pinjam',
    'pinjamanmu': 'pinjam',
    'meminjam': 'pinjam',
    'meminjamnya': 'pinjam',
    'meminjamkan': 'pinjam',
    'meminjamkannya': 'pinjam',
    'meminjami': 'pinjam',
    'meminjaman': 'pinjam',
    'meminjamku': 'pinjam',
    'peminjam': 'pinjam',
    'peminjamnya': 'pinjam',
    'peminjamkan': 'pinjam',
    'peminjaman': 'pinjam',
    'meminjaminya': 'pinjam',
    'meminjamimu': 'pinjam',
    'peminjamannya': 'pinjam',
    'peminjamanku': 'pinjam',
    'meminjamkankan': 'pinjam',
    'meminjamkanku': 'pinjam',
    'pinjam-meminjam': 'pinjam',
    'memintas': 'pintas',
    'memintasi': 'pintas',
    'pintasan': 'pintas',
    'sepintas': 'pintas',
    'sepintasnya': 'pintas',
    'pemintasan': 'pintas',
    'kepintasan': 'pintas',
    'memintaskan': 'pintas',
    'meminum': 'minum',
    'meminumnya': 'minum',
    'meminumkan': 'minum',
    'meminumkannya': 'minum',
    'meminuman': 'minum',
    'minuman': 'minum',
    'minumannya': 'minum',
    'minumanlah': 'minum',
    'minumanan': 'minum',
    'minumanku': 'minum',
    'minumanmu': 'minum',
    'peminum': 'minum',
    'peminumnya': 'minum',
    'peminuman': 'minum',
    'meminumi': 'minum',
    'terminum': 'minum',
    'memisit': 'pisit',
    'memohon': 'pohon',
    'memohonnya': 'pohon',
    'memohonkan': 'pohon',
    'memohonan': 'pohon',
    'pepohonan': 'pohon',
    'pepohonannya': 'pohon',
    'pohon-pohonan': 'pohon',
    'memonopoli': 'monopoli',
    'memonopolinya': 'monopoli',
    'memotivasi': 'motivasi',
    'memotivasinya': 'motivasi',
    'memotivasiku': 'motivasi',
    'memotivasimu': 'motivasi',
    'memotivasi-mu': 'motivasi',
    'termotivasi': 'motivasi',
    'termotivasinya': 'motivasi',
    'potongan': 'potong',
    'potongannya': 'potong',
    'pemotong': 'potong',
    'pemotongnya': 'potong',
    'pemotongan': 'potong',
    'memotong': 'potong',
    'memotongnya': 'potong',
    'memotongkan': 'potong',
    'memotongi': 'potong',
    'memotongan': 'potong',
    'berpotong': 'potong',
    'berpotongan': 'potong',
    'terpotong': 'potong',
    'terpotongnya': 'potong',
    'terpotonglah': 'potong',
    'pemotongannya': 'potong',
    'perpotongan': 'potong',
    'perpotongannya': 'potong',
    'potong-memotong': 'potong',
    'memperpotongkan': 'potong',
    'memotong-motong': 'potong',
    'memotong-motongnya': 'potong',
    'berpotong-potong': 'potong',
    'berpotong-potongan': 'potong',
    'memotret': 'potret',
    'memotretnya': 'potret',
    'memotretlah': 'potret',
    'memotretku': 'potret',
    'pemotret': 'potret',
    'pemotretnya': 'potret',
    'pemotretan': 'potret',
    'berpotret': 'potret',
    'pemotretannya': 'potret',
    'memparafrasakan': 'parafrasa',
    'beroleh': 'oleh',
    'berolehkan': 'oleh',
    'perolehan': 'oleh',
    'perolehannya': 'oleh',
    'memperoleh': 'oleh',
    'memperolehnya': 'oleh',
    'memperolehkan': 'oleh',
    'memperolehkannya': 'oleh',
    'memperolehan': 'oleh',
    'pemerolehan': 'oleh',
    'sembahan': 'sembah',
    'penyembah': 'sembah',
    'penyembahnya': 'sembah',
    'penyembahan': 'sembah',
    'menyembah': 'sembah',
    'menyembahnya': 'sembah',
    'menyembahkan': 'sembah',
    'menyembah-ku': 'sembah',
    'bersembah': 'sembah',
    'bersembahan': 'sembah',
    'persembahan': 'sembah',
    'persembahannya': 'sembah',
    'mempersembahkan': 'sembah',
    'mempersembahkannya': 'sembah',
    'senda gurau': 'senda',
    'mempersendakan': 'senda',
    'bersenda-senda': 'senda',
    'bersenda gurau': 'senda',
    'silakan': 'sila',
    'silakanlah': 'sila',
    'tersila': 'sila',
    'silalah': 'sila',
    'silalahi': 'sila',
    'bersila': 'sila',
    'menyilakan': 'sila',
    'menyilakannya': 'sila',
    'mempersilakan': 'sila',
    'mempersilakannya': 'sila',
    'mempersilakanku': 'sila',
    'petunang': 'tunang',
    'petunangan': 'tunang',
    'tunangan': 'tunang',
    'tunangannya': 'tunang',
    'tunanganlah': 'tunang',
    'tunanganku': 'tunang',
    'menunangi': 'tunang',
    'menunangkan': 'tunang',
    'bertunangan': 'tunang',
    'bertunanganlah': 'tunang',
    'pertunangan': 'tunang',
    'pertunangannya': 'tunang',
    'pertunanganmu': 'tunang',
    'mempertunangkan': 'tunang',
    'menunjuk': 'tunjuk',
    'menunjuknya': 'tunjuk',
    'menunjukkan': 'tunjuk',
    'menunjukkannya': 'tunjuk',
    'menunjuki': 'tunjuk',
    'menunjukan': 'tunjuk',
    'menunjukku': 'tunjuk',
    'petunjuk': 'tunjuk',
    'petunjuknya': 'tunjuk',
    'petunjukkan': 'tunjuk',
    'petunjukan': 'tunjuk',
    'petunjuk-mu': 'tunjuk',
    'penunjuk': 'tunjuk',
    'penunjuknya': 'tunjuk',
    'penunjukkan': 'tunjuk',
    'penunjukkannya': 'tunjuk',
    'penunjukan': 'tunjuk',
    'menunjukikan': 'tunjuk',
    'pertunjuk': 'tunjuk',
    'pertunjukkan': 'tunjuk',
    'pertunjukkannya': 'tunjuk',
    'pertunjukan': 'tunjuk',
    'penunjukannya': 'tunjuk',
    'penunjukanku': 'tunjuk',
    'menunjukkanlah': 'tunjuk',
    'menunjukkankan': 'tunjuk',
    'menunjukkani': 'tunjuk',
    'menunjukkanku': 'tunjuk',
    'pertunjukannya': 'tunjuk',
    'tunjuk-menunjuk': 'tunjuk',
    'mempertunjukkan': 'tunjuk',
    'mempertunjukkannya': 'tunjuk',
    'bertunjuk-tunjukan': 'tunjuk',
    'memproklamasikan': 'proklamasi',
    'memproklamasikankan': 'proklamasi',
    'mempromosikan': 'promosi',
    'mempromosikannya': 'promosi',
    'mempromosikani': 'promosi',
    'pemropaganda': 'propaganda',
    'berpropaganda': 'propaganda',
    'mempropagandakan': 'propaganda',
    'mempropagandakannya': 'propaganda',
    'pemroses': 'proses',
    'pemrosesnya': 'proses',
    'pemrosesan': 'proses',
    'memproses': 'proses',
    'memprosesnya': 'proses',
    'memprosesi': 'proses',
    'memprosesan': 'proses',
    'berproses': 'proses',
    'berprosesnya': 'proses',
    'berproseslah': 'proses',
    'berproseskan': 'proses',
    'berprosesi': 'proses',
    'pemrosesannya': 'proses',
    'berpunya': 'punya',
    'mempunyai': 'punya',
    'mempunyainya': 'punya',
    'mempunyaii': 'punya',
    'kepunyaan': 'punya',
    'kepunyaannya': 'punya',
    'kepunyaanku': 'punya',
    'kepunyaanmu': 'punya',
    'mempunyakan': 'punya',
    'memuakkan': 'muak',
    'memualkan': 'mual',
    'pemuasan': 'puas',
    'kepuasan': 'puas',
    'kepuasannya': 'puas',
    'memuaskan': 'puas',
    'memuaskannya': 'puas',
    'memuaskanlah': 'puas',
    'memuaskankan': 'puas',
    'memuaskanku': 'puas',
    'memuaskanmu': 'puas',
    'berpuas diri': 'puas',
    'sepuas-puasnya': 'puas',
    'memuat': 'muat',
    'memuatnya': 'muat',
    'memuatkan': 'muat',
    'memuati': 'muat',
    'memuatan': 'muat',
    'pemuat': 'muat',
    'pemuatan': 'muat',
    'muatan': 'muat',
    'muatannya': 'muat',
    'termuat': 'muat',
    'termuatnya': 'muat',
    'pemuatannya': 'muat',
    'bermuatan': 'muat',
    'memudar': 'pudar',
    'memudarnya': 'pudar',
    'memudarkan': 'pudar',
    'pemudaran': 'pudar',
    'pemuja': 'puja',
    'pemujanya': 'puja',
    'pemujaan': 'puja',
    'memuja': 'puja',
    'memujanya': 'puja',
    'memujaku': 'puja',
    'memujamu': 'puja',
    'pujaan': 'puja',
    'pujaannya': 'puja',
    'pujaanku': 'puja',
    'pemujaannya': 'puja',
    'memuja-muja': 'puja',
    'memuja-mujanya': 'puja',
    'pemukat': 'pukat',
    'pemukatan': 'pukat',
    'memukat': 'pukat',
    'memukau': 'pukau',
    'memukaunya': 'pukau',
    'pukauan': 'pukau',
    'terpukau': 'pukau',
    'terpukaunya': 'pukau',
    'pukulan': 'pukul',
    'pukulannya': 'pukul',
    'pukulanlah': 'pukul',
    'pukulanmu': 'pukul',
    'memukul': 'pukul',
    'memukulnya': 'pukul',
    'memukulkan': 'pukul',
    'memukulkannya': 'pukul',
    'memukuli': 'pukul',
    'memukulku': 'pukul',
    'memukulmu': 'pukul',
    'pemukul': 'pukul',
    'pemukulnya': 'pukul',
    'pemukulan': 'pukul',
    'memukulinya': 'pukul',
    'memukuliku': 'pukul',
    'memukulimu': 'pukul',
    'terpukul': 'pukul',
    'terpukulnya': 'pukul',
    'pemukulannya': 'pukul',
    'memperpukuli': 'pukul',
    'pukul-memukul': 'pukul',
    'memperpukulkan': 'pukul',
    'pemukulrataan': 'pukul rata',
    'memukulratakan': 'pukul rata',
    'memulas': 'pulas',
    'memulasnya': 'pulas',
    'memulaskan': 'pulas',
    'memulaskannya': 'pulas',
    'memulasi': 'pulas',
    'pulasan': 'pulas',
    'pulasannya': 'pulas',
    'kepulasan': 'pulas',
    'berpulasan': 'pulas',
    'pemulihan': 'pulih',
    'pemulihannya': 'pulih',
    'pemulihanku': 'pulih',
    'pemulihanmu': 'pulih',
    'memulihkan': 'pulih',
    'memulihkannya': 'pulih',
    'pemunahan': 'punah',
    'memunahkan': 'punah',
    'memuncak': 'puncak',
    'memuncaknya': 'puncak',
    'memuncakkan': 'puncak',
    'memuncaki': 'puncak',
    'pemuncak': 'puncak',
    'pemuncaknya': 'puncak',
    'punggahan': 'punggah',
    'memunggah': 'punggah',
    'pemunggahan': 'punggah',
    'muntahan': 'muntah',
    'muntahannya': 'muntah',
    'memuntahi': 'muntah',
    'memuntahinya': 'muntah',
    'memuntahkan': 'muntah',
    'memuntahkannya': 'muntah',
    'dimuntahkan': 'muntah',
    'dimuntahkannya': 'muntah',
    'dipupuk': 'pupuk',
    'dipupuknya': 'pupuk',
    'dipupuki': 'pupuk',
    'memupuk': 'pupuk',
    'memupuknya': 'pupuk',
    'memupuki': 'pupuk',
    'pemupuk': 'pupuk',
    'pemupukkan': 'pupuk',
    'pemupukan': 'pupuk',
    'terpupuk': 'pupuk',
    'terpupuklah': 'pupuk',
    'pemupukannya': 'pupuk',
    'memupus': 'pupus',
    'memupusnya': 'pupus',
    'memupuskan': 'pupus',
    'memupuskannya': 'pupus',
    'terpupus': 'pupus',
    'memutar balik': 'putar balik',
    'pemutarbalikan': 'putar balik',
    'memutarbalikkan': 'putar balik',
    'memutarbalikkannya': 'putar balik',
    'terputarbalikkan': 'putar balik',
    'menabung': 'tabung',
    'menabungnya': 'tabung',
    'menabunglah': 'tabung',
    'menabungkan': 'tabung',
    'menabungkannya': 'tabung',
    'menabungmu': 'tabung',
    'penabung': 'tabung',
    'penabungnya': 'tabung',
    'penabungan': 'tabung',
    'tabungan': 'tabung',
    'tabungannya': 'tabung',
    'tabunganku': 'tabung',
    'tabunganmu': 'tabung',
    'menadah': 'tadah',
    'menadahnya': 'tadah',
    'menadahkan': 'tadah',
    'menadahi': 'tadah',
    'tadahan': 'tadah',
    'penadah': 'tadah',
    'penadahnya': 'tadah',
    'penadahan': 'tadah',
    'bertadah': 'tadah',
    'menafikan': 'nafi',
    'menafikannya': 'nafi',
    'tahunan': 'tahun',
    'tahunannya': 'tahun',
    'tahunanan': 'tahun',
    'menahun': 'tahun',
    'menahunnya': 'tahun',
    'setahun': 'tahun',
    'setahunnya': 'tahun',
    'setahunlah': 'tahun',
    'setahunan': 'tahun',
    'bertahun': 'tahun',
    'bertahunan': 'tahun',
    'pertahunan': 'tahun',
    'bertahun-tahun': 'tahun',
    'bertahun-tahunnya': 'tahun',
    'bertahun-tahunlah': 'tahun',
    'menajak': 'tajak',
    'penajakan': 'tajak',
    'penajaman': 'tajam',
    'penajamanlah': 'tajam',
    'penajamanan': 'tajam',
    'menajamkan': 'tajam',
    'mempertajam': 'tajam',
    'mempertajamnya': 'tajam',
    'bertakdir': 'takdir',
    'menakdirkan': 'takdir',
    'menakdirkannya': 'takdir',
    'menakdirkanku': 'takdir',
    'penakik': 'takik',
    'takikan': 'takik',
    'menakik': 'takik',
    'menakikan': 'takik',
    'bertakik': 'takik',
    'bertakik-takik': 'takik',
    'taksiran': 'taksir',
    'taksirannya': 'taksir',
    'menaksir': 'taksir',
    'menaksirnya': 'taksir',
    'menaksirkan': 'taksir',
    'menaksirkannya': 'taksir',
    'penaksiran': 'taksir',
    'penaksirannya': 'taksir',
    'menakuk': 'takuk',
    'menakukkan': 'takuk',
    'menakukan': 'takuk',
    'bertakuk': 'takuk',
    'menakung': 'takung',
    'tertakung': 'takung',
    'bertakung': 'takung',
    'setala': 'tala',
    'penala': 'tala',
    'penalaan': 'tala',
    'menala': 'tala',
    'menalakan': 'tala',
    'bertala-tala': 'tala',
    'menambah': 'tambah',
    'menambahnya': 'tambah',
    'menambahkan': 'tambah',
    'menambahkannya': 'tambah',
    'menambahi': 'tambah',
    'menambahan': 'tambah',
    'penambah': 'tambah',
    'penambahkan': 'tambah',
    'penambahan': 'tambah',
    'tambahan': 'tambah',
    'tambahannya': 'tambah',
    'tambahanlah': 'tambah',
    'tambahankan': 'tambah',
    'tambahani': 'tambah',
    'tambahanan': 'tambah',
    'bertambah': 'tambah',
    'bertambahnya': 'tambah',
    'bertambahlah': 'tambah',
    'bertambahkan': 'tambah',
    'bertambahan': 'tambah',
    'menambahinya': 'tambah',
    'menambahikan': 'tambah',
    'penambahannya': 'tambah',
    'penambahanan': 'tambah',
    'pertambahan': 'tambah',
    'pertambahannya': 'tambah',
    'pertambahanan': 'tambah',
    'menambahkankan': 'tambah',
    'bertambah-tambah': 'tambah',
    'menambak': 'tambak',
    'menambakkan': 'tambak',
    'menambaki': 'tambak',
    'menambakan': 'tambak',
    'penambak': 'tambak',
    'penambakan': 'tambak',
    'petambak': 'tambak',
    'petambakan': 'tambak',
    'bertambak': 'tambak',
    'menambat': 'tambat',
    'menambatkan': 'tambat',
    'menambatkannya': 'tambat',
    'tambatan': 'tambat',
    'tambatannya': 'tambat',
    'bertambat': 'tambat',
    'bertambatnya': 'tambat',
    'tertambat': 'tambat',
    'pertambatan': 'tambat',
    'bertambatkan': 'tambat',
    'tampalan': 'tampal',
    'menampal': 'tampal',
    'menampalkan': 'tampal',
    'menampali': 'tampal',
    'menampung': 'tampung',
    'menampungnya': 'tampung',
    'menampungkan': 'tampung',
    'menampungi': 'tampung',
    'menampungan': 'tampung',
    'penampung': 'tampung',
    'penampungnya': 'tampung',
    'penampungan': 'tampung',
    'bertampung': 'tampung',
    'penampungannya': 'tampung',
    'penandasan': 'tandas',
    'menandaskan': 'tandas',
    'penanda tangan': 'tanda tangan',
    'menandatangani': 'tanda tangan',
    'menandatanganinya': 'tanda tangan',
    'menandatanganii': 'tanda tangan',
    'penandatanganan': 'tanda tangan',
    'penandatanganannya': 'tanda tangan',
    'penandatangananan': 'tanda tangan',
    'tertandatangani': 'tanda tangan',
    'bertanda tangan': 'tanda tangan',
    'menandu': 'tandu',
    'menandunya': 'tandu',
    'penandu': 'tandu',
    'penandukan': 'tandu',
    'bertandu': 'tandu',
    'pemenang': 'menang',
    'pemenangnya': 'menang',
    'pemenanglah': 'menang',
    'pemenangkan': 'menang',
    'pemenangan': 'menang',
    'pemenangku': 'menang',
    'memenangi': 'menang',
    'memenanginya': 'menang',
    'pemenangannya': 'menang',
    'pemenanganan': 'menang',
    'kemenangan': 'menang',
    'kemenangannya': 'menang',
    'kemenanganlah': 'menang',
    'kemenangani': 'menang',
    'kemenanganan': 'menang',
    'kemenanganku': 'menang',
    'kemenanganmu': 'menang',
    'memenangkan': 'menang',
    'memenangkannya': 'menang',
    'memenangkankan': 'menang',
    'mempermenangkan': 'menang',
    'menangap': 'tangap',
    'menangapi': 'tangap',
    'tanggapan': 'tanggap',
    'tanggapannya': 'tanggap',
    'tanggapanku': 'tanggap',
    'menanggap': 'tanggap',
    'menanggapnya': 'tanggap',
    'menanggapi': 'tanggap',
    'menanggapan': 'tanggap',
    'menanggapinya': 'tanggap',
    'menanggapkan': 'tanggap',
    'menangguk': 'tangguk',
    'penangguk': 'tangguk',
    'tertangguk': 'tangguk',
    'menangis': 'tangis',
    'menangisnya': 'tangis',
    'menangislah': 'tangis',
    'menangisi': 'tangis',
    'tangisan': 'tangis',
    'tangisannya': 'tangis',
    'tangisanlah': 'tangis',
    'tangisanku': 'tangis',
    'penangis': 'tangis',
    'menangisinya': 'tangis',
    'bertangisan': 'tangis',
    'menangiskan': 'tangis',
    'mempertangis': 'tangis',
    'bertangis-tangisan': 'tangis',
    'menangkis': 'tangkis',
    'menangkisnya': 'tangkis',
    'tangkisan': 'tangkis',
    'penangkis': 'tangkis',
    'penangkisan': 'tangkis',
    'tertangkis': 'tangkis',
    'tanjakan': 'tanjak',
    'tanjakannya': 'tanjak',
    'menanjak': 'tanjak',
    'menanjaknya': 'tanjak',
    'menanjakkan': 'tanjak',
    'menanjaki': 'tanjak',
    'bertanjak': 'tanjak',
    'ditanjakkan': 'tanjak',
    'penanti': 'nanti',
    'penantikan': 'nanti',
    'penantian': 'nanti',
    'menanti': 'nanti',
    'menantinya': 'nanti',
    'menantikan': 'nanti',
    'menantikannya': 'nanti',
    'menantii': 'nanti',
    'menantian': 'nanti',
    'menantiku': 'nanti',
    'menantimu': 'nanti',
    'nantinya': 'nanti',
    'penantiannya': 'nanti',
    'penantianku': 'nanti',
    'bernantian': 'nanti',
    'menantikanmu': 'nanti',
    'nanti-nantian': 'nanti',
    'menanti-nanti': 'nanti',
    'menanti-nantikan': 'nanti',
    'menanti-nantikannya': 'nanti',
    'bernanti-nanti': 'nanti',
    'ternanti-nanti': 'nanti',
    'bermenantu': 'menantu',
    'bermenantukan': 'menantu',
    'penapai': 'tapai',
    'penapaian': 'tapai',
    'menapai': 'tapai',
    'tapaian': 'tapai',
    'menapis': 'tapis',
    'menapiskan': 'tapis',
    'tapisan': 'tapis',
    'penapis': 'tapis',
    'penapisan': 'tapis',
    'menarah': 'tarah',
    'menarahkannya': 'tarah',
    'tarahan': 'tarah',
    'penarah': 'tarah',
    'bertarah': 'tarah',
    'bertarahan': 'tarah',
    'penarahan': 'tarah',
    'tarian': 'tari',
    'tariannya': 'tari',
    'tarianku': 'tari',
    'menari': 'tari',
    'menarinya': 'tari',
    'menarilah': 'tari',
    'menarikan': 'tarik',
    'menarikannya': 'tari',
    'penari': 'tari',
    'penarinya': 'tari',
    'penarilah': 'tari',
    'penarikan': 'tarik',
    'penarikannya': 'tarik',
    'penarian': 'tari',
    'bertari': 'tari',
    'bertarikan': 'tari',
    'tari-menari': 'tari',
    'tari-tarian': 'tari',
    'tari-tarianan': 'tari',
    'menarik': 'tarik',
    'menariknya': 'tarik',
    'menariklah': 'tarik',
    'menarikkan': 'tarik',
    'menariki': 'tarik',
    'menarikku': 'tarik',
    'menarikmu': 'tarik',
    'penarik': 'tarik',
    'penariknya': 'tarik',
    'penarikkan': 'tarik',
    'tarikan': 'tarik',
    'tarikannya': 'tarik',
    'tertarik': 'tarik',
    'tertariknya': 'tarik',
    'tertariklah': 'tarik',
    'tertarikkan': 'tarik',
    'tertarikan': 'tarik',
    'ketertarikan': 'tarik',
    'ketertarikannya': 'tarik',
    'ketertarikanku': 'tarik',
    'ketertarikanmu': 'tarik',
    'tarik-menarik': 'tarik',
    'tarik-menariknya': 'tarik',
    'bertarik-tarikan': 'tarik',
    'menatang': 'tatang',
    'menatangi': 'tatang',
    'tatapan': 'tatap',
    'tatapannya': 'tatap',
    'menatap': 'tatap',
    'menatapnya': 'tatap',
    'menatapkan': 'tatap',
    'menatapi': 'tatap',
    'menatapku': 'tatap',
    'menatapmu': 'tatap',
    'penatapan': 'tatap',
    'bertatapan': 'tatap',
    'bertatap-tatapan': 'tatap',
    'menaturalisasi': 'naturalisasi',
    'menaturalisasinya': 'naturalisasi',
    'menaturalisasikan': 'naturalisasi',
    'menaturalisasikannya': 'naturalisasi',
    'tawaran': 'tawar',
    'tawarannya': 'tawar',
    'tawaranku': 'tawar',
    'menawar': 'tawar',
    'menawarnya': 'tawar',
    'menawarlah': 'tawar',
    'menawarkan': 'tawar',
    'menawarkannya': 'tawar',
    'menawari': 'tawar',
    'menawaran': 'tawar',
    'menawarku': 'tawar',
    'penawar': 'tawar',
    'penawarnya': 'tawar',
    'penawarkan': 'tawar',
    'penawaran': 'tawar',
    'menawarinya': 'tawar',
    'menawariku': 'tawar',
    'menawarimu': 'tawar',
    'ketawaran': 'tawar',
    'penawarannya': 'tawar',
    'penawaranlah': 'tawar',
    'penawaranan': 'tawar',
    'penawaranku': 'tawar',
    'penawaranmu': 'tawar',
    'bertawaran': 'tawar',
    'menawarkankan': 'tawar',
    'menawarkanku': 'tawar',
    'menawarkanmu': 'tawar',
    'tawar jambi': 'tawar',
    'tawar-menawar': 'tawar',
    'tawar-menawarnya': 'tawar',
    'tawar-menawarkan': 'tawar',
    'tawar-menawari': 'tawar',
    'bertawar-tawaran': 'tawar',
    'tayangan': 'tayang',
    'tayangannya': 'tayang',
    'tayanganlah': 'tayang',
    'menayang': 'tayang',
    'menayangkan': 'tayang',
    'menayangkannya': 'tayang',
    'menayangan': 'tayang',
    'tertayang': 'tayang',
    'tertayangkan': 'tayang',
    'penayangan': 'tayang',
    'penayangannya': 'tayang',
    'penayanganan': 'tayang',
    'mencak-mencak': 'mencak',
    'mendingan': 'mending',
    'mendinganlah': 'mending',
    'menebah': 'tebah',
    'menebahkan': 'tebah',
    'penebang': 'tebang',
    'penebangnya': 'tebang',
    'penebangan': 'tebang',
    'tebangan': 'tebang',
    'tebangannya': 'tebang',
    'menebang': 'tebang',
    'menebangnya': 'tebang',
    'menebangkan': 'tebang',
    'menebangi': 'tebang',
    'menebanginya': 'tebang',
    'penebangannya': 'tebang',
    'penebar': 'tebar',
    'penebarnya': 'tebar',
    'penebaran': 'tebar',
    'menebar': 'tebar',
    'menebarnya': 'tebar',
    'menebarkan': 'tebar',
    'menebarkannya': 'tebar',
    'menebari': 'tebar',
    'tebaran': 'tebar',
    'tebarannya': 'tebar',
    'tertebar': 'tebar',
    'tertebaran': 'tebar',
    'bertebaran': 'tebar',
    'bertebarannya': 'tebar',
    'bertebaranlah': 'tebar',
    'mempertebarkan': 'tebar',
    'penebas': 'tebas',
    'penebasan': 'tebas',
    'menebas': 'tebas',
    'menebasnya': 'tebas',
    'menebaskan': 'tebas',
    'menebaskannya': 'tebas',
    'menebasi': 'tebas',
    'tebasan': 'tebas',
    'menebat': 'tebat',
    'penebatan': 'tebat',
    'ditebuk': 'tebuk',
    'menebuk': 'tebuk',
    'penebuk': 'tebuk',
    'tebukan': 'tebuk',
    'penebukan': 'tebuk',
    'tebusan': 'tebus',
    'tebusannya': 'tebus',
    'penebus': 'tebus',
    'penebusnya': 'tebus',
    'penebusan': 'tebus',
    'menebus': 'tebus',
    'menebusnya': 'tebus',
    'menebuslah': 'tebus',
    'menebuskan': 'tebus',
    'menebusku': 'tebus',
    'menebusmu': 'tebus',
    'penebusannya': 'tebus',
    'menegah': 'tegah',
    'menegahnya': 'tegah',
    'menegahi': 'tegah',
    'tegahan': 'tegah',
    'bertegah': 'tegah',
    'menegahkan': 'tegah',
    'menegak': 'tegak',
    'menegaknya': 'tegak',
    'menegakkan': 'tegak',
    'menegakkannya': 'tegak',
    'menegakan': 'tegak',
    'tegakan': 'tegak',
    'tegakanlah': 'tegak',
    'setegak': 'tegak',
    'setegaknya': 'tegak',
    'penegak': 'tegak',
    'penegaknya': 'tegak',
    'penegakkan': 'tegak',
    'penegakkannya': 'tegak',
    'penegakan': 'tegak',
    'tertegak': 'tegak',
    'bertegak': 'tegak',
    'penegakannya': 'tegak',
    'penegakanan': 'tegak',
    'ketegakan': 'tegak',
    'sepertegak': 'tegak',
    'tegak-tegak': 'tegak',
    'meneguk': 'teguk',
    'meneguknya': 'teguk',
    'menegukan': 'teguk',
    'seteguk': 'teguk',
    'terteguk': 'teguk',
    'ketegukan': 'teguk',
    'menegur': 'tegur',
    'menegurnya': 'tegur',
    'menegurku': 'tegur',
    'teguran': 'tegur',
    'tegurannya': 'tegur',
    'meneguri': 'tegur',
    'keteguran': 'tegur',
    'berteguran': 'tegur',
    'menegur-neguri': 'tegur',
    'menekan': 'tekan',
    'menekannya': 'tekan',
    'menekankan': 'tekan',
    'menekankannya': 'tekan',
    'menekanan': 'tekan',
    'menekanku': 'tekan',
    'menekanmu': 'tekan',
    'tekanan': 'tekan',
    'tekanannya': 'tekan',
    'tekananan': 'tekan',
    'tekananku': 'tekan',
    'penekan': 'tekan',
    'penekannya': 'tekan',
    'penekankan': 'tekan',
    'penekanan': 'tekan',
    'tertekan': 'tekan',
    'tertekannya': 'tekan',
    'tertekanlah': 'tekan',
    'tertekanan': 'tekan',
    'bertekan': 'tekan',
    'bertekanan': 'tekan',
    'penekanannya': 'tekan',
    'penekananan': 'tekan',
    'menekankankan': 'tekan',
    'menekankani': 'tekan',
    'bersetekan': 'tekan',
    'tertekan-tekan': 'tekan',
    'menekap': 'tekap',
    'tekapan': 'tekap',
    'menekapi': 'tekap',
    'bertekap': 'tekap',
    'menekapkan': 'tekap',
    'menelan': 'telan',
    'menelannya': 'telan',
    'menelankan': 'telan',
    'menelanku': 'telan',
    'menelanmu': 'telan',
    'tertelan': 'telan',
    'tertelannya': 'telan',
    'penelanan': 'telan',
    'bertelangkup': 'telangkup',
    'menelangkupkan': 'telangkup',
    'terteleng': 'teleng',
    'menelengkan': 'teleng',
    'bunga teleng': 'teleng',
    'terteleng-teleng': 'teleng',
    'menelungkup': 'telungkup',
    'menelungkupkan': 'telungkup',
    'menelungkupkannya': 'telungkup',
    'bertelengkup': 'telungkup',
    'tertelungkup': 'telungkup',
    'tembakan': 'tembak',
    'tembakannya': 'tembak',
    'tembakanku': 'tembak',
    'tembakanmu': 'tembak',
    'petembak': 'tembak',
    'penembak': 'tembak',
    'penembaknya': 'tembak',
    'penembakkan': 'tembak',
    'penembakan': 'tembak',
    'menembak': 'tembak',
    'menembaknya': 'tembak',
    'menembakkan': 'tembak',
    'menembakkannya': 'tembak',
    'menembaki': 'tembak',
    'menembakan': 'tembak',
    'menembakku': 'tembak',
    'menembakmu': 'tembak',
    'menembakinya': 'tembak',
    'tertembak': 'tembak',
    'tertembaknya': 'tembak',
    'tertembakan': 'tembak',
    'penembakannya': 'tembak',
    'penembakanan': 'tembak',
    'bertembakan': 'tembak',
    'tembak-menembak': 'tembak',
    'menemberang': 'temberang',
    'menembuk': 'tembuk',
    'menembukan': 'tembuk',
    'bertembuk-tembuk': 'tembuk',
    'tembusan': 'tembus',
    'tembusannya': 'tembus',
    'menembusi': 'tembus',
    'tertembus': 'tembus',
    'tertembusnya': 'tembus',
    'tertembuskan': 'tembus',
    'penembusan': 'tembus',
    'penembusannya': 'tembus',
    'tempaan': 'tempa',
    'penempa': 'tempa',
    'penempakan': 'tempa',
    'penempaan': 'tempa',
    'menempa': 'tempa',
    'menempanya': 'tempa',
    'menempakan': 'tempa',
    'menempai': 'tempa',
    'menempaku': 'tempa',
    'tempa-menempa': 'tempa',
    'tendangan': 'tendang',
    'tendangannya': 'tendang',
    'tendanganku': 'tendang',
    'tendanganmu': 'tendang',
    'menendang': 'tendang',
    'menendangnya': 'tendang',
    'menendangkan': 'tendang',
    'menendangkannya': 'tendang',
    'menendangi': 'tendang',
    'menendangan': 'tendang',
    'menendangku': 'tendang',
    'menendangmu': 'tendang',
    'tertendang': 'tendang',
    'tertendangnya': 'tendang',
    'tertendang-tendang': 'tendang',
    'menenggala': 'tenggala',
    'penenggelaman': 'tenggelam',
    'penenggelamannya': 'tenggelam',
    'menenggelamkan': 'tenggelam',
    'menenggelamkannya': 'tenggelam',
    'menenggelamkanku': 'tenggelam',
    'penenteraman': 'tenteram',
    'ketenteraman': 'tenteram',
    'menenteramkan': 'tenteram',
    'menentu': 'tentu',
    'menentunya': 'tentu',
    'menentukan': 'tentu',
    'menentukannya': 'tentu',
    'menentuan': 'tentu',
    'penentu': 'tentu',
    'penentunya': 'tentu',
    'penentukan': 'tentu',
    'penentuan': 'tentu',
    'bertentu': 'tentu',
    'tertentu': 'tentu',
    'tertentunya': 'tentu',
    'tertentulah': 'tentu',
    'tertentui': 'tentu',
    'menentui': 'tentu',
    'penentuannya': 'tentu',
    'ketentuan': 'tentu',
    'ketentuannya': 'tentu',
    'ketentuanlah': 'tentu',
    'ketentuanan': 'tentu',
    'menentukankan': 'tentu',
    'menentukanku': 'tentu',
    'berketentuan': 'tentu',
    'bertentu-tentu': 'tentu',
    'menepak': 'tepak',
    'menepakkan': 'tepak',
    'menepak-nepak': 'tepak',
    'menepak-nepakkan': 'tepak',
    'tepatan': 'tepat',
    'menepat': 'tepat',
    'menepatkan': 'tepat',
    'menepatkannya': 'tepat',
    'menepati': 'tepat',
    'menepatinya': 'tepat',
    'ketepatan': 'tepat',
    'ketepatannya': 'tepat',
    'pertepatan': 'tepat',
    'bertepatan': 'tepat',
    'bertepatannya': 'tepat',
    'berketepatan': 'tepat',
    'menepek': 'tepek',
    'bertepek-tepek': 'tepek',
    'menepis': 'tepis',
    'menepisnya': 'tepis',
    'menepiskan': 'tepis',
    'menera': 'tera',
    'menerakan': 'tera',
    'teraan': 'tera',
    'bertera': 'tera',
    'tertera': 'tera',
    'terteranya': 'tera',
    'peneraan': 'tera',
    'perteraan': 'tera',
    'penerang': 'terang',
    'penerangnya': 'terang',
    'penerangan': 'terang',
    'menerang': 'terang',
    'menerangkan': 'terang',
    'menerangkannya': 'terang',
    'menerangi': 'terang',
    'menerangan': 'terang',
    'meneranginya': 'terang',
    'penerangannya': 'terang',
    'peneranganan': 'terang',
    'keterangan': 'terang',
    'keterangannya': 'terang',
    'keteranganlah': 'terang',
    'keteranganan': 'terang',
    'keterangannyalah': 'terang',
    'keteranganmu': 'terang',
    'menerangkankan': 'terang',
    'berpenerangan': 'terang',
    'terang-terang': 'terang',
    'terang-terangnya': 'terang',
    'terang-terangkan': 'terang',
    'terang-terangan': 'terang',
    'terang-terangannya': 'terang',
    'terang-teranganan': 'terang',
    'berterang-terang': 'terang',
    'berterang-terangan': 'terang',
    'terang-terang laras': 'terang',
    'penerima': 'terima',
    'penerimanya': 'terima',
    'penerimalah': 'terima',
    'penerimaan': 'terima',
    'penerimamu': 'terima',
    'menerima': 'terima',
    'menerimanya': 'terima',
    'menerimalah': 'terima',
    'menerimakan': 'terima',
    'menerimaan': 'terima',
    'menerimaku': 'terima',
    'menerimamu': 'terima',
    'berterima': 'terima',
    'berterimakan': 'terima',
    'penerimaannya': 'terima',
    'penerimaanmu': 'terima',
    'keberterimaan': 'terima',
    'menerkam': 'terkam',
    'menerkamnya': 'terkam',
    'menerkamku': 'terkam',
    'penerkam': 'terkam',
    'penerkaman': 'terkam',
    'terkaman': 'terkam',
    'terkamannya': 'terkam',
    'terobosan': 'terobos',
    'terobosannya': 'terobos',
    'menerobos': 'terobos',
    'menerobosnya': 'terobos',
    'meneroboskan': 'terobos',
    'meneroboskannya': 'terobos',
    'penerobosan': 'terobos',
    'meneroka': 'teroka',
    'peneroka': 'teroka',
    'menerpa': 'terpa',
    'menerpanya': 'terpa',
    'menerpakan': 'terpa',
    'terpaan': 'terpa',
    'terpaannya': 'terpa',
    'terusan': 'terus',
    'terusannya': 'terus',
    'penerus': 'terus',
    'penerusnya': 'terus',
    'peneruslah': 'terus',
    'penerusan': 'terus',
    'penerusku': 'terus',
    'menerus': 'terus',
    'menerusnya': 'terus',
    'meneruslah': 'terus',
    'meneruskan': 'terus',
    'meneruskannya': 'terus',
    'menerusi': 'terus',
    'penerusannya': 'terus',
    'keterusan': 'terus',
    'keterusanlah': 'terus',
    'meneruskankan': 'terus',
    'seterusnya': 'terus',
    'terus-menerus': 'terus',
    'terus-menerusnya': 'terus',
    'terus-terusan': 'terus',
    'terus-terusanlah': 'terus',
    'terus-terusanan': 'terus',
    'menetak': 'tetak',
    'menetakan': 'tetak',
    'menetakkan': 'tetak',
    'bertetakan': 'tetak',
    'menetas': 'tetas',
    'menetasnya': 'tetas',
    'menetaskan': 'tetas',
    'menetaskannya': 'tetas',
    'penetas': 'tetas',
    'penetasi': 'tetas',
    'penetasan': 'tetas',
    'menetek': 'tetek',
    'meneteki': 'tetek',
    'menetekkan': 'tetek',
    'termengah-mengah': 'mengah',
    'mengap-mengap': 'mengap',
    'pengasoan': 'aso',
    'mengeong': 'ngeong',
    'mengepos': 'pos',
    'mengeposkan': 'pos',
    'mengeposkannya': 'pos',
    'pengeposan': 'pos',
    'semengga': 'mengga',
    'semengga-mengga': 'mengga',
    'bermengkal': 'mengkal',
    'memengkalkan': 'mengkal',
    'kemengkelan': 'mengkelan',
    'termengkelan': 'mengkelan',
    'cengking-mengking': 'mengking',
    'memengkis': 'mengkis',
    'ocehan': 'oceh',
    'ocehannya': 'oceh',
    'mengoceh': 'oceh',
    'mengocehi': 'oceh',
    'omelan': 'omel',
    'omelannya': 'omel',
    'mengomel': 'omel',
    'mengomeli': 'omel',
    'pengomel': 'omel',
    'mengomelinya': 'omel',
    'mengongkosi': 'ongkos',
    'mengongkosinya': 'ongkos',
    'perongkosan': 'ongkos',
    'uapan': 'uap',
    'penguap': 'uap',
    'penguapan': 'uap',
    'menguapinya': 'uap',
    'penguapannya': 'uap',
    'teruapkan': 'uap',
    'ubah suaian': 'ubah suai',
    'pengubahsuaian': 'ubah suai',
    'mengubahsuaikan': 'ubah suai',
    'ucapan': 'ucap',
    'ucapannya': 'ucap',
    'ucapanku': 'ucap',
    'ucapanmu': 'ucap',
    'berucap': 'ucap',
    'berucaplah': 'ucap',
    'mengucap': 'ucap',
    'mengucapnya': 'ucap',
    'mengucapkan': 'ucap',
    'mengucapkannya': 'ucap',
    'mengucapan': 'ucap',
    'pengucap': 'ucap',
    'pengucapnya': 'ucap',
    'pengucapan': 'ucap',
    'mengucapi': 'ucap',
    'pengucapannya': 'ucap',
    'terucapkan': 'ucap',
    'mengucapkankan': 'ucap',
    'ugutan': 'ugut',
    'mengugut': 'ugut',
    'diuji': 'uji',
    'diujinya': 'uji',
    'diujilah': 'uji',
    'diujikan': 'uji',
    'diujian': 'uji',
    'ujian': 'uji',
    'ujiannya': 'uji',
    'ujiani': 'uji',
    'ujianmu': 'uji',
    'beruji': 'uji',
    'berujian': 'uji',
    'teruji': 'uji',
    'terujinya': 'uji',
    'terujikan': 'uji',
    'penguji': 'uji',
    'pengujinya': 'uji',
    'pengujikan': 'uji',
    'pengujian': 'uji',
    'menguji': 'uji',
    'mengujinya': 'uji',
    'mengujikan': 'uji',
    'mengujikannya': 'uji',
    'mengujii': 'uji',
    'mengujian': 'uji',
    'mengujimu': 'uji',
    'keujian': 'uji',
    'pengujiannya': 'uji',
    'keterujian': 'uji',
    'pengumbuk': 'umbuk',
    'mengumbuk': 'umbuk',
    'seumpama': 'umpama',
    'seumpamanya': 'umpama',
    'berumpama': 'umpama',
    'mengumpamai': 'umpama',
    'perumpamaan': 'umpama',
    'perumpamaannya': 'umpama',
    'mengumpamakan': 'umpama',
    'mengumpamakannya': 'umpama',
    'mengumpan': 'umpan',
    'mengumpannya': 'umpan',
    'mengumpankan': 'umpan',
    'mengumpankannya': 'umpan',
    'mengumpani': 'umpan',
    'pengumpil': 'umpil',
    'pengumpilnya': 'umpil',
    'pengumpilan': 'umpil',
    'mengumpil': 'umpil',
    'mengumpilkan': 'umpil',
    'mengumpilan': 'umpil',
    'seumumnya': 'umum',
    'memperumum': 'umum',
    'pengumuman': 'umum',
    'pengumumannya': 'umum',
    'pengumumanlah': 'umum',
    'pengumumanan': 'umum',
    'mengumumkan': 'umum',
    'mengumumkannya': 'umum',
    'mengumumkankan': 'umum',
    'undangan': 'undang',
    'undangannya': 'undang',
    'undanganlah': 'undang',
    'undanganan': 'undang',
    'undanganku': 'undang',
    'undanganmu': 'undang',
    'berundang': 'undang',
    'pengundang': 'undang',
    'pengundangnya': 'undang',
    'pengundangan': 'undang',
    'undang-undang': 'undang',
    'undang-undangnya': 'undang',
    'undang-undanglah': 'undang',
    'undang-undangkan': 'undang',
    'undang-undangi': 'undang',
    'undang-undangan': 'undang',
    'pengundang-undang': 'undang',
    'pengundang-undangan': 'undang',
    'perundang-undangan': 'undang',
    'perundang-undangannya': 'undang',
    'perundang-undanganan': 'undang',
    'undian': 'undi',
    'undiannya': 'undi',
    'berundi': 'undi',
    'pengundi': 'undi',
    'pengundian': 'undi',
    'mengundi': 'undi',
    'mengundinya': 'undi',
    'pengundiannya': 'undi',
    'memperundikan': 'undi',
    'mengundur': 'undur',
    'mengundurnya': 'undur',
    'mengundurkan': 'undur',
    'mengundurkannya': 'undur',
    'mengunduran': 'undur',
    'pengunduran': 'undur',
    'pengundurannya': 'undur',
    'termengung': 'mengung',
    'mengunggis': 'unggis',
    'pengunggis': 'unggis',
    'unggunan': 'unggun',
    'berunggun': 'unggun',
    'mengunggun': 'unggun',
    'mengunggunkan': 'unggun',
    'berunggun-unggun': 'unggun',
    'ungkaian': 'ungkai',
    'mengungkai': 'ungkai',
    'ungkapan': 'ungkap',
    'ungkapannya': 'ungkap',
    'terungkap': 'ungkap',
    'terungkapnya': 'ungkap',
    'terungkaplah': 'ungkap',
    'terungkapkan': 'ungkap',
    'mengungkap': 'ungkap',
    'mengungkapnya': 'ungkap',
    'mengungkapkan': 'ungkap',
    'mengungkapkannya': 'ungkap',
    'mengungkapan': 'ungkap',
    'mengungkapi': 'ungkap',
    'pengungkapan': 'ungkap',
    'pengungkapannya': 'ungkap',
    'mengungkapkankan': 'ungkap',
    'mengungkapkanan': 'ungkap',
    'terungkap-ungkap': 'ungkap',
    'mengungkit': 'ungkit',
    'mengungkitnya': 'ungkit',
    'pengungkit': 'ungkit',
    'pengungkitnya': 'ungkit',
    'pengungkitan': 'ungkit',
    'ungkit-ungkit': 'ungkit',
    'mengungkit-ungkit': 'ungkit',
    'mengungkit-ungkitnya': 'ungkit',
    'mengunjuk': 'unjuk',
    'mengunjukkan': 'unjuk',
    'mengunjukan': 'unjuk',
    'pengunjukan': 'unjuk',
    'sepengunjuk': 'unjuk',
    'mengunting': 'unting',
    'unting-unting': 'unting',
    'upahan': 'upah',
    'berupah': 'upah',
    'mengupah': 'upah',
    'mengupahnya': 'upah',
    'mengupahi': 'upah',
    'pengupahan': 'upah',
    'pengupahannya': 'upah',
    'mengupahkan': 'upah',
    'upah-mengupah': 'upah',
    'uraian': 'urai',
    'uraiannya': 'urai',
    'terurai': 'urai',
    'terurainya': 'urai',
    'teruraikan': 'urai',
    'berurai': 'urai',
    'beruraikan': 'urai',
    'beruraian': 'urai',
    'mengurai': 'urai',
    'mengurainya': 'urai',
    'menguraikan': 'urai',
    'menguraikannya': 'urai',
    'peruraian': 'urai',
    'penguraian': 'urai',
    'penguraiannya': 'urai',
    'mengurup': 'urup',
    'urup-urup': 'urup',
    'urup-urupan': 'urup',
    'keurus': 'urus',
    'urusan': 'urus',
    'urusannya': 'urus',
    'urusanlah': 'urus',
    'urusani': 'urus',
    'urusanku': 'urus',
    'urusanmu': 'urus',
    'urusan-ku': 'urus',
    'terurus': 'urus',
    'terurusnya': 'urus',
    'keurusan': 'urus',
    'pengurus': 'urus',
    'pengurusnya': 'urus',
    'penguruslah': 'urus',
    'pengurusi': 'urus',
    'pengurusku': 'urus',
    'pengurusmu': 'urus',
    'mengurusinya': 'urus',
    'mengurusiku': 'urus',
    'mengurusimu': 'urus',
    'berurusan': 'urus',
    'urus-urus': 'urus',
    'urus-urusan': 'urus',
    'kepengurusan': 'urus',
    'kepengurusannya': 'urus',
    'kepengurusanan': 'urus',
    'kepengurusannyalah': 'urus',
    'mengusainya': 'usai',
    'mengusaikan': 'usai',
    'mengusap': 'usap',
    'mengusapnya': 'usap',
    'mengusapkan': 'usap',
    'mengusapkannya': 'usap',
    'mengusapi': 'usap',
    'usikan': 'usik',
    'terusik': 'usik',
    'terusiknya': 'usik',
    'pengusik': 'usik',
    'pengusiknya': 'usik',
    'mengusik': 'usik',
    'mengusiknya': 'usik',
    'mengusikku': 'usik',
    'mengusikmu': 'usik',
    'usiran': 'usir',
    'usirannya': 'usir',
    'terusir': 'usir',
    'terusirnya': 'usir',
    'pengusir': 'usir',
    'pengusirnya': 'usir',
    'pengusiran': 'usir',
    'mengusir': 'usir',
    'mengusirnya': 'usir',
    'mengusiri': 'usir',
    'mengusiran': 'usir',
    'mengusirku': 'usir',
    'mengusirmu': 'usir',
    'pengusirannya': 'usir',
    'usulan': 'usul',
    'usulannya': 'usul',
    'usulanku': 'usul',
    'usulanmu': 'usul',
    'pengusul': 'usul',
    'pengusulnya': 'usul',
    'pengusulan': 'usul',
    'mengusul': 'usul',
    'mengusulkan': 'usul',
    'mengusulkannya': 'usul',
    'mengusulan': 'usul',
    'pengusuli': 'usul',
    'mengusuli': 'usul',
    'pengusulannya': 'usul',
    'usungan': 'usung',
    'usungannya': 'usung',
    'berusung': 'usung',
    'pengusung': 'usung',
    'pengusungnya': 'usung',
    'pengusunglah': 'usung',
    'pengusungan': 'usung',
    'mengusung': 'usung',
    'mengusungnya': 'usung',
    'mengusungkan': 'usung',
    'mengusungi': 'usung',
    'pengusungannya': 'usung',
    'mengutara': 'utara',
    'mengutarakan': 'utara',
    'mengutarakannya': 'utara',
    'pengutaraan': 'utara',
    'utusan': 'utus',
    'utusannya': 'utus',
    'mengutus': 'utus',
    'mengutusnya': 'utus',
    'mengutuskan': 'utus',
    'mengutusku': 'utus',
    'mengutusmu': 'utus',
    'perutusan': 'utus',
    'perutusannya': 'utus',
    'pengutusan': 'utus',
    'meniarap': 'tiarap',
    'tertiarap': 'tiarap',
    'bertiarap': 'tiarap',
    'meniarapkan': 'tiarap',
    'menikah': 'nikah',
    'menikahnya': 'nikah',
    'menikahlah': 'nikah',
    'menikahkan': 'nikah',
    'menikahkannya': 'nikah',
    'menikahi': 'nikah',
    'menikahinya': 'nikah',
    'menikahiku': 'nikah',
    'menikahimu': 'nikah',
    'pernikahan': 'nikah',
    'pernikahannya': 'nikah',
    'pernikahanlah': 'nikah',
    'pernikahanan': 'nikah',
    'pernikahanku': 'nikah',
    'pernikahanmu': 'nikah',
    'menikahkanku': 'nikah',
    'menikam': 'tikam',
    'menikamnya': 'tikam',
    'menikamkan': 'tikam',
    'menikamkannya': 'tikam',
    'menikami': 'tikam',
    'menikamku': 'tikam',
    'menikammu': 'tikam',
    'penikam': 'tikam',
    'penikaman': 'tikam',
    'tikaman': 'tikam',
    'tertikam': 'tikam',
    'penikamannya': 'tikam',
    'pertikaman': 'tikam',
    'tikam-menikam': 'tikam',
    'bertikam-tikaman': 'tikam',
    'penikmat': 'nikmat',
    'penikmatnya': 'nikmat',
    'penikmati': 'nikmat',
    'penikmatan': 'nikmat',
    'menikmati': 'nikmat',
    'menikmatinya': 'nikmat',
    'menikmatilah': 'nikmat',
    'menikmatii': 'nikmat',
    'menikmatiku': 'nikmat',
    'menikmatimu': 'nikmat',
    'kenikmatan': 'nikmat',
    'kenikmatannya': 'nikmat',
    'kenikmatanlah': 'nikmat',
    'penilik': 'tilik',
    'penilikan': 'tilik',
    'menilik': 'tilik',
    'meniliknya': 'tilik',
    'meniliki': 'tilik',
    'tilikan': 'tilik',
    'tilikannya': 'tilik',
    'tilik-menilik': 'tilik',
    'menimang': 'timang',
    'menimangnya': 'timang',
    'ditimang': 'timang',
    'menimangkan': 'timang',
    'menimang-nimang': 'timang',
    'menimang-nimangnya': 'timang',
    'timang-timangan': 'timang',
    'timbangan': 'timbang',
    'timbangannya': 'timbang',
    'timbanganku': 'timbang',
    'setimbang': 'timbang',
    'ketimbang': 'timbang',
    'ketimbangnya': 'timbang',
    'ketimbangkan': 'timbang',
    'ketimbangan': 'timbang',
    'ketimbangku': 'timbang',
    'menimbang': 'timbang',
    'menimbangnya': 'timbang',
    'menimbangkan': 'timbang',
    'menimbangkannya': 'timbang',
    'menimbangi': 'timbang',
    'penimbang': 'timbang',
    'penimbangan': 'timbang',
    'bertimbang': 'timbang',
    'bertimbangkan': 'timbang',
    'setimbangan': 'timbang',
    'bertimbangan': 'timbang',
    'pertimbangan': 'timbang',
    'pertimbangannya': 'timbang',
    'pertimbanganlah': 'timbang',
    'pertimbangankan': 'timbang',
    'pertimbanganan': 'timbang',
    'pertimbanganku': 'timbang',
    'kesetimbangan': 'timbang',
    'kesetimbangannya': 'timbang',
    'menyetimbangkan': 'timbang',
    'mempertimbangkan': 'timbang',
    'mempertimbangkannya': 'timbang',
    'mempertimbangkankan': 'timbang',
    'mempertimbangkanku': 'timbang',
    'menimbang-nimbang': 'timbang',
    'menimbang-nimbangnya': 'timbang',
    'timbang-menimbang': 'timbang',
    'menimbus': 'timbus',
    'menimbusi': 'timbus',
    'tertimbus': 'timbus',
    'menimpa': 'timpa',
    'menimpanya': 'timpa',
    'menimpakan': 'timpa',
    'menimpakannya': 'timpa',
    'menimpai': 'timpa',
    'menimpanyalah': 'timpa',
    'menimpaku': 'timpa',
    'menimpamu': 'timpa',
    'ditimpa': 'timpa',
    'ditimpanya': 'timpa',
    'ditimpakan': 'timpa',
    'ditimpakannya': 'timpa',
    'timpaan': 'timpa',
    'tertimpa': 'timpa',
    'tertimpanya': 'timpa',
    'tertimpalah': 'timpa',
    'timpa-menimpa': 'timpa',
    'bertimpa-timpa': 'timpa',
    'menindik': 'tindik',
    'menindiknya': 'tindik',
    'menindikan': 'tindik',
    'bertindik': 'tindik',
    'tinggalan': 'tinggal',
    'tinggalannya': 'tinggal',
    'peninggal': 'tinggal',
    'peninggalkan': 'tinggal',
    'peninggalan': 'tinggal',
    'meninggal': 'tinggal',
    'meninggalnya': 'tinggal',
    'meninggalkan': 'tinggal',
    'meninggalkannya': 'tinggal',
    'meninggali': 'tinggal',
    'meninggalan': 'tinggal',
    'meninggalku': 'tinggal',
    'tertinggal': 'tinggal',
    'tertinggalnya': 'tinggal',
    'tertinggalkan': 'tinggal',
    'tertinggalan': 'tinggal',
    'meninggalinya': 'tinggal',
    'pertinggal': 'tinggal',
    'pertinggalnya': 'tinggal',
    'pertinggalan': 'tinggal',
    'bertinggal': 'tinggal',
    'sepeninggal': 'tinggal',
    'sepeninggalnya': 'tinggal',
    'sepeninggalan': 'tinggal',
    'ketinggalan': 'tinggal',
    'ketinggalannya': 'tinggal',
    'peninggalannya': 'tinggal',
    'peninggalanan': 'tinggal',
    'meninggalkankan': 'tinggal',
    'meninggalkanku': 'tinggal',
    'meninggalkanmu': 'tinggal',
    'ketertinggalan': 'tinggal',
    'ketertinggalannya': 'tinggal',
    'ketertinggalanku': 'tinggal',
    'peninjau': 'tinjau',
    'peninjaunya': 'tinjau',
    'peninjaukan': 'tinjau',
    'peninjauan': 'tinjau',
    'meninjau': 'tinjau',
    'meninjaunya': 'tinjau',
    'meninjaui': 'tinjau',
    'meninjauan': 'tinjau',
    'tinjauan': 'tinjau',
    'tinjauannya': 'tinjau',
    'peninjauannya': 'tinjau',
    'peninjauanan': 'tinjau',
    'tinjau-meninjau': 'tinjau',
    'bertinjau-tinjauan': 'tinjau',
    'penipu': 'tipu',
    'penipunya': 'tipu',
    'penipuan': 'tipu',
    'menipu': 'tipu',
    'menipunya': 'tipu',
    'menipukan': 'tipu',
    'menipuku': 'tipu',
    'menipumu': 'tipu',
    'tipuan': 'tipu',
    'tipuannya': 'tipu',
    'penipuannya': 'tipu',
    'penipuanlah': 'tipu',
    'bertipuan': 'tipu',
    'peniru': 'tiru',
    'penirunya': 'tiru',
    'peniruan': 'tiru',
    'tiruan': 'tiru',
    'tiruannya': 'tiru',
    'meniru': 'tiru',
    'menirunya': 'tiru',
    'menirulah': 'tiru',
    'menirukan': 'tiru',
    'menirukannya': 'tiru',
    'menirui': 'tiru',
    'menirumu': 'tiru',
    'meniru-niru': 'tiru',
    'tiru-tiruan': 'tiru',
    'menisik': 'tisik',
    'tisikan': 'tisik',
    'menisiki': 'tisik',
    'menitik': 'titik',
    'menitikkan': 'titik',
    'menitikan': 'titik',
    'bertitik': 'titik',
    'menitiki': 'titik',
    'bertitik-titik': 'titik',
    'penitikberatan': 'titik berat',
    'menitikberatkan': 'titik berat',
    'menitikberatkannya': 'titik berat',
    'titisan': 'titis',
    'titisannya': 'titis',
    'menitis': 'titis',
    'menitiskan': 'titis',
    'penitisan': 'titis',
    'ketitisan': 'titis',
    'bernoda': 'noda',
    'bernodakan': 'noda',
    'ternoda': 'noda',
    'ternodanya': 'noda',
    'ternodakan': 'noda',
    'ternodai': 'noda',
    'menodai': 'noda',
    'menodainya': 'noda',
    'penokok': 'tokok',
    'menokok': 'tokok',
    'bertokok': 'tokok',
    'tokok-menokok': 'tokok',
    'penolong': 'tolong',
    'penolongnya': 'tolong',
    'penolongi': 'tolong',
    'penolongan': 'tolong',
    'penolongmu': 'tolong',
    'menolong': 'tolong',
    'menolongnya': 'tolong',
    'menolonglah': 'tolong',
    'menolongku': 'tolong',
    'menolongmu': 'tolong',
    'tertolong': 'tolong',
    'tertolongnya': 'tolong',
    'tertolongkan': 'tolong',
    'tertolongan': 'tolong',
    'ketolongan': 'tolong',
    'pertolongan': 'tolong',
    'pertolongannya': 'tolong',
    'pertolongankan': 'tolong',
    'pertolonganku': 'tolong',
    'pertolonganmu': 'tolong',
    'pertolongan-mu': 'tolong',
    'tolong-menolong': 'tolong',
    'tolong-menolonglah': 'tolong',
    'bertolong-tolongan': 'tolong',
    'tonjolan': 'tonjol',
    'tonjolannya': 'tonjol',
    'menonjol': 'tonjol',
    'menonjolnya': 'tonjol',
    'menonjolkan': 'tonjol',
    'menonjolkannya': 'tonjol',
    'menonjolan': 'tonjol',
    'bertonjol': 'tonjol',
    'bertonjolan': 'tonjol',
    'tertonjol': 'tonjol',
    'tertonjolkan': 'tonjol',
    'penonjolan': 'tonjol',
    'penonjolannya': 'tonjol',
    'bertonjol-tonjol': 'tonjol',
    'menonjol-nonjolkan': 'tonjol',
    'tontonan': 'tonton',
    'tontonannya': 'tonton',
    'penonton': 'tonton',
    'penontonnya': 'tonton',
    'menonton': 'tonton',
    'menontonnya': 'tonton',
    'menontonkan': 'tonton',
    'menontonkannya': 'tonton',
    'menontoni': 'tonton',
    'menontonku': 'tonton',
    'menontonmu': 'tonton',
    'kepenontonan': 'tonton',
    'mempertontonkan': 'tonton',
    'mempertontonkannya': 'tonton',
    'mempertontonkankan': 'tonton',
    'penopang': 'topang',
    'penopangnya': 'topang',
    'topangan': 'topang',
    'menopang': 'topang',
    'menopangnya': 'topang',
    'menopangkan': 'topang',
    'menopangku': 'topang',
    'menopangmu': 'topang',
    'bertopang': 'topang',
    'bertopangkan': 'topang',
    'torehan': 'toreh',
    'torehannya': 'toreh',
    'menoreh': 'toreh',
    'menorehnya': 'toreh',
    'menorehkan': 'toreh',
    'menorehkannya': 'toreh',
    'menorehan': 'toreh',
    'penoreh': 'toreh',
    'penorehnya': 'toreh',
    'penorehan': 'toreh',
    'stensilan': 'stensil',
    'menstensil': 'stensil',
    'penswastaan': 'swasta',
    'menswastakan': 'swasta',
    'kementahan': 'mentah',
    'mementahkan': 'mentah',
    'mementahkannya': 'mentah',
    'mentah-mentah': 'mentah',
    'kementakan': 'mentak',
    'sementang': 'mentang',
    'sementangkan': 'mentang',
    'mentang-mentang': 'mentang',
    'mentang-mentanglah': 'mentang',
    'sementang-mentang': 'mentang',
    'mementegai': 'mentega',
    'kementerengan': 'mentereng',
    'menuam': 'tuam',
    'menuami': 'tuam',
    'bertuam': 'tuam',
    'tuangan': 'tuang',
    'tuangannya': 'tuang',
    'dituang': 'tuang',
    'dituangnya': 'tuang',
    'dituangkan': 'tuang',
    'dituangkannya': 'tuang',
    'dituangi': 'tuang',
    'dituangan': 'tuang',
    'menuang': 'tuang',
    'menuangnya': 'tuang',
    'menuangkan': 'tuang',
    'menuangkannya': 'tuang',
    'menuangi': 'tuang',
    'menuanginya': 'tuang',
    'bertuang': 'tuang',
    'bertuangan': 'tuang',
    'penuangan': 'tuang',
    'penuangannya': 'tuang',
    'ketuangan': 'tuang',
    'tubian': 'tubi',
    'menubikan': 'tubi',
    'bertubi-tubi': 'tubi',
    'bertubi-tubinya': 'tubi',
    'mempertubikan': 'tubi',
    'mempertubi-tubi': 'tubi',
    'mempertubi-tubikan': 'tubi',
    'tugalan': 'tugal',
    'menugal': 'tugal',
    'menugalkan': 'tugal',
    'menujah': 'tujah',
    'menujahkan': 'tujah',
    'penuju': 'tuju',
    'penujukan': 'tuju',
    'penujukannya': 'tuju',
    'setuju': 'tuju',
    'setujunya': 'tuju',
    'setujulah': 'tuju',
    'setujui': 'tuju',
    'setujuan': 'tuju',
    'menuju': 'tuju',
    'menujunya': 'tuju',
    'menujukan': 'tuju',
    'menujukannya': 'tuju',
    'menujui': 'tuju',
    'menujuku': 'tuju',
    'tujuan': 'tuju',
    'tujuannya': 'tuju',
    'tujuanku': 'tuju',
    'tujuanmu': 'tuju',
    'tertuju': 'tuju',
    'tertujunya': 'tuju',
    'tertujuan': 'tuju',
    'setujuannya': 'tuju',
    'bersetuju': 'tuju',
    'bersetujuan': 'tuju',
    'bertujuan': 'tuju',
    'bertujuannya': 'tuju',
    'bertujuani': 'tuju',
    'kesetujuan': 'tuju',
    'kesetujuannya': 'tuju',
    'menyetujui': 'tuju',
    'menyetujuinya': 'tuju',
    'persetujuan': 'tuju',
    'persetujuannya': 'tuju',
    'persetujuanmu': 'tuju',
    'menyetujukan': 'tuju',
    'mempersetujukan': 'tuju',
    'menukul': 'tukul',
    'penukul': 'tukul',
    'menular': 'tular',
    'menularnya': 'tular',
    'menularkan': 'tular',
    'menularkannya': 'tular',
    'menulari': 'tular',
    'menularan': 'tular',
    'menularinya': 'tular',
    'tertulari': 'tular',
    'penularan': 'tular',
    'penularannya': 'tular',
    'penularanan': 'tular',
    'ketularan': 'tular',
    'menumbang': 'tumbang',
    'menumbangkan': 'tumbang',
    'menumbangkannya': 'tumbang',
    'tumpasan': 'tumpas',
    'penumpas': 'tumpas',
    'penumpasan': 'tumpas',
    'menumpas': 'tumpas',
    'menumpasnya': 'tumpas',
    'menumpaskan': 'tumpas',
    'penumpasannya': 'tumpas',
    'penunaian': 'tunai',
    'menunaikan': 'tunai',
    'menunaikannya': 'tunai',
    'pertunaian': 'tunai',
    'penunda': 'tunda',
    'penundaan': 'tunda',
    'menunda': 'tunda',
    'menundanya': 'tunda',
    'menundaan': 'tunda',
    'bertunda': 'tunda',
    'tertunda': 'tunda',
    'tertundanya': 'tunda',
    'penundaannya': 'tunda',
    'penundaani': 'tunda',
    'menundakan': 'tunda',
    'menunda-nunda': 'tunda',
    'menunda-nundanya': 'tunda',
    'bertunda-tunda': 'tunda',
    'menunduk': 'tunduk',
    'menunduklah': 'tunduk',
    'menundukkan': 'tunduk',
    'menundukkannya': 'tunduk',
    'menundukan': 'tunduk',
    'petunduk': 'tunduk',
    'penundukan': 'tunduk',
    'ketundukan': 'tunduk',
    'ketertundukan': 'tunduk',
    'ketertundukannya': 'tunduk',
    'menunduk-nunduk': 'tunduk',
    'menunggang': 'tunggang',
    'menunggangnya': 'tunggang',
    'menunggangi': 'tunggang',
    'tunggangan': 'tunggang',
    'tunggangannya': 'tunggang',
    'penunggang': 'tunggang',
    'penunggangnya': 'tunggang',
    'penunggangan': 'tunggang',
    'bertunggang': 'tunggang',
    'menungganginya': 'tunggang',
    'tertunggang': 'tunggang',
    'bersetunggang': 'tunggang',
    'menunggangkan': 'tunggang',
    'tunggang-tunggit': 'tunggang',
    'tunggang-tunggik': 'tunggang',
    'tunggang-tungging': 'tunggang',
    'mempertunggangkan': 'tunggang',
    'penunggu': 'tunggu',
    'penunggunya': 'tunggu',
    'penungguan': 'tunggu',
    'menunggu': 'tunggu',
    'menunggunya': 'tunggu',
    'menunggulah': 'tunggu',
    'menunggukan': 'tunggu',
    'menunggui': 'tunggu',
    'menungguku': 'tunggu',
    'menunggumu': 'tunggu',
    'menungguinya': 'tunggu',
    'menungguiku': 'tunggu',
    'bertunggu': 'tunggu',
    'menuntun': 'tuntun',
    'menuntunnya': 'tuntun',
    'menuntunkan': 'tuntun',
    'menuntunku': 'tuntun',
    'menuntunmu': 'tuntun',
    'penuntun': 'tuntun',
    'penuntunnya': 'tuntun',
    'penuntunan': 'tuntun',
    'tuntunan': 'tuntun',
    'tuntunannya': 'tuntun',
    'bertuntun': 'tuntun',
    'menuris': 'turis',
    'seturut': 'turut',
    'menurut': 'turut',
    'menurutnya': 'turut',
    'menurutkan': 'turut',
    'menuruti': 'turut',
    'menurutan': 'turut',
    'menurutnyalah': 'turut',
    'menurutku': 'turut',
    'menurutmu': 'turut',
    'menurut-mu': 'turut',
    'penurut': 'turut',
    'penurutnya': 'turut',
    'penurutan': 'turut',
    'turutan': 'turut',
    'menurutinya': 'turut',
    'berturuti': 'turut',
    'perturutan': 'turut',
    'perturutannya': 'turut',
    'turut-menurut': 'turut',
    'turut-turutan': 'turut',
    'berturut-turut': 'turut',
    'berturut-turutnya': 'turut',
    'berturut-turutlah': 'turut',
    'memperturutkan': 'turut',
    'memperturut-turutkan': 'turut',
    'menusuk': 'tusuk',
    'menusuknya': 'tusuk',
    'menusukkan': 'tusuk',
    'menusukkannya': 'tusuk',
    'menusuki': 'tusuk',
    'menusukan': 'tusuk',
    'menusukku': 'tusuk',
    'menusukmu': 'tusuk',
    'tertusuk': 'tusuk',
    'tertusuknya': 'tusuk',
    'menusuk-nusuk': 'tusuk',
    'menusuk-nusukkan': 'tusuk',
    'menusuk-nusukan': 'tusuk',
    'menutup': 'tutup',
    'menutupnya': 'tutup',
    'menutupkan': 'tutup',
    'menutupi': 'tutup',
    'menutupan': 'tutup',
    'menutupku': 'tutup',
    'tutupan': 'tutup',
    'tutupannya': 'tutup',
    'penutup': 'tutup',
    'penutupnya': 'tutup',
    'penutupkan': 'tutup',
    'penutupi': 'tutup',
    'penutupan': 'tutup',
    'tertutup': 'tutup',
    'tertutupnya': 'tutup',
    'tertutuplah': 'tutup',
    'tertutupi': 'tutup',
    'bertutup': 'tutup',
    'bertutupkan': 'tutup',
    'menutupinya': 'tutup',
    'penutupannya': 'tutup',
    'penutupani': 'tutup',
    'ketertutupan': 'tutup',
    'ketertutupannya': 'tutup',
    'tersadar': 'sadar',
    'tersadarkan': 'sadar',
    'menyadar': 'sadar',
    'menyadarkan': 'sadar',
    'menyadarkannya': 'sadar',
    'menyadari': 'sadar',
    'menyadarinya': 'sadar',
    'menyadarilah': 'sadar',
    'kesadaran': 'sadar',
    'kesadarannya': 'sadar',
    'kesadaranku': 'sadar',
    'penyadaran': 'sadar',
    'penyadaranlah': 'sadar',
    'menyadarkanku': 'sadar',
    'menyadarkanmu': 'sadar',
    'sahutan': 'sahut',
    'sahutannya': 'sahut',
    'bersahut': 'sahut',
    'bersahutan': 'sahut',
    'penyahut': 'sahut',
    'menyahut': 'sahut',
    'menyahutnya': 'sahut',
    'menyahuti': 'sahut',
    'menyahutinya': 'sahut',
    'penyahutan': 'sahut',
    'sahut-menyahut': 'sahut',
    'bersahut-sahutan': 'sahut',
    'saingan': 'saing',
    'saingannya': 'saing',
    'sainganku': 'saing',
    'sainganmu': 'saing',
    'sesaing': 'saing',
    'pesaing': 'saing',
    'pesaingnya': 'saing',
    'pesaingan': 'saing',
    'pesaingku': 'saing',
    'penyaing': 'saing',
    'bersaing': 'saing',
    'bersaingnya': 'saing',
    'bersainglah': 'saing',
    'bersaingan': 'saing',
    'menyaingi': 'saing',
    'menyainginya': 'saing',
    'menyaingikan': 'saing',
    'menyaingiku': 'saing',
    'tersaingi': 'saing',
    'persaingan': 'saing',
    'persaingannya': 'saing',
    'persainganlah': 'saing',
    'persainganan': 'saing',
    'bersaingannya': 'saing',
    'mempersaingkan': 'saing',
    'saing-menyaing': 'saing',
    'penyalahgunaan': 'salah guna',
    'penyalahgunaannya': 'salah guna',
    'menyalahgunakan': 'salah guna',
    'menyalahgunakannya': 'salah guna',
    'salaian': 'salai',
    'tersalai': 'salai',
    'bersalai': 'salai',
    'saluran': 'salur',
    'salurannya': 'salur',
    'salurankan': 'salur',
    'saluranku': 'salur',
    'penyalur': 'salur',
    'penyalurnya': 'salur',
    'penyalurkan': 'salur',
    'penyaluran': 'salur',
    'tersalur': 'salur',
    'tersalurnya': 'salur',
    'tersalurkan': 'salur',
    'tersalurkannya': 'salur',
    'tersaluri': 'salur',
    'penyalurannya': 'salur',
    'penyaluranlah': 'salur',
    'penyaluranan': 'salur',
    'menyalurkan': 'salur',
    'menyalurkannya': 'salur',
    'menyalurkankannya': 'salur',
    'penyamak': 'samak',
    'penyamaknya': 'samak',
    'penyamakan': 'samak',
    'menyamak': 'samak',
    'menyamakkan': 'samak',
    'kenyamanan': 'nyaman',
    'kenyamanannya': 'nyaman',
    'kenyamananlah': 'nyaman',
    'kenyamananan': 'nyaman',
    'kenyamananmu': 'nyaman',
    'menyamankan': 'saman',
    'menyamankannya': 'saman',
    'sambaran': 'sambar',
    'sambarannya': 'sambar',
    'menyambar': 'sambar',
    'menyambarnya': 'sambar',
    'menyambarku': 'sambar',
    'penyambar': 'sambar',
    'tersambar': 'sambar',
    'tersambarnya': 'sambar',
    'bersambaran': 'sambar',
    'sambar-menyambar': 'sambar',
    'menyambar-nyambar': 'sambar',
    'bersambar-sambaran': 'sambar',
    'sambutan': 'sambut',
    'sambutannya': 'sambut',
    'menyambut': 'sambut',
    'menyambutnya': 'sambut',
    'menyambutkan': 'sambut',
    'menyambutan': 'sambut',
    'menyambutku': 'sambut',
    'menyambutmu': 'sambut',
    'bersambut': 'sambut',
    'bersambutan': 'sambut',
    'penyambut': 'sambut',
    'penyambutnya': 'sambut',
    'penyambutkan': 'sambut',
    'penyambutan': 'sambut',
    'penyambutannya': 'sambut',
    'sambut-menyambut': 'sambut',
    'bersambut-sambutan': 'sambut',
    'penyampah': 'sampah',
    'menyampah': 'sampah',
    'menyampahi': 'sampah',
    'penyampahan': 'sampah',
    'persampahan': 'sampah',
    'mempersampahkan': 'sampah',
    'tersampang': 'sampang',
    'menyampang': 'sampang',
    'menyampangi': 'sampang',
    'menyampu': 'sampu',
    'menyampuk': 'sampuk',
    'bersampuk': 'sampuk',
    'tersampuk': 'sampuk',
    'kesampukan': 'sampuk',
    'menyampukkan': 'sampuk',
    'samunan': 'samun',
    'menyamun': 'samun',
    'penyamun': 'samun',
    'kesamunan': 'samun',
    'menyamuni': 'samun',
    'penyamunan': 'samun',
    'bersandiwara': 'sandiwara',
    'penyandiwaraan': 'sandiwara',
    'menyandiwarakan': 'sandiwara',
    'penyangga': 'sangga',
    'penyangganya': 'sangga',
    'penyanggaan': 'sangga',
    'bersangga': 'sangga',
    'menyangga': 'sangga',
    'menyangganya': 'sangga',
    'bersanggakan': 'sangga',
    'sangkaan': 'sangka',
    'sangkaannya': 'sangka',
    'tersangka': 'sangka',
    'tersangkanya': 'sangka',
    'tersangkalah': 'sangka',
    'tersangkakan': 'sangka',
    'tersangkai': 'sangka',
    'tersangkaan': 'sangka',
    'menyangka': 'sangka',
    'menyangkanya': 'sangka',
    'menyangkakan': 'sangkak',
    'menyangkakannya': 'sangka',
    'bersangka': 'sangka',
    'sangkalan': 'sangkal',
    'sangkalannya': 'sangkal',
    'bersangkal': 'sangkal',
    'penyangkal': 'sangkal',
    'penyangkalan': 'sangkal',
    'menyangkal': 'sangkal',
    'menyangkalnya': 'sangkal',
    'menyangkali': 'sangkal',
    'penyangkalannya': 'sangkal',
    'penyangkalanku': 'sangkal',
    'sangkutan': 'sangkut',
    'sangkutannya': 'sangkut',
    'penyangkut': 'sangkut',
    'penyangkutnya': 'sangkut',
    'bersangkut': 'sangkut',
    'bersangkutkan': 'sangkut',
    'bersangkutan': 'sangkut',
    'menyangkut': 'sangkut',
    'menyangkutnya': 'sangkut',
    'menyangkutkan': 'sangkut',
    'menyangkutkannya': 'sangkut',
    'tersangkut': 'sangkut',
    'tersangkutnya': 'sangkut',
    'tersangkutan': 'sangkut',
    'persangkutan': 'sangkut',
    'bersangkutannya': 'sangkut',
    'bersangkutanlah': 'sangkut',
    'mempersangkutkan': 'sangkut',
    'sangkut-menyangkut': 'sangkut',
    'menyangkut-nyangkutkan': 'sangkut',
    'sanjungan': 'sanjung',
    'sanjungannya': 'sanjung',
    'tersanjung': 'sanjung',
    'tersanjungnya': 'sanjung',
    'menyanjung': 'sanjung',
    'menyanjungnya': 'sanjung',
    'menyanjungku': 'sanjung',
    'penyanjung': 'sanjung',
    'penyanjungan': 'sanjung',
    'menyanjung-nyanjung': 'sanjung',
    'menyanjung-nyanjungkan': 'sanjung',
    'sapaan': 'sapa',
    'sapaannya': 'sapa',
    'disapa': 'sapa',
    'disapanya': 'sapa',
    'disapai': 'sapa',
    'menyapa': 'sapa',
    'menyapanya': 'sapa',
    'menyapalah': 'sapa',
    'menyapakan': 'sapa',
    'menyapai': 'sapa',
    'menyapaku': 'sapa',
    'bersapa': 'sapa',
    'bersapaan': 'sapa',
    'tersapa': 'sapa',
    'sapa-menyapa': 'sapa',
    'bersapa-sapaan': 'sapa',
    'menyara': 'sara',
    'menyarakan': 'sarak',
    'menyarakannya': 'sara',
    'bersara': 'sara',
    'bersarakan': 'sarak',
    'menyarai': 'sara',
    'tersara bara': 'sara',
    'saranan': 'saran',
    'saranannya': 'saran',
    'saranani': 'saran',
    'menyarani': 'saran',
    'menyarankan': 'saran',
    'menyarankannya': 'saran',
    'menyarankankan': 'saran',
    'menyarankanku': 'saran',
    'sari-sari': 'sari',
    'sari-sarinya': 'sari',
    'menyarikan': 'sari',
    'sayatan': 'sayat',
    'sayatannya': 'sayat',
    'sesayat': 'sayat',
    'tersayat': 'sayat',
    'tersayatnya': 'sayat',
    'menyayat': 'sayat',
    'menyayatnya': 'sayat',
    'menyayatkan': 'sayat',
    'menyayati': 'sayat',
    'menyayat-nyayat': 'sayat',
    'kesayuan': 'sayu',
    'menyayukan': 'sayu',
    'sebaran': 'sebar',
    'sebarannya': 'sebar',
    'penyebar': 'sebar',
    'penyebarnya': 'sebar',
    'penyebarkan': 'sebar',
    'penyebaran': 'sebar',
    'menyebar': 'sebar',
    'menyebarnya': 'sebar',
    'menyebarlah': 'sebar',
    'menyebarkan': 'sebar',
    'menyebarkannya': 'sebar',
    'menyebari': 'sebar',
    'menyebaran': 'sebar',
    'tersebar': 'sebar',
    'tersebarnya': 'sebar',
    'tersebarlah': 'sebar',
    'tersebarkan': 'sebar',
    'tersebari': 'sebar',
    'bersebar': 'sebar',
    'bersebaran': 'sebar',
    'penyebarannya': 'sebar',
    'persebaran': 'sebar',
    'persebarannya': 'sebar',
    'menyebarkanlah': 'sebar',
    'tersebar luas': 'sebar luas',
    'penyebarluasan': 'sebar luas',
    'penyebarluasannya': 'sebar luas',
    'menyebarluaskan': 'sebar luas',
    'menyebarluaskannya': 'sebar luas',
    'menyebat': 'sebat',
    'menyebatkan': 'sebat',
    'kesebatan': 'sebat',
    'penyebatan': 'sebat',
    'sebutan': 'sebut',
    'sebutannya': 'sebut',
    'tersebut': 'sebut',
    'tersebutnya': 'sebut',
    'tersebutlah': 'sebut',
    'tersebutkan': 'sebut',
    'tersebuti': 'sebut',
    'penyebut': 'sebut',
    'penyebutnya': 'sebut',
    'penyebutkan': 'sebut',
    'penyebutan': 'sebut',
    'menyebut': 'sebut',
    'menyebutnya': 'sebut',
    'menyebutkan': 'sebut',
    'menyebutkannya': 'sebut',
    'menyebutan': 'sebut',
    'menyebutku': 'sebut',
    'menyebutmu': 'sebut',
    'penyebutannya': 'sebut',
    'penyebutanan': 'sebut',
    'menyebutkankan': 'sebut',
    'menyebutkani': 'sebut',
    'bersedih': 'sedih',
    'bersedihlah': 'sedih',
    'penyedih': 'sedih',
    'kesedihan': 'sedih',
    'kesedihannya': 'sedih',
    'kesedihanlah': 'sedih',
    'kesedihanku': 'sedih',
    'kesedihanmu': 'sedih',
    'menyedihkan': 'sedih',
    'menyedihkannya': 'sedih',
    'menyedihkanlah': 'sedih',
    'tersedih-sedih': 'sedih',
    'penyeduh': 'seduh',
    'penyeduhan': 'seduh',
    'menyeduh': 'seduh',
    'menyeduhnya': 'seduh',
    'menyeduhkan': 'seduh',
    'terseduh-seduh': 'seduh',
    'penyegan': 'segan',
    'keseganan': 'segan',
    'kesegananan': 'segan',
    'menyegani': 'segan',
    'menyeganinya': 'segan',
    'segan-segan': 'segan',
    'segan-segannya': 'segan',
    'segan-menyegan': 'segan',
    'segan-menyegani': 'segan',
    'menyejatkan': 'sejat',
    'sekaan': 'seka',
    'berseka': 'seka',
    'menyeka': 'seka',
    'menyekanya': 'seka',
    'menyekalah': 'seka',
    'menyekai': 'seka',
    'menyekakan': 'seka',
    'peselam': 'selam',
    'terselam': 'selam',
    'terselami': 'selam',
    'menyelam': 'selam',
    'menyelamnya': 'selam',
    'menyelamlah': 'selam',
    'menyelamkan': 'selam',
    'menyelami': 'selam',
    'berselam': 'selam',
    'penyelam': 'selam',
    'penyelamnya': 'selam',
    'penyelaman': 'selam',
    'menyelaminya': 'selam',
    'penyelamannya': 'selam',
    'penyelamanan': 'selam',
    'menyelar': 'selar',
    'menyelarkan': 'selar',
    'selenggaraan': 'selenggara',
    'menyelenggara': 'selenggara',
    'menyelenggarakan': 'selenggara',
    'menyelenggarakannya': 'selenggara',
    'menyelenggaraan': 'selenggara',
    'penyelenggara': 'selenggara',
    'penyelenggaranya': 'selenggara',
    'penyelenggaralah': 'selenggara',
    'penyelenggarakan': 'selenggara',
    'penyelenggarai': 'selenggara',
    'penyelenggaraan': 'selenggara',
    'terselenggara': 'selenggara',
    'terselenggaranya': 'selenggara',
    'terselenggaralah': 'selenggara',
    'terselenggarakan': 'selenggara',
    'terselenggarakannya': 'selenggara',
    'penyelenggaraannya': 'selenggara',
    'selesaian': 'selesai',
    'keselesaian': 'selesai',
    'penyelesaian': 'selesai',
    'penyelesaiannya': 'selesai',
    'penyelesaianlah': 'selesai',
    'penyelesaianan': 'selesai',
    'menyelesaikan': 'selesai',
    'menyelesaikannya': 'selesai',
    'terselesaikan': 'selesai',
    'terselesaikannya': 'selesai',
    'menyeleweng': 'seleweng',
    'menyelewengnya': 'seleweng',
    'menyelewengkan': 'seleweng',
    'menyelewengkannya': 'seleweng',
    'menyelewengi': 'seleweng',
    'menyelewengan': 'seleweng',
    'penyeleweng': 'seleweng',
    'penyelewengkan': 'seleweng',
    'penyelewengan': 'seleweng',
    'penyelewengannya': 'seleweng',
    'penyelidik': 'selidik',
    'penyelidiknya': 'selidik',
    'penyelidikkan': 'selidik',
    'penyelidiki': 'selidik',
    'penyelidikan': 'selidik',
    'menyelidik': 'selidik',
    'menyelidiknya': 'selidik',
    'menyelidiki': 'selidik',
    'menyelidikan': 'selidik',
    'menyelidikinya': 'selidik',
    'menyelidikii': 'selidik',
    'penyelidikannya': 'selidik',
    'berselimut': 'selimut',
    'berselimutkan': 'selimut',
    'berselimuti': 'selimut',
    'menyelimuti': 'selimut',
    'menyelimutinya': 'selimut',
    'menyelimutiku': 'selimut',
    'menyelimutimu': 'selimut',
    'menyelimutkan': 'selimut',
    'penyelinap': 'selinap',
    'penyelinapan': 'selinap',
    'menyelinap': 'selinap',
    'menyelinapnya': 'selinap',
    'menyelinaplah': 'selinap',
    'menyelinapkan': 'selinap',
    'menyelinapkannya': 'selinap',
    'penyelinapannya': 'selinap',
    'selipan': 'selip',
    'menyelip': 'selip',
    'menyelipnya': 'selip',
    'menyelipkan': 'selip',
    'menyelipkannya': 'selip',
    'menyelipi': 'selip',
    'terselip': 'selip',
    'terselipnya': 'selip',
    'terseliplah': 'selip',
    'terselipkan': 'selip',
    'terselipi': 'selip',
    'terselip': 'selip',
    'menyelisik': 'selisik',
    'penyelisikan': 'selisik',
    'terselit': 'selit',
    'menyelitkan': 'selit',
    'berselit sepit': 'selit',
    'berselit-selit': 'selit',
    'berselubung': 'selubung',
    'berselubungkan': 'selubung',
    'menyelubung': 'selubung',
    'menyelubungkan': 'selubung',
    'menyelubungi': 'selubung',
    'penyelubung': 'selubung',
    'penyelubungan': 'selubung',
    'terselubung': 'selubung',
    'terselubungnya': 'selubung',
    'terselubungi': 'selubung',
    'menyelubunginya': 'selubung',
    'seludupan': 'seludup',
    'penyeludup': 'seludup',
    'penyeludupan': 'seludup',
    'menyeludup': 'seludup',
    'menyeludupkan': 'seludup',
    'menyeludupkannya': 'seludup',
    'berseluk': 'seluk',
    'menyeluk': 'seluk',
    'seluk-semeluk': 'seluk',
    'memperselukkan': 'seluk',
    'semahan': 'semah',
    'menyemah': 'semah',
    'penyemah': 'semah',
    'semah-semah': 'semah',
    'menyemahkan': 'semah',
    'semaian': 'semai',
    'tersemai': 'semai',
    'tersemainya': 'semai',
    'menyemai': 'semai',
    'menyemaikan': 'semai',
    'pesemaian': 'semai',
    'penyemaian': 'semai',
    'penyemaiannya': 'semai',
    'persemaian': 'semai',
    'persemaiannya': 'semai',
    'mempersemaikan': 'semai',
    'sematan': 'semat',
    'menyemat': 'semat',
    'menyematkan': 'semat',
    'menyematkannya': 'semat',
    'menyemati': 'semat',
    'tersemat': 'semat',
    'tersematnya': 'semat',
    'tersematkan': 'semat',
    'tersemati': 'semat',
    'penyemat': 'semat',
    'penyematan': 'semat',
    'penyematannya': 'semat',
    'sembelihan': 'sembelih',
    'penyembelih': 'sembelih',
    'penyembelihan': 'sembelih',
    'menyembelih': 'sembelih',
    'menyembelihnya': 'sembelih',
    'penyembelihannya': 'sembelih',
    'penyembuh': 'sembuh',
    'penyembuhnya': 'sembuh',
    'penyembuhkan': 'sembuh',
    'penyembuhan': 'sembuh',
    'kesembuhan': 'sembuh',
    'kesembuhannya': 'sembuh',
    'kesembuhanku': 'sembuh',
    'penyembuhannya': 'sembuh',
    'penyembuhanku': 'sembuh',
    'penyembuhanmu': 'sembuh',
    'menyembuhkan': 'sembuh',
    'menyembuhkannya': 'sembuh',
    'menyembuhkanku': 'sembuh',
    'menyembuhkanmu': 'sembuh',
    'bersenang': 'senang',
    'kesenangan': 'senang',
    'kesenangannya': 'senang',
    'kesenanganku': 'senang',
    'kesenanganmu': 'senang',
    'menyenangi': 'senang',
    'menyenanginya': 'senang',
    'menyenangkan': 'senang',
    'menyenangkannya': 'senang',
    'mempersenang': 'senang',
    'mempersenangkan': 'senang',
    'bersenang-senang': 'senang',
    'bersenang-senangnya': 'senang',
    'bersenang-senanglah': 'senang',
    'bersenang-senangkan': 'senang',
    'menyenaraikan': 'senarai',
    'sendalan': 'sendal',
    'tersendal': 'sendal',
    'menyendal': 'sendal',
    'kesendalan': 'sendal',
    'menyendalkan': 'sendal',
    'bersendeng': 'sendeng',
    'menyendeng': 'sendeng',
    'menyendengkan': 'sendeng',
    'bersendengan': 'sendeng',
    'tersendeng-sendeng': 'sendeng',
    'sengauan': 'sengau',
    'menyengau': 'sengau',
    'penyengauan': 'sengau',
    'menyengaukan': 'sengau',
    'sengau-sengauan': 'sengau',
    'tersenget': 'senget',
    'menyenget': 'senget',
    'menyengetkan': 'senget',
    'sentakan': 'sentak',
    'menyentak': 'sentak',
    'menyentaknya': 'sentak',
    'menyentakkan': 'sentak',
    'menyentakan': 'sentak',
    'tersentak': 'sentak',
    'tersentaklah': 'sentak',
    'menyentak-nyentak': 'sentak',
    'sepakan': 'sepak',
    'sepakannya': 'sepak',
    'sepakanku': 'sepak',
    'penyepak': 'sepak',
    'menyepak': 'sepak',
    'menyepaknya': 'sepak',
    'menyepakkan': 'sepak',
    'menyepaki': 'sepak',
    'penyepakan': 'sepak',
    'bersepak-sepakan': 'sepak',
    'menyepak-nyepakkan': 'sepak',
    'keseraman': 'seram',
    'keseramannya': 'seram',
    'menyeramkan': 'seram',
    'menyeramkannya': 'seram',
    'menyeranah': 'seranah',
    'serangan': 'serang',
    'serangannya': 'serang',
    'serangankan': 'serang',
    'seranganan': 'serang',
    'seranganmu': 'serang',
    'menyerang': 'serang',
    'menyerangnya': 'serang',
    'menyeranglah': 'serang',
    'menyerangkan': 'serang',
    'menyerangan': 'serang',
    'menyerangku': 'serang',
    'menyerangmu': 'serang',
    'penyerang': 'serang',
    'penyerangnya': 'serang',
    'penyeranglah': 'serang',
    'penyerangkan': 'serang',
    'penyerangan': 'serang',
    'penyerangmu': 'serang',
    'berserang': 'serang',
    'berserangan': 'serang',
    'terserang': 'serang',
    'terserangnya': 'serang',
    'penyerangannya': 'serang',
    'penyeranganlah': 'serang',
    'serang-serangan': 'serang',
    'serang-serangannya': 'serang',
    'serang-menyerang': 'serang',
    'teserbu': 'serbu',
    'serbuan': 'serbu',
    'serbuannya': 'serbu',
    'menyerbu': 'serbu',
    'menyerbunya': 'serbu',
    'penyerbuan': 'serbu',
    'penyerbuannya': 'serbu',
    'menyerbukan': 'serbu',
    'terseret': 'seret',
    'terseretnya': 'seret',
    'terseretlah': 'seret',
    'penyeret': 'seret',
    'penyeretan': 'seret',
    'menyeret': 'seret',
    'menyeretnya': 'seret',
    'menyeretkan': 'seret',
    'menyeretku': 'seret',
    'menyeret-nyeret': 'seret',
    'menyerkap': 'serkap',
    'menyerkapi': 'serkap',
    'penyerkapan': 'serkap',
    'teserlah': 'serlah',
    'menyerlah': 'serlah',
    'penyesah': 'sesah',
    'penyesahan': 'sesah',
    'bersesah': 'sesah',
    'menyesah': 'sesah',
    'menyesahkan': 'sesah',
    'sesalan': 'sesal',
    'bersesal': 'sesal',
    'menyesal': 'sesal',
    'menyesalnya': 'sesal',
    'menyesallah': 'sesal',
    'menyesalkan': 'sesal',
    'menyesalkannya': 'sesal',
    'menyesali': 'sesal',
    'menyesalinya': 'sesal',
    'penyesalan': 'sesal',
    'penyesalannya': 'sesal',
    'penyesalanlah': 'sesal',
    'penyesalanku': 'sesal',
    'bersesalan': 'sesal',
    'menyesalkanlah': 'sesal',
    'sesal-menyesali': 'sesal',
    'penyetir': 'setir',
    'penyetiran': 'setir',
    'menyetir': 'setir',
    'menyetirnya': 'setir',
    'menyetiri': 'setir',
    'sewaan': 'sewa',
    'sewaannya': 'sewa',
    'menyewa': 'sewa',
    'menyewanya': 'sewa',
    'menyewakan': 'sewa',
    'menyewakannya': 'sewa',
    'menyewaan': 'sewa',
    'menyewaku': 'sewa',
    'penyewa': 'sewa',
    'penyewanya': 'sewa',
    'penyewaan': 'sewa',
    'penyewaannya': 'sewa',
    'mempersewakan': 'sewa',
    'bersiap': 'siap',
    'bersiapnya': 'siap',
    'bersiaplah': 'siap',
    'bersiapkan': 'siap',
    'bersiapan': 'siap',
    'penyiapan': 'siap',
    'penyiapannya': 'siap',
    'persiapan': 'siap',
    'persiapannya': 'siap',
    'persiapanlah': 'siap',
    'persiapankan': 'siap',
    'persiapanan': 'siap',
    'persiapanku': 'siap',
    'persiapanmu': 'siap',
    'menyiapkan': 'siap',
    'menyiapkannya': 'siap',
    'menyiapkanlah': 'siap',
    'menyiapkanku': 'siap',
    'bersiap-siap': 'siap',
    'bersiap-siaplah': 'siap',
    'bersiap-siapkan': 'siap',
    'mempersiapkan': 'siap',
    'mempersiapkannya': 'siap',
    'mempersiapkanan': 'siap',
    'siaran': 'siar',
    'siarannya': 'siar',
    'siarankan': 'siar',
    'siaranku': 'siar',
    'pesiar': 'siar',
    'pesiarnya': 'siar',
    'penyiar': 'siar',
    'penyiarnya': 'siar',
    'penyiaran': 'siar',
    'tersiar': 'siar',
    'tersiarnya': 'siar',
    'tersiarlah': 'siar',
    'tersiarkan': 'siar',
    'tersiarkannya': 'siar',
    'menyiar': 'siar',
    'menyiarkan': 'siar',
    'menyiarkannya': 'siar',
    'menyiaran': 'siar',
    'bersiar': 'siar',
    'bersiaran': 'siar',
    'penyiarannya': 'siar',
    'persiaran': 'siar',
    'bersiar-siar': 'siar',
    'menyiasat': 'siasat',
    'menyiasatkan': 'siasat',
    'menyiasati': 'siasat',
    'bersiasat': 'siasat',
    'menyiasatinya': 'siasat',
    'menyidai': 'sidai',
    'menyidaikan': 'sidai',
    'menyigung': 'sigung',
    'tersihir': 'sihir',
    'menyihir': 'sihir',
    'menyihirnya': 'sihir',
    'menyihiri': 'sihir',
    'menyihirkan': 'sihir',
    'siksaan': 'siksa',
    'siksaannya': 'siksa',
    'penyiksa': 'siksa',
    'penyiksanya': 'siksa',
    'penyiksaan': 'siksa',
    'penyiksaku': 'siksa',
    'tersiksa': 'siksa',
    'tersiksanya': 'siksa',
    'menyiksa': 'siksa',
    'menyiksanya': 'siksa',
    'menyiksalah': 'siksa',
    'menyiksakan': 'siksa',
    'menyiksaan': 'siksa',
    'menyiksaku': 'siksa',
    'menyiksamu': 'siksa',
    'menyiksai': 'siksa',
    'penyiksaannya': 'siksa',
    'ketersiksaan': 'siksa',
    'bersiku': 'siku',
    'menyiku': 'siku',
    'menyikunya': 'siku',
    'siku-siku': 'siku',
    'siku-sikunya': 'siku',
    'menyikukan': 'siku',
    'tersilau': 'silau',
    'tersilaukan': 'silau',
    'menyilau': 'silau',
    'menyilaukan': 'silau',
    'kesilauan': 'silau',
    'menyimbah': 'simbah',
    'bersimbah': 'simbah',
    'bersimbahkan': 'simbah',
    'tersimbah': 'simbah',
    'menyimbahkan': 'simbah',
    'simpanan': 'simpan',
    'simpanannya': 'simpan',
    'simpananmu': 'simpan',
    'menyimpan': 'simpan',
    'menyimpannya': 'simpan',
    'menyimpankan': 'simpan',
    'menyimpanan': 'simpan',
    'bersimpan': 'simpan',
    'penyimpan': 'simpan',
    'penyimpannya': 'simpan',
    'penyimpanan': 'simpan',
    'tersimpan': 'simpan',
    'tersimpannya': 'simpan',
    'menyimpani': 'simpan',
    'penyimpanannya': 'simpan',
    'penyimpananan': 'simpan',
    'sindiran': 'sindir',
    'sindirannya': 'sindir',
    'penyindir': 'sindir',
    'penyindiran': 'sindir',
    'menyindir': 'sindir',
    'menyindirnya': 'sindir',
    'menyindirkan': 'sindir',
    'menyindiri': 'sindir',
    'tersindir': 'sindir',
    'tersindiri': 'sindir',
    'sindir-menyindir': 'sindir',
    'menyinggung': 'singgung',
    'menyinggungnya': 'singgung',
    'menyinggungkan': 'singgung',
    'menyinggungku': 'singgung',
    'tersinggung': 'singgung',
    'tersinggungnya': 'singgung',
    'persinggungan': 'singgung',
    'persinggungannya': 'singgung',
    'bersinggungan': 'singgung',
    'menyingkir': 'singkir',
    'menyingkirnya': 'singkir',
    'menyingkirlah': 'singkir',
    'menyingkirkan': 'singkir',
    'menyingkirkannya': 'singkir',
    'menyingkiran': 'singkir',
    'tersingkir': 'singkir',
    'tersingkirnya': 'singkir',
    'tersingkirkan': 'singkir',
    'tersingkirkannya': 'singkir',
    'tersingkiri': 'singkir',
    'penyingkir': 'singkir',
    'penyingkiran': 'singkir',
    'menyingkiri': 'singkir',
    'menyingkirikan': 'singkir',
    'penyingkirannya': 'singkir',
    'menyingkirkanku': 'singkir',
    'menyingkirkanmu': 'singkir',
    'tersingsing': 'singsing',
    'menyingsing': 'singsing',
    'menyingsingkan': 'singsing',
    'disisih': 'sisih',
    'disisihkan': 'sisih',
    'disisihkannya': 'sisih',
    'tersisih': 'sisih',
    'tersisihnya': 'sisih',
    'tersisihkan': 'sisih',
    'tersisihkannya': 'sisih',
    'tersisihan': 'sisih',
    'menyisih': 'sisih',
    'menyisihkan': 'sisih',
    'menyisihkannya': 'sisih',
    'menyisihan': 'sisih',
    'penyisihan': 'sisih',
    'penyisihannya': 'sisih',
    'menyisihkankan': 'sisih',
    'ketersisihan': 'sisih',
    'sisipan': 'sisip',
    'tersisip': 'sisip',
    'tersisipnya': 'sisip',
    'tersisipkan': 'sisip',
    'tersisipi': 'sisip',
    'menyisip': 'sisip',
    'menyisipkan': 'sisip',
    'menyisipkannya': 'sisip',
    'menyisipi': 'sisip',
    'penyisip': 'sisip',
    'penyisipan': 'sisip',
    'kesisipan': 'sisip',
    'mempersisipkan': 'sisip',
    'sogokan': 'sogok',
    'sogokannya': 'sogok',
    'penyogok': 'sogok',
    'penyogokkan': 'sogok',
    'penyogokan': 'sogok',
    'menyogok': 'sogok',
    'menyogoknya': 'sogok',
    'sokongan': 'sokong',
    'sokongannya': 'sokong',
    'sokonganku': 'sokong',
    'menyokong': 'sokong',
    'menyokongnya': 'sokong',
    'penyokong': 'sokong',
    'penyokongnya': 'sokong',
    'penyokongan': 'sokong',
    'menyokongkan': 'sokong',
    'menyompoh': 'sompoh',
    'sorotan': 'sorot',
    'sorotannya': 'sorot',
    'menyorot': 'sorot',
    'menyorotnya': 'sorot',
    'menyorotlah': 'sorot',
    'menyorotkan': 'sorot',
    'menyorotkannya': 'sorot',
    'menyoroti': 'sorot',
    'penyorot': 'sorot',
    'penyoroti': 'sorot',
    'penyorotan': 'sorot',
    'menyorotinya': 'sorot',
    'suapan': 'suap',
    'suapannya': 'suap',
    'sesuap': 'suap',
    'menyuap': 'suap',
    'menyuapnya': 'suap',
    'menyuapkan': 'suap',
    'menyuapkannya': 'suap',
    'menyuapi': 'suap',
    'menyuapan': 'suap',
    'penyuap': 'suap',
    'penyuapnya': 'suap',
    'penyuapan': 'suap',
    'bersuap': 'suap',
    'bersuapan': 'suap',
    'menyuapinya': 'suap',
    'penyuapannya': 'suap',
    'menyuapkankan': 'suap',
    'bersuap-suapan': 'suap',
    'sesukat': 'sukat',
    'sukatan': 'sukat',
    'sukatani': 'sukat',
    'penyukat': 'sukat',
    'menyukat': 'sukat',
    'bersukat': 'sukat',
    'penyukatan': 'sukat',
    'sulaan': 'sula',
    'menyula': 'sula',
    'menyulai': 'sula',
    'penyula': 'sula',
    'penyulai': 'sula',
    'penyulaan': 'sula',
    'menyulakan': 'sula',
    'sulaman': 'sulam',
    'sulamannya': 'sulam',
    'sulamani': 'sulam',
    'menyulam': 'sulam',
    'menyulamnya': 'sulam',
    'menyulamkan': 'sulam',
    'bersulam': 'sulam',
    'penyulaman': 'sulam',
    'penyulamannya': 'sulam',
    'pesulap': 'sulap',
    'pesulapnya': 'sulap',
    'sulapan': 'sulap',
    'menyulap': 'sulap',
    'menyulapnya': 'sulap',
    'menyulapmu': 'sulap',
    'penyulap': 'sulap',
    'penyulapan': 'sulap',
    'bersulap': 'sulap',
    'sulingan': 'suling',
    'menyuling': 'suling',
    'tersuling': 'suling',
    'penyulingan': 'suling',
    'penyulingannya': 'suling',
    'menyulingkan': 'suling',
    'sunatan': 'sunat',
    'sunatannya': 'sunat',
    'bersunat': 'sunat',
    'menyunat': 'sunat',
    'menyunatnya': 'sunat',
    'menyunatkan': 'sunat',
    'menyunati': 'sunat',
    'penyunatan': 'sunat',
    'menyunatrasulkan': 'sunat rasul',
    'bersundal': 'sundal',
    'menyundal': 'sundal',
    'persundalan': 'sundal',
    'sungkupan': 'sungkup',
    'penyungkup': 'sungkup',
    'menyungkup': 'sungkup',
    'tersungkup': 'sungkup',
    'bersungkup': 'sungkup',
    'menyungkupi': 'sungkup',
    'menyungkupkan': 'sungkup',
    'tersungkur': 'sungkur',
    'tersungkurnya': 'sungkur',
    'menyungkur': 'sungkur',
    'menyungkurkan': 'sungkur',
    'suntikan': 'suntik',
    'suntikannya': 'suntik',
    'menyuntik': 'suntik',
    'menyuntiknya': 'suntik',
    'menyuntikkan': 'suntik',
    'menyuntikkannya': 'suntik',
    'menyuntikan': 'suntik',
    'menyuntikku': 'suntik',
    'penyuntikan': 'suntik',
    'penyuntikannya': 'suntik',
    'suntingan': 'sunting',
    'suntingannya': 'sunting',
    'menyunting': 'sunting',
    'menyuntingnya': 'sunting',
    'tersunting': 'sunting',
    'bersunting': 'sunting',
    'penyunting': 'sunting',
    'penyuntingan': 'sunting',
    'penyuntingannya': 'sunting',
    'menyuntingkan': 'sunting',
    'bersuntingkan': 'sunting',
    'mempersunting': 'sunting',
    'mempersuntingnya': 'sunting',
    'sunting-menyunting': 'sunting',
    'pesuruh': 'suruh',
    'pesuruhnya': 'suruh',
    'pesuruhan': 'suruh',
    'pesuruhmu': 'suruh',
    'suruhan': 'suruh',
    'suruhannya': 'suruh',
    'penyuruh': 'suruh',
    'penyuruhnya': 'suruh',
    'menyuruh': 'suruh',
    'menyuruhnya': 'suruh',
    'menyuruhkan': 'suruh',
    'menyuruhku': 'suruh',
    'menyuruhmu': 'suruh',
    'suruh-suruhan': 'suruh',
    'susukan': 'susuk',
    'susukanlah': 'susuk',
    'bersusuk': 'susuk',
    'menyusuk': 'susuk',
    'menyusukan': 'susuk',
    'bersusuk-susuk': 'susuk',
    'bersusuk-susukan': 'susuk',
    'susulan': 'susul',
    'susulannya': 'susul',
    'tersusul': 'susul',
    'penyusul': 'susul',
    'penyusulan': 'susul',
    'menyusul': 'susul',
    'menyusulnya': 'susul',
    'menyusullah': 'susul',
    'menyusulkan': 'susul',
    'menyusulkannya': 'susul',
    'menyusuli': 'susul',
    'menyusulku': 'susul',
    'menyusulmu': 'susul',
    'menyusulinya': 'susul',
    'susul-menyusul': 'susul',
    'susunan': 'susun',
    'susunannya': 'susun',
    'susunanlah': 'susun',
    'susunanan': 'susun',
    'menyusun': 'susun',
    'menyusunnya': 'susun',
    'menyusunkan': 'susun',
    'menyusunan': 'susun',
    'penyusun': 'susun',
    'penyusunnya': 'susun',
    'penyusunan': 'susun',
    'bersusun': 'susun',
    'bersusunan': 'susun',
    'tersusun': 'susun',
    'tersusunnya': 'susun',
    'tersusunlah': 'susun',
    'penyusunannya': 'susun',
    'penyusunanan': 'susun',
    'susupan': 'susup',
    'menyusup': 'susup',
    'menyusupnya': 'susup',
    'menyusuplah': 'susup',
    'menyusupkan': 'susup',
    'menyusupi': 'susup',
    'penyusup': 'susup',
    'penyusupnya': 'susup',
    'penyusupan': 'susup',
    'kesusupan': 'susup',
    'penyusupannya': 'susup',
    'susuran': 'susur',
    'menyusur': 'susur',
    'menyusurnya': 'susur',
    'menyusuri': 'susur',
    'penyusur': 'susur',
    'penyusuran': 'susur',
    'menyusurinya': 'susur',
    'penyusur bayar': 'susur',
    'menyusut': 'susut',
    'menyusutnya': 'susut',
    'menyusutlah': 'susut',
    'menyusutkan': 'susut',
    'menyusutan': 'susut',
    'menyusuti': 'susut',
    'penyusutan': 'susut',
    'penyusutannya': 'susut',
    'meraban': 'raban',
    'meracau': 'racau',
    'meradang': 'radang',
    'meradangnya': 'radang',
    'meradangkan': 'radang',
    'meradangan': 'radang',
    'peradang': 'radang',
    'peradangan': 'radang',
    'peradangannya': 'radang',
    'peradanganlah': 'radang',
    'seragam': 'ragam',
    'seragamnya': 'ragam',
    'seragamkan': 'ragam',
    'seragaman': 'ragam',
    'seragamku': 'ragam',
    'seragammu': 'ragam',
    'meragam': 'ragam',
    'meragamkan': 'ragam',
    'keragaman': 'ragam',
    'keragamannya': 'ragam',
    'keragamanan': 'ragam',
    'beragam-ragam': 'ragam',
    'seragam sebahu': 'ragam',
    'meragut': 'ragut',
    'perajut': 'rajut',
    'perajutan': 'rajut',
    'rajutan': 'rajut',
    'rajutannya': 'rajut',
    'terajut': 'rajut',
    'merajut': 'rajut',
    'merajutnya': 'rajut',
    'merajutkan': 'rajut',
    'merajutkannya': 'rajut',
    'merak hati': 'merak',
    'merak simpin': 'merak',
    'ramalan': 'ramal',
    'ramalannya': 'ramal',
    'ramalanmu': 'ramal',
    'meramal': 'ramal',
    'meramalnya': 'ramal',
    'meramalkan': 'ramal',
    'meramalkannya': 'ramal',
    'terambah': 'rambah',
    'merambah': 'rambah',
    'merambahnya': 'rambah',
    'merambahkan': 'rambah',
    'merambahi': 'rambah',
    'perambah': 'rambah',
    'perambahnya': 'rambah',
    'perambahan': 'rambah',
    'rambahan': 'rambah',
    'rambahannya': 'rambah',
    'perambahannya': 'rambah',
    'merambat': 'rambat',
    'merambatnya': 'rambat',
    'merambatlah': 'rambat',
    'merambatkan': 'rambat',
    'merambatkannya': 'rambat',
    'merambati': 'rambat',
    'rambatan': 'rambat',
    'rambatannya': 'rambat',
    'perambat': 'rambat',
    'perambatnya': 'rambat',
    'perambatan': 'rambat',
    'perambatannya': 'rambat',
    'perampas': 'rampas',
    'perampasan': 'rampas',
    'rampasan': 'rampas',
    'rampasannya': 'rampas',
    'merampas': 'rampas',
    'merampasnya': 'rampas',
    'merampasan': 'rampas',
    'merampasi': 'rampas',
    'perampasannya': 'rampas',
    'merancap': 'rancap',
    'meranduk': 'randuk',
    'meranggas': 'ranggas',
    'meranggasnya': 'ranggas',
    'meranggaskan': 'ranggas',
    'rangkakan': 'rangkak',
    'merangkak': 'rangkak',
    'merangkaknya': 'rangkak',
    'merangkaklah': 'rangkak',
    'merangkaki': 'rangkak',
    'perangkakan': 'rangkak',
    'merangkakkan': 'rangkak',
    'merangkak-rangkak': 'rangkak',
    'rangkulan': 'rangkul',
    'rangkulannya': 'rangkul',
    'merangkul': 'rangkul',
    'merangkulnya': 'rangkul',
    'merangkulkan': 'rangkul',
    'merangkuli': 'rangkul',
    'merangkulku': 'rangkul',
    'berangkulan': 'rangkul',
    'berangkulanlah': 'rangkul',
    'rangkul-merangkul': 'rangkul',
    'rangkuman': 'rangkum',
    'rangkumannya': 'rangkum',
    'merangkum': 'rangkum',
    'merangkumnya': 'rangkum',
    'merangkumkan': 'rangkum',
    'merangkumkannya': 'rangkum',
    'merangkuman': 'rangkum',
    'merangkup': 'rangkup',
    'terangkup': 'rangkup',
    'rantaian': 'rantai',
    'terantai': 'rantai',
    'merantai': 'rantai',
    'merantainya': 'rantai',
    'merantaikan': 'rantai',
    'berantai': 'rantai',
    'berantainya': 'rantai',
    'berantailah': 'rantai',
    'berantai-rantai': 'rantai',
    'rapatan': 'rapat',
    'berapat': 'rapat',
    'merapat': 'rapat',
    'merapatnya': 'rapat',
    'merapatlah': 'rapat',
    'merapatkan': 'rapat',
    'merapatkannya': 'rapat',
    'merapati': 'rapat',
    'perapat': 'rapat',
    'perapatan': 'rapat',
    'kerapatan': 'rapat',
    'kerapatannya': 'rapat',
    'kerapatanan': 'rapat',
    'memperapat': 'rapat',
    'perasaian': 'rasai',
    'merasaikan': 'rasai',
    'merasuk': 'rasuk',
    'merasuknya': 'rasuk',
    'merasuki': 'rasuk',
    'kerasukan': 'rasuk',
    'merata': 'rata',
    'meratanya': 'rata',
    'meratalah': 'rata',
    'meratakan': 'rata',
    'meratakannya': 'rata',
    'meratai': 'rata',
    'merataan': 'rata',
    'serata': 'rata',
    'rata-rata': 'rata',
    'rata-ratanya': 'rata',
    'rata-ratalah': 'rata',
    'rata-ratakan': 'rata',
    'rata-ratai': 'rata',
    'pemerataan': 'rata',
    'pemerataannya': 'rata',
    'memeratakan': 'rata',
    'menyeratakan': 'rata',
    'merata-ratakan': 'rata',
    'ratapan': 'ratap',
    'ratapannya': 'ratap',
    'ratapani': 'ratap',
    'meratap': 'ratap',
    'meratapi': 'ratap',
    'meratapinya': 'ratap',
    'raungan': 'raung',
    'raungannya': 'raung',
    'meraung': 'raung',
    'meraungkan': 'raung',
    'meraungi': 'raung',
    'meraung-raung': 'raung',
    'meraung-raungnya': 'raung',
    'meraung-raungkan': 'raung',
    'peraup': 'raup',
    'raupan': 'raup',
    'seraup': 'raup',
    'meraup': 'raup',
    'meraupnya': 'raup',
    'meraupkannya': 'raup',
    'merawat': 'rawat',
    'merawatnya': 'rawat',
    'merawatkan': 'rawat',
    'merawatkannya': 'rawat',
    'merawati': 'rawat',
    'merawatan': 'rawat',
    'merawatku': 'rawat',
    'merawatmu': 'rawat',
    'terawat': 'rawat',
    'terawatnya': 'rawat',
    'rawatan': 'rawat',
    'perawat': 'rawat',
    'perawatnya': 'rawat',
    'perawatlah': 'rawat',
    'perawati': 'rawat',
    'perawatan': 'rawat',
    'perawatku': 'rawat',
    'perawatannya': 'rawat',
    'perawatanan': 'rawat',
    'perawatanku': 'rawat',
    'keperawatan': 'rawat',
    'keperawatannya': 'rawat',
    'perayaan': 'raya',
    'perayaannya': 'raya',
    'perayaanan': 'raya',
    'merayakan': 'raya',
    'merayakannya': 'raya',
    'merayan': 'rayan',
    'merayani': 'rayan',
    'terayan-rayan': 'rayan',
    'merayau': 'rayau',
    'merayau-rayau': 'rayau',
    'rayuan': 'rayu',
    'rayuannya': 'rayu',
    'rayuanmu': 'rayu',
    'perayu': 'rayu',
    'perayunya': 'rayu',
    'merayu': 'rayu',
    'merayunya': 'rayu',
    'merayuku': 'rayu',
    'merayukan': 'rayu',
    'merayu-rayu': 'rayu',
    'kemercusuaran': 'mercusuar',
    'rebahan': 'rebah',
    'merebah': 'rebah',
    'merebahnya': 'rebah',
    'merebahkan': 'rebah',
    'merebahkannya': 'rebah',
    'rebah-rebah': 'rebah',
    'rebah-rebahan': 'rebah',
    'merebak': 'rebak',
    'merebaknya': 'rebak',
    'merebaklah': 'rebak',
    'merebakkan': 'rebak',
    'merebakan': 'rebak',
    'merebu': 'rebu',
    'merebus': 'rebus',
    'merebusnya': 'rebus',
    'rebusan': 'rebus',
    'rebusannya': 'rebus',
    'rebutan': 'rebut',
    'rebutannya': 'rebut',
    'merebut': 'rebut',
    'merebutnya': 'rebut',
    'merebutkan': 'rebut',
    'terebut': 'rebut',
    'terebutnya': 'rebut',
    'berebut': 'rebut',
    'berebutnya': 'rebut',
    'berebutlah': 'rebut',
    'berebutkan': 'rebut',
    'berebutan': 'rebut',
    'perebutan': 'rebut',
    'perebutannya': 'rebut',
    'berebut-rebut': 'rebut',
    'memperebutkan': 'rebut',
    'memperebutkannya': 'rebut',
    'memperebutkankan': 'rebut',
    'berebut-rebutan': 'rebut',
    'bereda': 'reda',
    'beredanya': 'reda',
    'mereda': 'reda',
    'meredanya': 'reda',
    'meredakan': 'reda',
    'meredakannya': 'reda',
    'meredai': 'reda',
    'peredaan': 'reda',
    'peredaannya': 'reda',
    'keredaan': 'reda',
    'redaman': 'redam',
    'redamannya': 'redam',
    'meredam': 'redam',
    'meredamnya': 'redam',
    'meredamkan': 'redam',
    'peredam': 'redam',
    'peredamnya': 'redam',
    'peredaman': 'redam',
    'peredamannya': 'redam',
    'redam-redam': 'redam',
    'bermerek': 'merek',
    'bermereknya': 'merek',
    'merekanya': 'reka',
    'merekalah': 'reka',
    'merekakan': 'reka',
    'merekai': 'reka',
    'rekaan': 'reka',
    'rekaannya': 'reka',
    'reka-reka': 'reka',
    'reka-rekaan': 'reka',
    'mereka-reka': 'reka',
    'merekah': 'rekah',
    'merekahnya': 'rekah',
    'merekahlah': 'rekah',
    'merekahkan': 'rekah',
    'perekat': 'rekat',
    'perekatnya': 'rekat',
    'perekatkan': 'rekat',
    'perekatan': 'rekat',
    'merekat': 'rekat',
    'merekatnya': 'rekat',
    'merekatkan': 'rekat',
    'merekatkannya': 'rekat',
    'serela': 'rela',
    'serelanya': 'rela',
    'merelai': 'relai',
    'merelainya': 'relai',
    'kerelaan': 'rela',
    'kerelaannya': 'rela',
    'merelakan': 'rela',
    'merelakannya': 'rela',
    'merelakanku': 'rela',
    'merelap': 'relap',
    'merelap-relap': 'relap',
    'merem-merem': 'merem',
    'memeremkan': 'merem',
    'meremang': 'remang',
    'meremangkan': 'remang',
    'keremangan': 'remang',
    'remang-remang': 'remang',
    'remang-remangnya': 'remang',
    'merembes': 'rembes',
    'merembesnya': 'rembes',
    'merembeskan': 'rembes',
    'merembesi': 'rembes',
    'perembesan': 'rembes',
    'perembesannya': 'rembes',
    'merempuh': 'rempuh',
    'perencana': 'rencana',
    'perencananya': 'rencana',
    'perencanakan': 'rencana',
    'perencanaan': 'rencana',
    'berencana': 'rencana',
    'berencananya': 'rencana',
    'berencanalah': 'rencana',
    'berencanakan': 'rencana',
    'merencana': 'rencana',
    'merencanakan': 'rencana',
    'merencanakannya': 'rencana',
    'merencanaan': 'rencana',
    'perencanaannya': 'rencana',
    'perencanaanku': 'rencana',
    'perencanaanmu': 'rencana',
    'merencanakankan': 'rencana',
    'terendam': 'rendam',
    'terendamnya': 'rendam',
    'rendaman': 'rendam',
    'rendamannya': 'rendam',
    'berendam': 'rendam',
    'berendamnya': 'rendam',
    'berendamlah': 'rendam',
    'merendam': 'rendam',
    'merendamnya': 'rendam',
    'merendamkan': 'rendam',
    'merendami': 'rendam',
    'perendaman': 'rendam',
    'merengek': 'rengek',
    'merengeki': 'rengek',
    'merengek-rengek': 'rengek',
    'merenggut': 'renggut',
    'merenggutnya': 'renggut',
    'merenggutku': 'renggut',
    'merengus': 'rengus',
    'perengus': 'rengus',
    'rentangan': 'rentang',
    'rentangannya': 'rentang',
    'merentang': 'rentang',
    'merentangkan': 'rentang',
    'merentangan': 'rentang',
    'terentang': 'rentang',
    'serentang': 'rentang',
    'merentangi': 'rentang',
    'renungan': 'renung',
    'renungannya': 'renung',
    'merenung': 'renung',
    'merenunglah': 'renung',
    'merenungkan': 'renung',
    'merenungkannya': 'renung',
    'merenungi': 'renung',
    'merenunginya': 'renung',
    'perenungan': 'renung',
    'perenungannya': 'renung',
    'merepes': 'repes',
    'resapan': 'resap',
    'resapannya': 'resap',
    'teresap': 'resap',
    'meresap': 'resap',
    'meresapnya': 'resap',
    'meresapkan': 'resap',
    'meresapi': 'resap',
    'meresapinya': 'resap',
    'peresapan': 'resap',
    'merestui': 'restu',
    'merestuinya': 'restu',
    'meretak': 'retak',
    'meretaknya': 'retak',
    'meretakkan': 'retak',
    'meretakkannya': 'retak',
    'meretakan': 'retak',
    'retakan': 'retak',
    'retakannya': 'retak',
    'peretakan': 'retak',
    'keretakan': 'retak',
    'keretakannya': 'retak',
    'retak-retak': 'retak',
    'merewang': 'rewang',
    'bermerger': 'merger',
    'meriah': 'riah',
    'meriahnya': 'riah',
    'meriahlah': 'riah',
    'meriahkan': 'riah',
    'meriam buluh': 'meriam katak',
    'berias': 'rias',
    'beriaslah': 'rias',
    'beriaskan': 'rias',
    'merias': 'rias',
    'meriasnya': 'rias',
    'meriasi': 'rias',
    'riasan': 'rias',
    'riasannya': 'rias',
    'riasanku': 'rias',
    'meringkik': 'ringkik',
    'rintihan': 'rintih',
    'rintihannya': 'rintih',
    'merintih': 'rintih',
    'perintis': 'rintis',
    'perintisnya': 'rintis',
    'perintisi': 'rintis',
    'perintisan': 'rintis',
    'merintis': 'rintis',
    'merintisnya': 'rintis',
    'rintisan': 'rintis',
    'rintisannya': 'rintis',
    'keperintisan': 'rintis',
    'perobohan': 'roboh',
    'perobohannya': 'roboh',
    'merobohkan': 'roboh',
    'merobohkannya': 'roboh',
    'robohan': 'roboh',
    'kerobohan': 'roboh',
    'merodok': 'rodok',
    'perokok': 'rokok',
    'perokoknya': 'rokok',
    'perokoklah': 'rokok',
    'merokok': 'rokok',
    'merokoknya': 'rokok',
    'merokoklah': 'rokok',
    'merokoknyalah': 'rokok',
    'perompak': 'rompak',
    'perompaknya': 'rompak',
    'perompakkan': 'rompak',
    'perompakan': 'rompak',
    'merompak': 'rompak',
    'merompaknya': 'rompak',
    'peronda': 'ronda',
    'perondaan': 'ronda',
    'meronda': 'ronda',
    'merondai': 'ronda',
    'merosot': 'rosot',
    'merosotnya': 'rosot',
    'merosotlah': 'rosot',
    'merosotkan': 'rosot',
    'merosotan': 'rosot',
    'kemerosotan': 'rosot',
    'kemerosotannya': 'rosot',
    'merotan': 'rotan',
    'perotan': 'rotan',
    'berotan': 'rotan',
    'rujukan': 'rujuk',
    'rujukannya': 'rujuk',
    'rujukanlah': 'rujuk',
    'merujuk': 'rujuk',
    'merujuknya': 'rujuk',
    'merujukkan': 'rujuk',
    'merujuki': 'rujuk',
    'merujukan': 'rujuk',
    'perumus': 'rumus',
    'perumusnya': 'rumus',
    'perumuskan': 'rumus',
    'perumusan': 'rumus',
    'perumusannya': 'rumus',
    'merumuskan': 'rumus',
    'merumuskannya': 'rumus',
    'merundung': 'rundung',
    'merundungnya': 'rundung',
    'merundungi': 'rundung',
    'seruntai': 'runtai',
    'meruntai': 'runtai',
    'berusak': 'rusak',
    'merusak': 'rusak',
    'merusaknya': 'rusak',
    'merusaklah': 'rusak',
    'merusakkan': 'rusak',
    'merusaki': 'rusak',
    'merusakan': 'rusak',
    'perusak': 'rusak',
    'perusaknya': 'rusak',
    'perusakkan': 'rusak',
    'perusakan': 'rusak',
    'merusakinya': 'rusak',
    'kerusakan': 'rusak',
    'kerusakannya': 'rusak',
    'kerusakani': 'rusak',
    'kerusakanan': 'rusak',
    'perusakannya': 'rusak',
    'bermesin': 'mesin',
    'bermesinkan': 'mesin',
    'permesinan': 'mesin',
    'permesinannya': 'mesin',
    'meskipun': 'meski',
    'meskipunnya': 'meski',
    'kemestian': 'mesti',
    'memestikan': 'mesti',
    'semestinya': 'mesti',
    'semestinyalah': 'mesti',
    'semestinyakan': 'mesti',
    'memesumi': 'mesum',
    'bermesum': 'mesum',
    'kemesuman': 'mesum',
    'permesuman': 'mesum',
    'bermetamorfosis': 'metamorfosis',
    'meteran': 'meter',
    'meterannya': 'meter',
    'termeterai': 'meterai',
    'bermeterai': 'meterai',
    'bermeteraikan': 'meterai',
    'memeteraikan': 'meterai',
    'kemewahan': 'mewah',
    'kemewahannya': 'mewah',
    'bermewah-mewah': 'mewah',
    'bermewah-mewahan': 'mewah',
    'pewaris': 'waris',
    'pewarisnya': 'waris',
    'pewarisan': 'waris',
    'warisan': 'waris',
    'warisannya': 'waris',
    'warisanku': 'waris',
    'warisanmu': 'waris',
    'mewarisi': 'waris',
    'mewarisinya': 'waris',
    'pewarisannya': 'waris',
    'kewarisan': 'waris',
    'mewariskan': 'waris',
    'mewariskannya': 'waris',
    'pewarta': 'warta',
    'pewartanya': 'warta',
    'pewartaan': 'warta',
    'pewartaannya': 'warta',
    'mewartakan': 'warta',
    'mewartakannya': 'warta',
    'semiang': 'miang',
    'bermigrasi': 'migrasi',
    'bermigrasinya': 'migrasi',
    'miju-miju': 'miju',
    'kemiliteran': 'militer',
    'kemiliterannya': 'militer',
    'mingguan': 'minggu',
    'mingguannya': 'minggu',
    'mingguanlah': 'minggu',
    'berminggu-minggu': 'minggu',
    'bermini': 'mini',
    'meminikan': 'mini',
    'meminimalkan': 'minimal',
    'meminimalkannya': 'minimal',
    'meminta': 'minta',
    'memintanya': 'minta',
    'memintalah': 'minta',
    'memintakan': 'minta',
    'memintai': 'minta',
    'memintaan': 'minta',
    'memintaku': 'minta',
    'memintamu': 'minta',
    'peminta': 'minta',
    'pemintanya': 'minta',
    'pemintai': 'minta',
    'pemintaan': 'minta',
    'berminta': 'minta',
    'memintainya': 'minta',
    'permintaan': 'minta',
    'permintaannya': 'minta',
    'permintaani': 'minta',
    'permintaanku': 'minta',
    'permintaanmu': 'minta',
    'minta-minta': 'minta',
    'minta-mintalah': 'minta',
    'meminta-minta': 'minta',
    'peminta-minta': 'minta',
    'berminta-minta': 'minta',
    'bermisai': 'misai',
    'semisal': 'misal',
    'semisalnya': 'misal',
    'memisalkan': 'misal',
    'pemitosan': 'mitos',
    'memitoskan': 'mitos',
    'bermitra': 'mitra',
    'bermitranya': 'mitra',
    'bermitralah': 'mitra',
    'kemitraan': 'mitra',
    'kemitraannya': 'mitra',
    'kemitrasejajaran': 'mitra sejajar',
    'bermobil': 'mobil',
    'permobilan': 'mobil',
    'memobilisasi': 'mobilisasi',
    'memobilisasinya': 'mobilisasi',
    'memobilisasikan': 'mobilisasi',
    'pemobilisasian': 'mobilisasi',
    'pemodal': 'modal',
    'pemodalnya': 'modal',
    'pemodalan': 'modal',
    'memodali': 'modal',
    'memodalinya': 'modal',
    'bermodal': 'modal',
    'bermodalnya': 'modal',
    'bermodalkan': 'modal',
    'permodalan': 'modal',
    'permodalannya': 'modal',
    'permodalanan': 'modal',
    'memoderatori': 'moderator',
    'termodern': 'modern',
    'kemodernan': 'modern',
    'pemodernan': 'modern',
    'memodernkan': 'modern',
    'memodernkannya': 'modern',
    'memodernisasi': 'modernisasi',
    'memodernisasinya': 'modernisasi',
    'memodernisasikan': 'modernisasi',
    'memodernisasikannya': 'modernisasi',
    'pemodifikasi': 'modifikasi',
    'pemodifikasian': 'modifikasi',
    'memodifikasi': 'modifikasi',
    'memodifikasinya': 'modifikasi',
    'memodifikasikan': 'modifikasi',
    'memodifikasii': 'modifikasi',
    'termodifikasi': 'modifikasi',
    'semoga': 'moga',
    'semoganya': 'moga',
    'semogalah': 'moga',
    'moga-moga': 'moga',
    'pemogok': 'mogok',
    'pemogokkan': 'mogok',
    'pemogokan': 'mogok',
    'pemogokannya': 'mogok',
    'pemohon': 'mohon',
    'pemohonnya': 'mohon',
    'pemohonlah': 'mohon',
    'pemohonan': 'mohon',
    'bermohon': 'mohon',
    'bermohonnya': 'mohon',
    'permohonan': 'mohon',
    'permohonannya': 'mohon',
    'permohonanan': 'mohon',
    'permohonanku': 'mohon',
    'permohonanmu': 'mohon',
    'kemolekan': 'molek',
    'kemolekannya': 'molek',
    'momongan': 'momong',
    'bermoncong': 'moncong',
    'memoncongkan': 'moncong',
    'bermongkok': 'mongkok',
    'memonitor': 'monitor',
    'memonitornya': 'monitor',
    'memonitori': 'monitor',
    'pemonitoran': 'monitor',
    'bermonolog': 'monolog',
    'termonyong-monyong': 'monyong',
    'morak-marik': 'morak',
    'bermotif': 'motif',
    'bermotifkan': 'motif',
    'memuai': 'muai',
    'memuaikan': 'muai',
    'pemuaian': 'muai',
    'bermuara': 'muara',
    'bermuaranya': 'muara',
    'pemubaziran': 'mubazir',
    'kemubaziran': 'mubazir',
    'memubazirkan': 'mubazir',
    'memubazirkannya': 'mubazir',
    'pemuda': 'muda',
    'pemudanya': 'muda',
    'pemudalah': 'muda',
    'pemudaan': 'muda',
    'pemudaku': 'muda',
    'bermuda': 'muda',
    'termuda': 'muda',
    'termudanya': 'muda',
    'kemudaan': 'muda',
    'kemudaannya': 'muda',
    'memudakan': 'muda',
    'kepemudaan': 'muda',
    'kepemudaannya': 'muda',
    'mempermuda': 'muda',
    'bermuda-muda': 'muda',
    'kemuda-mudaan': 'muda',
    'pemudah': 'mudah',
    'pemudahan': 'mudah',
    'semudah': 'mudah',
    'semudahnya': 'mudah',
    'kemudahan': 'mudah',
    'kemudahannya': 'mudah',
    'kemudahanlah': 'mudah',
    'memudahkan': 'mudah',
    'memudahkannya': 'mudah',
    'memudahkankan': 'mudah',
    'memudahkanku': 'mudah',
    'memudahkanmu': 'mudah',
    'mempermudah': 'mudah',
    'mempermudahnya': 'mudah',
    'mempermudahkan': 'mudah',
    'mempermudahan': 'mudah',
    'mempermudahmu': 'mudah',
    'mudah-mudahan': 'mudah',
    'mudah-mudahannya': 'mudah',
    'mudah-mudahanlah': 'mudah',
    'mudah-mudahanan': 'mudah',
    'bermudah-mudah': 'mudah',
    'memudik': 'mudik',
    'memudikkan': 'mudik',
    'memudiki': 'mudik',
    'pemudik': 'mudik',
    'pemudiknya': 'mudik',
    'pemudikan': 'mudik',
    'semudik': 'mudik',
    'bermudun': 'mudun',
    'memufakati': 'mufakat',
    'bermufakat': 'mufakat',
    'kemufakatan': 'mufakat',
    'pemufakatan': 'mufakat',
    'pemufakatannya': 'mufakat',
    'memufakatkan': 'mufakat',
    'memufakatkannya': 'mufakat',
    'almuhit': 'muhit',
    'semujur': 'mujur',
    'pemujur': 'mujur',
    'kemujuran': 'mujur',
    'kemujurannya': 'mujur',
    'semujur-mujurnya': 'mujur',
    'memukabalahkan': 'mukabalah',
    'pemukim': 'mukim',
    'pemukimnya': 'mukim',
    'pemukiman': 'mukim',
    'bermukim': 'mukim',
    'bermukimnya': 'mukim',
    'bermukimlah': 'mukim',
    'bermukiman': 'mukim',
    'pemukimannya': 'mukim',
    'pemukimanan': 'mukim',
    'pemukimanku': 'mukim',
    'memukimkan': 'mukim',
    'memukimkannya': 'mukim',
    'permukiman': 'mukim',
    'permukimannya': 'mukim',
    'permukimanan': 'mukim',
    'kemujizatan': 'mukjizat',
    'memula': 'mula',
    'memulakan': 'mula',
    'memulai': 'mula',
    'semula': 'mula',
    'semulanya': 'mula',
    'semulai': 'mula',
    'pemula': 'mula',
    'pemulanya': 'mula',
    'pemulai': 'mula',
    'pemulaan': 'mula',
    'bermula': 'mula',
    'bermulanya': 'mula',
    'bermulai': 'mula',
    'bermulaan': 'mula',
    'mula-mula': 'mula',
    'mula-mulanya': 'mula',
    'mula-mulai': 'mula',
    'permulaan': 'mula',
    'permulaannya': 'mula',
    'sebermula': 'mula',
    'bermula-mula': 'mula',
    'pemulsaan': 'mulsa',
    'muluk-muluk': 'muluk',
    'muluk-muluklah': 'muluk',
    'bermuluk-muluk': 'muluk',
    'memulur': 'mulur',
    'kemulusan': 'mulus',
    'kemulusannya': 'mulus',
    'memuluskan': 'mulus',
    'memuluskannya': 'mulus',
    'memuluskanmu': 'mulus',
    'mempermulus': 'mulus',
    'bermulut': 'mulut',
    'mulut-mulutan': 'mulut',
    'bermulut-mulut': 'mulut',
    'memumikan': 'mumi',
    'bermunajat': 'munajat',
    'memuncrat': 'muncrat',
    'memuncratkan': 'muncrat',
    'kemunculan': 'muncul',
    'kemunculannya': 'muncul',
    'kemunculanan': 'muncul',
    'pemunculan': 'muncul',
    'pemunculannya': 'muncul',
    'memunculkan': 'muncul',
    'memunculkannya': 'muncul',
    'bermunculan': 'muncul',
    'bermunculannya': 'muncul',
    'bermunculanlah': 'muncul',
    'pemunduran': 'mundur',
    'pemundurannya': 'mundur',
    'kemunduran': 'mundur',
    'kemundurannya': 'mundur',
    'memundurkan': 'mundur',
    'memundurkannya': 'mundur',
    'memungkari': 'mungkar',
    'kemungkaran': 'mungkar',
    'memungkiri': 'mungkir',
    'memungkirinya': 'mungkir',
    'mungmungan': 'mungmung',
    'memunjung': 'punjung',
    'pemurah': 'murah',
    'murahan': 'murah',
    'murahannya': 'murah',
    'kemurahan': 'murah',
    'kemurahannya': 'murah',
    'kemurahan-mu': 'murah',
    'memurahkan': 'murah',
    'mempermurah': 'murah',
    'permuseuman': 'museum',
    'memuseumkan': 'museum',
    'musikan': 'musik',
    'musikanan': 'musik',
    'pemusik': 'musik',
    'pemusiknya': 'musik',
    'bermusik': 'musik',
    'bermusiknya': 'musik',
    'bermusikmu': 'musik',
    'memusiki': 'musik',
    'memusikkan': 'musik',
    'permusikan': 'musik',
    'musiman': 'musim',
    'musimannya': 'musim',
    'bermusim': 'musim',
    'kemuskilan': 'muskil',
    'memuskilkan': 'muskil',
    'pemusnah': 'musnah',
    'pemusnahnya': 'musnah',
    'pemusnahkan': 'musnah',
    'pemusnahan': 'musnah',
    'pemusnahannya': 'musnah',
    'kemusnahan': 'musnah',
    'kemusnahannya': 'musnah',
    'memusnahkan': 'musnah',
    'memusnahkannya': 'musnah',
    'kemustahilan': 'mustahil',
    'kemustahilannya': 'mustahil',
    'memustahilkan': 'mustahil',
    'bermusyawarah': 'musyawarah',
    'bermusyawarahlah': 'musyawarah',
    'memusyawarahkan': 'musyawarah',
    'memusyawarahkannya': 'musyawarah',
    'kemusyrikan': 'musyrik',
    'memutalaah': 'mutalaah',
    'memutalaahkan': 'mutalaah',
    'pemutasian': 'mutasi',
    'pemutasiannya': 'mutasi',
    'memutasikan': 'mutasi',
    'memutasikannya': 'mutasi',
    'bermuwajahah': 'muwajahah',
    'kenabian': 'nabi',
    'kenabiannya': 'nabi',
    'bernada': 'nada',
    'bernadakan': 'nada',
    'nada-nadanya': 'nada',
    'bernafiri': 'nafiri',
    'menafkahi': 'nafkah',
    'menafkahinya': 'nafkah',
    'menafkahiku': 'nafkah',
    'menafkahkan': 'nafkah',
    'bernafsi-nafsi': 'nafsi',
    'naga-naga': 'naga',
    'naga-naganya': 'naga',
    'ternahak': 'nahak',
    'menaikkelaskan': 'naik kelas',
    'menaik': 'naik',
    'menaiknya': 'naik',
    'menaikkan': 'naik',
    'menaikkannya': 'naik',
    'menaiki': 'naik',
    'menaikan': 'naik',
    'menaikinya': 'naik',
    'menaikikan': 'naik',
    'penaikan': 'naik',
    'penaikannya': 'naik',
    'penaikanan': 'naik',
    'kenaikan': 'naik',
    'kenaikannya': 'naik',
    'kenaikanlah': 'naik',
    'kenaikani': 'naik',
    'menaikturunkan': 'naik turun',
    'kenajisan': 'najis',
    'menajiskan': 'najis',
    'bernaka-naka': 'naka',
    'menakali': 'nakal',
    'menakalinya': 'nakal',
    'kenakalan': 'nakal',
    'kenakalannya': 'nakal',
    'nakal-nakalan': 'nakal',
    'menakhodai': 'nakhoda',
    'bernala-nala': 'nala',
    'bernalam': 'nalam',
    'menalamkan': 'nalam',
    'bernalar': 'nalar',
    'penalaran': 'nalar',
    'penalarannya': 'nalar',
    'menalarkan': 'nalar',
    'kebernalaran': 'nalar',
    'menanap': 'nanap',
    'ternanar': 'nanar',
    'menanarkan': 'nanar',
    'senapas': 'napas',
    'bernapas': 'napas',
    'bernapasnya': 'napas',
    'bernapaslah': 'napas',
    'bernapaskan': 'napas',
    'bernapasan': 'napas',
    'pernapasan': 'napas',
    'pernapasannya': 'napas',
    'menapaskan': 'napas',
    'menaskan': 'nas',
    'menasakhkan': 'nasakh',
    'penasihat': 'nasihat',
    'penasihatnya': 'nasihat',
    'penasihatan': 'nasihat',
    'penasihatku': 'nasihat',
    'menasihati': 'nasihat',
    'menasihatinya': 'nasihat',
    'menasihatiku': 'nasihat',
    'menasihatkan': 'nasihat',
    'menasihatkannya': 'nasihat',
    'menasionalisasi': 'nasionalisasi',
    'menasionalisasinya': 'nasionalisasi',
    'menasionalisasikan': 'nasionalisasi',
    'menasionalisasikannya': 'nasionalisasi',
    'menazamkan': 'nazam',
    'menegara': 'negara',
    'menegarakan': 'negara',
    'menegarai': 'negara',
    'bernegara': 'negara',
    'bernegaranya': 'negara',
    'kenegaraan': 'negara',
    'kenegaraannya': 'negara',
    'kenegarawanan': 'negarawan',
    'kenegarawanannya': 'negarawan',
    'kenegarawananlah': 'negarawan',
    'kenegatifan': 'negatif',
    'menegosiasikan': 'negosiasi',
    'menegosiasikannya': 'negosiasi',
    'nenek-nenek': 'nenek',
    'menenes': 'nenes',
    'peneonan': 'neon',
    'menerakakan': 'neraka',
    'kenestapaan': 'nestapa',
    'kenetralan': 'netral',
    'kenetralannya': 'netral',
    'penetralan': 'netral',
    'menetralkan': 'netral',
    'menetralkannya': 'netral',
    'menganga': 'nganga',
    'mengangakan': 'nganga',
    'mengangai': 'nganga',
    'ternganga': 'nganga',
    'ternganganya': 'nganga',
    'ngeang-ngeang': 'ngeang',
    'mengenas': 'ngenas',
    'mengenasi': 'ngenas',
    'mengiang': 'ngiang',
    'terngiang': 'ngiang',
    'mengiang-ngiang': 'ngiang',
    'terngiang-ngiang': 'ngiang',
    'meniaga': 'niaga',
    'meniagakan': 'niaga',
    'meniagakannya': 'niaga',
    'peniaga': 'niaga',
    'peniagaan': 'niaga',
    'berniaga': 'niaga',
    'perniagaan': 'niaga',
    'perniagaannya': 'niaga',
    'memperniagakan': 'niaga',
    'menihilkan': 'nihil',
    'menihilkannya': 'nihil',
    'penilai': 'nilai',
    'penilainya': 'nilai',
    'penilaian': 'nilai',
    'menilai': 'nilai',
    'menilainya': 'nilai',
    'menilailah': 'nilai',
    'menilaii': 'nilai',
    'menilaian': 'nilai',
    'menilaiku': 'nilai',
    'menilaimu': 'nilai',
    'bernilai': 'nilai',
    'bernilainya': 'nilai',
    'bernilaian': 'nilai',
    'ternilai': 'nilai',
    'penilaiannya': 'nilai',
    'penilaianan': 'nilai',
    'penilaianku': 'nilai',
    'penilaianmu': 'nilai',
    'terninabobo': 'ninabobo',
    'terninabobokan': 'ninabobo',
    'meninabobokan': 'ninabobo',
    'meningratkan': 'ningrat',
    'keningrat-ningratan': 'ningrat',
    'keniraksaraan': 'niraksara',
    'kenisbian': 'nisbi',
    'menisbikan': 'nisbi',
    'keniscayaan': 'niscaya',
    'keniscayaannya': 'niscaya',
    'penista': 'nista',
    'penistanya': 'nista',
    'penistakan': 'nista',
    'penistaan': 'nista',
    'menista': 'nista',
    'menistanya': 'nista',
    'menistakan': 'nista',
    'menistakannya': 'nista',
    'menistai': 'nista',
    'menistaan': 'nista',
    'nistaan': 'nista',
    'ternista': 'nista',
    'ternistakan': 'nista',
    'kenistaan': 'nista',
    'menistakanan': 'nista',
    'penobatan': 'nobat',
    'penobatannya': 'nobat',
    'menobatkan': 'tobat',
    'menobatkannya': 'tobat',
    'menominasikan': 'nominasi',
    'menominasikannya': 'nominasi',
    'menomori': 'nomor',
    'menomorinya': 'nomor',
    'bernomor': 'nomor',
    'bernomorkan': 'nomor',
    'penomoran': 'nomor',
    'penomorannya': 'nomor',
    'nona makan sirih': 'nona',
    'penonaktifan': 'nonaktif',
    'penonaktifannya': 'nonaktif',
    'menonaktifkan': 'nonaktif',
    'menonaktifkannya': 'nonaktif',
    'menonong': 'nonong',
    'menormalkan': 'normal',
    'menormalkannya': 'normal',
    'menormalisasikan': 'normalisasi',
    'bernostalgia': 'nostalgia',
    'bernostalgialah': 'nostalgia',
    'kenotarisan': 'notaris',
    'pernovelan': 'novel',
    'bernubuat': 'nubuat',
    'menubuatkan': 'nubuat',
    'kenudisan': 'nudis',
    'nujuman': 'nujum',
    'menujum': 'nujum',
    'penujuman': 'nujum',
    'menujumkan': 'nujum',
    'menukil': 'nukil',
    'menukilkan': 'nukil',
    'nukilan': 'nukil',
    'nukilannya': 'nukil',
    'ternukil': 'nukil',
    'nyai-nyai': 'nyai',
    'menyalangkan': 'nyalang',
    'bernyali': 'nyali',
    'bernyalinya': 'nyali',
    'bernyalilah': 'nyali',
    'nyamikan': 'nyamik',
    'ternyana': 'nyana',
    'menyanya': 'nyanya',
    'menyanyakan': 'nyanya',
    'menyanyah': 'nyanyah',
    'menyanyu': 'nyanyu',
    'senyawa': 'nyawa',
    'senyawanya': 'nyawa',
    'senyawaan': 'senyawa',
    'bernyawa': 'nyawa',
    'bernyawakan': 'nyawa',
    'bersenyawa': 'senyawa',
    'bersenyawanya': 'senyawa',
    'persenyawaan': 'senyawa',
    'menyenyeh': 'nyenyeh',
    'kenyinyiran': 'nyinyir',
    'nyolong-nyolong': 'nyolong',
    'menyonyong': 'nyonyong',
    'menyonyor': 'nyonyor',
    'menyunyut': 'nyunyut',
    'nyut-nyutan': 'nyut',
    'berobat': 'obat',
    'berobatnya': 'obat',
    'berobatlah': 'obat',
    'berobatkan': 'obat',
    'berobati': 'obat',
    'terobat': 'obat',
    'terobati': 'obat',
    'pengobat': 'obat',
    'pengobatnya': 'obat',
    'pengobati': 'obat',
    'pengobatan': 'obat',
    'terobatinya': 'obat',
    'terobatilah': 'obat',
    'mengobati': 'obat',
    'mengobatinya': 'obat',
    'mengobatiku': 'obat',
    'pengobatannya': 'obat',
    'pengobatanan': 'obat',
    'pengobatanku': 'obat',
    'mengobatkan': 'obat',
    'mengobatkannya': 'obat',
    'obat-obatan': 'obat',
    'obat-obatannya': 'obat',
    'obat-obatanan': 'obat',
    'obat-obatanku': 'obat',
    'pengobeng': 'obeng',
    'mengobeng': 'obeng',
    'objekan': 'objek',
    'pengobjek': 'objek',
    'mengobjek': 'objek',
    'mengobjekkan': 'objek',
    'pengobjekan': 'objek',
    'mengobor': 'obor',
    'mengobori': 'obor',
    'pengoboran': 'obor',
    'obralan': 'obral',
    'mengobral': 'obral',
    'mengobralnya': 'obral',
    'mengobralkan': 'obral',
    'mengobralkannya': 'obral',
    'pengobralan': 'obral',
    'obrolan': 'obrol',
    'obrolannya': 'obrol',
    'obrolanku': 'obrol',
    'obrolanmu': 'obrol',
    'mengobrol': 'obrol',
    'mengobrollah': 'obrol',
    'mengobrolkan': 'obrol',
    'mengobrolkannya': 'obrol',
    'mengobservasi': 'observasi',
    'mengobservasinya': 'observasi',
    'mengobservasikan': 'observasi',
    'mengobservasiku': 'observasi',
    'terobsesi': 'obsesi',
    'terobsesinya': 'obsesi',
    'odolan': 'odol',
    'mengodol': 'odol',
    'pengodolan': 'odol',
    'mengodol-odol': 'odol',
    'mengogah': 'ogah',
    'ogah-ogahan': 'ogah',
    'berogak-ogak': 'ogak-ogak',
    'mengogam': 'ogam',
    'mengogel': 'ogel',
    'mengogok': 'ogok',
    'mengogokkan': 'ogok',
    'mengogok-ogok': 'ogok',
    'mengoja': 'oja',
    'pengojek': 'ojek',
    'pengojeknya': 'ojek',
    'mengojek': 'ojek',
    'mengojeknya': 'ojek',
    'mengojekkan': 'ojek',
    'mengojok': 'ojok',
    'teroksidasi': 'oksidasi',
    'pengoksidasi': 'oksidasi',
    'mengoksidasi': 'oksidasi',
    'beroksigen': 'oksigen',
    'olahan': 'olah',
    'olahannya': 'olah',
    'olahanan': 'olah',
    'berolah': 'olah',
    'berolahan': 'olah',
    'pengolah': 'olah',
    'pengolahnya': 'olah',
    'pengolahan': 'olah',
    'mengolah': 'olah',
    'mengolahnya': 'olah',
    'mengolahkan': 'olah',
    'mengolahan': 'olah',
    'pengolahannya': 'olah',
    'pengolahanan': 'olah',
    'seolah-olah': 'olah',
    'seolah-olahnya': 'olah',
    'memperolahkan': 'olah',
    'mengolak-alik': 'olak-alik',
    'mengolak-alikkan': 'olak-alik',
    'olang-alingan': 'olang-aling',
    'mengolang-aling': 'olang-aling',
    'mengolang-alingkan': 'olang-aling',
    'mengolek': 'olek',
    'mengoleki': 'olek',
    'olengan': 'oleng',
    'mengoleng': 'oleng',
    'teroleng-oleng': 'oleng',
    'beroleng-oleng': 'oleng',
    'mengoleng-oleng': 'oleng',
    'olesan': 'oles',
    'olesannya': 'oles',
    'mengoles': 'oles',
    'mengolesnya': 'oles',
    'mengoleskan': 'oles',
    'mengoleskannya': 'oles',
    'mengolesi': 'oles',
    'pengoles': 'oles',
    'pengolesnya': 'oles',
    'pengolesan': 'oles',
    'mengolet': 'olet',
    'olok-olok': 'olok',
    'olok-oloknya': 'olok',
    'olok-olokkan': 'olok',
    'olok-olokan': 'olok',
    'berolok-olok': 'olok',
    'mengolok-olok': 'olok',
    'mengolok-oloknya': 'olok',
    'mengolok-olokkan': 'olok',
    'mengolok-olokku': 'olok',
    'memperolok-olok': 'olok',
    'memperolok-olokkan': 'olok',
    'memperolok-olokan': 'olok',
    'berombak': 'ombak',
    'mengombak': 'ombak',
    'terombang-ambing': 'ombang-ambing',
    'terombang-ambingnya': 'ombang-ambing',
    'terombang-ambingkan': 'ombang-ambing',
    'mengombang-ambing': 'ombang-ambing',
    'mengombang-ambingkan': 'ombang-ambing',
    'mengombang-ambingkannya': 'ombang-ambing',
    'ombyokan': 'ombyok',
    'omongan': 'omong',
    'omongannya': 'omong',
    'omonganlah': 'omong',
    'omonganku': 'omong',
    'mengomong': 'omong',
    'mengomongkannya': 'omong',
    'pengomongan': 'omong',
    'mengomongkan': 'omong',
    'beromong-omong': 'omong',
    'mengompol': 'ompol',
    'mengompolnya': 'ompol',
    'omprengan': 'ompreng',
    'mengompreng': 'ompreng',
    'pengomprong': 'omprong',
    'mengomprong': 'omprong',
    'pengomprongan': 'omprong',
    'beromzet': 'omzet',
    'keonaran': 'onar',
    'keonarannya': 'onar',
    'mengonarkan': 'onar',
    'mengondokkan': 'ondok',
    'ondos-ondos': 'ondos',
    'onggokan': 'onggok',
    'mengonggokkan': 'onggok',
    'beronggok-onggok': 'onggok',
    'ongkang-ongkang': 'ongkang',
    'mengongkang-ongkang': 'ongkang',
    'mengongkoki': 'ongkok',
    'mengongkok-ongkok': 'ongkok',
    'mengonslah': 'onslah',
    'mengonyah-anyih': 'onyah-anyih',
    'mengonyok': 'onyok',
    'mengonyokkan': 'onyok',
    'onyotan': 'onyot',
    'mengonyot': 'onyot',
    'mengopak-apik': 'opak-apik',
    'mengopeletkan': 'opelet',
    'operan': 'oper',
    'operannya': 'oper',
    'mengoper': 'oper',
    'mengopernya': 'oper',
    'mengoperkan': 'oper',
    'mengoperkannya': 'oper',
    'pengoperan': 'oper',
    'beroperasi': 'operasi',
    'beroperasinya': 'operasi',
    'beroperasilah': 'operasi',
    'beroperasikan': 'operasi',
    'beroperasii': 'operasi',
    'mengoperasi': 'operasi',
    'mengoperasinya': 'operasi',
    'mengoperasikan': 'operasi',
    'mengoperasikannya': 'operasi',
    'mengoperasian': 'operasi',
    'mengoperasiku': 'operasi',
    'pengoperasian': 'operasi',
    'pengoperasiannya': 'operasi',
    'mengoperasikanan': 'operasi',
    'beroplah': 'oplah',
    'mengoplos': 'oplos',
    'mengoplosnya': 'oplos',
    'mengoposisi': 'oposisi',
    'mengoposisikan': 'oposisi',
    'pengoptimalan': 'optimal',
    'pengoptimalannya': 'optimal',
    'mengoptimalkan': 'optimal',
    'mengoptimalkannya': 'optimal',
    'mengoptimalkankan': 'optimal',
    'pengoptimuman': 'optimum',
    'mengoptimumkan': 'optimum',
    'terorak': 'orak',
    'pengorak': 'orak',
    'mengorak': 'orak',
    'mengorak-arik': 'orak-arik',
    'pengorak-arik': 'orak-arik',
    'seorang': 'orang',
    'seorangnya': 'orang',
    'seoranglah': 'orang',
    'seorangan': 'orang',
    'seseorang': 'orang',
    'seseoranglah': 'orang',
    'seseorangan': 'orang',
    'perorangan': 'orang',
    'perorangannya': 'orang',
    'keseorangan': 'orang',
    'mengorangkan': 'orang',
    'perseorangan': 'orang',
    'perseorangannya': 'orang',
    'orang-orangan': 'orang',
    'berorang-orang': 'orang',
    'berorasi': 'orasi',
    'berorasinya': 'orasi',
    'mengorat-oret': 'orat-oret',
    'mengorbit': 'orbit',
    'mengorbitnya': 'orbit',
    'mengorbitkan': 'orbit',
    'mengorbitkannya': 'orbit',
    'mengorbiti': 'orbit',
    'pengorbitan': 'orbit',
    'pengorbitannya': 'orbit',
    'oretan': 'oret',
    'mengoret-oret': 'oret',
    'terorganisasi': 'organisasi',
    'terorganisasikan': 'organisasi',
    'berorganisasi': 'organisasi',
    'berorganisasilah': 'organisasi',
    'pengorganisasi': 'organisasi',
    'pengorganisasian': 'organisasi',
    'mengorganisasi': 'organisasi',
    'mengorganisasikan': 'organisasi',
    'mengorganisasikannya': 'organisasi',
    'keorganisasian': 'organisasi',
    'keorganisasiannya': 'organisasi',
    'pengorganisasiannya': 'organisasi',
    'berorientasi': 'orientasi',
    'berorientasikan': 'orientasi',
    'mengorkestrasikan': 'orkestrasi',
    'pengornamenan': 'ornamen',
    'mengornamenkan': 'ornamen',
    'mengorok-orok': 'orok-orok',
    'berotak': 'otak',
    'berotakkan': 'otak',
    'mengotakinya': 'otak',
    'otak-otakan': 'otak',
    'otak udang': 'mengotaki',
    'mengotak-atik': 'otak-atik',
    'mengotak-atiknya': 'otak-atik',
    'pengotomatisan': 'otomatis',
    'mengotomatiskan': 'otomatis',
    'berotonomi': 'otonomi',
    'pengotonomian': 'otonomi',
    'mengotonomikan': 'otonomi',
    'mengotot': 'otot',
    'mengototnya': 'otot',
    'perototan': 'otot',
    'ovenan': 'oven',
    'mengoyak-oyak': 'oyak',
    'mengoyok': 'oyok',
    'kepabeanan': 'pabean',
    'kepabeanannya': 'pabean',
    'kepabeananan': 'pabean',
    'berpacangan': 'pacangan',
    'pacaran': 'pacar',
    'pacarannya': 'pacar',
    'memacari': 'pacar',
    'memacarinya': 'pacar',
    'memacarimu': 'pacar',
    'berpacaran': 'pacar',
    'berpacarannya': 'pacar',
    'memacek': 'pacek',
    'pemacek': 'pacek',
    'berpacek': 'pacek',
    'pemacekan': 'pacek',
    'memacik': 'pacik',
    'memacu': 'pacu',
    'memacunya': 'pacu',
    'memacukan': 'pacu',
    'memacuku': 'pacu',
    'pacuan': 'pacu',
    'pacuannya': 'pacu',
    'pemacu': 'pacu',
    'pemacunya': 'pacu',
    'pemacuan': 'pacu',
    'berpacu': 'pacu',
    'berpacunya': 'pacu',
    'berpacuan': 'pacu',
    'memacuk': 'pacuk',
    'memacul': 'pacul',
    'terpacul': 'pacul',
    'memadai': 'pada',
    'memadainya': 'pada',
    'memadailah': 'pada',
    'terpada': 'pada',
    'kepadaan': 'pada',
    'kepadaannya': 'pada',
    'memadakan': 'pada',
    'memadakannya': 'pada',
    'memada-madai': 'pada',
    'berpada-pada': 'pada',
    'padahan': 'padah',
    'pemadam': 'padam',
    'pemadamnya': 'padam',
    'pemadamkan': 'padam',
    'pemadaman': 'padam',
    'memadami': 'padam',
    'pemadamannya': 'padam',
    'pemadamanan': 'padam',
    'kepadaman': 'padam',
    'memadamkan': 'padam',
    'memadamkannya': 'padam',
    'memadan': 'padan',
    'memadankan': 'padan',
    'memadankannya': 'padan',
    'memadani': 'padan',
    'padanan': 'padan',
    'padanannya': 'padan',
    'pemadan': 'padan',
    'pemadanan': 'padan',
    'berpadan': 'padan',
    'berpadanan': 'padan',
    'bersepadan': 'padan',
    'menyepadan': 'padan',
    'menyepadankan': 'padan',
    'memadan-madan': 'padan',
    'sepadan': 'padan',
    'berpadang': 'padang',
    'berpadangan': 'padang',
    'sepadi': 'padi',
    'berpadi': 'padi',
    'perpadian': 'padi',
    'padi-padian': 'padi',
    'memaes': 'paes',
    'paesan': 'paes',
    'paesani': 'paes',
    'memagas': 'pagas',
    'sepagian': 'pagi',
    'kepagian': 'pagi',
    'pagi-pagi': 'pagi',
    'pagi-paginya': 'pagi',
    'sepaha': 'paha',
    'berpahala': 'pahala',
    'sepaham': 'paham',
    'sepahamnya': 'paham',
    'sepahamlah': 'paham',
    'sepahaman': 'paham',
    'memahami': 'paham',
    'memahaminya': 'paham',
    'memahamilah': 'paham',
    'memahamii': 'paham',
    'memahamiku': 'paham',
    'memahamimu': 'paham',
    'berpaham': 'paham',
    'berpahamkan': 'paham',
    'terpahami': 'paham',
    'pemahaman': 'paham',
    'pemahamannya': 'paham',
    'pemahamanan': 'paham',
    'pemahamanku': 'paham',
    'pemahamanmu': 'paham',
    'memahamkan': 'paham',
    'sepahit': 'pahit',
    'kepahitan': 'pahit',
    'kepahitannya': 'pahit',
    'memahitkan': 'pahit',
    'berpahit-pahit': 'pahit',
    'pailan': 'pail',
    'kepailitan': 'pailit',
    'kepailitannya': 'pailit',
    'pemair': 'pair',
    'memairi': 'pair',
    'berpair-pair': 'pair',
    'pemajak': 'pajak',
    'pemajakan': 'pajak',
    'memajaki': 'pajak',
    'memajakinya': 'pajak',
    'pemajakannya': 'pajak',
    'perpajakan': 'pajak',
    'perpajakannya': 'pajak',
    'pemajaan': 'pajan',
    'terpajan': 'pajan',
    'terpajannya': 'pajan',
    'memajankan': 'pajan',
    'pajangan': 'pajang',
    'pajangannya': 'pajang',
    'pemajang': 'pajang',
    'pemajangan': 'pajang',
    'memajang': 'pajang',
    'memajangnya': 'pajang',
    'memajangkan': 'pajang',
    'pakanan': 'pakan',
    'berpakan': 'pakan',
    'berpakankan': 'pakan',
    'berpakansi': 'pakansi',
    'memaksa': 'paksa',
    'memaksanya': 'paksa',
    'memaksakan': 'paksa',
    'memaksakannya': 'paksa',
    'memaksaan': 'paksa',
    'memaksaku': 'paksa',
    'memaksamu': 'paksa',
    'paksaan': 'paksa',
    'paksaannya': 'paksa',
    'terpaksa': 'paksa',
    'terpaksanya': 'paksa',
    'terpaksalah': 'paksa',
    'terpaksai': 'paksa',
    'pemaksaan': 'paksa',
    'pemaksaannya': 'paksa',
    'memaksakanlah': 'paksa',
    'keterpaksaan': 'paksa',
    'keterpaksaannya': 'paksa',
    'keterpaksaanlah': 'paksa',
    'memaksa-maksa': 'paksa',
    'memakuk': 'pakuk',
    'berpal-pal': 'pal',
    'sepala-pala': 'pala',
    'pemalak': 'palak',
    'pemalakan': 'palak',
    'memalak': 'palak',
    'memalaknya': 'palak',
    'memalaki': 'palak',
    'memalam': 'palam',
    'pemalam': 'palam',
    'memalang': 'palang',
    'memalangnya': 'palang',
    'memalangkan': 'palang',
    'memalangkannya': 'palang',
    'memalarkan': 'palar',
    'palean': 'pale',
    'memale': 'pale',
    'palingan': 'paling',
    'sepaling': 'paling',
    'berpaling': 'paling',
    'berpalingnya': 'paling',
    'berpalinglah': 'paling',
    'paling-paling': 'paling',
    'memalis': 'palis',
    'berpalis': 'palis',
    'terpalis': 'palis',
    'memaliskan': 'palis',
    'paluan': 'palu',
    'memalu': 'palu',
    'memalunya': 'palu',
    'palu-memalu': 'palu',
    'berpalu-palu': 'palu',
    'berpalu-paluan': 'palu',
    'memalun': 'palun',
    'memalunkan': 'palun',
    'berpalun-palun': 'palun',
    'palungan': 'palung',
    'pemalut': 'palut',
    'memalut': 'palut',
    'berpalut': 'palut',
    'terpalut': 'palut',
    'berpaman': 'paman',
    'pameran': 'pamer',
    'pamerannya': 'pamer',
    'pamerankan': 'pamer',
    'berpameran': 'pamer',
    'memamerkan': 'pamer',
    'memamerkannya': 'pamer',
    'memamerkankan': 'pamer',
    'memamitkan': 'pamit',
    'berpamitan': 'pamit',
    'berpamitannya': 'pamit',
    'kepamongprajaan': 'pamong praja',
    'berpamor': 'pamor',
    'memampas': 'pampas',
    'pampasan': 'pampas',
    'pemampasan': 'pampas',
    'memampat': 'pampat',
    'memampatkan': 'pampat',
    'memampatkannya': 'pampat',
    'pemampat': 'pampat',
    'pemampatan': 'pampat',
    'terpampat': 'pampat',
    'kepampatan': 'pampat',
    'keterpampatan': 'pampat',
    'kepamrihan': 'pamrih',
    'terpana': 'pana',
    'keterpanaan': 'pana',
    'memancal': 'pancal',
    'memancarteruskan': 'pancar terus',
    'memancit': 'pancit',
    'memancit-mancitkan': 'pancit',
    'berpanco': 'panco',
    'memandakkan': 'pandak',
    'memperpandak': 'pandak',
    'kepandiran': 'pandir',
    'kepandir-pandiran': 'pandir',
    'pemandu': 'pandu',
    'pemandunya': 'pandu',
    'pemanduan': 'pandu',
    'pemandumu': 'pandu',
    'memandu': 'pandu',
    'memandunya': 'pandu',
    'memandukan': 'pandu',
    'memanduku': 'pandu',
    'memandumu': 'pandu',
    'panduan': 'pandu',
    'panduannya': 'pandu',
    'panduanmu': 'pandu',
    'berpandu': 'pandu',
    'berpandukan': 'pandu',
    'berpanduan': 'pandu',
    'kepanduan': 'pandu',
    'panenan': 'panen',
    'panenannya': 'panen',
    'memanen': 'panen',
    'memanennya': 'panen',
    'memanenkan': 'panen',
    'memanenkannya': 'panen',
    'pemanenan': 'panen',
    'pemanenannya': 'panen',
    'terpangah': 'pangah',
    'memanggakkan': 'panggak',
    'panggalan': 'panggal',
    'memanggul': 'panggul',
    'memanggulnya': 'panggul',
    'memanggung': 'panggung',
    'memanggungkan': 'panggung',
    'memanggungkannya': 'panggung',
    'panggungan': 'panggung',
    'pemanggungan': 'panggung',
    'memangkah': 'pangkah',
    'memangkal': 'pangkal',
    'memangkalkan': 'pangkal',
    'pangkalan': 'pangkal',
    'pangkalannya': 'pangkal',
    'pangkalanan': 'pangkal',
    'berpangkal': 'pangkal',
    'berpangkalan': 'pangkal',
    'berpangkalanlah': 'pangkal',
    'berpangkal tolak': 'pangkal tolak',
    'memangkek': 'pangkek',
    'pemangku': 'pangku',
    'pemangkui': 'pangku',
    'pemangkuan': 'pangku',
    'memangku': 'pangku',
    'memangkunya': 'pangku',
    'pangkuan': 'pangku',
    'pangkuannya': 'pangku',
    'pangkuanku': 'pangku',
    'pangkuanmu': 'pangku',
    'pangkuan-mu': 'pangku',
    'berpangku': 'pangku',
    'berpangkuan': 'pangku',
    'memangkung': 'pangkung',
    'memangkur': 'pangkur',
    'berpangsa': 'pangsa',
    'memangsakan': 'pangsa',
    'kepangsek': 'pangsek',
    'berpangsi': 'pangsi',
    'memanguk': 'panguk',
    'memangur': 'pangur',
    'kepanikan': 'panik',
    'kepanikannya': 'panik',
    'kepanikanku': 'panik',
    'kepanikanmu': 'panik',
    'kepaniteraan': 'panitera',
    'kepanitiaan': 'panitia',
    'kepanitiaannya': 'panitia',
    'mempanitiai': 'panitia',
    'mengarak panja': 'panja',
    'memanjang': 'panjang',
    'memanjangnya': 'panjang',
    'memanjangkan': 'panjang',
    'memanjangkannya': 'panjang',
    'memanjangi': 'panjang',
    'sepanjang': 'panjang',
    'sepanjangnya': 'panjang',
    'sepanjangan': 'panjang',
    'berpanjang': 'panjang',
    'berpanjangan': 'panjang',
    'pemanjangan': 'panjang',
    'kepanjangan': 'panjang',
    'kepanjangannya': 'panjang',
    'kepanjanganan': 'panjang',
    'perpanjangan': 'panjang',
    'perpanjangannya': 'panjang',
    'perpanjanganan': 'panjang',
    'memperpanjang': 'panjang',
    'memperpanjangnya': 'panjang',
    'memperpanjangkan': 'panjang',
    'memperpanjangan': 'panjang',
    'pemerpanjangan': 'panjang',
    'berkepanjangan': 'panjang',
    'berkepanjangannya': 'panjang',
    'berkepanjanganlah': 'panjang',
    'berpanjang kalam': 'panjang',
    'berpanjang-panjang': 'panjang',
    'panjatan': 'panjat',
    'panjatannya': 'panjat',
    'memanjat': 'panjat',
    'memanjatnya': 'panjat',
    'memanjatlah': 'panjat',
    'memanjatkan': 'panjat',
    'memanjatkannya': 'panjat',
    'memanjati': 'panjat',
    'memanjatan': 'panjat',
    'pemanjat': 'panjat',
    'pemanjatnya': 'panjat',
    'pemanjatan': 'panjat',
    'pemanjatannya': 'panjat',
    'panji-panji': 'panji',
    'panji-panjinya': 'panji',
    'memanjingkan': 'panjing',
    'memanjut': 'panjut',
    'memanjutkan': 'panjut',
    'memanjut-manjut': 'panjut',
    'memantai': 'pantai',
    'pantaran': 'pantar',
    'pantarannya': 'pantar',
    'sepantar': 'pantar',
    'sepantaran': 'pantar',
    'pemantas': 'pantas',
    'pemantasan': 'pantas',
    'memantas': 'pantas',
    'memantaskan': 'pantas',
    'sepantasnya': 'pantas',
    'sepantasnyalah': 'pantas',
    'memantas-mantas diri': 'pantas',
    'memantati': 'pantat',
    'pantauan': 'pantau',
    'pantauannya': 'pantau',
    'pemantau': 'pantau',
    'pemantaunya': 'pantau',
    'pemantaulah': 'pantau',
    'pemantauan': 'pantau',
    'memantau': 'pantau',
    'memantaunya': 'pantau',
    'memantaulah': 'pantau',
    'memantauan': 'pantau',
    'memantauku': 'pantau',
    'memantaumu': 'pantau',
    'terpantau': 'pantau',
    'terpantaunya': 'pantau',
    'terpantaui': 'pantau',
    'pemantauannya': 'pantau',
    'memantek': 'pantek',
    'terpantek': 'pantek',
    'pemantik': 'pantik',
    'pemantiknya': 'pantik',
    'memantik': 'pantik',
    'memantiknya': 'pantik',
    'memantikkan': 'pantik',
    'memantikan': 'pantik',
    'pemantikan': 'pantik',
    'terpanting': 'panting',
    'berpantingan': 'panting',
    'memantis': 'pantis',
    'sepantun': 'pantun',
    'pemantun': 'pantun',
    'berpantun': 'pantun',
    'memantuni': 'pantun',
    'memantunkan': 'pantun',
    'berpantun-pantun': 'pantun',
    'memapah': 'papah',
    'memapahnya': 'papah',
    'memapahku': 'papah',
    'berpapah': 'papah',
    'memapak': 'papak',
    'memapaki': 'papak',
    'pemapakan': 'papak',
    'berpapakan': 'papak',
    'memapan': 'papan',
    'memapankan': 'papan',
    'memapani': 'papan',
    'memapras': 'papras',
    'para-para': 'para',
    'paraban': 'parab',
    'berparade': 'parade',
    'memaraf': 'paraf',
    'memarafnya': 'paraf',
    'memparafrasekan': 'parafrase',
    'memperparah': 'parah',
    'memperparahnya': 'parah',
    'memarani': 'paran',
    'memarang': 'parang',
    'memarangi': 'parang',
    'parangan': 'parang',
    'memarangkan': 'parang',
    'pemarap': 'parap',
    'pemarapan': 'parap',
    'memarap': 'parap',
    'berparap': 'parap',
    'memaras': 'paras',
    'separas': 'paras',
    'separasi': 'paras',
    'memarih': 'parih',
    'memarit': 'parit',
    'berpariwisata': 'pariwisata',
    'kepariwisataan': 'pariwisata',
    'kepariwisataannya': 'pariwisata',
    'memarkir': 'parkir',
    'memarkirnya': 'parkir',
    'memarkirkan': 'parkir',
    'memarkirkannya': 'parkir',
    'memarkiran': 'parkir',
    'terparkir': 'parkir',
    'terparkirnya': 'parkir',
    'terparkirkan': 'parkir',
    'terparkiri': 'parkir',
    'perparkiran': 'parkir',
    'perparkirannya': 'parkir',
    'memarodikan': 'parodi',
    'berpartai': 'partai',
    'berpartailah': 'partai',
    'kepartaian': 'partai',
    'kepartaiannya': 'partai',
    'berpartisipasi': 'partisipasi',
    'berpartisipasinya': 'partisipasi',
    'berpartisipasilah': 'partisipasi',
    'berpartner': 'partner',
    'paru-paru': 'paru',
    'paru-parunya': 'paru',
    'paru-paruku': 'paru',
    'paru-parumu': 'paru',
    'paruhan': 'paruh',
    'separuh': 'paruh',
    'separuhnya': 'paruh',
    'separuhlah': 'paruh',
    'separuhnyalah': 'paruh',
    'memaruh': 'paruh',
    'pemaruh': 'paruh',
    'pemarun': 'parun',
    'memarun': 'parun',
    'parunan': 'parun',
    'pemarunan': 'parun',
    'mengepas': 'pas',
    'mengepasnya': 'pas',
    'mengepaskan': 'pas',
    'pas-pasan': 'pas',
    'pas-pasanlah': 'pas',
    'terpasah': 'pasah',
    'memasok': 'pasok',
    'memasoknya': 'pasok',
    'memasoki': 'pasok',
    'memasokan': 'pasok',
    'pasokan': 'pasok',
    'pasokannya': 'pasok',
    'pasokani': 'pasok',
    'pasokanan': 'pasok',
    'pemasok': 'pasok',
    'pemasoknya': 'pasok',
    'pemasoklah': 'pasok',
    'pemasokkan': 'pasok',
    'pemasokan': 'pasok',
    'pemasokannya': 'pasok',
    'memasokkan': 'pasok',
    'berpaspor': 'paspor',
    'berpasporkan': 'paspor',
    'berpasrah': 'pasrah',
    'kepasrahan': 'pasrah',
    'kepasrahannya': 'pasrah',
    'kepasrahanku': 'pasrah',
    'memasrahkan': 'pasrah',
    'memasrahkannya': 'pasrah',
    'dipasteurisasi': 'pasteurisasi',
    'pemastian': 'pasti',
    'pemastiannya': 'pasti',
    'kepastian': 'pasti',
    'kepastiannya': 'pasti',
    'kepastianlah': 'pasti',
    'memastikan': 'pasti',
    'memastikannya': 'pasti',
    'memastikanan': 'pasti',
    'pastoran': 'pastor',
    'pasukan': 'pasuk',
    'pasukannya': 'pasuk',
    'pasukanlah': 'pasuk',
    'pasukanan': 'pasuk',
    'pasukanku': 'pasuk',
    'pasukanmu': 'pasuk',
    'berpasuk-pasuk': 'pasuk',
    'memasung': 'pasung',
    'memasungnya': 'pasung',
    'pasungan': 'pasung',
    'pasungannya': 'pasung',
    'pemasungan': 'pasung',
    'pemasungannya': 'pasung',
    'memasungkan': 'pasung',
    'berpatam': 'patam',
    'mematar': 'patar',
    'mematenkan': 'paten',
    'mematenkannya': 'paten',
    'pematih': 'patih',
    'pematihan': 'patih',
    'kepatihan': 'patih',
    'mematik': 'patik',
    'mematiknya': 'patik',
    'mematikkan': 'patik',
    'mematil': 'patil',
    'memating': 'pating',
    'patokan': 'patok',
    'patokannya': 'patok',
    'patokanan': 'patok',
    'mematok': 'patok',
    'mematoknya': 'patok',
    'mematokkan': 'patok',
    'mematokan': 'patok',
    'pematokan': 'patok',
    'pematokannya': 'patok',
    'mematri': 'patri',
    'mematrikan': 'patri',
    'patrian': 'patri',
    'patriani': 'patri',
    'pematri': 'patri',
    'pematrian': 'patri',
    'terpatri': 'patri',
    'terpatrikan': 'patri',
    'mempatroli': 'patroli',
    'berpatroli': 'patroli',
    'mematuhi': 'patuh',
    'mematuhinya': 'patuh',
    'mematuhiku': 'patuh',
    'kepatuhan': 'patuh',
    'kepatuhannya': 'patuh',
    'pematuhan': 'patuh',
    'pematung': 'patung',
    'pematungnya': 'patung',
    'mematung': 'patung',
    'mematungnya': 'patung',
    'mematungkan': 'patung',
    'berpatungan': 'patungan',
    'mematut': 'patut',
    'mematutkan': 'patut',
    'kepatutan': 'patut',
    'kepatutannya': 'patut',
    'berpatutan': 'patut',
    'sepatutnya': 'patut',
    'sepatutnyalah': 'patut',
    'mematut-matut': 'patut',
    'memauk': 'pauk',
    'memaukkan': 'pauk',
    'memauki': 'pauk',
    'pemauk': 'pauk',
    'kepausan': 'paus',
    'kepausannya': 'paus',
    'berpawai': 'pawai',
    'memayang': 'payang',
    'pemayar': 'payar',
    'pemayaran': 'payar',
    'berpayudara': 'payudara',
    'memayungi': 'payung',
    'memayunginya': 'payung',
    'berpayung': 'payung',
    'berpayungkan': 'payung',
    'berpayungan': 'payung',
    'memayungkan': 'payung',
    'memecakkan': 'pecak',
    'memecal': 'pecal',
    'memeda': 'peda',
    'memedai': 'peda',
    'memedang': 'pedang',
    'kepedihan': 'pedih',
    'kepedihannya': 'pedih',
    'memedihkan': 'pedih',
    'berpedoman': 'pedoman',
    'memedomani': 'pedoman',
    'kepedulian': 'peduli',
    'kepeduliannya': 'peduli',
    'kepedulianlah': 'peduli',
    'memedulikan': 'peduli',
    'memedulikannya': 'peduli',
    'terpegah': 'pegah',
    'memegalkan': 'pegal',
    'terpegan': 'pegan',
    'memegas': 'pegas',
    'memegaskan': 'pegas',
    'memegat': 'pegat',
    'pemegatan': 'pegat',
    'kepegawaian': 'pegawai',
    'kepegawaiannya': 'pegawai',
    'kepegawaianan': 'pegawai',
    'kepegawaianmu': 'pegawai',
    'terpegun': 'pegun',
    'terpejam': 'pejam',
    'memejamkan': 'pejam',
    'memejamkannya': 'pejam',
    'kepekatan': 'pekat',
    'kepekatannya': 'pekat',
    'memekatkan': 'pekat',
    'memekau': 'pekau',
    'memeking': 'peking',
    'memekis': 'pekis',
    'sepeku': 'peku',
    'memekuk': 'pekuk',
    'mengepel': 'pel',
    'mengepelnya': 'pel',
    'memelankan': 'pelan',
    'memelankannya': 'pelan',
    'pelan-pelan': 'pelan',
    'pelan-pelanlah': 'pelan',
    'memelana': 'pelana',
    'berpelana': 'pelana',
    'terpelanting': 'pelanting',
    'memelaspas': 'pelaspas',
    'berpelatuk': 'pelatuk',
    'pelawaan': 'pelawa',
    'memelawa': 'pelawa',
    'memeleceh': 'peleceh',
    'terpelecok': 'pelecok',
    'terpelekok': 'pelekok',
    'terpelencit': 'pelencit',
    'terpelengak': 'pelengak',
    'berpelepah': 'pelepah',
    'memelesat': 'pelesat',
    'terpelesat': 'pelesat',
    'pelesiran': 'pelesir',
    'pelesirannya': 'pelesir',
    'berpelesir': 'pelesir',
    'berpelesiran': 'pelesir',
    'peletan': 'pelet',
    'memelet': 'pelet',
    'memeletnya': 'pelet',
    'memeletek': 'peletek',
    'peliharaan': 'pelihara',
    'peliharaannya': 'pelihara',
    'peliharaanku': 'pelihara',
    'peliharaanmu': 'pelihara',
    'pemelihara': 'pelihara',
    'pemeliharanya': 'pelihara',
    'pemeliharaan': 'pelihara',
    'memelihara': 'pelihara',
    'memeliharanya': 'pelihara',
    'memeliharamu': 'pelihara',
    'terpelihara': 'pelihara',
    'terpeliharanya': 'pelihara',
    'pemeliharaannya': 'pelihara',
    'memeliharakan': 'pelihara',
    'pelintiran': 'pelintir',
    'pelintirannya': 'pelintir',
    'memelintir': 'pelintir',
    'memelintirnya': 'pelintir',
    'memelintirkan': 'pelintir',
    'pemelintir': 'pelintir',
    'pemelintiran': 'pelintir',
    'terpelintir': 'pelintir',
    'terpelintirnya': 'pelintir',
    'memelintir-melintir': 'pelintir',
    'pelipisan': 'pelipis',
    'memelisit': 'pelisit',
    'kepelitan': 'pelit',
    'memelitur': 'pelitur',
    'pelituran': 'pelitur',
    'berpelitur': 'pelitur',
    'memelonco': 'pelonco',
    'perpeloncoan': 'pelonco',
    'memelopori': 'pelopor',
    'memeloporinya': 'pelopor',
    'kepeloporan': 'pelopor',
    'kepeloporannya': 'pelopor',
    'memeloroti': 'pelorot',
    'terpelosot': 'pelosot',
    'memelotot': 'pelotot',
    'memelototkan': 'pelotot',
    'memelototi': 'pelotot',
    'memelototinya': 'pelotot',
    'memelototiku': 'pelotot',
    'berpeluang': 'peluang',
    'berpeluangnya': 'peluang',
    'berpeluangan': 'peluang',
    'berpematang': 'pematang',
    'berpentas': 'pentas',
    'pementasan': 'pentas',
    'pementasannya': 'pentas',
    'mementaskan': 'pentas',
    'mementaskannya': 'pentas',
    'pemerintah': 'perintah',
    'pemerintahnya': 'perintah',
    'pemerintahlah': 'perintah',
    'pemerintahkan': 'perintah',
    'pemerintahi': 'perintah',
    'pemerintahan': 'perintah',
    'pemerintahku': 'perintah',
    'pemerintahmu': 'perintah',
    'memerintah': 'perintah',
    'memerintahnya': 'perintah',
    'memerintahkan': 'perintah',
    'memerintahkannya': 'perintah',
    'memerintahan': 'perintah',
    'memerintahmu': 'perintah',
    'terperintah': 'perintah',
    'memerintahi': 'perintah',
    'pemerintahannya': 'perintah',
    'pemerintahanlah': 'perintah',
    'pemerintahanan': 'perintah',
    'pemerintahannyalah': 'perintah',
    'pemerintahanku': 'perintah',
    'pemerintahanmu': 'perintah',
    'memerintahkankan': 'perintah',
    'memerintahkanku': 'perintah',
    'memerintahkanmu': 'perintah',
    'berpemerintahan': 'perintah',
    'petaan': 'peta',
    'terpeta': 'peta',
    'terpetakan': 'peta',
    'terpetakannya': 'peta',
    'pemetaan': 'peta',
    'pemetaannya': 'peta',
    'perpetaan': 'peta',
    'perpetaannya': 'peta',
    'memetakan': 'peta',
    'memetakannya': 'peta',
    'pemidangan': 'pemidang',
    'pemirsa': 'pirsa',
    'pemirsanya': 'pirsa',
    'penambang': 'tambang',
    'penambangnya': 'tambang',
    'penambangan': 'tambang',
    'menambang': 'tambang',
    'menambangnya': 'tambang',
    'menambangkan': 'tambang',
    'menambangan': 'tambang',
    'tambangan': 'tambang',
    'penambangannya': 'tambang',
    'bertambangan': 'tambang',
    'pertambangan': 'tambang',
    'pertambangannya': 'tambang',
    'pertambanganlah': 'tambang',
    'penampilan': 'tampil',
    'penampilannya': 'tampil',
    'penampilannyalah': 'tampil',
    'penampilanku': 'tampil',
    'penampilanmu': 'tampil',
    'menampilkan': 'tampil',
    'menampilkannya': 'tampil',
    'menampilkankan': 'tampil',
    'berpenampilan': 'tampil',
    'berpenampilannya': 'tampil',
    'berpenampilanlah': 'tampil',
    'penangkal': 'tangkal',
    'penangkalnya': 'tangkal',
    'penangkalan': 'tangkal',
    'menangkal': 'tangkal',
    'menangkalnya': 'tangkal',
    'menangkali': 'tangkal',
    'tertangkal': 'tangkal',
    'penangkalannya': 'tangkal',
    'menangkalkan': 'tangkal',
    'memencak-mencak': 'pencak',
    'memencet': 'pencet',
    'memencetnya': 'pencet',
    'memenceti': 'pencet',
    'kepencut': 'pencut',
    'memenda': 'penda',
    'pendaan': 'penda',
    'pendaannya': 'penda',
    'pendaanan': 'penda',
    'memendaki': 'pendak',
    'pendaran': 'pendar',
    'berpendar': 'pendar',
    'berpendarnya': 'pendar',
    'berpendaran': 'pendar',
    'berpendar-pendar': 'pendar',
    'memendek': 'pendek',
    'memendeknya': 'pendek',
    'memendekkan': 'pendek',
    'memendekkannya': 'pendek',
    'memendekan': 'pendek',
    'pemendekan': 'pendek',
    'kependekan': 'pendek',
    'kependetaan': 'pendeta',
    'kependetaannya': 'pendeta',
    'berpending': 'pending',
    'berpendingan': 'pending',
    'menegas': 'tegas',
    'menegasnya': 'tegas',
    'menegaskan': 'tegas',
    'menegaskannya': 'tegas',
    'menegasi': 'tegas',
    'menegasan': 'tegas',
    'penegasan': 'tegas',
    'penegasannya': 'tegas',
    'ketegasan': 'tegas',
    'ketegasannya': 'tegas',
    'ketegasanlah': 'tegas',
    'ketegasanan': 'tegas',
    'ketegasanmu': 'tegas',
    'menegaskankan': 'tegas',
    'menegaskanku': 'tegas',
    'pertegasan': 'tegas',
    'mempertegas': 'tegas',
    'mempertegasnya': 'tegas',
    'mempertegaskan': 'tegas',
    'penerbang': 'terbang',
    'penerbangnya': 'terbang',
    'penerbangkan': 'terbang',
    'penerbangan': 'terbang',
    'menerbangi': 'terbang',
    'menerbanginya': 'terbang',
    'penerbangannya': 'terbang',
    'penerbanganan': 'terbang',
    'penerbanganku': 'terbang',
    'beterbangan': 'terbang',
    'beterbangannya': 'terbang',
    'menerbangkan': 'terbang',
    'menerbangkannya': 'terbang',
    'terbang-terbang': 'terbang',
    'terbang-terbangan': 'terbang',
    'terbang-terbang hinggap': 'terbang',
    'berpenetrasi': 'penetrasi',
    'berpengantin': 'pengantin',
    'memengap': 'pengap',
    'kepengapan': 'pengap',
    'memengapkan': 'pengap',
    'memengat': 'pengat',
    'pengkolan': 'pengkol',
    'memengkol': 'pengkol',
    'memengos': 'pengos',
    'tiduran': 'tidur',
    'penidur': 'tidur',
    'peniduran': 'tidur',
    'meniduri': 'tidur',
    'menidurinya': 'tidur',
    'menidurimu': 'tidur',
    'tertidur': 'tidur',
    'tertidurnya': 'tidur',
    'petiduran': 'tidur',
    'ketiduran': 'tidur',
    'menidurkan': 'tidur',
    'menidurkannya': 'tidur',
    'seketiduran': 'tidur',
    'tidur-tidur': 'tidur',
    'tidur-tiduran': 'tidur',
    'berseketiduran': 'tidur',
    'ketidur-tiduran': 'tidur',
    'penimbal': 'timbal',
    'timbalan': 'timbal',
    'menimbal': 'timbal',
    'menimbalkan': 'timbal',
    'setimbal': 'timbal',
    'bertimbal': 'timbal',
    'menimbali': 'timbal',
    'bertimbalan': 'timbal',
    'kesetimbalan': 'timbal',
    'bertimbal-timbalan': 'timbal',
    'memensiun': 'pensiun',
    'memensiunkan': 'pensiun',
    'memensiunkannya': 'pensiun',
    'pensiunan': 'pensiun',
    'pensiunannya': 'pensiun',
    'penyair': 'syair',
    'penyairnya': 'syair',
    'penyairan': 'syair',
    'penyairku': 'syair',
    'pensyair': 'syair',
    'bersyair': 'syair',
    'bersyairkan': 'syair',
    'menyairkan': 'syair',
    'kepenyairan': 'syair',
    'kepenyairannya': 'syair',
    'terpental': 'pental',
    'terpentalnya': 'pental',
    'mementang': 'pentang',
    'terpentang': 'pentang',
    'mementil': 'pentil',
    'pentolan': 'pentol',
    'pentolannya': 'pentol',
    'berpentol': 'pentol',
    'pentungan': 'pentung',
    'pentungannya': 'pentung',
    'mementung': 'pentung',
    'mementungi': 'pentung',
    'pentung-pentungan': 'pentung',
    'dituai': 'tuai',
    'dituainya': 'tuai',
    'penuai': 'tuai',
    'penuaian': 'tuai',
    'menuai': 'tuai',
    'menuainya': 'tuai',
    'menuaikan': 'tuai',
    'menuaii': 'tuai',
    'tuaian': 'tuai',
    'menumpang': 'tumpang',
    'menumpangnya': 'tumpang',
    'menumpanglah': 'tumpang',
    'menumpangkan': 'tumpang',
    'menumpangkannya': 'tumpang',
    'menumpangi': 'tumpang',
    'penumpang': 'tumpang',
    'penumpangnya': 'tumpang',
    'penumpanglah': 'tumpang',
    'penumpangkan': 'tumpang',
    'penumpangan': 'tumpang',
    'penumpangku': 'tumpang',
    'tumpangan': 'tumpang',
    'tumpangannya': 'tumpang',
    'tertumpang': 'tumpang',
    'tertumpangi': 'tumpang',
    'menumpanginya': 'tumpang',
    'penumpangannya': 'tumpang',
    'tunjangan': 'tunjang',
    'tunjangannya': 'tunjang',
    'penunjang': 'tunjang',
    'penunjangnya': 'tunjang',
    'penunjangan': 'tunjang',
    'menunjang': 'tunjang',
    'menunjangnya': 'tunjang',
    'menunjangkan': 'tunjang',
    'tertunjang': 'tunjang',
    'bersajak': 'sajak',
    'penyajak': 'sajak',
    'menyajak': 'sajak',
    'persajakan': 'sajak',
    'menyajakkan': 'sajak',
    'menyalir': 'salir',
    'penyaliran': 'salir',
    'sandangan': 'sandang',
    'penyandang': 'sandang',
    'penyandangnya': 'sandang',
    'penyandangan': 'sandang',
    'menyandang': 'sandang',
    'menyandangnya': 'sandang',
    'menyandangkan': 'sandang',
    'mempersandangkan': 'sandang',
    'saringan': 'saring',
    'saringannya': 'saring',
    'menyaring': 'saring',
    'menyaringnya': 'saring',
    'menyaringan': 'saring',
    'penyaring': 'saring',
    'penyaringnya': 'saring',
    'penyaringan': 'saring',
    'penyaringannya': 'saring',
    'semburan': 'sembur',
    'semburannya': 'sembur',
    'penyembur': 'sembur',
    'penyemburkan': 'sembur',
    'penyemburan': 'sembur',
    'tersembur': 'sembur',
    'tersemburlah': 'sembur',
    'menyembur': 'sembur',
    'menyemburnya': 'sembur',
    'menyemburkan': 'sembur',
    'menyemburkannya': 'sembur',
    'menyemburi': 'sembur',
    'bersemburan': 'sembur',
    'penyemburannya': 'sembur',
    'sembur-sembur': 'sembur',
    'bersembur-semburan': 'sembur',
    'semprotan': 'semprot',
    'semprotannya': 'semprot',
    'menyemprot': 'semprot',
    'menyemprotnya': 'semprot',
    'menyemprotkan': 'semprot',
    'menyemprotkannya': 'semprot',
    'menyemproti': 'semprot',
    'menyemprotan': 'semprot',
    'penyemprot': 'semprot',
    'penyemprotnya': 'semprot',
    'penyemprotkan': 'semprot',
    'penyemprotan': 'semprot',
    'penyemprotannya': 'semprot',
    'menyengap': 'sengap',
    'penyengap': 'sengap',
    'menyengapkan': 'sengap',
    'serahan': 'serah',
    'menyerah': 'serah',
    'menyerahnya': 'serah',
    'menyerahlah': 'serah',
    'menyerahkan': 'serah',
    'menyerahkannya': 'serah',
    'menyerahan': 'serah',
    'terserah': 'serah',
    'terserahnya': 'serah',
    'terserahlah': 'serah',
    'berserah': 'serah',
    'berserahlah': 'serah',
    'berserahkan': 'serah',
    'berserahan': 'serah',
    'seserahan': 'serah',
    'seserahannya': 'serah',
    'menyerahi': 'serah',
    'penyerahan': 'serah',
    'penyerahannya': 'serah',
    'penyerahanan': 'serah',
    'menyerahkankan': 'serah',
    'menyerahkani': 'serah',
    'menyerahkanku': 'serah',
    'menyerahkanmu': 'serah',
    'memepah': 'pepah',
    'sepepak': 'pepak',
    'memepak': 'pepak',
    'memepas': 'pepas',
    'memepat': 'pepat',
    'memepati': 'pepat',
    'berpepat': 'pepat',
    'memeper': 'peper',
    'memeperkan': 'peper',
    'terpeper': 'peper',
    'pepesan': 'pepes',
    'pepesanan': 'pepes',
    'memepes': 'pepes',
    'memepet': 'pepet',
    'memepetnya': 'pepet',
    'memepetkan': 'pepet',
    'kepepet': 'pepet',
    'kepepetnya': 'pepet',
    'memepeti': 'pepet',
    'terpepet': 'pepet',
    'meraga': 'raga',
    'meragakan': 'raga',
    'peraga': 'raga',
    'peraganya': 'raga',
    'peragakan': 'raga',
    'peragaan': 'raga',
    'peragaannya': 'raga',
    'pemeraga': 'raga',
    'pemeragaan': 'raga',
    'memperagakan': 'raga',
    'memperagakannya': 'raga',
    'keperagawanan': 'peragawan',
    'keperagawatian': 'peragawati',
    'perah keringat': 'perah otak',
    'berperahu': 'perahu',
    'memerai': 'perai',
    'berperai-perai': 'perai',
    'teraih': 'raih',
    'peraih': 'raih',
    'peraihnya': 'raih',
    'peraihan': 'raih',
    'meraih': 'raih',
    'meraihnya': 'raih',
    'meraihkan': 'raih',
    'meraihan': 'raih',
    'meraihku': 'raih',
    'meraihmu': 'raih',
    'keperakan': 'perak',
    'keperakannya': 'perak',
    'keperak-perakan': 'perak',
    'pemeran': 'peran',
    'pemerannya': 'peran',
    'pemeranan': 'peran',
    'peranan': 'peran',
    'peranannya': 'peran',
    'perananan': 'peran',
    'berperan': 'peran',
    'berperannya': 'peran',
    'berperanlah': 'peran',
    'berperanan': 'peran',
    'memerankan': 'peran',
    'memerankannya': 'peran',
    'memerankanku': 'peran',
    'berperan serta': 'peran serta',
    'perancah': 'rancah',
    'perancahnya': 'rancah',
    'memerangi': 'perang',
    'memeranginya': 'perang',
    'memerangimu': 'perang',
    'berperang': 'perang',
    'berperangnya': 'perang',
    'berperangan': 'perang',
    'peperangan': 'perang',
    'peperangannya': 'perang',
    'peperanganku': 'perang',
    'berperang-perangan': 'perang',
    'terperangah': 'perangah',
    'terperangahnya': 'perangah',
    'memerangahkan': 'perangah',
    'seperanggu': 'peranggu',
    'seperangguan': 'peranggu',
    'merangkap': 'rangkap',
    'merangkapnya': 'rangkap',
    'merangkapkan': 'rangkap',
    'berangkap': 'rangkap',
    'perangkap': 'rangkap',
    'perangkapnya': 'rangkap',
    'perangkapan': 'rangkap',
    'perangkapku': 'rangkap',
    'berangkap-rangkapan': 'rangkap',
    'memerap': 'perap',
    'memerapkan': 'perap',
    'terperap': 'perap',
    'berperata': 'perata',
    'memerawani': 'perawan',
    'keperawanan': 'perawan',
    'keperawanannya': 'perawan',
    'keperawananku': 'perawan',
    'keperawananmu': 'perawan',
    'diperbal': 'perbal',
    'memerban': 'perban',
    'memercit': 'percit',
    'tepercit': 'percit',
    'tepercul': 'percul',
    'diperdanakan': 'perdana',
    'diperdom': 'perdom',
    'diperdomi': 'perdom',
    'terperedus': 'peredus',
    'terpereh-pereh': 'pereh',
    'keperempuanan': 'perempuan',
    'keperempuanannya': 'perempuan',
    'terperenyuk': 'perenyuk',
    'memereteli': 'peretel',
    'pemeretelan': 'peretel',
    'kepergok': 'pergok',
    'kepergoknya': 'pergok',
    'tepergok': 'pergok',
    'tepergoknya': 'pergok',
    'tepergoki': 'pergok',
    'memergoki': 'pergok',
    'memergokinya': 'pergok',
    'memergokiku': 'pergok',
    'memergol': 'pergol',
    'memergoli': 'pergol',
    'berperi': 'peri',
    'berperikan': 'peri',
    'pemerian': 'peri',
    'memerikan': 'peri',
    'terperikan': 'peri',
    'keperigelan': 'perigel',
    'perincian': 'perinci',
    'perinciannya': 'perinci',
    'memerinci': 'perinci',
    'memerincinya': 'perinci',
    'memerincikan': 'perinci',
    'terperinci': 'perinci',
    'pemerincian': 'perinci',
    'memeringis': 'peringis',
    'rintangan': 'rintang',
    'rintangannya': 'rintang',
    'rintanganlah': 'rintang',
    'perintang': 'rintang',
    'perintangan': 'rintang',
    'merintang': 'rintang',
    'merintangi': 'rintang',
    'terintang': 'rintang',
    'terintangi': 'rintang',
    'merintanginya': 'rintang',
    'merintangkan': 'rintang',
    'perintang-rintang': 'rintang',
    'merintang-rintang': 'rintang',
    'berperistiwa': 'peristiwa',
    'beperkara': 'perkara',
    'beperkaralah': 'perkara',
    'memperkarai': 'perkara',
    'memperkarakan': 'perkara',
    'memperkarakannya': 'perkara',
    'memerkosa': 'perkosa',
    'memerkosanya': 'perkosa',
    'memerkosaan': 'perkosa',
    'memerkosaku': 'perkosa',
    'pemerkosa': 'perkosa',
    'pemerkosanya': 'perkosa',
    'pemerkosaan': 'perkosa',
    'pemerkosaku': 'perkosa',
    'pemerkosaannya': 'perkosa',
    'memerlahan': 'perlahan',
    'memerlahankan': 'perlahan',
    'perlahan-lahan': 'perlahan',
    'perlahan-lahanlah': 'perlahan',
    'perlian': 'perli',
    'memerli': 'perli',
    'memerlikan': 'perli',
    'teperling': 'perling',
    'perlip-perlipan': 'perlip',
    'teperlus': 'perlus',
    'kepermaian': 'permai',
    'memermak': 'permak',
    'memermaknya': 'permak',
    'tepermanai': 'permana',
    'mempermisikan': 'permisi',
    'pernak-pernik': 'pernik',
    'pernak-perniknya': 'pernik',
    'pernik-pernik': 'pernik',
    'memernis': 'pernis',
    'pernisan': 'pernis',
    'memerogol': 'perogol',
    'terperohong': 'perohong',
    'terperonyok': 'peronyok',
    'terperosok': 'perosok',
    'terperosoknya': 'perosok',
    'memerosot': 'perosot',
    'memerosotkan': 'perosot',
    'kepustakaan': 'pustaka',
    'perpustakaan': 'pustaka',
    'perpustakaannya': 'pustaka',
    'bersahabat': 'sahabat',
    'bersahabatnya': 'sahabat',
    'bersahabatlah': 'sahabat',
    'bersahabatan': 'sahabat',
    'persahabatan': 'sahabat',
    'persahabatannya': 'sahabat',
    'persahabatanlah': 'sahabat',
    'persahabatanku': 'sahabat',
    'persahabatanmu': 'sahabat',
    'mempersahabatkan': 'sahabat',
    'bersegi': 'segi',
    'persegi': 'segi',
    'perseginya': 'segi',
    'memersekoti': 'persekot',
    'mempersekoti': 'persekot',
    'memersekusi': 'persekusi',
    'persenan': 'persen',
    'persenannya': 'persen',
    'persenanlah': 'persen',
    'memerseni': 'persen',
    'memersenkan': 'persen',
    'bersenjata': 'senjata',
    'bersenjatanya': 'senjata',
    'bersenjatalah': 'senjata',
    'bersenjatakan': 'senjata',
    'kesenjataan': 'senjata',
    'kesenjataannya': 'senjata',
    'persenjataan': 'senjata',
    'persenjataannya': 'senjata',
    'mempersenjatai': 'senjata',
    'mempersenjatainya': 'senjata',
    'tersenyawa': 'senyawa',
    'memersepsikan': 'persepsi',
    'memersepsikannya': 'persepsi',
    'seratus': 'ratus',
    'seratusnya': 'ratus',
    'seratusan': 'ratus',
    'ratusan': 'ratus',
    'ratusannya': 'ratus',
    'ratusanlah': 'ratus',
    'ratusanan': 'ratus',
    'meratus': 'ratus',
    'peratus': 'ratus',
    'peratusan': 'ratus',
    'seperatus': 'ratus',
    'menyeratus': 'ratus',
    'perseratus': 'ratus',
    'seperseratus': 'ratus',
    'seperseratusnya': 'ratus',
    'beratus-ratus': 'ratus',
    'pesero': 'sero',
    'peseroan': 'sero',
    'perseroan': 'sero',
    'perseroannya': 'sero',
    'perseroankan': 'sero',
    'berseteru': 'seteru',
    'berseterunya': 'seteru',
    'berseteruan': 'seteru',
    'menyeterui': 'seteru',
    'perseteruan': 'seteru',
    'perseteruannya': 'seteru',
    'memperseterukan': 'seteru',
    'setubuh': 'tubuh',
    'setubuhnya': 'tubuh',
    'setubuhi': 'tubuh',
    'bertubuh': 'tubuh',
    'menubuhkan': 'tubuh',
    'pertubuhan': 'tubuh',
    'bersetubuh': 'tubuh',
    'bersetubuhi': 'tubuh',
    'bersetubuhan': 'tubuh',
    'menyetubuhi': 'tubuh',
    'menyetubuhinya': 'tubuh',
    'persetubuhan': 'tubuh',
    'persetubuhannya': 'tubuh',
    'tepersil': 'persil',
    'memersonanongratakan': 'persona nongrata',
    'memersonifikasi': 'personifikasi',
    'memersonifikasikan': 'personifikasi',
    'memersuasi': 'persuasi',
    'pertalan': 'pertal',
    'memert al': 'pertal',
    'memertamakan': 'pertama',
    'pertama-tama': 'pertama',
    'pertama-tamanya': 'pertama',
    'terperuak': 'peruak',
    'memeruk': 'peruk',
    'memerukan': 'peruk',
    'terperuk': 'peruk',
    'memerukkan': 'peruk',
    'memerum': 'perum',
    'memerun': 'perun',
    'pemerunan': 'perun',
    'seperunjung': 'perunjung',
    'seperunjungan': 'perunjung',
    'memerusa': 'perusa',
    'seperut': 'perut',
    'memeruti': 'perut',
    'berperut': 'perut',
    'perwalian': 'wali',
    'perwaliannya': 'wali',
    'mewalikan': 'wali',
    'memperwalikan': 'wali',
    'berwatak': 'watak',
    'berwatakkan': 'watak',
    'mewataki': 'watak',
    'perwatakan': 'watak',
    'berpesai-pesai': 'pesai',
    'memesamkan': 'pesam',
    'pesangon': 'sangon',
    'pesangonnya': 'sangon',
    'pesangonlah': 'sangon',
    'pesangonkan': 'sangon',
    'pesangonan': 'sangon',
    'berpesawat': 'pesawat',
    'sepeser': 'peser',
    'memesona': 'pesona',
    'memesonanya': 'pesona',
    'memesonakan': 'pesona',
    'terpesona': 'pesona',
    'terpesonanya': 'pesona',
    'memesonai': 'pesona',
    'memesonakanku': 'pesona',
    'berpesta pora': 'pesta pora',
    'kepetah-lidahan': 'petah lidah',
    'petakan': 'petak',
    'petakannya': 'petak',
    'berpetak': 'petak',
    'memetak-metak': 'petak',
    'berpetak-petak': 'petak',
    'memetalkan': 'petal',
    'berpetam': 'petam',
    'kepetangan': 'petang',
    'petang-petang': 'petang',
    'sepetang-petangan': 'petang',
    'pemetang-metangan': 'petang',
    'memetang-metangkan': 'petang',
    '2 tani': 'tani',
    'petani': 'tani',
    'petaninya': 'tani',
    'petanilah': 'tani',
    'petanian': 'tani',
    'bertani': 'tani',
    'bertaninya': 'tani',
    'pertanian': 'tani',
    'pertaniannya': 'tani',
    'pertanianan': 'tani',
    'petasan': 'petas',
    'petasannya': 'petas',
    'petentengan': 'petenteng',
    'memetieskan': 'peti es',
    'berpeti-peti': 'peti',
    'memetia': 'petia',
    'memetiakan': 'petia',
    'memeting': 'peting',
    'memetingkan': 'peting',
    'memetir-metir': 'petir',
    'berpetua': 'petua',
    'dipetuakan': 'petua',
    'berpetuah': 'petuah',
    'memetuahkan': 'petuah',
    'pewawancara': 'wawancara',
    'pewawancaranya': 'wawancara',
    'pewawancaramu': 'wawancara',
    'mewawancarai': 'wawancara',
    'mewawancarainya': 'wawancara',
    'mewawancaraiku': 'wawancara',
    'mewawancaraimu': 'wawancara',
    'berwawancara': 'wawancara',
    'terwawancara': 'wawancara',
    'memiagamkan': 'piagam',
    'berpialang': 'pialang',
    'memialangkan': 'pialang',
    'berpiama': 'piama',
    'memiang': 'piang',
    'memiangnya': 'piang',
    'pemiara': 'piara',
    'piaraan': 'piara',
    'piaraannya': 'piara',
    'piaraanku': 'piara',
    'memiara': 'piara',
    'pemiaraan': 'piara',
    'memiat': 'piat',
    'piat-piut': 'piat',
    'kepiatuan': 'piatu',
    'kepiawaian': 'piawai',
    'kepiawaiannya': 'piawai',
    'terpica': 'pica',
    'memicakan': 'pica',
    'kepicikan': 'picik',
    'memicikkan': 'picik',
    'memicing': 'picing',
    'memicingkan': 'picing',
    'sepicing': 'picing',
    'terpicing': 'picing',
    'berpicing': 'picing',
    'picisan': 'picis',
    'sepicis': 'picis',
    'terpico': 'pico',
    'memicu': 'picu',
    'memicunya': 'picu',
    'memicui': 'picu',
    'memicuku': 'picu',
    'pemicu': 'picu',
    'pemicunya': 'picu',
    'pemiculah': 'picu',
    'pemicuan': 'picu',
    'memidana': 'pidana',
    'memidanakan': 'pidana',
    'memidanakannya': 'pidana',
    'terpidana': 'pidana',
    'terpidananya': 'pidana',
    'terpidanai': 'pidana',
    'berpidana': 'pidana',
    'pemidanaan': 'pidana',
    'pemidanaannya': 'pidana',
    'memidi': 'pidi',
    'memijah': 'pijah',
    'memijahnya': 'pijah',
    'memijahkan': 'pijah',
    'pemijahan': 'pijah',
    'pemijahannya': 'pijah',
    'memijat': 'pijat',
    'memijatnya': 'pijat',
    'memijatkan': 'pijat',
    'memijatkannya': 'pijat',
    'memijati': 'pijat',
    'memijatmu': 'pijat',
    'pemijat': 'pijat',
    'pemijatnya': 'pijat',
    'pemijatan': 'pijat',
    'pijatan': 'pijat',
    'pijatannya': 'pijat',
    'pemijatannya': 'pijat',
    'pijat-pijat': 'pijat',
    'pijat-pijatlah': 'pijat',
    'pijat-pijatan': 'pijat',
    'memijit': 'pijit',
    'memijitnya': 'pijit',
    'terpijit': 'pijit',
    'berpikauan': 'pikau',
    'terpikau-pikau': 'pikau',
    'berpiknik': 'piknik',
    'memikul': 'pikul',
    'memikulnya': 'pikul',
    'memikulkan': 'pikul',
    'pemikul': 'pikul',
    'pemikulan': 'pikul',
    'pikulan': 'pikul',
    'pikulannya': 'pikul',
    'berpikul-pikul': 'pikul',
    'memilah': 'pilah',
    'memilahnya': 'pilah',
    'memilahkan': 'pilah',
    'terpilah': 'pilah',
    'terpilah-pilah': 'pilah',
    'memilis': 'pilis',
    'berpilis': 'pilis',
    'memiloti': 'pilot',
    'berpinak': 'pinak',
    'berpinar': 'pinar',
    'memincuk': 'pincuk',
    'kepincuk': 'pincuk',
    'terpincut': 'pincut',
    'terpincutnya': 'pincut',
    'pindaan': 'pinda',
    'meminda': 'pinda',
    'memindakan': 'pinda',
    'memindai': 'pindai',
    'pemindaan': 'pinda',
    'memindahtangankan': 'pindah tangan',
    'memindahtugaskan': 'pindah tugas',
    'memindahtugaskannya': 'pindah tugas',
    'memindainya': 'pindai',
    'pemindai': 'pindai',
    'pemindainya': 'pindai',
    'pemindaian': 'pindai',
    'pemindaiannya': 'pindai',
    'terpinga-pinga': 'pinga',
    'sepinggan': 'pinggan',
    'peminggang': 'pinggang',
    'sepinggang': 'pinggang',
    'sepinggangnya': 'pinggang',
    'berpinggang': 'pinggang',
    'peminggir': 'pinggir',
    'peminggiran': 'pinggir',
    'pinggiran': 'pinggir',
    'pinggirannya': 'pinggir',
    'meminggir': 'pinggir',
    'meminggirkan': 'pinggir',
    'meminggirkannya': 'pinggir',
    'meminggiri': 'pinggir',
    'kepinggiran': 'pinggir',
    'terpinggirkan': 'pinggir',
    'terpinggirkannya': 'pinggir',
    'pingitan': 'pingit',
    'pingitannya': 'pingit',
    'memingit': 'pingit',
    'berpingit': 'pingit',
    'terpingkal-pingkal': 'pingkal',
    'terpingkau-pingkau': 'pingkau',
    'dipingpong': 'pingpong',
    'terpinta': 'pinta',
    'berpinta': 'pinta',
    'terpintar': 'pintar',
    'kepintaran': 'pintar',
    'kepintarannya': 'pintar',
    'kepintaranmu': 'pintar',
    'kepioniran': 'pionir',
    'kepionirannya': 'pionir',
    'pemipaan': 'pipa',
    'perpipaan': 'pipa',
    'memipihkan': 'pipih',
    'pipilan': 'pipil',
    'memipil': 'pipil',
    'pipisan': 'pipis',
    'memipis': 'pipis',
    'memipiskan': 'pipis',
    'memipit': 'pipit',
    'pipitan': 'pipit',
    'memirau': 'pirau',
    'berpirau': 'pirau',
    'berpirau-pirau': 'pirau',
    'memirik': 'pirik',
    'piringan': 'piring',
    'piringannya': 'piring',
    'perpisangan': 'pisang',
    'pisang-pisang': 'pisang',
    'pisang-pisangan': 'pisang',
    'memistol': 'pistol',
    'pistol-pistolan': 'pistol',
    'pisuhan': 'pisuh',
    'berpita': 'pita',
    'memitar': 'pitar',
    'pitingan': 'piting',
    'memiting': 'piting',
    'memitingnya': 'piting',
    'piting-memiting': 'piting',
    'berpiutang': 'piutang',
    'memiutangi': 'piutang',
    'memiutangkan': 'piutang',
    'keplastisan': 'plastis',
    'memplombir': 'plombir',
    'perploncoan': 'plonco',
    'perploncoannya': 'plonco',
    'memoces': 'poces',
    'memocok': 'pocok',
    'sepocong': 'pocong',
    'memojok': 'pojok',
    'memojokkan': 'pojok',
    'memojokkannya': 'pojok',
    'memojoki': 'pojok',
    'memojokan': 'pojok',
    'terpojok': 'pojok',
    'terpojoknya': 'pojok',
    'terpojokkan': 'pojok',
    'terpojokan': 'pojok',
    'pemojokan': 'pojok',
    'berpokok': 'pokok',
    'memokoki': 'pokok',
    'memokokkan': 'pokok',
    'memokrolkan': 'pokrol',
    'pokrol-pokrolan': 'pokrol',
    'berpola': 'pola',
    'berpolah-polah': 'polah',
    'polang-paling': 'polang',
    'berpolemik': 'polemik',
    'berpolemiknya': 'polemik',
    'poleng-poleng': 'poleng',
    'polesan': 'poles',
    'polesannya': 'poles',
    'pemoles': 'poles',
    'pemolesan': 'poles',
    'memoles': 'poles',
    'memolesnya': 'poles',
    'memoleskan': 'poles',
    'memoleskannya': 'poles',
    'memolesi': 'poles',
    'berpoligami': 'poligami',
    'pemolimeran': 'polimer',
    'kepolisian': 'polisi',
    'kepolisiannya': 'polisi',
    'kepolisianlah': 'polisi',
    'kepolisiani': 'polisi',
    'memolok': 'polok',
    'berpolok-polok': 'polok',
    'polongan': 'polong',
    'polong-polongan': 'polong',
    'kepolosan': 'polos',
    'kepolosannya': 'polos',
    'poma-poma': 'poma',
    'pompaan': 'pompa',
    'memompa': 'pompa',
    'memompanya': 'pompa',
    'memompakan': 'pompa',
    'pemompaan': 'pompa',
    'pemompaannya': 'pompa',
    'memondok': 'pondok',
    'memondokkan': 'pondok',
    'pondokan': 'pondok',
    'pondokannya': 'pondok',
    'pemondokan': 'pondok',
    'pemondokannya': 'pondok',
    'pondongan': 'pondong',
    'memondong': 'pondong',
    'memondongi': 'pondong',
    'berpondong': 'pondong',
    'terponggok': 'ponggok',
    'berponi': 'poni',
    'berponinya': 'poni',
    'terpontang-panting': 'pontang-panting',
    'berpontang-panting': 'pontang-panting',
    'memontang-mantingkan': 'pontang-panting',
    'memonten': 'ponten',
    'popokan': 'popok',
    'memopok': 'popok',
    'memopokkan': 'popok',
    'memopor': 'popor',
    'kepopuleran': 'populer',
    'kepopulerannya': 'populer',
    'memopulerkan': 'populer',
    'memopulerkannya': 'populer',
    'memorahkan': 'porah',
    'berporah-porah': 'porah',
    'memorakporandakan': 'porak',
    'memorak-perandakan': 'porak-peranda',
    'memorak-porandakan': 'porak-poranda',
    'berpori': 'pori',
    'berporinya': 'pori',
    'keporian': 'pori',
    'memorot': 'porot',
    'memoroti': 'porot',
    'berpose': 'pose',
    'berposenya': 'pose',
    'berposelah': 'pose',
    'memposer': 'poser',
    'pemosisian': 'posisi',
    'pemosisiannya': 'posisi',
    'memosisikan': 'posisi',
    'memosisikannya': 'posisi',
    'kepositifan': 'positif',
    'kepositifannya': 'positif',
    'memositifkan': 'positif',
    'keprabuan': 'prabu',
    'keprajuritan': 'prajurit',
    'pemrakarsa': 'prakarsa',
    'pemrakarsanya': 'prakarsa',
    'berprakarsa': 'prakarsa',
    'memprakarsai': 'prakarsa',
    'memprakarsainya': 'prakarsa',
    'pemrakarsaan': 'prakarsa',
    'prakiraan': 'prakira',
    'prakiraannya': 'prakira',
    'pemrakiraan': 'prakira',
    'memprakirakan': 'prakira',
    'berpraktik': 'praktik',
    'mempraktikkan': 'praktik',
    'mempraktikkannya': 'praktik',
    'kepraktisan': 'praktis',
    'kepraktisannya': 'praktis',
    'sepraktis-praktisnya': 'praktis',
    'kepramugaraan': 'pramugara',
    'kepramukaan': 'pramuka',
    'kepramukaannya': 'pramuka',
    'mempraperadilankan': 'praperadilan',
    'pemrasaran': 'prasaran',
    'memprediksi': 'prediksi',
    'memprediksinya': 'prediksi',
    'memprediksikan': 'prediksi',
    'memprediksikannya': 'prediksi',
    'mengepres': 'pres',
    'pengepresan': 'pres',
    'mempresentasikan': 'presentasi',
    'mempresentasikannya': 'presentasi',
    'kepresidenan': 'presiden',
    'kepresidenannya': 'presiden',
    'kepresidenanan': 'presiden',
    'kepresidenanku': 'presiden',
    'kepresidenanmu': 'presiden',
    'berprestasi': 'prestasi',
    'berprestasinya': 'prestasi',
    'berprestasilah': 'prestasi',
    'berprestise': 'prestise',
    'berpretensi': 'pretensi',
    'kepriayian': 'priayi',
    'mempribumikan': 'pribumi',
    'berprihatin': 'prihatin',
    'keprihatinan': 'prihatin',
    'keprihatinannya': 'prihatin',
    'keprihatinanlah': 'prihatin',
    'keprihatinanan': 'prihatin',
    'memprihatinkan': 'prihatin',
    'memprihatinkannya': 'prihatin',
    'memprihatinkanlah': 'prihatin',
    'memprioritaskan': 'prioritas',
    'memprioritaskannya': 'prioritas',
    'mengemprit': 'prit',
    'memprivatisasikan': 'privatisasi',
    'pemroduksi': 'produksi',
    'pemroduksinya': 'produksi',
    'pemroduksian': 'produksi',
    'berproduksi': 'produksi',
    'berproduksinya': 'produksi',
    'memproduksi': 'produksi',
    'memproduksinya': 'produksi',
    'memproduksikan': 'produksi',
    'keproduktifan': 'produktif',
    'keproduktifannya': 'produktif',
    'berprofesi': 'profesi',
    'pemrogram': 'program',
    'pemrogramnya': 'program',
    'pemrograman': 'program',
    'memprogram': 'program',
    'memprogramnya': 'program',
    'memprogramkan': 'program',
    'memprogramkannya': 'program',
    'memprograman': 'program',
    'terprogram': 'program',
    'terprogramnya': 'program',
    'terprogramlah': 'program',
    'terprogramkan': 'program',
    'pemrogramannya': 'program',
    'memprosakan': 'prosa',
    'pemrotes': 'protes',
    'pemrotesnya': 'protes',
    'pemrotesan': 'protes',
    'memprotes': 'protes',
    'memprotesnya': 'protes',
    'memprotesi': 'protes',
    'terprovokasi': 'provokasi',
    'terprovokasinya': 'provokasi',
    'memproyeksikan': 'proyeksi',
    'memproyeksikannya': 'proyeksi',
    'berpuak-puak': 'puak',
    'berpuaka': 'puaka',
    'kepualan': 'pual',
    'berpual-pual': 'pual',
    'terpublikasi': 'publikasi',
    'terpublikasinya': 'publikasi',
    'terpublikasikan': 'publikasi',
    'terpublikasikannya': 'publikasi',
    'pemublikasian': 'publikasi',
    'memublikasikan': 'publikasi',
    'memublikasikannya': 'publikasi',
    'berpucuk': 'pucuk',
    'memudikan': 'pudi',
    'memudur': 'pudur',
    'memudurkan': 'pudur',
    'memuduri': 'pudur',
    'berpugak-pugak': 'pugak',
    'memugar': 'pugar',
    'memugarnya': 'pugar',
    'pemugar': 'pugar',
    'pemugaran': 'pugar',
    'memugari': 'pugar',
    'pemugarannya': 'pugar',
    'memugarkan': 'pugar',
    'memugas': 'pugas',
    'pugasan': 'pugas',
    'pemugasan': 'pugas',
    'memuingkan': 'puing',
    'puing-puing': 'puing',
    'puing-puingnya': 'puing',
    'berpuing-puing': 'puing',
    'berpuisi': 'puisi',
    'pemuisian': 'puisi',
    'memuisikan': 'puisi',
    'kepujanggaan': 'pujangga',
    'memujuk': 'pujuk',
    'memujuknya': 'pujuk',
    'terpujuk': 'pujuk',
    'memujut': 'pujut',
    'memukal': 'pukal',
    'sepukal': 'pukal',
    'memukang-mukang': 'pukang',
    'berpukas': 'pukas',
    'berpukas-pukas': 'pukas',
    'pengepul': 'pul',
    'pengepulnya': 'pul',
    'pengepulkan': 'pul',
    'puluhan': 'puluh',
    'puluhannya': 'puluh',
    'puluhanlah': 'puluh',
    'puluhanan': 'puluh',
    'sepuluh': 'puluh',
    'sepuluhnya': 'puluh',
    'sepuluhan': 'puluh',
    'perpuluhan': 'puluh',
    'persepuluhan': 'puluh',
    'berpuluh-puluh': 'puluh',
    'memulun-mulun': 'pulun',
    'berpulun-pulun': 'pulun',
    'pemulung': 'pulung',
    'pemulungnya': 'pulung',
    'pemulungan': 'pulung',
    'memulung': 'pulung',
    'memulungnya': 'pulung',
    'memulungi': 'pulung',
    'memulut': 'pulut',
    'terpulut': 'pulut',
    'pulut-pulut': 'pulut',
    'memumpun': 'pumpun',
    'memumpuni': 'pumpun',
    'pumpunan': 'pumpun',
    'terpumpun': 'pumpun',
    'berpumpun': 'pumpun',
    'pundi-pundi': 'pundi',
    'pundi-pundinya': 'pundi',
    'memundi-mundi': 'pundi',
    'memundi-mundikan': 'pundi',
    'memunggal': 'punggal',
    'memunggung': 'punggung',
    'memunggungi': 'punggung',
    'memunggungkan': 'punggung',
    'punggung-memunggung': 'punggung',
    'memungkang': 'pungkang',
    'pungkasan': 'pungkas',
    'pemungkas': 'pungkas',
    'pemungkasnya': 'pungkas',
    'memungkasi': 'pungkas',
    'pemungkur': 'pungkur',
    'memungli': 'pungli',
    'sepunguk': 'punguk',
    'punjungan': 'punjung',
    'memunjungi': 'punjung',
    'memunjut': 'punjut',
    'puntalan': 'puntal',
    'memuntal': 'puntal',
    'pemuntal': 'puntal',
    'pemuntalan': 'puntal',
    'berpuntal-puntal': 'puntalan',
    'puntiran': 'puntir',
    'memuntir': 'puntir',
    'memuntirnya': 'puntir',
    'memuntung': 'puntung',
    'memuntungkan': 'puntung',
    'berpunuk': 'punuk',
    'sepupu': 'pupu',
    'sepupunya': 'pupu',
    'sepupuan': 'pupu',
    'sepupuku': 'pupu',
    'sepupumu': 'pupu',
    'memupuh': 'pupuh',
    'berpupuh': 'pupuh',
    'memperpupuhkan': 'pupuh',
    'pupuk hijau': 'memupuk',
    'memupur': 'pupur',
    'memupuri': 'pupur',
    'berpupur': 'pupur',
    'memupurkan': 'pupur',
    'puputan': 'puput',
    'memuput': 'puput',
    'berpuput': 'puput',
    'berpura-pura': 'pura-pura',
    'berpura-puralah': 'pura-pura',
    'kepura-puraan': 'pura-pura',
    'kepurbaan': 'purba',
    'kepurbakalaan': 'purbakala',
    'berpuru': 'puru',
    'berpuruan': 'puru',
    'terpuruk': 'puruk',
    'terpuruknya': 'puruk',
    'terpuruklah': 'puruk',
    'terpurukan': 'puruk',
    'memurukkan': 'puruk',
    'seterpuruk': 'puruk',
    'memusakai': 'pusaka',
    'berpusaka': 'pusaka',
    'memusakakan': 'pusaka',
    'memusar': 'pusar',
    'pusaran': 'pusar',
    'pusarannya': 'pusar',
    'berpusar': 'pusar',
    'berpusaran': 'pusar',
    'pusar-pusar': 'pusar',
    'berpusar-pusar': 'pusar',
    'sepusat': 'pusat',
    'berpusat': 'pusat',
    'berpusatnya': 'pusat',
    'berpusatkan': 'pusat',
    'pemusatan': 'pusat',
    'pemusatanan': 'pusat',
    'memusatkan': 'pusat',
    'memusatkannya': 'pusat',
    'memusokan': 'puso',
    'berpusu': 'pusu',
    'berpusu-pusu': 'pusu',
    'memusut': 'pusut',
    'memusutkan': 'pusut',
    'berputar lidah': 'putar lidah',
    'puteran': 'puter',
    'memuter': 'puter',
    'berputih mata': 'putih mata',
    'berputih tulang': 'putih tulang',
    'berputik': 'putik',
    'berputra': 'putra',
    'keputraan': 'putra',
    'memutrakan': 'putra',
    'berputrakan': 'putra',
    'berpuyan': 'puyan',
    'memuyengkan': 'puyeng',
    'memuyu-muyu': 'puyu',
    'berqalam': 'qalam',
    'mengqasar': 'qasar',
    'rabaan': 'raba',
    'meraba': 'raba',
    'merabanya': 'raba',
    'merabai': 'raba',
    'peraba': 'raba',
    'perabanya': 'raba',
    'perabaan': 'raba',
    'teraba': 'raba',
    'terabanya': 'raba',
    'perabaannya': 'raba',
    'meraba-raba': 'raba',
    'meraba-rabanya': 'raba',
    'meraba-rabakan': 'raba',
    'meraba-rabaku': 'raba',
    'teraba-raba': 'raba',
    'raba-rabaan': 'raba',
    'merabak': 'rabak',
    'terabak': 'rabak',
    'merabas': 'rabas',
    'merabat': 'rabat',
    'merabet': 'rabet',
    'merabit': 'rabit',
    'merabuk': 'rabuk',
    'merabuki': 'rabuk',
    'perabun': 'rabun',
    'merabuni': 'rabun',
    'kerabunan': 'rabun',
    'merabunkan': 'rabun',
    'berabun-rabun': 'rabun',
    'perabung': 'rabung',
    'merabung': 'rabung',
    'perabungan': 'rabung',
    'merabut': 'rabut',
    'meracak': 'racak',
    'seracik': 'racik',
    'meracik': 'racik',
    'meraciknya': 'racik',
    'meracikkan': 'racik',
    'racikan': 'racik',
    'racikannya': 'racik',
    'peracikan': 'racik',
    'peracikannya': 'racik',
    'meracuh': 'racuh',
    'rada-rada': 'rada',
    'rada-radanya': 'rada',
    'meradah': 'radah',
    'meradai': 'radai',
    'meradak': 'radak',
    'meradakan': 'radak',
    'beradak': 'radak',
    'meradakkan': 'radak',
    'meradikalkan': 'radikal',
    'meradiokan': 'radio',
    'meradukan': 'radu',
    'meragang': 'ragang',
    'ragangan': 'ragang',
    'meragas': 'ragas',
    'meraguk': 'raguk',
    'teragung': 'ragung',
    'merahap': 'rahap',
    'perahap': 'rahap',
    'merahapkan': 'rahap',
    'berahasia': 'rahasia',
    'berahasiakan': 'rahasia',
    'kerahasiaan': 'rahasia',
    'kerahasiaannya': 'rahasia',
    'merahasiakan': 'rahasia',
    'merahasiakannya': 'rahasia',
    'rahasia-rahasiaan': 'rahasia',
    'merahimi': 'rahim',
    'kerahiman': 'rahim',
    'kerahimannya': 'rahim',
    'merais': 'rais',
    'merajah': 'rajah',
    'merajahi': 'rajah',
    'merajalela': 'rajalela',
    'merajalelanya': 'rajalela',
    'rajaman': 'rajam',
    'merajam': 'rajam',
    'terajam': 'rajam',
    'merajang': 'rajang',
    'rajangan': 'rajang',
    'merajuk': 'rajuk',
    'merajuknya': 'rajuk',
    'perajuk': 'rajuk',
    'merajuki': 'rajuk',
    'merakah': 'rakah',
    'merakap': 'rakap',
    'merakat': 'rakat',
    'serakit': 'rakit',
    'merakit': 'rakit',
    'merakitnya': 'rakit',
    'berakit': 'rakit',
    'berakitan': 'rakit',
    'rakitan': 'rakit',
    'rakitannya': 'rakit',
    'perakit': 'rakit',
    'perakitnya': 'rakit',
    'perakitan': 'rakit',
    'perakitannya': 'rakit',
    'berakit-rakit': 'rakit',
    'meraksasa': 'raksasa',
    'meraksasanya': 'raksasa',
    'peraksi': 'raksi',
    'meraksi': 'raksi',
    'meraksikan': 'raksi',
    'berakuk': 'rakuk',
    'rakungan': 'rakung',
    'merakut': 'rakut',
    'merakyat': 'rakyat',
    'merakyatnya': 'rakyat',
    'merakyatlah': 'rakyat',
    'merakyatkan': 'rakyat',
    'perakyatan': 'rakyat',
    'kerakyatan': 'rakyat',
    'kerakyatannya': 'rakyat',
    'meralat': 'ralat',
    'meralatnya': 'ralat',
    'meralip': 'ralip',
    'beramah-tamah': 'ramah tamah',
    'keramahtamahan': 'ramah tamah',
    'keramahtamahannya': 'ramah tamah',
    'keramahtamahanan': 'ramah tamah',
    'teramai': 'ramai',
    'keramaian': 'ramai',
    'keramaiannya': 'ramai',
    'keramaianan': 'ramai',
    'meramaikan': 'ramai',
    'meramaikannya': 'ramai',
    'beramai-ramai': 'ramai',
    'berambai': 'rambai',
    'merambak': 'rambak',
    'merambakkan': 'rambak',
    'rambak tiongkok': 'rambak',
    'meramban': 'ramban',
    'rambanan': 'ramban',
    'merambang': 'rambang',
    'merambang-rambang': 'rambang',
    'merambeh': 'rambeh',
    'rambeh-rambeh': 'rambeh',
    'meraminkan': 'ramin',
    'merampai': 'rampai',
    'rampaian': 'rampai',
    'merampaikan': 'rampai',
    'merampak': 'rampak',
    'perampang': 'rampang',
    'rampatan': 'rampat',
    'merampat': 'rampat',
    'perampatan': 'rampat',
    'kerampatan': 'rampat',
    'merampatkan': 'rampat',
    'meramping': 'ramping',
    'merampingnya': 'ramping',
    'merampingkan': 'ramping',
    'merampingkannya': 'ramping',
    'merampok': 'rampok',
    'merampoknya': 'rampok',
    'merampokan': 'rampok',
    'perampok': 'rampok',
    'perampoknya': 'rampok',
    'perampokkan': 'rampok',
    'perampokan': 'rampok',
    'perampokannya': 'rampok',
    'perampungan': 'rampung',
    'perampungannya': 'rampung',
    'merampungkan': 'rampung',
    'merampungkannya': 'rampung',
    'berampus': 'rampus',
    'merampus': 'rampus',
    'meramu': 'ramu',
    'meramunya': 'ramu',
    'peramu': 'ramu',
    'peramunya': 'ramu',
    'peramuan': 'ramu',
    'ramuan': 'ramu',
    'ramuannya': 'ramu',
    'reramuan': 'ramu',
    'ramu-ramuan': 'ramu',
    'meramus': 'ramus',
    'beramus': 'ramus',
    'meranap': 'ranap',
    'meranca': 'ranca',
    'merancakan': 'rancak',
    'serancak': 'rancak',
    'rancakan': 'rancak',
    'merancak': 'rancak',
    'kerancakan': 'rancak',
    'kerancak-rancakan': 'rancak',
    'rancaman': 'rancam',
    'perancang': 'rancang',
    'perancangnya': 'rancang',
    'perancangan': 'rancang',
    'berancang': 'rancang',
    'rancangan': 'rancang',
    'rancangannya': 'rancang',
    'rancanganan': 'rancang',
    'rancanganku': 'rancang',
    'merancang': 'rancang',
    'merancangnya': 'rancang',
    'merancangkan': 'rancang',
    'merancangkannya': 'rancang',
    'merancangan': 'rancang',
    'perancangannya': 'rancang',
    'kerancuan': 'rancu',
    'kerancuannya': 'rancu',
    'merancukan': 'rancu',
    'merancung': 'rancung',
    'perancung': 'rancung',
    'perancungan': 'rancung',
    'meranda': 'randa',
    'merandai': 'randai',
    'berandai-randai': 'randai',
    'merandak': 'randak',
    'merandat': 'randat',
    'merandatkan': 'randat',
    'merandau': 'randau',
    'merandek': 'randek',
    'merandungkan': 'randung',
    'merangah': 'rangah',
    'merangai': 'rangai',
    'merangak': 'rangak',
    'meranggah': 'ranggah',
    'meranggakkan': 'ranggak',
    'meranggikan': 'ranggi',
    'meranggitkan': 'ranggit',
    'meranggul': 'ranggul',
    'meranggung': 'ranggung',
    'berangkaian': 'rangkai',
    'serangkai': 'rangkai',
    'serangkaian': 'rangkai',
    'perangkai': 'rangkai',
    'perangkainya': 'rangkai',
    'perangkaian': 'rangkai',
    'merangkai': 'rangkai',
    'merangkainya': 'rangkai',
    'merangkaikan': 'rangkai',
    'merangkaikannya': 'rangkai',
    'rangkaian': 'rangkai',
    'rangkaiannya': 'rangkai',
    'menyerangkaikan': 'rangkai',
    'berangkai-rangkai': 'rangkai',
    'merangkam': 'rangkam',
    'merangkang': 'rangkang',
    'merangket': 'rangket',
    'merangkit': 'rangkit',
    'merangkung': 'rangkung',
    'rangkungan': 'rangkung',
    'merangkus': 'rangkus',
    'merangkut': 'rangkut',
    'merangum': 'rangum',
    'seranjang': 'ranjang',
    'seranjangnya': 'ranjang',
    'berseranjang': 'ranjang',
    'meranjangkan': 'ranjang',
    'keranjingan': 'ranjing',
    'keranjingannya': 'ranjing',
    'meransum': 'ransum',
    'berantam': 'rantam',
    'berantamlah': 'rantam',
    'merantas': 'rantas',
    'perantau': 'rantau',
    'perantauan': 'rantau',
    'merantau': 'rantau',
    'merantaunya': 'rantau',
    'merantaulah': 'rantau',
    'serantau': 'rantau',
    'perantauannya': 'rantau',
    'perantauanmu': 'rantau',
    'meranting': 'ranting',
    'beranting': 'ranting',
    'merantuk': 'rantuk',
    'merantukkan': 'rantuk',
    'meranyah': 'ranyah',
    'meranyau': 'ranyau',
    'meranyun': 'ranyun',
    'merapah': 'rapah',
    'merapai': 'rapai',
    'merapal': 'rapal',
    'merapalkan': 'rapal',
    'merapik': 'rapik',
    'merapikkan': 'rapik',
    'raporan': 'rapor',
    'meraporkan': 'rapor',
    'merapu': 'rapu',
    'merapukan': 'rapu',
    'perapuh': 'rapuh',
    'perapuhan': 'rapuh',
    'kerapuhan': 'rapuh',
    'kerapuhannya': 'rapuh',
    'merapuhkan': 'rapuh',
    'berapun': 'rapun',
    'merapun': 'rapun',
    'merapung': 'rapung',
    'merapungkan': 'rapung',
    'merapus': 'rapus',
    'merarai': 'rarai',
    'perarai': 'rarai',
    'merarasi': 'raras',
    'serasam': 'rasam',
    'berasan': 'rasan',
    'merasani': 'rasan',
    'perasanan': 'rasan',
    'perasanannya': 'rasan',
    'merasi': 'rasi',
    'merasikan': 'rasi',
    'berasian': 'rasian',
    'merasiankan': 'rasian',
    'berasio': 'rasio',
    'kerasionalan': 'rasional',
    'merasionalkan': 'rasional',
    'merasionalisasi': 'rasionalisasi',
    'merasionalisasikan': 'rasionalisasi',
    'merasionalisasikannya': 'rasionalisasi',
    'kerasulan': 'rasul',
    'kerasulannya': 'rasul',
    'meratah': 'ratah',
    'meratib': 'ratib',
    'meratibkan': 'ratib',
    'meratifikasi': 'ratifikasi',
    'meratifikasinya': 'ratifikasi',
    'meraum': 'raum',
    'meraun': 'raun',
    'raun-raun': 'raun',
    'rautan': 'raut',
    'meraut': 'raut',
    'berawa': 'rawa',
    'berawa-rawa': 'rawa',
    'merawai': 'rawai',
    'merawaikan': 'rawai',
    'merawak': 'rawak',
    'serawan': 'rawan',
    'merawan': 'rawan',
    'kerawanan': 'rawan',
    'kerawanannya': 'rawan',
    'kerawananan': 'rawan',
    'merawankan': 'rawan',
    'merawang': 'rawang',
    'perawi': 'rawi',
    'perawinya': 'rawi',
    'merawi': 'rawi',
    'merawikan': 'rawi',
    'merawit': 'rawit',
    'kerawitan': 'rawit',
    'pengrawit': 'rawit',
    'rayahan': 'rayah',
    'merayah': 'rayah',
    'merayahi': 'rayah',
    'merayang': 'rayang',
    'merayap': 'rayap',
    'merayapnya': 'rayap',
    'merayapi': 'rayap',
    'rayapan': 'rayap',
    'terayap-rayap': 'rayap',
    'perayonan': 'rayon',
    'merealisasi': 'realisasi',
    'merealisasikan': 'realisasi',
    'merealisasikannya': 'realisasi',
    'merealisasian': 'realisasi',
    'berebab': 'rebab',
    'merebankan': 'reban',
    'berebana': 'rebana',
    'rebas-rebas': 'rebas',
    'merebat': 'rebat',
    'merebeh': 'rebeh',
    'rebekan': 'rebek',
    'berebesan': 'rebes',
    'merebuk': 'rebuk',
    'merebung': 'rebung',
    'merecak': 'recak',
    'recehan': 'receh',
    'recehannya': 'receh',
    'perecik': 'recik',
    'merecik': 'recik',
    'recikan': 'recik',
    'merecikkan': 'recik',
    'perecok': 'recok',
    'merecok': 'recok',
    'merecokkan': 'recok',
    'merecoki': 'recok',
    'merecokinya': 'recok',
    'kerecokan': 'recok',
    'merecup': 'recup',
    'meredah': 'redah',
    'meredahkan': 'redah',
    'meredih': 'redih',
    'peredih': 'redih',
    'meredik': 'redik',
    'mereduksi': 'reduksi',
    'mereduksinya': 'reduksi',
    'meredup': 'redup',
    'meredupnya': 'redup',
    'meredupkan': 'redup',
    'meredupkannya': 'redup',
    'keredupan': 'redup',
    'redep-redup': 'redup',
    'meredusir': 'redusir',
    'meredut': 'redut',
    'mereekspor': 'reekspor',
    'merefleksikan': 'refleksi',
    'merefleksikannya': 'refleksi',
    'terefleksikan': 'refleksi',
    'berefraksi': 'refraksi',
    'meregah': 'regah',
    'meregang': 'regang',
    'meregangnya': 'regang',
    'meregangkan': 'regang',
    'meregangkannya': 'regang',
    'regangan': 'regang',
    'regangannya': 'regang',
    'peregangan': 'regang',
    'peregangannya': 'regang',
    'berseregang': 'seregang',
    'beregang-regang': 'regang',
    'meregas': 'regas',
    'meregat': 'regat',
    'keregenan': 'regen',
    'sereguk': 'reguk',
    'mereguk': 'reguk',
    'mereguknya': 'reguk',
    'meregukan': 'reguk',
    'meregup': 'regup',
    'merehab': 'rehab',
    'merehabnya': 'rehab',
    'merehabilitasi': 'rehabilitasi',
    'merehabilitasinya': 'rehabilitasi',
    'merehabilitasikan': 'rehabilitasi',
    'reja-reja': 'reja',
    'merejah': 'rejah',
    'perejah': 'rejah',
    'merejahkan': 'rejah',
    'merejan': 'rejan',
    'merejang': 'rejang',
    'perejang': 'rejang',
    'serejang': 'rejang',
    'merejeng': 'rejeng',
    'merejuk': 'rejuk',
    'mereka cipta': 'reka cipta',
    'perekam': 'rekam',
    'perekamnya': 'rekam',
    'perekaman': 'rekam',
    'rekaman': 'rekam',
    'rekamannya': 'rekam',
    'rekamanlah': 'rekam',
    'rekamanan': 'rekam',
    'rekamanku': 'rekam',
    'merekam': 'rekam',
    'merekamnya': 'rekam',
    'merekamlah': 'rekam',
    'merekamkan': 'rekam',
    'merekaman': 'rekam',
    'merekammu': 'rekam',
    'perekamannya': 'rekam',
    'perekamanan': 'rekam',
    'merekan': 'rekan',
    'berekan': 'rekan',
    'berekanan': 'rekan',
    'rekanan': 'rekan',
    'rekanannya': 'rekan',
    'rekananan': 'rekan',
    'perekayasa': 'rekayasa',
    'perekayasaan': 'rekayasa',
    'merekayasa': 'rekayasa',
    'merekayasanya': 'rekayasa',
    'rekenan': 'reken',
    'mereken': 'reken',
    'merekes': 'rekes',
    'mereklamasikan': 'reklamasi',
    'merekomendasi': 'rekomendasi',
    'merekomendasinya': 'rekomendasi',
    'merekomendasikan': 'rekomendasi',
    'merekomendasikannya': 'rekomendasi',
    'merekonstruksi': 'rekonstruksi',
    'merekonstruksinya': 'rekonstruksi',
    'merekonstruksikan': 'rekonstruksi',
    'berekreasi': 'rekreasi',
    'merekrut': 'rekrut',
    'merekrutnya': 'rekrut',
    'merekruti': 'rekrut',
    'merekrutku': 'rekrut',
    'merekrutmu': 'rekrut',
    'perekrutan': 'rekrut',
    'perekrutannya': 'rekrut',
    'merelang': 'relang',
    'merelas': 'relas',
    'merelevansi': 'relevansi',
    'merelevansikan': 'relevansi',
    'pereli': 'reli',
    'merelokasi': 'relokasi',
    'merelokasinya': 'relokasi',
    'merelokasikan': 'relokasi',
    'merelokasikannya': 'relokasi',
    'bereluk': 'reluk',
    'merelung': 'relung',
    'mengerem': 'rem',
    'mengeremnya': 'rem',
    'keremahan': 'remah',
    'meremahkan': 'remah',
    'remah-remah': 'remah',
    'remah-remahnya': 'remah',
    'remah-remahan': 'remah',
    'meremah-remah': 'remah',
    'peremajaan': 'remaja',
    'peremajaannya': 'remaja',
    'meremajakan': 'remaja',
    'meremajakannya': 'remaja',
    'meremas': 'remas',
    'meremasnya': 'remas',
    'meremas-remas': 'remas',
    'meremas-remasnya': 'remas',
    'merembah': 'rembah',
    'rembah-rembah': 'rembah',
    'rembah-rembih': 'rembah',
    'merembet': 'rembet',
    'merembetnya': 'rembet',
    'merembetkan': 'rembet',
    'merembih': 'rembih',
    'berembuk': 'rembuk',
    'berembuklah': 'rembuk',
    'rembukan': 'rembuk',
    'perembukan': 'rembuk',
    'merembukkan': 'rembuk',
    'merembukkannya': 'rembuk',
    'memperembukkan': 'rembuk',
    'berembut-rembut': 'rembut',
    'terembut-rembut': 'rembut',
    'meremet': 'remet',
    'merempa': 'rempa',
    'merempah': 'rempah',
    'merempahi': 'rempah',
    'rempah-rempah': 'rempah',
    'rempah-rempahnya': 'rempah',
    'rempah-rempahan': 'rempah',
    'merempah-rempah': 'rempah',
    'merempah-rempahi': 'rempah',
    'serempak': 'rempak',
    'serempaknya': 'rempak',
    'berempak': 'rempak',
    'menyerempak': 'serempak',
    'menyerempakkan': 'serempak',
    'peremuk': 'remuk',
    'peremukan': 'remuk',
    'meremukkan': 'remuk',
    'meremukkannya': 'remuk',
    'terencah': 'rencah',
    'merencah': 'rencah',
    'perencah': 'rencah',
    'merencam': 'rencam',
    'terencat': 'rencat',
    'berenceng': 'renceng',
    'serenceng': 'renceng',
    'rencengan': 'renceng',
    'merendang': 'rendang',
    'perendangan': 'rendang',
    'berendeng': 'rendeng',
    'merendengkan': 'rendeng',
    'terendong': 'rendong',
    'merenek': 'renek',
    'merengap': 'rengap',
    'merengas': 'rengas',
    'merengat': 'rengat',
    'merengatkan': 'rengat',
    'merengeh': 'rengeh',
    'merengeng-rengeng': 'rengeng',
    'merengkah': 'rengkah',
    'perengkahan': 'rengkah',
    'merengkeh': 'rengkeh',
    'merengket': 'rengket',
    'merengkuh': 'rengkuh',
    'merengkuhnya': 'rengkuh',
    'merengsa': 'rengsa',
    'berengsaan': 'rengsa',
    'perengut': 'rengut',
    'merengut': 'rengut',
    'merengutkan': 'rengut',
    'merenik-renik': 'renik',
    'merenjeng': 'renjeng',
    'merenjis': 'renjis',
    'merenjiskan': 'renjis',
    'merenovasi': 'renovasi',
    'merenovasinya': 'renovasi',
    'merenta-renta': 'renta',
    'merentak': 'rentak',
    'merentakan': 'rentak',
    'terentak': 'rentak',
    'serentak': 'rentak',
    'serentaknya': 'rentak',
    'menyerentakkan': 'rentak',
    'merentan': 'rentan',
    'merentankan': 'rentan',
    'kerentanan': 'rentan',
    'kerentanannya': 'rentan',
    'kerentananan': 'rentan',
    'merentap': 'rentap',
    'merentapkan': 'rentap',
    'merentas': 'rentas',
    'rentengan': 'renteng',
    'serenteng': 'renteng',
    'serentengan': 'renteng',
    'merenteng': 'renteng',
    'berenteng-renteng': 'renteng',
    'berentet': 'rentet',
    'berentetan': 'rentet',
    'rentetan': 'rentet',
    'rentetannya': 'rentet',
    'merentikan': 'renti',
    'merentik': 'rentik',
    'berenyah': 'renyah',
    'merenyah': 'renyah',
    'merenyahnya': 'renyah',
    'kerenyahan': 'renyah',
    'kerenyahannya': 'renyah',
    'renyai-renyai': 'renyai',
    'merenyai-renyai': 'renyai',
    'merenyeh': 'renyeh',
    'merenyuk': 'renyuk',
    'serenyuk': 'renyuk',
    'merenyukkan': 'renyuk',
    'merenyut': 'renyut',
    'merepang': 'repang',
    'mereparasi': 'reparasi',
    'mereparasinya': 'reparasi',
    'terepas': 'repas',
    'keterepasan': 'repas',
    'merepatriasi': 'repatriasi',
    'merepatriasikan': 'repatriasi',
    'merepet': 'repet',
    'perepet': 'repet',
    'repihan': 'repih',
    'serepih': 'repih',
    'mereportasekan': 'reportase',
    'kerepotan': 'repot',
    'kerepotannya': 'repot',
    'kerepotanlah': 'repot',
    'merepotkan': 'repot',
    'merepotkannya': 'repot',
    'merepotkanmu': 'repot',
    'repot-repot': 'repot',
    'repot-repotlah': 'repot',
    'mereproduksi': 'reproduksi',
    'mereproduksinya': 'reproduksi',
    'repuh-repuh': 'repuh',
    'mererak': 'rerak',
    'bererakan': 'rerak',
    'rerotan': 'rerot',
    'mererot': 'rerot',
    'seresam': 'resam',
    'meresan': 'resan',
    'meresek-resek': 'resek',
    'meresepkan': 'resep',
    'meresepkannya': 'resep',
    'keresidenan': 'residen',
    'meresik': 'resik',
    'keresikan': 'resik',
    'peresmian': 'resmi',
    'peresmiannya': 'resmi',
    'keresmian': 'resmi',
    'keresmiannya': 'resmi',
    'meresmikan': 'resmi',
    'meresmikannya': 'resmi',
    'meresosialisasi': 'resosialisasi',
    'merespons': 'respons',
    'meresponsnya': 'respons',
    'meresponslah': 'respons',
    'meresponsi': 'respons',
    'meresponsmu': 'respons',
    'merestorasi': 'restorasi',
    'merestorasinya': 'restorasi',
    'merestrukturisasi': 'restrukturisasi',
    'merestrukturisasinya': 'restrukturisasi',
    'merestrukturisasikan': 'restrukturisasi',
    'meresumekan': 'resume',
    'peretas': 'retas',
    'peretasnya': 'retas',
    'peretaslah': 'retas',
    'peretasan': 'retas',
    'meretas': 'retas',
    'meretasnya': 'retas',
    'meretaskan': 'retas',
    'peretasannya': 'retas',
    'meretek': 'retek',
    'meretih': 'retih',
    'meretur': 'retur',
    'merevisi': 'revisi',
    'merevisinya': 'revisi',
    'merewak': 'rewak',
    'merewaknya': 'rewak',
    'kerewelan': 'rewel',
    'kerewelannya': 'rewel',
    'merewet': 'rewet',
    'keriaan': 'ria',
    'keriaannya': 'ria',
    'beria-ria': 'ria',
    'beriak': 'riak',
    'beriak-riak': 'riak',
    'meriap': 'riap',
    'meriapkan': 'riap',
    'ribaan': 'riba',
    'meriba': 'riba',
    'rica-rica': 'rica',
    'mericau': 'ricau',
    'mericik': 'ricik',
    'kericuhan': 'ricuh',
    'kericuhannya': 'ricuh',
    'meridai': 'rida',
    'berigi-rigi': 'rigi-rigi',
    'berihat': 'rihat',
    'merikuhkan': 'rikuh',
    'merilis': 'rilis',
    'merilisnya': 'rilis',
    'meriliskan': 'rilis',
    'merilisi': 'rilis',
    'berima': 'rima',
    'merimaskan': 'rimas',
    'perimba': 'rimba',
    'perimbakan': 'rimba',
    'merimba': 'rimba',
    'merimbas': 'rimbas',
    'merimbun': 'rimbun',
    'merimbunkan': 'rimbun',
    'merimbuni': 'rimbun',
    'kerimbunan': 'rimbun',
    'kerimbunannya': 'rimbun',
    'serimis': 'rimis',
    'merimpuhkan': 'rimpuh',
    'merimpung': 'rimpung',
    'merinai': 'rinai',
    'berinaian': 'rinai',
    'merinaikan': 'rinai',
    'rinai-rinai': 'rinai',
    'perincis': 'rincis',
    'rincisan': 'rincis',
    'merincis': 'rincis',
    'perincisan': 'rincis',
    'merincukan': 'rincu',
    'perindang': 'rindang',
    'perindangan': 'rindang',
    'merindang': 'rindang',
    'merindangkan': 'rindang',
    'merindangi': 'rindang',
    'merinding': 'rinding',
    'merindingnya': 'rinding',
    'merindingkan': 'rinding',
    'perindu': 'rindu',
    'perindukan': 'rindu',
    'merindu': 'rindu',
    'merindukan': 'rindu',
    'merindukannya': 'rindu',
    'merindui': 'rindu',
    'rinduan': 'rindu',
    'kerinduan': 'rindu',
    'kerinduannya': 'rindu',
    'kerinduanku': 'rindu',
    'kerinduanmu': 'rindu',
    'merindukanku': 'rindu',
    'merindukanmu': 'rindu',
    'meringgiti': 'ringgit',
    'beringgit-ringgit': 'ringgit',
    'meringih': 'ringih',
    'meringik': 'ringik',
    'meringis': 'ringis',
    'meringkai': 'ringkai',
    'meringkaikan': 'ringkai',
    'ringkasan': 'ringkas',
    'ringkasannya': 'ringkas',
    'meringkaskan': 'ringkas',
    'meringking': 'ringking',
    'meringkuk': 'ringkuk',
    'meringkuknya': 'ringkuk',
    'meringkuklah': 'ringkuk',
    'ringkukan': 'ringkuk',
    'meringkukkan': 'ringkuk',
    'dalam ringkuk': 'ringkuk',
    'meringkus': 'ringkus',
    'meringkusnya': 'ringkus',
    'meringsing': 'ringsing',
    'merintas': 'rintas',
    'berintik-rintik': 'rintik',
    'merintik-rintik': 'rintik-rintik',
    'merisak': 'risak',
    'merisaknya': 'risak',
    'periset': 'riset',
    'perisetnya': 'riset',
    'meriset': 'riset',
    'merisetnya': 'riset',
    'merisik': 'risik',
    'risikan': 'risik',
    'merisikkan': 'risik',
    'meritul': 'ritul',
    'meriung': 'riung',
    'riungan': 'riung',
    'beriwayat': 'riwayat',
    'keriwayatan': 'riwayat',
    'meriwayatkan': 'riwayat',
    'robekan': 'robek',
    'robekannya': 'robek',
    'merobek': 'robek',
    'merobeknya': 'robek',
    'merobekkan': 'robek',
    'merobeki': 'robek',
    'merobekan': 'robek',
    'perobek': 'robek',
    'perobekan': 'robek',
    'merobek-robek': 'robek',
    'merobek-robeknya': 'robek',
    'merobok': 'robok',
    'bersirobok': 'robok',
    'merobot': 'robot',
    'perobotan': 'robot',
    'beroda': 'roda',
    'berodanya': 'roda',
    'berodi': 'rodi',
    'merodong': 'rodong',
    'merodongkan': 'rodong',
    'merogoh': 'rogoh',
    'merogohnya': 'rogoh',
    'merogohkan': 'rogoh',
    'merogok': 'rogok',
    'merogol': 'rogol',
    'merogolnya': 'rogol',
    'kerohanian': 'rohani',
    'kerohaniannya': 'rohani',
    'rojengan': 'rojeng',
    'merojeng': 'rojeng',
    'merojol': 'rojol',
    'meroket': 'roket',
    'meroketnya': 'roket',
    'meroketkan': 'roket',
    'meroketi': 'roket',
    'peroketan': 'roket',
    'seroma': 'roma',
    'keromantisan': 'romantis',
    'keromantisannya': 'romantis',
    'meromantisisme': 'romantisisme',
    'merombak': 'rombak',
    'merombaknya': 'rombak',
    'merombakan': 'rombak',
    'perombakan': 'rombak',
    'perombakannya': 'rombak',
    'perombakanan': 'rombak',
    'rombengan': 'rombeng',
    'merombengkan': 'rombeng',
    'merombong': 'rombong',
    'rombongan': 'rombong',
    'rombongannya': 'rombong',
    'rombongani': 'rombong',
    'meromet': 'romet',
    'meromok': 'romok',
    'rompang-romping': 'rompang',
    'merompongkan': 'rompong',
    'meromusakan': 'romusa',
    'berona': 'rona',
    'perona': 'rona',
    'teronce': 'ronce',
    'meronce': 'ronce',
    'peroncean': 'ronce',
    'beroncet-roncet': 'roncet',
    'merondok': 'rondok',
    'berondok': 'rondok',
    'merondokkan': 'rondok',
    'meroneo': 'roneo',
    'merongga': 'rongga',
    'berongga': 'rongga',
    'meronggeng': 'ronggeng',
    'keronggengan': 'ronggeng',
    'meronggong': 'ronggong',
    'merongkok': 'rongkok',
    'berongkol': 'rongkol',
    'serongkol': 'rongkol',
    'merongos': 'rongos',
    'rongkong': 'rongos',
    'perongos': 'rongos',
    'perongrong': 'rongrong',
    'perongrongan': 'rongrong',
    'merongrong': 'rongrong',
    'merongrongnya': 'rongrong',
    'merongseng': 'rongseng',
    'rongsokan': 'rongsok',
    'rongsokannya': 'rongsok',
    'meronta': 'ronta',
    'meronta-ronta': 'ronta',
    'merontgen': 'rontgen',
    'kerontokan': 'rontok',
    'kerontokannya': 'rontok',
    'merontokkan': 'rontok',
    'merontokkannya': 'rontok',
    'meronyeh': 'ronyeh',
    'meronyok': 'ronyok',
    'merorod': 'rorod',
    'merosok': 'rosok',
    'rosokan': 'rosok',
    'merosokkan': 'rosok',
    'berotasi': 'rotasi',
    'merotok': 'rotok',
    'merowot': 'rowot',
    'meroyak': 'royak',
    'keroyalan': 'royal',
    'beroyal-royal': 'royal',
    'royal-royalan': 'royal',
    'meroyan': 'royan',
    'meroyer': 'royer',
    'merua': 'rua',
    'meruanya': 'rua',
    'meruakan': 'ruak',
    'seruah': 'ruah',
    'meruah': 'ruah',
    'meruahnya': 'ruah',
    'seperuah': 'ruah',
    'meruahkan': 'ruah',
    'meruak': 'ruak',
    'meruaknya': 'ruak',
    'ruak-ruak': 'ruak',
    'meruang': 'ruang',
    'meruangkan': 'ruang',
    'ruangan': 'ruang',
    'ruangannya': 'ruang',
    'ruanganlah': 'ruang',
    'ruanganan': 'ruang',
    'ruanganku': 'ruang',
    'ruanganmu': 'ruang',
    'meruap': 'ruap',
    'meruapnya': 'ruap',
    'meruapkan': 'ruap',
    'meruapan': 'ruap',
    'meruap-ruap': 'ruap',
    'seruas': 'ruas',
    'peruasan': 'ruas',
    'beruas-ruas': 'ruas',
    'meruban': 'ruban',
    'merubu': 'rubu',
    'merubu-rubu': 'rubu',
    'merubung': 'rubung',
    'merubungi': 'rubung',
    'merudal': 'rudal',
    'merudalnya': 'rudal',
    'merudu': 'rudu',
    'meruing': 'ruing',
    'teruit': 'uit',
    'merujah': 'rujah',
    'ruji-ruji': 'ruji',
    'meruku': 'ruku',
    'reruku': 'ruku',
    'ruku-ruku': 'ruku',
    'merukuk': 'rukuk',
    'kerukunan': 'rukun',
    'kerukunannya': 'rukun',
    'kerukunanan': 'rukun',
    'merukunkan': 'rukun',
    'serumah': 'rumah',
    'serumahnya': 'rumah',
    'berumah': 'rumah',
    'berumahkan': 'rumah',
    'perumahan': 'rumah',
    'perumahannya': 'rumah',
    'perumahanlah': 'rumah',
    'perumahanan': 'rumah',
    'merumahkan': 'rumah',
    'merumahkannya': 'rumah',
    'memperumahkan': 'rumah',
    'rumah-rumahan': 'rumah',
    'rumah-rumahannya': 'rumah',
    'menyerumahkan': 'rumah',
    'merumahsakitkan': 'rumah sakit',
    'berumah tangga': 'rumah tangga',
    'kerumahtanggaan': 'rumah tangga',
    'kerumahtanggaannya': 'rumah tangga',
    'berumbai-rumbai': 'rumbai',
    'merumbu': 'rumbu',
    'rumitan': 'rumit',
    'kerumitan': 'rumit',
    'kerumitannya': 'rumit',
    'merumitkan': 'rumit',
    'merumitkannya': 'rumit',
    'merumpi': 'rumpi',
    'kerumpilan': 'rumpil',
    'merumponkan': 'rumpon',
    'berumpun': 'rumpun',
    'serumpun': 'rumpun',
    'serumpunnya': 'rumpun',
    'merumpun': 'rumpun',
    'berrumpun-rumpun': 'rumpun',
    'merumput': 'rumput',
    'merumputnya': 'rumput',
    'merumputkan': 'rumput',
    'merumputkannya': 'rumput',
    'merumputi': 'rumput',
    'rerumputan': 'rumput',
    'rerumputannya': 'rumput',
    'perumputan': 'rumput',
    'rumput-rumputan': 'rumput',
    'merumrum': 'rumrum',
    'merumuk': 'rumuk',
    'merumung': 'rumung',
    'runding-merunding': 'berunding',
    'rundukan': 'runduk',
    'merunduk': 'runduk',
    'merunduklah': 'runduk',
    'merundukkan': 'runduk',
    'merundukan': 'runduk',
    'merunggas': 'runggas',
    'berunggas-runggas': 'runggas',
    'rungguhan': 'rungguh',
    'merungguh': 'rungguh',
    'merungguhkan': 'rungguh',
    'merunggut': 'runggut',
    'merungkau': 'rungkau',
    'kerungkuhan': 'rungkuh',
    'merungkup': 'rungkup',
    'merungus': 'rungus',
    'merungus-rungus': 'rungus',
    'merunjam': 'runjam',
    'merunjang': 'runjang',
    'merunjau': 'runjau',
    'merunjung': 'runjung',
    'meruntas': 'runtas',
    'merunti': 'runti',
    'meruntih': 'runtih',
    'runtunan': 'runtun',
    'meruntun': 'runtun',
    'meruntunkan': 'runtun',
    'beruntun': 'untun',
    'beruntunnya': 'untun',
    'beruntun-runtun': 'runtun',
    'beruntutan': 'runtutan',
    'perunut': 'runut',
    'perunutan': 'runut',
    'runutan': 'runut',
    'runutannya': 'runut',
    'merunut': 'runut',
    'merunutnya': 'runut',
    'merunutkan': 'runut',
    'merunuti': 'runut',
    'merunyamkan': 'runyam',
    'merunyut': 'runyut',
    'meruok': 'ruok',
    'serupiah': 'rupiah',
    'merurut': 'rurut',
    'merusuh': 'rusuh',
    'merusuhkan': 'rusuh',
    'merusuhi': 'rusuh',
    'perusuh': 'rusuh',
    'perusuhnya': 'rusuh',
    'perusuhan': 'rusuh',
    'berusuh': 'rusuh',
    'berusuhan': 'rusuh',
    'kerusuhan': 'rusuh',
    'kerusuhannya': 'rusuh',
    'kerusuhanlah': 'rusuh',
    'kerusuhanan': 'rusuh',
    'memperusuh': 'rusuh',
    'merusuk': 'rusuk',
    'kerutinan': 'rutin',
    'merutinkan': 'rutin',
    'merutuk': 'rutuk',
    'merutuki': 'rutuk',
    'ruwatan': 'ruwat',
    'ruwatannya': 'ruwat',
    'meruwat': 'ruwat',
    'keruwetan': 'ruwet',
    'keruwetannya': 'ruwet',
    'meruwetkan': 'ruwet',
    'meruyak': 'ruyak',
    'meruyaknya': 'ruyak',
    'meruyupkan': 'ruyup',
    'sesaat': 'saat',
    'sesaatnya': 'saat',
    'menyaba': 'saba',
    'bersaba': 'saba',
    'menyabak': 'sabak',
    'saban-saban': 'saban',
    'bersabar': 'sabar',
    'bersabarnya': 'sabar',
    'bersabarlah': 'sabar',
    'penyabar': 'sabar',
    'penyabaran': 'sabar',
    'tersabar': 'sabar',
    'kesabaran': 'sabar',
    'kesabarannya': 'sabar',
    'kesabaranlah': 'sabar',
    'kesabaranku': 'sabar',
    'kesabaranmu': 'sabar',
    'menyabarkan': 'sabar',
    'mempersabar': 'sabar',
    'menyabat': 'sabat',
    'bersabda': 'sabda',
    'menyabdakan': 'sabda',
    'sabetan': 'sabet',
    'sabetannya': 'sabet',
    'penyabet': 'sabet',
    'penyabetan': 'sabet',
    'menyabet': 'sabet',
    'menyabetnya': 'sabet',
    'menyabetkan': 'sabet',
    'menyabetkannya': 'sabet',
    'tersabet': 'sabet',
    'sabitan': 'sabit',
    'penyabit': 'sabit',
    'menyabit': 'sabit',
    'penyabitan': 'sabit',
    'menyabitkan': 'sabit',
    'menyablon': 'sablon',
    'penyablon': 'sablon',
    'penyablonan': 'sablon',
    'sabotan': 'sabot',
    'penyabot': 'sabot',
    'penyabotan': 'sabot',
    'menyabot': 'sabot',
    'bersabuk': 'sabuk',
    'sabuk jingga': 'sabuk',
    'menyabun': 'sabun',
    'menyabuni': 'sabun',
    'bersabun': 'sabun',
    'menyabuninya': 'sabun',
    'penyabunan': 'sabun',
    'penyabunanan': 'sabun',
    'menyabunkan': 'sabun',
    'sabungan': 'sabung',
    'penyabung': 'sabung',
    'penyabungnya': 'sabung',
    'penyabungan': 'sabung',
    'menyabung': 'sabung',
    'tersabung': 'sabung',
    'bersabung': 'sabung',
    'persabungan': 'sabung',
    'menyabungkan': 'sabung',
    'sabung-menyabung': 'sabung',
    'tersabur': 'sabur',
    'menyabur': 'sabur',
    'menyaburkan': 'sabur',
    'kesadahan': 'sadah',
    'bersadai': 'sadai',
    'tersadai': 'sadai',
    'menyadaikan': 'sadai',
    'sadang sading': 'sadang',
    'sadapan': 'sadap',
    'sadapannya': 'sadap',
    'tersadap': 'sadap',
    'tersadapnya': 'sadap',
    'menyadap': 'sadap',
    'menyadapnya': 'sadap',
    'menyadapan': 'sadap',
    'penyadap': 'sadap',
    'penyadapnya': 'sadap',
    'penyadapan': 'sadap',
    'penyadapannya': 'sadap',
    'menyadau': 'sadau',
    'bersadau': 'sadau',
    'menyadikkan': 'sadik',
    'kesadisan': 'sadis',
    'kesadisannya': 'sadis',
    'bersado': 'sado',
    'sado masokis': 'sado',
    'menyadran': 'sadran',
    'saduran': 'sadur',
    'penyadur': 'sadur',
    'penyaduran': 'sadur',
    'menyadur': 'sadur',
    'menyadurnya': 'sadur',
    'bersaf-saf': 'saf',
    'bersafar': 'safar',
    'bersafari': 'safari',
    'menyagang': 'sagang',
    'tersagang': 'sagang',
    'menyagar': 'sagar',
    'bersagar': 'sagar',
    'sesagon': 'sagon',
    'menyagu': 'sagu',
    'kesahan': 'sah',
    'pengesahan': 'sah',
    'pengesahannya': 'sah',
    'mengesahkankan': 'sah',
    'bersahaja': 'sahaja',
    'bersahajanya': 'sahaja',
    'menyahaja': 'sahaja',
    'kesahajaan': 'sahaja',
    'kesahajaannya': 'sahaja',
    'menyahajakan': 'sahaja',
    'mempersahajakan': 'sahaja',
    'menyahap': 'sahap',
    'bersahap': 'sahap',
    'kesahihan': 'sahih',
    'kesahihannya': 'sahih',
    'penyahihan': 'sahih',
    'menyahihkan': 'sahih',
    'sesajen': 'sajen',
    'sajian': 'saji',
    'sajiannya': 'saji',
    'tersaji': 'saji',
    'tersajinya': 'saji',
    'tersajilah': 'saji',
    'tersajikan': 'saji',
    'penyaji': 'saji',
    'penyajinya': 'saji',
    'penyajikan': 'saji',
    'penyajian': 'saji',
    'bersaji': 'saji',
    'penyajiannya': 'saji',
    'menyajikan': 'saji',
    'menyajikannya': 'saji',
    'saji-sajian': 'saji',
    'menyakal': 'sakal',
    'sakapan': 'sakap',
    'menyakap': 'sakap',
    'menyakapi': 'sakap',
    'penyakap': 'sakap',
    'penyakapan': 'sakap',
    'menyakar': 'sakar',
    'penyakar': 'sakar',
    'tersakat': 'sakat',
    'penyakat': 'sakat',
    'menyakatkan': 'sakat',
    'kesakralan': 'sakral',
    'kesakralannya': 'sakral',
    'bersaksi': 'saksi',
    'bersaksinya': 'saksi',
    'bersaksilah': 'saksi',
    'kesaksian': 'saksi',
    'kesaksiannya': 'saksi',
    'kesaksianku': 'saksi',
    'penyaksian': 'saksi',
    'menyaksikan': 'saksi',
    'menyaksikannya': 'saksi',
    'menyaksikanku': 'saksi',
    'menyaksikanmu': 'saksi',
    'mempersaksikan': 'saksi',
    'tersaku': 'saku',
    'saku-saku': 'saku',
    'menyakukan': 'saku',
    'penyalahartian': 'salah arti',
    'menyalahartikan': 'salah arti',
    'menyalahartikannya': 'salah arti',
    'salakan': 'salak',
    'menyalak': 'salak',
    'menyalakkan': 'salak',
    'penyalak': 'salak',
    'menyalang': 'salang',
    'bersalat': 'salat',
    'menyalatkan': 'salat',
    'menyalatkannya': 'salat',
    'kesalehan': 'saleh',
    'kesalehannya': 'saleh',
    'menyalep': 'salep',
    'penyalib': 'salib',
    'penyaliban': 'salib',
    'menyalib': 'salib',
    'menyalibnya': 'salib',
    'menyalibkan': 'salib',
    'penyalibannya': 'salib',
    'kesalingan': 'saling',
    'menyalip': 'salip',
    'menyalipnya': 'salip',
    'menyalipku': 'salip',
    'menyalipmu': 'salip',
    'bersalip-salipan': 'salip',
    'menyalju': 'salju',
    'bersalju': 'salju',
    'bersaljunya': 'salju',
    'pesalto': 'salto',
    'bersalto': 'salto',
    'bersaluir': 'saluir',
    'menyaluir': 'saluir',
    'bersaluk': 'saluk',
    'bersalung': 'salung',
    'salutan': 'salut',
    'tersalut': 'salut',
    'bersalut': 'salut',
    'penyalut': 'salut',
    'menyalut': 'salut',
    'menyaluti': 'salut',
    'penyalutan': 'salut',
    'kesamarataan': 'sama rata',
    'penyamarataan': 'sama rata',
    'menyamaratakan': 'sama rata',
    'menyamaratakannya': 'sama rata',
    'menyaman': 'saman',
    'menyamanan': 'saman',
    'kesamaptaan': 'samapta',
    'menyambal': 'sambal',
    'menyambalewa': 'sambalewa',
    'menyambalewakan': 'sambalewa',
    'bersambang': 'sambang',
    'menyambang': 'sambang',
    'menyambangi': 'sambang',
    'menyambanginya': 'sambang',
    'menyambangiku': 'sambang',
    'menyambangimu': 'sambang',
    'sambang darah': 'sambang',
    'sambatan': 'sambat',
    'sambatannya': 'sambat',
    'sesambat': 'sambat',
    'menyambat': 'sambat',
    'bersambat': 'sambat',
    'persambatan': 'sambat',
    'penyambatan': 'sambat',
    'menyambi': 'sambi',
    'menyambinya': 'sambi',
    'sambilan': 'sambil',
    'sambilannya': 'sambil',
    'tersambil': 'sambil',
    'menyambilkan': 'sambil',
    'menyambillalukan': 'sambil lalu',
    'sambitan': 'sambit',
    'menyambit': 'sambit',
    'menyambitnya': 'sambit',
    'penyambit': 'sambit',
    'penyambitan': 'sambit',
    'tersambit': 'sambit',
    'menyambiti': 'sambit',
    'menyambitkan': 'sambit',
    'sambungan': 'sambung',
    'sambungannya': 'sambung',
    'bersambung': 'sambung',
    'bersambungan': 'sambung',
    'menyambung': 'sambung',
    'menyambungnya': 'sambung',
    'menyambungkan': 'sambung',
    'menyambungkannya': 'sambung',
    'menyambungan': 'sambung',
    'penyambung': 'sambung',
    'penyambungnya': 'sambung',
    'penyambungan': 'sambung',
    'penyambungannya': 'sambung',
    'persambungan': 'sambung',
    'mempersambungkan': 'sambung',
    'sambung-bersambung': 'sambung',
    'sambung-menyambung': 'sambung',
    'bersambung tangan': 'sambung tangan',
    'menyamir': 'samir',
    'menyamirkan': 'samir',
    'sampaian': 'sampai',
    'sesampai': 'sampai',
    'sesampainya': 'sampai',
    'sesampaikan': 'sampai',
    'penyampai': 'sampai',
    'penyampaikan': 'sampai',
    'penyampaian': 'sampai',
    'tersampai': 'sampai',
    'tersampainya': 'sampai',
    'tersampaikan': 'sampai',
    'tersampaikannya': 'sampai',
    'menyampai': 'sampai',
    'menyampainya': 'sampai',
    'menyampaikan': 'sampai',
    'menyampaikannya': 'sampai',
    'menyampaian': 'sampai',
    'kesampaian': 'sampai',
    'kesampaiannya': 'sampai',
    'penyampaiannya': 'sampai',
    'menyampaikanlah': 'sampai',
    'menyampaikankan': 'sampai',
    'sampai-sampai': 'sampai',
    'berkesampaian': 'sampai',
    'menyampak': 'sampak',
    'menyampakkan': 'sampak',
    'menyampakan': 'sampak',
    'bersampan': 'sampan',
    'bersampan-sampan': 'sampan',
    'kesamper': 'samper',
    'menyamper': 'samper',
    'menyamperi': 'samper',
    'sampingan': 'samping',
    'sampingannya': 'samping',
    'sampinganmu': 'samping',
    'tersamping': 'samping',
    'tersampingkan': 'samping',
    'menyamping': 'samping',
    'menyampingnya': 'samping',
    'menyampingkan': 'samping',
    'menyampingi': 'samping',
    'bersamping': 'samping',
    'bersampingan': 'samping',
    'penyampingan': 'samping',
    'mengesampingkan': 'samping',
    'mengesampingkannya': 'samping',
    'samping-menyamping': 'samping',
    'sampiran': 'sampir',
    'tersampir': 'sampir',
    'bersampiran': 'sampir',
    'menyampirkan': 'sampir',
    'menyampirkannya': 'sampir',
    'bersamplok': 'samplok',
    'menyampo': 'sampo',
    'menyampoi': 'sampo',
    'penyampoan': 'sampo',
    'penyampul': 'sampul',
    'penyampulan': 'sampul',
    'menyampul': 'sampul',
    'menyampulnya': 'sampul',
    'bersampul': 'sampul',
    'bersampulkan': 'sampul',
    'menyampuli': 'sampul',
    'persamuhan': 'samuh',
    'bersanak': 'sanak',
    'menyanak': 'sanak',
    'bersanat': 'sanat',
    'menyandakan': 'sandak',
    'bersandal': 'sandal',
    'menyandera': 'sandera',
    'menyanderanya': 'sandera',
    'menyanderakan': 'sandera',
    'menyanderaku': 'sandera',
    'penyandera': 'sandera',
    'penyanderanya': 'sandera',
    'penyanderaan': 'sandera',
    'penyanderaannya': 'sandera',
    'sandingan': 'sanding',
    'bersanding': 'sanding',
    'bersandingnya': 'sanding',
    'bersandingkan': 'sanding',
    'bersandingan': 'sanding',
    'menyanding': 'sanding',
    'menyandingkan': 'sanding',
    'menyandingkannya': 'sanding',
    'menyandingan': 'sanding',
    'menyandingi': 'sanding',
    'menyandinginya': 'sanding',
    'mempersandingkan': 'sanding',
    'sandungan': 'sandung',
    'sandungannya': 'sandung',
    'kesandung': 'sandung',
    'menyandung': 'sandung',
    'menyandungnya': 'sandung',
    'menyandungkan': 'sandung',
    'tersandung': 'sandung',
    'tersandungnya': 'sandung',
    'tersandunglah': 'sandung',
    'tersanga-sanga': 'sanga',
    'bersangai': 'sangai',
    'tersangai': 'sangai',
    'menyangai': 'sangai',
    'kesangaran': 'sangar',
    'kesangarannya': 'sangar',
    'tersangat': 'sanggat',
    'kesangatan': 'sangat',
    'bersangatan': 'sangat',
    'menyangatkan': 'sangat',
    'mempersangat': 'sangat',
    'sangat-sangat': 'sangat',
    'sangat-sangatlah': 'sangat',
    'mempersangatkan': 'sangat',
    'sanggahan': 'sanggah',
    'sanggahannya': 'sanggah',
    'penyanggah': 'sanggah',
    'penyanggahnya': 'sanggah',
    'penyanggahan': 'sanggah',
    'menyanggah': 'sanggah',
    'menyanggahnya': 'sanggah',
    'menyanggam': 'sanggam',
    'bersanggama': 'sanggama',
    'menyanggang': 'sanggang',
    'menyanggep': 'sanggep',
    'menyanggerah': 'sanggerah',
    'bersanggit': 'sanggit',
    'menyanggit': 'sanggit',
    'menyanggrah': 'sanggrah',
    'pesanggrahan': 'sanggrah',
    'menyanggul': 'sanggul',
    'menyanggulnya': 'sanggul',
    'bersanggul': 'sanggul',
    'menyanggulkan': 'sanggul',
    'sesanggup': 'sanggup',
    'sesanggupnya': 'sanggup',
    'sesanggupan': 'sanggup',
    'menyanggupi': 'sanggup',
    'menyanggupinya': 'sanggup',
    'kesanggupan': 'sanggup',
    'kesanggupannya': 'sanggup',
    'menyanggupkan': 'sanggup',
    'sesangkak': 'sangkak',
    'bersangkak': 'sangkak',
    'menyangkak': 'sangkak',
    'menyangkaki': 'sangkak',
    'menyangkap': 'sangkap',
    'sangkaran': 'sangkar',
    'bersangkar': 'sangkar',
    'menyangkarkan': 'sangkar',
    'bersangkut paut': 'sangkut paut',
    'menyangkutpautkan': 'sangkut paut',
    'menyangling': 'sangling',
    'menyanglingkan': 'sangling',
    'menyangrai': 'sangrai',
    'menyangrainya': 'sangrai',
    'kesangsang': 'sangsang',
    'menyangsang': 'sangsang',
    'tersangsang': 'sangsang',
    'bersanksi': 'sanksi',
    'pesantai': 'santai',
    'bersantai': 'santai',
    'bersantainya': 'santai',
    'bersantailah': 'santai',
    'kesantaian': 'santai',
    'bersantai-santai': 'santai',
    'menyantak': 'santak',
    'menyantakan': 'santak',
    'menyantakkan': 'santak',
    'bersantan': 'santan',
    'bersantanlah': 'santan',
    'pesantap': 'santap',
    'santapan': 'santap',
    'santapannya': 'santap',
    'bersantap': 'santap',
    'bersantapnya': 'santap',
    'bersantaplah': 'santap',
    'menyantap': 'santap',
    'menyantapnya': 'santap',
    'penyantapan': 'santap',
    'persantapan': 'santap',
    'menyantet': 'santet',
    'menyantetnya': 'santet',
    'santiran': 'santir',
    'pesantrian': 'santri',
    'santunan': 'santun',
    'santunannya': 'santun',
    'penyantun': 'santun',
    'penyantunan': 'santun',
    'menyantun': 'santun',
    'menyantunkan': 'santun',
    'menyantuni': 'santun',
    'menyantuninya': 'santun',
    'menyantung': 'santung',
    'sapai-sapai': 'sapai',
    'sapihan': 'sapih',
    'menyapih': 'sapih',
    'menyapihnya': 'sapih',
    'sapuan': 'sapu',
    'sapuannya': 'sapu',
    'disapu': 'sapu',
    'disapunya': 'sapu',
    'disapukan': 'sapu',
    'tersapu': 'sapu',
    'tersapunya': 'sapu',
    'menyapu': 'sapu',
    'menyapunya': 'sapu',
    'menyapulah': 'sapu',
    'menyapukan': 'sapu',
    'menyapukannya': 'sapu',
    'penyapu': 'sapu',
    'penyapunya': 'sapu',
    'penyapuan': 'sapu',
    'sapu-sapu': 'sapu',
    'menyapu-nyapu': 'sapu',
    'menyaput': 'saput',
    'tersaput': 'saput',
    'menyaputi': 'saput',
    'bersarak': 'sarak',
    'menyarak': 'sarak',
    'sarapan': 'sarap',
    'sarapannya': 'sarap',
    'sarapanlah': 'sarap',
    'sarapanku': 'sarap',
    'menyarap': 'sarap',
    'menyarapi': 'sarap',
    'bersarasehan': 'sarasehan',
    'menyarasehankan': 'sarasehan',
    'menyarat': 'sarat',
    'menyaratkan': 'sarat',
    'menyarati': 'sarat',
    'menyarat-nyarat': 'sarat',
    'menyaraukan': 'sarau',
    'menyaripatikan': 'sari pati',
    'tersaripatikan': 'sari pati',
    'kesarjanaan': 'sarjana',
    'kesarjanaannya': 'sarjana',
    'menyaru': 'saru',
    'menyarukan': 'saruk',
    'menyarukannya': 'saru',
    'penyaruan': 'saru',
    'penyaruannya': 'saru',
    'menyaruk': 'saruk',
    'tersaruk': 'saruk',
    'tersaruk-saruk': 'saruk',
    'menyarut': 'sarut',
    'sasakan': 'sasak',
    'sasakannya': 'sasak',
    'menyasak': 'sasak',
    'bersasak': 'sasak',
    'menyasap': 'sasap',
    'menyasau': 'sasau',
    'kesastraan': 'sastra',
    'kesastrawanan': 'sastrawan',
    'menyatai': 'satai',
    'menyataian': 'satai',
    'persataian': 'satai',
    'mempersatai': 'satai',
    'menyatih': 'satih',
    'menyatroni': 'satron',
    'menyatumejakan': 'satu meja',
    'bersatu padu': 'satu padu',
    'penyatupaduan': 'satu padu',
    'menyatupadukan': 'satu padu',
    'mempersatupadukan': 'satu padu',
    'bersauh': 'sauh',
    'bersauhnya': 'sauh',
    'saukan': 'sauk',
    'saukani': 'sauk',
    'menyauk': 'sauk',
    'penyaukan': 'sauk',
    'sauk-sauk': 'sauk',
    'sauk-menyauk': 'sauk',
    'tersaur': 'saur',
    'bersaur': 'saur',
    'menyaur': 'saur',
    'menyauri': 'saur',
    'pesawah': 'sawah',
    'pesawahan': 'sawah',
    'bersawah': 'sawah',
    'penyawah': 'sawah',
    'menyawah': 'sawah',
    'persawahan': 'sawah',
    'persawahannya': 'sawah',
    'persawahanan': 'sawah',
    'bersawala': 'sawala',
    'sawangan': 'sawang',
    'pesawangan': 'sawang',
    'menyawar': 'sawar',
    'menyawarkan': 'sawar',
    'menyawer': 'sawer',
    'sesawi': 'sawi',
    'sawitan': 'sawit',
    'bersayap': 'sayap',
    'bersayapnya': 'sayap',
    'menyayembarakan': 'sayembara',
    'menyayung': 'sayung',
    'sayup-sayup': 'sayup',
    'sesayup-sayup': 'sayup',
    'sayup-menyayup': 'sayup',
    'sayuran': 'sayur',
    'sayurannya': 'sayur',
    'menyayur': 'sayur',
    'menyayurnya': 'sayur',
    'sayur-mayur': 'sayur',
    'sayur-mayurnya': 'sayur',
    'sayur-mayuran': 'sayur',
    'sayur-sayuran': 'sayur',
    'sayur-sayurannya': 'sayur',
    'sayur-sayuranan': 'sayur',
    'berseba': 'seba',
    'menyeba': 'seba',
    'menyebakan': 'seba',
    'tersebab': 'sebab',
    'bersebab': 'sebab',
    'penyebab': 'sebab',
    'penyebabnya': 'sebab',
    'penyebabkan': 'sebab',
    'penyebaban': 'sebab',
    'menyebabkan': 'sebab',
    'menyebabkannya': 'sebab',
    'menyebabkankan': 'sebab',
    'menyebabkankannya': 'sebab',
    'menyebabkanku': 'sebab',
    'menyebabkanmu': 'sebab',
    'menyebal': 'sebal',
    'menyebalkan': 'sebal',
    'menyebalkannya': 'sebal',
    'kesebalan': 'sebal',
    'kesebalannya': 'sebal',
    'menyebalkanmu': 'sebal',
    'menyebaurkan': 'sebaur',
    'penyeberang': 'seberang',
    'penyeberangnya': 'seberang',
    'penyeberangi': 'seberang',
    'penyeberangan': 'seberang',
    'terseberang': 'seberang',
    'terseberangkan': 'seberang',
    'menyeberang': 'seberang',
    'menyeberangnya': 'seberang',
    'menyeberanglah': 'seberang',
    'menyeberangkan': 'seberang',
    'menyeberangkannya': 'seberang',
    'menyeberangi': 'seberang',
    'menyeberangan': 'seberang',
    'menyeberanginya': 'seberang',
    'keseberangan': 'seberang',
    'penyeberangannya': 'seberang',
    'berseberangan': 'seberang',
    'berseberangannya': 'seberang',
    'seberang-menyeberang': 'seberang',
    'menyebit': 'sebit',
    'menyebitkan': 'sebit',
    'menyebrot': 'sebrot',
    'menyebu': 'sebu',
    'menyebunya': 'sebu',
    'menyebukan': 'sebuk',
    'menyebuk': 'sebuk',
    'penyebukan': 'sebuk',
    'tersedak': 'sedak',
    'tersedaknya': 'sedak',
    'kesedakan': 'sedak',
    'sedam-sedam': 'sedam',
    'bersedan-sedan': 'sedan',
    'tersedan-sedan': 'sedan',
    'menyedang': 'sedang',
    'sedangkan': 'sedang',
    'sedangkankan': 'sedang',
    'sedangkani': 'sedang',
    'sedangkanan': 'sedang',
    'menyedangkan': 'sedang',
    'sedang-menyedang': 'sedang',
    'menyedang-nyedang': 'sedang',
    'menyedang-nyedangkan': 'sedang',
    'bersedekah': 'sedekah',
    'bersedekahlah': 'sedekah',
    'menyedekahi': 'sedekah',
    'menyedekahkan': 'sedekah',
    'bersedekap': 'sedekap',
    'kesederhanaan': 'sederhana',
    'kesederhanaannya': 'sederhana',
    'penyederhanaan': 'sederhana',
    'penyederhanaannya': 'sederhana',
    'menyederhanakan': 'sederhana',
    'menyederhanakannya': 'sederhana',
    'sedikitnya': 'sedikit',
    'menyedikit': 'sedikit',
    'tersedikit': 'sedikit',
    'menyedikiti': 'sedikit',
    'menyedikitkan': 'sedikit',
    'sedikit-sedikit': 'sedikit',
    'sedikit-sedikitlah': 'sedikit',
    'mempersedikitkan': 'sedikit',
    'sedikit-sedikitnya': 'sedikit',
    'sedotan': 'sedot',
    'sedotannya': 'sedot',
    'sedotanlah': 'sedot',
    'tersedot': 'sedot',
    'tersedotnya': 'sedot',
    'menyedot': 'sedot',
    'menyedotnya': 'sedot',
    'menyedotan': 'sedot',
    'penyedot': 'sedot',
    'penyedotnya': 'sedot',
    'penyedotan': 'sedot',
    'penyedotannya': 'sedot',
    'bersedu': 'sedu',
    'tersedu-sedu': 'sedu',
    'bersedu-sedu': 'sedu',
    'menyegak': 'segak',
    'segalanya': 'segala',
    'segala-galanya': 'segala',
    'bersegeh': 'segeh',
    'menyegehi': 'segeh',
    'segelan': 'segel',
    'segelannya': 'segel',
    'bersegel': 'segel',
    'menyegel': 'segel',
    'menyegelnya': 'segel',
    'menyegelan': 'segel',
    'penyegel': 'segel',
    'penyegelan': 'segel',
    'penyegelannya': 'segel',
    'sesegera': 'segera',
    'sesegeranya': 'segera',
    'bersegera': 'segera',
    'bersegeralah': 'segera',
    'persegeraan': 'segera',
    'penyegeraan': 'segera',
    'menyegerakan': 'segera',
    'menyegerakannya': 'segera',
    'mempersegera': 'segera',
    'mepersegerakan': 'segera',
    'bersegmen': 'segmen',
    'bersegmenkan': 'segmen',
    'menyegmentasikan': 'segmentasi',
    'kesejahteraan': 'sejahtera',
    'kesejahteraannya': 'sejahtera',
    'kesejahteraanlah': 'sejahtera',
    'kesejahteraanku': 'sejahtera',
    'penyejahteraan': 'sejahtera',
    'menyejahterakan': 'sejahtera',
    'menyejahterakannya': 'sejahtera',
    'bersejingkat': 'sejingkat',
    'bersejuk': 'sejuk',
    'menyejuk': 'sejuk',
    'menyejukkan': 'sejuk',
    'menyejukkannya': 'sejuk',
    'menyejukan': 'sejuk',
    'penyejuk': 'sejuk',
    'penyejukan': 'sejuk',
    'kesejukan': 'sejuk',
    'kesejukannya': 'sejuk',
    'bersejuk-sejuk': 'sejuk',
    'tersekang': 'sekang',
    'penyekang': 'sekang',
    'menyekang': 'sekang',
    'sekapan': 'sekap',
    'sekapannya': 'sekap',
    'penyekap': 'sekap',
    'penyekapnya': 'sekap',
    'penyekapkan': 'sekap',
    'penyekapan': 'sekap',
    'tersekap': 'sekap',
    'menyekap': 'sekap',
    'menyekapnya': 'sekap',
    'menyekapan': 'sekap',
    'penyekapannya': 'sekap',
    'menyekar': 'sekar',
    'sekatan': 'sekat',
    'persekat': 'sekat',
    'persekatan': 'sekat',
    'bersekat': 'sekat',
    'penyekat': 'sekat',
    'penyekatnya': 'sekat',
    'penyekatan': 'sekat',
    'menyekat': 'sekat',
    'menyekati': 'sekat',
    'menyekatan': 'sekat',
    'tersekat': 'sekat',
    'bersekat-sekat': 'sekat',
    'bersekresi': 'sekresi',
    'menyekresi': 'sekresi',
    'menyekresikan': 'sekresi',
    'disekrup': 'sekrup',
    'menyekrup': 'sekrup',
    'bersekutu': 'sekutu',
    'menyekutui': 'sekutu',
    'persekutuan': 'sekutu',
    'persekutuannya': 'sekutu',
    'menyekutukan': 'sekutu',
    'disel': 'sel',
    'diselnya': 'sel',
    'bersel': 'sel',
    'berselan': 'sel',
    'bersela': 'sela',
    'berselai': 'sela',
    'penyela': 'sela',
    'penyelaan': 'sela',
    'menyela': 'sela',
    'menyelanya': 'sela',
    'menyelakan': 'selak',
    'menyelakannya': 'sela',
    'penyelaannya': 'sela',
    'sela-sela': 'sela',
    'sela-selanya': 'sela',
    'sela-menyela': 'sela',
    'menyeladang': 'seladang',
    'berselaju': 'selaju',
    'keselak': 'selak',
    'menyelak': 'selak',
    'terselak': 'selak',
    'menyelakkan': 'selak',
    'menyelampai': 'selampai',
    'menyelampaikan': 'selampai',
    'menyelampitkan': 'selampit',
    'berselang': 'selang',
    'berselangan': 'selang',
    'menyelang': 'selang',
    'menyelangi': 'selang',
    'menyelangkan': 'selang',
    'memperselangi': 'selang',
    'memperselangkan': 'selang',
    'selang tenggang': 'selang',
    'berselang-selang': 'selang',
    'berselang-tenggang': 'selang',
    'menyelang-nyelangkan': 'selang',
    'berselang-seli': 'selang-seli',
    'berselang-seling': 'selang-seling',
    'menyelang-nyeling': 'selang-seling',
    'menyelang-nyelingkan': 'selang-seling',
    'selangkangan': 'selangkang',
    'selangkangannya': 'selangkang',
    'menyelangkupi': 'selangkup',
    'terselap': 'selap',
    'menyelap': 'selap',
    'keselapan': 'selap',
    'menyelapi': 'selap',
    'selapanan': 'selapan',
    'menyelara': 'selara',
    'menyelarakan': 'selara',
    'terselat': 'selat',
    'terselatkan': 'selat',
    'terselatan': 'selat',
    'menyelat': 'selat',
    'menyelatkan': 'selat',
    'selawatan': 'selawat',
    'berselawat': 'selawat',
    'menyelawat': 'selawat',
    'menyelawatkan': 'selawat',
    'berselekeh': 'selekeh',
    'menyelekehi': 'selekeh',
    'berselekoh': 'selekoh',
    'menyelekoh': 'selekoh',
    'penyeleksi': 'seleksi',
    'penyeleksinya': 'seleksi',
    'penyeleksian': 'seleksi',
    'menyeleksi': 'seleksi',
    'menyeleksinya': 'seleksi',
    'menyeleksii': 'seleksi',
    'penyeleksiannya': 'seleksi',
    'keselektifan': 'selektif',
    'berseleleran': 'seleler',
    'menyelembana': 'selembana',
    'terselempang': 'selempang',
    'berselempang': 'selempang',
    'berselempangkan': 'selempang',
    'menyelempangkan': 'selempang',
    'menyelendang': 'selendang',
    'berselendang': 'selendang',
    'menyelendangi': 'selendang',
    'memperselendang': 'selendang',
    'menyelendangkan': 'selendang',
    'memperselendangkan': 'selendang',
    'menyelentik': 'selentik',
    'selentingan': 'selenting',
    'selentingannya': 'selenting',
    'menyelenting': 'selenting',
    'menyelentingkan': 'selenting',
    'berselepat': 'selepat',
    'berselesa': 'selesa',
    'menyeletuk': 'seletuk',
    'penyelia': 'selia',
    'penyelianya': 'selia',
    'penyeliaan': 'selia',
    'menyelia': 'selia',
    'berselibut': 'selibut',
    'menyeligi': 'seligi',
    'menyeligit': 'seligit',
    'menyelimpang': 'selimpang',
    '4selimpat': 'selimpat',
    'menyelimpat': 'selimpat',
    'selingan': 'seling',
    'selingannya': 'seling',
    'penyeling': 'seling',
    'berseling': 'seling',
    'berselingan': 'seling',
    'berselingku': 'seling',
    'menyeling': 'seling',
    'menyelingkan': 'seling',
    'menyelingi': 'seling',
    'menyelinginya': 'seling',
    'menyelingar': 'selingar',
    'menyelingkit': 'selingkit',
    'berselingkit': 'selingkit',
    'berselingkuh': 'selingkuh',
    'berselingkuhnya': 'selingkuh',
    'perselingkuhan': 'selingkuh',
    'perselingkuhannya': 'selingkuh',
    'menyelingkuhkan': 'selingkuh',
    'menyelingkup': 'selingkup',
    'menyelingkupi': 'selingkup',
    'menyelir': 'selir',
    'memperselir': 'selir',
    'selir-menyelir': 'selir',
    'memperselirkan': 'selir',
    'berselirak': 'selirak',
    'menyelisipkan': 'selisip',
    'menyelisir': 'selisir',
    'seliweran': 'seliwer',
    'berseliweran': 'seliwer',
    'berseloka': 'seloka',
    'menyelomoti': 'selomot',
    'menyelongkan': 'selong',
    'menyelongkar': 'selongkar',
    'menyelongsongi': 'selongsong',
    'selonjoran': 'selonjor',
    'berselonjor': 'selonjor',
    'berselonjoran': 'selonjor',
    'menyelonong': 'selonong',
    'menyelot': 'selot',
    'seloyongan': 'seloyong',
    'berseloyong': 'seloyong',
    'seloyong-seloyong': 'seloyong',
    'berseluar': 'seluar',
    'menyeluduk': 'seluduk',
    'berseluk-beluk': 'seluk-beluk',
    'menyelukat': 'selukat',
    'berselulup': 'selulup',
    'terselulur': 'selulur',
    'peseluncur': 'seluncur',
    'selundupan': 'selundup',
    'selundupannya': 'selundup',
    'penyelundup': 'selundup',
    'penyelundupnya': 'selundup',
    'penyelundupkan': 'selundup',
    'penyelundupan': 'selundup',
    'menyelundup': 'selundup',
    'menyelundupnya': 'selundup',
    'menyelundupkan': 'selundup',
    'menyelundupkannya': 'selundup',
    'menyelundupan': 'selundup',
    'menyelundupi': 'selundup',
    'penyelundupannya': 'selundup',
    'menyelungkup': 'selungkup',
    'menyelungkupi': 'selungkup',
    'menyeluruh': 'seluruh',
    'menyeluruhnya': 'seluruh',
    'menyeluruhi': 'seluruh',
    'keseluruhan': 'seluruh',
    'keseluruhannya': 'seluruh',
    'keseluruhanlah': 'seluruh',
    'keseluruhanan': 'seluruh',
    'menyelusuh': 'selusuh',
    'menyelusup': 'selusup',
    'menyelusupkan': 'selusup',
    'terselusur': 'selusur',
    'menyelusur': 'selusur',
    'menyelusuri': 'selusur',
    'penyelusuran': 'selusur',
    'menyelusurkan': 'selusur',
    'sema-sema': 'sema',
    'bersemak': 'semak',
    'menyemak': 'semak',
    'menyemakan': 'semak',
    'semak-semak': 'semak',
    'semak-semaknya': 'semak',
    'menyemakkan': 'semak',
    'kesemanan': 'seman',
    'bersemangat': 'semangat',
    'bersemangatnya': 'semangat',
    'bersemangatlah': 'semangat',
    'bersemangatkan': 'semangat',
    'menyemangati': 'semangat',
    'menyemangatinya': 'semangat',
    'menyemangatiku': 'semangat',
    'penyemangatan': 'semangat',
    'menyemangatkan': 'semangat',
    'menyemangatkannya': 'semangat',
    'kesemaran': 'semara',
    'bersemayam': 'semayam',
    'bersemayamnya': 'semayam',
    'persemayaman': 'semayam',
    'persemayamannya': 'semayam',
    'menyemayamkan': 'semayam',
    'menyemayamkannya': 'semayam',
    'menyembai': 'sembai',
    'tersembam': 'sembam',
    'menyembam': 'sembam',
    'menyembamkan': 'sembam',
    'sembarangan': 'sembarang',
    'sembarangannya': 'sembarang',
    'sembaranganlah': 'sembarang',
    'menyembarangi': 'sembarang',
    'menyembat': 'sembat',
    'menyembatkan': 'sembat',
    'bersembayan': 'sembayan',
    'kesembilan': 'sembilan',
    'kesembilannya': 'sembilan',
    'bersembilan': 'sembilan',
    'sembiluan': 'sembilu',
    'menyembilu': 'sembilu',
    'sembiran': 'sembir',
    'menyembir': 'sembir',
    'bersemboyan': 'semboyan',
    'menyemboyankan': 'semboyan',
    'kesembronoan': 'sembrono',
    'kesembronoannya': 'sembrono',
    'menyembronokan': 'sembrono',
    'menyembul': 'sembul',
    'menyembulnya': 'sembul',
    'menyembullah': 'sembul',
    'menyembulkan': 'sembul',
    'tersembul': 'sembul',
    'tersembulnya': 'sembul',
    'bersemburit': 'semburit',
    'bersememeh': 'sememeh',
    'semenan': 'semen',
    'menyemen': 'semen',
    'menyemennya': 'semen',
    'bersemen': 'semen',
    'penyemenan': 'semen',
    'semena-mena': 'semena',
    'semena-menanya': 'semena',
    'kesemena-menaan': 'semena',
    'bersemenda': 'semenda',
    'semenda-menyemenda': 'semenda',
    'semenggah-menggah': 'semenggah',
    'kesementaraan': 'sementara',
    'kesemestaan': 'semesta',
    'semesteran': 'semester',
    'semesterannya': 'semester',
    'bersemi': 'semi',
    'berseminya': 'semi',
    'bersemilah': 'semi',
    'menyemir': 'semir',
    'menyemirnya': 'semir',
    'menyemirkan': 'semir',
    'bersemir': 'semir',
    'bersempadan': 'sempadan',
    'menyempadani': 'sempadan',
    'sempalan': 'sempal',
    'sempalannya': 'sempal',
    'menyempal': 'sempal',
    'tersempal': 'sempal',
    'penyempal': 'sempal',
    'penyempalan': 'sempal',
    'menyempali': 'sempal',
    'tersempalai': 'sempalai',
    'menyempang': 'sempang',
    'bersempang': 'sempang',
    'bersempena': 'sempena',
    'menyempenakan': 'sempena',
    'tersempil': 'sempil',
    'menyempil': 'sempil',
    'menyempilkan': 'sempil',
    'sempoyongan': 'sempoyong',
    'sempritan': 'semprit',
    'menyemprit': 'semprit',
    'penyemprit': 'semprit',
    'penyempritan': 'semprit',
    'bersemprong': 'semprong',
    'tersempul': 'sempul',
    'bersempuras': 'sempuras',
    'kesemrawutan': 'semrawut',
    'kesemrawutannya': 'semrawut',
    'tersemu': 'semu',
    'menyemu': 'semu',
    'penyemu': 'semu',
    'menyemui': 'semu',
    'semu-semu': 'semu',
    'penyemuan': 'semu',
    'menyemukan': 'semu',
    'semuanya': 'semua',
    'semuanyanya': 'semua',
    'semuanyalah': 'semua',
    'semuanyai': 'semua',
    'semua-muanya': 'semua',
    'menyemur': 'semur',
    'menyemurkan': 'semur',
    'menyemut': 'semut',
    'menyemutnya': 'semut',
    'menyemuti': 'semut',
    'kesemutan': 'semut',
    'kesemutannya': 'semut',
    'semut-semutan': 'semut',
    'senan': 'sen',
    'sen-senan': 'sen',
    'tersenak': 'senak',
    'menyenak': 'senak',
    'menyenakan': 'senak',
    'kesenakan': 'senak',
    'menyenakkan': 'senak',
    'kesenak-senakan': 'senak',
    'menyenak-nyenak': 'senak',
    'pesenam': 'senam',
    'bersenam': 'senam',
    'bersenapan': 'senapan',
    'tersendam': 'sendam',
    'bersendar': 'sendar',
    'tersendat': 'sendat',
    'tersendatnya': 'sendat',
    'tersendatan': 'sendat',
    'menyendat': 'sendat',
    'menyendatkan': 'sendat',
    'penyendatan': 'sendat',
    'tersendat-sendat': 'sendat',
    'tersendat-sendatnya': 'sendat',
    'bersendel': 'sendel',
    'dengan -': 'sendiri',
    'sendirian': 'sendiri',
    'sendiriannya': 'sendiri',
    'sendirianlah': 'sendiri',
    'menyendiri': 'sendiri',
    'menyendirinya': 'sendiri',
    'sendirinya': 'sendiri',
    'bersendiri': 'sendiri',
    'penyendiri': 'sendiri',
    'tersendiri': 'sendiri',
    'tersendirinya': 'sendiri',
    'tersendirikan': 'sendiri',
    'kesendirian': 'sendiri',
    'kesendiriannya': 'sendiri',
    'kesendirianmu': 'sendiri',
    'penyendirian': 'sendiri',
    'menyendirikan': 'sendiri',
    'sendiri-sendiri': 'sendiri',
    'tersendok': 'sendok',
    'menyendok': 'sendok',
    'menyendoknya': 'sendok',
    'menyendokkan': 'sendok',
    'menyendoki': 'sendok',
    'tersendorong': 'sendorong',
    'bersendorongan': 'sendorong',
    'bersendu': 'sendu',
    'kesenduan': 'sendu',
    'menyengaja': 'sengaja',
    'menyengajakan': 'sengaja',
    'bersengaja': 'sengaja',
    'kesengajaan': 'sengaja',
    'kesengajaannya': 'sengaja',
    'menyengal': 'sengal',
    'sengal-sengal': 'sengal',
    'tersengal-sengal': 'sengal',
    'menyengam': 'sengam',
    'menyengar': 'sengar',
    'menyengarkan': 'sengar',
    'sengatan': 'sengat',
    'sengatannya': 'sengat',
    'penyengat': 'sengat',
    'menyengat': 'sengat',
    'menyengatnya': 'sengat',
    'menyengatkan': 'sengat',
    'menyengatku': 'sengat',
    'tersengat': 'sengat',
    'tersengatnya': 'sengat',
    'bersengat': 'sengat',
    'penyengatan': 'sengat',
    'senggakan': 'senggak',
    'menyenggak': 'senggak',
    'menyenggaki': 'senggak',
    'bersenggang': 'senggang',
    'kesenggangan': 'senggang',
    'menyenggangkan': 'senggang',
    'senggang-tenggang': 'senggang',
    'bersenggang-senggang': 'senggang',
    'menyenggau': 'senggau',
    'bersenggau-senggau': 'senggau',
    'menyengget': 'sengget',
    'kesenggol': 'senggol',
    'senggolan': 'senggol',
    'senggolannya': 'senggol',
    'tersenggol': 'senggol',
    'bersenggol': 'senggol',
    'bersenggolan': 'senggol',
    'menyenggol': 'senggol',
    'menyenggolnya': 'senggol',
    'menyenggolmu': 'senggol',
    'bersenggolannya': 'senggol',
    'penyenggolan': 'senggol',
    'senggol-menyenggol': 'senggol',
    'menyengguk': 'sengguk',
    'tersengguk': 'sengguk',
    'sesenggukan': 'sengguk',
    'senggak-sengguk': 'sengguk',
    'tersengguk-sengguk': 'sengguk',
    'bersenggulung': 'senggulung',
    'menyenggut': 'senggut',
    'sengihan': 'sengih',
    'tersengih': 'sengih',
    'menyengih': 'sengih',
    'menyenggihkan': 'sengih',
    'menyengir': 'sengir',
    'menyengit': 'sengit',
    'menyengitkan': 'sengit',
    'kesengitan': 'sengit',
    'kesengitannya': 'sengit',
    'menyengkak': 'sengkak',
    'menyengkang': 'sengkang',
    'penyengkang': 'sengkang',
    'tersengkang': 'sengkang',
    'bersengkarut': 'sengkarut',
    'sengkedan': 'sengked',
    'bersengkela': 'sengkela',
    'menyengkela': 'sengkela',
    'menyengkelangkan': 'sengkelang',
    'menyengkeling': 'sengkeling',
    'bersengkeling': 'sengkeling',
    'menyengkelit': 'sengkelit',
    'bersengkelit': 'sengkelit',
    'sengkeran': 'sengker',
    'menyengker': 'sengker',
    'menyengkilit': 'sengkilit',
    'tersengsam': 'sengsam',
    'kesengsaman': 'sengsam',
    'kesengsem': 'sengsem',
    'kesengsemnya': 'sengsem',
    'tersengsem': 'sengsem',
    'menyenguk': 'senguk',
    'tersengut-sengut': 'sengut',
    'berseni': 'seni',
    'menyeni': 'seni',
    'kesenian': 'seni',
    'keseniannya': 'seni',
    'kesenianmu': 'seni',
    'kesenimanan': 'seniman',
    'kesenimanannya': 'seniman',
    'kesenimananku': 'seniman',
    'kesenioran': 'senior',
    'keseniorannya': 'senior',
    'kesenjaan': 'senja',
    'kesenjangan': 'senjang',
    'kesenjangannya': 'senjang',
    'persenjangan': 'senjang',
    'ketidaksenonohan': 'senonoh',
    'bersenoyong': 'senoyong',
    'sensoran': 'sensor',
    'penyensor': 'sensor',
    'penyensoran': 'sensor',
    'menyensus': 'sensus',
    'menyental': 'sental',
    'menyentalkan': 'sental',
    'menyentengi': 'senteng',
    'kesentengan': 'senteng',
    'menyentengkan': 'senteng',
    'menyenteri': 'senter',
    'menyenterinya': 'senter',
    'sentilan': 'sentil',
    'sentilannya': 'sentil',
    'menyentil': 'sentil',
    'menyentilnya': 'sentil',
    'menyentilkan': 'sentil',
    'tersentil': 'sentil',
    'bersentosa': 'sentosa',
    'kesentosaan': 'sentosa',
    'menyentosakan': 'sentosa',
    'kesentralan': 'sentral',
    'penyentralan': 'sentral',
    'menyentralkan': 'sentral',
    'menyentralisasi': 'sentralisasi',
    'menyentralisasikan': 'sentralisasi',
    'tersentralisasi': 'sentralisasi',
    'tersentralisasinya': 'sentralisasi',
    'tersentralisasikan': 'sentralisasi',
    'tersentuk': 'sentuk',
    'senyuman': 'senyum',
    'senyumannya': 'senyum',
    'senyumanan': 'senyum',
    'senyumanku': 'senyum',
    'senyumanmu': 'senyum',
    'tersenyum': 'senyum',
    'tersenyumnya': 'senyum',
    'tersenyumlah': 'senyum',
    'menyenyumi': 'senyum',
    'terseok-seok': 'seok',
    'terseok-seoknya': 'seok',
    'bersep': 'sep',
    'menyepah': 'sepah',
    'tersepah': 'sepah',
    'bersepah': 'sepah',
    'bersepah-sepah': 'sepah',
    'pesepak bola': 'sepak bola',
    'bersepak bola': 'sepak bola',
    'persepakbolaan': 'sepak bola',
    'persepakbolaannya': 'sepak bola',
    'menyepan': 'sepan',
    'bersepan': 'sepan',
    'sepelan': 'sepel',
    'menyepel': 'sepel',
    'menyepelkannya': 'sepel',
    'menyepelekan': 'sepele',
    'menyepelekannya': 'sepele',
    'menyeperah': 'seperah',
    'sepertikan': 'seperti',
    'sepertinya': 'seperti',
    'sepertinyanya': 'seperti',
    'menyepertikan': 'seperti',
    'penyepit': 'sepit',
    'penyepitan': 'sepit',
    'tersepit': 'sepit',
    'menyepit': 'sepit',
    'sepoi-sepoi': 'sepoi',
    'menyepuk': 'sepuk',
    'tersepuk': 'sepuk',
    'tersera-sera': 'sera',
    'penyerahterimaan': 'serah terima',
    'menyerahterimakan': 'serah terima',
    'berserak': 'serak',
    'berseraknya': 'serak',
    'berserakkan': 'serak',
    'berserakan': 'serak',
    'menyerak': 'serak',
    'menyerakkan': 'serak',
    'menyerakan': 'serak',
    'terserak': 'serak',
    'terserakan': 'serak',
    'berserakannya': 'serak',
    'serak-serak': 'serak',
    'berserak-serak': 'serak',
    'terserak-serak': 'serak',
    'menyerak-nyerakkan': 'serak',
    'berserama': 'serama',
    'serampangan': 'serampang',
    'serampangannya': 'serampang',
    'terserampang': 'serampang',
    'menyerampang': 'serampang',
    'keserampangan': 'serampang',
    'serampang dua belas': 'serampang',
    'terserampuk': 'serampuk',
    'berseran': 'seran',
    'menyerana': 'serana',
    'menyerandang': 'serandang',
    'terserandung': 'serandung',
    'berseranggung': 'seranggung',
    'menyeranggung': 'seranggung',
    'menyerangsang': 'serangsang',
    'penyeranian': 'serani',
    'menyeranikan': 'serani',
    'penyeranta': 'seranta',
    'menyerantakan': 'seranta',
    'diserap': 'serap',
    'diserapnya': 'serap',
    'serapan': 'serap',
    'serapannya': 'serap',
    'menyerap': 'serap',
    'menyerapnya': 'serap',
    'menyerapkan': 'serap',
    'menyerapan': 'serap',
    'terserap': 'serap',
    'terserapnya': 'serap',
    'penyerap': 'serap',
    'penyerapan': 'serap',
    'penyerapannya': 'serap',
    'menyerapahi': 'serapah',
    'menyeraya': 'seraya',
    'menyerayakan': 'seraya',
    'seraya-menyeraya': 'seraya',
    'serba-serbi': 'serba',
    'serba-serbinya': 'serba',
    'keserbagunaan': 'serbaguna',
    'menyerbak': 'serbak',
    'menyerbakkan': 'serbak',
    'beserban': 'serban',
    'beserbankan': 'serban',
    'menyerbeti': 'serbet',
    'menyerbuk': 'serbuk',
    'menyerbukkan': 'serbuk',
    'menyerbuki': 'serbuk',
    'menyerbukinya': 'serbuk',
    'penyerbukan': 'serbuk',
    'penyerbukannya': 'serbuk',
    'beserdam': 'serdam',
    'beserdawa': 'serdawa',
    'beserdih': 'serdih',
    'terserempak': 'serempak',
    'keserempakan': 'serempak',
    'keserempet': 'serempet',
    'menyerempet': 'serempet',
    'menyerempetnya': 'serempet',
    'menyerempetkan': 'serempet',
    'penyerempet': 'serempet',
    'penyerempetan': 'serempet',
    'terserempet': 'serempet',
    'terserempetnya': 'serempet',
    'menyerendeng': 'serendeng',
    'menyerendengkan': 'serendeng',
    'berserengam': 'serengam',
    'menyerengeh': 'serengeh',
    'berserenjang': 'serenjang',
    'menyerepi': 'serep',
    'menyerepkan': 'serep',
    'menyergah': 'sergah',
    'tesergam': 'sergam',
    'sergapan': 'sergap',
    'sergapannya': 'sergap',
    'tesergap': 'sergap',
    'menyergap': 'sergap',
    'menyergapnya': 'sergap',
    'menyergapi': 'sergap',
    'menyergapan': 'sergap',
    'menyergapku': 'sergap',
    'penyergap': 'sergap',
    'penyergapan': 'sergap',
    'penyergapannya': 'sergap',
    'berseri': 'seri',
    'berserinya': 'seri',
    'menyeri': 'seri',
    'menyerikan': 'seri',
    'perserian': 'seri',
    'berseri-seri': 'seri',
    'serak-serik': 'serik',
    'berserikat': 'serikat',
    'berserikatnya': 'serikat',
    'berserikatkan': 'serikat',
    'menyerikati': 'serikat',
    'perserikatan': 'serikat',
    'menyerikatkan': 'serikat',
    'keserimpet': 'serimpet',
    'menyerimpet': 'serimpet',
    'menyerimpung': 'serimpung',
    'penyerimpung': 'serimpung',
    'terserimpung': 'serimpung',
    'menyerindaikan': 'serindai',
    'menyering': 'sering',
    'menyeringkan': 'sering',
    'sering-sering': 'sering',
    'sering-seringnya': 'sering',
    'sering-seringlah': 'sering',
    'menyeringai': 'seringai',
    'terseringing': 'seringing',
    'menyeringing': 'seringing',
    'menyerit': 'serit',
    'menyeritkan': 'serit',
    'menyerkah': 'serkah',
    'menyerkai': 'serkai',
    'penyerkup': 'serkup',
    'menyerkup': 'serkup',
    'menyerkupkan': 'serkup',
    'teserling': 'serling',
    'menyernak': 'sernak',
    'terserobok': 'serobok',
    'berserobok': 'serobok',
    'menyerobot': 'serobot',
    'menyerobotnya': 'serobot',
    'penyerobot': 'serobot',
    'penyerobotan': 'serobot',
    'serobot-serobotan': 'serobot',
    'serokan': 'serok',
    'menyerok': 'serok',
    'menyeroknya': 'serok',
    'menyeroki': 'serok',
    'terserok': 'serok',
    'penyerok': 'serok',
    'terserompok': 'serompok',
    'terserondok': 'serondok',
    'menyerondol': 'serondol',
    'menyerondong': 'serondong',
    'terserondong': 'serondong',
    'keseronokan': 'seronok',
    'menyeronokkan': 'seronok',
    'menyeropot': 'seropot',
    'menyerosoh': 'serosoh',
    'terserot': 'serot',
    'menyerot': 'serot',
    'menyerotkan': 'serot',
    'menyeroti': 'serot',
    'seroyongan': 'seroyong',
    'serpihan': 'serpih',
    'serpihannya': 'serpih',
    'menyerpih': 'serpih',
    'penyerpihan': 'serpih',
    'peserta': 'serta',
    'pesertanya': 'serta',
    'pesertai': 'serta',
    'pesertaan': 'serta',
    'beserta': 'serta',
    'besertanya': 'serta',
    'besertakan': 'serta',
    'besertai': 'serta',
    'besertaan': 'serta',
    'besertamu': 'serta',
    'penyerta': 'serta',
    'penyertanya': 'serta',
    'penyertakan': 'serta',
    'penyertaan': 'serta',
    'menyertai': 'serta',
    'menyertainya': 'serta',
    'menyertaiku': 'serta',
    'menyertaimu': 'serta',
    'kesertaan': 'serta',
    'kesertaannya': 'serta',
    'penyertaannya': 'serta',
    'menyertakan': 'serta',
    'menyertakannya': 'serta',
    'serta-serta': 'serta',
    'mempesertakan': 'serta',
    'serta-menyertai': 'serta',
    'kesertamertaan': 'serta-merta',
    'penyertifikatan': 'sertifikat',
    'menyertifikatkan': 'sertifikat',
    'menyertu': 'sertu',
    'seruan': 'seru',
    'seruannya': 'seru',
    'seruanku': 'seru',
    'berseru': 'seru',
    'penyeru': 'seru',
    'penyerukan': 'seru',
    'penyeruan': 'seru',
    'menyeru': 'seru',
    'menyerunya': 'seru',
    'menyerukan': 'seru',
    'menyerukannya': 'seru',
    'menyeruan': 'seru',
    'berseru-seru': 'seru',
    'menyeru-nyerukan': 'seru',
    'menyeruak': 'seruak',
    'menyeruaknya': 'seruak',
    'menyeruaklah': 'seruak',
    'menyeruakkan': 'seruak',
    'menyeruakan': 'seruak',
    'penyerudi': 'serudi',
    'berserudi': 'serudi',
    'menyerudi': 'serudi',
    'serudukan': 'seruduk',
    'serudukannya': 'seruduk',
    'keseruduk': 'seruduk',
    'terseruduk': 'seruduk',
    'penyeruduk': 'seruduk',
    'penyerudukan': 'seruduk',
    'menyeruduk': 'seruduk',
    'menyeruduknya': 'seruduk',
    'menyerudukkan': 'seruduk',
    'menyerudukkannya': 'seruduk',
    'menyeruit': 'seruit',
    'bersuling': 'seruling',
    'menyerum': 'serum',
    'terserunda': 'serunda',
    'berserunda': 'serunda',
    'menyerunda': 'serunda',
    'menyerundang': 'serundang',
    'menyeruput': 'seruput',
    'menyeruputnya': 'seruput',
    'serutan': 'serut',
    'serutannya': 'serut',
    'menyerut': 'serut',
    'menyerutnya': 'serut',
    'penyerutan': 'serut',
    'menyeruyuk': 'seruyuk',
    'menyervis': 'servis',
    'tersesak': 'sesak',
    'menyesak': 'sesak',
    'menyesakkan': 'sesak',
    'menyesaki': 'sesak',
    'menyesakan': 'sesak',
    'kesesakan': 'sesak',
    'bersesak-sesak': 'sesak',
    'bersesak-sesakan': 'sesak',
    'sesak-menyesak': 'sesak',
    'sesapan': 'sesap',
    'menyesap': 'sesap',
    'menyesapkan': 'sesap',
    'menyesapi': 'sesap',
    'tersesap': 'sesap',
    'penyesapan': 'sesap',
    'sesaran': 'sesar',
    'menyesar': 'sesar',
    'bersesaran': 'sesar',
    'penyesaran': 'sesar',
    'menyesarkan': 'sesar',
    'bersesat': 'sesat',
    'tersesat': 'sesat',
    'tersesatnya': 'sesat',
    'tersesatkan': 'sesat',
    'kesesatan': 'sesat',
    'kesesatannya': 'sesat',
    'penyesatan': 'sesat',
    'menyesatkan': 'sesat',
    'menyesatkannya': 'sesat',
    'menyeser': 'seser',
    'sesuai': 'suai',
    'sesuainya': 'suai',
    'sesuailah': 'suai',
    'sesuaikan': 'suai',
    'sesuaii': 'suai',
    'sesuaian': 'suai',
    'bersuai': 'suai',
    'bersuaian': 'suai',
    'bersesuai': 'suai',
    'bersesuaian': 'suai',
    'kesesuaian': 'suai',
    'kesesuaiannya': 'suai',
    'penyesuaian': 'suai',
    'penyesuaiannya': 'suai',
    'penyesuaianlah': 'suai',
    'persesuaian': 'suai',
    'persesuaiannya': 'suai',
    'menyesuaikan': 'suai',
    'menyesuaikannya': 'suai',
    'menyesuaikanlah': 'suai',
    'menyesuaikankan': 'suai',
    'tersesuaikan': 'suai',
    'berkesesuaian': 'suai',
    'sesuatu': 'suatu',
    'sesuatunya': 'suatu',
    'sesuatulah': 'suatu',
    'bersuatu': 'suatu',
    'mempersuatukan': 'suatu',
    'sesudah': 'sudah',
    'sesudahnya': 'sudah',
    'sesudahmu': 'sudah',
    'bersudah': 'sudah',
    'penyudah': 'sudah',
    'penyudahan': 'sudah',
    'menyudahi': 'sudah',
    'menyudahinya': 'sudah',
    'kesudahan': 'sudah',
    'kesudahannya': 'sudah',
    'mempersudah': 'sudah',
    'menyudahkan': 'sudah',
    'sesudah-sudah': 'sudah',
    'bersudah-sudah': 'sudah',
    'sesudah-sudahnya': 'sudah',
    'berkesudahan': 'sudah',
    'sungguhan': 'sungguh',
    'sungguhannya': 'sungguh',
    'kesungguhan': 'sungguhan',
    'kesungguhannya': 'sungguhan',
    'menyungguhi': 'sungguh',
    'sesungguhnya': 'sungguhan',
    'sesungguhnyalah': 'sungguhan',
    'penyungguhan': 'sungguhan',
    'menyungguhkan': 'sungguhan',
    'berkesungguhan': 'sungguh',
    'mempersungguhi': 'sungguh',
    'sungguh-sungguh': 'sungguhan',
    'sungguh-sungguhnya': 'sungguhan',
    'bersungguh-sungguh': 'sungguhan',
    'bersungguh-sungguhlah': 'sungguhan',
    'menyungguh-nyungguhi': 'sungguh',
    'pengeset': 'set',
    'pengesetan': 'set',
    'tersetai-setai': 'setai',
    'bersetai-setai': 'setai',
    'setakat': 'takat',
    'menyetan': 'setan',
    'persetan': 'setan',
    'kesetanan': 'setan',
    'kesetanannya': 'setan',
    'mempersetan': 'setan',
    'mempersetankan': 'setan',
    'setara': 'tara',
    'setaranya': 'tara',
    'setaralah': 'tara',
    'setarakan': 'tara',
    'setaraan': 'tara',
    'tertara': 'tara',
    'bertara': 'tara',
    'menarakan': 'tara',
    'penyetara': 'tara',
    'penyetarakan': 'tara',
    'penyetaraan': 'tara',
    'menyetarakan': 'tara',
    'menyetarakannya': 'tara',
    'setekan': 'setek',
    'setelan': 'setel',
    'setelannya': 'setel',
    'menyetel': 'setel',
    'menyetelnya': 'setel',
    'menyetelkan': 'setel',
    'penyetelan': 'setel',
    'penyetelannya': 'setel',
    'bersetelan': 'setel',
    'menyetel-nyetel': 'setel',
    'penelah': 'telah',
    'penelahan': 'telah',
    'menelah': 'telah',
    'menelahan': 'telah',
    'setelah': 'telah',
    'setelahnya': 'telah',
    'setelahkan': 'telah',
    'setelahi': 'telah',
    'menyetelengkan': 'seteleng',
    'seteman': 'setem',
    'menyetem': 'setem',
    'penyeteman': 'setem',
    'setengah': 'tengah',
    'setengahnya': 'tengah',
    'setengahlah': 'tengah',
    'setengahnyalah': 'tengah',
    'menengah': 'tengah',
    'menengahnya': 'tengah',
    'menengahkan': 'tengah',
    'menengahi': 'tengah',
    'tengahan': 'tengah',
    'tengahannya': 'tengah',
    'penengah': 'tengah',
    'penengahnya': 'tengah',
    'penengahan': 'tengah',
    'menengahinya': 'tengah',
    'pertengahan': 'tengah',
    'pertengahannya': 'tengah',
    'mengetengahi': 'tengah',
    'mengetengahkan': 'tengah',
    'setengah-setengah': 'tengah',
    'kesetiakawanan': 'setia kawan',
    'kesetiakawanannya': 'setia kawan',
    'kesetiakawananan': 'setia kawan',
    'bersetia': 'setia',
    'kesetiaan': 'setia',
    'kesetiaannya': 'setia',
    'kesetiaanku': 'setia',
    'setiba': 'tiba',
    'setibanya': 'tiba',
    'setikan': 'setik',
    'setikannya': 'setik',
    'menyetik': 'setik',
    'timpalan': 'timpal',
    'timpalannya': 'timpal',
    'setimpal': 'timpal',
    'menimpali': 'timpal',
    'menimpalinya': 'timpal',
    'menyetip': 'setip',
    'setopan': 'setop',
    'penyetop': 'setop',
    'penyetopan': 'setop',
    'menyetop': 'setop',
    'menyetopnya': 'setop',
    'menyetopkan': 'setop',
    'menyetopmu': 'setop',
    'setoran': 'setor',
    'setorannya': 'setor',
    'setoranlah': 'setor',
    'menyetor': 'setor',
    'menyetornya': 'setor',
    'menyetorkan': 'setor',
    'menyetorkannya': 'setor',
    'penyetor': 'setor',
    'penyetornya': 'setor',
    'penyetorkan': 'setor',
    'penyetoran': 'setor',
    'penyetorannya': 'setor',
    'setrapan': 'setrap',
    'menyetrap': 'strap',
    'penyetrapan': 'setrap',
    'setrikaan': 'setrika',
    'bersetrika': 'setrika',
    'menyetrika': 'setrika',
    'menyetrikanya': 'setrika',
    'menyetrikakan': 'setrika',
    'penyetrika': 'setrika',
    'penyetrikaan': 'setrika',
    'bersetrip': 'setrip',
    'menyetrip': 'setrip',
    'penyetripan': 'setrip',
    'kesetrum': 'setrum',
    'tersetrum': 'setrum',
    'tersetrumnya': 'setrum',
    'menyetrum': 'setrum',
    'menyetrumnya': 'setrum',
    'menyetrumkan': 'setrum',
    'menyetrumku': 'setrum',
    'penyetruman': 'setrum',
    'menyetui': 'setu',
    'menyetum': 'setum',
    'penyetuman': 'setum',
    'menyetup': 'setup',
    'bersewaka': 'sewaka',
    'menyewat': 'sewat',
    'sewot-sewotan': 'sewot',
    'sia-sia': 'sia',
    'sia-sianya': 'sia',
    'sia-sialah': 'sia',
    'sia-siakan': 'sia',
    'tersia-sia': 'sia-sia',
    'tersia-siakan': 'sia-sia',
    'bersia-sia': 'sia-sia',
    'kesia-siaan': 'sia-sia',
    'menyia-nyiakan': 'sia-sia',
    'menyia-nyiakannya': 'sia-sia',
    'bersiaga': 'siaga',
    'bersiaganya': 'siaga',
    'bersiagalah': 'siaga',
    'kesiagaan': 'siaga',
    'kesiagaannya': 'siaga',
    'menyiagakan': 'siaga',
    'tersiah': 'siah',
    'bersiah': 'siah',
    'menyiah': 'siah',
    'menyiahkan': 'siah',
    'sesiak': 'siak',
    'bersiakon': 'siakon',
    'sialan': 'sial',
    'kesialan': 'sial',
    'kesialannya': 'sial',
    'menyialkan': 'sial',
    'bersialang': 'sialang',
    'bersiap sedia': 'siap sedia',
    'kesiapsiagaan': 'siap siaga',
    'kesiapsiagaannya': 'siap siaga',
    'siapa-siapa': 'siapa',
    'siapa-siapanya': 'siapa',
    'menyiat': 'siat',
    'menyiatkan': 'siat',
    'menyibak': 'sibak',
    'menyibaknya': 'sibak',
    'menyibakkan': 'sibak',
    'menyibakan': 'sibak',
    'bersibak': 'sibak',
    'menyibak-nyibak': 'sibak',
    'sesibar': 'sibar',
    'bersibar': 'sibar',
    'bersibaran': 'sibar',
    'sibar-sibar': 'sibar',
    'sibiran': 'sibir',
    'sesibir': 'sibir',
    'menyibuk': 'sibuk',
    'menyibukkan': 'sibuk',
    'menyibukkannya': 'sibuk',
    'menyibukan': 'sibuk',
    'bersibuk': 'sibuk',
    'kesibukan': 'sibuk',
    'kesibukannya': 'sibuk',
    'kesibukanlah': 'sibuk',
    'kesibukanku': 'sibuk',
    'kesibukanmu': 'sibuk',
    'menyibur': 'sibur',
    'sibur-sibur': 'sibur',
    'sida-sida': 'sida',
    'menyidik': 'sidik',
    'menyidiknya': 'sidik',
    'menyidiki': 'sidik',
    'menyidikan': 'sidik',
    'penyidik': 'sidik',
    'penyidiknya': 'sidik',
    'penyidiklah': 'sidik',
    'penyidikkan': 'sidik',
    'penyidikkannya': 'sidik',
    'penyidiki': 'sidik',
    'penyidikan': 'sidik',
    'penyidikannya': 'sidik',
    'penyidikanlah': 'sidik',
    'bersiduga': 'siduga',
    'menyiduk': 'siduk',
    'menyiduknya': 'siduk',
    'disigai': 'sigai',
    'menyigai': 'sigai',
    'bersigai': 'sigai',
    'bersigap': 'sigap',
    'kesigapan': 'sigap',
    'kesigapannya': 'sigap',
    'menyigapkan': 'sigap',
    'menyigar': 'sigar',
    'penyigi': 'sigi',
    'penyigian': 'sigi',
    'menyigi': 'sigi',
    'bersikap': 'sikap',
    'bersikapnya': 'sikap',
    'bersikaplah': 'sikap',
    'menyikap': 'sikap',
    'menyikapnya': 'sikap',
    'menyikapi': 'sikap',
    'menyikapinya': 'sikap',
    'penyikat': 'sikat',
    'penyikatan': 'sikat',
    'menyikat': 'sikat',
    'menyikatnya': 'sikat',
    'menyikatkan': 'sikat',
    'menyikati': 'sikat',
    'bersikudidi': 'sikudidi',
    'sikutan': 'sikut',
    'sikutannya': 'sikut',
    'tersikut': 'sikut',
    'menyikut': 'sikut',
    'menyikutnya': 'sikut',
    'menyikuti': 'sikut',
    'menyikutku': 'sikut',
    'bersikutan': 'sikut',
    'sikut-sikutan': 'sikut',
    'bersikut-sikutan': 'sikut',
    'silahkan': 'silah',
    'silahkanlah': 'silah',
    'silah-silah': 'silah',
    'tersilam': 'silam',
    'menyilam': 'silam',
    'menyilamkan': 'silam',
    'penyilap': 'silap',
    'bersilap': 'silap',
    'menyilap': 'silap',
    'pesilat': 'silat',
    'pesilatnya': 'silat',
    'bersilat': 'silat',
    'menyilat': 'silat',
    'persilatan': 'silat',
    'bersilaturahmi': 'silaturahmi',
    'bersilengah': 'silengah',
    'menyilet': 'silet',
    'menyiletkannya': 'silet',
    'menyileti': 'silet',
    'penyiletan': 'silet',
    'silihan': 'silih',
    'bersilih': 'silih',
    'menyilih': 'silih',
    'penyilihan': 'silih',
    'persilihan': 'silih',
    'menyilik': 'silik',
    'siliran': 'silir',
    'silir-semilir': 'silir',
    'bersilir-silir': 'silir',
    'menyilukan': 'silu',
    'menyimak': 'simak',
    'menyimaknya': 'simak',
    'bersimbang': 'simbang',
    'menyimbang': 'simbang',
    'menyimbangkan': 'simbang',
    'menyimbangi': 'simbang',
    'tersimbur': 'simbur',
    'menyimbur': 'simbur',
    'bersimbur': 'simbur',
    'menyimburi': 'simbur',
    'menyimburkan': 'simbur',
    'bersimbur-simburan': 'simbur',
    'bersimpai': 'simpai',
    'tersimpai': 'simpai',
    'menyimpai': 'simpai',
    'menyimpaikan': 'simpai',
    'simpangan': 'simpang',
    'simpangannya': 'simpang',
    'menyimpang': 'simpang',
    'menyimpangnya': 'simpang',
    'menyimpangkan': 'simpang',
    'menyimpangi': 'simpang',
    'menyimpangan': 'simpang',
    'bersimpang': 'simpang',
    'bersimpangan': 'simpang',
    'persimpangan': 'simpang',
    'persimpangannya': 'simpang',
    'penyimpangan': 'simpang',
    'penyimpangannya': 'simpang',
    'bersimpang siur': 'simpang siur',
    'kesimpangsiuran': 'simpang siur',
    'kesimpangsiurannya': 'simpang siur',
    'kesimpatan': 'simpat',
    'bersimpati': 'simpati',
    'kesimpatikan': 'simpatik',
    'menyimpirkan': 'simpir',
    'bersimpuh': 'simpuh',
    'bersimpuhlah': 'simpuh',
    'tersimpuh': 'simpuh',
    'menyimpuk': 'simpuk',
    'menyimpukan': 'simpuk',
    'menyimulasi': 'simulasi',
    'menyimulasikan': 'simulasi',
    'menyimulasikannya': 'simulasi',
    'bersinau-sinau': 'sinau',
    'pesinden': 'sinden',
    'menyinden': 'sinden',
    'bersinergi': 'sinergi',
    'bersinerginya': 'sinergi',
    'bersinergilah': 'sinergi',
    'bersinergii': 'sinergi',
    'mengnyinergikan': 'sinergi',
    'bersinetron': 'sinetron',
    'penyinetronan': 'sinetron',
    'menyinetronkan': 'sinetron',
    'tersingahak': 'singahak',
    'singgahan': 'singgah',
    'bersinggah': 'singgah',
    'bersinggahnya': 'singgah',
    'menyinggahi': 'singgah',
    'menyinggahinya': 'singgah',
    'persinggahan': 'singgah',
    'persinggahannya': 'singgah',
    'mempersinggah': 'singgah',
    'menyinggahkan': 'singgah',
    'singgah-menyinggah': 'singgah',
    'menyinggang': 'singgang',
    'menyinggir': 'singgir',
    'menyinggirkan': 'singgir',
    'menyinggit': 'singgit',
    'bersinggit': 'singgit',
    'menyinggul': 'singgul',
    'menyingit': 'singit',
    'tersingit': 'singit',
    'singkapan': 'singkap',
    'tersingkap': 'singkap',
    'tersingkapnya': 'singkap',
    'tersingkaplah': 'singkap',
    'tersingkapkan': 'singkap',
    'menyingkap': 'singkap',
    'menyingkapnya': 'singkap',
    'menyingkapkan': 'singkap',
    'menyingkapi': 'singkap',
    'singkatan': 'singkat',
    'singkatannya': 'singkat',
    'penyingkat': 'singkat',
    'penyingkatan': 'singkat',
    'menyingkat': 'singkat',
    'menyingkatnya': 'singkat',
    'menyingkatkan': 'singkat',
    'menyingkur': 'singkur',
    'menyingsatkan': 'singsat',
    'penyingset': 'singset',
    'penyingsetan': 'singset',
    'menyingsetkan': 'singset',
    'sinian': 'sini',
    'ke sini': 'sini',
    'kesinian': 'sini',
    'mengesinikan': 'sini',
    'menyinkronkan': 'sinkron',
    'menyinkronkannya': 'sinkron',
    'kesinoniman': 'sinonim',
    'penyinrili': 'sinrili',
    'menyinter': 'sinter',
    'penyinteran': 'sinter',
    'menyintesis': 'sintesis',
    'menyintesiskan': 'sintesis',
    'kesintingan': 'sinting',
    'kesintingannya': 'sinting',
    'menyintuk': 'sintuk',
    'bersintuk': 'sintuk',
    'menyintukkan': 'sintuk',
    'menyintung': 'sintung',
    'mensinyalir': 'sinyalir',
    'mensinyalirkan': 'sinyalir',
    'sipatan': 'sipat',
    'menyipat': 'sipat',
    'menyipati': 'sipat',
    'penyipatan': 'sipat',
    'menyipatkan': 'sipat',
    'menyipi': 'sipi',
    'tersipi': 'sipi',
    'menyipitkan': 'sipit',
    'menyipitkannya': 'sipit',
    'tersipu': 'sipu',
    'kesipuan': 'sipu',
    'tersipu-sipu': 'sipu',
    'kesipu-sipuan': 'sipu',
    'mengesir': 'sir',
    'sir-siran': 'sir',
    'tersirah': 'sirah',
    'siraman': 'siram',
    'siramannya': 'siram',
    'menyiram': 'siram',
    'menyiramnya': 'siram',
    'menyiramkan': 'siram',
    'menyiramkannya': 'siram',
    'menyirami': 'siram',
    'menyiraman': 'siram',
    'bersiram': 'siram',
    'penyiram': 'siram',
    'penyiraman': 'siram',
    'menyiraminya': 'siram',
    'pesiraman': 'siram',
    'penyiramannya': 'siram',
    'persiraman': 'siram',
    'tersirap': 'sirap',
    'menyirapkan': 'sirap',
    'siratan': 'sirat',
    'menyirat': 'sirat',
    'menyiratkan': 'sirat',
    'menyirati': 'sirat',
    'tersirat': 'sirat',
    'tersiratnya': 'sirat',
    'tersiratkan': 'sirat',
    'sirat-sirat': 'sirat',
    'kesirep': 'sirep',
    'penyirep': 'sirep',
    'menyirep': 'sirep',
    'tersirep': 'sirep',
    'menyirepi': 'sirep',
    'penyirepan': 'sirep',
    'penyirih': 'sirih',
    'menyirih': 'sirih',
    'menyirihi': 'sirih',
    'penyirihan': 'sirih',
    'menyirihkan': 'sirih',
    'sirikan': 'sirik',
    'menyirik': 'sirik',
    'menyirikan': 'sirik',
    'kesirikan': 'sirik',
    'menyirnakan': 'sirna',
    'bersiru': 'siru',
    'tersisa': 'sisa',
    'tersisanya': 'sisa',
    'tersisalah': 'sisa',
    'tersisakan': 'sisa',
    'tersisai': 'sisa',
    'bersisa': 'sisa',
    'bersisakan': 'sisa',
    'menyisai': 'sisa',
    'menyisakan': 'sisa',
    'menyisakannya': 'sisa',
    'bersisalak': 'sisalak',
    'bersisi': 'sisi',
    'bersisikan': 'sisik',
    'bersisian': 'sisi',
    'ke sisi': 'sisi',
    'menyisi': 'sisi',
    'menyisikan': 'sisik',
    'mengesisikan': 'sisi',
    'menyisik': 'sisik',
    'bersisik': 'sisik',
    'menyisiki': 'sisik',
    'menyisir': 'sisir',
    'menyisirnya': 'sisir',
    'menyisirlah': 'sisir',
    'menyisiri': 'sisir',
    'menyisiran': 'sisir',
    'bersisir': 'sisir',
    'kesisiran': 'sisir',
    'bersistem': 'sistem',
    'penyisteman': 'sistem',
    'menyistemkan': 'sistem',
    'bersisurut': 'sisurut',
    'sitaan': 'sita',
    'sitaannya': 'sita',
    'menyita': 'sita',
    'menyitanya': 'sita',
    'menyitai': 'sita',
    'penyita': 'sita',
    'penyitaan': 'sita',
    'penyitaannya': 'sita',
    'menyitat': 'sitat',
    'siteran': 'siter',
    'menyitir': 'sitir',
    'menyiuk': 'siuk',
    'siulan': 'siul',
    'siulannya': 'siul',
    'bersiul': 'siul',
    'bersiulan': 'siul',
    'menyiulkan': 'siul',
    'siungan': 'siung',
    'bersiung': 'siung',
    'berkesiuran': 'siur',
    'berskala': 'skala',
    'menskedulkan': 'skedul',
    'menskemakan': 'skema',
    'menskenariokan': 'skenario',
    'mensketsa': 'sketsa',
    'menskor': 'skor',
    'penskoran': 'skor',
    'penskorannya': 'skor',
    'menskors': 'skors',
    'menskorsnya': 'skors',
    'penskorsan': 'skors',
    'mensmokel': 'smokel',
    'bersoal': 'soal',
    'bersoalan': 'soal',
    'menyoal': 'soal',
    'menyoalkan': 'soal',
    'menyoalkannya': 'soal',
    'persoalan': 'soal',
    'persoalannya': 'soal',
    'persoalankan': 'soal',
    'persoalanan': 'soal',
    'persoalanmu': 'soal',
    'mempersoalkan': 'soal',
    'mempersoalkannya': 'soal',
    'bersobat': 'sobat',
    'menyobat': 'sobat',
    'menyobati': 'sobat',
    'persobatan': 'sobat',
    'sesobek': 'sobek',
    'sobekan': 'sobek',
    'sobekannya': 'sobek',
    'menyobek': 'sobek',
    'menyobeknya': 'sobek',
    'menyobeki': 'sobek',
    'penyobekan': 'sobek',
    'sobek-sobekan': 'sobek',
    'menyobek-nyobek': 'sobek',
    'menyobek-nyobeknya': 'sobek',
    'tersobok': 'sobok',
    'bersobok': 'sobok',
    'soda kristal': 'soda kue',
    'sodetan': 'sodet',
    'sodetannya': 'sodet',
    'menyodet': 'sodet',
    'penyodetan': 'sodet',
    'penyodok': 'sodok',
    'penyodokan': 'sodok',
    'menyodok': 'sodok',
    'menyodoknya': 'sodok',
    'menyodokkan': 'sodok',
    'menyodokan': 'sodok',
    'sodok-sodokan': 'sodok',
    'menyodomi': 'sodomi',
    'menyodominya': 'sodomi',
    'penyodomi': 'sodomi',
    'sodoran': 'sodor',
    'sodorannya': 'sodor',
    'menyodorkan': 'sodor',
    'menyodorkannya': 'sodor',
    'menyoga': 'soga',
    'kesohor': 'sohor',
    'kesohoran': 'sohor',
    'tersohor': 'sohor',
    'tersohornya': 'sohor',
    'menyoja': 'soja',
    'bersoja': 'soja',
    'tersoja-soja': 'soja',
    'bersokom': 'sokom',
    'menyokom': 'sokom',
    'menyokomkan': 'sokom',
    'bersol': 'sol',
    'mengesol': 'sol',
    'mengesolkan': 'sol',
    'menyolang': 'solang',
    'menyolder': 'solder',
    'menyolidkan': 'solid',
    'pesolok': 'solok',
    'penyolok': 'solok',
    'mengesom': 'som',
    'menyombol': 'sombol',
    'tersomplok': 'somplok',
    'bersomplokan': 'somplok',
    'tersompok': 'sompok',
    'menyondang': 'sondang',
    'penyondong': 'sondong',
    'menyondong': 'sondong',
    'menyondongkan': 'sondong',
    'tersongel': 'songel',
    'menyongket': 'songket',
    'menyongketkan': 'songket',
    'bersongkok': 'songkok',
    'menyongsong': 'songsong',
    'menyongsongnya': 'songsong',
    'menyongsongkan': 'songsong',
    'menyongsongmu': 'songsong',
    'bersongsong': 'songsong',
    'songsong arus': 'songsong',
    'sontekan': 'sontek',
    'sontekannya': 'sontek',
    'menyontek': 'sontek',
    'menyonteknya': 'sontek',
    'menyontekkan': 'sontek',
    'menyontekan': 'sontek',
    'menyontok': 'sontok',
    'kesopansantunan': 'sopan santun',
    'bersopan santun': 'sopan santun',
    'menyopir': 'sopir',
    'menyopiri': 'sopir',
    'menyopirinya': 'sopir',
    'bersorak-sorai': 'sorak-sorai',
    'sorangan': 'sorang',
    'kesorangan': 'sorang',
    'kesorean': 'sore',
    'tersoren': 'soren',
    'sorogan': 'sorog',
    'sorongan': 'sorong',
    'menyorong': 'sorong',
    'menyorongkan': 'sorong',
    'menyorongkannya': 'sorong',
    'tersorong': 'sorong',
    'menyorong-nyorongkan': 'sorong',
    'sortiran': 'sortir',
    'penyortir': 'sortir',
    'penyortiran': 'sortir',
    'menyortir': 'sortir',
    'menyortirnya': 'sortir',
    'kesosialan': 'sosial',
    'kesosialannya': 'sosial',
    'bersosialisasi': 'sosialisasi',
    'bersosialisasinya': 'sosialisasi',
    'bersosialisasilah': 'sosialisasi',
    'bersosialisasikan': 'sosialisasi',
    'mensosialisasikan': 'sosialisasi',
    'mensosialisasikannya': 'sosialisasi',
    'sosohan': 'sosoh',
    'penyosoh': 'sosoh',
    'penyosohan': 'sosoh',
    'bersosoh': 'sosoh',
    'menyosoh': 'sosoh',
    'penyosohannya': 'sosoh',
    'menyosok': 'sosok',
    'menyosokkan': 'sosok',
    'bersosok': 'sosok',
    'menyosor': 'sosor',
    'menyosorkan': 'sosor',
    'persotoan': 'soto',
    'menyoyak': 'soyak',
    'menyoyaknyoyak': 'soyak',
    'berspekulasi': 'spekulasi',
    'berspekulasilah': 'spekulasi',
    'menspekulasikan': 'spekulasi',
    'berspesialisasi': 'spesialisasi',
    'menspion': 'spion',
    'mensponsori': 'sponsor',
    'mensponsorinya': 'sponsor',
    'pensponsoran': 'sponsor',
    'sponsor-sponsoran': 'sponsor',
    'kespontanan': 'spontan',
    'kesportifan': 'sportif',
    'kestabilan': 'stabil',
    'kestabilannya': 'stabil',
    'penstabilan': 'stabil',
    'penstabilannya': 'stabil',
    'menstabilkan': 'stabil',
    'menstabilkannya': 'stabil',
    'penstandaran': 'standar',
    'menstandarkan': 'standar',
    'menstarter': 'starter',
    'menstarternya': 'starter',
    'menstarterkan': 'starter',
    'berstatus': 'status',
    'berstatusnya': 'status',
    'berstatuskan': 'status',
    'menstempel': 'stempel',
    'berstempel': 'stempel',
    'kesterilan': 'steril',
    'kesterilannya': 'steril',
    'pensterilan': 'steril',
    'mensterilkan': 'steril',
    'mensterilkannya': 'steril',
    'menstilir': 'stilir',
    'menstimulasi': 'stimulasi',
    'menstimulasinya': 'stimulasi',
    'menstimulasikan': 'stimulasi',
    'menstimulasikannya': 'stimulasi',
    'berstrata': 'strata',
    'penstrataan': 'strata',
    'menstratakan': 'strata',
    'terstruktur': 'struktur',
    'terstrukturnya': 'struktur',
    'terstrukturi': 'struktur',
    'berstruktur': 'struktur',
    'berstrukturkan': 'struktur',
    'penstrukturan': 'struktur',
    'menstrukturkan': 'struktur',
    'bersua': 'sua',
    'bersuanya': 'sua',
    'menyua': 'sua',
    'menyuai': 'sua',
    'tersua': 'sua',
    'persuaan': 'sua',
    'mempersuakan': 'sua',
    'menyuak': 'suak',
    'menyuaki': 'suak',
    'menyuakakan': 'suaka',
    'suam-suam': 'suam',
    'bersuami': 'suami',
    'bersuamikan': 'suami',
    'mempersuami': 'suami',
    'mempersuamikan': 'suami',
    'suang-suang': 'suang',
    'sesuang-suang': 'suang',
    'menyuar': 'suar',
    'menyuarkan': 'suar',
    'menyuaran': 'suar',
    'bersuar': 'suar',
    'bersuaran': 'suar',
    'tersuar': 'suar',
    'bersuara': 'suara',
    'bersuaranya': 'suara',
    'bersuaralah': 'suara',
    'penyuaraan': 'suara',
    'menyuarakan': 'suara',
    'menyuarakannya': 'suara',
    'menyuarangkan': 'suarang',
    'menyuasanai': 'suasana',
    'menyubal': 'subal',
    'menyubang': 'subang',
    'menyubangkan': 'subang',
    'bersubang': 'subang',
    'menyublim': 'sublim',
    'penyubliman': 'sublim',
    'menyubordinasikan': 'subordinasi',
    'menyubsider': 'subsider',
    'bersubsidi': 'subsidi',
    'bersubsidinya': 'subsidi',
    'tersubstitusikan': 'substitusi',
    'menyubversikan': 'subversi',
    'penyuci hama': 'suci hama',
    'menyucihamakan': 'suci hama',
    'menyudet': 'sudet',
    'menyudi': 'sudi',
    'kesudian': 'sudi',
    'menyudikan': 'sudi',
    'bersudikan': 'sudi',
    'mempersudikan': 'sudi',
    'menyudip': 'sudip',
    'menyudu': 'sudu',
    'menyudukan': 'sudu',
    'tersudu': 'sudu',
    'sudu-sudu': 'sudu',
    'sudung-sudung': 'sudung',
    'menyudut': 'sudut',
    'menyudutnya': 'sudut',
    'menyudutkan': 'sudut',
    'menyudutkannya': 'sudut',
    'tersudut': 'sudut',
    'tersudutnya': 'sudut',
    'tersudutkan': 'sudut',
    'menyudutkanku': 'sudut',
    'kesufian': 'sufi',
    'menyugar': 'sugar',
    'pesugi': 'sugi',
    'pesugian': 'sugi',
    'menyugi': 'sugi',
    'bersugi': 'sugi',
    'sugi-sugi': 'sugi',
    'suguhan': 'suguh',
    'suguhannya': 'suguh',
    'tersuguh': 'suguh',
    'tersuguhlah': 'suguh',
    'tersuguhkan': 'suguh',
    'tersuguhkannya': 'suguh',
    'tersuguhi': 'suguh',
    'menyuguhi': 'suguh',
    'menyuguhinya': 'suguh',
    'menyuguhkan': 'suguh',
    'menyuguhkannya': 'suguh',
    'menyugun': 'sugun',
    'menyugunkan': 'sugun',
    'bersuh': 'suh',
    'suitan': 'suit',
    'bersuit': 'suit',
    'sujian': 'suji',
    'menyuji': 'suji',
    'menyujikan': 'suji',
    'bersuji': 'suji',
    'bersujud': 'sujud',
    'bersujudlah': 'sujud',
    'tersujud': 'sujud',
    'bersukacita': 'sukacita',
    'bersukacitalah': 'sukacita',
    'bersukaria': 'sukaria',
    'kesuksesan': 'sukses',
    'kesuksesannya': 'sukses',
    'kesuksesanku': 'sukses',
    'kesuksesanmu': 'sukses',
    'menyukseskan': 'sukses',
    'menyukseskannya': 'sukses',
    'menyulang': 'sulang',
    'menyulangi': 'sulang',
    'menyulangkan': 'sulang',
    'bersulang-sulang': 'sulang',
    'sulang-menyulang': 'sulang',
    'menyulih': 'sulih',
    'menyulihi': 'sulih',
    'kesultanan': 'sultan',
    'kesultanannya': 'sultan',
    'pesuluh': 'suluh',
    'menyuluh': 'suluh',
    'menyuluhi': 'suluh',
    'bersuluh': 'suluh',
    'penyuluh': 'suluh',
    'penyuluhnya': 'suluh',
    'penyuluhlah': 'suluh',
    'penyuluhan': 'suluh',
    'penyuluhannya': 'suluh',
    'bersuluhkan': 'suluh',
    'bersuluk': 'suluk',
    'bersulur': 'sulur',
    'menyulur': 'sulur',
    'menyulurkan': 'sulur',
    'sulur-suluran': 'sulur',
    'menyulut': 'sulut',
    'menyulutnya': 'sulut',
    'menyulutkan': 'sulut',
    'menyulutkannya': 'sulut',
    'menyuluti': 'sulut',
    'menyumba': 'sumba',
    'menyumbakan': 'sumba',
    'sumbangan': 'sumbang',
    'sumbangannya': 'sumbang',
    'sumbangankan': 'sumbang',
    'menyumbang': 'sumbang',
    'menyumbangnya': 'sumbang',
    'menyumbanglah': 'sumbang',
    'menyumbangkan': 'sumbang',
    'menyumbangkannya': 'sumbang',
    'menyumbangan': 'sumbang',
    'penyumbang': 'sumbang',
    'penyumbangnya': 'sumbang',
    'penyumbangan': 'sumbang',
    'sesumbar': 'sumbar',
    'sesumbarnya': 'sumbar',
    'sesumbar-mu': 'sumbar',
    'bersumbar': 'sumbar',
    'menyumbar': 'sumbar',
    'sumbatan': 'sumbat',
    'sumbatannya': 'sumbat',
    'tersumbat': 'sumbat',
    'tersumbatnya': 'sumbat',
    'tersumbatkan': 'sumbat',
    'penyumbat': 'sumbat',
    'penyumbatnya': 'sumbat',
    'penyumbatan': 'sumbat',
    'menyumbat': 'sumbat',
    'menyumbatnya': 'sumbat',
    'menyumbatan': 'sumbat',
    'penyumbatannya': 'sumbat',
    'bersumber': 'sumber',
    'bersumberkan': 'sumber',
    'menyumbi': 'sumbi',
    'bersumbu': 'sumbu',
    'menyumbui': 'sumbu',
    'persumbuan': 'sumbu',
    'menyumbur': 'sumbur',
    'menyumburkan': 'sumbur',
    'menyumirkan': 'sumir',
    'pesumo': 'sumo',
    'tersumpal': 'sumpal',
    'menyumpal': 'sumpal',
    'menyumpalnya': 'sumpal',
    'menyumpalkan': 'sumpal',
    'menyumpalkannya': 'sumpal',
    'kesumpekan': 'sumpek',
    'sumpitan': 'sumpit',
    'menyumpit': 'sumpit',
    'tersumpit': 'sumpit',
    'penyumpit': 'sumpit',
    'penyumpitan': 'sumpit',
    'sumpit-sumpit': 'sumpit',
    'menyumsum': 'sumsum',
    'sumuran': 'sumur',
    'bersumur': 'sumur',
    'mengesun': 'sun',
    'disunahkan': 'sunah',
    'menyunahkan': 'sunah',
    'menyunam': 'sunam',
    'menyunamkan': 'sunam',
    'kesunanan': 'sunan',
    'tersundak': 'sundak',
    'menyundak': 'sundak',
    'sundukan': 'sunduk',
    'menyunduk': 'sunduk',
    'menyunduki': 'sunduk',
    'sundulan': 'sundul',
    'sundulannya': 'sundul',
    'sundulanku': 'sundul',
    'sundulanmu': 'sundul',
    'tersundul': 'sundul',
    'penyundul': 'sundul',
    'menyundul': 'sundul',
    'menyundulnya': 'sundul',
    'menyundulkan': 'sundul',
    'menyundulku': 'sundul',
    'penyundulan': 'sundul',
    'menyundut': 'sundut',
    'menyundutnya': 'sundut',
    'menyundutkan': 'sundut',
    'bersundut': 'sundut',
    'penyundut': 'sundut',
    'penyundutan': 'sundut',
    'sundut-bersundut': 'sundut',
    'menyungga': 'sungga',
    'menyunggi': 'sunggi',
    'menyungginya': 'sunggi',
    'penyungging': 'sungging',
    'menyungging': 'sungging',
    'menyunggingkan': 'sungging',
    'tersungging': 'sungging',
    'penyunggingan': 'sungging',
    'menyunggit': 'sunggit',
    'sungguhpun': 'sungguhan',
    'menyungkah': 'sungkah',
    'menyungkahkan': 'sungkah',
    'kesungkanan': 'sungkan',
    'tersungkap': 'sungkap',
    'bersungkawa': 'sungkawa',
    'menyungkem': 'sungkem',
    'menyungkit': 'sungkit',
    'bersungkit': 'sungkit',
    'tersungkuk': 'sungkuk',
    'tersungkuk-sungkuk': 'sungkuk',
    'menyungkum': 'sungkum',
    'tersungkum': 'sungkum',
    'menyungsang': 'sungsang',
    'menyungsangkan': 'sungsang',
    'tersunjam': 'sunjam',
    'menyuntih': 'suntih',
    'tersuntuk': 'suntuk',
    'kesuntukan': 'suntuk',
    'menyunu': 'sunu',
    'kesunyataan': 'sunyata',
    'penyuplai': 'suplai',
    'penyuplainya': 'suplai',
    'penyuplaian': 'suplai',
    'menyuplai': 'suplai',
    'menyuplainya': 'suplai',
    'supletoar': 'suplir',
    'persuratkabaran': 'surat kabar',
    'suri teladan': 'suri',
    'bersurih': 'surih',
    'menyurih': 'surih',
    'menyurihkan': 'surih',
    'surukan': 'suruk',
    'tersuruk': 'suruk',
    'menyuruk': 'suruk',
    'menyurukkan': 'suruk',
    'menyurukan': 'suruk',
    'menyuruki': 'suruk',
    'bersurukan': 'suruk',
    'suruk-surukan': 'suruk',
    'tersuruk-suruk': 'suruk',
    'menyuruk-nyuruk': 'suruk',
    'bersuruk-surukan': 'suruk',
    'kesurupan': 'surup',
    'kesurupannya': 'surup',
    'tersurut': 'surut',
    'tersurutkan': 'surut',
    'menyuruti': 'surut',
    'menyurutkan': 'surut',
    'menyurutkannya': 'surut',
    'penyurvei': 'survei',
    'penyurveinya': 'survei',
    'penyurveian': 'survei',
    'menyurvei': 'survei',
    'menyurveinya': 'survei',
    'bersusah hati': 'susah hati',
    'bersusah': 'susah',
    'menyusahi': 'susah',
    'kesusahan': 'susah',
    'kesusahannya': 'susah',
    'menyusahkan': 'susah',
    'menyusahkannya': 'susah',
    'menyusahkanku': 'susah',
    'mempersusah': 'susah',
    'bersusah-susah': 'susah',
    'kesusastraan': 'susastra',
    'kesusastraannya': 'susastra',
    'tersuspensi': 'suspensi',
    'susteran': 'suster',
    'susuan': 'susu',
    'susuanan': 'susu',
    'penyusu': 'susu',
    'penyusukan': 'susu',
    'penyusui': 'susu',
    'penyusuan': 'susu',
    'bersusu': 'susu',
    'menyusu': 'susu',
    'menyusunya': 'susu',
    'menyusui': 'susu',
    'menyusuan': 'susu',
    'menyusuinya': 'susu',
    'menyusuilah': 'susu',
    'menyusuimu': 'susu',
    'persusuan': 'susu',
    'penyusuanan': 'susu',
    'bersutan': 'sutan',
    'bersutan-sutan': 'sutan',
    'bersuten': 'suten',
    'kesutradaraan': 'sutradara',
    'menyutradarai': 'sutradara',
    'menyutradarainya': 'sutradara',
    'penyutradaraan': 'sutradara',
    'penyutradaraannya': 'sutradara',
    'menyuwir': 'suwir',
    'suwir-suwir': 'suwir',
    'keswasembadaan': 'swasembada',
    'bersyahadat': 'syahadat',
    'kesyahduan': 'syahdu',
    'mensyaki': 'syak',
    'mensyariatkan': 'syariat',
    'mensyarikat': 'syarikat',
    'bersyarikat': 'syarikat',
    'mensyirikkan': 'syirik',
    'bersyubhat': 'syubhat',
    'syukuran': 'syukur',
    'syukurannya': 'syukur',
    'syukuranlah': 'syukur',
    'bersyukur': 'syukur',
    'bersyukurnya': 'syukur',
    'bersyukurlah': 'syukur',
    'bersyukurkan': 'syukur',
    'mensyukuri': 'syukur',
    'mensyukurinya': 'syukur',
    'mensyurkan': 'syur',
    'ketaatasasan': 'taat asas',
    'menaati': 'taat',
    'menaatinya': 'taat',
    'ketaatan': 'taat',
    'ketaatannya': 'taat',
    'menabak': 'tabak',
    'menabaknya': 'tabak',
    'menabelkan': 'tabel',
    'bertabiat': 'tabiat',
    'pertabiban': 'tabib',
    'menabik': 'tabik',
    'menabikan': 'tabik',
    'bersitabik': 'tabik',
    'menabiri': 'tabir',
    'bertabir': 'tabir',
    'tabir-mabir': 'tabir',
    'bertablig': 'tablig',
    'menabligkan': 'tablig',
    'menabok': 'tabok',
    'tabrakan': 'tabrak',
    'tabrakannya': 'tabrak',
    'tabrakanlah': 'tabrak',
    'menabrak': 'tabrak',
    'menabraknya': 'tabrak',
    'menabrakkan': 'tabrak',
    'menabrakkannya': 'tabrak',
    'menabraki': 'tabrak',
    'menabrakan': 'tabrak',
    'menabrakku': 'tabrak',
    'menabrakmu': 'tabrak',
    'penabrak': 'tabrak',
    'penabraknya': 'tabrak',
    'penabrakkan': 'tabrak',
    'penabrakan': 'tabrak',
    'tertabrak': 'tabrak',
    'tertabraknya': 'tabrak',
    'tertabrakan': 'tabrak',
    'bertabrakan': 'tabrak',
    'bertabrakannya': 'tabrak',
    'tabrak-tubruk': 'tabrak',
    'menabukan': 'tabu',
    'menabuh': 'tabuh',
    'menabuhnya': 'tabuh',
    'menabuhkan': 'tabuh',
    'tabuhan': 'tabuh',
    'tabuhannya': 'tabuh',
    'tetabuhan': 'tabuh',
    'tabuh-tabuhan': 'tabuh',
    'menabulasi': 'tabulasi',
    'menabun': 'tabun',
    'tabunan': 'tabun',
    'tabun-menabun': 'tabun',
    'menadaburkan': 'tadabur',
    'bertadarus': 'tadarus',
    'penadbir': 'tadbir',
    'penadbiran': 'tadbir',
    'menadbirkan': 'tadbir',
    'tadinya': 'tadi',
    'tertadung': 'tadung',
    'menafahus': 'tafahus',
    'tafsiran': 'tafsir',
    'tafsirannya': 'tafsir',
    'penafsiran': 'tafsir',
    'penafsirannya': 'tafsir',
    'menafsirkan': 'tafsir',
    'menafsirkannya': 'tafsir',
    'menagak': 'tagak',
    'menagakkan': 'tagak',
    'menagak-nagak': 'tagak',
    'tertagak-tagak': 'tagak',
    'menagan': 'tagan',
    'menagani': 'tagan',
    'bertagan': 'tagan',
    'bertagar': 'tagar',
    'bertahajud': 'tahajud',
    'bertahak': 'tahak',
    'bertahalul': 'tahalul',
    'bertahana': 'tahana',
    'setahap': 'tahap',
    'tahapan': 'tahap',
    'tahapannya': 'tahap',
    'tahapani': 'tahap',
    'tahapanan': 'tahap',
    'bertahap': 'tahap',
    'bertahapnya': 'tahap',
    'bertahaplah': 'tahap',
    'bertahapan': 'tahap',
    'penahapan': 'tahap',
    'penahapannya': 'tahap',
    'menahapkan': 'tahap',
    'bertahar': 'tahar',
    'menaharkan': 'tahar',
    'bertaharah': 'taharah',
    'tahbisan': 'tahbis',
    'penahbisan': 'tahbis',
    'menahbiskan': 'tahbis',
    'menahbiskannya': 'tahbis',
    'ketahiran': 'tahir',
    'penahiran': 'tahir',
    'menahkikkan': 'tahkik',
    'bertahkim': 'tahkim',
    'tahlilan': 'tahlil',
    'menahnik': 'tahnik',
    'penaja': 'taja',
    'penajanya': 'taja',
    'penajaan': 'taja',
    'menaja': 'taja',
    'tajaan': 'taja',
    'kepenajaan': 'taja',
    'bertaji': 'taji',
    'bertajinya': 'taji',
    'menajin': 'tajin',
    'menajinkan': 'tajin',
    'menajuk': 'tajuk',
    'menajukan': 'tajuk',
    'bertajuk-tajuk': 'tajuk',
    'penajur': 'tajur',
    'ketakaburan': 'takabur',
    'menakah': 'takah',
    'takah-takahnya': 'takah',
    'menakak': 'takak',
    'bertakak': 'takak',
    'menakar': 'takar',
    'menakarnya': 'takar',
    'setakar': 'takar',
    'takaran': 'takar',
    'takarannya': 'takar',
    'takaranan': 'takar',
    'penakar': 'takar',
    'penakaran': 'takar',
    'menakari': 'takar',
    'penakarannya': 'takar',
    'takbiran': 'takbir',
    'takbirannya': 'takbir',
    'menakbirkan': 'takbir',
    'penakdisan': 'takdis',
    'menakdiskan': 'takdis',
    'menakhlikkan': 'takhlik',
    'menakhsiskan': 'takhsis',
    'bertakhta': 'takhta',
    'bertakhtalah': 'takhta',
    'bertakhtakan': 'takhta',
    'menakhtakan': 'takhta',
    'menaki': 'taki',
    'bertaki': 'taki',
    'menakjubi': 'takjub',
    'ketakjuban': 'takjub',
    'ketakjubannya': 'takjub',
    'menakjubkan': 'takjub',
    'menakjubkannya': 'takjub',
    'bertaklid': 'taklid',
    'menaklik': 'taklik',
    'bertaklik': 'taklik',
    'taklukan': 'takluk',
    'taklukannya': 'takluk',
    'penakluk': 'takluk',
    'penakluknya': 'takluk',
    'penaklukkan': 'takluk',
    'penaklukkannya': 'takluk',
    'penaklukan': 'takluk',
    'penaklukannya': 'takluk',
    'menaklukkan': 'takluk',
    'menaklukkannya': 'takluk',
    'menaklukkankan': 'takluk',
    'menaklukkanku': 'takluk',
    'menakma': 'takma',
    'menakmakan': 'takma',
    'takmurnian': 'takmurni',
    'menakol': 'takol',
    'ketakrifan': 'takrif',
    'menakrifkan': 'takrif',
    'ketaksaan': 'taksa',
    'menaksikan': 'taksi',
    'menakur': 'takur',
    'menakurkan': 'takur',
    'menakwilkan': 'takwil',
    'bertakziah': 'takziah',
    'menakzimkan': 'takzim',
    'menakzirkan': 'takzir',
    'bertalah-talah': 'talah',
    'menalak': 'talak',
    'menalaknya': 'talak',
    'menalang': 'talang',
    'menalangi': 'talang',
    'penalang': 'talang',
    'penalangan': 'talang',
    'menalanginya': 'talang',
    'bertalaran': 'talar',
    'setali': 'tali',
    'penali': 'tali',
    'penalinya': 'tali',
    'penalii': 'tali',
    'penalian': 'tali',
    'bertali': 'tali',
    'bertalian': 'tali',
    'tali-tali': 'tali',
    'pertalian': 'tali',
    'pertaliannya': 'tali',
    'bertali-tali': 'tali',
    'tali-bertali': 'tali',
    'mempertalikan': 'tali',
    'menalkinkan': 'talkin',
    'bertalu-talu': 'talu',
    'bertalun': 'talun',
    'talun-temalun': 'talun',
    'bertalun-talun': 'talun',
    'bertamadun': 'tamadun',
    'pertamanan': 'taman',
    'pertamanannya': 'taman',
    'pertamananan': 'taman',
    'bertamasya': 'tamasya',
    'tamatan': 'tamat',
    'tamatannya': 'tamat',
    'menamatkan': 'tamat',
    'menamatkannya': 'tamat',
    'menambal': 'tambal',
    'menambalnya': 'tambal',
    'menambalkan': 'tambal',
    'menambali': 'tambal',
    'menambalan': 'tambal',
    'tambalan': 'tambal',
    'tambalannya': 'tambal',
    'penambalan': 'tambal',
    'penambalannya': 'tambal',
    'menambari': 'tambar',
    'tambuhan': 'tambuh',
    'bertambuh': 'tambuh',
    'menambuhkan': 'tambuh',
    'penambul': 'tambul',
    'menambul': 'tambul',
    'bertambul': 'tambul',
    'menambun': 'tambun',
    'tambunan': 'tambun',
    'tambunanan': 'tambun',
    'bertambun': 'tambun',
    'bertambunnya': 'tambun',
    'menambunkan': 'tambun',
    'menambungi': 'tambung',
    'menambus': 'tambus',
    'tertambus': 'tambus',
    'menamengi': 'tameng',
    'menampak': 'tampak',
    'menampakkan': 'tampak',
    'menampakkannya': 'tampak',
    'menampaki': 'tampak',
    'menampakan': 'tampak',
    'tampaknya': 'tampak',
    'tertampak': 'tampak',
    'penampakan': 'tampak',
    'penampakannya': 'tampak',
    'tampak-tampak': 'tampak',
    'menampan': 'tampan',
    'bertampan': 'tampan',
    'mempertampan': 'tampan',
    'penampang': 'tampang',
    'penampangnya': 'tampang',
    'penampangan': 'tampang',
    'menampang': 'tampang',
    'menampangkan': 'tampang',
    'menampar': 'tampar',
    'menamparnya': 'tampar',
    'menamparkan': 'tampar',
    'menampari': 'tampar',
    'menamparku': 'tampar',
    'menamparmu': 'tampar',
    'tamparan': 'tampar',
    'tamparannya': 'tampar',
    'menamparinya': 'tampar',
    'menampariku': 'tampar',
    'bertampar': 'tampar',
    'menampas': 'tampas',
    'menampel': 'tampel',
    'tampian': 'tampi',
    'menampi': 'tampi',
    'menampikan': 'tampik',
    'penampi': 'tampi',
    'penampilah': 'tampi',
    'penampikan': 'tampik',
    'penampian': 'tampi',
    'tampikan': 'tampik',
    'tampikannya': 'tampik',
    'menampik': 'tampik',
    'menampiknya': 'tampik',
    'menampiklah': 'tampik',
    'menampikkan': 'tampik',
    'menampin': 'tampin',
    'bertampin': 'tampin',
    'bertampuk': 'tampuk',
    'tamsilan': 'tamsil',
    'bertamsil': 'tamsil',
    'menamsilkan': 'tamsil',
    'tertamsilkan': 'tamsil',
    'menamu': 'tamu',
    'menamukan': 'tamu',
    'menamui': 'tamu',
    'bertamu': 'tamu',
    'bertamunya': 'tamu',
    'ketamuan': 'tamu',
    'menamyizkan': 'tamyiz',
    'menanai': 'tanai',
    'penanak': 'tanak',
    'menanak': 'tanak',
    'bertanak': 'tanak',
    'sepenanak': 'tanak',
    'sepertanak': 'tanak',
    'mempertanak': 'tanak',
    'mempertanakan': 'tanak',
    'tanak-tanakan': 'tanak',
    'sepenanak nasi': 'tanak',
    'sepertanak nasi': 'tanak',
    'menanang': 'tanang',
    'menanangkan': 'tanang',
    'menanangi': 'tanang',
    'menancang': 'tancang',
    'menancangkan': 'tancang',
    'menancap': 'tancap',
    'menancapnya': 'tancap',
    'menancapkan': 'tancap',
    'menancapkannya': 'tancap',
    'tertancap': 'tancap',
    'tertancapnya': 'tancap',
    'penanda': 'tanda',
    'penandanya': 'tanda',
    'penandaan': 'tanda',
    'bertanda': 'tanda',
    'bertandakan': 'tandak',
    'tertanda': 'tanda',
    'tertandanya': 'tanda',
    'tertandai': 'tanda',
    'menandai': 'tanda',
    'menandainya': 'tanda',
    'menandaikan': 'tanda',
    'pertanda': 'tanda',
    'pertandanya': 'tanda',
    'pertandaan': 'tanda',
    'penandaannya': 'tanda',
    'menandakan': 'tandak',
    'menandakannya': 'tanda',
    'bertanda-tandaan': 'tanda',
    'penandak': 'tandak',
    'menandak': 'tandak',
    'menandakkan': 'tandak',
    'bertandak': 'tandak',
    'setandan': 'tandan',
    'petandang': 'tandang',
    'bertandang': 'tandang',
    'bertandangnya': 'tandang',
    'bertandanglah': 'tandang',
    'bertandangan': 'tandang',
    'menandangi': 'tandang',
    'menanding': 'tanding',
    'menandingnya': 'tanding',
    'menandingkan': 'tanding',
    'menandingkannya': 'tanding',
    'menandingi': 'tanding',
    'menandingan': 'tanding',
    'tandingan': 'tanding',
    'tandingannya': 'tanding',
    'tandinganlah': 'tanding',
    'menandinginya': 'tanding',
    'bertanding': 'tanding',
    'bertandingnya': 'tanding',
    'bertandinglah': 'tanding',
    'bertandingan': 'tanding',
    'pertandingan': 'tanding',
    'pertandingannya': 'tanding',
    'pertandinganlah': 'tanding',
    'pertandinganan': 'tanding',
    'pertandinganku': 'tanding',
    'mempertandingkan': 'tanding',
    'mempertandingkannya': 'tanding',
    'penandusan': 'tandus',
    'menanduskan': 'tandus',
    'penangas': 'tangas',
    'menangas': 'tangas',
    'bertangas': 'tangas',
    'penangasan': 'tangas',
    'setangga': 'tangga',
    'bertangga': 'tangga',
    'penanggah': 'tanggah',
    'penanggahan': 'tanggah',
    'menanggang': 'tanggang',
    'bertanggang': 'tanggang',
    'menanggar': 'tanggar',
    'menanggarkan': 'tanggar',
    'menanggul': 'tanggul',
    'menangguli': 'tanggul',
    'menanggulangi': 'tanggulang',
    'menanggulanginya': 'tanggulang',
    'penanggulangan': 'tanggulang',
    'penanggulangannya': 'tanggulang',
    'penanggulanganan': 'tanggulang',
    'penanggung jawab': 'tanggung jawab',
    'menanggungjawabi': 'tanggung jawab',
    'bertanggung jawab': 'tanggung jawab',
    'pertanggungjawaban': 'tanggung jawab',
    'pertanggungjawabannya': 'tanggung jawab',
    'pertanggungjawabanlah': 'tanggung jawab',
    'pertanggungjawabankan': 'tanggung jawab',
    'pertanggungjawabanan': 'tanggung jawab',
    'mempertanggungjawabkan': 'tanggung jawab',
    'mempertanggungjawabkannya': 'tanggung jawab',
    'penanggung': 'tanggung',
    'penanggungnya': 'tanggung',
    'penanggungan': 'tanggung',
    'menanggung': 'tanggung',
    'menanggungnya': 'tanggung',
    'menanggungkan': 'tanggung',
    'menanggungi': 'tanggung',
    'tanggungan': 'tanggung',
    'tanggungannya': 'tanggung',
    'tanggunganku': 'tanggung',
    'tertanggung': 'tanggung',
    'tertanggungkan': 'tanggung',
    'pertanggungan': 'tanggung',
    'pertanggungannya': 'tanggung',
    'tanggung-tanggung': 'tanggung',
    'mempertanggungkan': 'tanggung',
    'tanggung-menanggung': 'tanggung',
    'tangkahan': 'tangkah',
    'menangkap': 'tangkap',
    'menangkapnya': 'tangkap',
    'menangkapkan': 'tangkap',
    'menangkapi': 'tangkap',
    'menangkapan': 'tangkap',
    'menangkapku': 'tangkap',
    'menangkapmu': 'tangkap',
    'tangkapan': 'tangkap',
    'tangkapannya': 'tangkap',
    'tangkapanku': 'tangkap',
    'penangkap': 'tangkap',
    'penangkapnya': 'tangkap',
    'penangkapkan': 'tangkap',
    'penangkapan': 'tangkap',
    'bertangkap': 'tangkap',
    'tertangkap': 'tangkap',
    'tertangkapnya': 'tangkap',
    'tertangkaplah': 'tangkap',
    'tertangkapkan': 'tangkap',
    'sepenangkap': 'tangkap',
    'sepenangkapan': 'tangkap',
    'ketangkapan': 'tangkap',
    'penangkapannya': 'tangkap',
    'penangkapanan': 'tangkap',
    'penangkapanku': 'tangkap',
    'penangkar': 'tangkar',
    'penangkaran': 'tangkar',
    'penangkarannya': 'tangkar',
    'menangkarkan': 'tangkar',
    'menangkil': 'tangkil',
    'bertangkil-tangkil': 'tangkil',
    'menangkuk': 'tangkuk',
    'menangkul': 'tangkul',
    'setangkup': 'tangkup',
    'menangkup': 'tangkup',
    'menangkupnya': 'tangkup',
    'menangkupkan': 'tangkup',
    'bertangkup': 'tangkup',
    'tertangkup': 'tangkup',
    'menangkuptelentangkan': 'tangkup telentang',
    'menangsel': 'tangsel',
    'menanjul': 'tanjul',
    'menanjuli': 'tanjul',
    'tertanjul': 'tanjul',
    'menanjung': 'tanjung',
    'menanjur': 'tanjur',
    'menanjur-nanjur': 'tanjur',
    'menantang': 'tantang',
    'menantangnya': 'tantang',
    'menantangkan': 'tantang',
    'menantangi': 'tantang',
    'menantangku': 'tantang',
    'menantangmu': 'tantang',
    'penantang': 'tantang',
    'penantangnya': 'tantang',
    'penantangan': 'tantang',
    'tantangan': 'tantang',
    'tantangannya': 'tantang',
    'tantangani': 'tantang',
    'tantanganan': 'tantang',
    'tantanganku': 'tantang',
    'tantanganmu': 'tantang',
    'tertantang': 'tantang',
    'tertantanglah': 'tantang',
    'bertanti': 'tanti',
    'menanwinkan': 'tanwin',
    'menapuk': 'tapuk',
    'menapung': 'tapung',
    'menapungnya': 'tapung',
    'menapus': 'tapus',
    'setaraf': 'taraf',
    'bertaraf': 'taraf',
    'menarafkan': 'taraf',
    'menyetarafkan': 'taraf',
    'bertarak': 'tarak',
    'pertarakan': 'tarak',
    'menarang': 'tarang',
    'petarangan': 'tarang',
    'bertarap': 'tarap',
    'bertarawih': 'tarawih',
    'menarbiahkan': 'tarbiah',
    'penargetan': 'target',
    'penargetannya': 'target',
    'menargetkan': 'target',
    'menargetkannya': 'target',
    'penarifan': 'tarif',
    'menarifkan': 'tarif',
    'menarikhkan': 'tarikh',
    'menaris': 'taris',
    'bertajih': 'tarjih',
    'bertaruk': 'taruk',
    'menarupi': 'tarup',
    'menasak': 'tasak',
    'penasak': 'tasak',
    'menasarufkan': 'tasaruf',
    'bertasawuf': 'tasawuf',
    'bertasbih': 'tasbih',
    'bertasbihlah': 'tasbih',
    'bertasbihkan': 'tasbih',
    'menasdikkan': 'tasdik',
    'penashih': 'tashih',
    'menashih': 'tashih',
    'menashihkan': 'tashih',
    'menasrifkan': 'tasrif',
    'tasyakuran': 'tasyakur',
    'tasyakurannya': 'tasyakur',
    'bertasyakur': 'tasyakur',
    'bertasyhid': 'tasyhid',
    'menasyhidkan': 'tasyhid',
    'menasyrihkan': 'tasyrih',
    'ketatabahasaan': 'tata bahasa',
    'penatagunaan': 'tata guna',
    'penata': 'tata',
    'penatanya': 'tata',
    'penataan': 'tata',
    'menata': 'tata',
    'menatanya': 'tata',
    'menatakan': 'tata',
    'tataan': 'tata',
    'penataannya': 'tata',
    'ketatalaksanaan': 'tata laksana',
    'penatalaksanaan': 'tata laksana',
    'penatalaksanaannya': 'tata laksana',
    'ketatanegaraan': 'tata negara',
    'ketatanegaraannya': 'tata negara',
    'ketataniagaan': 'tata niaga',
    'ketataprajaan': 'tata praja',
    'ketatausahaan': 'tata usaha',
    'bertatai-tatai': 'tatai',
    'tatakan': 'tatak',
    'tatakannya': 'tatak',
    'menataki': 'tatak',
    'tertatal': 'tatal',
    'menatar': 'tatar',
    'penatar': 'tatar',
    'penataran': 'tatar',
    'tataran': 'tatar',
    'tatarannya': 'tatar',
    'petatar': 'tatar',
    'bertatar': 'tatar',
    'penatarannya': 'tatar',
    'menatih': 'tatih',
    'tertatih-tatih': 'tatih',
    'tertatih-tatihnya': 'tatih',
    'bertatih-tatih': 'tatih',
    'menating': 'tating',
    'menato': 'tato',
    'menatonya': 'tato',
    'menauhidkan': 'tauhid',
    'menaul': 'taul',
    'bertauliah': 'tauliah',
    'menauliahkan': 'tauliah',
    'tauran': 'taur',
    'menauri': 'taur',
    'bertawajuh': 'tawajuh',
    'menawaki': 'tawak',
    'menawakkan': 'tawak',
    'bertawakal': 'tawakal',
    'tawanan': 'tawan',
    'tawanannya': 'tawan',
    'tawananan': 'tawan',
    'penawan': 'tawan',
    'penawanan': 'tawan',
    'menawan': 'tawan',
    'menawannya': 'tawan',
    'menawanan': 'tawan',
    'tertawan': 'tawan',
    'bertawan-tawan': 'tawan',
    'tawuran': 'tawur',
    'tawurannya': 'tawur',
    'tawuranlah': 'tawur',
    'bertayamum': 'tayamum',
    'tayuban': 'tayub',
    'tayum-temayum': 'tayum',
    'berteater': 'teater',
    'meneaterkan': 'teater',
    'tebakan': 'tebak',
    'tebakannya': 'tebak',
    'tebakanku': 'tebak',
    'menebak': 'tebak',
    'menebaknya': 'tebak',
    'menebakkan': 'tebak',
    'penebak': 'tebak',
    'penebakan': 'tebak',
    'meneban': 'teban',
    'tebanan': 'teban',
    'menebeng': 'tebeng',
    'menebengnya': 'tebeng',
    'bertebeng': 'tebeng',
    'menebengkan': 'tebeng',
    'menebing': 'tebing',
    'menebok': 'tebok',
    'tebu-tebu': 'tebu',
    'menebu-nebu': 'tebu',
    'bertebu-tebu': 'tebu',
    'bertebu-tebukan': 'tebu',
    'bertedengan': 'tedeng',
    'tedong-tedong': 'tedong',
    'meneduh': 'teduh',
    'meneduhkan': 'teduh',
    'meneduhi': 'teduh',
    'peneduh': 'teduh',
    'peneduhnya': 'teduh',
    'peneduhan': 'teduh',
    'berteduh': 'teduh',
    'berteduhnya': 'teduh',
    'berteduhlah': 'teduh',
    'keteduhan': 'teduh',
    'keteduhannya': 'teduh',
    'perteduhan': 'teduh',
    'perteduhannya': 'teduh',
    'berteduhkan': 'teduh',
    'ketegapan': 'tegap',
    'menegapkan': 'tegap',
    'menegun': 'tegun',
    'bertegun': 'tegun',
    'tertegun': 'tegun',
    'tertegun-tegun': 'tegun',
    'teh-tehan': 'teh',
    'meneja': 'teja',
    'berteka-teki': 'teka teki',
    'peneka': 'tekaan',
    'penekakan': 'tekaan',
    'penekakannya': 'tekaan',
    'menekak': 'tekak',
    'menekakan': 'tekak',
    'bertekak': 'tekak',
    'menekang': 'tekang',
    'menekat': 'tekat',
    'menekati': 'tekat',
    'tekatan': 'tekat',
    'bertekat': 'tekat',
    'bertekatkan': 'tekat',
    'menekek': 'tekek',
    'menekekan': 'tekek',
    'menekel': 'tekel',
    'menekelnya': 'tekel',
    'menekelku': 'tekel',
    'penekelan': 'tekel',
    'meneken': 'teken',
    'menekennya': 'teken',
    'tekenan': 'teken',
    'penekenan': 'teken',
    'meneker': 'teker',
    'tekeran': 'teker',
    'ditekik': 'tekik',
    'menekik': 'tekik',
    'ketekoran': 'tekor',
    'pertekstilan': 'tekstil',
    'bertekstur': 'tekstur',
    'menekuk': 'tekuk',
    'menekuknya': 'tekuk',
    'menekukkan': 'tekuk',
    'menekukan': 'tekuk',
    'tekukan': 'tekuk',
    'bertekuk': 'tekuk',
    'menekur': 'tekur',
    'menekuri': 'tekur',
    'bertekur': 'tekur',
    'menekurkan': 'tekur',
    'pertelaan': 'tela',
    'menelaah': 'telaah',
    'menelaahnya': 'telaah',
    'penelaah': 'telaah',
    'penelaahan': 'telaah',
    'penelaahannya': 'telaah',
    'bertelabat': 'telabat',
    'meneladan': 'teladan',
    'meneladankan': 'teladan',
    'meneladani': 'teladan',
    'meneladaninya': 'teladan',
    'keteladanan': 'teladan',
    'keteladanannya': 'teladan',
    'keteladananan': 'teladan',
    'keteladananmu': 'teladan',
    'bertelang-telang': 'telang',
    'menelangkai': 'telangkai',
    'penelangkaian': 'telangkai',
    'ketelanjuran': 'telanjur',
    'penelantaran': 'telantar',
    'penelantarannya': 'telantar',
    'menelantarkan': 'telantar',
    'menelantarkannya': 'telantar',
    'menelantarkanku': 'telantar',
    'menelap': 'telap',
    'telapakan': 'telapak',
    'petelasan': 'telas',
    'bertelau-telau': 'telau',
    'bertele-tele': 'tele',
    'bertele-telenya': 'tele',
    'bertele-telelah': 'tele',
    'keteledoran': 'teledor',
    'keteledorannya': 'teledor',
    'meneledorkan': 'teledor',
    'menelegram': 'telegram',
    'bertelekan': 'telekan',
    'pertelekomunikasian': 'telekomunikasi',
    'berteleku': 'teleku',
    'setelempap': 'telempap',
    'menelempap': 'telempap',
    'bertelempong': 'telempong',
    'menelentang': 'telentang',
    'menelentangkan': 'telentang',
    'tertelentang': 'telentang',
    'menelepon': 'telepon',
    'meneleponnya': 'telepon',
    'meneleponkan': 'telepon',
    'meneleponi': 'telepon',
    'meneleponku': 'telepon',
    'meneleponmu': 'telepon',
    'bertelepon': 'telepon',
    'berteleponan': 'telepon',
    'bertelepuk': 'telepuk',
    'bertelepukan': 'telepuk',
    'telesan': 'teles',
    'pertelevisian': 'televisi',
    'menelik': 'telik',
    'penelik': 'telik',
    'menelikung': 'telikung',
    'menelikungnya': 'telikung',
    'bertelimpuh': 'telimpuh',
    'menelinga': 'telinga',
    'bertelinga': 'telinga',
    'bertelingkah': 'telingkah',
    'tertelingkung': 'telingkung',
    'meneliti': 'teliti',
    'menelitinya': 'teliti',
    'menelitian': 'teliti',
    'peneliti': 'teliti',
    'penelitinya': 'teliti',
    'penelitikan': 'teliti',
    'penelitii': 'teliti',
    'penelitian': 'teliti',
    'ketelitian': 'teliti',
    'ketelitiannya': 'teliti',
    'ketelitianlah': 'teliti',
    'ketelitianmu': 'teliti',
    'penelitiannya': 'teliti',
    'penelitiani': 'teliti',
    'penelitianku': 'teliti',
    'berteluk': 'teluk',
    'menelus': 'telus',
    'menelusi': 'telus',
    'menelusuk': 'telusuk',
    'menelusuri': 'telusur',
    'menelusurinya': 'telusur',
    'penelusuran': 'telusur',
    'penelusurannya': 'telusur',
    'menelutut': 'telutut',
    'mengetem': 'tem',
    'mengetemkan': 'tem',
    'bertema': 'tema',
    'bertemakan': 'tema',
    'temas-temas': 'temas',
    'menembaga': 'tembaga',
    'pertembakauan': 'tembakau',
    'menembang': 'tembang',
    'menembangnya': 'tembang',
    'menembangkan': 'tembang',
    'penembang': 'tembang',
    'penembangnya': 'tembang',
    'penembangkan': 'tembang',
    'penembangan': 'tembang',
    'menembis': 'tembis',
    'menembok': 'tembok',
    'menemboknya': 'tembok',
    'temeh-temeh': 'temeh',
    'menemin': 'temin',
    'bertemin': 'temin',
    'menempah': 'tempah',
    'tempahan': 'tempah',
    'menempap': 'tempap',
    'setempap': 'tempap',
    'bertempap': 'tempap',
    'setempat': 'tempat',
    'setempatnya': 'tempat',
    'setempatlah': 'tempat',
    'setempati': 'tempat',
    'tempatan': 'tempat',
    'bertempat': 'tempat',
    'bertempatkan': 'tempat',
    'bertempatan': 'tempat',
    'menempati': 'tempat',
    'menempatinya': 'tempat',
    'menempatikan': 'tempat',
    'menempatikannya': 'tempat',
    'menempatii': 'tempat',
    'ketempatan': 'tempat',
    'penempatan': 'tempat',
    'penempatannya': 'tempat',
    'penempatanan': 'tempat',
    'menempatkan': 'tempat',
    'menempatkannya': 'tempat',
    'menempatkankannya': 'tempat',
    'menempatkanku': 'tempat',
    'menempatkanmu': 'tempat',
    'bertempat-tempat': 'tempat',
    'setempat-setempat': 'tempat',
    'menempelak': 'tempelak',
    'menempelakkan': 'tempelak',
    'tempelengan': 'tempeleng',
    'menempeleng': 'tempeleng',
    'menempelengnya': 'tempeleng',
    'bertemperamen': 'temperamen',
    'bertemperasan': 'temperas',
    'bertemperau': 'temperau',
    'bertempiar': 'tempiar',
    'bertempiaran': 'tempiar',
    'menempias': 'tempias',
    'bertempias': 'tempias',
    'tempikan': 'tempik',
    'bertempik': 'tempik',
    'menempikkan': 'tempik',
    'menemplok': 'templok',
    'tempo-tempo': 'tempo',
    'bertempoh': 'tempoh',
    'menempohkan': 'tempoh',
    'menempong': 'tempong',
    'setempuh': 'tempuh',
    'menempuh': 'tempuh',
    'menempuhnya': 'tempuh',
    'menempuhi': 'tempuh',
    'tertempuh': 'tempuh',
    'ketempuhan': 'tempuh',
    'menempuhkan': 'tempuh',
    'bertempuh-tempuh': 'tempuh',
    'menempulingi': 'tempuling',
    'menemudugai': 'temu duga',
    'menemu duga': 'temu duga',
    'bertemu duga': 'temu duga',
    'ketenagakerjaan': 'tenaga kerja',
    'ketenagakerjaannya': 'tenaga kerja',
    'ketenaganukliran': 'tenaga nuklir',
    'ketenaran': 'tenar',
    'ketenarannya': 'tenar',
    'ketenaranku': 'tenar',
    'menenarkan': 'tenar',
    'menendas': 'tendas',
    'menendaskan': 'tendas',
    'bertendensi': 'tendensi',
    'menenderkan': 'tender',
    'menengadah': 'tengadah',
    'menengadahkan': 'tengadah',
    'menengarai': 'tengara',
    'menengarainya': 'tengara',
    'menenggak': 'tenggak',
    'menenggaknya': 'tenggak',
    'menenggakkan': 'tenggak',
    'menenggakan': 'tenggak',
    'tertenggan': 'tenggan',
    'menenggang': 'tenggang',
    'menenggangkan': 'tenggang',
    'tertenggang': 'tenggang',
    'bertenggang': 'tenggang',
    'bertenggangan': 'tenggang',
    'pertenggangan': 'tenggang',
    'mempertenggangkan': 'tenggang',
    'tenggang-menenggang': 'tenggang',
    'bertenggang-tenggangan': 'tenggang',
    'menenggara': 'tenggara',
    'menenggarai': 'tenggara',
    'tenggorokan': 'tenggorok',
    'tenggorokannya': 'tenggorok',
    'tenggorokanku': 'tenggorok',
    'tenggorokanmu': 'tenggorok',
    'menengil': 'tengil',
    'menengkarapkan': 'tengkarap',
    'menengkel': 'tengkel',
    'bertengkelek': 'tengkelek',
    'menengking': 'tengking',
    'tengkingan': 'tengking',
    'bertengking': 'tengking',
    'setengkuk': 'tengkuk',
    'bertengkuluk': 'tengkuluk',
    'menengkurap': 'tengkurap',
    'menengkurapkan': 'tengkurap',
    'menengkurapkannya': 'tengkurap',
    'menengok': 'tengok',
    'menengoknya': 'tengok',
    'menengokkan': 'tengok',
    'menengoki': 'tengok',
    'menengokan': 'tengok',
    'menengokku': 'tengok',
    'menengokmu': 'tengok',
    'tengok-menengok': 'tengok',
    'petenis': 'tenis',
    'petenisnya': 'tenis',
    'bertenjet': 'tenjet',
    'menenok': 'tenok',
    'ketentaraan': 'tentara',
    'ketentaraannya': 'tentara',
    'pertentaraan': 'tentara',
    'menenteng': 'tenteng',
    'menentengnya': 'tenteng',
    'tenunan': 'tenun',
    'tenunannya': 'tenun',
    'penenun': 'tenun',
    'penenunnya': 'tenun',
    'penenunan': 'tenun',
    'menenun': 'tenun',
    'menenunnya': 'tenun',
    'bertenun': 'tenun',
    'pertenunan': 'tenun',
    'penenung': 'tenung',
    'penenungan': 'tenung',
    'tenungan': 'tenung',
    'menenung': 'tenung',
    'bertenung': 'tenung',
    'pertenungan': 'tenung',
    'menepam': 'tepam',
    'menepas': 'tepas',
    'bertepas': 'tepas',
    'menepasi': 'tepas',
    'bertepat guna': 'tepat guna',
    'tepian': 'tepi',
    'tepiannya': 'tepi',
    'bertepi': 'tepi',
    'bertepikan': 'tepi',
    'bertepian': 'tepi',
    'menepikan': 'tepik',
    'menepikannya': 'tepi',
    'mengetepikan': 'tepi',
    'menepik': 'tepik',
    'tepukan': 'tepuk',
    'tepukannya': 'tepuk',
    'menepuk': 'tepuk',
    'menepuknya': 'tepuk',
    'menepukkan': 'tepuk',
    'menepuki': 'tepuk',
    'bertepuk': 'tepuk',
    'menepungtawari': 'tepung tawar',
    'peneral': 'teral',
    'peneralan': 'teral',
    'meneral': 'teral',
    'berterali': 'terali',
    'berteralikan': 'terali',
    'keterampilan': 'terampil',
    'keterampilannya': 'terampil',
    'keterampilanku': 'terampil',
    'menerampilkan': 'terampil',
    'meneran': 'teran',
    'menerankan': 'teran',
    'menerangjelaskan': 'terang jelas',
    'menerap': 'terap',
    'menerapkan': 'terap',
    'menerapkannya': 'terap',
    'menerapi': 'terap',
    'menerapan': 'terap',
    'terapan': 'terap',
    'terapannya': 'terap',
    'penerap': 'terap',
    'penerapnya': 'terap',
    'penerapkan': 'terap',
    'penerapi': 'terap',
    'penerapan': 'terap',
    'berterap': 'terap',
    'penerapannya': 'terap',
    'penerapanan': 'terap',
    'menerapkankannya': 'terap',
    'berteras': 'teras',
    'berteraskan': 'teras',
    'meneratak': 'teratak',
    'meneratap': 'teratap',
    'menerau': 'terau',
    'menerawang': 'terawang',
    'menerawangnya': 'terawang',
    'menerawangkan': 'terawang',
    'menerawangkannya': 'terawang',
    'berterawang': 'terawang',
    'menerbankan': 'terban',
    'penerbit': 'terbit',
    'penerbitnya': 'terbit',
    'penerbitkan': 'terbit',
    'penerbitan': 'terbit',
    'terbitan': 'terbit',
    'terbitannya': 'terbit',
    'penerbitannya': 'terbit',
    'menerbitkan': 'terbit',
    'menerbitkannya': 'terbit',
    'menerikkan': 'terik',
    'menerika': 'terika',
    'berterima kasih': 'terima kasih',
    'menerindili': 'terindil',
    'berteritik': 'teritik',
    'menerjang': 'terjang',
    'menerjangnya': 'terjang',
    'menerjangan': 'terjang',
    'penerjangan': 'terjang',
    'menerjangkan': 'terjang',
    'terjemahan': 'terjemah',
    'terjemahannya': 'terjemah',
    'terjemahanku': 'terjemah',
    'penerjemah': 'terjemah',
    'penerjemahnya': 'terjemah',
    'penerjemahan': 'terjemah',
    'penerjemahku': 'terjemah',
    'penerjemahannya': 'terjemah',
    'penerjemahanan': 'terjemah',
    'menerjemahkan': 'terjemah',
    'menerjemahkannya': 'terjemah',
    'penerjun': 'terjun',
    'penerjunnya': 'terjun',
    'penerjunan': 'terjun',
    'menerjuni': 'terjun',
    'menerjuninya': 'terjun',
    'keterjunan': 'terjun',
    'beterjunan': 'terjun',
    'penerjunannya': 'terjun',
    'menerjunkan': 'terjun',
    'menerjunkannya': 'terjun',
    'menerjunkankan': 'terjun',
    'menerka': 'terka',
    'menerkanya': 'terka',
    'terkaan': 'terka',
    'penerka': 'terka',
    'penerkaan': 'terka',
    'menerkap': 'terkap',
    'beterkup': 'terkup',
    'menerkup': 'terkup',
    'menerkupkan': 'terkup',
    'menerok': 'terok',
    'menerombol': 'terombol',
    'meneropong': 'teropong',
    'meneropongnya': 'teropong',
    'meneropongi': 'teropong',
    'meneror': 'teror',
    'menerornya': 'teror',
    'menerormu': 'teror',
    'terubusan': 'terubus',
    'menerumkan': 'terum',
    'menerungku': 'terungku',
    'menerungkukan': 'terungku',
    'terutama': 'utama',
    'terutamanya': 'utama',
    'terutamakan': 'utama',
    'keutamaan': 'utama',
    'keutamaannya': 'utama',
    'pengutamaan': 'utama',
    'pengutamaannya': 'utama',
    'mengutamakan': 'utama',
    'mengutamakannya': 'utama',
    'mengutamakankan': 'utama',
    'mengetes': 'tes',
    'mengetesnya': 'tes',
    'mengeteskan': 'tes',
    'pengetesan': 'tes',
    'pengetesannya': 'tes',
    'bertesmak': 'tesmak',
    'menetal': 'tetal',
    'ketetalan': 'tetal',
    'menetalkan': 'tetal',
    'penetap': 'tetap',
    'penetapkan': 'tetap',
    'penetapan': 'tetap',
    'menetap': 'tetap',
    'menetapnya': 'tetap',
    'menetaplah': 'tetap',
    'menetapkan': 'tetap',
    'menetapkannya': 'tetap',
    'menetapi': 'tetap',
    'menetapan': 'tetap',
    'menetapikan': 'tetap',
    'penetapannya': 'tetap',
    'penetapanan': 'tetap',
    'ketetapan': 'tetap',
    'ketetapannya': 'tetap',
    'mempertetap': 'tetap',
    'berketetapan': 'tetap',
    'mempertetapkan': 'tetap',
    'menetar': 'tetar',
    'menetes': 'tetes',
    'menetesnya': 'tetes',
    'meneteslah': 'tetes',
    'meneteskan': 'tetes',
    'meneteskannya': 'tetes',
    'menetesi': 'tetes',
    'tetesan': 'tetes',
    'tetesannya': 'tetes',
    'bertetesan': 'tetes',
    'tetua': 'tua',
    'tetuanya': 'tua',
    'menua': 'tua',
    'menuanya': 'tua',
    'menuakan': 'tua',
    'menuaan': 'tua',
    'tertua': 'tua',
    'tertuanya': 'tua',
    'tertuai': 'tua',
    'tertuaku': 'tua',
    'penuaan': 'tua',
    'penuaannya': 'tua',
    'penuaanku': 'tua',
    'ketuaan': 'tua',
    'tua-tua': 'tua',
    'tua-tuaan': 'tua',
    'pengetua': 'tua',
    'bertua-tua': 'tua',
    'ketua-tuaan': 'tua',
    'bertua-tuaan': 'tua',
    'tuang-tuang': 'tetuang',
    'ketewasan': 'tewas',
    'menewaskan': 'tewas',
    'menewaskannya': 'tewas',
    'menewaskankan': 'tewas',
    'menewaskanmu': 'tewas',
    'meniada': 'tiada',
    'meniadakan': 'tiada',
    'meniadakannya': 'tiada',
    'ketiadaan': 'tiada',
    'ketiadaannya': 'tiada',
    'peniadaan': 'tiada',
    'mempertiadakan': 'tiada',
    'meniani': 'tian',
    'bertian': 'tian',
    'meniangpancangi': 'tiang pancang',
    'setiap': 'tiap',
    'setiapnya': 'tiap',
    'meniapkan': 'tiap',
    'tiap-tiap': 'tiap',
    'tiap-tiapnya': 'tiap',
    'menidakkan': 'tidak',
    'setidaknya': 'tidak',
    'setidaknyanya': 'tidak',
    'mempertidak': 'tidak',
    'tidak-tidak': 'tidak',
    'tidak-tidaknya': 'tidak',
    'mempertidakkan': 'tidak',
    'setidak-tidaknya': 'tidak',
    'setidak-tidaknyanya': 'tidak',
    'menigari': 'tigari',
    'menigas': 'tigas',
    'mengetik': 'tik',
    'mengetiknya': 'tik',
    'mengetikkan': 'tik',
    'mengetikkannya': 'tik',
    'pengetik': 'tik',
    'pengetikkan': 'tik',
    'pengetikan': 'tik',
    'tikan': 'tik',
    'ketikan': 'tik',
    'pengetikannya': 'tik',
    'menika-nika': 'tika',
    'menikas': 'tikas',
    'bertikas': 'tikas',
    'menikung': 'tikung',
    'menikungnya': 'tikung',
    'menikus': 'tikus',
    'bertilam': 'tilam',
    'menilang': 'tilang',
    'menilangnya': 'tilang',
    'tertilang': 'tilang',
    'menilap': 'tilap',
    'petilasan': 'tilas',
    'mengetim': 'tim',
    'pengetim': 'tim',
    'pengetiman': 'tim',
    'penimba': 'timba',
    'menimba': 'timba',
    'menimbanya': 'timba',
    'tertimba': 'timba',
    'bertimba': 'timba',
    'penimbaan': 'timba',
    'tertimbakan': 'timba',
    'bertimbakan': 'timba',
    'menimbau': 'timbau',
    'menimbel': 'timbel',
    'menimbrung': 'timbrung',
    'menimbuk': 'timbuk',
    'menimbukkan': 'timbuk',
    'menimbukan': 'timbuk',
    'penimbul': 'timbul',
    'penimbulkan': 'timbul',
    'penimbulan': 'timbul',
    'menimbul': 'timbul',
    'menimbulnya': 'timbul',
    'menimbulkan': 'timbul',
    'menimbulan': 'timbul',
    'menimbulkani': 'timbul',
    'timbunan': 'timbun',
    'timbunannya': 'timbun',
    'menimbun': 'timbun',
    'menimbunnya': 'timbun',
    'menimbunlah': 'timbun',
    'menimbunkan': 'timbun',
    'menimbuni': 'timbun',
    'menimbunan': 'timbun',
    'penimbun': 'timbun',
    'penimbunnya': 'timbun',
    'penimbunan': 'timbun',
    'bertimbun': 'timbun',
    'bertimbunlah': 'timbun',
    'tertimbun': 'timbun',
    'tertimbunnya': 'timbun',
    'tertimbunan': 'timbun',
    'penimbunannya': 'timbun',
    'menimbun-nimbun': 'timbun',
    'bertimbun-timbun': 'timbun',
    'menimpang': 'timpang',
    'ketimpangan': 'timpang',
    'ketimpangannya': 'timpang',
    'menimpangkan': 'timpang',
    'tertimpang-timpang': 'timpang',
    'menimpang-nimpangkan': 'timpang',
    'bertimpas-timpas': 'timpas',
    'bertimpuh': 'timpuh',
    'menimpuk': 'timpuk',
    'menimpuknya': 'timpuk',
    'menimpukkan': 'timpuk',
    'menimpuki': 'timpuk',
    'menimpukinya': 'timpuk',
    'timun-timunan': 'timun',
    'menimur': 'timur',
    'ketimuran': 'timur',
    'ketimurannya': 'timur',
    'menindaklanjuti': 'tindak lanjut',
    'menindaklanjutinya': 'tindak lanjut',
    'menindaklanjutii': 'tindak lanjut',
    'menindan': 'tindan',
    'bertindan': 'tindan',
    'tindasan': 'tindas',
    'penindas': 'tindas',
    'penindasnya': 'tindas',
    'penindasan': 'tindas',
    'penindasmu': 'tindas',
    'menindas': 'tindas',
    'menindasnya': 'tindas',
    'menindasku': 'tindas',
    'tertindas': 'tindas',
    'tertindasnya': 'tindas',
    'penindasannya': 'tindas',
    'ketertindasan': 'tindas',
    'ketertindasannya': 'tindas',
    'ditindih': 'tindih',
    'ditindihi': 'tindih',
    'tindihan': 'tindih',
    'penindih': 'tindih',
    'penindihan': 'tindih',
    'menindih': 'tindih',
    'menindihnya': 'tindih',
    'menindihkan': 'tindih',
    'menindihi': 'tindih',
    'tertindih': 'tindih',
    'bertindih': 'tindih',
    'bertindihan': 'tindih',
    'ketindihan': 'tindih',
    'tindih-menindih': 'tindih',
    'tindih-bertindih': 'tindih',
    'meninggam': 'tinggam',
    'meninggung': 'tinggung',
    'bertinggung': 'tinggung',
    'meningkap': 'tingkap',
    'meningkapkan': 'tingkap',
    'tingkapan': 'tingkap',
    'meningkar': 'tingkar',
    'meningkarnya': 'tingkar',
    'meningkarkan': 'tingkar',
    'tingkeban': 'tingkeb',
    'bertingkrang': 'tingkrang',
    'bertingkuh': 'tingkuh',
    'peninju': 'tinju',
    'peninjuan': 'tinju',
    'meninju': 'tinju',
    'meninjunya': 'tinju',
    'meninjuku': 'tinju',
    'petinju': 'tinju',
    'petinjunya': 'tinju',
    'bertinju': 'tinju',
    'bertinjunya': 'tinju',
    'pertinjuan': 'tinju',
    'meninjukan': 'tinju',
    'tinju-meninju': 'tinju',
    'menintai': 'tinta',
    'meninting': 'tinting',
    'tintingan': 'tinting',
    'menipis': 'tipis',
    'menipisnya': 'tipis',
    'menipislah': 'tipis',
    'menipiskan': 'tipis',
    'menipiskannya': 'tipis',
    'menipisi': 'tipis',
    'menipiskankan': 'tipis',
    'tetirah': 'tirah',
    'petirahan': 'tirah',
    'tirakatan': 'tirakat',
    'bertiras-tiras': 'tiras',
    'tirisan': 'tiris',
    'meniris': 'tiris',
    'menirisnya': 'tiris',
    'meniriskan': 'tiris',
    'meniriskannya': 'tiris',
    'penirisan': 'tiris',
    'menirus': 'tirus',
    'meniruskan': 'tirus',
    'bertitah': 'titah',
    'menitahkan': 'titah',
    'menitahkannya': 'titah',
    'tertitar-titar': 'titar',
    'bertitar-titar': 'titar',
    'menitar-nitarkan': 'titar',
    'bertitel': 'titel',
    'bertitelkan': 'titel',
    'titian': 'titi',
    'meniti': 'titi',
    'menitinya': 'titi',
    'menitip': 'titip',
    'menitipkan': 'titip',
    'menitipkannya': 'titip',
    'menitipi': 'titip',
    'menitipan': 'titip',
    'penitip': 'titip',
    'penitipnya': 'titip',
    'penitipan': 'titip',
    'titipan': 'titip',
    'titipannya': 'titip',
    'titipanlah': 'titip',
    'titipanku': 'titip',
    'titipanmu': 'titip',
    'titipan-mu': 'titip',
    'penitipannya': 'titip',
    'menitipkankan': 'titip',
    'menitir': 'titir',
    'titiran': 'titir',
    'meniup': 'tiup',
    'meniupnya': 'tiup',
    'meniuplah': 'tiup',
    'meniupkan': 'tiup',
    'meniupkannya': 'tiup',
    'tiupan': 'tiup',
    'tiupannya': 'tiup',
    'tertiup': 'tiup',
    'bertiup': 'tiup',
    'bertiupnya': 'tiup',
    'tiup-tiup': 'tiup',
    'meniup-niup': 'tiup',
    'meniup-niupnya': 'tiup',
    'meniup-niupkan': 'tiup',
    'meniwahkan': 'tiwah',
    'bertiwikrama': 'tiwikrama',
    'menobak': 'tobak',
    'bertobak': 'tobak',
    'bertobat': 'tobat',
    'bertobatnya': 'tobat',
    'bertobatlah': 'tobat',
    'pertobatan': 'tobat',
    'pertobatannya': 'tobat',
    'bertoboh-toboh': 'toboh',
    'menodong': 'todong',
    'menodongnya': 'todong',
    'menodongkan': 'todong',
    'menodongkannya': 'todong',
    'menodongku': 'todong',
    'penodong': 'todong',
    'penodongnya': 'todong',
    'penodongan': 'todong',
    'menogan': 'togan',
    'menogelkan': 'togel',
    'bertogok': 'togok',
    'menohok': 'tohok',
    'menohokkan': 'tohok',
    'bertohor': 'tohor',
    'ketohoran': 'tohor',
    'menohorkan': 'tohor',
    'menokak': 'tokak',
    'tokak-takik': 'tokak',
    'bertoko': 'toko',
    'pertokoan': 'toko',
    'pertokoannya': 'toko',
    'menokong': 'tokong',
    'bertolap': 'tolap',
    'menoleh': 'toleh',
    'menolehnya': 'toleh',
    'menolehlah': 'toleh',
    'menolehkan': 'toleh',
    'pertolehan': 'toleh',
    'penolok': 'tolok',
    'penolokan': 'tolok',
    'setolok': 'tolok',
    'menolok': 'tolok',
    'menomang': 'tomang',
    'ketomboian': 'tomboi',
    'menomboki': 'tombok',
    'menombokinya': 'tombok',
    'bertonase': 'tonase',
    'menonggak': 'tonggak',
    'bertonggok': 'tonggok',
    'menonggokkan': 'tonggok',
    'tongkahan': 'tongkah',
    'menongkah': 'tongkah',
    'penongkat': 'tongkat',
    'menongkat': 'tongkat',
    'bertongkat': 'tongkat',
    'menongkatkan': 'tongkat',
    'tongkrongan': 'tongkrong',
    'tongkrongannya': 'tongkrong',
    'menongkrong': 'tongkrong',
    'menongkrongi': 'tongkrong',
    'menongol': 'tongol',
    'menongolkan': 'tongol',
    'menonjok': 'tonjok',
    'menonjoknya': 'tonjok',
    'menonjokkan': 'tonjok',
    'menonjoki': 'tonjok',
    'menonjokan': 'tonjok',
    'mengetop': 'top',
    'menopek': 'topek',
    'bertopi': 'topi',
    'bertopik': 'topik',
    'penopikan': 'topik',
    'menopikkan': 'topik',
    'menorpedo': 'torpedo',
    'mengetos': 'tos',
    'menotal': 'total',
    'menotalkan': 'total',
    'totol-totol': 'totol',
    'totol-totolnya': 'totol',
    'menoyor': 'toyor',
    'menoyornya': 'toyor',
    'mentradisi': 'tradisi',
    'mentradisikan': 'tradisi',
    'mentraktir': 'traktir',
    'mentraktirnya': 'traktir',
    'mentraktirmu': 'traktir',
    'mentraktor': 'traktor',
    'mentransfer': 'transfer',
    'mentransfernya': 'transfer',
    'mentransferkan': 'transfer',
    'mentransformasikan': 'transformasi',
    'mentransformasikannya': 'transformasi',
    'pentranskripsi': 'transkripsi',
    'pentranskripsian': 'transkripsi',
    'mentranskripsikan': 'transkripsi',
    'bertransmigrasi': 'transmigrasi',
    'mentransmigrasikan': 'transmigrasi',
    'mentransmigrasilokalkan': 'transmigrasi lokal',
    'mentransmisikan': 'transmisi',
    'mentransmisikannya': 'transmisi',
    'tertransmisikan': 'transmisi',
    'mentransmutasikan': 'transmutasi',
    'mentransplantasikan': 'transplantasi',
    'mentransplantasikannya': 'transplantasi',
    'mentranspor': 'transpor',
    'mengetren': 'tren',
    'ketrengginasan': 'trengginas',
    'triliunan': 'triliun',
    'pentrompet': 'trompet',
    'mentrompetkan': 'trompet',
    'bertruk-truk': 'truk',
    'menual': 'tual',
    'menuali': 'tual',
    'bertual-tual': 'tual',
    'petualang': 'tualang',
    'petualangnya': 'tualang',
    'petualangan': 'tualang',
    'bertualang': 'tualang',
    'bertualangan': 'tualang',
    'petualangannya': 'tualang',
    'petualanganku': 'tualang',
    'petualanganmu': 'tualang',
    'pertualangan': 'tualang',
    'pertualangannya': 'tualang',
    'bertuan': 'tuan',
    'bertuannya': 'tuan',
    'menuani': 'tuan',
    'pertuanan': 'tuan',
    'menuankan': 'tuan',
    'tuan-tuan': 'tuan',
    'bertuankan': 'tuan',
    'mempertuan': 'tuan',
    'ketuan-tuanan': 'tuan',
    'mempertuankan': 'tuan',
    'menuanrumahi': 'tuan rumah',
    'menuas': 'tuas',
    'menuba': 'tuba',
    'menubai': 'tuba',
    'tuban-tuban': 'tuban',
    'ketubruk': 'tubruk',
    'menubruk': 'tubruk',
    'menubruknya': 'tubruk',
    'menubrukkan': 'tubruk',
    'menubrukan': 'tubruk',
    'menubrukku': 'tubruk',
    'tubrukan': 'tubruk',
    'tubrukannya': 'tubruk',
    'tertubruk': 'tubruk',
    'bertubrukan': 'tubruk',
    'bertubrukannya': 'tubruk',
    'menuding': 'tuding',
    'menudingnya': 'tuding',
    'menudingkan': 'tuding',
    'menudingi': 'tuding',
    'menudingan': 'tuding',
    'tudingan': 'tuding',
    'tudingannya': 'tuding',
    'tudingani': 'tuding',
    'menuding-nuding': 'tuding',
    'menuding-nudingkan': 'tuding',
    'menuduh': 'tuduh',
    'menuduhnya': 'tuduh',
    'menuduhlah': 'tuduh',
    'menuduhkan': 'tuduh',
    'menuduhku': 'tuduh',
    'tuduhan': 'tuduh',
    'tuduhannya': 'tuduh',
    'tuduhanan': 'tuduh',
    'tuduhanku': 'tuduh',
    'penuduh': 'tuduh',
    'penuduhnya': 'tuduh',
    'penuduhan': 'tuduh',
    'tertuduh': 'tuduh',
    'tertuduhnya': 'tuduh',
    'menudung': 'tudung',
    'menudungi': 'tudung',
    'penudung': 'tudung',
    'tertudung': 'tudung',
    'bertudung': 'tudung',
    'penudungan': 'tudung',
    'menudungkan': 'tudung',
    'menugaskaryakan': 'tugas karya',
    'petugas': 'tugas',
    'petugasnya': 'tugas',
    'petugaslah': 'tugas',
    'petugasi': 'tugas',
    'petugasan': 'tugas',
    'bertugas': 'tugas',
    'bertugasnya': 'tugas',
    'bertugaslah': 'tugas',
    'bertugasi': 'tugas',
    'menugasi': 'tugas',
    'menugasinya': 'tugas',
    'penugasan': 'tugas',
    'penugasannya': 'tugas',
    'penugasanku': 'tugas',
    'menugaskan': 'tugas',
    'menugaskannya': 'tugas',
    'tuguran': 'tugur',
    'menuguri': 'tugur',
    'menuil': 'tuil',
    'menuilkan': 'tuil',
    'menujuhbulani': 'tujuh bulan',
    'tujuh bulanan': 'tujuh bulan',
    'menujuh bulan': 'tujuh bulan',
    'menujuh hari': 'tujuh hari',
    'menukai': 'tukai',
    'menukam': 'tukam',
    'menukas': 'tukas',
    'menukasnya': 'tukas',
    'menukaskan': 'tukas',
    'tukasan': 'tukas',
    'menukasi': 'tukas',
    'bertukas-tukas': 'tukas',
    'menukik': 'tukik',
    'menukiknya': 'tukik',
    'menukikkan': 'tukik',
    'bertukuk': 'tukuk',
    'menulahi': 'tulah',
    'ketulahan': 'tulah',
    'menulang': 'tulang',
    'menulangi': 'tulang',
    'tertulang': 'tulang',
    'bertulang': 'tulang',
    'bertulangnya': 'tulang',
    'penulangan': 'tulang',
    'penulangannya': 'tulang',
    'ketulangan': 'tulang',
    'pertulangan': 'tulang',
    'tulang-tulangan': 'tulang',
    'ketulusan': 'tulus',
    'ketulusannya': 'tulus',
    'mengetum': 'tum',
    'menumang': 'tumang',
    'menumangkan': 'tumang',
    'menumis': 'tumis',
    'menumisnya': 'tumis',
    'bertumis': 'tumis',
    'menumisi': 'tumis',
    'tumpahan': 'tumpah',
    'tumpahannya': 'tumpah',
    'menumpahi': 'tumpah',
    'tertumpah': 'tumpah',
    'tertumpahnya': 'tumpah',
    'tertumpahkan': 'tumpah',
    'ketumpahan': 'tumpah',
    'penumpahan': 'tumpah',
    'pertumpahan': 'tumpah',
    'menumpahkan': 'tumpah',
    'menumpahkannya': 'tumpah',
    'menumpah-numpahkan': 'tumpah',
    'setumpak': 'tumpak',
    'bertumpak-tumpak': 'tumpak',
    'menumpangsarikan': 'tumpang sari',
    'ketumpangtindihan': 'tumpang-tindih',
    'bertumpang-tindih': 'tumpang-tindih',
    'menumpat': 'tumpat',
    'tertumpat': 'tumpat',
    'menumpatkan': 'tumpat',
    'tumpengan': 'tumpeng',
    'menumpil': 'tumpil',
    'penumpil': 'tumpil',
    'menumplakkan': 'tumplak',
    'menumpuk': 'tumpuk',
    'menumpuknya': 'tumpuk',
    'menumpukkan': 'tumpuk',
    'menumpuki': 'tumpuk',
    'setumpuk': 'tumpuk',
    'setumpuknya': 'tumpuk',
    'tumpukan': 'tumpuk',
    'tumpukannya': 'tumpuk',
    'tertumpuk': 'tumpuk',
    'tertumpuknya': 'tumpuk',
    'penumpukanan': 'tumpuk',
    'bertumpuk-tumpuk': 'tumpuk',
    'bertumpuk-tumpukan': 'tumpuk',
    'ketumpulan': 'tumpul',
    'ketumpulannya': 'tumpul',
    'menumpulkan': 'tumpul',
    'menumpur': 'tumpur',
    'menumpurkan': 'tumpur',
    'tertumus': 'tumus',
    'tertunam': 'tunam',
    'menunas': 'tunas',
    'bertunas': 'tunas',
    'menunasi': 'tunas',
    'pertunasan': 'tunas',
    'bertundang': 'tundang',
    'bertundangan': 'tundang',
    'menundung': 'tundung',
    'tundungan': 'tundung',
    'menungau': 'tungau',
    'penunggak': 'tunggak',
    'penunggaknya': 'tunggak',
    'penunggakkan': 'tunggak',
    'penunggakan': 'tunggak',
    'menunggak': 'tunggak',
    'menunggaknya': 'tunggak',
    'menunggaklah': 'tunggak',
    'menunggakan': 'tunggak',
    'tunggakan': 'tunggak',
    'tunggakannya': 'tunggak',
    'menunggal': 'tunggal',
    'menunggalkan': 'tunggal',
    'setunggal': 'tunggal',
    'ketunggalan': 'tunggal',
    'ketunggalannya': 'tunggal',
    'menungganglanggangkan': 'tunggang langgang',
    'menunggik': 'tunggik',
    'tertunggik': 'tunggik',
    'menunggikkan': 'tunggik',
    'menungging': 'tungging',
    'menunggingkan': 'tungging',
    'setungging': 'tungging',
    'bersetungging': 'tungging',
    'menunggul': 'tunggul',
    'menunggulkan': 'tunggul',
    'menungguli': 'tunggul',
    'tunggul-tunggul': 'tunggul',
    'menungkai': 'tungkai',
    'penungkul': 'tungkul',
    'penungkulan': 'tungkul',
    'menungkul': 'tungkul',
    'menungkup': 'tungkup',
    'tertungkup': 'tungkup',
    'menungkupkan': 'tungkup',
    'menungkus': 'tungkus',
    'menunjal': 'tunjal',
    'menunjam': 'tunjam',
    'menunjamnya': 'tunjam',
    'ketuntasan': 'tuntas',
    'menuntaskan': 'tuntas',
    'menuntaskannya': 'tuntas',
    'menuntung': 'tuntung',
    'menuntungkan': 'tuntung',
    'menuntungkannya': 'tuntung',
    'setuntung': 'tuntung',
    'tertuntung': 'tuntung',
    'menuntut': 'tuntut',
    'menuntutnya': 'tuntut',
    'menuntutlah': 'tuntut',
    'menuntutkan': 'tuntut',
    'menuntuti': 'tuntut',
    'menuntutan': 'tuntut',
    'menuntutku': 'tuntut',
    'menuntutmu': 'tuntut',
    'penuntut': 'tuntut',
    'penuntutnya': 'tuntut',
    'penuntutan': 'tuntut',
    'tuntutan': 'tuntut',
    'tuntutannya': 'tuntut',
    'tuntutanan': 'tuntut',
    'tuntutanku': 'tuntut',
    'penuntutannya': 'tuntut',
    'menunu': 'tunu',
    'menunukan': 'tunu',
    'tertunu': 'tunu',
    'penunuan': 'tunu',
    'tupai-tupaian': 'tupai',
    'bertura-tura': 'tura',
    'peturasan': 'turas',
    'menurbakan': 'turba',
    'turi-turian': 'turi',
    'menurus': 'turus',
    'menurusnya': 'turus',
    'menuruskan': 'turus',
    'menuruskannya': 'turus',
    'menurusi': 'turus',
    'menusir': 'tusir',
    'bertutu': 'tutu',
    'menutuh': 'tutuh',
    'menutuhkan': 'tutuh',
    'menutuk': 'tutuk',
    'menutukan': 'tutuk',
    'menutuli': 'tutul',
    'menutulkan': 'tutul',
    'tuyuk-tuyuk': 'tuyuk',
    'menguani': 'uan',
    'menguankan': 'uan',
    'menguar': 'uar',
    'menguarnya': 'uar',
    'uar-uar': 'uar',
    'penguaran': 'uar',
    'menguar-uarkan': 'uar-uar',
    'mengubah bentuk': 'ubah bentuk',
    'pengubahbentukan': 'ubah bentuk',
    'mengubang': 'ubang',
    'mengubar': 'ubar',
    'mengubarkan': 'ubar',
    'ubatan': 'ubat',
    'ubek-ubekan': 'ubek',
    'mengubek-ubek': 'ubek',
    'ubel-ubel': 'ubel',
    'uberan': 'uber',
    'penguber': 'uber',
    'menguber': 'uber',
    'penguberan': 'uber',
    'menguber-uber': 'uber',
    'mengubit-ubit': 'ubit',
    'mengubrak-abrik': 'ubrak-abrik',
    'ububan': 'ubub',
    'pengubub': 'ubub',
    'mengububi': 'ubub',
    'pengububan': 'ubub',
    'mengubung': 'ubung',
    'mengubungkan': 'ubung',
    'mengubungkannya': 'ubung',
    'mengubungi': 'ubung',
    'mengubungan': 'ubung',
    'mengucek': 'ucek',
    'menguceknya': 'ucek',
    'mengucek-ucek': 'ucek',
    'mengudak': 'udak',
    'udap-udapan': 'udap',
    'mengudar': 'udar',
    'mengudari': 'udar',
    'pengudaran': 'udar',
    'mengudarkan': 'udar',
    'mengudara': 'udara',
    'mengudaranya': 'udara',
    'mengudarakan': 'udara',
    'mengudarakannya': 'udara',
    'pengudaraan': 'udara',
    'mengudek': 'udek',
    'udutan': 'udut',
    'mengudut': 'udut',
    'pengudut': 'udut',
    'berufuk': 'ufuk',
    'keugaharian': 'ugahari',
    'mengugemi': 'ugem',
    'ugeran': 'uger',
    'menguik': 'uik',
    'menguik-uik': 'uik',
    'menguis-uis': 'uis',
    'ujaran': 'ujar',
    'ujarannya': 'ujar',
    'berujar': 'ujar',
    'ujar-ujar': 'ujar',
    'ujar-ujaran': 'ujar',
    'mengujarkan': 'ujar',
    'berujud': 'ujud',
    'mengujud': 'ujud',
    'mengujudkan': 'ujud',
    'seujung': 'ujung',
    'berujung': 'ujung',
    'berujungnya': 'ujung',
    'berujunglah': 'ujung',
    'berujungan': 'ujung',
    'pengujung': 'ujung',
    'pengujungnya': 'ujung',
    'pengujungan': 'ujung',
    'mengujung': 'ujung',
    'mengujungi': 'ujung',
    'ukupan': 'ukup',
    'berukup': 'ukup',
    'pengukup': 'ukup',
    'perukupan': 'ukup',
    'mengukupi': 'ukup',
    'pengukupan': 'ukup',
    'berulah': 'ulah',
    'ulakan': 'ulak',
    'ulak-ulak': 'ulak',
    'ulaman': 'ulam',
    'berulam': 'ulam',
    'ulam-ulam': 'ulam',
    'berulang kali': 'ulang kali',
    'berulang tahun': 'ulang tahun',
    'berulang-alik': 'ulang-alik',
    'mengular': 'ular',
    'mengularnya': 'ular',
    'mengularkan': 'ular',
    'ular-ularan': 'ular',
    'seulas': 'ulas',
    'ulasan': 'ulas',
    'ulasannya': 'ulas',
    'diulas': 'ulas',
    'diulasnya': 'ulas',
    'diulaskan': 'ulas',
    'diulaskannya': 'ulas',
    'berulas': 'ulas',
    'mengulas': 'ulas',
    'mengulasnya': 'ulas',
    'mengulaskan': 'ulas',
    'mengulaskannya': 'ulas',
    'mengulasi': 'ulas',
    'pengulas': 'ulas',
    'pengulasan': 'ulas',
    'perulasan': 'ulas',
    'mengulas-ulas': 'ulas',
    'ulekan': 'ulek',
    'ulekannya': 'ulek',
    'mengulek': 'ulek',
    'menguleknya': 'ulek',
    'ulek-ulek': 'ulek',
    'pengulekan': 'ulek',
    'uleman': 'ulem',
    'mengulemi': 'ulem',
    'menguleni': 'ulen',
    'mengules': 'ules',
    'keuletan': 'ulet',
    'keuletannya': 'ulet',
    'keuletanlah': 'ulet',
    'mengulik': 'ulik',
    'menguliknya': 'ulik',
    'berulit': 'ulit',
    'mengulitkan': 'ulit',
    'mengulit-ulit': 'ulit',
    'berulos': 'ulos',
    'pengulosan': 'ulos',
    'beruluk salam': 'uluk salam',
    'uluran': 'ulur',
    'terulur': 'ulur',
    'terulurnya': 'ulur',
    'mengulur': 'ulur',
    'mengulurnya': 'ulur',
    'mengulurkan': 'ulur',
    'penguluran': 'ulur',
    'memperulur': 'ulur',
    'mengulur-ulur': 'ulur',
    'mengulur-ulurnya': 'ulur',
    'menguman': 'uman',
    'menguman-uman': 'uman',
    'keumatan': 'umat',
    'keumatannya': 'umat',
    'pengumban': 'umban',
    'terumbang-umbang': 'umbang',
    'terumbang-ambing': 'umbang-ambing',
    'mengumbang-ambingkan': 'umbang-ambing',
    'mengumbar': 'umbar',
    'mengumbarnya': 'umbar',
    'mengumbarkan': 'umbar',
    'pengumbaran': 'umbar',
    'berumbi': 'umbi',
    'umbi-umbian': 'umbi',
    'umbi-umbiannya': 'umbi',
    'umbul-umbul': 'umbul',
    'umbul-umbulnya': 'umbul',
    'mengumbut': 'umbut',
    'berumpak': 'umpak',
    'mengumpak': 'umpak',
    'mengumpakan': 'umpak',
    'pengumpak': 'umpak',
    'mengumpak-umpak': 'umpak',
    'umpatan': 'umpat',
    'umpatannya': 'umpat',
    'pengumpat': 'umpat',
    'mengumpat': 'umpat',
    'mengumpatnya': 'umpat',
    'mengumpati': 'umpat',
    'pengumpatan': 'umpat',
    'umpetan': 'umpet',
    'mengumpet': 'umpet',
    'berumpuk': 'umpuk',
    'berumun': 'umun',
    'mengumun': 'umun',
    'mengumunkan': 'umun',
    'undakan': 'undak',
    'mengundak': 'undak',
    'mengundakan': 'undak',
    'undak-undakan': 'undak',
    'undak-undakannya': 'undak',
    'berundak-undak': 'undak',
    'berundan-undan': 'undan',
    'mengunduh': 'unduh',
    'mengunduhnya': 'unduh',
    'mengunduhkan': 'unduh',
    'memperundungkan': 'undung-undung',
    'berundung-undung': 'undung-undung',
    'mengungam': 'ungam',
    'unggah ungguh': 'unggah',
    'mengunggas': 'unggas',
    'berunggut-unggut': 'unggut',
    'mengungkah': 'ungkah',
    'mengungkat-ungkat': 'ungkat',
    'pengungkil': 'ungkil',
    'pengungkilan': 'ungkil',
    'mengungkil': 'ungkil',
    'ungkulan': 'ungkul',
    'berungkur-ungkuran': 'ungkur',
    'pengungsi': 'ungsi',
    'pengungsinya': 'ungsi',
    'pengungsilah': 'ungsi',
    'pengungsian': 'ungsi',
    'mengungsi': 'ungsi',
    'mengungsinya': 'ungsi',
    'mengungsilah': 'ungsi',
    'mengungsikan': 'ungsi',
    'mengungsikannya': 'ungsi',
    'mengungsian': 'ungsi',
    'pengungsiannya': 'ungsi',
    'keungu-unguan': 'ungu',
    'beruniform': 'uniform',
    'keuniversalan': 'universal',
    'berunjuk rasa': 'unjuk rasa',
    'pengunjuk rasa': 'unjuk rasa',
    'mengunjun': 'unjun',
    'mengunjuni': 'unjun',
    'mengunjungkan': 'unjung',
    'unjuran': 'unjur',
    'belunjur': 'unjur',
    'terunjur': 'unjur',
    'mengunjur': 'unjur',
    'mengunjurkan': 'unjur',
    'mengunjutkan': 'unjut',
    'untaian': 'untai',
    'untaiannya': 'untai',
    'beruntai': 'untai',
    'teruntai': 'untai',
    'menguntai': 'untai',
    'menguntaikannya': 'untai',
    'beruntaian': 'untai',
    'beruntai-untai': 'untai',
    'menguntal': 'untal',
    'seuntil': 'until',
    'menguntil': 'until',
    'menguntir': 'untir',
    'teruntuk': 'untuk',
    'beruntuk': 'untuk',
    'peruntukan': 'untuk',
    'peruntukannya': 'untuk',
    'menguntukkan': 'untuk',
    'memperuntukkan': 'untuk',
    'memperuntukkannya': 'untuk',
    'mengunun': 'unun',
    'berunyai': 'unyai',
    'mengunyai': 'unyai',
    'berunyai-unyai': 'unyai',
    'mengupa-upa': 'upa',
    'upaman': 'upam',
    'terupam': 'upam',
    'mengupam': 'upam',
    'pengupam': 'upam',
    'mengupar': 'upar',
    'menguparkan': 'upar',
    'terupaya': 'upaya',
    'berupaya': 'upaya',
    'berupayanya': 'upaya',
    'berupayalah': 'upaya',
    'berupayakan': 'upaya',
    'pengupayaan': 'upaya',
    'mengupayakan': 'upaya',
    'mengupayakannya': 'upaya',
    'seupaya-upaya': 'upaya',
    'seupaya-upayanya': 'upaya',
    'upih-upih': 'upih',
    'berura-ura': 'ura-ura',
    'mengurah': 'urah',
    'mengurahi': 'urah',
    'urakan': 'urak',
    'urakannya': 'urak',
    'berurap': 'urap',
    'mengurap': 'urap',
    'mengurapi': 'urap',
    'beruras': 'uras',
    'berurasi': 'uras',
    'mengurasikan': 'uras',
    'menguraskan': 'uras',
    'berurat': 'urat',
    'menguri': 'uri',
    'mengurik': 'urik',
    'mengurik-urik': 'urik',
    'berurine': 'urine',
    'uring-uringan': 'uring',
    'uring-uringannya': 'uring',
    'beruris-uris': 'uris',
    'urukan': 'uruk',
    'menguruk': 'uruk',
    'menguruknya': 'uruk',
    'mengurukan': 'uruk',
    'pengurukan': 'uruk',
    'pengurukannya': 'uruk',
    'urunan': 'urun',
    'urunannya': 'urun',
    'urunanan': 'urun',
    'berurung': 'urung',
    'usahkan': 'usah',
    'mengusaki': 'usak',
    'berusali': 'usali',
    'user-useran': 'user-user',
    'usilan': 'usil',
    'mengusil-usil': 'usil',
    'mengusil-usilkan': 'usil',
    'keusrekan': 'usrek',
    'pengusutan': 'usut',
    'pengusutannya': 'usut',
    'mengutak-atik': 'utak-atik',
    'mengutak-atiknya': 'utak-atik',
    'utangan': 'utang',
    'berutang': 'utang',
    'berutangnya': 'utang',
    'berutanglah': 'utang',
    'mengutangi': 'utang',
    'mengutanginya': 'utang',
    'perutangan': 'utang',
    'mengutangkan': 'utang',
    'memperutangi': 'utang',
    'memperutangkan': 'utang',
    'utasan': 'utas',
    'berutas': 'utas',
    'pengutik': 'utik',
    'pengutikan': 'utik',
    'mengutik-utik': 'utik',
    'menguyuh': 'uyuh',
    'menguyuhi': 'uyuh',
    'pervaginaan': 'vagina',
    'bervakansi': 'vakansi',
    'memvaksinasi': 'vaksinasi',
    'memvaksinasinya': 'vaksinasi',
    'memvaksinasikan': 'vaksinasi',
    'kevakuman': 'vakum',
    'pervalasan': 'valas',
    'bervariasi': 'variasi',
    'bervariasinya': 'variasi',
    'memvariasikan': 'variasi',
    'memvariasikannya': 'variasi',
    'memveto': 'veto',
    'memvetonya': 'veto',
    'virus': 'visa',
    'virusnya': 'visa',
    'memvisualkan': 'visual',
    'memvisualkannya': 'visual',
    'memvisualisasikan': 'visualisasi',
    'memvisualisasikannya': 'visualisasi',
    'memvitalkan': 'vital',
    'memvonis': 'vonis',
    'memvonisnya': 'vonis',
    'memvonisku': 'vonis',
    'berwaad': 'waad',
    'mewabah': 'wabah',
    'mewabahnya': 'wabah',
    'mewabahkan': 'wabah',
    'mewabahi': 'wabah',
    'mewadahi': 'wadah',
    'mewadahinya': 'wadah',
    'terwadahi': 'wadah',
    'terwadahinya': 'wadah',
    'berwadahkan': 'wadah',
    'mewahyukan': 'wahyu',
    'berwajah': 'wajah',
    'berwajahkan': 'wajah',
    'perwajahan': 'wajah',
    'perwajahannya': 'wajah',
    'berwakaf': 'wakaf',
    'mewakafkan': 'wakaf',
    'mewakafkannya': 'wakaf',
    'berwakil': 'wakil',
    'berwakilan': 'wakil',
    'mewakili': 'wakil',
    'mewakilinya': 'wakil',
    'mewakilii': 'wakil',
    'mewakiliku': 'wakil',
    'terwakili': 'wakil',
    'terwakilinya': 'wakil',
    'mewakilkan': 'wakil',
    'mewakilkannya': 'wakil',
    'perwakilan': 'wakil',
    'perwakilannya': 'wakil',
    'perwakilani': 'wakil',
    'perwakilanku': 'wakil',
    'keterwakilan': 'wakil',
    'keterwakilannya': 'wakil',
    'sewaktu': 'waktu',
    'berwaktu': 'waktu',
    'pewaktuan': 'waktu',
    'sewaktu-waktu': 'waktu',
    'sewaktu-waktunya': 'waktu',
    'terwalak': 'walak',
    'mewalakkan': 'walak',
    'kewangsaan': 'wangsa',
    'wanita tunasusila': 'kewanitaan',
    'wantahan': 'wantah',
    'mewantek': 'wantek',
    'pewantekan': 'wantek',
    'mewanti-wanti': 'wanti-wanti',
    'mewanti-wantinya': 'wanti-wanti',
    'mewanti-wantikan': 'wanti-wanti',
    'wara-wara': 'wara',
    'pewaralaba': 'waralaba',
    'pewaralabanya': 'waralaba',
    'terwaralaba': 'waralaba',
    'pewaralabaan': 'waralaba',
    'kewargaan': 'warga',
    'kewargaannya': 'warga',
    'kewarganegaraan': 'warga negara',
    'kewarganegaraannya': 'warga negara',
    'kewarganegaraanku': 'warga negara',
    'kewarganegaraanmu': 'warga negara',
    'pewarganegaraan': 'warga negara',
    'mewarganegarakan': 'warga negara',
    'berwari': 'wari',
    'berwarna-warni': 'warna-warni',
    'berwarna-warninya': 'warna-warni',
    'mewarna-warnikan': 'warna-warni',
    'berwarung': 'warung',
    'mewasiti': 'wasit',
    'perwasitan': 'wasit',
    'perwasitannya': 'wasit',
    'kewaskitaan': 'waskita',
    'mewaspadai': 'waspada',
    'mewaspadainya': 'waspada',
    'berwaspada': 'waspada',
    'berwaspadalah': 'waspada',
    'kewaspadaan': 'waspada',
    'kewaspadaannya': 'waspada',
    'kewaspadaanmu': 'waspada',
    'mewaspadakan': 'waspada',
    'berwaswas': 'waswas',
    'pewatas': 'watas',
    'mewatasi': 'watas',
    'berwawanmuka': 'wawanmuka',
    'berwawanrembuk': 'wawanrembuk',
    'mewawas diri': 'wawas diri',
    'mewawas': 'wawas',
    'wawasan': 'wawas',
    'wawasannya': 'wawas',
    'wawasanmu': 'wawas',
    'pewayang': 'wayang',
    'pewayangan': 'wayang',
    'wayangan': 'wayang',
    'wayangannya': 'wayang',
    'mewayangkan': 'wayang',
    'kewedanaan': 'wedana',
    'mewedar': 'wedar',
    'wedaran': 'wedar',
    'wedelan': 'wedel',
    'mewedel': 'wedel',
    'kewedukan': 'weduk',
    'mewejang': 'wejang',
    'wejangan': 'wejang',
    'wejangannya': 'wejang',
    'welasan': 'welas',
    'welingan': 'weling',
    'wewenang': 'wenang',
    'wewenangnya': 'wenang',
    'wewenanglah': 'wenang',
    'wewenangkan': 'wenang',
    'wewenangan': 'wenang',
    'wewenangku': 'wenang',
    'berwenang': 'wenang',
    'berwenangnya': 'wenang',
    'berwenanglah': 'wenang',
    'berwenangkan': 'wenang',
    'berwenangan': 'wenang',
    'kewenangan': 'wenang',
    'kewenangannya': 'wenang',
    'kewenangankan': 'wenang',
    'kewenanganan': 'wenang',
    'kewenanganku': 'wenang',
    'sewenang-wenang': 'wenang',
    'sewenang-wenangnya': 'wenang',
    'sewenang-wenangan': 'wenang',
    'kesewenang-wenangan': 'wenang',
    'kesewenang-wenangannya': 'wenang',
    'kesewenang-wenanganan': 'wenang',
    'wijikan': 'wijik',
    'sewilayah': 'wilayah',
    'sewilayahnya': 'wilayah',
    'mewilayahi': 'wilayah',
    'perwilayahan': 'wilayah',
    'berwindu-windu': 'windu',
    'sewingit': 'wingit',
    'kewiraan': 'wira',
    'berwiraswasta': 'wiraswasta',
    'kewiraswastaan': 'wiraswasta',
    'mewiraswastakan': 'wiraswasta',
    'wiridan': 'wirid',
    'mewiridkan': 'wirid',
    'mewiru': 'wiru',
    'mewirukan': 'wiru',
    'berwiru-wiru': 'wiru',
    'berwisata': 'wisata',
    'berwisatanya': 'wisata',
    'berwisatalah': 'wisata',
    'mewismakan': 'wisma',
    'mewisuda': 'wisuda',
    'mewisudanya': 'wisuda',
    'mewisudakan': 'wisuda',
    'berwudu': 'wudu',
    'mewujud': 'wujud',
    'mewujudnya': 'wujud',
    'mewujudkan': 'wujud',
    'mewujudkannya': 'wujud',
    'mewujudan': 'wujud',
    'terwujud': 'wujud',
    'terwujudnya': 'wujud',
    'terwujudlah': 'wujud',
    'terwujudkan': 'wujud',
    'terwujudkannya': 'wujud',
    'berwujud': 'wujud',
    'pewujudan': 'wujud',
    'pewujudannya': 'wujud',
    'kewujudan': 'wujud',
    'mewujudkankannya': 'wujud',
    'perwujudan': 'wujud',
    'perwujudannya': 'wujud',
    'memperwujudkan': 'wujud',
    'berwukuf': 'wukuf',
    'wulangan': 'wulang',
    'memperyahudikan': 'yahudi',
    'meyakini': 'yakin',
    'meyakininya': 'yakin',
    'keyakinan': 'yakin',
    'keyakinannya': 'yakin',
    'keyakinanlah': 'yakin',
    'keyakinanan': 'yakin',
    'keyakinanku': 'yakin',
    'keyakinanmu': 'yakin',
    'meyakinkan': 'yakin',
    'meyakinkannya': 'yakin',
    'meyakinkankan': 'yakin',
    'meyakinkanku': 'yakin',
    'meyakinkanmu': 'yakin',
    'berkeyakinan': 'yakin',
    'berkeyakinannya': 'yakin',
    'berkeyakinanan': 'yakin',
    'meyakin-yakini': 'yakin',
    'kun fa yakun': 'yakun',
    'yang-yang': 'yang',
    'yang-yangan': 'yang',
    'beryang-yang': 'yang',
    'beryoga': 'yoga',
    'beryogalah': 'yoga',
    'seyogianya': 'yogia',
    'sezarah': 'zarah',
    'menzarah': 'zarah',
    'pezikir': 'zikir',
    'berzikir': 'zikir',
    'berzikirlah': 'zikir',
    'berzikiri': 'zikir',
    'perzonaan': 'zona'
}
