# coding: utf8
from __future__ import unicode_literals


VERBS_IRREG = {
    "abalourdie": ("abalourdir",),
    "abalourdies": ("abalourdir",),
    "abalourdi": ("abalourdir",),
    "abalourdîmes": ("abalourdir",),
    "abalourdira": ("abalourdir",),
    "abalourdiraient": ("abalourdir",),
    "abalourdirai": ("abalourdir",),
    "abalourdirais": ("abalourdir",),
    "abalourdirait": ("abalourdir",),
    "abalourdiras": ("abalourdir",),
    "abalourdirent": ("abalourdir",),
    "abalourdirez": ("abalourdir",),
    "abalourdiriez": ("abalourdir",),
    "abalourdirions": ("abalourdir",),
    "abalourdirons": ("abalourdir",),
    "abalourdiront": ("abalourdir",),
    "abalourdis": ("abalourdir",),
    "abalourdissaient": ("abalourdir",),
    "abalourdissais": ("abalourdir",),
    "abalourdissait": ("abalourdir",),
    "abalourdissant": ("abalourdir",),
    "abalourdissent": ("abalourdir",),
    "abalourdisse": ("abalourdir",),
    "abalourdisses": ("abalourdir",),
    "abalourdissez": ("abalourdir",),
    "abalourdissiez": ("abalourdir",),
    "abalourdissions": ("abalourdir",),
    "abalourdissons": ("abalourdir",),
    "abalourdîtes": ("abalourdir",),
    "abalourdit": ("abalourdir",),
    "abalourdît": ("abalourdir",),
    "abasourdie": ("abasourdir",),
    "abasourdies": ("abasourdir",),
    "abasourdi": ("abasourdir",),
    "abasourdîmes": ("abasourdir",),
    "abasourdira": ("abasourdir",),
    "abasourdiraient": ("abasourdir",),
    "abasourdirai": ("abasourdir",),
    "abasourdirais": ("abasourdir",),
    "abasourdirait": ("abasourdir",),
    "abasourdiras": ("abasourdir",),
    "abasourdirent": ("abasourdir",),
    "abasourdirez": ("abasourdir",),
    "abasourdiriez": ("abasourdir",),
    "abasourdirions": ("abasourdir",),
    "abasourdirons": ("abasourdir",),
    "abasourdiront": ("abasourdir",),
    "abasourdis": ("abasourdir",),
    "abasourdissaient": ("abasourdir",),
    "abasourdissais": ("abasourdir",),
    "abasourdissait": ("abasourdir",),
    "abasourdissant": ("abasourdir",),
    "abasourdissent": ("abasourdir",),
    "abasourdisse": ("abasourdir",),
    "abasourdisses": ("abasourdir",),
    "abasourdissez": ("abasourdir",),
    "abasourdissiez": ("abasourdir",),
    "abasourdissions": ("abasourdir",),
    "abasourdissons": ("abasourdir",),
    "abasourdîtes": ("abasourdir",),
    "abasourdit": ("abasourdir",),
    "abasourdît": ("abasourdir",),
    "abâtardie": ("abâtardir",),
    "abâtardies": ("abâtardir",),
    "abâtardi": ("abâtardir",),
    "abâtardîmes": ("abâtardir",),
    "abâtardira": ("abâtardir",),
    "abâtardiraient": ("abâtardir",),
    "abâtardirai": ("abâtardir",),
    "abâtardirais": ("abâtardir",),
    "abâtardirait": ("abâtardir",),
    "abâtardiras": ("abâtardir",),
    "abâtardirent": ("abâtardir",),
    "abâtardirez": ("abâtardir",),
    "abâtardiriez": ("abâtardir",),
    "abâtardirions": ("abâtardir",),
    "abâtardirons": ("abâtardir",),
    "abâtardiront": ("abâtardir",),
    "abâtardis": ("abâtardir",),
    "abâtardissaient": ("abâtardir",),
    "abâtardissais": ("abâtardir",),
    "abâtardissait": ("abâtardir",),
    "abâtardissant": ("abâtardir",),
    "abâtardissent": ("abâtardir",),
    "abâtardisse": ("abâtardir",),
    "abâtardisses": ("abâtardir",),
    "abâtardissez": ("abâtardir",),
    "abâtardissiez": ("abâtardir",),
    "abâtardissions": ("abâtardir",),
    "abâtardissons": ("abâtardir",),
    "abâtardîtes": ("abâtardir",),
    "abâtardit": ("abâtardir",),
    "abâtardît": ("abâtardir",),
    "abat": ("abattre",),
    "abats": ("abattre",),
    "abattaient": ("abattre",),
    "abattais": ("abattre",),
    "abattait": ("abattre",),
    "abattant": ("abattre",),
    "abattent": ("abattre",),
    "abatte": ("abattre",),
    "abattes": ("abattre",),
    "abattez": ("abattre",),
    "abattiez": ("abattre",),
    "abattîmes": ("abattre",),
    "abattions": ("abattre",),
    "abattirent": ("abattre",),
    "abattis": ("abattre",),
    "abattissent": ("abattre",),
    "abattisses": ("abattre",),
    "abattisse": ("abattre",),
    "abattissiez": ("abattre",),
    "abattissions": ("abattre",),
    "abattîtes": ("abattre",),
    "abattit": ("abattre",),
    "abattît": ("abattre",),
    "abattons": ("abattre",),
    "abattra": ("abattre",),
    "abattraient": ("abattre",),
    "abattrai": ("abattre",),
    "abattrais": ("abattre",),
    "abattrait": ("abattre",),
    "abattras": ("abattre",),
    "abattrez": ("abattre",),
    "abattriez": ("abattre",),
    "abattrions": ("abattre",),
    "abattrons": ("abattre",),
    "abattront": ("abattre",),
    "abattue": ("abattre",),
    "abattues": ("abattre",),
    "abattu": ("abattre",),
    "abattus": ("abattre",),
    "abcédaient": ("abcéder",),
    "abcédai": ("abcéder",),
    "abcédais": ("abcéder",),
    "abcédait": ("abcéder",),
    "abcéda": ("abcéder",),
    "abcédâmes": ("abcéder",),
    "abcédant": ("abcéder",),
    "abcédas": ("abcéder",),
    "abcédassent": ("abcéder",),
    "abcédasses": ("abcéder",),
    "abcédasse": ("abcéder",),
    "abcédassiez": ("abcéder",),
    "abcédassions": ("abcéder",),
    "abcédâtes": ("abcéder",),
    "abcédât": ("abcéder",),
    "abcédé": ("abcéder",),
    "abcèdent": ("abcéder",),
    "abcède": ("abcéder",),
    "abcédera": ("abcéder",),
    "abcéderaient": ("abcéder",),
    "abcéderai": ("abcéder",),
    "abcéderais": ("abcéder",),
    "abcéderait": ("abcéder",),
    "abcéderas": ("abcéder",),
    "abcédèrent": ("abcéder",),
    "abcéderez": ("abcéder",),
    "abcéderiez": ("abcéder",),
    "abcéderions": ("abcéder",),
    "abcéderons": ("abcéder",),
    "abcéderont": ("abcéder",),
    "abcèdes": ("abcéder",),
    "abcédez": ("abcéder",),
    "abcédiez": ("abcéder",),
    "abcédions": ("abcéder",),
    "abcédons": ("abcéder",),
    "abeausi": ("abeausir",),
    "abeausîmes": ("abeausir",),
    "abeausira": ("abeausir",),
    "abeausiraient": ("abeausir",),
    "abeausirai": ("abeausir",),
    "abeausirais": ("abeausir",),
    "abeausirait": ("abeausir",),
    "abeausiras": ("abeausir",),
    "abeausirent": ("abeausir",),
    "abeausirez": ("abeausir",),
    "abeausiriez": ("abeausir",),
    "abeausirions": ("abeausir",),
    "abeausirons": ("abeausir",),
    "abeausiront": ("abeausir",),
    "abeausis": ("abeausir",),
    "abeausissaient": ("abeausir",),
    "abeausissais": ("abeausir",),
    "abeausissait": ("abeausir",),
    "abeausissant": ("abeausir",),
    "abeausissent": ("abeausir",),
    "abeausisse": ("abeausir",),
    "abeausisses": ("abeausir",),
    "abeausissez": ("abeausir",),
    "abeausissiez": ("abeausir",),
    "abeausissions": ("abeausir",),
    "abeausissons": ("abeausir",),
    "abeausîtes": ("abeausir",),
    "abeausit": ("abeausir",),
    "abeausît": ("abeausir",),
    "abéchaient": ("abécher",),
    "abéchai": ("abécher",),
    "abéchais": ("abécher",),
    "abéchait": ("abécher",),
    "abécha": ("abécher",),
    "abéchâmes": ("abécher",),
    "abéchant": ("abécher",),
    "abéchas": ("abécher",),
    "abéchassent": ("abécher",),
    "abéchasses": ("abécher",),
    "abéchasse": ("abécher",),
    "abéchassiez": ("abécher",),
    "abéchassions": ("abécher",),
    "abéchâtes": ("abécher",),
    "abéchât": ("abécher",),
    "abéchée": ("abécher",),
    "abéchées": ("abécher",),
    "abéché": ("abécher",),
    "abèchent": ("abécher",),
    "abèche": ("abécher",),
    "abéchera": ("abécher",),
    "abécheraient": ("abécher",),
    "abécherai": ("abécher",),
    "abécherais": ("abécher",),
    "abécherait": ("abécher",),
    "abécheras": ("abécher",),
    "abéchèrent": ("abécher",),
    "abécherez": ("abécher",),
    "abécheriez": ("abécher",),
    "abécherions": ("abécher",),
    "abécherons": ("abécher",),
    "abécheront": ("abécher",),
    "abéchés": ("abécher",),
    "abèches": ("abécher",),
    "abéchez": ("abécher",),
    "abéchiez": ("abécher",),
    "abéchions": ("abécher",),
    "abéchons": ("abécher",),
    "abéquaient": ("abéquer",),
    "abéquai": ("abéquer",),
    "abéquais": ("abéquer",),
    "abéquait": ("abéquer",),
    "abéqua": ("abéquer",),
    "abéquâmes": ("abéquer",),
    "abéquant": ("abéquer",),
    "abéquas": ("abéquer",),
    "abéquassent": ("abéquer",),
    "abéquasses": ("abéquer",),
    "abéquasse": ("abéquer",),
    "abéquassiez": ("abéquer",),
    "abéquassions": ("abéquer",),
    "abéquâtes": ("abéquer",),
    "abéquât": ("abéquer",),
    "abéquée": ("abéquer",),
    "abéquées": ("abéquer",),
    "abéqué": ("abéquer",),
    "abèquent": ("abéquer",),
    "abèque": ("abéquer",),
    "abéquera": ("abéquer",),
    "abéqueraient": ("abéquer",),
    "abéquerai": ("abéquer",),
    "abéquerais": ("abéquer",),
    "abéquerait": ("abéquer",),
    "abéqueras": ("abéquer",),
    "abéquèrent": ("abéquer",),
    "abéquerez": ("abéquer",),
    "abéqueriez": ("abéquer",),
    "abéquerions": ("abéquer",),
    "abéquerons": ("abéquer",),
    "abéqueront": ("abéquer",),
    "abéqués": ("abéquer",),
    "abèques": ("abéquer",),
    "abéquez": ("abéquer",),
    "abéquiez": ("abéquer",),
    "abéquions": ("abéquer",),
    "abéquons": ("abéquer",),
    "abêtie": ("abêtir",),
    "abêties": ("abêtir",),
    "abêti": ("abêtir",),
    "abêtîmes": ("abêtir",),
    "abêtira": ("abêtir",),
    "abêtiraient": ("abêtir",),
    "abêtirai": ("abêtir",),
    "abêtirais": ("abêtir",),
    "abêtirait": ("abêtir",),
    "abêtiras": ("abêtir",),
    "abêtirent": ("abêtir",),
    "abêtirez": ("abêtir",),
    "abêtiriez": ("abêtir",),
    "abêtirions": ("abêtir",),
    "abêtirons": ("abêtir",),
    "abêtiront": ("abêtir",),
    "abêtis": ("abêtir",),
    "abêtissaient": ("abêtir",),
    "abêtissais": ("abêtir",),
    "abêtissait": ("abêtir",),
    "abêtissant": ("abêtir",),
    "abêtissent": ("abêtir",),
    "abêtisse": ("abêtir",),
    "abêtisses": ("abêtir",),
    "abêtissez": ("abêtir",),
    "abêtissiez": ("abêtir",),
    "abêtissions": ("abêtir",),
    "abêtissons": ("abêtir",),
    "abêtîtes": ("abêtir",),
    "abêtit": ("abêtir",),
    "abêtît": ("abêtir",),
    "abolie": ("abolir",),
    "abolies": ("abolir",),
    "aboli": ("abolir",),
    "abolîmes": ("abolir",),
    "abolira": ("abolir",),
    "aboliraient": ("abolir",),
    "abolirai": ("abolir",),
    "abolirais": ("abolir",),
    "abolirait": ("abolir",),
    "aboliras": ("abolir",),
    "abolirent": ("abolir",),
    "abolirez": ("abolir",),
    "aboliriez": ("abolir",),
    "abolirions": ("abolir",),
    "abolirons": ("abolir",),
    "aboliront": ("abolir",),
    "abolis": ("abolir",),
    "abolissaient": ("abolir",),
    "abolissais": ("abolir",),
    "abolissait": ("abolir",),
    "abolissant": ("abolir",),
    "abolissent": ("abolir",),
    "abolisse": ("abolir",),
    "abolisses": ("abolir",),
    "abolissez": ("abolir",),
    "abolissiez": ("abolir",),
    "abolissions": ("abolir",),
    "abolissons": ("abolir",),
    "abolîtes": ("abolir",),
    "abolit": ("abolir",),
    "abolît": ("abolir",),
    "abonnie": ("abonnir",),
    "abonnies": ("abonnir",),
    "abonni": ("abonnir",),
    "abonnîmes": ("abonnir",),
    "abonnira": ("abonnir",),
    "abonniraient": ("abonnir",),
    "abonnirai": ("abonnir",),
    "abonnirais": ("abonnir",),
    "abonnirait": ("abonnir",),
    "abonniras": ("abonnir",),
    "abonnirent": ("abonnir",),
    "abonnirez": ("abonnir",),
    "abonniriez": ("abonnir",),
    "abonnirions": ("abonnir",),
    "abonnirons": ("abonnir",),
    "abonniront": ("abonnir",),
    "abonnis": ("abonnir",),
    "abonnissaient": ("abonnir",),
    "abonnissais": ("abonnir",),
    "abonnissait": ("abonnir",),
    "abonnissant": ("abonnir",),
    "abonnissent": ("abonnir",),
    "abonnisse": ("abonnir",),
    "abonnisses": ("abonnir",),
    "abonnissez": ("abonnir",),
    "abonnissiez": ("abonnir",),
    "abonnissions": ("abonnir",),
    "abonnissons": ("abonnir",),
    "abonnîtes": ("abonnir",),
    "abonnit": ("abonnir",),
    "abonnît": ("abonnir",),
    "abouti": ("aboutir",),
    "aboutîmes": ("aboutir",),
    "aboutira": ("aboutir",),
    "aboutiraient": ("aboutir",),
    "aboutirai": ("aboutir",),
    "aboutirais": ("aboutir",),
    "aboutirait": ("aboutir",),
    "aboutiras": ("aboutir",),
    "aboutirent": ("aboutir",),
    "aboutirez": ("aboutir",),
    "aboutiriez": ("aboutir",),
    "aboutirions": ("aboutir",),
    "aboutirons": ("aboutir",),
    "aboutiront": ("aboutir",),
    "aboutis": ("aboutir",),
    "aboutissaient": ("aboutir",),
    "aboutissais": ("aboutir",),
    "aboutissait": ("aboutir",),
    "aboutissant": ("aboutir",),
    "aboutissent": ("aboutir",),
    "aboutisse": ("aboutir",),
    "aboutisses": ("aboutir",),
    "aboutissez": ("aboutir",),
    "aboutissiez": ("aboutir",),
    "aboutissions": ("aboutir",),
    "aboutissons": ("aboutir",),
    "aboutîtes": ("aboutir",),
    "aboutit": ("aboutir",),
    "aboutît": ("aboutir",),
    "aboient": ("aboyer",),
    "aboie": ("aboyer",),
    "aboiera": ("aboyer",),
    "aboieraient": ("aboyer",),
    "aboierai": ("aboyer",),
    "aboierais": ("aboyer",),
    "aboierait": ("aboyer",),
    "aboieras": ("aboyer",),
    "aboierez": ("aboyer",),
    "aboieriez": ("aboyer",),
    "aboierions": ("aboyer",),
    "aboierons": ("aboyer",),
    "aboieront": ("aboyer",),
    "aboies": ("aboyer",),
    "aboyaient": ("aboyer",),
    "aboyai": ("aboyer",),
    "aboyais": ("aboyer",),
    "aboyait": ("aboyer",),
    "aboya": ("aboyer",),
    "aboyâmes": ("aboyer",),
    "aboyant": ("aboyer",),
    "aboyas": ("aboyer",),
    "aboyassent": ("aboyer",),
    "aboyasses": ("aboyer",),
    "aboyasse": ("aboyer",),
    "aboyassiez": ("aboyer",),
    "aboyassions": ("aboyer",),
    "aboyâtes": ("aboyer",),
    "aboyât": ("aboyer",),
    "aboyée": ("aboyer",),
    "aboyées": ("aboyer",),
    "aboyé": ("aboyer",),
    "aboyèrent": ("aboyer",),
    "aboyés": ("aboyer",),
    "aboyez": ("aboyer",),
    "aboyiez": ("aboyer",),
    "aboyions": ("aboyer",),
    "aboyons": ("aboyer",),
    "abréagi": ("abréagir",),
    "abréagîmes": ("abréagir",),
    "abréagira": ("abréagir",),
    "abréagiraient": ("abréagir",),
    "abréagirai": ("abréagir",),
    "abréagirais": ("abréagir",),
    "abréagirait": ("abréagir",),
    "abréagiras": ("abréagir",),
    "abréagirent": ("abréagir",),
    "abréagirez": ("abréagir",),
    "abréagiriez": ("abréagir",),
    "abréagirions": ("abréagir",),
    "abréagirons": ("abréagir",),
    "abréagiront": ("abréagir",),
    "abréagis": ("abréagir",),
    "abréagissaient": ("abréagir",),
    "abréagissais": ("abréagir",),
    "abréagissait": ("abréagir",),
    "abréagissant": ("abréagir",),
    "abréagissent": ("abréagir",),
    "abréagisse": ("abréagir",),
    "abréagisses": ("abréagir",),
    "abréagissez": ("abréagir",),
    "abréagissiez": ("abréagir",),
    "abréagissions": ("abréagir",),
    "abréagissons": ("abréagir",),
    "abréagîtes": ("abréagir",),
    "abréagit": ("abréagir",),
    "abréagît": ("abréagir",),
    "abrégeaient": ("abréger",),
    "abrégeai": ("abréger",),
    "abrégeais": ("abréger",),
    "abrégeait": ("abréger",),
    "abrégea": ("abréger",),
    "abrégeâmes": ("abréger",),
    "abrégeant": ("abréger",),
    "abrégeas": ("abréger",),
    "abrégeassent": ("abréger",),
    "abrégeasses": ("abréger",),
    "abrégeasse": ("abréger",),
    "abrégeassiez": ("abréger",),
    "abrégeassions": ("abréger",),
    "abrégeâtes": ("abréger",),
    "abrégeât": ("abréger",),
    "abrégée": ("abréger",),
    "abrégées": ("abréger",),
    "abrégé": ("abréger",),
    "abrègent": ("abréger",),
    "abrégeons": ("abréger",),
    "abrège": ("abréger",),
    "abrégera": ("abréger",),
    "abrégeraient": ("abréger",),
    "abrégerai": ("abréger",),
    "abrégerais": ("abréger",),
    "abrégerait": ("abréger",),
    "abrégeras": ("abréger",),
    "abrégèrent": ("abréger",),
    "abrégerez": ("abréger",),
    "abrégeriez": ("abréger",),
    "abrégerions": ("abréger",),
    "abrégerons": ("abréger",),
    "abrégeront": ("abréger",),
    "abrégés": ("abréger",),
    "abrèges": ("abréger",),
    "abrégez": ("abréger",),
    "abrégiez": ("abréger",),
    "abrégions": ("abréger",),
    "abrogeaient": ("abroger",),
    "abrogeai": ("abroger",),
    "abrogeais": ("abroger",),
    "abrogeait": ("abroger",),
    "abrogea": ("abroger",),
    "abrogeâmes": ("abroger",),
    "abrogeant": ("abroger",),
    "abrogeas": ("abroger",),
    "abrogeassent": ("abroger",),
    "abrogeasses": ("abroger",),
    "abrogeasse": ("abroger",),
    "abrogeassiez": ("abroger",),
    "abrogeassions": ("abroger",),
    "abrogeâtes": ("abroger",),
    "abrogeât": ("abroger",),
    "abrogée": ("abroger",),
    "abrogées": ("abroger",),
    "abrogé": ("abroger",),
    "abrogent": ("abroger",),
    "abrogeons": ("abroger",),
    "abroge": ("abroger",),
    "abrogera": ("abroger",),
    "abrogeraient": ("abroger",),
    "abrogerai": ("abroger",),
    "abrogerais": ("abroger",),
    "abrogerait": ("abroger",),
    "abrogeras": ("abroger",),
    "abrogèrent": ("abroger",),
    "abrogerez": ("abroger",),
    "abrogeriez": ("abroger",),
    "abrogerions": ("abroger",),
    "abrogerons": ("abroger",),
    "abrogeront": ("abroger",),
    "abrogés": ("abroger",),
    "abroges": ("abroger",),
    "abrogez": ("abroger",),
    "abrogiez": ("abroger",),
    "abrogions": ("abroger",),
    "abroutie": ("abroutir",),
    "abrouties": ("abroutir",),
    "abrouti": ("abroutir",),
    "abroutîmes": ("abroutir",),
    "abroutira": ("abroutir",),
    "abroutiraient": ("abroutir",),
    "abroutirai": ("abroutir",),
    "abroutirais": ("abroutir",),
    "abroutirait": ("abroutir",),
    "abroutiras": ("abroutir",),
    "abroutirent": ("abroutir",),
    "abroutirez": ("abroutir",),
    "abroutiriez": ("abroutir",),
    "abroutirions": ("abroutir",),
    "abroutirons": ("abroutir",),
    "abroutiront": ("abroutir",),
    "abroutis": ("abroutir",),
    "abroutissaient": ("abroutir",),
    "abroutissais": ("abroutir",),
    "abroutissait": ("abroutir",),
    "abroutissant": ("abroutir",),
    "abroutissent": ("abroutir",),
    "abroutisse": ("abroutir",),
    "abroutisses": ("abroutir",),
    "abroutissez": ("abroutir",),
    "abroutissiez": ("abroutir",),
    "abroutissions": ("abroutir",),
    "abroutissons": ("abroutir",),
    "abroutîtes": ("abroutir",),
    "abroutit": ("abroutir",),
    "abroutît": ("abroutir",),
    "abrutie": ("abrutir",),
    "abruties": ("abrutir",),
    "abruti": ("abrutir",),
    "abrutîmes": ("abrutir",),
    "abrutira": ("abrutir",),
    "abrutiraient": ("abrutir",),
    "abrutirai": ("abrutir",),
    "abrutirais": ("abrutir",),
    "abrutirait": ("abrutir",),
    "abrutiras": ("abrutir",),
    "abrutirent": ("abrutir",),
    "abrutirez": ("abrutir",),
    "abrutiriez": ("abrutir",),
    "abrutirions": ("abrutir",),
    "abrutirons": ("abrutir",),
    "abrutiront": ("abrutir",),
    "abrutis": ("abrutir",),
    "abrutissaient": ("abrutir",),
    "abrutissais": ("abrutir",),
    "abrutissait": ("abrutir",),
    "abrutissant": ("abrutir",),
    "abrutissent": ("abrutir",),
    "abrutisse": ("abrutir",),
    "abrutisses": ("abrutir",),
    "abrutissez": ("abrutir",),
    "abrutissiez": ("abrutir",),
    "abrutissions": ("abrutir",),
    "abrutissons": ("abrutir",),
    "abrutîtes": ("abrutir",),
    "abrutit": ("abrutir",),
    "abrutît": ("abrutir",),
    "absolûmes": ("absoudre",),
    "absolurent": ("absoudre",),
    "absolus": ("absoudre",),
    "absolussent": ("absoudre",),
    "absolusses": ("absoudre",),
    "absolusse": ("absoudre",),
    "absolussiez": ("absoudre",),
    "absolussions": ("absoudre",),
    "absolûtes": ("absoudre",),
    "absolut": ("absoudre",),
    "absolût": ("absoudre",),
    "absolvaient": ("absoudre",),
    "absolvais": ("absoudre",),
    "absolvait": ("absoudre",),
    "absolvant": ("absoudre",),
    "absolvent": ("absoudre",),
    "absolve": ("absoudre",),
    "absolves": ("absoudre",),
    "absolvez": ("absoudre",),
    "absolviez": ("absoudre",),
    "absolvions": ("absoudre",),
    "absolvons": ("absoudre",),
    "absoudra": ("absoudre",),
    "absoudraient": ("absoudre",),
    "absoudrai": ("absoudre",),
    "absoudrais": ("absoudre",),
    "absoudrait": ("absoudre",),
    "absoudras": ("absoudre",),
    "absoudrez": ("absoudre",),
    "absoudriez": ("absoudre",),
    "absoudrions": ("absoudre",),
    "absoudrons": ("absoudre",),
    "absoudront": ("absoudre",),
    "absous": ("absoudre",),
    "absoute": ("absoudre",),
    "absoutes": ("absoudre",),
    "absout": ("absoudre",),
    "abstenaient": ("abstenir",),
    "abstenais": ("abstenir",),
    "abstenait": ("abstenir",),
    "abstenant": ("abstenir",),
    "abstenez": ("abstenir",),
    "absteniez": ("abstenir",),
    "abstenions": ("abstenir",),
    "abstenons": ("abstenir",),
    "abstenue": ("abstenir",),
    "abstenues": ("abstenir",),
    "abstenu": ("abstenir",),
    "abstenus": ("abstenir",),
    "abstiendra": ("abstenir",),
    "abstiendraient": ("abstenir",),
    "abstiendrai": ("abstenir",),
    "abstiendrais": ("abstenir",),
    "abstiendrait": ("abstenir",),
    "abstiendras": ("abstenir",),
    "abstiendrez": ("abstenir",),
    "abstiendriez": ("abstenir",),
    "abstiendrions": ("abstenir",),
    "abstiendrons": ("abstenir",),
    "abstiendront": ("abstenir",),
    "abstiennent": ("abstenir",),
    "abstienne": ("abstenir",),
    "abstiennes": ("abstenir",),
    "abstiens": ("abstenir",),
    "abstient": ("abstenir",),
    "abstînmes": ("abstenir",),
    "abstinrent": ("abstenir",),
    "abstins": ("abstenir",),
    "abstinssent": ("abstenir",),
    "abstinsses": ("abstenir",),
    "abstinsse": ("abstenir",),
    "abstinssiez": ("abstenir",),
    "abstinssions": ("abstenir",),
    "abstîntes": ("abstenir",),
    "abstint": ("abstenir",),
    "abstînt": ("abstenir",),
    "abstergeaient": ("absterger",),
    "abstergeai": ("absterger",),
    "abstergeais": ("absterger",),
    "abstergeait": ("absterger",),
    "abstergea": ("absterger",),
    "abstergeâmes": ("absterger",),
    "abstergeant": ("absterger",),
    "abstergeas": ("absterger",),
    "abstergeassent": ("absterger",),
    "abstergeasses": ("absterger",),
    "abstergeasse": ("absterger",),
    "abstergeassiez": ("absterger",),
    "abstergeassions": ("absterger",),
    "abstergeâtes": ("absterger",),
    "abstergeât": ("absterger",),
    "abstergée": ("absterger",),
    "abstergées": ("absterger",),
    "abstergé": ("absterger",),
    "abstergent": ("absterger",),
    "abstergeons": ("absterger",),
    "absterge": ("absterger",),
    "abstergera": ("absterger",),
    "abstergeraient": ("absterger",),
    "abstergerai": ("absterger",),
    "abstergerais": ("absterger",),
    "abstergerait": ("absterger",),
    "abstergeras": ("absterger",),
    "abstergèrent": ("absterger",),
    "abstergerez": ("absterger",),
    "abstergeriez": ("absterger",),
    "abstergerions": ("absterger",),
    "abstergerons": ("absterger",),
    "abstergeront": ("absterger",),
    "abstergés": ("absterger",),
    "absterges": ("absterger",),
    "abstergez": ("absterger",),
    "abstergiez": ("absterger",),
    "abstergions": ("absterger",),
    "abstraient": ("abstraire",),
    "abstraie": ("abstraire",),
    "abstraies": ("abstraire",),
    "abstraira": ("abstraire",),
    "abstrairaient": ("abstraire",),
    "abstrairai": ("abstraire",),
    "abstrairais": ("abstraire",),
    "abstrairait": ("abstraire",),
    "abstrairas": ("abstraire",),
    "abstrairez": ("abstraire",),
    "abstrairiez": ("abstraire",),
    "abstrairions": ("abstraire",),
    "abstrairons": ("abstraire",),
    "abstrairont": ("abstraire",),
    "abstrais": ("abstraire",),
    "abstraite": ("abstraire",),
    "abstraites": ("abstraire",),
    "abstrait": ("abstraire",),
    "abstraits": ("abstraire",),
    "abstrayaient": ("abstraire",),
    "abstrayais": ("abstraire",),
    "abstrayait": ("abstraire",),
    "abstrayant": ("abstraire",),
    "abstrayez": ("abstraire",),
    "abstrayiez": ("abstraire",),
    "abstrayions": ("abstraire",),
    "abstrayons": ("abstraire",),
    "accalmie": ("accalmir",),
    "accalmies": ("accalmir",),
    "accalmi": ("accalmir",),
    "accalmîmes": ("accalmir",),
    "accalmira": ("accalmir",),
    "accalmiraient": ("accalmir",),
    "accalmirai": ("accalmir",),
    "accalmirais": ("accalmir",),
    "accalmirait": ("accalmir",),
    "accalmiras": ("accalmir",),
    "accalmirent": ("accalmir",),
    "accalmirez": ("accalmir",),
    "accalmiriez": ("accalmir",),
    "accalmirions": ("accalmir",),
    "accalmirons": ("accalmir",),
    "accalmiront": ("accalmir",),
    "accalmis": ("accalmir",),
    "accalmissaient": ("accalmir",),
    "accalmissais": ("accalmir",),
    "accalmissait": ("accalmir",),
    "accalmissant": ("accalmir",),
    "accalmissent": ("accalmir",),
    "accalmisse": ("accalmir",),
    "accalmisses": ("accalmir",),
    "accalmissez": ("accalmir",),
    "accalmissiez": ("accalmir",),
    "accalmissions": ("accalmir",),
    "accalmissons": ("accalmir",),
    "accalmîtes": ("accalmir",),
    "accalmit": ("accalmir",),
    "accalmît": ("accalmir",),
    "accédaient": ("accéder",),
    "accédai": ("accéder",),
    "accédais": ("accéder",),
    "accédait": ("accéder",),
    "accéda": ("accéder",),
    "accédâmes": ("accéder",),
    "accédant": ("accéder",),
    "accédas": ("accéder",),
    "accédassent": ("accéder",),
    "accédasses": ("accéder",),
    "accédasse": ("accéder",),
    "accédassiez": ("accéder",),
    "accédassions": ("accéder",),
    "accédâtes": ("accéder",),
    "accédât": ("accéder",),
    "accédé": ("accéder",),
    "accèdent": ("accéder",),
    "accède": ("accéder",),
    "accédera": ("accéder",),
    "accéderaient": ("accéder",),
    "accéderai": ("accéder",),
    "accéderais": ("accéder",),
    "accéderait": ("accéder",),
    "accéderas": ("accéder",),
    "accédèrent": ("accéder",),
    "accéderez": ("accéder",),
    "accéderiez": ("accéder",),
    "accéderions": ("accéder",),
    "accéderons": ("accéder",),
    "accéderont": ("accéder",),
    "accèdes": ("accéder",),
    "accédez": ("accéder",),
    "accédiez": ("accéder",),
    "accédions": ("accéder",),
    "accédons": ("accéder",),
    "accéléraient": ("accélérer",),
    "accélérai": ("accélérer",),
    "accélérais": ("accélérer",),
    "accélérait": ("accélérer",),
    "accéléra": ("accélérer",),
    "accélérâmes": ("accélérer",),
    "accélérant": ("accélérer",),
    "accéléras": ("accélérer",),
    "accélérassent": ("accélérer",),
    "accélérasses": ("accélérer",),
    "accélérasse": ("accélérer",),
    "accélérassiez": ("accélérer",),
    "accélérassions": ("accélérer",),
    "accélérâtes": ("accélérer",),
    "accélérât": ("accélérer",),
    "accélérée": ("accélérer",),
    "accélérées": ("accélérer",),
    "accéléré": ("accélérer",),
    "accélèrent": ("accélérer",),
    "accélère": ("accélérer",),
    "accélérera": ("accélérer",),
    "accéléreraient": ("accélérer",),
    "accélérerai": ("accélérer",),
    "accélérerais": ("accélérer",),
    "accélérerait": ("accélérer",),
    "accéléreras": ("accélérer",),
    "accélérèrent": ("accélérer",),
    "accélérerez": ("accélérer",),
    "accéléreriez": ("accélérer",),
    "accélérerions": ("accélérer",),
    "accélérerons": ("accélérer",),
    "accéléreront": ("accélérer",),
    "accélérés": ("accélérer",),
    "accélères": ("accélérer",),
    "accélérez": ("accélérer",),
    "accélériez": ("accélérer",),
    "accélérions": ("accélérer",),
    "accélérons": ("accélérer",),
    "accomplie": ("accomplir",),
    "accomplies": ("accomplir",),
    "accompli": ("accomplir",),
    "accomplîmes": ("accomplir",),
    "accomplira": ("accomplir",),
    "accompliraient": ("accomplir",),
    "accomplirai": ("accomplir",),
    "accomplirais": ("accomplir",),
    "accomplirait": ("accomplir",),
    "accompliras": ("accomplir",),
    "accomplirent": ("accomplir",),
    "accomplirez": ("accomplir",),
    "accompliriez": ("accomplir",),
    "accomplirions": ("accomplir",),
    "accomplirons": ("accomplir",),
    "accompliront": ("accomplir",),
    "accomplis": ("accomplir",),
    "accomplissaient": ("accomplir",),
    "accomplissais": ("accomplir",),
    "accomplissait": ("accomplir",),
    "accomplissant": ("accomplir",),
    "accomplissent": ("accomplir",),
    "accomplisse": ("accomplir",),
    "accomplisses": ("accomplir",),
    "accomplissez": ("accomplir",),
    "accomplissiez": ("accomplir",),
    "accomplissions": ("accomplir",),
    "accomplissons": ("accomplir",),
    "accomplîtes": ("accomplir",),
    "accomplit": ("accomplir",),
    "accomplît": ("accomplir",),
    "accouardie": ("accouardir",),
    "accouardies": ("accouardir",),
    "accouardi": ("accouardir",),
    "accouardîmes": ("accouardir",),
    "accouardira": ("accouardir",),
    "accouardiraient": ("accouardir",),
    "accouardirai": ("accouardir",),
    "accouardirais": ("accouardir",),
    "accouardirait": ("accouardir",),
    "accouardiras": ("accouardir",),
    "accouardirent": ("accouardir",),
    "accouardirez": ("accouardir",),
    "accouardiriez": ("accouardir",),
    "accouardirions": ("accouardir",),
    "accouardirons": ("accouardir",),
    "accouardiront": ("accouardir",),
    "accouardis": ("accouardir",),
    "accouardissaient": ("accouardir",),
    "accouardissais": ("accouardir",),
    "accouardissait": ("accouardir",),
    "accouardissant": ("accouardir",),
    "accouardissent": ("accouardir",),
    "accouardisse": ("accouardir",),
    "accouardisses": ("accouardir",),
    "accouardissez": ("accouardir",),
    "accouardissiez": ("accouardir",),
    "accouardissions": ("accouardir",),
    "accouardissons": ("accouardir",),
    "accouardîtes": ("accouardir",),
    "accouardit": ("accouardir",),
    "accouardît": ("accouardir",),
    "accourcie": ("accourcir",),
    "accourcies": ("accourcir",),
    "accourci": ("accourcir",),
    "accourcîmes": ("accourcir",),
    "accourcira": ("accourcir",),
    "accourciraient": ("accourcir",),
    "accourcirai": ("accourcir",),
    "accourcirais": ("accourcir",),
    "accourcirait": ("accourcir",),
    "accourciras": ("accourcir",),
    "accourcirent": ("accourcir",),
    "accourcirez": ("accourcir",),
    "accourciriez": ("accourcir",),
    "accourcirions": ("accourcir",),
    "accourcirons": ("accourcir",),
    "accourciront": ("accourcir",),
    "accourcis": ("accourcir",),
    "accourcissaient": ("accourcir",),
    "accourcissais": ("accourcir",),
    "accourcissait": ("accourcir",),
    "accourcissant": ("accourcir",),
    "accourcissent": ("accourcir",),
    "accourcisse": ("accourcir",),
    "accourcisses": ("accourcir",),
    "accourcissez": ("accourcir",),
    "accourcissiez": ("accourcir",),
    "accourcissions": ("accourcir",),
    "accourcissons": ("accourcir",),
    "accourcîtes": ("accourcir",),
    "accourcit": ("accourcir",),
    "accourcît": ("accourcir",),
    "accouraient": ("accourir",),
    "accourais": ("accourir",),
    "accourait": ("accourir",),
    "accourant": ("accourir",),
    "accourent": ("accourir",),
    "accoure": ("accourir",),
    "accoures": ("accourir",),
    "accourez": ("accourir",),
    "accouriez": ("accourir",),
    "accourions": ("accourir",),
    "accourons": ("accourir",),
    "accourra": ("accourir",),
    "accourraient": ("accourir",),
    "accourrai": ("accourir",),
    "accourrais": ("accourir",),
    "accourrait": ("accourir",),
    "accourras": ("accourir",),
    "accourrez": ("accourir",),
    "accourriez": ("accourir",),
    "accourrions": ("accourir",),
    "accourrons": ("accourir",),
    "accourront": ("accourir",),
    "accours": ("accourir",),
    "accourt": ("accourir",),
    "accourue": ("accourir",),
    "accourues": ("accourir",),
    "accouru": ("accourir",),
    "accourûmes": ("accourir",),
    "accoururent": ("accourir",),
    "accourus": ("accourir",),
    "accourussent": ("accourir",),
    "accourusses": ("accourir",),
    "accourusse": ("accourir",),
    "accourussiez": ("accourir",),
    "accourussions": ("accourir",),
    "accourûtes": ("accourir",),
    "accourut": ("accourir",),
    "accourût": ("accourir",),
    "accrois": ("accroître",),
    "accroissaient": ("accroître",),
    "accroissais": ("accroître",),
    "accroissait": ("accroître",),
    "accroissant": ("accroître",),
    "accroissent": ("accroître",),
    "accroisse": ("accroître",),
    "accroisses": ("accroître",),
    "accroissez": ("accroître",),
    "accroissiez": ("accroître",),
    "accroissions": ("accroître",),
    "accroissons": ("accroître",),
    "accroît": ("accroître",),
    "accroîtra": ("accroître",),
    "accroîtraient": ("accroître",),
    "accroîtrai": ("accroître",),
    "accroîtrais": ("accroître",),
    "accroîtrait": ("accroître",),
    "accroîtras": ("accroître",),
    "accroîtrez": ("accroître",),
    "accroîtriez": ("accroître",),
    "accroîtrions": ("accroître",),
    "accroîtrons": ("accroître",),
    "accroîtront": ("accroître",),
    "accrue": ("accroître",),
    "accrues": ("accroître",),
    "accru": ("accroître",),
    "accrûmes": ("accroître",),
    "accrurent": ("accroître",),
    "accrus": ("accroître",),
    "accrussent": ("accroître",),
    "accrusses": ("accroître",),
    "accrusse": ("accroître",),
    "accrussiez": ("accroître",),
    "accrussions": ("accroître",),
    "accrûtes": ("accroître",),
    "accrut": ("accroître",),
    "accrût": ("accroître",),
    "accroupie": ("accroupir",),
    "accroupies": ("accroupir",),
    "accroupi": ("accroupir",),
    "accroupîmes": ("accroupir",),
    "accroupira": ("accroupir",),
    "accroupiraient": ("accroupir",),
    "accroupirai": ("accroupir",),
    "accroupirais": ("accroupir",),
    "accroupirait": ("accroupir",),
    "accroupiras": ("accroupir",),
    "accroupirent": ("accroupir",),
    "accroupirez": ("accroupir",),
    "accroupiriez": ("accroupir",),
    "accroupirions": ("accroupir",),
    "accroupirons": ("accroupir",),
    "accroupiront": ("accroupir",),
    "accroupis": ("accroupir",),
    "accroupissaient": ("accroupir",),
    "accroupissais": ("accroupir",),
    "accroupissait": ("accroupir",),
    "accroupissant": ("accroupir",),
    "accroupissent": ("accroupir",),
    "accroupisse": ("accroupir",),
    "accroupisses": ("accroupir",),
    "accroupissez": ("accroupir",),
    "accroupissiez": ("accroupir",),
    "accroupissions": ("accroupir",),
    "accroupissons": ("accroupir",),
    "accroupîtes": ("accroupir",),
    "accroupit": ("accroupir",),
    "accroupît": ("accroupir",),
    "accueillaient": ("accueillir",),
    "accueillais": ("accueillir",),
    "accueillait": ("accueillir",),
    "accueillant": ("accueillir",),
    "accueillent": ("accueillir",),
    "accueille": ("accueillir",),
    "accueillera": ("accueillir",),
    "accueilleraient": ("accueillir",),
    "accueillerai": ("accueillir",),
    "accueillerais": ("accueillir",),
    "accueillerait": ("accueillir",),
    "accueilleras": ("accueillir",),
    "accueillerez": ("accueillir",),
    "accueilleriez": ("accueillir",),
    "accueillerions": ("accueillir",),
    "accueillerons": ("accueillir",),
    "accueilleront": ("accueillir",),
    "accueilles": ("accueillir",),
    "accueillez": ("accueillir",),
    "accueillie": ("accueillir",),
    "accueillies": ("accueillir",),
    "accueilliez": ("accueillir",),
    "accueilli": ("accueillir",),
    "accueillîmes": ("accueillir",),
    "accueillions": ("accueillir",),
    "accueillirent": ("accueillir",),
    "accueillis": ("accueillir",),
    "accueillissent": ("accueillir",),
    "accueillisses": ("accueillir",),
    "accueillisse": ("accueillir",),
    "accueillissiez": ("accueillir",),
    "accueillissions": ("accueillir",),
    "accueillîtes": ("accueillir",),
    "accueillit": ("accueillir",),
    "accueillît": ("accueillir",),
    "accueillons": ("accueillir",),
    "acéraient": ("acérer",),
    "acérai": ("acérer",),
    "acérais": ("acérer",),
    "acérait": ("acérer",),
    "acéra": ("acérer",),
    "acérâmes": ("acérer",),
    "acérant": ("acérer",),
    "acéras": ("acérer",),
    "acérassent": ("acérer",),
    "acérasses": ("acérer",),
    "acérasse": ("acérer",),
    "acérassiez": ("acérer",),
    "acérassions": ("acérer",),
    "acérâtes": ("acérer",),
    "acérât": ("acérer",),
    "acérée": ("acérer",),
    "acérées": ("acérer",),
    "acéré": ("acérer",),
    "acèrent": ("acérer",),
    "acère": ("acérer",),
    "acérera": ("acérer",),
    "acéreraient": ("acérer",),
    "acérerai": ("acérer",),
    "acérerais": ("acérer",),
    "acérerait": ("acérer",),
    "acéreras": ("acérer",),
    "acérèrent": ("acérer",),
    "acérerez": ("acérer",),
    "acéreriez": ("acérer",),
    "acérerions": ("acérer",),
    "acérerons": ("acérer",),
    "acéreront": ("acérer",),
    "acérés": ("acérer",),
    "acères": ("acérer",),
    "acérez": ("acérer",),
    "acériez": ("acérer",),
    "acérions": ("acérer",),
    "acérons": ("acérer",),
    "acétifiaient": ("acétifier",),
    "acétifiai": ("acétifier",),
    "acétifiais": ("acétifier",),
    "acétifiait": ("acétifier",),
    "acétifia": ("acétifier",),
    "acétifiâmes": ("acétifier",),
    "acétifiant": ("acétifier",),
    "acétifias": ("acétifier",),
    "acétifiassent": ("acétifier",),
    "acétifiasses": ("acétifier",),
    "acétifiasse": ("acétifier",),
    "acétifiassiez": ("acétifier",),
    "acétifiassions": ("acétifier",),
    "acétifiâtes": ("acétifier",),
    "acétifiât": ("acétifier",),
    "acétifiée": ("acétifier",),
    "acétifiées": ("acétifier",),
    "acétifié": ("acétifier",),
    "acétifient": ("acétifier",),
    "acétifie": ("acétifier",),
    "acétifiera": ("acétifier",),
    "acétifieraient": ("acétifier",),
    "acétifierai": ("acétifier",),
    "acétifierais": ("acétifier",),
    "acétifierait": ("acétifier",),
    "acétifieras": ("acétifier",),
    "acétifièrent": ("acétifier",),
    "acétifierez": ("acétifier",),
    "acétifieriez": ("acétifier",),
    "acétifierions": ("acétifier",),
    "acétifierons": ("acétifier",),
    "acétifieront": ("acétifier",),
    "acétifiés": ("acétifier",),
    "acétifies": ("acétifier",),
    "acétifiez": ("acétifier",),
    "acétifiiez": ("acétifier",),
    "acétifiions": ("acétifier",),
    "acétifions": ("acétifier",),
    "achetaient": ("acheter",),
    "achetai": ("acheter",),
    "achetais": ("acheter",),
    "achetait": ("acheter",),
    "acheta": ("acheter",),
    "achetâmes": ("acheter",),
    "achetant": ("acheter",),
    "achetas": ("acheter",),
    "achetassent": ("acheter",),
    "achetasses": ("acheter",),
    "achetasse": ("acheter",),
    "achetassiez": ("acheter",),
    "achetassions": ("acheter",),
    "achetâtes": ("acheter",),
    "achetât": ("acheter",),
    "achetée": ("acheter",),
    "achetées": ("acheter",),
    "acheté": ("acheter",),
    "achètent": ("acheter",),
    "achète": ("acheter",),
    "achètera": ("acheter",),
    "achèteraient": ("acheter",),
    "achèterai": ("acheter",),
    "achèterais": ("acheter",),
    "achèterait": ("acheter",),
    "achèteras": ("acheter",),
    "achetèrent": ("acheter",),
    "achèterez": ("acheter",),
    "achèteriez": ("acheter",),
    "achèterions": ("acheter",),
    "achèterons": ("acheter",),
    "achèteront": ("acheter",),
    "achetés": ("acheter",),
    "achètes": ("acheter",),
    "achetez": ("acheter",),
    "achetiez": ("acheter",),
    "achetions": ("acheter",),
    "achetons": ("acheter",),
    "achevaient": ("achever",),
    "achevai": ("achever",),
    "achevais": ("achever",),
    "achevait": ("achever",),
    "acheva": ("achever",),
    "achevâmes": ("achever",),
    "achevant": ("achever",),
    "achevas": ("achever",),
    "achevassent": ("achever",),
    "achevasses": ("achever",),
    "achevasse": ("achever",),
    "achevassiez": ("achever",),
    "achevassions": ("achever",),
    "achevâtes": ("achever",),
    "achevât": ("achever",),
    "achevée": ("achever",),
    "achevées": ("achever",),
    "achevé": ("achever",),
    "achèvent": ("achever",),
    "achève": ("achever",),
    "achèvera": ("achever",),
    "achèveraient": ("achever",),
    "achèverai": ("achever",),
    "achèverais": ("achever",),
    "achèverait": ("achever",),
    "achèveras": ("achever",),
    "achevèrent": ("achever",),
    "achèverez": ("achever",),
    "achèveriez": ("achever",),
    "achèverions": ("achever",),
    "achèverons": ("achever",),
    "achèveront": ("achever",),
    "achevés": ("achever",),
    "achèves": ("achever",),
    "achevez": ("achever",),
    "acheviez": ("achever",),
    "achevions": ("achever",),
    "achevons": ("achever",),
    "acidifiaient": ("acidifier",),
    "acidifiai": ("acidifier",),
    "acidifiais": ("acidifier",),
    "acidifiait": ("acidifier",),
    "acidifia": ("acidifier",),
    "acidifiâmes": ("acidifier",),
    "acidifiant": ("acidifier",),
    "acidifias": ("acidifier",),
    "acidifiassent": ("acidifier",),
    "acidifiasses": ("acidifier",),
    "acidifiasse": ("acidifier",),
    "acidifiassiez": ("acidifier",),
    "acidifiassions": ("acidifier",),
    "acidifiâtes": ("acidifier",),
    "acidifiât": ("acidifier",),
    "acidifiée": ("acidifier",),
    "acidifiées": ("acidifier",),
    "acidifié": ("acidifier",),
    "acidifient": ("acidifier",),
    "acidifie": ("acidifier",),
    "acidifiera": ("acidifier",),
    "acidifieraient": ("acidifier",),
    "acidifierai": ("acidifier",),
    "acidifierais": ("acidifier",),
    "acidifierait": ("acidifier",),
    "acidifieras": ("acidifier",),
    "acidifièrent": ("acidifier",),
    "acidifierez": ("acidifier",),
    "acidifieriez": ("acidifier",),
    "acidifierions": ("acidifier",),
    "acidifierons": ("acidifier",),
    "acidifieront": ("acidifier",),
    "acidifiés": ("acidifier",),
    "acidifies": ("acidifier",),
    "acidifiez": ("acidifier",),
    "acidifiiez": ("acidifier",),
    "acidifiions": ("acidifier",),
    "acidifions": ("acidifier",),
    "aciéraient": ("aciérer",),
    "aciérai": ("aciérer",),
    "aciérais": ("aciérer",),
    "aciérait": ("aciérer",),
    "aciéra": ("aciérer",),
    "aciérâmes": ("aciérer",),
    "aciérant": ("aciérer",),
    "aciéras": ("aciérer",),
    "aciérassent": ("aciérer",),
    "aciérasses": ("aciérer",),
    "aciérasse": ("aciérer",),
    "aciérassiez": ("aciérer",),
    "aciérassions": ("aciérer",),
    "aciérâtes": ("aciérer",),
    "aciérât": ("aciérer",),
    "aciérée": ("aciérer",),
    "aciérées": ("aciérer",),
    "aciéré": ("aciérer",),
    "acièrent": ("aciérer",),
    "acière": ("aciérer",),
    "aciérera": ("aciérer",),
    "aciéreraient": ("aciérer",),
    "aciérerai": ("aciérer",),
    "aciérerais": ("aciérer",),
    "aciérerait": ("aciérer",),
    "aciéreras": ("aciérer",),
    "aciérèrent": ("aciérer",),
    "aciérerez": ("aciérer",),
    "aciéreriez": ("aciérer",),
    "aciérerions": ("aciérer",),
    "aciérerons": ("aciérer",),
    "aciéreront": ("aciérer",),
    "aciérés": ("aciérer",),
    "acières": ("aciérer",),
    "aciérez": ("aciérer",),
    "aciériez": ("aciérer",),
    "aciérions": ("aciérer",),
    "aciérons": ("aciérer",),
    "aciselaient": ("aciseler",),
    "aciselai": ("aciseler",),
    "aciselais": ("aciseler",),
    "aciselait": ("aciseler",),
    "acisela": ("aciseler",),
    "aciselâmes": ("aciseler",),
    "aciselant": ("aciseler",),
    "aciselas": ("aciseler",),
    "aciselassent": ("aciseler",),
    "aciselasses": ("aciseler",),
    "aciselasse": ("aciseler",),
    "aciselassiez": ("aciseler",),
    "aciselassions": ("aciseler",),
    "aciselâtes": ("aciseler",),
    "aciselât": ("aciseler",),
    "aciselée": ("aciseler",),
    "aciselées": ("aciseler",),
    "aciselé": ("aciseler",),
    "acisèlent": ("aciseler",),
    "acisèle": ("aciseler",),
    "acisèlera": ("aciseler",),
    "acisèleraient": ("aciseler",),
    "acisèlerai": ("aciseler",),
    "acisèlerais": ("aciseler",),
    "acisèlerait": ("aciseler",),
    "acisèleras": ("aciseler",),
    "aciselèrent": ("aciseler",),
    "acisèlerez": ("aciseler",),
    "acisèleriez": ("aciseler",),
    "acisèlerions": ("aciseler",),
    "acisèlerons": ("aciseler",),
    "acisèleront": ("aciseler",),
    "aciselés": ("aciseler",),
    "acisèles": ("aciseler",),
    "aciselez": ("aciseler",),
    "aciseliez": ("aciseler",),
    "aciselions": ("aciseler",),
    "aciselons": ("aciseler",),
    "acquéraient": ("acquérir",),
    "acquérais": ("acquérir",),
    "acquérait": ("acquérir",),
    "acquérant": ("acquérir",),
    "acquérez": ("acquérir",),
    "acquériez": ("acquérir",),
    "acquérions": ("acquérir",),
    "acquérons": ("acquérir",),
    "acquerra": ("acquérir",),
    "acquerraient": ("acquérir",),
    "acquerrai": ("acquérir",),
    "acquerrais": ("acquérir",),
    "acquerrait": ("acquérir",),
    "acquerras": ("acquérir",),
    "acquerrez": ("acquérir",),
    "acquerriez": ("acquérir",),
    "acquerrions": ("acquérir",),
    "acquerrons": ("acquérir",),
    "acquerront": ("acquérir",),
    "acquièrent": ("acquérir",),
    "acquière": ("acquérir",),
    "acquières": ("acquérir",),
    "acquiers": ("acquérir",),
    "acquiert": ("acquérir",),
    "acquîmes": ("acquérir",),
    "acquirent": ("acquérir",),
    "acquise": ("acquérir",),
    "acquises": ("acquérir",),
    "acquis": ("acquérir",),
    "acquissent": ("acquérir",),
    "acquisses": ("acquérir",),
    "acquisse": ("acquérir",),
    "acquissiez": ("acquérir",),
    "acquissions": ("acquérir",),
    "acquîtes": ("acquérir",),
    "acquit": ("acquérir",),
    "acquît": ("acquérir",),
    "acquiesçaient": ("acquiescer",),
    "acquiesçai": ("acquiescer",),
    "acquiesçais": ("acquiescer",),
    "acquiesçait": ("acquiescer",),
    "acquiesça": ("acquiescer",),
    "acquiesçâmes": ("acquiescer",),
    "acquiesçant": ("acquiescer",),
    "acquiesças": ("acquiescer",),
    "acquiesçassent": ("acquiescer",),
    "acquiesçasses": ("acquiescer",),
    "acquiesçasse": ("acquiescer",),
    "acquiesçassiez": ("acquiescer",),
    "acquiesçassions": ("acquiescer",),
    "acquiesçâtes": ("acquiescer",),
    "acquiesçât": ("acquiescer",),
    "acquiescé": ("acquiescer",),
    "acquiescent": ("acquiescer",),
    "acquiesce": ("acquiescer",),
    "acquiescera": ("acquiescer",),
    "acquiesceraient": ("acquiescer",),
    "acquiescerai": ("acquiescer",),
    "acquiescerais": ("acquiescer",),
    "acquiescerait": ("acquiescer",),
    "acquiesceras": ("acquiescer",),
    "acquiescèrent": ("acquiescer",),
    "acquiescerez": ("acquiescer",),
    "acquiesceriez": ("acquiescer",),
    "acquiescerions": ("acquiescer",),
    "acquiescerons": ("acquiescer",),
    "acquiesceront": ("acquiescer",),
    "acquiesces": ("acquiescer",),
    "acquiescez": ("acquiescer",),
    "acquiesciez": ("acquiescer",),
    "acquiescions": ("acquiescer",),
    "acquiesçons": ("acquiescer",),
    "adhéraient": ("adhérer",),
    "adhérai": ("adhérer",),
    "adhérais": ("adhérer",),
    "adhérait": ("adhérer",),
    "adhéra": ("adhérer",),
    "adhérâmes": ("adhérer",),
    "adhérant": ("adhérer",),
    "adhéras": ("adhérer",),
    "adhérassent": ("adhérer",),
    "adhérasses": ("adhérer",),
    "adhérasse": ("adhérer",),
    "adhérassiez": ("adhérer",),
    "adhérassions": ("adhérer",),
    "adhérâtes": ("adhérer",),
    "adhérât": ("adhérer",),
    "adhéré": ("adhérer",),
    "adhèrent": ("adhérer",),
    "adhère": ("adhérer",),
    "adhérera": ("adhérer",),
    "adhéreraient": ("adhérer",),
    "adhérerai": ("adhérer",),
    "adhérerais": ("adhérer",),
    "adhérerait": ("adhérer",),
    "adhéreras": ("adhérer",),
    "adhérèrent": ("adhérer",),
    "adhérerez": ("adhérer",),
    "adhéreriez": ("adhérer",),
    "adhérerions": ("adhérer",),
    "adhérerons": ("adhérer",),
    "adhéreront": ("adhérer",),
    "adhères": ("adhérer",),
    "adhérez": ("adhérer",),
    "adhériez": ("adhérer",),
    "adhérions": ("adhérer",),
    "adhérons": ("adhérer",),
    "adjoignaient": ("adjoindre",),
    "adjoignais": ("adjoindre",),
    "adjoignait": ("adjoindre",),
    "adjoignant": ("adjoindre",),
    "adjoignent": ("adjoindre",),
    "adjoigne": ("adjoindre",),
    "adjoignes": ("adjoindre",),
    "adjoignez": ("adjoindre",),
    "adjoigniez": ("adjoindre",),
    "adjoignîmes": ("adjoindre",),
    "adjoignions": ("adjoindre",),
    "adjoignirent": ("adjoindre",),
    "adjoignis": ("adjoindre",),
    "adjoignissent": ("adjoindre",),
    "adjoignisses": ("adjoindre",),
    "adjoignisse": ("adjoindre",),
    "adjoignissiez": ("adjoindre",),
    "adjoignissions": ("adjoindre",),
    "adjoignîtes": ("adjoindre",),
    "adjoignit": ("adjoindre",),
    "adjoignît": ("adjoindre",),
    "adjoignons": ("adjoindre",),
    "adjoindra": ("adjoindre",),
    "adjoindraient": ("adjoindre",),
    "adjoindrai": ("adjoindre",),
    "adjoindrais": ("adjoindre",),
    "adjoindrait": ("adjoindre",),
    "adjoindras": ("adjoindre",),
    "adjoindrez": ("adjoindre",),
    "adjoindriez": ("adjoindre",),
    "adjoindrions": ("adjoindre",),
    "adjoindrons": ("adjoindre",),
    "adjoindront": ("adjoindre",),
    "adjoins": ("adjoindre",),
    "adjointe": ("adjoindre",),
    "adjointes": ("adjoindre",),
    "adjoint": ("adjoindre",),
    "adjoints": ("adjoindre",),
    "adjugeaient": ("adjuger",),
    "adjugeai": ("adjuger",),
    "adjugeais": ("adjuger",),
    "adjugeait": ("adjuger",),
    "adjugea": ("adjuger",),
    "adjugeâmes": ("adjuger",),
    "adjugeant": ("adjuger",),
    "adjugeas": ("adjuger",),
    "adjugeassent": ("adjuger",),
    "adjugeasses": ("adjuger",),
    "adjugeasse": ("adjuger",),
    "adjugeassiez": ("adjuger",),
    "adjugeassions": ("adjuger",),
    "adjugeâtes": ("adjuger",),
    "adjugeât": ("adjuger",),
    "adjugée": ("adjuger",),
    "adjugées": ("adjuger",),
    "adjugé": ("adjuger",),
    "adjugent": ("adjuger",),
    "adjugeons": ("adjuger",),
    "adjuge": ("adjuger",),
    "adjugera": ("adjuger",),
    "adjugeraient": ("adjuger",),
    "adjugerai": ("adjuger",),
    "adjugerais": ("adjuger",),
    "adjugerait": ("adjuger",),
    "adjugeras": ("adjuger",),
    "adjugèrent": ("adjuger",),
    "adjugerez": ("adjuger",),
    "adjugeriez": ("adjuger",),
    "adjugerions": ("adjuger",),
    "adjugerons": ("adjuger",),
    "adjugeront": ("adjuger",),
    "adjugés": ("adjuger",),
    "adjuges": ("adjuger",),
    "adjugez": ("adjuger",),
    "adjugiez": ("adjuger",),
    "adjugions": ("adjuger",),
    "admet": ("admettre",),
    "admets": ("admettre",),
    "admettaient": ("admettre",),
    "admettais": ("admettre",),
    "admettait": ("admettre",),
    "admettant": ("admettre",),
    "admettent": ("admettre",),
    "admette": ("admettre",),
    "admettes": ("admettre",),
    "admettez": ("admettre",),
    "admettiez": ("admettre",),
    "admettions": ("admettre",),
    "admettons": ("admettre",),
    "admettra": ("admettre",),
    "admettraient": ("admettre",),
    "admettrai": ("admettre",),
    "admettrais": ("admettre",),
    "admettrait": ("admettre",),
    "admettras": ("admettre",),
    "admettrez": ("admettre",),
    "admettriez": ("admettre",),
    "admettrions": ("admettre",),
    "admettrons": ("admettre",),
    "admettront": ("admettre",),
    "admîmes": ("admettre",),
    "admirent": ("admettre",),
    "admise": ("admettre",),
    "admises": ("admettre",),
    "admis": ("admettre",),
    "admissent": ("admettre",),
    "admisses": ("admettre",),
    "admisse": ("admettre",),
    "admissiez": ("admettre",),
    "admissions": ("admettre",),
    "admîtes": ("admettre",),
    "admit": ("admettre",),
    "admît": ("admettre",),
    "adoucie": ("adoucir",),
    "adoucies": ("adoucir",),
    "adouci": ("adoucir",),
    "adoucîmes": ("adoucir",),
    "adoucira": ("adoucir",),
    "adouciraient": ("adoucir",),
    "adoucirai": ("adoucir",),
    "adoucirais": ("adoucir",),
    "adoucirait": ("adoucir",),
    "adouciras": ("adoucir",),
    "adoucirent": ("adoucir",),
    "adoucirez": ("adoucir",),
    "adouciriez": ("adoucir",),
    "adoucirions": ("adoucir",),
    "adoucirons": ("adoucir",),
    "adouciront": ("adoucir",),
    "adoucis": ("adoucir",),
    "adoucissaient": ("adoucir",),
    "adoucissais": ("adoucir",),
    "adoucissait": ("adoucir",),
    "adoucissant": ("adoucir",),
    "adoucissent": ("adoucir",),
    "adoucisse": ("adoucir",),
    "adoucisses": ("adoucir",),
    "adoucissez": ("adoucir",),
    "adoucissiez": ("adoucir",),
    "adoucissions": ("adoucir",),
    "adoucissons": ("adoucir",),
    "adoucîtes": ("adoucir",),
    "adoucit": ("adoucir",),
    "adoucît": ("adoucir",),
    "adrogeaient": ("adroger",),
    "adrogeai": ("adroger",),
    "adrogeais": ("adroger",),
    "adrogeait": ("adroger",),
    "adrogea": ("adroger",),
    "adrogeâmes": ("adroger",),
    "adrogeant": ("adroger",),
    "adrogeas": ("adroger",),
    "adrogeassent": ("adroger",),
    "adrogeasses": ("adroger",),
    "adrogeasse": ("adroger",),
    "adrogeassiez": ("adroger",),
    "adrogeassions": ("adroger",),
    "adrogeâtes": ("adroger",),
    "adrogeât": ("adroger",),
    "adrogée": ("adroger",),
    "adrogées": ("adroger",),
    "adrogé": ("adroger",),
    "adrogent": ("adroger",),
    "adrogeons": ("adroger",),
    "adroge": ("adroger",),
    "adrogera": ("adroger",),
    "adrogeraient": ("adroger",),
    "adrogerai": ("adroger",),
    "adrogerais": ("adroger",),
    "adrogerait": ("adroger",),
    "adrogeras": ("adroger",),
    "adrogèrent": ("adroger",),
    "adrogerez": ("adroger",),
    "adrogeriez": ("adroger",),
    "adrogerions": ("adroger",),
    "adrogerons": ("adroger",),
    "adrogeront": ("adroger",),
    "adrogés": ("adroger",),
    "adroges": ("adroger",),
    "adrogez": ("adroger",),
    "adrogiez": ("adroger",),
    "adrogions": ("adroger",),
    "adultéraient": ("adultérer",),
    "adultérai": ("adultérer",),
    "adultérais": ("adultérer",),
    "adultérait": ("adultérer",),
    "adultéra": ("adultérer",),
    "adultérâmes": ("adultérer",),
    "adultérant": ("adultérer",),
    "adultéras": ("adultérer",),
    "adultérassent": ("adultérer",),
    "adultérasses": ("adultérer",),
    "adultérasse": ("adultérer",),
    "adultérassiez": ("adultérer",),
    "adultérassions": ("adultérer",),
    "adultérâtes": ("adultérer",),
    "adultérât": ("adultérer",),
    "adultérée": ("adultérer",),
    "adultérées": ("adultérer",),
    "adultéré": ("adultérer",),
    "adultèrent": ("adultérer",),
    "adultère": ("adultérer",),
    "adultérera": ("adultérer",),
    "adultéreraient": ("adultérer",),
    "adultérerai": ("adultérer",),
    "adultérerais": ("adultérer",),
    "adultérerait": ("adultérer",),
    "adultéreras": ("adultérer",),
    "adultérèrent": ("adultérer",),
    "adultérerez": ("adultérer",),
    "adultéreriez": ("adultérer",),
    "adultérerions": ("adultérer",),
    "adultérerons": ("adultérer",),
    "adultéreront": ("adultérer",),
    "adultérés": ("adultérer",),
    "adultères": ("adultérer",),
    "adultérez": ("adultérer",),
    "adultériez": ("adultérer",),
    "adultérions": ("adultérer",),
    "adultérons": ("adultérer",),
    "advenaient": ("advenir",),
    "advenait": ("advenir",),
    "advenant": ("advenir",),
    "advenue": ("advenir",),
    "advenues": ("advenir",),
    "advenu": ("advenir",),
    "advenus": ("advenir",),
    "adviendra": ("advenir",),
    "adviendraient": ("advenir",),
    "adviendrait": ("advenir",),
    "adviendront": ("advenir",),
    "adviennent": ("advenir",),
    "advienne": ("advenir",),
    "advient": ("advenir",),
    "advinrent": ("advenir",),
    "advinssent": ("advenir",),
    "advint": ("advenir",),
    "advînt": ("advenir",),
    "aéraient": ("aérer",),
    "aérai": ("aérer",),
    "aérais": ("aérer",),
    "aérait": ("aérer",),
    "aéra": ("aérer",),
    "aérâmes": ("aérer",),
    "aérant": ("aérer",),
    "aéras": ("aérer",),
    "aérassent": ("aérer",),
    "aérasses": ("aérer",),
    "aérasse": ("aérer",),
    "aérassiez": ("aérer",),
    "aérassions": ("aérer",),
    "aérâtes": ("aérer",),
    "aérât": ("aérer",),
    "aérée": ("aérer",),
    "aérées": ("aérer",),
    "aéré": ("aérer",),
    "aèrent": ("aérer",),
    "aère": ("aérer",),
    "aérera": ("aérer",),
    "aéreraient": ("aérer",),
    "aérerai": ("aérer",),
    "aérerais": ("aérer",),
    "aérerait": ("aérer",),
    "aéreras": ("aérer",),
    "aérèrent": ("aérer",),
    "aérerez": ("aérer",),
    "aéreriez": ("aérer",),
    "aérerions": ("aérer",),
    "aérerons": ("aérer",),
    "aéreront": ("aérer",),
    "aérés": ("aérer",),
    "aères": ("aérer",),
    "aérez": ("aérer",),
    "aériez": ("aérer",),
    "aérions": ("aérer",),
    "aérons": ("aérer",),
    "affadie": ("affadir",),
    "affadies": ("affadir",),
    "affadi": ("affadir",),
    "affadîmes": ("affadir",),
    "affadira": ("affadir",),
    "affadiraient": ("affadir",),
    "affadirai": ("affadir",),
    "affadirais": ("affadir",),
    "affadirait": ("affadir",),
    "affadiras": ("affadir",),
    "affadirent": ("affadir",),
    "affadirez": ("affadir",),
    "affadiriez": ("affadir",),
    "affadirions": ("affadir",),
    "affadirons": ("affadir",),
    "affadiront": ("affadir",),
    "affadis": ("affadir",),
    "affadissaient": ("affadir",),
    "affadissais": ("affadir",),
    "affadissait": ("affadir",),
    "affadissant": ("affadir",),
    "affadissent": ("affadir",),
    "affadisse": ("affadir",),
    "affadisses": ("affadir",),
    "affadissez": ("affadir",),
    "affadissiez": ("affadir",),
    "affadissions": ("affadir",),
    "affadissons": ("affadir",),
    "affadîtes": ("affadir",),
    "affadit": ("affadir",),
    "affadît": ("affadir",),
    "affaiblie": ("affaiblir",),
    "affaiblies": ("affaiblir",),
    "affaibli": ("affaiblir",),
    "affaiblîmes": ("affaiblir",),
    "affaiblira": ("affaiblir",),
    "affaibliraient": ("affaiblir",),
    "affaiblirai": ("affaiblir",),
    "affaiblirais": ("affaiblir",),
    "affaiblirait": ("affaiblir",),
    "affaibliras": ("affaiblir",),
    "affaiblirent": ("affaiblir",),
    "affaiblirez": ("affaiblir",),
    "affaibliriez": ("affaiblir",),
    "affaiblirions": ("affaiblir",),
    "affaiblirons": ("affaiblir",),
    "affaibliront": ("affaiblir",),
    "affaiblis": ("affaiblir",),
    "affaiblissaient": ("affaiblir",),
    "affaiblissais": ("affaiblir",),
    "affaiblissait": ("affaiblir",),
    "affaiblissant": ("affaiblir",),
    "affaiblissent": ("affaiblir",),
    "affaiblisse": ("affaiblir",),
    "affaiblisses": ("affaiblir",),
    "affaiblissez": ("affaiblir",),
    "affaiblissiez": ("affaiblir",),
    "affaiblissions": ("affaiblir",),
    "affaiblissons": ("affaiblir",),
    "affaiblîtes": ("affaiblir",),
    "affaiblit": ("affaiblir",),
    "affaiblît": ("affaiblir",),
    "affainéantie": ("affainéantir",),
    "affainéanties": ("affainéantir",),
    "affainéanti": ("affainéantir",),
    "affainéantîmes": ("affainéantir",),
    "affainéantira": ("affainéantir",),
    "affainéantiraient": ("affainéantir",),
    "affainéantirai": ("affainéantir",),
    "affainéantirais": ("affainéantir",),
    "affainéantirait": ("affainéantir",),
    "affainéantiras": ("affainéantir",),
    "affainéantirent": ("affainéantir",),
    "affainéantirez": ("affainéantir",),
    "affainéantiriez": ("affainéantir",),
    "affainéantirions": ("affainéantir",),
    "affainéantirons": ("affainéantir",),
    "affainéantiront": ("affainéantir",),
    "affainéantis": ("affainéantir",),
    "affainéantissaient": ("affainéantir",),
    "affainéantissais": ("affainéantir",),
    "affainéantissait": ("affainéantir",),
    "affainéantissant": ("affainéantir",),
    "affainéantissent": ("affainéantir",),
    "affainéantisse": ("affainéantir",),
    "affainéantisses": ("affainéantir",),
    "affainéantissez": ("affainéantir",),
    "affainéantissiez": ("affainéantir",),
    "affainéantissions": ("affainéantir",),
    "affainéantissons": ("affainéantir",),
    "affainéantîtes": ("affainéantir",),
    "affainéantit": ("affainéantir",),
    "affainéantît": ("affainéantir",),
    "afféageaient": ("afféager",),
    "afféageai": ("afféager",),
    "afféageais": ("afféager",),
    "afféageait": ("afféager",),
    "afféagea": ("afféager",),
    "afféageâmes": ("afféager",),
    "afféageant": ("afféager",),
    "afféageas": ("afféager",),
    "afféageassent": ("afféager",),
    "afféageasses": ("afféager",),
    "afféageasse": ("afféager",),
    "afféageassiez": ("afféager",),
    "afféageassions": ("afféager",),
    "afféageâtes": ("afféager",),
    "afféageât": ("afféager",),
    "afféagée": ("afféager",),
    "afféagées": ("afféager",),
    "afféagé": ("afféager",),
    "afféagent": ("afféager",),
    "afféageons": ("afféager",),
    "afféage": ("afféager",),
    "afféagera": ("afféager",),
    "afféageraient": ("afféager",),
    "afféagerai": ("afféager",),
    "afféagerais": ("afféager",),
    "afféagerait": ("afféager",),
    "afféageras": ("afféager",),
    "afféagèrent": ("afféager",),
    "afféagerez": ("afféager",),
    "afféageriez": ("afféager",),
    "afféagerions": ("afféager",),
    "afféagerons": ("afféager",),
    "afféageront": ("afféager",),
    "afféagés": ("afféager",),
    "afféages": ("afféager",),
    "afféagez": ("afféager",),
    "afféagiez": ("afféager",),
    "afféagions": ("afféager",),
    "affenaient": ("affener",),
    "affenai": ("affener",),
    "affenais": ("affener",),
    "affenait": ("affener",),
    "affena": ("affener",),
    "affenâmes": ("affener",),
    "affenant": ("affener",),
    "affenas": ("affener",),
    "affenassent": ("affener",),
    "affenasses": ("affener",),
    "affenasse": ("affener",),
    "affenassiez": ("affener",),
    "affenassions": ("affener",),
    "affenâtes": ("affener",),
    "affenât": ("affener",),
    "affenée": ("affener",),
    "affenées": ("affener",),
    "affené": ("affener",),
    "affènent": ("affener",),
    "affène": ("affener",),
    "affènera": ("affener",),
    "affèneraient": ("affener",),
    "affènerai": ("affener",),
    "affènerais": ("affener",),
    "affènerait": ("affener",),
    "affèneras": ("affener",),
    "affenèrent": ("affener",),
    "affènerez": ("affener",),
    "affèneriez": ("affener",),
    "affènerions": ("affener",),
    "affènerons": ("affener",),
    "affèneront": ("affener",),
    "affenés": ("affener",),
    "affènes": ("affener",),
    "affenez": ("affener",),
    "affeniez": ("affener",),
    "affenions": ("affener",),
    "affenons": ("affener",),
    "afféraient": ("afférer",),
    "afférai": ("afférer",),
    "afférais": ("afférer",),
    "afférait": ("afférer",),
    "afféra": ("afférer",),
    "afférâmes": ("afférer",),
    "afférant": ("afférer",),
    "afféras": ("afférer",),
    "afférassent": ("afférer",),
    "afférasses": ("afférer",),
    "afférasse": ("afférer",),
    "afférassiez": ("afférer",),
    "afférassions": ("afférer",),
    "afférâtes": ("afférer",),
    "afférât": ("afférer",),
    "afférée": ("afférer",),
    "afférées": ("afférer",),
    "afféré": ("afférer",),
    "affèrent": ("afférer",),
    "affère": ("afférer",),
    "afférera": ("afférer",),
    "afféreraient": ("afférer",),
    "afférerai": ("afférer",),
    "afférerais": ("afférer",),
    "afférerait": ("afférer",),
    "afféreras": ("afférer",),
    "afférèrent": ("afférer",),
    "afférerez": ("afférer",),
    "afféreriez": ("afférer",),
    "afférerions": ("afférer",),
    "afférerons": ("afférer",),
    "afféreront": ("afférer",),
    "afférés": ("afférer",),
    "affères": ("afférer",),
    "afférez": ("afférer",),
    "affériez": ("afférer",),
    "afférions": ("afférer",),
    "afférons": ("afférer",),
    "affermie": ("affermir",),
    "affermies": ("affermir",),
    "affermi": ("affermir",),
    "affermîmes": ("affermir",),
    "affermira": ("affermir",),
    "affermiraient": ("affermir",),
    "affermirai": ("affermir",),
    "affermirais": ("affermir",),
    "affermirait": ("affermir",),
    "affermiras": ("affermir",),
    "affermirent": ("affermir",),
    "affermirez": ("affermir",),
    "affermiriez": ("affermir",),
    "affermirions": ("affermir",),
    "affermirons": ("affermir",),
    "affermiront": ("affermir",),
    "affermis": ("affermir",),
    "affermissaient": ("affermir",),
    "affermissais": ("affermir",),
    "affermissait": ("affermir",),
    "affermissant": ("affermir",),
    "affermissent": ("affermir",),
    "affermisse": ("affermir",),
    "affermisses": ("affermir",),
    "affermissez": ("affermir",),
    "affermissiez": ("affermir",),
    "affermissions": ("affermir",),
    "affermissons": ("affermir",),
    "affermîtes": ("affermir",),
    "affermit": ("affermir",),
    "affermît": ("affermir",),
    "affiliaient": ("affilier",),
    "affiliai": ("affilier",),
    "affiliais": ("affilier",),
    "affiliait": ("affilier",),
    "affilia": ("affilier",),
    "affiliâmes": ("affilier",),
    "affiliant": ("affilier",),
    "affilias": ("affilier",),
    "affiliassent": ("affilier",),
    "affiliasses": ("affilier",),
    "affiliasse": ("affilier",),
    "affiliassiez": ("affilier",),
    "affiliassions": ("affilier",),
    "affiliâtes": ("affilier",),
    "affiliât": ("affilier",),
    "affiliée": ("affilier",),
    "affiliées": ("affilier",),
    "affilié": ("affilier",),
    "affilient": ("affilier",),
    "affilie": ("affilier",),
    "affiliera": ("affilier",),
    "affilieraient": ("affilier",),
    "affilierai": ("affilier",),
    "affilierais": ("affilier",),
    "affilierait": ("affilier",),
    "affilieras": ("affilier",),
    "affilièrent": ("affilier",),
    "affilierez": ("affilier",),
    "affilieriez": ("affilier",),
    "affilierions": ("affilier",),
    "affilierons": ("affilier",),
    "affilieront": ("affilier",),
    "affiliés": ("affilier",),
    "affilies": ("affilier",),
    "affiliez": ("affilier",),
    "affiliiez": ("affilier",),
    "affiliions": ("affilier",),
    "affilions": ("affilier",),
    "affléchaient": ("afflécher",),
    "affléchai": ("afflécher",),
    "affléchais": ("afflécher",),
    "affléchait": ("afflécher",),
    "afflécha": ("afflécher",),
    "affléchâmes": ("afflécher",),
    "affléchant": ("afflécher",),
    "affléchas": ("afflécher",),
    "affléchassent": ("afflécher",),
    "affléchasses": ("afflécher",),
    "affléchasse": ("afflécher",),
    "affléchassiez": ("afflécher",),
    "affléchassions": ("afflécher",),
    "affléchâtes": ("afflécher",),
    "affléchât": ("afflécher",),
    "affléchée": ("afflécher",),
    "affléchées": ("afflécher",),
    "affléché": ("afflécher",),
    "afflèchent": ("afflécher",),
    "afflèche": ("afflécher",),
    "affléchera": ("afflécher",),
    "afflécheraient": ("afflécher",),
    "afflécherai": ("afflécher",),
    "afflécherais": ("afflécher",),
    "afflécherait": ("afflécher",),
    "afflécheras": ("afflécher",),
    "affléchèrent": ("afflécher",),
    "afflécherez": ("afflécher",),
    "afflécheriez": ("afflécher",),
    "afflécherions": ("afflécher",),
    "afflécherons": ("afflécher",),
    "afflécheront": ("afflécher",),
    "affléchés": ("afflécher",),
    "afflèches": ("afflécher",),
    "affléchez": ("afflécher",),
    "affléchiez": ("afflécher",),
    "affléchions": ("afflécher",),
    "affléchons": ("afflécher",),
    "affligeaient": ("affliger",),
    "affligeai": ("affliger",),
    "affligeais": ("affliger",),
    "affligeait": ("affliger",),
    "affligea": ("affliger",),
    "affligeâmes": ("affliger",),
    "affligeant": ("affliger",),
    "affligeas": ("affliger",),
    "affligeassent": ("affliger",),
    "affligeasses": ("affliger",),
    "affligeasse": ("affliger",),
    "affligeassiez": ("affliger",),
    "affligeassions": ("affliger",),
    "affligeâtes": ("affliger",),
    "affligeât": ("affliger",),
    "affligée": ("affliger",),
    "affligées": ("affliger",),
    "affligé": ("affliger",),
    "affligent": ("affliger",),
    "affligeons": ("affliger",),
    "afflige": ("affliger",),
    "affligera": ("affliger",),
    "affligeraient": ("affliger",),
    "affligerai": ("affliger",),
    "affligerais": ("affliger",),
    "affligerait": ("affliger",),
    "affligeras": ("affliger",),
    "affligèrent": ("affliger",),
    "affligerez": ("affliger",),
    "affligeriez": ("affliger",),
    "affligerions": ("affliger",),
    "affligerons": ("affliger",),
    "affligeront": ("affliger",),
    "affligés": ("affliger",),
    "affliges": ("affliger",),
    "affligez": ("affliger",),
    "affligiez": ("affliger",),
    "affligions": ("affliger",),
    "affolie": ("affolir",),
    "affolies": ("affolir",),
    "affoli": ("affolir",),
    "affolîmes": ("affolir",),
    "affolira": ("affolir",),
    "affoliraient": ("affolir",),
    "affolirai": ("affolir",),
    "affolirais": ("affolir",),
    "affolirait": ("affolir",),
    "affoliras": ("affolir",),
    "affolirent": ("affolir",),
    "affolirez": ("affolir",),
    "affoliriez": ("affolir",),
    "affolirions": ("affolir",),
    "affolirons": ("affolir",),
    "affoliront": ("affolir",),
    "affolis": ("affolir",),
    "affolissaient": ("affolir",),
    "affolissais": ("affolir",),
    "affolissait": ("affolir",),
    "affolissant": ("affolir",),
    "affolissent": ("affolir",),
    "affolisse": ("affolir",),
    "affolisses": ("affolir",),
    "affolissez": ("affolir",),
    "affolissiez": ("affolir",),
    "affolissions": ("affolir",),
    "affolissons": ("affolir",),
    "affolîtes": ("affolir",),
    "affolit": ("affolir",),
    "affolît": ("affolir",),
    "affouageaient": ("affouager",),
    "affouageai": ("affouager",),
    "affouageais": ("affouager",),
    "affouageait": ("affouager",),
    "affouagea": ("affouager",),
    "affouageâmes": ("affouager",),
    "affouageant": ("affouager",),
    "affouageas": ("affouager",),
    "affouageassent": ("affouager",),
    "affouageasses": ("affouager",),
    "affouageasse": ("affouager",),
    "affouageassiez": ("affouager",),
    "affouageassions": ("affouager",),
    "affouageâtes": ("affouager",),
    "affouageât": ("affouager",),
    "affouagée": ("affouager",),
    "affouagées": ("affouager",),
    "affouagé": ("affouager",),
    "affouagent": ("affouager",),
    "affouageons": ("affouager",),
    "affouage": ("affouager",),
    "affouagera": ("affouager",),
    "affouageraient": ("affouager",),
    "affouagerai": ("affouager",),
    "affouagerais": ("affouager",),
    "affouagerait": ("affouager",),
    "affouageras": ("affouager",),
    "affouagèrent": ("affouager",),
    "affouagerez": ("affouager",),
    "affouageriez": ("affouager",),
    "affouagerions": ("affouager",),
    "affouagerons": ("affouager",),
    "affouageront": ("affouager",),
    "affouagés": ("affouager",),
    "affouages": ("affouager",),
    "affouagez": ("affouager",),
    "affouagiez": ("affouager",),
    "affouagions": ("affouager",),
    "affourageaient": ("affourager",),
    "affourageai": ("affourager",),
    "affourageais": ("affourager",),
    "affourageait": ("affourager",),
    "affouragea": ("affourager",),
    "affourageâmes": ("affourager",),
    "affourageant": ("affourager",),
    "affourageas": ("affourager",),
    "affourageassent": ("affourager",),
    "affourageasses": ("affourager",),
    "affourageasse": ("affourager",),
    "affourageassiez": ("affourager",),
    "affourageassions": ("affourager",),
    "affourageâtes": ("affourager",),
    "affourageât": ("affourager",),
    "affouragée": ("affourager",),
    "affouragées": ("affourager",),
    "affouragé": ("affourager",),
    "affouragent": ("affourager",),
    "affourageons": ("affourager",),
    "affourage": ("affourager",),
    "affouragera": ("affourager",),
    "affourageraient": ("affourager",),
    "affouragerai": ("affourager",),
    "affouragerais": ("affourager",),
    "affouragerait": ("affourager",),
    "affourageras": ("affourager",),
    "affouragèrent": ("affourager",),
    "affouragerez": ("affourager",),
    "affourageriez": ("affourager",),
    "affouragerions": ("affourager",),
    "affouragerons": ("affourager",),
    "affourageront": ("affourager",),
    "affouragés": ("affourager",),
    "affourages": ("affourager",),
    "affouragez": ("affourager",),
    "affouragiez": ("affourager",),
    "affouragions": ("affourager",),
    "affourrageaient": ("affourrager",),
    "affourrageai": ("affourrager",),
    "affourrageais": ("affourrager",),
    "affourrageait": ("affourrager",),
    "affourragea": ("affourrager",),
    "affourrageâmes": ("affourrager",),
    "affourrageant": ("affourrager",),
    "affourrageas": ("affourrager",),
    "affourrageassent": ("affourrager",),
    "affourrageasses": ("affourrager",),
    "affourrageasse": ("affourrager",),
    "affourrageassiez": ("affourrager",),
    "affourrageassions": ("affourrager",),
    "affourrageâtes": ("affourrager",),
    "affourrageât": ("affourrager",),
    "affourragée": ("affourrager",),
    "affourragées": ("affourrager",),
    "affourragé": ("affourrager",),
    "affourragent": ("affourrager",),
    "affourrageons": ("affourrager",),
    "affourrage": ("affourrager",),
    "affourragera": ("affourrager",),
    "affourrageraient": ("affourrager",),
    "affourragerai": ("affourrager",),
    "affourragerais": ("affourrager",),
    "affourragerait": ("affourrager",),
    "affourrageras": ("affourrager",),
    "affourragèrent": ("affourrager",),
    "affourragerez": ("affourrager",),
    "affourrageriez": ("affourrager",),
    "affourragerions": ("affourrager",),
    "affourragerons": ("affourrager",),
    "affourrageront": ("affourrager",),
    "affourragés": ("affourrager",),
    "affourrages": ("affourrager",),
    "affourragez": ("affourrager",),
    "affourragiez": ("affourrager",),
    "affourragions": ("affourrager",),
    "affraîchie": ("affraîchir",),
    "affraîchies": ("affraîchir",),
    "affraîchi": ("affraîchir",),
    "affraîchîmes": ("affraîchir",),
    "affraîchira": ("affraîchir",),
    "affraîchiraient": ("affraîchir",),
    "affraîchirai": ("affraîchir",),
    "affraîchirais": ("affraîchir",),
    "affraîchirait": ("affraîchir",),
    "affraîchiras": ("affraîchir",),
    "affraîchirent": ("affraîchir",),
    "affraîchirez": ("affraîchir",),
    "affraîchiriez": ("affraîchir",),
    "affraîchirions": ("affraîchir",),
    "affraîchirons": ("affraîchir",),
    "affraîchiront": ("affraîchir",),
    "affraîchis": ("affraîchir",),
    "affraîchissaient": ("affraîchir",),
    "affraîchissais": ("affraîchir",),
    "affraîchissait": ("affraîchir",),
    "affraîchissant": ("affraîchir",),
    "affraîchissent": ("affraîchir",),
    "affraîchisse": ("affraîchir",),
    "affraîchisses": ("affraîchir",),
    "affraîchissez": ("affraîchir",),
    "affraîchissiez": ("affraîchir",),
    "affraîchissions": ("affraîchir",),
    "affraîchissons": ("affraîchir",),
    "affraîchîtes": ("affraîchir",),
    "affraîchit": ("affraîchir",),
    "affraîchît": ("affraîchir",),
    "affranchie": ("affranchir",),
    "affranchies": ("affranchir",),
    "affranchi": ("affranchir",),
    "affranchîmes": ("affranchir",),
    "affranchira": ("affranchir",),
    "affranchiraient": ("affranchir",),
    "affranchirai": ("affranchir",),
    "affranchirais": ("affranchir",),
    "affranchirait": ("affranchir",),
    "affranchiras": ("affranchir",),
    "affranchirent": ("affranchir",),
    "affranchirez": ("affranchir",),
    "affranchiriez": ("affranchir",),
    "affranchirions": ("affranchir",),
    "affranchirons": ("affranchir",),
    "affranchiront": ("affranchir",),
    "affranchis": ("affranchir",),
    "affranchissaient": ("affranchir",),
    "affranchissais": ("affranchir",),
    "affranchissait": ("affranchir",),
    "affranchissant": ("affranchir",),
    "affranchissent": ("affranchir",),
    "affranchisse": ("affranchir",),
    "affranchisses": ("affranchir",),
    "affranchissez": ("affranchir",),
    "affranchissiez": ("affranchir",),
    "affranchissions": ("affranchir",),
    "affranchissons": ("affranchir",),
    "affranchîtes": ("affranchir",),
    "affranchit": ("affranchir",),
    "affranchît": ("affranchir",),
    "affrétaient": ("affréter",),
    "affrétai": ("affréter",),
    "affrétais": ("affréter",),
    "affrétait": ("affréter",),
    "affréta": ("affréter",),
    "affrétâmes": ("affréter",),
    "affrétant": ("affréter",),
    "affrétas": ("affréter",),
    "affrétassent": ("affréter",),
    "affrétasses": ("affréter",),
    "affrétasse": ("affréter",),
    "affrétassiez": ("affréter",),
    "affrétassions": ("affréter",),
    "affrétâtes": ("affréter",),
    "affrétât": ("affréter",),
    "affrétée": ("affréter",),
    "affrétées": ("affréter",),
    "affrété": ("affréter",),
    "affrètent": ("affréter",),
    "affrète": ("affréter",),
    "affrétera": ("affréter",),
    "affréteraient": ("affréter",),
    "affréterai": ("affréter",),
    "affréterais": ("affréter",),
    "affréterait": ("affréter",),
    "affréteras": ("affréter",),
    "affrétèrent": ("affréter",),
    "affréterez": ("affréter",),
    "affréteriez": ("affréter",),
    "affréterions": ("affréter",),
    "affréterons": ("affréter",),
    "affréteront": ("affréter",),
    "affrétés": ("affréter",),
    "affrètes": ("affréter",),
    "affrétez": ("affréter",),
    "affrétiez": ("affréter",),
    "affrétions": ("affréter",),
    "affrétons": ("affréter",),
    "agaçaient": ("agacer",),
    "agaçai": ("agacer",),
    "agaçais": ("agacer",),
    "agaçait": ("agacer",),
    "agaça": ("agacer",),
    "agaçâmes": ("agacer",),
    "agaçant": ("agacer",),
    "agaças": ("agacer",),
    "agaçassent": ("agacer",),
    "agaçasses": ("agacer",),
    "agaçasse": ("agacer",),
    "agaçassiez": ("agacer",),
    "agaçassions": ("agacer",),
    "agaçâtes": ("agacer",),
    "agaçât": ("agacer",),
    "agacée": ("agacer",),
    "agacées": ("agacer",),
    "agacé": ("agacer",),
    "agacent": ("agacer",),
    "agace": ("agacer",),
    "agacera": ("agacer",),
    "agaceraient": ("agacer",),
    "agacerai": ("agacer",),
    "agacerais": ("agacer",),
    "agacerait": ("agacer",),
    "agaceras": ("agacer",),
    "agacèrent": ("agacer",),
    "agacerez": ("agacer",),
    "agaceriez": ("agacer",),
    "agacerions": ("agacer",),
    "agacerons": ("agacer",),
    "agaceront": ("agacer",),
    "agacés": ("agacer",),
    "agaces": ("agacer",),
    "agacez": ("agacer",),
    "agaciez": ("agacer",),
    "agacions": ("agacer",),
    "agaçons": ("agacer",),
    "agaillardie": ("agaillardir",),
    "agaillardies": ("agaillardir",),
    "agaillardi": ("agaillardir",),
    "agaillardîmes": ("agaillardir",),
    "agaillardira": ("agaillardir",),
    "agaillardiraient": ("agaillardir",),
    "agaillardirai": ("agaillardir",),
    "agaillardirais": ("agaillardir",),
    "agaillardirait": ("agaillardir",),
    "agaillardiras": ("agaillardir",),
    "agaillardirent": ("agaillardir",),
    "agaillardirez": ("agaillardir",),
    "agaillardiriez": ("agaillardir",),
    "agaillardirions": ("agaillardir",),
    "agaillardirons": ("agaillardir",),
    "agaillardiront": ("agaillardir",),
    "agaillardis": ("agaillardir",),
    "agaillardissaient": ("agaillardir",),
    "agaillardissais": ("agaillardir",),
    "agaillardissait": ("agaillardir",),
    "agaillardissant": ("agaillardir",),
    "agaillardissent": ("agaillardir",),
    "agaillardisse": ("agaillardir",),
    "agaillardisses": ("agaillardir",),
    "agaillardissez": ("agaillardir",),
    "agaillardissiez": ("agaillardir",),
    "agaillardissions": ("agaillardir",),
    "agaillardissons": ("agaillardir",),
    "agaillardîtes": ("agaillardir",),
    "agaillardit": ("agaillardir",),
    "agaillardît": ("agaillardir",),
    "agatifiaient": ("agatifier",),
    "agatifiai": ("agatifier",),
    "agatifiais": ("agatifier",),
    "agatifiait": ("agatifier",),
    "agatifia": ("agatifier",),
    "agatifiâmes": ("agatifier",),
    "agatifiant": ("agatifier",),
    "agatifias": ("agatifier",),
    "agatifiassent": ("agatifier",),
    "agatifiasses": ("agatifier",),
    "agatifiasse": ("agatifier",),
    "agatifiassiez": ("agatifier",),
    "agatifiassions": ("agatifier",),
    "agatifiâtes": ("agatifier",),
    "agatifiât": ("agatifier",),
    "agatifiée": ("agatifier",),
    "agatifiées": ("agatifier",),
    "agatifié": ("agatifier",),
    "agatifient": ("agatifier",),
    "agatifie": ("agatifier",),
    "agatifiera": ("agatifier",),
    "agatifieraient": ("agatifier",),
    "agatifierai": ("agatifier",),
    "agatifierais": ("agatifier",),
    "agatifierait": ("agatifier",),
    "agatifieras": ("agatifier",),
    "agatifièrent": ("agatifier",),
    "agatifierez": ("agatifier",),
    "agatifieriez": ("agatifier",),
    "agatifierions": ("agatifier",),
    "agatifierons": ("agatifier",),
    "agatifieront": ("agatifier",),
    "agatifiés": ("agatifier",),
    "agatifies": ("agatifier",),
    "agatifiez": ("agatifier",),
    "agatifiiez": ("agatifier",),
    "agatifiions": ("agatifier",),
    "agatifions": ("agatifier",),
    "agençaient": ("agencer",),
    "agençai": ("agencer",),
    "agençais": ("agencer",),
    "agençait": ("agencer",),
    "agença": ("agencer",),
    "agençâmes": ("agencer",),
    "agençant": ("agencer",),
    "agenças": ("agencer",),
    "agençassent": ("agencer",),
    "agençasses": ("agencer",),
    "agençasse": ("agencer",),
    "agençassiez": ("agencer",),
    "agençassions": ("agencer",),
    "agençâtes": ("agencer",),
    "agençât": ("agencer",),
    "agencée": ("agencer",),
    "agencées": ("agencer",),
    "agencé": ("agencer",),
    "agencent": ("agencer",),
    "agence": ("agencer",),
    "agencera": ("agencer",),
    "agenceraient": ("agencer",),
    "agencerai": ("agencer",),
    "agencerais": ("agencer",),
    "agencerait": ("agencer",),
    "agenceras": ("agencer",),
    "agencèrent": ("agencer",),
    "agencerez": ("agencer",),
    "agenceriez": ("agencer",),
    "agencerions": ("agencer",),
    "agencerons": ("agencer",),
    "agenceront": ("agencer",),
    "agencés": ("agencer",),
    "agences": ("agencer",),
    "agencez": ("agencer",),
    "agenciez": ("agencer",),
    "agencions": ("agencer",),
    "agençons": ("agencer",),
    "aggloméraient": ("agglomérer",),
    "agglomérai": ("agglomérer",),
    "agglomérais": ("agglomérer",),
    "agglomérait": ("agglomérer",),
    "aggloméra": ("agglomérer",),
    "agglomérâmes": ("agglomérer",),
    "agglomérant": ("agglomérer",),
    "aggloméras": ("agglomérer",),
    "agglomérassent": ("agglomérer",),
    "agglomérasses": ("agglomérer",),
    "agglomérasse": ("agglomérer",),
    "agglomérassiez": ("agglomérer",),
    "agglomérassions": ("agglomérer",),
    "agglomérâtes": ("agglomérer",),
    "agglomérât": ("agglomérer",),
    "agglomérée": ("agglomérer",),
    "agglomérées": ("agglomérer",),
    "aggloméré": ("agglomérer",),
    "agglomèrent": ("agglomérer",),
    "agglomère": ("agglomérer",),
    "agglomérera": ("agglomérer",),
    "aggloméreraient": ("agglomérer",),
    "agglomérerai": ("agglomérer",),
    "agglomérerais": ("agglomérer",),
    "agglomérerait": ("agglomérer",),
    "aggloméreras": ("agglomérer",),
    "agglomérèrent": ("agglomérer",),
    "agglomérerez": ("agglomérer",),
    "aggloméreriez": ("agglomérer",),
    "agglomérerions": ("agglomérer",),
    "agglomérerons": ("agglomérer",),
    "aggloméreront": ("agglomérer",),
    "agglomérés": ("agglomérer",),
    "agglomères": ("agglomérer",),
    "agglomérez": ("agglomérer",),
    "agglomériez": ("agglomérer",),
    "agglomérions": ("agglomérer",),
    "agglomérons": ("agglomérer",),
    "agie": ("agir",),
    "agies": ("agir",),
    "agi": ("agir",),
    "agîmes": ("agir",),
    "agira": ("agir",),
    "agiraient": ("agir",),
    "agirai": ("agir",),
    "agirais": ("agir",),
    "agirait": ("agir",),
    "agiras": ("agir",),
    "agirent": ("agir",),
    "agirez": ("agir",),
    "agiriez": ("agir",),
    "agirions": ("agir",),
    "agirons": ("agir",),
    "agiront": ("agir",),
    "agis": ("agir",),
    "agissaient": ("agir",),
    "agissais": ("agir",),
    "agissait": ("agir",),
    "agissant": ("agir",),
    "agissent": ("agir",),
    "agisse": ("agir",),
    "agisses": ("agir",),
    "agissez": ("agir",),
    "agissiez": ("agir",),
    "agissions": ("agir",),
    "agissons": ("agir",),
    "agîtes": ("agir",),
    "agit": ("agir",),
    "agît": ("agir",),
    "agnelaient": ("agneler",),
    "agnelai": ("agneler",),
    "agnelais": ("agneler",),
    "agnelait": ("agneler",),
    "agnela": ("agneler",),
    "agnelâmes": ("agneler",),
    "agnelant": ("agneler",),
    "agnelas": ("agneler",),
    "agnelassent": ("agneler",),
    "agnelasses": ("agneler",),
    "agnelasse": ("agneler",),
    "agnelassiez": ("agneler",),
    "agnelassions": ("agneler",),
    "agnelâtes": ("agneler",),
    "agnelât": ("agneler",),
    "agnelée": ("agneler",),
    "agnelées": ("agneler",),
    "agnelé": ("agneler",),
    "agnelèrent": ("agneler",),
    "agnelés": ("agneler",),
    "agnelez": ("agneler",),
    "agneliez": ("agneler",),
    "agnelions": ("agneler",),
    "agnellent": ("agneler",),
    "agnelle": ("agneler",),
    "agnellera": ("agneler",),
    "agnelleraient": ("agneler",),
    "agnellerai": ("agneler",),
    "agnellerais": ("agneler",),
    "agnellerait": ("agneler",),
    "agnelleras": ("agneler",),
    "agnellerez": ("agneler",),
    "agnelleriez": ("agneler",),
    "agnellerions": ("agneler",),
    "agnellerons": ("agneler",),
    "agnelleront": ("agneler",),
    "agnelles": ("agneler",),
    "agnelons": ("agneler",),
    "agonie": ("agonir",),
    "agonies": ("agonir",),
    "agoni": ("agonir",),
    "agonîmes": ("agonir",),
    "agonira": ("agonir",),
    "agoniraient": ("agonir",),
    "agonirai": ("agonir",),
    "agonirais": ("agonir",),
    "agonirait": ("agonir",),
    "agoniras": ("agonir",),
    "agonirent": ("agonir",),
    "agonirez": ("agonir",),
    "agoniriez": ("agonir",),
    "agonirions": ("agonir",),
    "agonirons": ("agonir",),
    "agoniront": ("agonir",),
    "agonis": ("agonir",),
    "agonissaient": ("agonir",),
    "agonissais": ("agonir",),
    "agonissait": ("agonir",),
    "agonissant": ("agonir",),
    "agonissent": ("agonir",),
    "agonisse": ("agonir",),
    "agonisses": ("agonir",),
    "agonissez": ("agonir",),
    "agonissiez": ("agonir",),
    "agonissions": ("agonir",),
    "agonissons": ("agonir",),
    "agonîtes": ("agonir",),
    "agonit": ("agonir",),
    "agonît": ("agonir",),
    "agrandie": ("agrandir",),
    "agrandies": ("agrandir",),
    "agrandi": ("agrandir",),
    "agrandîmes": ("agrandir",),
    "agrandira": ("agrandir",),
    "agrandiraient": ("agrandir",),
    "agrandirai": ("agrandir",),
    "agrandirais": ("agrandir",),
    "agrandirait": ("agrandir",),
    "agrandiras": ("agrandir",),
    "agrandirent": ("agrandir",),
    "agrandirez": ("agrandir",),
    "agrandiriez": ("agrandir",),
    "agrandirions": ("agrandir",),
    "agrandirons": ("agrandir",),
    "agrandiront": ("agrandir",),
    "agrandis": ("agrandir",),
    "agrandissaient": ("agrandir",),
    "agrandissais": ("agrandir",),
    "agrandissait": ("agrandir",),
    "agrandissant": ("agrandir",),
    "agrandissent": ("agrandir",),
    "agrandisse": ("agrandir",),
    "agrandisses": ("agrandir",),
    "agrandissez": ("agrandir",),
    "agrandissiez": ("agrandir",),
    "agrandissions": ("agrandir",),
    "agrandissons": ("agrandir",),
    "agrandîtes": ("agrandir",),
    "agrandit": ("agrandir",),
    "agrandît": ("agrandir",),
    "agréaient": ("agréer",),
    "agréai": ("agréer",),
    "agréais": ("agréer",),
    "agréait": ("agréer",),
    "agréa": ("agréer",),
    "agréâmes": ("agréer",),
    "agréant": ("agréer",),
    "agréas": ("agréer",),
    "agréassent": ("agréer",),
    "agréasses": ("agréer",),
    "agréasse": ("agréer",),
    "agréassiez": ("agréer",),
    "agréassions": ("agréer",),
    "agréâtes": ("agréer",),
    "agréât": ("agréer",),
    "agréée": ("agréer",),
    "agréées": ("agréer",),
    "agréé": ("agréer",),
    "agréent": ("agréer",),
    "agrée": ("agréer",),
    "agréera": ("agréer",),
    "agréeraient": ("agréer",),
    "agréerai": ("agréer",),
    "agréerais": ("agréer",),
    "agréerait": ("agréer",),
    "agréeras": ("agréer",),
    "agréèrent": ("agréer",),
    "agréerez": ("agréer",),
    "agréeriez": ("agréer",),
    "agréerions": ("agréer",),
    "agréerons": ("agréer",),
    "agréeront": ("agréer",),
    "agréés": ("agréer",),
    "agrées": ("agréer",),
    "agréez": ("agréer",),
    "agréiez": ("agréer",),
    "agréions": ("agréer",),
    "agréons": ("agréer",),
    "agrégeaient": ("agréger",),
    "agrégeai": ("agréger",),
    "agrégeais": ("agréger",),
    "agrégeait": ("agréger",),
    "agrégea": ("agréger",),
    "agrégeâmes": ("agréger",),
    "agrégeant": ("agréger",),
    "agrégeas": ("agréger",),
    "agrégeassent": ("agréger",),
    "agrégeasses": ("agréger",),
    "agrégeasse": ("agréger",),
    "agrégeassiez": ("agréger",),
    "agrégeassions": ("agréger",),
    "agrégeâtes": ("agréger",),
    "agrégeât": ("agréger",),
    "agrégée": ("agréger",),
    "agrégées": ("agréger",),
    "agrégé": ("agréger",),
    "agrègent": ("agréger",),
    "agrégeons": ("agréger",),
    "agrège": ("agréger",),
    "agrégera": ("agréger",),
    "agrégeraient": ("agréger",),
    "agrégerai": ("agréger",),
    "agrégerais": ("agréger",),
    "agrégerait": ("agréger",),
    "agrégeras": ("agréger",),
    "agrégèrent": ("agréger",),
    "agrégerez": ("agréger",),
    "agrégeriez": ("agréger",),
    "agrégerions": ("agréger",),
    "agrégerons": ("agréger",),
    "agrégeront": ("agréger",),
    "agrégés": ("agréger",),
    "agrèges": ("agréger",),
    "agrégez": ("agréger",),
    "agrégiez": ("agréger",),
    "agrégions": ("agréger",),
    "agrenaient": ("agrener",),
    "agrenai": ("agrener",),
    "agrenais": ("agrener",),
    "agrenait": ("agrener",),
    "agrena": ("agrener",),
    "agrenâmes": ("agrener",),
    "agrenant": ("agrener",),
    "agrenas": ("agrener",),
    "agrenassent": ("agrener",),
    "agrenasses": ("agrener",),
    "agrenasse": ("agrener",),
    "agrenassiez": ("agrener",),
    "agrenassions": ("agrener",),
    "agrenâtes": ("agrener",),
    "agrenât": ("agrener",),
    "agrenée": ("agrener",),
    "agrenées": ("agrener",),
    "agrené": ("agrener",),
    "agrènent": ("agrener",),
    "agrène": ("agrener",),
    "agrènera": ("agrener",),
    "agrèneraient": ("agrener",),
    "agrènerai": ("agrener",),
    "agrènerais": ("agrener",),
    "agrènerait": ("agrener",),
    "agrèneras": ("agrener",),
    "agrenèrent": ("agrener",),
    "agrènerez": ("agrener",),
    "agrèneriez": ("agrener",),
    "agrènerions": ("agrener",),
    "agrènerons": ("agrener",),
    "agrèneront": ("agrener",),
    "agrenés": ("agrener",),
    "agrènes": ("agrener",),
    "agrenez": ("agrener",),
    "agreniez": ("agrener",),
    "agrenions": ("agrener",),
    "agrenons": ("agrener",),
    "aguerrie": ("aguerrir",),
    "aguerries": ("aguerrir",),
    "aguerri": ("aguerrir",),
    "aguerrîmes": ("aguerrir",),
    "aguerrira": ("aguerrir",),
    "aguerriraient": ("aguerrir",),
    "aguerrirai": ("aguerrir",),
    "aguerrirais": ("aguerrir",),
    "aguerrirait": ("aguerrir",),
    "aguerriras": ("aguerrir",),
    "aguerrirent": ("aguerrir",),
    "aguerrirez": ("aguerrir",),
    "aguerririez": ("aguerrir",),
    "aguerririons": ("aguerrir",),
    "aguerrirons": ("aguerrir",),
    "aguerriront": ("aguerrir",),
    "aguerris": ("aguerrir",),
    "aguerrissaient": ("aguerrir",),
    "aguerrissais": ("aguerrir",),
    "aguerrissait": ("aguerrir",),
    "aguerrissant": ("aguerrir",),
    "aguerrissent": ("aguerrir",),
    "aguerrisse": ("aguerrir",),
    "aguerrisses": ("aguerrir",),
    "aguerrissez": ("aguerrir",),
    "aguerrissiez": ("aguerrir",),
    "aguerrissions": ("aguerrir",),
    "aguerrissons": ("aguerrir",),
    "aguerrîtes": ("aguerrir",),
    "aguerrit": ("aguerrir",),
    "aguerrît": ("aguerrir",),
    "ahurie": ("ahurir",),
    "ahuries": ("ahurir",),
    "ahuri": ("ahurir",),
    "ahurîmes": ("ahurir",),
    "ahurira": ("ahurir",),
    "ahuriraient": ("ahurir",),
    "ahurirai": ("ahurir",),
    "ahurirais": ("ahurir",),
    "ahurirait": ("ahurir",),
    "ahuriras": ("ahurir",),
    "ahurirent": ("ahurir",),
    "ahurirez": ("ahurir",),
    "ahuririez": ("ahurir",),
    "ahuririons": ("ahurir",),
    "ahurirons": ("ahurir",),
    "ahuriront": ("ahurir",),
    "ahuris": ("ahurir",),
    "ahurissaient": ("ahurir",),
    "ahurissais": ("ahurir",),
    "ahurissait": ("ahurir",),
    "ahurissant": ("ahurir",),
    "ahurissent": ("ahurir",),
    "ahurisse": ("ahurir",),
    "ahurisses": ("ahurir",),
    "ahurissez": ("ahurir",),
    "ahurissiez": ("ahurir",),
    "ahurissions": ("ahurir",),
    "ahurissons": ("ahurir",),
    "ahurîtes": ("ahurir",),
    "ahurit": ("ahurir",),
    "ahurît": ("ahurir",),
    "aigrie": ("aigrir",),
    "aigries": ("aigrir",),
    "aigri": ("aigrir",),
    "aigrîmes": ("aigrir",),
    "aigrira": ("aigrir",),
    "aigriraient": ("aigrir",),
    "aigrirai": ("aigrir",),
    "aigrirais": ("aigrir",),
    "aigrirait": ("aigrir",),
    "aigriras": ("aigrir",),
    "aigrirent": ("aigrir",),
    "aigrirez": ("aigrir",),
    "aigririez": ("aigrir",),
    "aigririons": ("aigrir",),
    "aigrirons": ("aigrir",),
    "aigriront": ("aigrir",),
    "aigris": ("aigrir",),
    "aigrissaient": ("aigrir",),
    "aigrissais": ("aigrir",),
    "aigrissait": ("aigrir",),
    "aigrissant": ("aigrir",),
    "aigrissent": ("aigrir",),
    "aigrisse": ("aigrir",),
    "aigrisses": ("aigrir",),
    "aigrissez": ("aigrir",),
    "aigrissiez": ("aigrir",),
    "aigrissions": ("aigrir",),
    "aigrissons": ("aigrir",),
    "aigrîtes": ("aigrir",),
    "aigrit": ("aigrir",),
    "aigrît": ("aigrir",),
    "aiguaient": ("aiguayer",),
    "aiguaie": ("aiguayer",),
    "aiguaiera": ("aiguayer",),
    "aiguaieraient": ("aiguayer",),
    "aiguaierai": ("aiguayer",),
    "aiguaierais": ("aiguayer",),
    "aiguaierait": ("aiguayer",),
    "aiguaieras": ("aiguayer",),
    "aiguaierez": ("aiguayer",),
    "aiguaieriez": ("aiguayer",),
    "aiguaierions": ("aiguayer",),
    "aiguaierons": ("aiguayer",),
    "aiguaieront": ("aiguayer",),
    "aiguaies": ("aiguayer",),
    "aiguayaient": ("aiguayer",),
    "aiguayai": ("aiguayer",),
    "aiguayais": ("aiguayer",),
    "aiguayait": ("aiguayer",),
    "aiguaya": ("aiguayer",),
    "aiguayâmes": ("aiguayer",),
    "aiguayant": ("aiguayer",),
    "aiguayas": ("aiguayer",),
    "aiguayassent": ("aiguayer",),
    "aiguayasses": ("aiguayer",),
    "aiguayasse": ("aiguayer",),
    "aiguayassiez": ("aiguayer",),
    "aiguayassions": ("aiguayer",),
    "aiguayâtes": ("aiguayer",),
    "aiguayât": ("aiguayer",),
    "aiguayée": ("aiguayer",),
    "aiguayées": ("aiguayer",),
    "aiguayé": ("aiguayer",),
    "aiguayent": ("aiguayer",),
    "aiguaye": ("aiguayer",),
    "aiguayera": ("aiguayer",),
    "aiguayeraient": ("aiguayer",),
    "aiguayerai": ("aiguayer",),
    "aiguayerais": ("aiguayer",),
    "aiguayerait": ("aiguayer",),
    "aiguayeras": ("aiguayer",),
    "aiguayèrent": ("aiguayer",),
    "aiguayerez": ("aiguayer",),
    "aiguayeriez": ("aiguayer",),
    "aiguayerions": ("aiguayer",),
    "aiguayerons": ("aiguayer",),
    "aiguayeront": ("aiguayer",),
    "aiguayés": ("aiguayer",),
    "aiguayes": ("aiguayer",),
    "aiguayez": ("aiguayer",),
    "aiguayiez": ("aiguayer",),
    "aiguayions": ("aiguayer",),
    "aiguayons": ("aiguayer",),
    "aiguilletaient": ("aiguilleter",),
    "aiguilletai": ("aiguilleter",),
    "aiguilletais": ("aiguilleter",),
    "aiguilletait": ("aiguilleter",),
    "aiguilleta": ("aiguilleter",),
    "aiguilletâmes": ("aiguilleter",),
    "aiguilletant": ("aiguilleter",),
    "aiguilletas": ("aiguilleter",),
    "aiguilletassent": ("aiguilleter",),
    "aiguilletasses": ("aiguilleter",),
    "aiguilletasse": ("aiguilleter",),
    "aiguilletassiez": ("aiguilleter",),
    "aiguilletassions": ("aiguilleter",),
    "aiguilletâtes": ("aiguilleter",),
    "aiguilletât": ("aiguilleter",),
    "aiguilletée": ("aiguilleter",),
    "aiguilletées": ("aiguilleter",),
    "aiguilleté": ("aiguilleter",),
    "aiguilletèrent": ("aiguilleter",),
    "aiguilletés": ("aiguilleter",),
    "aiguilletez": ("aiguilleter",),
    "aiguilletiez": ("aiguilleter",),
    "aiguilletions": ("aiguilleter",),
    "aiguilletons": ("aiguilleter",),
    "aiguillettent": ("aiguilleter",),
    "aiguillette": ("aiguilleter",),
    "aiguillettera": ("aiguilleter",),
    "aiguilletteraient": ("aiguilleter",),
    "aiguilletterai": ("aiguilleter",),
    "aiguilletterais": ("aiguilleter",),
    "aiguilletterait": ("aiguilleter",),
    "aiguilletteras": ("aiguilleter",),
    "aiguilletterez": ("aiguilleter",),
    "aiguilletteriez": ("aiguilleter",),
    "aiguilletterions": ("aiguilleter",),
    "aiguilletterons": ("aiguilleter",),
    "aiguilletteront": ("aiguilleter",),
    "aiguillettes": ("aiguilleter",),
    "alâchie": ("alâchir",),
    "alâchies": ("alâchir",),
    "alâchi": ("alâchir",),
    "alâchîmes": ("alâchir",),
    "alâchira": ("alâchir",),
    "alâchiraient": ("alâchir",),
    "alâchirai": ("alâchir",),
    "alâchirais": ("alâchir",),
    "alâchirait": ("alâchir",),
    "alâchiras": ("alâchir",),
    "alâchirent": ("alâchir",),
    "alâchirez": ("alâchir",),
    "alâchiriez": ("alâchir",),
    "alâchirions": ("alâchir",),
    "alâchirons": ("alâchir",),
    "alâchiront": ("alâchir",),
    "alâchis": ("alâchir",),
    "alâchissaient": ("alâchir",),
    "alâchissais": ("alâchir",),
    "alâchissait": ("alâchir",),
    "alâchissant": ("alâchir",),
    "alâchissent": ("alâchir",),
    "alâchisse": ("alâchir",),
    "alâchisses": ("alâchir",),
    "alâchissez": ("alâchir",),
    "alâchissiez": ("alâchir",),
    "alâchissions": ("alâchir",),
    "alâchissons": ("alâchir",),
    "alâchîtes": ("alâchir",),
    "alâchit": ("alâchir",),
    "alâchît": ("alâchir",),
    "alanguie": ("alanguir",),
    "alanguies": ("alanguir",),
    "alangui": ("alanguir",),
    "alanguîmes": ("alanguir",),
    "alanguira": ("alanguir",),
    "alanguiraient": ("alanguir",),
    "alanguirai": ("alanguir",),
    "alanguirais": ("alanguir",),
    "alanguirait": ("alanguir",),
    "alanguiras": ("alanguir",),
    "alanguirent": ("alanguir",),
    "alanguirez": ("alanguir",),
    "alanguiriez": ("alanguir",),
    "alanguirions": ("alanguir",),
    "alanguirons": ("alanguir",),
    "alanguiront": ("alanguir",),
    "alanguis": ("alanguir",),
    "alanguissaient": ("alanguir",),
    "alanguissais": ("alanguir",),
    "alanguissait": ("alanguir",),
    "alanguissant": ("alanguir",),
    "alanguissent": ("alanguir",),
    "alanguisse": ("alanguir",),
    "alanguisses": ("alanguir",),
    "alanguissez": ("alanguir",),
    "alanguissiez": ("alanguir",),
    "alanguissions": ("alanguir",),
    "alanguissons": ("alanguir",),
    "alanguîtes": ("alanguir",),
    "alanguit": ("alanguir",),
    "alanguît": ("alanguir",),
    "alcoolifiaient": ("alcoolifier",),
    "alcoolifiai": ("alcoolifier",),
    "alcoolifiais": ("alcoolifier",),
    "alcoolifiait": ("alcoolifier",),
    "alcoolifia": ("alcoolifier",),
    "alcoolifiâmes": ("alcoolifier",),
    "alcoolifiant": ("alcoolifier",),
    "alcoolifias": ("alcoolifier",),
    "alcoolifiassent": ("alcoolifier",),
    "alcoolifiasses": ("alcoolifier",),
    "alcoolifiasse": ("alcoolifier",),
    "alcoolifiassiez": ("alcoolifier",),
    "alcoolifiassions": ("alcoolifier",),
    "alcoolifiâtes": ("alcoolifier",),
    "alcoolifiât": ("alcoolifier",),
    "alcoolifiée": ("alcoolifier",),
    "alcoolifiées": ("alcoolifier",),
    "alcoolifié": ("alcoolifier",),
    "alcoolifient": ("alcoolifier",),
    "alcoolifie": ("alcoolifier",),
    "alcoolifiera": ("alcoolifier",),
    "alcoolifieraient": ("alcoolifier",),
    "alcoolifierai": ("alcoolifier",),
    "alcoolifierais": ("alcoolifier",),
    "alcoolifierait": ("alcoolifier",),
    "alcoolifieras": ("alcoolifier",),
    "alcoolifièrent": ("alcoolifier",),
    "alcoolifierez": ("alcoolifier",),
    "alcoolifieriez": ("alcoolifier",),
    "alcoolifierions": ("alcoolifier",),
    "alcoolifierons": ("alcoolifier",),
    "alcoolifieront": ("alcoolifier",),
    "alcoolifiés": ("alcoolifier",),
    "alcoolifies": ("alcoolifier",),
    "alcoolifiez": ("alcoolifier",),
    "alcoolifiiez": ("alcoolifier",),
    "alcoolifiions": ("alcoolifier",),
    "alcoolifions": ("alcoolifier",),
    "alentie": ("alentir",),
    "alenties": ("alentir",),
    "alenti": ("alentir",),
    "alentîmes": ("alentir",),
    "alentira": ("alentir",),
    "alentiraient": ("alentir",),
    "alentirai": ("alentir",),
    "alentirais": ("alentir",),
    "alentirait": ("alentir",),
    "alentiras": ("alentir",),
    "alentirent": ("alentir",),
    "alentirez": ("alentir",),
    "alentiriez": ("alentir",),
    "alentirions": ("alentir",),
    "alentirons": ("alentir",),
    "alentiront": ("alentir",),
    "alentis": ("alentir",),
    "alentissaient": ("alentir",),
    "alentissais": ("alentir",),
    "alentissait": ("alentir",),
    "alentissant": ("alentir",),
    "alentissent": ("alentir",),
    "alentisse": ("alentir",),
    "alentisses": ("alentir",),
    "alentissez": ("alentir",),
    "alentissiez": ("alentir",),
    "alentissions": ("alentir",),
    "alentissons": ("alentir",),
    "alentîtes": ("alentir",),
    "alentit": ("alentir",),
    "alentît": ("alentir",),
    "alésaient": ("aléser",),
    "alésai": ("aléser",),
    "alésais": ("aléser",),
    "alésait": ("aléser",),
    "alésa": ("aléser",),
    "alésâmes": ("aléser",),
    "alésant": ("aléser",),
    "alésas": ("aléser",),
    "alésassent": ("aléser",),
    "alésasses": ("aléser",),
    "alésasse": ("aléser",),
    "alésassiez": ("aléser",),
    "alésassions": ("aléser",),
    "alésâtes": ("aléser",),
    "alésât": ("aléser",),
    "alésée": ("aléser",),
    "alésées": ("aléser",),
    "alésé": ("aléser",),
    "alèsent": ("aléser",),
    "alèse": ("aléser",),
    "alésera": ("aléser",),
    "aléseraient": ("aléser",),
    "aléserai": ("aléser",),
    "aléserais": ("aléser",),
    "aléserait": ("aléser",),
    "aléseras": ("aléser",),
    "alésèrent": ("aléser",),
    "aléserez": ("aléser",),
    "aléseriez": ("aléser",),
    "aléserions": ("aléser",),
    "aléserons": ("aléser",),
    "aléseront": ("aléser",),
    "alésés": ("aléser",),
    "alèses": ("aléser",),
    "alésez": ("aléser",),
    "alésiez": ("aléser",),
    "alésions": ("aléser",),
    "alésons": ("aléser",),
    "alestie": ("alestir",),
    "alesties": ("alestir",),
    "alesti": ("alestir",),
    "alestîmes": ("alestir",),
    "alestira": ("alestir",),
    "alestiraient": ("alestir",),
    "alestirai": ("alestir",),
    "alestirais": ("alestir",),
    "alestirait": ("alestir",),
    "alestiras": ("alestir",),
    "alestirent": ("alestir",),
    "alestirez": ("alestir",),
    "alestiriez": ("alestir",),
    "alestirions": ("alestir",),
    "alestirons": ("alestir",),
    "alestiront": ("alestir",),
    "alestis": ("alestir",),
    "alestissaient": ("alestir",),
    "alestissais": ("alestir",),
    "alestissait": ("alestir",),
    "alestissant": ("alestir",),
    "alestissent": ("alestir",),
    "alestisse": ("alestir",),
    "alestisses": ("alestir",),
    "alestissez": ("alestir",),
    "alestissiez": ("alestir",),
    "alestissions": ("alestir",),
    "alestissons": ("alestir",),
    "alestîtes": ("alestir",),
    "alestit": ("alestir",),
    "alestît": ("alestir",),
    "aliénaient": ("aliéner",),
    "aliénai": ("aliéner",),
    "aliénais": ("aliéner",),
    "aliénait": ("aliéner",),
    "aliéna": ("aliéner",),
    "aliénâmes": ("aliéner",),
    "aliénant": ("aliéner",),
    "aliénas": ("aliéner",),
    "aliénassent": ("aliéner",),
    "aliénasses": ("aliéner",),
    "aliénasse": ("aliéner",),
    "aliénassiez": ("aliéner",),
    "aliénassions": ("aliéner",),
    "aliénâtes": ("aliéner",),
    "aliénât": ("aliéner",),
    "aliénée": ("aliéner",),
    "aliénées": ("aliéner",),
    "aliéné": ("aliéner",),
    "aliènent": ("aliéner",),
    "aliène": ("aliéner",),
    "aliénera": ("aliéner",),
    "aliéneraient": ("aliéner",),
    "aliénerai": ("aliéner",),
    "aliénerais": ("aliéner",),
    "aliénerait": ("aliéner",),
    "aliéneras": ("aliéner",),
    "aliénèrent": ("aliéner",),
    "aliénerez": ("aliéner",),
    "aliéneriez": ("aliéner",),
    "aliénerions": ("aliéner",),
    "aliénerons": ("aliéner",),
    "aliéneront": ("aliéner",),
    "aliénés": ("aliéner",),
    "aliènes": ("aliéner",),
    "aliénez": ("aliéner",),
    "aliéniez": ("aliéner",),
    "aliénions": ("aliéner",),
    "aliénons": ("aliéner",),
    "alingeaient": ("alinger",),
    "alingeai": ("alinger",),
    "alingeais": ("alinger",),
    "alingeait": ("alinger",),
    "alingea": ("alinger",),
    "alingeâmes": ("alinger",),
    "alingeant": ("alinger",),
    "alingeas": ("alinger",),
    "alingeassent": ("alinger",),
    "alingeasses": ("alinger",),
    "alingeasse": ("alinger",),
    "alingeassiez": ("alinger",),
    "alingeassions": ("alinger",),
    "alingeâtes": ("alinger",),
    "alingeât": ("alinger",),
    "alingée": ("alinger",),
    "alingées": ("alinger",),
    "alingé": ("alinger",),
    "alingent": ("alinger",),
    "alingeons": ("alinger",),
    "alinge": ("alinger",),
    "alingera": ("alinger",),
    "alingeraient": ("alinger",),
    "alingerai": ("alinger",),
    "alingerais": ("alinger",),
    "alingerait": ("alinger",),
    "alingeras": ("alinger",),
    "alingèrent": ("alinger",),
    "alingerez": ("alinger",),
    "alingeriez": ("alinger",),
    "alingerions": ("alinger",),
    "alingerons": ("alinger",),
    "alingeront": ("alinger",),
    "alingés": ("alinger",),
    "alinges": ("alinger",),
    "alingez": ("alinger",),
    "alingiez": ("alinger",),
    "alingions": ("alinger",),
    "alléchaient": ("allécher",),
    "alléchai": ("allécher",),
    "alléchais": ("allécher",),
    "alléchait": ("allécher",),
    "allécha": ("allécher",),
    "alléchâmes": ("allécher",),
    "alléchant": ("allécher",),
    "alléchas": ("allécher",),
    "alléchassent": ("allécher",),
    "alléchasses": ("allécher",),
    "alléchasse": ("allécher",),
    "alléchassiez": ("allécher",),
    "alléchassions": ("allécher",),
    "alléchâtes": ("allécher",),
    "alléchât": ("allécher",),
    "alléchée": ("allécher",),
    "alléchées": ("allécher",),
    "alléché": ("allécher",),
    "allèchent": ("allécher",),
    "allèche": ("allécher",),
    "alléchera": ("allécher",),
    "allécheraient": ("allécher",),
    "allécherai": ("allécher",),
    "allécherais": ("allécher",),
    "allécherait": ("allécher",),
    "allécheras": ("allécher",),
    "alléchèrent": ("allécher",),
    "allécherez": ("allécher",),
    "allécheriez": ("allécher",),
    "allécherions": ("allécher",),
    "allécherons": ("allécher",),
    "allécheront": ("allécher",),
    "alléchés": ("allécher",),
    "allèches": ("allécher",),
    "alléchez": ("allécher",),
    "alléchiez": ("allécher",),
    "alléchions": ("allécher",),
    "alléchons": ("allécher",),
    "allégeaient": ("alléger",),
    "allégeai": ("alléger",),
    "allégeais": ("alléger",),
    "allégeait": ("alléger",),
    "allégea": ("alléger",),
    "allégeâmes": ("alléger",),
    "allégeant": ("alléger",),
    "allégeas": ("alléger",),
    "allégeassent": ("alléger",),
    "allégeasses": ("alléger",),
    "allégeasse": ("alléger",),
    "allégeassiez": ("alléger",),
    "allégeassions": ("alléger",),
    "allégeâtes": ("alléger",),
    "allégeât": ("alléger",),
    "allégée": ("alléger",),
    "allégées": ("alléger",),
    "allégé": ("alléger",),
    "allègent": ("alléger",),
    "allégeons": ("alléger",),
    "allège": ("alléger",),
    "allégera": ("alléger",),
    "allégeraient": ("alléger",),
    "allégerai": ("alléger",),
    "allégerais": ("alléger",),
    "allégerait": ("alléger",),
    "allégeras": ("alléger",),
    "allégèrent": ("alléger",),
    "allégerez": ("alléger",),
    "allégeriez": ("alléger",),
    "allégerions": ("alléger",),
    "allégerons": ("alléger",),
    "allégeront": ("alléger",),
    "allégés": ("alléger",),
    "allèges": ("alléger",),
    "allégez": ("alléger",),
    "allégiez": ("alléger",),
    "allégions": ("alléger",),
    "allégie": ("allégir",),
    "allégies": ("allégir",),
    "allégi": ("allégir",),
    "allégîmes": ("allégir",),
    "allégira": ("allégir",),
    "allégiraient": ("allégir",),
    "allégirai": ("allégir",),
    "allégirais": ("allégir",),
    "allégirait": ("allégir",),
    "allégiras": ("allégir",),
    "allégirent": ("allégir",),
    "allégirez": ("allégir",),
    "allégiriez": ("allégir",),
    "allégirions": ("allégir",),
    "allégirons": ("allégir",),
    "allégiront": ("allégir",),
    "allégis": ("allégir",),
    "allégissaient": ("allégir",),
    "allégissais": ("allégir",),
    "allégissait": ("allégir",),
    "allégissant": ("allégir",),
    "allégissent": ("allégir",),
    "allégisse": ("allégir",),
    "allégisses": ("allégir",),
    "allégissez": ("allégir",),
    "allégissiez": ("allégir",),
    "allégissions": ("allégir",),
    "allégissons": ("allégir",),
    "allégîtes": ("allégir",),
    "allégit": ("allégir",),
    "allégît": ("allégir",),
    "alléguaient": ("alléguer",),
    "alléguai": ("alléguer",),
    "alléguais": ("alléguer",),
    "alléguait": ("alléguer",),
    "allégua": ("alléguer",),
    "alléguâmes": ("alléguer",),
    "alléguant": ("alléguer",),
    "alléguas": ("alléguer",),
    "alléguassent": ("alléguer",),
    "alléguasses": ("alléguer",),
    "alléguasse": ("alléguer",),
    "alléguassiez": ("alléguer",),
    "alléguassions": ("alléguer",),
    "alléguâtes": ("alléguer",),
    "alléguât": ("alléguer",),
    "alléguée": ("alléguer",),
    "alléguées": ("alléguer",),
    "allégué": ("alléguer",),
    "allèguent": ("alléguer",),
    "allègue": ("alléguer",),
    "alléguera": ("alléguer",),
    "allégueraient": ("alléguer",),
    "alléguerai": ("alléguer",),
    "alléguerais": ("alléguer",),
    "alléguerait": ("alléguer",),
    "allégueras": ("alléguer",),
    "alléguèrent": ("alléguer",),
    "alléguerez": ("alléguer",),
    "allégueriez": ("alléguer",),
    "alléguerions": ("alléguer",),
    "alléguerons": ("alléguer",),
    "allégueront": ("alléguer",),
    "allégués": ("alléguer",),
    "allègues": ("alléguer",),
    "alléguez": ("alléguer",),
    "alléguiez": ("alléguer",),
    "alléguions": ("alléguer",),
    "alléguons": ("alléguer",),
    "aillent": ("aller",),
    "aille": ("aller",),
    "ailles": ("aller",),
    "allaient": ("aller",),
    "allai": ("aller",),
    "allais": ("aller",),
    "allait": ("aller",),
    "alla": ("aller",),
    "allâmes": ("aller",),
    "allant": ("aller",),
    "allas": ("aller",),
    "allassent": ("aller",),
    "allasses": ("aller",),
    "allasse": ("aller",),
    "allassiez": ("aller",),
    "allassions": ("aller",),
    "allâtes": ("aller",),
    "allât": ("aller",),
    "allée": ("aller",),
    "allées": ("aller",),
    "allé": ("aller",),
    "allèrent": ("aller",),
    "allés": ("aller",),
    "allez": ("aller",),
    "alliez": ("allier",),
    "allions": ("allier",),
    "allons": ("aller",),
    "ira": ("aller",),
    "iraient": ("aller",),
    "irai": ("aller",),
    "irais": ("aller",),
    "irait": ("aller",),
    "iras": ("aller",),
    "irez": ("aller",),
    "iriez": ("aller",),
    "irions": ("aller",),
    "irons": ("aller",),
    "iront": ("aller",),
    "vais": ("aller",),
    "va": ("aller",),
    "vas": ("aller",),
    "vont": ("aller",),
    "alliaient": ("allier",),
    "alliai": ("allier",),
    "alliais": ("allier",),
    "alliait": ("allier",),
    "allia": ("allier",),
    "alliâmes": ("allier",),
    "alliant": ("allier",),
    "allias": ("allier",),
    "alliassent": ("allier",),
    "alliasses": ("allier",),
    "alliasse": ("allier",),
    "alliassiez": ("allier",),
    "alliassions": ("allier",),
    "alliâtes": ("allier",),
    "alliât": ("allier",),
    "alliée": ("allier",),
    "alliées": ("allier",),
    "allié": ("allier",),
    "allient": ("allier",),
    "allie": ("allier",),
    "alliera": ("allier",),
    "allieraient": ("allier",),
    "allierai": ("allier",),
    "allierais": ("allier",),
    "allierait": ("allier",),
    "allieras": ("allier",),
    "allièrent": ("allier",),
    "allierez": ("allier",),
    "allieriez": ("allier",),
    "allierions": ("allier",),
    "allierons": ("allier",),
    "allieront": ("allier",),
    "alliés": ("allier",),
    "allies": ("allier",),
    "alliiez": ("allier",),
    "alliions": ("allier",),
    "allitéraient": ("allitérer",),
    "allitérai": ("allitérer",),
    "allitérais": ("allitérer",),
    "allitérait": ("allitérer",),
    "allitéra": ("allitérer",),
    "allitérâmes": ("allitérer",),
    "allitérant": ("allitérer",),
    "allitéras": ("allitérer",),
    "allitérassent": ("allitérer",),
    "allitérasses": ("allitérer",),
    "allitérasse": ("allitérer",),
    "allitérassiez": ("allitérer",),
    "allitérassions": ("allitérer",),
    "allitérâtes": ("allitérer",),
    "allitérât": ("allitérer",),
    "allitérée": ("allitérer",),
    "allitérées": ("allitérer",),
    "allitéré": ("allitérer",),
    "allitèrent": ("allitérer",),
    "allitère": ("allitérer",),
    "allitérera": ("allitérer",),
    "allitéreraient": ("allitérer",),
    "allitérerai": ("allitérer",),
    "allitérerais": ("allitérer",),
    "allitérerait": ("allitérer",),
    "allitéreras": ("allitérer",),
    "allitérèrent": ("allitérer",),
    "allitérerez": ("allitérer",),
    "allitéreriez": ("allitérer",),
    "allitérerions": ("allitérer",),
    "allitérerons": ("allitérer",),
    "allitéreront": ("allitérer",),
    "allitérés": ("allitérer",),
    "allitères": ("allitérer",),
    "allitérez": ("allitérer",),
    "allitériez": ("allitérer",),
    "allitérions": ("allitérer",),
    "allitérons": ("allitérer",),
    "allongeaient": ("allonger",),
    "allongeai": ("allonger",),
    "allongeais": ("allonger",),
    "allongeait": ("allonger",),
    "allongea": ("allonger",),
    "allongeâmes": ("allonger",),
    "allongeant": ("allonger",),
    "allongeas": ("allonger",),
    "allongeassent": ("allonger",),
    "allongeasses": ("allonger",),
    "allongeasse": ("allonger",),
    "allongeassiez": ("allonger",),
    "allongeassions": ("allonger",),
    "allongeâtes": ("allonger",),
    "allongeât": ("allonger",),
    "allongée": ("allonger",),
    "allongées": ("allonger",),
    "allongé": ("allonger",),
    "allongent": ("allonger",),
    "allongeons": ("allonger",),
    "allonge": ("allonger",),
    "allongera": ("allonger",),
    "allongeraient": ("allonger",),
    "allongerai": ("allonger",),
    "allongerais": ("allonger",),
    "allongerait": ("allonger",),
    "allongeras": ("allonger",),
    "allongèrent": ("allonger",),
    "allongerez": ("allonger",),
    "allongeriez": ("allonger",),
    "allongerions": ("allonger",),
    "allongerons": ("allonger",),
    "allongeront": ("allonger",),
    "allongés": ("allonger",),
    "allonges": ("allonger",),
    "allongez": ("allonger",),
    "allongiez": ("allonger",),
    "allongions": ("allonger",),
    "allotie": ("allotir",),
    "alloties": ("allotir",),
    "alloti": ("allotir",),
    "allotîmes": ("allotir",),
    "allotira": ("allotir",),
    "allotiraient": ("allotir",),
    "allotirai": ("allotir",),
    "allotirais": ("allotir",),
    "allotirait": ("allotir",),
    "allotiras": ("allotir",),
    "allotirent": ("allotir",),
    "allotirez": ("allotir",),
    "allotiriez": ("allotir",),
    "allotirions": ("allotir",),
    "allotirons": ("allotir",),
    "allotiront": ("allotir",),
    "allotis": ("allotir",),
    "allotissaient": ("allotir",),
    "allotissais": ("allotir",),
    "allotissait": ("allotir",),
    "allotissant": ("allotir",),
    "allotissent": ("allotir",),
    "allotisse": ("allotir",),
    "allotisses": ("allotir",),
    "allotissez": ("allotir",),
    "allotissiez": ("allotir",),
    "allotissions": ("allotir",),
    "allotissons": ("allotir",),
    "allotîtes": ("allotir",),
    "allotit": ("allotir",),
    "allotît": ("allotir",),
    "allouvie": ("allouvir",),
    "allouvies": ("allouvir",),
    "allouvi": ("allouvir",),
    "allouvîmes": ("allouvir",),
    "allouvira": ("allouvir",),
    "allouviraient": ("allouvir",),
    "allouvirai": ("allouvir",),
    "allouvirais": ("allouvir",),
    "allouvirait": ("allouvir",),
    "allouviras": ("allouvir",),
    "allouvirent": ("allouvir",),
    "allouvirez": ("allouvir",),
    "allouviriez": ("allouvir",),
    "allouvirions": ("allouvir",),
    "allouvirons": ("allouvir",),
    "allouviront": ("allouvir",),
    "allouvis": ("allouvir",),
    "allouvissaient": ("allouvir",),
    "allouvissais": ("allouvir",),
    "allouvissait": ("allouvir",),
    "allouvissant": ("allouvir",),
    "allouvissent": ("allouvir",),
    "allouvisse": ("allouvir",),
    "allouvisses": ("allouvir",),
    "allouvissez": ("allouvir",),
    "allouvissiez": ("allouvir",),
    "allouvissions": ("allouvir",),
    "allouvissons": ("allouvir",),
    "allouvîtes": ("allouvir",),
    "allouvit": ("allouvir",),
    "allouvît": ("allouvir",),
    "alourdie": ("alourdir",),
    "alourdies": ("alourdir",),
    "alourdi": ("alourdir",),
    "alourdîmes": ("alourdir",),
    "alourdira": ("alourdir",),
    "alourdiraient": ("alourdir",),
    "alourdirai": ("alourdir",),
    "alourdirais": ("alourdir",),
    "alourdirait": ("alourdir",),
    "alourdiras": ("alourdir",),
    "alourdirent": ("alourdir",),
    "alourdirez": ("alourdir",),
    "alourdiriez": ("alourdir",),
    "alourdirions": ("alourdir",),
    "alourdirons": ("alourdir",),
    "alourdiront": ("alourdir",),
    "alourdis": ("alourdir",),
    "alourdissaient": ("alourdir",),
    "alourdissais": ("alourdir",),
    "alourdissait": ("alourdir",),
    "alourdissant": ("alourdir",),
    "alourdissent": ("alourdir",),
    "alourdisse": ("alourdir",),
    "alourdisses": ("alourdir",),
    "alourdissez": ("alourdir",),
    "alourdissiez": ("alourdir",),
    "alourdissions": ("alourdir",),
    "alourdissons": ("alourdir",),
    "alourdîtes": ("alourdir",),
    "alourdit": ("alourdir",),
    "alourdît": ("alourdir",),
    "alouvie": ("alouvir",),
    "alouvies": ("alouvir",),
    "alouvi": ("alouvir",),
    "alouvîmes": ("alouvir",),
    "alouvira": ("alouvir",),
    "alouviraient": ("alouvir",),
    "alouvirai": ("alouvir",),
    "alouvirais": ("alouvir",),
    "alouvirait": ("alouvir",),
    "alouviras": ("alouvir",),
    "alouvirent": ("alouvir",),
    "alouvirez": ("alouvir",),
    "alouviriez": ("alouvir",),
    "alouvirions": ("alouvir",),
    "alouvirons": ("alouvir",),
    "alouviront": ("alouvir",),
    "alouvis": ("alouvir",),
    "alouvissaient": ("alouvir",),
    "alouvissais": ("alouvir",),
    "alouvissait": ("alouvir",),
    "alouvissant": ("alouvir",),
    "alouvissent": ("alouvir",),
    "alouvisse": ("alouvir",),
    "alouvisses": ("alouvir",),
    "alouvissez": ("alouvir",),
    "alouvissiez": ("alouvir",),
    "alouvissions": ("alouvir",),
    "alouvissons": ("alouvir",),
    "alouvîtes": ("alouvir",),
    "alouvit": ("alouvir",),
    "alouvît": ("alouvir",),
    "aloient": ("aloyer",),
    "aloie": ("aloyer",),
    "aloiera": ("aloyer",),
    "aloieraient": ("aloyer",),
    "aloierai": ("aloyer",),
    "aloierais": ("aloyer",),
    "aloierait": ("aloyer",),
    "aloieras": ("aloyer",),
    "aloierez": ("aloyer",),
    "aloieriez": ("aloyer",),
    "aloierions": ("aloyer",),
    "aloierons": ("aloyer",),
    "aloieront": ("aloyer",),
    "aloies": ("aloyer",),
    "aloyaient": ("aloyer",),
    "aloyai": ("aloyer",),
    "aloyais": ("aloyer",),
    "aloyait": ("aloyer",),
    "aloya": ("aloyer",),
    "aloyâmes": ("aloyer",),
    "aloyant": ("aloyer",),
    "aloyas": ("aloyer",),
    "aloyassent": ("aloyer",),
    "aloyasses": ("aloyer",),
    "aloyasse": ("aloyer",),
    "aloyassiez": ("aloyer",),
    "aloyassions": ("aloyer",),
    "aloyâtes": ("aloyer",),
    "aloyât": ("aloyer",),
    "aloyée": ("aloyer",),
    "aloyées": ("aloyer",),
    "aloyé": ("aloyer",),
    "aloyèrent": ("aloyer",),
    "aloyés": ("aloyer",),
    "aloyez": ("aloyer",),
    "aloyiez": ("aloyer",),
    "aloyions": ("aloyer",),
    "aloyons": ("aloyer",),
    "altéraient": ("altérer",),
    "altérai": ("altérer",),
    "altérais": ("altérer",),
    "altérait": ("altérer",),
    "altéra": ("altérer",),
    "altérâmes": ("altérer",),
    "altérant": ("altérer",),
    "altéras": ("altérer",),
    "altérassent": ("altérer",),
    "altérasses": ("altérer",),
    "altérasse": ("altérer",),
    "altérassiez": ("altérer",),
    "altérassions": ("altérer",),
    "altérâtes": ("altérer",),
    "altérât": ("altérer",),
    "altérée": ("altérer",),
    "altérées": ("altérer",),
    "altéré": ("altérer",),
    "altèrent": ("altérer",),
    "altère": ("altérer",),
    "altérera": ("altérer",),
    "altéreraient": ("altérer",),
    "altérerai": ("altérer",),
    "altérerais": ("altérer",),
    "altérerait": ("altérer",),
    "altéreras": ("altérer",),
    "altérèrent": ("altérer",),
    "altérerez": ("altérer",),
    "altéreriez": ("altérer",),
    "altérerions": ("altérer",),
    "altérerons": ("altérer",),
    "altéreront": ("altérer",),
    "altérés": ("altérer",),
    "altères": ("altérer",),
    "altérez": ("altérer",),
    "altériez": ("altérer",),
    "altérions": ("altérer",),
    "altérons": ("altérer",),
    "aluminiaient": ("aluminier",),
    "aluminiai": ("aluminier",),
    "aluminiais": ("aluminier",),
    "aluminiait": ("aluminier",),
    "aluminia": ("aluminier",),
    "aluminiâmes": ("aluminier",),
    "aluminiant": ("aluminier",),
    "aluminias": ("aluminier",),
    "aluminiassent": ("aluminier",),
    "aluminiasses": ("aluminier",),
    "aluminiasse": ("aluminier",),
    "aluminiassiez": ("aluminier",),
    "aluminiassions": ("aluminier",),
    "aluminiâtes": ("aluminier",),
    "aluminiât": ("aluminier",),
    "aluminiée": ("aluminier",),
    "aluminiées": ("aluminier",),
    "aluminié": ("aluminier",),
    "aluminient": ("aluminier",),
    "aluminie": ("aluminier",),
    "aluminiera": ("aluminier",),
    "aluminieraient": ("aluminier",),
    "aluminierai": ("aluminier",),
    "aluminierais": ("aluminier",),
    "aluminierait": ("aluminier",),
    "aluminieras": ("aluminier",),
    "aluminièrent": ("aluminier",),
    "aluminierez": ("aluminier",),
    "aluminieriez": ("aluminier",),
    "aluminierions": ("aluminier",),
    "aluminierons": ("aluminier",),
    "aluminieront": ("aluminier",),
    "aluminiés": ("aluminier",),
    "aluminies": ("aluminier",),
    "aluminiez": ("aluminier",),
    "aluminiiez": ("aluminier",),
    "aluminiions": ("aluminier",),
    "aluminions": ("aluminier",),
    "alunie": ("alunir",),
    "alunies": ("alunir",),
    "aluni": ("alunir",),
    "alunîmes": ("alunir",),
    "alunira": ("alunir",),
    "aluniraient": ("alunir",),
    "alunirai": ("alunir",),
    "alunirais": ("alunir",),
    "alunirait": ("alunir",),
    "aluniras": ("alunir",),
    "alunirent": ("alunir",),
    "alunirez": ("alunir",),
    "aluniriez": ("alunir",),
    "alunirions": ("alunir",),
    "alunirons": ("alunir",),
    "aluniront": ("alunir",),
    "alunis": ("alunir",),
    "alunissaient": ("alunir",),
    "alunissais": ("alunir",),
    "alunissait": ("alunir",),
    "alunissant": ("alunir",),
    "alunissent": ("alunir",),
    "alunisse": ("alunir",),
    "alunisses": ("alunir",),
    "alunissez": ("alunir",),
    "alunissiez": ("alunir",),
    "alunissions": ("alunir",),
    "alunissons": ("alunir",),
    "alunîtes": ("alunir",),
    "alunit": ("alunir",),
    "alunît": ("alunir",),
    "amaigrie": ("amaigrir",),
    "amaigries": ("amaigrir",),
    "amaigri": ("amaigrir",),
    "amaigrîmes": ("amaigrir",),
    "amaigrira": ("amaigrir",),
    "amaigriraient": ("amaigrir",),
    "amaigrirai": ("amaigrir",),
    "amaigrirais": ("amaigrir",),
    "amaigrirait": ("amaigrir",),
    "amaigriras": ("amaigrir",),
    "amaigrirent": ("amaigrir",),
    "amaigrirez": ("amaigrir",),
    "amaigririez": ("amaigrir",),
    "amaigririons": ("amaigrir",),
    "amaigrirons": ("amaigrir",),
    "amaigriront": ("amaigrir",),
    "amaigris": ("amaigrir",),
    "amaigrissaient": ("amaigrir",),
    "amaigrissais": ("amaigrir",),
    "amaigrissait": ("amaigrir",),
    "amaigrissant": ("amaigrir",),
    "amaigrissent": ("amaigrir",),
    "amaigrisse": ("amaigrir",),
    "amaigrisses": ("amaigrir",),
    "amaigrissez": ("amaigrir",),
    "amaigrissiez": ("amaigrir",),
    "amaigrissions": ("amaigrir",),
    "amaigrissons": ("amaigrir",),
    "amaigrîtes": ("amaigrir",),
    "amaigrit": ("amaigrir",),
    "amaigrît": ("amaigrir",),
    "amassaient": ("amasser",),
    "amassai": ("amasser",),
    "amassais": ("amasser",),
    "amassait": ("amasser",),
    "amassa": ("amasser",),
    "amassâmes": ("amasser",),
    "amassant": ("amasser",),
    "amassas": ("amasser",),
    "amassassent": ("amasser",),
    "amassasses": ("amasser",),
    "amassasse": ("amasser",),
    "amassassiez": ("amasser",),
    "amassassions": ("amasser",),
    "amassâtes": ("amasser",),
    "amassât": ("amasser",),
    "amassée": ("amasser",),
    "amassées": ("amasser",),
    "amassé": ("amasser",),
    "amassent": ("amasser",),
    "amasse": ("amasser",),
    "amassera": ("amasser",),
    "amasseraient": ("amasser",),
    "amasserai": ("amasser",),
    "amasserais": ("amasser",),
    "amasserait": ("amasser",),
    "amasseras": ("amasser",),
    "amassèrent": ("amasser",),
    "amasserez": ("amasser",),
    "amasseriez": ("amasser",),
    "amasserions": ("amasser",),
    "amasserons": ("amasser",),
    "amasseront": ("amasser",),
    "amassés": ("amasser",),
    "amasses": ("amasser",),
    "amassez": ("amasser",),
    "amassiez": ("amasser",),
    "amassions": ("amasser",),
    "amassons": ("amasser",),
    "amatie": ("amatir",),
    "amaties": ("amatir",),
    "amati": ("amatir",),
    "amatîmes": ("amatir",),
    "amatira": ("amatir",),
    "amatiraient": ("amatir",),
    "amatirai": ("amatir",),
    "amatirais": ("amatir",),
    "amatirait": ("amatir",),
    "amatiras": ("amatir",),
    "amatirent": ("amatir",),
    "amatirez": ("amatir",),
    "amatiriez": ("amatir",),
    "amatirions": ("amatir",),
    "amatirons": ("amatir",),
    "amatiront": ("amatir",),
    "amatis": ("amatir",),
    "amatissaient": ("amatir",),
    "amatissais": ("amatir",),
    "amatissait": ("amatir",),
    "amatissant": ("amatir",),
    "amatissent": ("amatir",),
    "amatisse": ("amatir",),
    "amatisses": ("amatir",),
    "amatissez": ("amatir",),
    "amatissiez": ("amatir",),
    "amatissions": ("amatir",),
    "amatissons": ("amatir",),
    "amatîtes": ("amatir",),
    "amatit": ("amatir",),
    "amatît": ("amatir",),
    "aménageaient": ("aménager",),
    "aménageai": ("aménager",),
    "aménageais": ("aménager",),
    "aménageait": ("aménager",),
    "aménagea": ("aménager",),
    "aménageâmes": ("aménager",),
    "aménageant": ("aménager",),
    "aménageas": ("aménager",),
    "aménageassent": ("aménager",),
    "aménageasses": ("aménager",),
    "aménageasse": ("aménager",),
    "aménageassiez": ("aménager",),
    "aménageassions": ("aménager",),
    "aménageâtes": ("aménager",),
    "aménageât": ("aménager",),
    "aménagée": ("aménager",),
    "aménagées": ("aménager",),
    "aménagé": ("aménager",),
    "aménagent": ("aménager",),
    "aménageons": ("aménager",),
    "aménage": ("aménager",),
    "aménagera": ("aménager",),
    "aménageraient": ("aménager",),
    "aménagerai": ("aménager",),
    "aménagerais": ("aménager",),
    "aménagerait": ("aménager",),
    "aménageras": ("aménager",),
    "aménagèrent": ("aménager",),
    "aménagerez": ("aménager",),
    "aménageriez": ("aménager",),
    "aménagerions": ("aménager",),
    "aménagerons": ("aménager",),
    "aménageront": ("aménager",),
    "aménagés": ("aménager",),
    "aménages": ("aménager",),
    "aménagez": ("aménager",),
    "aménagiez": ("aménager",),
    "aménagions": ("aménager",),
    "amenaient": ("amener",),
    "amenai": ("amener",),
    "amenais": ("amener",),
    "amenait": ("amener",),
    "amena": ("amener",),
    "amenâmes": ("amener",),
    "amenant": ("amener",),
    "amenas": ("amener",),
    "amenassent": ("amener",),
    "amenasses": ("amener",),
    "amenasse": ("amener",),
    "amenassiez": ("amener",),
    "amenassions": ("amener",),
    "amenâtes": ("amener",),
    "amenât": ("amener",),
    "amenée": ("amener",),
    "amenées": ("amener",),
    "amené": ("amener",),
    "amènent": ("amener",),
    "amène": ("amener",),
    "amènera": ("amener",),
    "amèneraient": ("amener",),
    "amènerai": ("amener",),
    "amènerais": ("amener",),
    "amènerait": ("amener",),
    "amèneras": ("amener",),
    "amenèrent": ("amener",),
    "amènerez": ("amener",),
    "amèneriez": ("amener",),
    "amènerions": ("amener",),
    "amènerons": ("amener",),
    "amèneront": ("amener",),
    "amenés": ("amener",),
    "amènes": ("amener",),
    "amenez": ("amener",),
    "ameniez": ("amener",),
    "amenions": ("amener",),
    "amenons": ("amener",),
    "amerrie": ("amerrir",),
    "amerries": ("amerrir",),
    "amerri": ("amerrir",),
    "amerrîmes": ("amerrir",),
    "amerrira": ("amerrir",),
    "amerriraient": ("amerrir",),
    "amerrirai": ("amerrir",),
    "amerrirais": ("amerrir",),
    "amerrirait": ("amerrir",),
    "amerriras": ("amerrir",),
    "amerrirent": ("amerrir",),
    "amerrirez": ("amerrir",),
    "amerririez": ("amerrir",),
    "amerririons": ("amerrir",),
    "amerrirons": ("amerrir",),
    "amerriront": ("amerrir",),
    "amerris": ("amerrir",),
    "amerrissaient": ("amerrir",),
    "amerrissais": ("amerrir",),
    "amerrissait": ("amerrir",),
    "amerrissant": ("amerrir",),
    "amerrissent": ("amerrir",),
    "amerrisse": ("amerrir",),
    "amerrisses": ("amerrir",),
    "amerrissez": ("amerrir",),
    "amerrissiez": ("amerrir",),
    "amerrissions": ("amerrir",),
    "amerrissons": ("amerrir",),
    "amerrîtes": ("amerrir",),
    "amerrit": ("amerrir",),
    "amerrît": ("amerrir",),
    "ameublie": ("ameublir",),
    "ameublies": ("ameublir",),
    "ameubli": ("ameublir",),
    "ameublîmes": ("ameublir",),
    "ameublira": ("ameublir",),
    "ameubliraient": ("ameublir",),
    "ameublirai": ("ameublir",),
    "ameublirais": ("ameublir",),
    "ameublirait": ("ameublir",),
    "ameubliras": ("ameublir",),
    "ameublirent": ("ameublir",),
    "ameublirez": ("ameublir",),
    "ameubliriez": ("ameublir",),
    "ameublirions": ("ameublir",),
    "ameublirons": ("ameublir",),
    "ameubliront": ("ameublir",),
    "ameublis": ("ameublir",),
    "ameublissaient": ("ameublir",),
    "ameublissais": ("ameublir",),
    "ameublissait": ("ameublir",),
    "ameublissant": ("ameublir",),
    "ameublissent": ("ameublir",),
    "ameublisse": ("ameublir",),
    "ameublisses": ("ameublir",),
    "ameublissez": ("ameublir",),
    "ameublissiez": ("ameublir",),
    "ameublissions": ("ameublir",),
    "ameublissons": ("ameublir",),
    "ameublîtes": ("ameublir",),
    "ameublit": ("ameublir",),
    "ameublît": ("ameublir",),
    "amincie": ("amincir",),
    "amincies": ("amincir",),
    "aminci": ("amincir",),
    "amincîmes": ("amincir",),
    "amincira": ("amincir",),
    "aminciraient": ("amincir",),
    "amincirai": ("amincir",),
    "amincirais": ("amincir",),
    "amincirait": ("amincir",),
    "aminciras": ("amincir",),
    "amincirent": ("amincir",),
    "amincirez": ("amincir",),
    "aminciriez": ("amincir",),
    "amincirions": ("amincir",),
    "amincirons": ("amincir",),
    "aminciront": ("amincir",),
    "amincis": ("amincir",),
    "amincissaient": ("amincir",),
    "amincissais": ("amincir",),
    "amincissait": ("amincir",),
    "amincissant": ("amincir",),
    "amincissent": ("amincir",),
    "amincisse": ("amincir",),
    "amincisses": ("amincir",),
    "amincissez": ("amincir",),
    "amincissiez": ("amincir",),
    "amincissions": ("amincir",),
    "amincissons": ("amincir",),
    "amincîtes": ("amincir",),
    "amincit": ("amincir",),
    "amincît": ("amincir",),
    "ammonifiaient": ("ammonifier",),
    "ammonifiai": ("ammonifier",),
    "ammonifiais": ("ammonifier",),
    "ammonifiait": ("ammonifier",),
    "ammonifia": ("ammonifier",),
    "ammonifiâmes": ("ammonifier",),
    "ammonifiant": ("ammonifier",),
    "ammonifias": ("ammonifier",),
    "ammonifiassent": ("ammonifier",),
    "ammonifiasses": ("ammonifier",),
    "ammonifiasse": ("ammonifier",),
    "ammonifiassiez": ("ammonifier",),
    "ammonifiassions": ("ammonifier",),
    "ammonifiâtes": ("ammonifier",),
    "ammonifiât": ("ammonifier",),
    "ammonifiée": ("ammonifier",),
    "ammonifiées": ("ammonifier",),
    "ammonifié": ("ammonifier",),
    "ammonifient": ("ammonifier",),
    "ammonifie": ("ammonifier",),
    "ammonifiera": ("ammonifier",),
    "ammonifieraient": ("ammonifier",),
    "ammonifierai": ("ammonifier",),
    "ammonifierais": ("ammonifier",),
    "ammonifierait": ("ammonifier",),
    "ammonifieras": ("ammonifier",),
    "ammonifièrent": ("ammonifier",),
    "ammonifierez": ("ammonifier",),
    "ammonifieriez": ("ammonifier",),
    "ammonifierions": ("ammonifier",),
    "ammonifierons": ("ammonifier",),
    "ammonifieront": ("ammonifier",),
    "ammonifiés": ("ammonifier",),
    "ammonifies": ("ammonifier",),
    "ammonifiez": ("ammonifier",),
    "ammonifiiez": ("ammonifier",),
    "ammonifiions": ("ammonifier",),
    "ammonifions": ("ammonifier",),
    "amnistiaient": ("amnistier",),
    "amnistiai": ("amnistier",),
    "amnistiais": ("amnistier",),
    "amnistiait": ("amnistier",),
    "amnistia": ("amnistier",),
    "amnistiâmes": ("amnistier",),
    "amnistiant": ("amnistier",),
    "amnistias": ("amnistier",),
    "amnistiassent": ("amnistier",),
    "amnistiasses": ("amnistier",),
    "amnistiasse": ("amnistier",),
    "amnistiassiez": ("amnistier",),
    "amnistiassions": ("amnistier",),
    "amnistiâtes": ("amnistier",),
    "amnistiât": ("amnistier",),
    "amnistiée": ("amnistier",),
    "amnistiées": ("amnistier",),
    "amnistié": ("amnistier",),
    "amnistient": ("amnistier",),
    "amnistie": ("amnistier",),
    "amnistiera": ("amnistier",),
    "amnistieraient": ("amnistier",),
    "amnistierai": ("amnistier",),
    "amnistierais": ("amnistier",),
    "amnistierait": ("amnistier",),
    "amnistieras": ("amnistier",),
    "amnistièrent": ("amnistier",),
    "amnistierez": ("amnistier",),
    "amnistieriez": ("amnistier",),
    "amnistierions": ("amnistier",),
    "amnistierons": ("amnistier",),
    "amnistieront": ("amnistier",),
    "amnistiés": ("amnistier",),
    "amnisties": ("amnistier",),
    "amnistiez": ("amnistier",),
    "amnistiiez": ("amnistier",),
    "amnistiions": ("amnistier",),
    "amnistions": ("amnistier",),
    "amochie": ("amochir",),
    "amochies": ("amochir",),
    "amochi": ("amochir",),
    "amochîmes": ("amochir",),
    "amochira": ("amochir",),
    "amochiraient": ("amochir",),
    "amochirai": ("amochir",),
    "amochirais": ("amochir",),
    "amochirait": ("amochir",),
    "amochiras": ("amochir",),
    "amochirent": ("amochir",),
    "amochirez": ("amochir",),
    "amochiriez": ("amochir",),
    "amochirions": ("amochir",),
    "amochirons": ("amochir",),
    "amochiront": ("amochir",),
    "amochis": ("amochir",),
    "amochissaient": ("amochir",),
    "amochissais": ("amochir",),
    "amochissait": ("amochir",),
    "amochissant": ("amochir",),
    "amochissent": ("amochir",),
    "amochisse": ("amochir",),
    "amochisses": ("amochir",),
    "amochissez": ("amochir",),
    "amochissiez": ("amochir",),
    "amochissions": ("amochir",),
    "amochissons": ("amochir",),
    "amochîtes": ("amochir",),
    "amochit": ("amochir",),
    "amochît": ("amochir",),
    "amodiaient": ("amodier",),
    "amodiai": ("amodier",),
    "amodiais": ("amodier",),
    "amodiait": ("amodier",),
    "amodia": ("amodier",),
    "amodiâmes": ("amodier",),
    "amodiant": ("amodier",),
    "amodias": ("amodier",),
    "amodiassent": ("amodier",),
    "amodiasses": ("amodier",),
    "amodiasse": ("amodier",),
    "amodiassiez": ("amodier",),
    "amodiassions": ("amodier",),
    "amodiâtes": ("amodier",),
    "amodiât": ("amodier",),
    "amodiée": ("amodier",),
    "amodiées": ("amodier",),
    "amodié": ("amodier",),
    "amodient": ("amodier",),
    "amodie": ("amodier",),
    "amodiera": ("amodier",),
    "amodieraient": ("amodier",),
    "amodierai": ("amodier",),
    "amodierais": ("amodier",),
    "amodierait": ("amodier",),
    "amodieras": ("amodier",),
    "amodièrent": ("amodier",),
    "amodierez": ("amodier",),
    "amodieriez": ("amodier",),
    "amodierions": ("amodier",),
    "amodierons": ("amodier",),
    "amodieront": ("amodier",),
    "amodiés": ("amodier",),
    "amodies": ("amodier",),
    "amodiez": ("amodier",),
    "amodiiez": ("amodier",),
    "amodiions": ("amodier",),
    "amodions": ("amodier",),
    "amoindrie": ("amoindrir",),
    "amoindries": ("amoindrir",),
    "amoindri": ("amoindrir",),
    "amoindrîmes": ("amoindrir",),
    "amoindrira": ("amoindrir",),
    "amoindriraient": ("amoindrir",),
    "amoindrirai": ("amoindrir",),
    "amoindrirais": ("amoindrir",),
    "amoindrirait": ("amoindrir",),
    "amoindriras": ("amoindrir",),
    "amoindrirent": ("amoindrir",),
    "amoindrirez": ("amoindrir",),
    "amoindririez": ("amoindrir",),
    "amoindririons": ("amoindrir",),
    "amoindrirons": ("amoindrir",),
    "amoindriront": ("amoindrir",),
    "amoindris": ("amoindrir",),
    "amoindrissaient": ("amoindrir",),
    "amoindrissais": ("amoindrir",),
    "amoindrissait": ("amoindrir",),
    "amoindrissant": ("amoindrir",),
    "amoindrissent": ("amoindrir",),
    "amoindrisse": ("amoindrir",),
    "amoindrisses": ("amoindrir",),
    "amoindrissez": ("amoindrir",),
    "amoindrissiez": ("amoindrir",),
    "amoindrissions": ("amoindrir",),
    "amoindrissons": ("amoindrir",),
    "amoindrîtes": ("amoindrir",),
    "amoindrit": ("amoindrir",),
    "amoindrît": ("amoindrir",),
    "amollie": ("amollir",),
    "amollies": ("amollir",),
    "amolli": ("amollir",),
    "amollîmes": ("amollir",),
    "amollira": ("amollir",),
    "amolliraient": ("amollir",),
    "amollirai": ("amollir",),
    "amollirais": ("amollir",),
    "amollirait": ("amollir",),
    "amolliras": ("amollir",),
    "amollirent": ("amollir",),
    "amollirez": ("amollir",),
    "amolliriez": ("amollir",),
    "amollirions": ("amollir",),
    "amollirons": ("amollir",),
    "amolliront": ("amollir",),
    "amollis": ("amollir",),
    "amollissaient": ("amollir",),
    "amollissais": ("amollir",),
    "amollissait": ("amollir",),
    "amollissant": ("amollir",),
    "amollissent": ("amollir",),
    "amollisse": ("amollir",),
    "amollisses": ("amollir",),
    "amollissez": ("amollir",),
    "amollissiez": ("amollir",),
    "amollissions": ("amollir",),
    "amollissons": ("amollir",),
    "amollîtes": ("amollir",),
    "amollit": ("amollir",),
    "amollît": ("amollir",),
    "amoncelaient": ("amonceler",),
    "amoncelai": ("amonceler",),
    "amoncelais": ("amonceler",),
    "amoncelait": ("amonceler",),
    "amoncela": ("amonceler",),
    "amoncelâmes": ("amonceler",),
    "amoncelant": ("amonceler",),
    "amoncelas": ("amonceler",),
    "amoncelassent": ("amonceler",),
    "amoncelasses": ("amonceler",),
    "amoncelasse": ("amonceler",),
    "amoncelassiez": ("amonceler",),
    "amoncelassions": ("amonceler",),
    "amoncelâtes": ("amonceler",),
    "amoncelât": ("amonceler",),
    "amoncelée": ("amonceler",),
    "amoncelées": ("amonceler",),
    "amoncelé": ("amonceler",),
    "amoncelèrent": ("amonceler",),
    "amoncelés": ("amonceler",),
    "amoncelez": ("amonceler",),
    "amonceliez": ("amonceler",),
    "amoncelions": ("amonceler",),
    "amoncellent": ("amonceler",),
    "amoncelle": ("amonceler",),
    "amoncellera": ("amonceler",),
    "amoncelleraient": ("amonceler",),
    "amoncellerai": ("amonceler",),
    "amoncellerais": ("amonceler",),
    "amoncellerait": ("amonceler",),
    "amoncelleras": ("amonceler",),
    "amoncellerez": ("amonceler",),
    "amoncelleriez": ("amonceler",),
    "amoncellerions": ("amonceler",),
    "amoncellerons": ("amonceler",),
    "amoncelleront": ("amonceler",),
    "amoncelles": ("amonceler",),
    "amoncelons": ("amonceler",),
    "amorçaient": ("amorcer",),
    "amorçai": ("amorcer",),
    "amorçais": ("amorcer",),
    "amorçait": ("amorcer",),
    "amorça": ("amorcer",),
    "amorçâmes": ("amorcer",),
    "amorçant": ("amorcer",),
    "amorças": ("amorcer",),
    "amorçassent": ("amorcer",),
    "amorçasses": ("amorcer",),
    "amorçasse": ("amorcer",),
    "amorçassiez": ("amorcer",),
    "amorçassions": ("amorcer",),
    "amorçâtes": ("amorcer",),
    "amorçât": ("amorcer",),
    "amorcée": ("amorcer",),
    "amorcées": ("amorcer",),
    "amorcé": ("amorcer",),
    "amorcent": ("amorcer",),
    "amorce": ("amorcer",),
    "amorcera": ("amorcer",),
    "amorceraient": ("amorcer",),
    "amorcerai": ("amorcer",),
    "amorcerais": ("amorcer",),
    "amorcerait": ("amorcer",),
    "amorceras": ("amorcer",),
    "amorcèrent": ("amorcer",),
    "amorcerez": ("amorcer",),
    "amorceriez": ("amorcer",),
    "amorcerions": ("amorcer",),
    "amorcerons": ("amorcer",),
    "amorceront": ("amorcer",),
    "amorcés": ("amorcer",),
    "amorces": ("amorcer",),
    "amorcez": ("amorcer",),
    "amorciez": ("amorcer",),
    "amorcions": ("amorcer",),
    "amorçons": ("amorcer",),
    "amordançaient": ("amordancer",),
    "amordançai": ("amordancer",),
    "amordançais": ("amordancer",),
    "amordançait": ("amordancer",),
    "amordança": ("amordancer",),
    "amordançâmes": ("amordancer",),
    "amordançant": ("amordancer",),
    "amordanças": ("amordancer",),
    "amordançassent": ("amordancer",),
    "amordançasses": ("amordancer",),
    "amordançasse": ("amordancer",),
    "amordançassiez": ("amordancer",),
    "amordançassions": ("amordancer",),
    "amordançâtes": ("amordancer",),
    "amordançât": ("amordancer",),
    "amordancée": ("amordancer",),
    "amordancées": ("amordancer",),
    "amordancé": ("amordancer",),
    "amordancent": ("amordancer",),
    "amordance": ("amordancer",),
    "amordancera": ("amordancer",),
    "amordanceraient": ("amordancer",),
    "amordancerai": ("amordancer",),
    "amordancerais": ("amordancer",),
    "amordancerait": ("amordancer",),
    "amordanceras": ("amordancer",),
    "amordancèrent": ("amordancer",),
    "amordancerez": ("amordancer",),
    "amordanceriez": ("amordancer",),
    "amordancerions": ("amordancer",),
    "amordancerons": ("amordancer",),
    "amordanceront": ("amordancer",),
    "amordancés": ("amordancer",),
    "amordances": ("amordancer",),
    "amordancez": ("amordancer",),
    "amordanciez": ("amordancer",),
    "amordancions": ("amordancer",),
    "amordançons": ("amordancer",),
    "amortie": ("amortir",),
    "amorties": ("amortir",),
    "amorti": ("amortir",),
    "amortîmes": ("amortir",),
    "amortira": ("amortir",),
    "amortiraient": ("amortir",),
    "amortirai": ("amortir",),
    "amortirais": ("amortir",),
    "amortirait": ("amortir",),
    "amortiras": ("amortir",),
    "amortirent": ("amortir",),
    "amortirez": ("amortir",),
    "amortiriez": ("amortir",),
    "amortirions": ("amortir",),
    "amortirons": ("amortir",),
    "amortiront": ("amortir",),
    "amortis": ("amortir",),
    "amortissaient": ("amortir",),
    "amortissais": ("amortir",),
    "amortissait": ("amortir",),
    "amortissant": ("amortir",),
    "amortissent": ("amortir",),
    "amortisse": ("amortir",),
    "amortisses": ("amortir",),
    "amortissez": ("amortir",),
    "amortissiez": ("amortir",),
    "amortissions": ("amortir",),
    "amortissons": ("amortir",),
    "amortîtes": ("amortir",),
    "amortit": ("amortir",),
    "amortît": ("amortir",),
    "amplifiaient": ("amplifier",),
    "amplifiai": ("amplifier",),
    "amplifiais": ("amplifier",),
    "amplifiait": ("amplifier",),
    "amplifia": ("amplifier",),
    "amplifiâmes": ("amplifier",),
    "amplifiant": ("amplifier",),
    "amplifias": ("amplifier",),
    "amplifiassent": ("amplifier",),
    "amplifiasses": ("amplifier",),
    "amplifiasse": ("amplifier",),
    "amplifiassiez": ("amplifier",),
    "amplifiassions": ("amplifier",),
    "amplifiâtes": ("amplifier",),
    "amplifiât": ("amplifier",),
    "amplifiée": ("amplifier",),
    "amplifiées": ("amplifier",),
    "amplifié": ("amplifier",),
    "amplifient": ("amplifier",),
    "amplifie": ("amplifier",),
    "amplifiera": ("amplifier",),
    "amplifieraient": ("amplifier",),
    "amplifierai": ("amplifier",),
    "amplifierais": ("amplifier",),
    "amplifierait": ("amplifier",),
    "amplifieras": ("amplifier",),
    "amplifièrent": ("amplifier",),
    "amplifierez": ("amplifier",),
    "amplifieriez": ("amplifier",),
    "amplifierions": ("amplifier",),
    "amplifierons": ("amplifier",),
    "amplifieront": ("amplifier",),
    "amplifiés": ("amplifier",),
    "amplifies": ("amplifier",),
    "amplifiez": ("amplifier",),
    "amplifiiez": ("amplifier",),
    "amplifiions": ("amplifier",),
    "amplifions": ("amplifier",),
    "amuïe": ("amuïr",),
    "amuïes": ("amuïr",),
    "amuï": ("amuïr",),
    "amuïmes": ("amuïr",),
    "amuïra": ("amuïr",),
    "amuïraient": ("amuïr",),
    "amuïrai": ("amuïr",),
    "amuïrais": ("amuïr",),
    "amuïrait": ("amuïr",),
    "amuïras": ("amuïr",),
    "amuïrent": ("amuïr",),
    "amuïrez": ("amuïr",),
    "amuïriez": ("amuïr",),
    "amuïrions": ("amuïr",),
    "amuïrons": ("amuïr",),
    "amuïront": ("amuïr",),
    "amuïs": ("amuïr",),
    "amuïssaient": ("amuïr",),
    "amuïssais": ("amuïr",),
    "amuïssait": ("amuïr",),
    "amuïssant": ("amuïr",),
    "amuïssent": ("amuïr",),
    "amuïsse": ("amuïr",),
    "amuïsses": ("amuïr",),
    "amuïssez": ("amuïr",),
    "amuïssiez": ("amuïr",),
    "amuïssions": ("amuïr",),
    "amuïssons": ("amuïr",),
    "amuïtes": ("amuïr",),
    "amuït": ("amuïr",),
    "analgésiaient": ("analgésier",),
    "analgésiai": ("analgésier",),
    "analgésiais": ("analgésier",),
    "analgésiait": ("analgésier",),
    "analgésia": ("analgésier",),
    "analgésiâmes": ("analgésier",),
    "analgésiant": ("analgésier",),
    "analgésias": ("analgésier",),
    "analgésiassent": ("analgésier",),
    "analgésiasses": ("analgésier",),
    "analgésiasse": ("analgésier",),
    "analgésiassiez": ("analgésier",),
    "analgésiassions": ("analgésier",),
    "analgésiâtes": ("analgésier",),
    "analgésiât": ("analgésier",),
    "analgésiée": ("analgésier",),
    "analgésiées": ("analgésier",),
    "analgésié": ("analgésier",),
    "analgésient": ("analgésier",),
    "analgésie": ("analgésier",),
    "analgésiera": ("analgésier",),
    "analgésieraient": ("analgésier",),
    "analgésierai": ("analgésier",),
    "analgésierais": ("analgésier",),
    "analgésierait": ("analgésier",),
    "analgésieras": ("analgésier",),
    "analgésièrent": ("analgésier",),
    "analgésierez": ("analgésier",),
    "analgésieriez": ("analgésier",),
    "analgésierions": ("analgésier",),
    "analgésierons": ("analgésier",),
    "analgésieront": ("analgésier",),
    "analgésiés": ("analgésier",),
    "analgésies": ("analgésier",),
    "analgésiez": ("analgésier",),
    "analgésiiez": ("analgésier",),
    "analgésiions": ("analgésier",),
    "analgésions": ("analgésier",),
    "anéantie": ("anéantir",),
    "anéanties": ("anéantir",),
    "anéanti": ("anéantir",),
    "anéantîmes": ("anéantir",),
    "anéantira": ("anéantir",),
    "anéantiraient": ("anéantir",),
    "anéantirai": ("anéantir",),
    "anéantirais": ("anéantir",),
    "anéantirait": ("anéantir",),
    "anéantiras": ("anéantir",),
    "anéantirent": ("anéantir",),
    "anéantirez": ("anéantir",),
    "anéantiriez": ("anéantir",),
    "anéantirions": ("anéantir",),
    "anéantirons": ("anéantir",),
    "anéantiront": ("anéantir",),
    "anéantis": ("anéantir",),
    "anéantissaient": ("anéantir",),
    "anéantissais": ("anéantir",),
    "anéantissait": ("anéantir",),
    "anéantissant": ("anéantir",),
    "anéantissent": ("anéantir",),
    "anéantisse": ("anéantir",),
    "anéantisses": ("anéantir",),
    "anéantissez": ("anéantir",),
    "anéantissiez": ("anéantir",),
    "anéantissions": ("anéantir",),
    "anéantissons": ("anéantir",),
    "anéantîtes": ("anéantir",),
    "anéantit": ("anéantir",),
    "anéantît": ("anéantir",),
    "anémiaient": ("anémier",),
    "anémiai": ("anémier",),
    "anémiais": ("anémier",),
    "anémiait": ("anémier",),
    "anémia": ("anémier",),
    "anémiâmes": ("anémier",),
    "anémiant": ("anémier",),
    "anémias": ("anémier",),
    "anémiassent": ("anémier",),
    "anémiasses": ("anémier",),
    "anémiasse": ("anémier",),
    "anémiassiez": ("anémier",),
    "anémiassions": ("anémier",),
    "anémiâtes": ("anémier",),
    "anémiât": ("anémier",),
    "anémiée": ("anémier",),
    "anémiées": ("anémier",),
    "anémié": ("anémier",),
    "anémient": ("anémier",),
    "anémie": ("anémier",),
    "anémiera": ("anémier",),
    "anémieraient": ("anémier",),
    "anémierai": ("anémier",),
    "anémierais": ("anémier",),
    "anémierait": ("anémier",),
    "anémieras": ("anémier",),
    "anémièrent": ("anémier",),
    "anémierez": ("anémier",),
    "anémieriez": ("anémier",),
    "anémierions": ("anémier",),
    "anémierons": ("anémier",),
    "anémieront": ("anémier",),
    "anémiés": ("anémier",),
    "anémies": ("anémier",),
    "anémiez": ("anémier",),
    "anémiiez": ("anémier",),
    "anémiions": ("anémier",),
    "anémions": ("anémier",),
    "anesthésiaient": ("anesthésier",),
    "anesthésiai": ("anesthésier",),
    "anesthésiais": ("anesthésier",),
    "anesthésiait": ("anesthésier",),
    "anesthésia": ("anesthésier",),
    "anesthésiâmes": ("anesthésier",),
    "anesthésiant": ("anesthésier",),
    "anesthésias": ("anesthésier",),
    "anesthésiassent": ("anesthésier",),
    "anesthésiasses": ("anesthésier",),
    "anesthésiasse": ("anesthésier",),
    "anesthésiassiez": ("anesthésier",),
    "anesthésiassions": ("anesthésier",),
    "anesthésiâtes": ("anesthésier",),
    "anesthésiât": ("anesthésier",),
    "anesthésiée": ("anesthésier",),
    "anesthésiées": ("anesthésier",),
    "anesthésié": ("anesthésier",),
    "anesthésient": ("anesthésier",),
    "anesthésie": ("anesthésier",),
    "anesthésiera": ("anesthésier",),
    "anesthésieraient": ("anesthésier",),
    "anesthésierai": ("anesthésier",),
    "anesthésierais": ("anesthésier",),
    "anesthésierait": ("anesthésier",),
    "anesthésieras": ("anesthésier",),
    "anesthésièrent": ("anesthésier",),
    "anesthésierez": ("anesthésier",),
    "anesthésieriez": ("anesthésier",),
    "anesthésierions": ("anesthésier",),
    "anesthésierons": ("anesthésier",),
    "anesthésieront": ("anesthésier",),
    "anesthésiés": ("anesthésier",),
    "anesthésies": ("anesthésier",),
    "anesthésiez": ("anesthésier",),
    "anesthésiiez": ("anesthésier",),
    "anesthésiions": ("anesthésier",),
    "anesthésions": ("anesthésier",),
    "angariaient": ("angarier",),
    "angariai": ("angarier",),
    "angariais": ("angarier",),
    "angariait": ("angarier",),
    "angaria": ("angarier",),
    "angariâmes": ("angarier",),
    "angariant": ("angarier",),
    "angarias": ("angarier",),
    "angariassent": ("angarier",),
    "angariasses": ("angarier",),
    "angariasse": ("angarier",),
    "angariassiez": ("angarier",),
    "angariassions": ("angarier",),
    "angariâtes": ("angarier",),
    "angariât": ("angarier",),
    "angariée": ("angarier",),
    "angariées": ("angarier",),
    "angarié": ("angarier",),
    "angarient": ("angarier",),
    "angarie": ("angarier",),
    "angariera": ("angarier",),
    "angarieraient": ("angarier",),
    "angarierai": ("angarier",),
    "angarierais": ("angarier",),
    "angarierait": ("angarier",),
    "angarieras": ("angarier",),
    "angarièrent": ("angarier",),
    "angarierez": ("angarier",),
    "angarieriez": ("angarier",),
    "angarierions": ("angarier",),
    "angarierons": ("angarier",),
    "angarieront": ("angarier",),
    "angariés": ("angarier",),
    "angaries": ("angarier",),
    "angariez": ("angarier",),
    "angariiez": ("angarier",),
    "angariions": ("angarier",),
    "angarions": ("angarier",),
    "anglésaient": ("angléser",),
    "anglésai": ("angléser",),
    "anglésais": ("angléser",),
    "anglésait": ("angléser",),
    "anglésa": ("angléser",),
    "anglésâmes": ("angléser",),
    "anglésant": ("angléser",),
    "anglésas": ("angléser",),
    "anglésassent": ("angléser",),
    "anglésasses": ("angléser",),
    "anglésasse": ("angléser",),
    "anglésassiez": ("angléser",),
    "anglésassions": ("angléser",),
    "anglésâtes": ("angléser",),
    "anglésât": ("angléser",),
    "anglésée": ("angléser",),
    "anglésées": ("angléser",),
    "anglésé": ("angléser",),
    "anglèsent": ("angléser",),
    "anglèse": ("angléser",),
    "anglésera": ("angléser",),
    "angléseraient": ("angléser",),
    "angléserai": ("angléser",),
    "angléserais": ("angléser",),
    "angléserait": ("angléser",),
    "angléseras": ("angléser",),
    "anglésèrent": ("angléser",),
    "angléserez": ("angléser",),
    "angléseriez": ("angléser",),
    "angléserions": ("angléser",),
    "angléserons": ("angléser",),
    "angléseront": ("angléser",),
    "anglésés": ("angléser",),
    "anglèses": ("angléser",),
    "anglésez": ("angléser",),
    "anglésiez": ("angléser",),
    "anglésions": ("angléser",),
    "anglésons": ("angléser",),
    "anhélaient": ("anhéler",),
    "anhélai": ("anhéler",),
    "anhélais": ("anhéler",),
    "anhélait": ("anhéler",),
    "anhéla": ("anhéler",),
    "anhélâmes": ("anhéler",),
    "anhélant": ("anhéler",),
    "anhélas": ("anhéler",),
    "anhélassent": ("anhéler",),
    "anhélasses": ("anhéler",),
    "anhélasse": ("anhéler",),
    "anhélassiez": ("anhéler",),
    "anhélassions": ("anhéler",),
    "anhélâtes": ("anhéler",),
    "anhélât": ("anhéler",),
    "anhélée": ("anhéler",),
    "anhélées": ("anhéler",),
    "anhélé": ("anhéler",),
    "anhèlent": ("anhéler",),
    "anhèle": ("anhéler",),
    "anhélera": ("anhéler",),
    "anhéleraient": ("anhéler",),
    "anhélerai": ("anhéler",),
    "anhélerais": ("anhéler",),
    "anhélerait": ("anhéler",),
    "anhéleras": ("anhéler",),
    "anhélèrent": ("anhéler",),
    "anhélerez": ("anhéler",),
    "anhéleriez": ("anhéler",),
    "anhélerions": ("anhéler",),
    "anhélerons": ("anhéler",),
    "anhéleront": ("anhéler",),
    "anhélés": ("anhéler",),
    "anhèles": ("anhéler",),
    "anhélez": ("anhéler",),
    "anhéliez": ("anhéler",),
    "anhélions": ("anhéler",),
    "anhélons": ("anhéler",),
    "annelaient": ("anneler",),
    "annelai": ("anneler",),
    "annelais": ("anneler",),
    "annelait": ("anneler",),
    "annela": ("anneler",),
    "annelâmes": ("anneler",),
    "annelant": ("anneler",),
    "annelas": ("anneler",),
    "annelassent": ("anneler",),
    "annelasses": ("anneler",),
    "annelasse": ("anneler",),
    "annelassiez": ("anneler",),
    "annelassions": ("anneler",),
    "annelâtes": ("anneler",),
    "annelât": ("anneler",),
    "annelée": ("anneler",),
    "annelées": ("anneler",),
    "annelé": ("anneler",),
    "annelèrent": ("anneler",),
    "annelés": ("anneler",),
    "annelez": ("anneler",),
    "anneliez": ("anneler",),
    "annelions": ("anneler",),
    "annellent": ("anneler",),
    "annelle": ("anneler",),
    "annellera": ("anneler",),
    "annelleraient": ("anneler",),
    "annellerai": ("anneler",),
    "annellerais": ("anneler",),
    "annellerait": ("anneler",),
    "annelleras": ("anneler",),
    "annellerez": ("anneler",),
    "annelleriez": ("anneler",),
    "annellerions": ("anneler",),
    "annellerons": ("anneler",),
    "annelleront": ("anneler",),
    "annelles": ("anneler",),
    "annelons": ("anneler",),
    "annonçaient": ("annoncer",),
    "annonçai": ("annoncer",),
    "annonçais": ("annoncer",),
    "annonçait": ("annoncer",),
    "annonça": ("annoncer",),
    "annonçâmes": ("annoncer",),
    "annonçant": ("annoncer",),
    "annonças": ("annoncer",),
    "annonçassent": ("annoncer",),
    "annonçasses": ("annoncer",),
    "annonçasse": ("annoncer",),
    "annonçassiez": ("annoncer",),
    "annonçassions": ("annoncer",),
    "annonçâtes": ("annoncer",),
    "annonçât": ("annoncer",),
    "annoncée": ("annoncer",),
    "annoncées": ("annoncer",),
    "annoncé": ("annoncer",),
    "annoncent": ("annoncer",),
    "annonce": ("annoncer",),
    "annoncera": ("annoncer",),
    "annonceraient": ("annoncer",),
    "annoncerai": ("annoncer",),
    "annoncerais": ("annoncer",),
    "annoncerait": ("annoncer",),
    "annonceras": ("annoncer",),
    "annoncèrent": ("annoncer",),
    "annoncerez": ("annoncer",),
    "annonceriez": ("annoncer",),
    "annoncerions": ("annoncer",),
    "annoncerons": ("annoncer",),
    "annonceront": ("annoncer",),
    "annoncés": ("annoncer",),
    "annonces": ("annoncer",),
    "annoncez": ("annoncer",),
    "annonciez": ("annoncer",),
    "annoncions": ("annoncer",),
    "annonçons": ("annoncer",),
    "anoblie": ("anoblir",),
    "anoblies": ("anoblir",),
    "anobli": ("anoblir",),
    "anoblîmes": ("anoblir",),
    "anoblira": ("anoblir",),
    "anobliraient": ("anoblir",),
    "anoblirai": ("anoblir",),
    "anoblirais": ("anoblir",),
    "anoblirait": ("anoblir",),
    "anobliras": ("anoblir",),
    "anoblirent": ("anoblir",),
    "anoblirez": ("anoblir",),
    "anobliriez": ("anoblir",),
    "anoblirions": ("anoblir",),
    "anoblirons": ("anoblir",),
    "anobliront": ("anoblir",),
    "anoblis": ("anoblir",),
    "anoblissaient": ("anoblir",),
    "anoblissais": ("anoblir",),
    "anoblissait": ("anoblir",),
    "anoblissant": ("anoblir",),
    "anoblissent": ("anoblir",),
    "anoblisse": ("anoblir",),
    "anoblisses": ("anoblir",),
    "anoblissez": ("anoblir",),
    "anoblissiez": ("anoblir",),
    "anoblissions": ("anoblir",),
    "anoblissons": ("anoblir",),
    "anoblîtes": ("anoblir",),
    "anoblit": ("anoblir",),
    "anoblît": ("anoblir",),
    "anonchalie": ("anonchalir",),
    "anonchalies": ("anonchalir",),
    "anonchali": ("anonchalir",),
    "anonchalîmes": ("anonchalir",),
    "anonchalira": ("anonchalir",),
    "anonchaliraient": ("anonchalir",),
    "anonchalirai": ("anonchalir",),
    "anonchalirais": ("anonchalir",),
    "anonchalirait": ("anonchalir",),
    "anonchaliras": ("anonchalir",),
    "anonchalirent": ("anonchalir",),
    "anonchalirez": ("anonchalir",),
    "anonchaliriez": ("anonchalir",),
    "anonchalirions": ("anonchalir",),
    "anonchalirons": ("anonchalir",),
    "anonchaliront": ("anonchalir",),
    "anonchalis": ("anonchalir",),
    "anonchalissaient": ("anonchalir",),
    "anonchalissais": ("anonchalir",),
    "anonchalissait": ("anonchalir",),
    "anonchalissant": ("anonchalir",),
    "anonchalissent": ("anonchalir",),
    "anonchalisse": ("anonchalir",),
    "anonchalisses": ("anonchalir",),
    "anonchalissez": ("anonchalir",),
    "anonchalissiez": ("anonchalir",),
    "anonchalissions": ("anonchalir",),
    "anonchalissons": ("anonchalir",),
    "anonchalîtes": ("anonchalir",),
    "anonchalit": ("anonchalir",),
    "anonchalît": ("anonchalir",),
    "anordie": ("anordir",),
    "anordies": ("anordir",),
    "anordi": ("anordir",),
    "anordîmes": ("anordir",),
    "anordira": ("anordir",),
    "anordiraient": ("anordir",),
    "anordirai": ("anordir",),
    "anordirais": ("anordir",),
    "anordirait": ("anordir",),
    "anordiras": ("anordir",),
    "anordirent": ("anordir",),
    "anordirez": ("anordir",),
    "anordiriez": ("anordir",),
    "anordirions": ("anordir",),
    "anordirons": ("anordir",),
    "anordiront": ("anordir",),
    "anordis": ("anordir",),
    "anordissaient": ("anordir",),
    "anordissais": ("anordir",),
    "anordissait": ("anordir",),
    "anordissant": ("anordir",),
    "anordissent": ("anordir",),
    "anordisse": ("anordir",),
    "anordisses": ("anordir",),
    "anordissez": ("anordir",),
    "anordissiez": ("anordir",),
    "anordissions": ("anordir",),
    "anordissons": ("anordir",),
    "anordîtes": ("anordir",),
    "anordit": ("anordir",),
    "anordît": ("anordir",),
    "apâlie": ("apâlir",),
    "apâlies": ("apâlir",),
    "apâli": ("apâlir",),
    "apâlîmes": ("apâlir",),
    "apâlira": ("apâlir",),
    "apâliraient": ("apâlir",),
    "apâlirai": ("apâlir",),
    "apâlirais": ("apâlir",),
    "apâlirait": ("apâlir",),
    "apâliras": ("apâlir",),
    "apâlirent": ("apâlir",),
    "apâlirez": ("apâlir",),
    "apâliriez": ("apâlir",),
    "apâlirions": ("apâlir",),
    "apâlirons": ("apâlir",),
    "apâliront": ("apâlir",),
    "apâlis": ("apâlir",),
    "apâlissaient": ("apâlir",),
    "apâlissais": ("apâlir",),
    "apâlissait": ("apâlir",),
    "apâlissant": ("apâlir",),
    "apâlissent": ("apâlir",),
    "apâlisse": ("apâlir",),
    "apâlisses": ("apâlir",),
    "apâlissez": ("apâlir",),
    "apâlissiez": ("apâlir",),
    "apâlissions": ("apâlir",),
    "apâlissons": ("apâlir",),
    "apâlîtes": ("apâlir",),
    "apâlit": ("apâlir",),
    "apâlît": ("apâlir",),
    "apanageaient": ("apanager",),
    "apanageai": ("apanager",),
    "apanageais": ("apanager",),
    "apanageait": ("apanager",),
    "apanagea": ("apanager",),
    "apanageâmes": ("apanager",),
    "apanageant": ("apanager",),
    "apanageas": ("apanager",),
    "apanageassent": ("apanager",),
    "apanageasses": ("apanager",),
    "apanageasse": ("apanager",),
    "apanageassiez": ("apanager",),
    "apanageassions": ("apanager",),
    "apanageâtes": ("apanager",),
    "apanageât": ("apanager",),
    "apanagée": ("apanager",),
    "apanagées": ("apanager",),
    "apanagé": ("apanager",),
    "apanagent": ("apanager",),
    "apanageons": ("apanager",),
    "apanage": ("apanager",),
    "apanagera": ("apanager",),
    "apanageraient": ("apanager",),
    "apanagerai": ("apanager",),
    "apanagerais": ("apanager",),
    "apanagerait": ("apanager",),
    "apanageras": ("apanager",),
    "apanagèrent": ("apanager",),
    "apanagerez": ("apanager",),
    "apanageriez": ("apanager",),
    "apanagerions": ("apanager",),
    "apanagerons": ("apanager",),
    "apanageront": ("apanager",),
    "apanagés": ("apanager",),
    "apanages": ("apanager",),
    "apanagez": ("apanager",),
    "apanagiez": ("apanager",),
    "apanagions": ("apanager",),
    "apapelardie": ("apapelardir",),
    "apapelardies": ("apapelardir",),
    "apapelardi": ("apapelardir",),
    "apapelardîmes": ("apapelardir",),
    "apapelardira": ("apapelardir",),
    "apapelardiraient": ("apapelardir",),
    "apapelardirai": ("apapelardir",),
    "apapelardirais": ("apapelardir",),
    "apapelardirait": ("apapelardir",),
    "apapelardiras": ("apapelardir",),
    "apapelardirent": ("apapelardir",),
    "apapelardirez": ("apapelardir",),
    "apapelardiriez": ("apapelardir",),
    "apapelardirions": ("apapelardir",),
    "apapelardirons": ("apapelardir",),
    "apapelardiront": ("apapelardir",),
    "apapelardis": ("apapelardir",),
    "apapelardissaient": ("apapelardir",),
    "apapelardissais": ("apapelardir",),
    "apapelardissait": ("apapelardir",),
    "apapelardissant": ("apapelardir",),
    "apapelardissent": ("apapelardir",),
    "apapelardisse": ("apapelardir",),
    "apapelardisses": ("apapelardir",),
    "apapelardissez": ("apapelardir",),
    "apapelardissiez": ("apapelardir",),
    "apapelardissions": ("apapelardir",),
    "apapelardissons": ("apapelardir",),
    "apapelardîtes": ("apapelardir",),
    "apapelardit": ("apapelardir",),
    "apapelardît": ("apapelardir",),
    "apercevaient": ("apercevoir",),
    "apercevais": ("apercevoir",),
    "apercevait": ("apercevoir",),
    "apercevant": ("apercevoir",),
    "apercevez": ("apercevoir",),
    "aperceviez": ("apercevoir",),
    "apercevions": ("apercevoir",),
    "apercevons": ("apercevoir",),
    "apercevra": ("apercevoir",),
    "apercevraient": ("apercevoir",),
    "apercevrai": ("apercevoir",),
    "apercevrais": ("apercevoir",),
    "apercevrait": ("apercevoir",),
    "apercevras": ("apercevoir",),
    "apercevrez": ("apercevoir",),
    "apercevriez": ("apercevoir",),
    "apercevrions": ("apercevoir",),
    "apercevrons": ("apercevoir",),
    "apercevront": ("apercevoir",),
    "aperçois": ("apercevoir",),
    "aperçoit": ("apercevoir",),
    "aperçoivent": ("apercevoir",),
    "aperçoive": ("apercevoir",),
    "aperçoives": ("apercevoir",),
    "aperçue": ("apercevoir",),
    "aperçues": ("apercevoir",),
    "aperçu": ("apercevoir",),
    "aperçûmes": ("apercevoir",),
    "aperçurent": ("apercevoir",),
    "aperçus": ("apercevoir",),
    "aperçussent": ("apercevoir",),
    "aperçusses": ("apercevoir",),
    "aperçusse": ("apercevoir",),
    "aperçussiez": ("apercevoir",),
    "aperçussions": ("apercevoir",),
    "aperçûtes": ("apercevoir",),
    "aperçut": ("apercevoir",),
    "aperçût": ("apercevoir",),
    "apiéçaient": ("apiécer",),
    "apiéçai": ("apiécer",),
    "apiéçais": ("apiécer",),
    "apiéçait": ("apiécer",),
    "apiéça": ("apiécer",),
    "apiéçâmes": ("apiécer",),
    "apiéçant": ("apiécer",),
    "apiéças": ("apiécer",),
    "apiéçassent": ("apiécer",),
    "apiéçasses": ("apiécer",),
    "apiéçasse": ("apiécer",),
    "apiéçassiez": ("apiécer",),
    "apiéçassions": ("apiécer",),
    "apiéçâtes": ("apiécer",),
    "apiéçât": ("apiécer",),
    "apiécée": ("apiécer",),
    "apiécées": ("apiécer",),
    "apiécé": ("apiécer",),
    "apiècent": ("apiécer",),
    "apièce": ("apiécer",),
    "apiécera": ("apiécer",),
    "apiéceraient": ("apiécer",),
    "apiécerai": ("apiécer",),
    "apiécerais": ("apiécer",),
    "apiécerait": ("apiécer",),
    "apiéceras": ("apiécer",),
    "apiécèrent": ("apiécer",),
    "apiécerez": ("apiécer",),
    "apiéceriez": ("apiécer",),
    "apiécerions": ("apiécer",),
    "apiécerons": ("apiécer",),
    "apiéceront": ("apiécer",),
    "apiécés": ("apiécer",),
    "apièces": ("apiécer",),
    "apiécez": ("apiécer",),
    "apiéciez": ("apiécer",),
    "apiécions": ("apiécer",),
    "apiéçons": ("apiécer",),
    "apitoient": ("apitoyer",),
    "apitoie": ("apitoyer",),
    "apitoiera": ("apitoyer",),
    "apitoieraient": ("apitoyer",),
    "apitoierai": ("apitoyer",),
    "apitoierais": ("apitoyer",),
    "apitoierait": ("apitoyer",),
    "apitoieras": ("apitoyer",),
    "apitoierez": ("apitoyer",),
    "apitoieriez": ("apitoyer",),
    "apitoierions": ("apitoyer",),
    "apitoierons": ("apitoyer",),
    "apitoieront": ("apitoyer",),
    "apitoies": ("apitoyer",),
    "apitoyaient": ("apitoyer",),
    "apitoyai": ("apitoyer",),
    "apitoyais": ("apitoyer",),
    "apitoyait": ("apitoyer",),
    "apitoya": ("apitoyer",),
    "apitoyâmes": ("apitoyer",),
    "apitoyant": ("apitoyer",),
    "apitoyas": ("apitoyer",),
    "apitoyassent": ("apitoyer",),
    "apitoyasses": ("apitoyer",),
    "apitoyasse": ("apitoyer",),
    "apitoyassiez": ("apitoyer",),
    "apitoyassions": ("apitoyer",),
    "apitoyâtes": ("apitoyer",),
    "apitoyât": ("apitoyer",),
    "apitoyée": ("apitoyer",),
    "apitoyées": ("apitoyer",),
    "apitoyé": ("apitoyer",),
    "apitoyèrent": ("apitoyer",),
    "apitoyés": ("apitoyer",),
    "apitoyez": ("apitoyer",),
    "apitoyiez": ("apitoyer",),
    "apitoyions": ("apitoyer",),
    "apitoyons": ("apitoyer",),
    "aplanie": ("aplanir",),
    "aplanies": ("aplanir",),
    "aplani": ("aplanir",),
    "aplanîmes": ("aplanir",),
    "aplanira": ("aplanir",),
    "aplaniraient": ("aplanir",),
    "aplanirai": ("aplanir",),
    "aplanirais": ("aplanir",),
    "aplanirait": ("aplanir",),
    "aplaniras": ("aplanir",),
    "aplanirent": ("aplanir",),
    "aplanirez": ("aplanir",),
    "aplaniriez": ("aplanir",),
    "aplanirions": ("aplanir",),
    "aplanirons": ("aplanir",),
    "aplaniront": ("aplanir",),
    "aplanis": ("aplanir",),
    "aplanissaient": ("aplanir",),
    "aplanissais": ("aplanir",),
    "aplanissait": ("aplanir",),
    "aplanissant": ("aplanir",),
    "aplanissent": ("aplanir",),
    "aplanisse": ("aplanir",),
    "aplanisses": ("aplanir",),
    "aplanissez": ("aplanir",),
    "aplanissiez": ("aplanir",),
    "aplanissions": ("aplanir",),
    "aplanissons": ("aplanir",),
    "aplanîtes": ("aplanir",),
    "aplanit": ("aplanir",),
    "aplanît": ("aplanir",),
    "aplatie": ("aplatir",),
    "aplaties": ("aplatir",),
    "aplati": ("aplatir",),
    "aplatîmes": ("aplatir",),
    "aplatira": ("aplatir",),
    "aplatiraient": ("aplatir",),
    "aplatirai": ("aplatir",),
    "aplatirais": ("aplatir",),
    "aplatirait": ("aplatir",),
    "aplatiras": ("aplatir",),
    "aplatirent": ("aplatir",),
    "aplatirez": ("aplatir",),
    "aplatiriez": ("aplatir",),
    "aplatirions": ("aplatir",),
    "aplatirons": ("aplatir",),
    "aplatiront": ("aplatir",),
    "aplatis": ("aplatir",),
    "aplatissaient": ("aplatir",),
    "aplatissais": ("aplatir",),
    "aplatissait": ("aplatir",),
    "aplatissant": ("aplatir",),
    "aplatissent": ("aplatir",),
    "aplatisse": ("aplatir",),
    "aplatisses": ("aplatir",),
    "aplatissez": ("aplatir",),
    "aplatissiez": ("aplatir",),
    "aplatissions": ("aplatir",),
    "aplatissons": ("aplatir",),
    "aplatîtes": ("aplatir",),
    "aplatit": ("aplatir",),
    "aplatît": ("aplatir",),
    "aplenie": ("aplenir",),
    "aplenies": ("aplenir",),
    "apleni": ("aplenir",),
    "aplenîmes": ("aplenir",),
    "aplenira": ("aplenir",),
    "apleniraient": ("aplenir",),
    "aplenirai": ("aplenir",),
    "aplenirais": ("aplenir",),
    "aplenirait": ("aplenir",),
    "apleniras": ("aplenir",),
    "aplenirent": ("aplenir",),
    "aplenirez": ("aplenir",),
    "apleniriez": ("aplenir",),
    "aplenirions": ("aplenir",),
    "aplenirons": ("aplenir",),
    "apleniront": ("aplenir",),
    "aplenis": ("aplenir",),
    "aplenissaient": ("aplenir",),
    "aplenissais": ("aplenir",),
    "aplenissait": ("aplenir",),
    "aplenissant": ("aplenir",),
    "aplenissent": ("aplenir",),
    "aplenisse": ("aplenir",),
    "aplenisses": ("aplenir",),
    "aplenissez": ("aplenir",),
    "aplenissiez": ("aplenir",),
    "aplenissions": ("aplenir",),
    "aplenissons": ("aplenir",),
    "aplenîtes": ("aplenir",),
    "aplenit": ("aplenir",),
    "aplenît": ("aplenir",),
    "apoltronnie": ("apoltronnir",),
    "apoltronnies": ("apoltronnir",),
    "apoltronni": ("apoltronnir",),
    "apoltronnîmes": ("apoltronnir",),
    "apoltronnira": ("apoltronnir",),
    "apoltronniraient": ("apoltronnir",),
    "apoltronnirai": ("apoltronnir",),
    "apoltronnirais": ("apoltronnir",),
    "apoltronnirait": ("apoltronnir",),
    "apoltronniras": ("apoltronnir",),
    "apoltronnirent": ("apoltronnir",),
    "apoltronnirez": ("apoltronnir",),
    "apoltronniriez": ("apoltronnir",),
    "apoltronnirions": ("apoltronnir",),
    "apoltronnirons": ("apoltronnir",),
    "apoltronniront": ("apoltronnir",),
    "apoltronnis": ("apoltronnir",),
    "apoltronnissaient": ("apoltronnir",),
    "apoltronnissais": ("apoltronnir",),
    "apoltronnissait": ("apoltronnir",),
    "apoltronnissant": ("apoltronnir",),
    "apoltronnissent": ("apoltronnir",),
    "apoltronnisse": ("apoltronnir",),
    "apoltronnisses": ("apoltronnir",),
    "apoltronnissez": ("apoltronnir",),
    "apoltronnissiez": ("apoltronnir",),
    "apoltronnissions": ("apoltronnir",),
    "apoltronnissons": ("apoltronnir",),
    "apoltronnîtes": ("apoltronnir",),
    "apoltronnit": ("apoltronnir",),
    "apoltronnît": ("apoltronnir",),
    "apostasiaient": ("apostasier",),
    "apostasiai": ("apostasier",),
    "apostasiais": ("apostasier",),
    "apostasiait": ("apostasier",),
    "apostasia": ("apostasier",),
    "apostasiâmes": ("apostasier",),
    "apostasiant": ("apostasier",),
    "apostasias": ("apostasier",),
    "apostasiassent": ("apostasier",),
    "apostasiasses": ("apostasier",),
    "apostasiasse": ("apostasier",),
    "apostasiassiez": ("apostasier",),
    "apostasiassions": ("apostasier",),
    "apostasiâtes": ("apostasier",),
    "apostasiât": ("apostasier",),
    "apostasié": ("apostasier",),
    "apostasient": ("apostasier",),
    "apostasie": ("apostasier",),
    "apostasiera": ("apostasier",),
    "apostasieraient": ("apostasier",),
    "apostasierai": ("apostasier",),
    "apostasierais": ("apostasier",),
    "apostasierait": ("apostasier",),
    "apostasieras": ("apostasier",),
    "apostasièrent": ("apostasier",),
    "apostasierez": ("apostasier",),
    "apostasieriez": ("apostasier",),
    "apostasierions": ("apostasier",),
    "apostasierons": ("apostasier",),
    "apostasieront": ("apostasier",),
    "apostasies": ("apostasier",),
    "apostasiez": ("apostasier",),
    "apostasiiez": ("apostasier",),
    "apostasiions": ("apostasier",),
    "apostasions": ("apostasier",),
    "appâlie": ("appâlir",),
    "appâlies": ("appâlir",),
    "appâli": ("appâlir",),
    "appâlîmes": ("appâlir",),
    "appâlira": ("appâlir",),
    "appâliraient": ("appâlir",),
    "appâlirai": ("appâlir",),
    "appâlirais": ("appâlir",),
    "appâlirait": ("appâlir",),
    "appâliras": ("appâlir",),
    "appâlirent": ("appâlir",),
    "appâlirez": ("appâlir",),
    "appâliriez": ("appâlir",),
    "appâlirions": ("appâlir",),
    "appâlirons": ("appâlir",),
    "appâliront": ("appâlir",),
    "appâlis": ("appâlir",),
    "appâlissaient": ("appâlir",),
    "appâlissais": ("appâlir",),
    "appâlissait": ("appâlir",),
    "appâlissant": ("appâlir",),
    "appâlissent": ("appâlir",),
    "appâlisse": ("appâlir",),
    "appâlisses": ("appâlir",),
    "appâlissez": ("appâlir",),
    "appâlissiez": ("appâlir",),
    "appâlissions": ("appâlir",),
    "appâlissons": ("appâlir",),
    "appâlîtes": ("appâlir",),
    "appâlit": ("appâlir",),
    "appâlît": ("appâlir",),
    "apparais": ("apparaître",),
    "apparaissaient": ("apparaître",),
    "apparaissais": ("apparaître",),
    "apparaissait": ("apparaître",),
    "apparaissant": ("apparaître",),
    "apparaissent": ("apparaître",),
    "apparaisse": ("apparaître",),
    "apparaisses": ("apparaître",),
    "apparaissez": ("apparaître",),
    "apparaissiez": ("apparaître",),
    "apparaissions": ("apparaître",),
    "apparaissons": ("apparaître",),
    "apparaît": ("apparaître",),
    "apparaîtra": ("apparaître",),
    "apparaîtraient": ("apparaître",),
    "apparaîtrai": ("apparaître",),
    "apparaîtrais": ("apparaître",),
    "apparaîtrait": ("apparaître",),
    "apparaîtras": ("apparaître",),
    "apparaîtrez": ("apparaître",),
    "apparaîtriez": ("apparaître",),
    "apparaîtrions": ("apparaître",),
    "apparaîtrons": ("apparaître",),
    "apparaîtront": ("apparaître",),
    "apparue": ("apparaître",),
    "apparues": ("apparaître",),
    "apparu": ("apparaître",),
    "apparûmes": ("apparaître",),
    "apparurent": ("apparaître",),
    "apparus": ("apparaître",),
    "apparussent": ("apparaître",),
    "apparusses": ("apparaître",),
    "apparusse": ("apparaître",),
    "apparussiez": ("apparaître",),
    "apparussions": ("apparaître",),
    "apparûtes": ("apparaître",),
    "apparut": ("apparaître",),
    "apparût": ("apparaître",),
    "appariaient": ("apparier",),
    "appariai": ("apparier",),
    "appariais": ("apparier",),
    "appariait": ("apparier",),
    "apparia": ("apparier",),
    "appariâmes": ("apparier",),
    "appariant": ("apparier",),
    "apparias": ("apparier",),
    "appariassent": ("apparier",),
    "appariasses": ("apparier",),
    "appariasse": ("apparier",),
    "appariassiez": ("apparier",),
    "appariassions": ("apparier",),
    "appariâtes": ("apparier",),
    "appariât": ("apparier",),
    "appariée": ("apparier",),
    "appariées": ("apparier",),
    "apparié": ("apparier",),
    "apparient": ("apparier",),
    "apparie": ("apparier",),
    "appariera": ("apparier",),
    "apparieraient": ("apparier",),
    "apparierai": ("apparier",),
    "apparierais": ("apparier",),
    "apparierait": ("apparier",),
    "apparieras": ("apparier",),
    "apparièrent": ("apparier",),
    "apparierez": ("apparier",),
    "apparieriez": ("apparier",),
    "apparierions": ("apparier",),
    "apparierons": ("apparier",),
    "apparieront": ("apparier",),
    "appariés": ("apparier",),
    "apparies": ("apparier",),
    "appariez": ("apparier",),
    "appariiez": ("apparier",),
    "appariions": ("apparier",),
    "apparions": ("apparier",),
    "appartenaient": ("appartenir",),
    "appartenais": ("appartenir",),
    "appartenait": ("appartenir",),
    "appartenant": ("appartenir",),
    "appartenez": ("appartenir",),
    "apparteniez": ("appartenir",),
    "appartenions": ("appartenir",),
    "appartenons": ("appartenir",),
    "appartenue": ("appartenir",),
    "appartenues": ("appartenir",),
    "appartenu": ("appartenir",),
    "appartenus": ("appartenir",),
    "appartiendra": ("appartenir",),
    "appartiendraient": ("appartenir",),
    "appartiendrai": ("appartenir",),
    "appartiendrais": ("appartenir",),
    "appartiendrait": ("appartenir",),
    "appartiendras": ("appartenir",),
    "appartiendrez": ("appartenir",),
    "appartiendriez": ("appartenir",),
    "appartiendrions": ("appartenir",),
    "appartiendrons": ("appartenir",),
    "appartiendront": ("appartenir",),
    "appartiennent": ("appartenir",),
    "appartienne": ("appartenir",),
    "appartiennes": ("appartenir",),
    "appartiens": ("appartenir",),
    "appartient": ("appartenir",),
    "appartînmes": ("appartenir",),
    "appartinrent": ("appartenir",),
    "appartins": ("appartenir",),
    "appartinssent": ("appartenir",),
    "appartinsses": ("appartenir",),
    "appartinsse": ("appartenir",),
    "appartinssiez": ("appartenir",),
    "appartinssions": ("appartenir",),
    "appartîntes": ("appartenir",),
    "appartint": ("appartenir",),
    "appartînt": ("appartenir",),
    "appâtaient": ("appâter",),
    "appâtai": ("appâter",),
    "appâtais": ("appâter",),
    "appâtait": ("appâter",),
    "appâta": ("appâter",),
    "appâtâmes": ("appâter",),
    "appâtant": ("appâter",),
    "appâtas": ("appâter",),
    "appâtassent": ("appâter",),
    "appâtasses": ("appâter",),
    "appâtasse": ("appâter",),
    "appâtassiez": ("appâter",),
    "appâtassions": ("appâter",),
    "appâtâtes": ("appâter",),
    "appâtât": ("appâter",),
    "appâtée": ("appâter",),
    "appâtées": ("appâter",),
    "appâté": ("appâter",),
    "appâtent": ("appâter",),
    "appâte": ("appâter",),
    "appâtera": ("appâter",),
    "appâteraient": ("appâter",),
    "appâterai": ("appâter",),
    "appâterais": ("appâter",),
    "appâterait": ("appâter",),
    "appâteras": ("appâter",),
    "appâtèrent": ("appâter",),
    "appâterez": ("appâter",),
    "appâteriez": ("appâter",),
    "appâterions": ("appâter",),
    "appâterons": ("appâter",),
    "appâteront": ("appâter",),
    "appâtés": ("appâter",),
    "appâtes": ("appâter",),
    "appâtez": ("appâter",),
    "appâtiez": ("appâter",),
    "appâtions": ("appâter",),
    "appâtons": ("appâter",),
    "appauvrie": ("appauvrir",),
    "appauvries": ("appauvrir",),
    "appauvri": ("appauvrir",),
    "appauvrîmes": ("appauvrir",),
    "appauvrira": ("appauvrir",),
    "appauvriraient": ("appauvrir",),
    "appauvrirai": ("appauvrir",),
    "appauvrirais": ("appauvrir",),
    "appauvrirait": ("appauvrir",),
    "appauvriras": ("appauvrir",),
    "appauvrirent": ("appauvrir",),
    "appauvrirez": ("appauvrir",),
    "appauvririez": ("appauvrir",),
    "appauvririons": ("appauvrir",),
    "appauvrirons": ("appauvrir",),
    "appauvriront": ("appauvrir",),
    "appauvris": ("appauvrir",),
    "appauvrissaient": ("appauvrir",),
    "appauvrissais": ("appauvrir",),
    "appauvrissait": ("appauvrir",),
    "appauvrissant": ("appauvrir",),
    "appauvrissent": ("appauvrir",),
    "appauvrisse": ("appauvrir",),
    "appauvrisses": ("appauvrir",),
    "appauvrissez": ("appauvrir",),
    "appauvrissiez": ("appauvrir",),
    "appauvrissions": ("appauvrir",),
    "appauvrissons": ("appauvrir",),
    "appauvrîtes": ("appauvrir",),
    "appauvrit": ("appauvrir",),
    "appauvrît": ("appauvrir",),
    "appelaient": ("appeler",),
    "appelai": ("appeler",),
    "appelais": ("appeler",),
    "appelait": ("appeler",),
    "appela": ("appeler",),
    "appelâmes": ("appeler",),
    "appelant": ("appeler",),
    "appelas": ("appeler",),
    "appelassent": ("appeler",),
    "appelasses": ("appeler",),
    "appelasse": ("appeler",),
    "appelassiez": ("appeler",),
    "appelassions": ("appeler",),
    "appelâtes": ("appeler",),
    "appelât": ("appeler",),
    "appelée": ("appeler",),
    "appelées": ("appeler",),
    "appelé": ("appeler",),
    "appelèrent": ("appeler",),
    "appelés": ("appeler",),
    "appelez": ("appeler",),
    "appeliez": ("appeler",),
    "appelions": ("appeler",),
    "appellent": ("appeler",),
    "appelle": ("appeler",),
    "appellera": ("appeler",),
    "appelleraient": ("appeler",),
    "appellerai": ("appeler",),
    "appellerais": ("appeler",),
    "appellerait": ("appeler",),
    "appelleras": ("appeler",),
    "appellerez": ("appeler",),
    "appelleriez": ("appeler",),
    "appellerions": ("appeler",),
    "appellerons": ("appeler",),
    "appelleront": ("appeler",),
    "appelles": ("appeler",),
    "appelons": ("appeler",),
    "appendaient": ("appendre",),
    "appendais": ("appendre",),
    "appendait": ("appendre",),
    "appendant": ("appendre",),
    "appendent": ("appendre",),
    "appende": ("appendre",),
    "appendes": ("appendre",),
    "appendez": ("appendre",),
    "appendiez": ("appendre",),
    "appendîmes": ("appendre",),
    "appendions": ("appendre",),
    "appendirent": ("appendre",),
    "appendis": ("appendre",),
    "appendissent": ("appendre",),
    "appendisses": ("appendre",),
    "appendisse": ("appendre",),
    "appendissiez": ("appendre",),
    "appendissions": ("appendre",),
    "appendîtes": ("appendre",),
    "appendit": ("appendre",),
    "appendît": ("appendre",),
    "appendons": ("appendre",),
    "append": ("appendre",),
    "appendra": ("appendre",),
    "appendraient": ("appendre",),
    "appendrai": ("appendre",),
    "appendrais": ("appendre",),
    "appendrait": ("appendre",),
    "appendras": ("appendre",),
    "appendrez": ("appendre",),
    "appendriez": ("appendre",),
    "appendrions": ("appendre",),
    "appendrons": ("appendre",),
    "appendront": ("appendre",),
    "appends": ("appendre",),
    "appendue": ("appendre",),
    "appendues": ("appendre",),
    "appendu": ("appendre",),
    "appendus": ("appendre",),
    "appesantie": ("appesantir",),
    "appesanties": ("appesantir",),
    "appesanti": ("appesantir",),
    "appesantîmes": ("appesantir",),
    "appesantira": ("appesantir",),
    "appesantiraient": ("appesantir",),
    "appesantirai": ("appesantir",),
    "appesantirais": ("appesantir",),
    "appesantirait": ("appesantir",),
    "appesantiras": ("appesantir",),
    "appesantirent": ("appesantir",),
    "appesantirez": ("appesantir",),
    "appesantiriez": ("appesantir",),
    "appesantirions": ("appesantir",),
    "appesantirons": ("appesantir",),
    "appesantiront": ("appesantir",),
    "appesantis": ("appesantir",),
    "appesantissaient": ("appesantir",),
    "appesantissais": ("appesantir",),
    "appesantissait": ("appesantir",),
    "appesantissant": ("appesantir",),
    "appesantissent": ("appesantir",),
    "appesantisse": ("appesantir",),
    "appesantisses": ("appesantir",),
    "appesantissez": ("appesantir",),
    "appesantissiez": ("appesantir",),
    "appesantissions": ("appesantir",),
    "appesantissons": ("appesantir",),
    "appesantîtes": ("appesantir",),
    "appesantit": ("appesantir",),
    "appesantît": ("appesantir",),
    "appétaient": ("appéter",),
    "appétai": ("appéter",),
    "appétais": ("appéter",),
    "appétait": ("appéter",),
    "appéta": ("appéter",),
    "appétâmes": ("appéter",),
    "appétant": ("appéter",),
    "appétas": ("appéter",),
    "appétassent": ("appéter",),
    "appétasses": ("appéter",),
    "appétasse": ("appéter",),
    "appétassiez": ("appéter",),
    "appétassions": ("appéter",),
    "appétâtes": ("appéter",),
    "appétât": ("appéter",),
    "appétée": ("appéter",),
    "appétées": ("appéter",),
    "appété": ("appéter",),
    "appètent": ("appéter",),
    "appète": ("appéter",),
    "appétera": ("appéter",),
    "appéteraient": ("appéter",),
    "appéterai": ("appéter",),
    "appéterais": ("appéter",),
    "appéterait": ("appéter",),
    "appéteras": ("appéter",),
    "appétèrent": ("appéter",),
    "appéterez": ("appéter",),
    "appéteriez": ("appéter",),
    "appéterions": ("appéter",),
    "appéterons": ("appéter",),
    "appéteront": ("appéter",),
    "appétés": ("appéter",),
    "appètes": ("appéter",),
    "appétez": ("appéter",),
    "appétiez": ("appéter",),
    "appétions": ("appéter",),
    "appétons": ("appéter",),
    "applaudie": ("applaudir",),
    "applaudies": ("applaudir",),
    "applaudi": ("applaudir",),
    "applaudîmes": ("applaudir",),
    "applaudira": ("applaudir",),
    "applaudiraient": ("applaudir",),
    "applaudirai": ("applaudir",),
    "applaudirais": ("applaudir",),
    "applaudirait": ("applaudir",),
    "applaudiras": ("applaudir",),
    "applaudirent": ("applaudir",),
    "applaudirez": ("applaudir",),
    "applaudiriez": ("applaudir",),
    "applaudirions": ("applaudir",),
    "applaudirons": ("applaudir",),
    "applaudiront": ("applaudir",),
    "applaudis": ("applaudir",),
    "applaudissaient": ("applaudir",),
    "applaudissais": ("applaudir",),
    "applaudissait": ("applaudir",),
    "applaudissant": ("applaudir",),
    "applaudissent": ("applaudir",),
    "applaudisse": ("applaudir",),
    "applaudisses": ("applaudir",),
    "applaudissez": ("applaudir",),
    "applaudissiez": ("applaudir",),
    "applaudissions": ("applaudir",),
    "applaudissons": ("applaudir",),
    "applaudîtes": ("applaudir",),
    "applaudit": ("applaudir",),
    "applaudît": ("applaudir",),
    "appointie": ("appointir",),
    "appointies": ("appointir",),
    "appointi": ("appointir",),
    "appointîmes": ("appointir",),
    "appointira": ("appointir",),
    "appointiraient": ("appointir",),
    "appointirai": ("appointir",),
    "appointirais": ("appointir",),
    "appointirait": ("appointir",),
    "appointiras": ("appointir",),
    "appointirent": ("appointir",),
    "appointirez": ("appointir",),
    "appointiriez": ("appointir",),
    "appointirions": ("appointir",),
    "appointirons": ("appointir",),
    "appointiront": ("appointir",),
    "appointis": ("appointir",),
    "appointissaient": ("appointir",),
    "appointissais": ("appointir",),
    "appointissait": ("appointir",),
    "appointissant": ("appointir",),
    "appointissent": ("appointir",),
    "appointisse": ("appointir",),
    "appointisses": ("appointir",),
    "appointissez": ("appointir",),
    "appointissiez": ("appointir",),
    "appointissions": ("appointir",),
    "appointissons": ("appointir",),
    "appointîtes": ("appointir",),
    "appointit": ("appointir",),
    "appointît": ("appointir",),
    "appoltronnie": ("appoltronnir",),
    "appoltronnies": ("appoltronnir",),
    "appoltronni": ("appoltronnir",),
    "appoltronnîmes": ("appoltronnir",),
    "appoltronnira": ("appoltronnir",),
    "appoltronniraient": ("appoltronnir",),
    "appoltronnirai": ("appoltronnir",),
    "appoltronnirais": ("appoltronnir",),
    "appoltronnirait": ("appoltronnir",),
    "appoltronniras": ("appoltronnir",),
    "appoltronnirent": ("appoltronnir",),
    "appoltronnirez": ("appoltronnir",),
    "appoltronniriez": ("appoltronnir",),
    "appoltronnirions": ("appoltronnir",),
    "appoltronnirons": ("appoltronnir",),
    "appoltronniront": ("appoltronnir",),
    "appoltronnis": ("appoltronnir",),
    "appoltronnissaient": ("appoltronnir",),
    "appoltronnissais": ("appoltronnir",),
    "appoltronnissait": ("appoltronnir",),
    "appoltronnissant": ("appoltronnir",),
    "appoltronnissent": ("appoltronnir",),
    "appoltronnisse": ("appoltronnir",),
    "appoltronnisses": ("appoltronnir",),
    "appoltronnissez": ("appoltronnir",),
    "appoltronnissiez": ("appoltronnir",),
    "appoltronnissions": ("appoltronnir",),
    "appoltronnissons": ("appoltronnir",),
    "appoltronnîtes": ("appoltronnir",),
    "appoltronnit": ("appoltronnir",),
    "appoltronnît": ("appoltronnir",),
    "appréciaient": ("apprécier",),
    "appréciai": ("apprécier",),
    "appréciais": ("apprécier",),
    "appréciait": ("apprécier",),
    "apprécia": ("apprécier",),
    "appréciâmes": ("apprécier",),
    "appréciant": ("apprécier",),
    "apprécias": ("apprécier",),
    "appréciassent": ("apprécier",),
    "appréciasses": ("apprécier",),
    "appréciasse": ("apprécier",),
    "appréciassiez": ("apprécier",),
    "appréciassions": ("apprécier",),
    "appréciâtes": ("apprécier",),
    "appréciât": ("apprécier",),
    "appréciée": ("apprécier",),
    "appréciées": ("apprécier",),
    "apprécié": ("apprécier",),
    "apprécient": ("apprécier",),
    "apprécie": ("apprécier",),
    "appréciera": ("apprécier",),
    "apprécieraient": ("apprécier",),
    "apprécierai": ("apprécier",),
    "apprécierais": ("apprécier",),
    "apprécierait": ("apprécier",),
    "apprécieras": ("apprécier",),
    "apprécièrent": ("apprécier",),
    "apprécierez": ("apprécier",),
    "apprécieriez": ("apprécier",),
    "apprécierions": ("apprécier",),
    "apprécierons": ("apprécier",),
    "apprécieront": ("apprécier",),
    "appréciés": ("apprécier",),
    "apprécies": ("apprécier",),
    "appréciez": ("apprécier",),
    "appréciiez": ("apprécier",),
    "appréciions": ("apprécier",),
    "apprécions": ("apprécier",),
    "apprenaient": ("apprendre",),
    "apprenais": ("apprendre",),
    "apprenait": ("apprendre",),
    "apprenant": ("apprendre",),
    "apprend": ("apprendre",),
    "apprendra": ("apprendre",),
    "apprendraient": ("apprendre",),
    "apprendrai": ("apprendre",),
    "apprendrais": ("apprendre",),
    "apprendrait": ("apprendre",),
    "apprendras": ("apprendre",),
    "apprendrez": ("apprendre",),
    "apprendriez": ("apprendre",),
    "apprendrions": ("apprendre",),
    "apprendrons": ("apprendre",),
    "apprendront": ("apprendre",),
    "apprends": ("apprendre",),
    "apprenez": ("apprendre",),
    "appreniez": ("apprendre",),
    "apprenions": ("apprendre",),
    "apprennent": ("apprendre",),
    "apprenne": ("apprendre",),
    "apprennes": ("apprendre",),
    "apprenons": ("apprendre",),
    "apprîmes": ("apprendre",),
    "apprirent": ("apprendre",),
    "apprise": ("apprendre",),
    "apprises": ("apprendre",),
    "appris": ("apprendre",),
    "apprissent": ("apprendre",),
    "apprisses": ("apprendre",),
    "apprisse": ("apprendre",),
    "apprissiez": ("apprendre",),
    "apprissions": ("apprendre",),
    "apprîtes": ("apprendre",),
    "apprit": ("apprendre",),
    "apprît": ("apprendre",),
    "approfondie": ("approfondir",),
    "approfondies": ("approfondir",),
    "approfondi": ("approfondir",),
    "approfondîmes": ("approfondir",),
    "approfondira": ("approfondir",),
    "approfondiraient": ("approfondir",),
    "approfondirai": ("approfondir",),
    "approfondirais": ("approfondir",),
    "approfondirait": ("approfondir",),
    "approfondiras": ("approfondir",),
    "approfondirent": ("approfondir",),
    "approfondirez": ("approfondir",),
    "approfondiriez": ("approfondir",),
    "approfondirions": ("approfondir",),
    "approfondirons": ("approfondir",),
    "approfondiront": ("approfondir",),
    "approfondis": ("approfondir",),
    "approfondissaient": ("approfondir",),
    "approfondissais": ("approfondir",),
    "approfondissait": ("approfondir",),
    "approfondissant": ("approfondir",),
    "approfondissent": ("approfondir",),
    "approfondisse": ("approfondir",),
    "approfondisses": ("approfondir",),
    "approfondissez": ("approfondir",),
    "approfondissiez": ("approfondir",),
    "approfondissions": ("approfondir",),
    "approfondissons": ("approfondir",),
    "approfondîtes": ("approfondir",),
    "approfondit": ("approfondir",),
    "approfondît": ("approfondir",),
    "appropriaient": ("approprier",),
    "appropriai": ("approprier",),
    "appropriais": ("approprier",),
    "appropriait": ("approprier",),
    "appropria": ("approprier",),
    "appropriâmes": ("approprier",),
    "appropriant": ("approprier",),
    "approprias": ("approprier",),
    "appropriassent": ("approprier",),
    "appropriasses": ("approprier",),
    "appropriasse": ("approprier",),
    "appropriassiez": ("approprier",),
    "appropriassions": ("approprier",),
    "appropriâtes": ("approprier",),
    "appropriât": ("approprier",),
    "appropriée": ("approprier",),
    "appropriées": ("approprier",),
    "approprié": ("approprier",),
    "approprient": ("approprier",),
    "approprie": ("approprier",),
    "appropriera": ("approprier",),
    "approprieraient": ("approprier",),
    "approprierai": ("approprier",),
    "approprierais": ("approprier",),
    "approprierait": ("approprier",),
    "approprieras": ("approprier",),
    "approprièrent": ("approprier",),
    "approprierez": ("approprier",),
    "approprieriez": ("approprier",),
    "approprierions": ("approprier",),
    "approprierons": ("approprier",),
    "approprieront": ("approprier",),
    "appropriés": ("approprier",),
    "appropries": ("approprier",),
    "appropriez": ("approprier",),
    "appropriiez": ("approprier",),
    "appropriions": ("approprier",),
    "approprions": ("approprier",),
    "appuient": ("appuyer",),
    "appuie": ("appuyer",),
    "appuiera": ("appuyer",),
    "appuieraient": ("appuyer",),
    "appuierai": ("appuyer",),
    "appuierais": ("appuyer",),
    "appuierait": ("appuyer",),
    "appuieras": ("appuyer",),
    "appuierez": ("appuyer",),
    "appuieriez": ("appuyer",),
    "appuierions": ("appuyer",),
    "appuierons": ("appuyer",),
    "appuieront": ("appuyer",),
    "appuies": ("appuyer",),
    "appuyaient": ("appuyer",),
    "appuyai": ("appuyer",),
    "appuyais": ("appuyer",),
    "appuyait": ("appuyer",),
    "appuya": ("appuyer",),
    "appuyâmes": ("appuyer",),
    "appuyant": ("appuyer",),
    "appuyas": ("appuyer",),
    "appuyassent": ("appuyer",),
    "appuyasses": ("appuyer",),
    "appuyasse": ("appuyer",),
    "appuyassiez": ("appuyer",),
    "appuyassions": ("appuyer",),
    "appuyâtes": ("appuyer",),
    "appuyât": ("appuyer",),
    "appuyée": ("appuyer",),
    "appuyées": ("appuyer",),
    "appuyé": ("appuyer",),
    "appuyèrent": ("appuyer",),
    "appuyés": ("appuyer",),
    "appuyez": ("appuyer",),
    "appuyiez": ("appuyer",),
    "appuyions": ("appuyer",),
    "appuyons": ("appuyer",),
    "aquatie": ("aquatir",),
    "aquaties": ("aquatir",),
    "aquati": ("aquatir",),
    "aquatîmes": ("aquatir",),
    "aquatira": ("aquatir",),
    "aquatiraient": ("aquatir",),
    "aquatirai": ("aquatir",),
    "aquatirais": ("aquatir",),
    "aquatirait": ("aquatir",),
    "aquatiras": ("aquatir",),
    "aquatirent": ("aquatir",),
    "aquatirez": ("aquatir",),
    "aquatiriez": ("aquatir",),
    "aquatirions": ("aquatir",),
    "aquatirons": ("aquatir",),
    "aquatiront": ("aquatir",),
    "aquatis": ("aquatir",),
    "aquatissaient": ("aquatir",),
    "aquatissais": ("aquatir",),
    "aquatissait": ("aquatir",),
    "aquatissant": ("aquatir",),
    "aquatissent": ("aquatir",),
    "aquatisse": ("aquatir",),
    "aquatisses": ("aquatir",),
    "aquatissez": ("aquatir",),
    "aquatissiez": ("aquatir",),
    "aquatissions": ("aquatir",),
    "aquatissons": ("aquatir",),
    "aquatîtes": ("aquatir",),
    "aquatit": ("aquatir",),
    "aquatît": ("aquatir",),
    "arbitrageaient": ("arbitrager",),
    "arbitrageai": ("arbitrager",),
    "arbitrageais": ("arbitrager",),
    "arbitrageait": ("arbitrager",),
    "arbitragea": ("arbitrager",),
    "arbitrageâmes": ("arbitrager",),
    "arbitrageant": ("arbitrager",),
    "arbitrageas": ("arbitrager",),
    "arbitrageassent": ("arbitrager",),
    "arbitrageasses": ("arbitrager",),
    "arbitrageasse": ("arbitrager",),
    "arbitrageassiez": ("arbitrager",),
    "arbitrageassions": ("arbitrager",),
    "arbitrageâtes": ("arbitrager",),
    "arbitrageât": ("arbitrager",),
    "arbitragée": ("arbitrager",),
    "arbitragées": ("arbitrager",),
    "arbitragé": ("arbitrager",),
    "arbitragent": ("arbitrager",),
    "arbitrageons": ("arbitrager",),
    "arbitrage": ("arbitrager",),
    "arbitragera": ("arbitrager",),
    "arbitrageraient": ("arbitrager",),
    "arbitragerai": ("arbitrager",),
    "arbitragerais": ("arbitrager",),
    "arbitragerait": ("arbitrager",),
    "arbitrageras": ("arbitrager",),
    "arbitragèrent": ("arbitrager",),
    "arbitragerez": ("arbitrager",),
    "arbitrageriez": ("arbitrager",),
    "arbitragerions": ("arbitrager",),
    "arbitragerons": ("arbitrager",),
    "arbitrageront": ("arbitrager",),
    "arbitragés": ("arbitrager",),
    "arbitrages": ("arbitrager",),
    "arbitragez": ("arbitrager",),
    "arbitragiez": ("arbitrager",),
    "arbitragions": ("arbitrager",),
    "ardaient": ("ardre",),
    "ardai": ("ardre",),
    "ardais": ("ardre",),
    "ardait": ("ardre",),
    "arda": ("ardre",),
    "ardâmes": ("ardre",),
    "ardas": ("ardre",),
    "ardâtes": ("ardre",),
    "ardèrent": ("ardre",),
    "ardiez": ("ardre",),
    "ardions": ("ardre",),
    "arénaient": ("aréner",),
    "arénai": ("aréner",),
    "arénais": ("aréner",),
    "arénait": ("aréner",),
    "aréna": ("aréner",),
    "arénâmes": ("aréner",),
    "arénant": ("aréner",),
    "arénas": ("aréner",),
    "arénassent": ("aréner",),
    "arénasses": ("aréner",),
    "arénasse": ("aréner",),
    "arénassiez": ("aréner",),
    "arénassions": ("aréner",),
    "arénâtes": ("aréner",),
    "arénât": ("aréner",),
    "arénée": ("aréner",),
    "arénées": ("aréner",),
    "aréné": ("aréner",),
    "arènent": ("aréner",),
    "arène": ("aréner",),
    "arénera": ("aréner",),
    "aréneraient": ("aréner",),
    "arénerai": ("aréner",),
    "arénerais": ("aréner",),
    "arénerait": ("aréner",),
    "aréneras": ("aréner",),
    "arénèrent": ("aréner",),
    "arénerez": ("aréner",),
    "aréneriez": ("aréner",),
    "arénerions": ("aréner",),
    "arénerons": ("aréner",),
    "aréneront": ("aréner",),
    "arénés": ("aréner",),
    "arènes": ("aréner",),
    "arénez": ("aréner",),
    "aréniez": ("aréner",),
    "arénions": ("aréner",),
    "arénons": ("aréner",),
    "arguaient": ("arguer",),
    "arguai": ("arguer",),
    "arguais": ("arguer",),
    "arguait": ("arguer",),
    "argua": ("arguer",),
    "arguâmes": ("arguer",),
    "arguant": ("arguer",),
    "arguas": ("arguer",),
    "arguassent": ("arguer",),
    "arguasses": ("arguer",),
    "arguasse": ("arguer",),
    "arguassiez": ("arguer",),
    "arguassions": ("arguer",),
    "arguâtes": ("arguer",),
    "arguât": ("arguer",),
    "argué": ("arguer",),
    "arguent": ("arguer",),
    "arguënt": ("arguer",),
    "argue": ("arguer",),
    "arguë": ("arguer",),
    "arguera": ("arguer",),
    "arguëra": ("arguer",),
    "argueraient": ("arguer",),
    "arguëraient": ("arguer",),
    "arguerai": ("arguer",),
    "arguërai": ("arguer",),
    "arguerais": ("arguer",),
    "arguërais": ("arguer",),
    "arguerait": ("arguer",),
    "arguërait": ("arguer",),
    "argueras": ("arguer",),
    "arguëras": ("arguer",),
    "arguèrent": ("arguer",),
    "arguerez": ("arguer",),
    "arguërez": ("arguer",),
    "argueriez": ("arguer",),
    "arguëriez": ("arguer",),
    "arguerions": ("arguer",),
    "arguërions": ("arguer",),
    "arguerons": ("arguer",),
    "arguërons": ("arguer",),
    "argueront": ("arguer",),
    "arguëront": ("arguer",),
    "argues": ("arguer",),
    "arguës": ("arguer",),
    "arguez": ("arguer",),
    "arguiez": ("arguer",),
    "arguions": ("arguer",),
    "arguons": ("arguer",),
    "armoriaient": ("armorier",),
    "armoriai": ("armorier",),
    "armoriais": ("armorier",),
    "armoriait": ("armorier",),
    "armoria": ("armorier",),
    "armoriâmes": ("armorier",),
    "armoriant": ("armorier",),
    "armorias": ("armorier",),
    "armoriassent": ("armorier",),
    "armoriasses": ("armorier",),
    "armoriasse": ("armorier",),
    "armoriassiez": ("armorier",),
    "armoriassions": ("armorier",),
    "armoriâtes": ("armorier",),
    "armoriât": ("armorier",),
    "armoriée": ("armorier",),
    "armoriées": ("armorier",),
    "armorié": ("armorier",),
    "armorient": ("armorier",),
    "armorie": ("armorier",),
    "armoriera": ("armorier",),
    "armorieraient": ("armorier",),
    "armorierai": ("armorier",),
    "armorierais": ("armorier",),
    "armorierait": ("armorier",),
    "armorieras": ("armorier",),
    "armorièrent": ("armorier",),
    "armorierez": ("armorier",),
    "armorieriez": ("armorier",),
    "armorierions": ("armorier",),
    "armorierons": ("armorier",),
    "armorieront": ("armorier",),
    "armoriés": ("armorier",),
    "armories": ("armorier",),
    "armoriez": ("armorier",),
    "armoriiez": ("armorier",),
    "armoriions": ("armorier",),
    "armorions": ("armorier",),
    "arpégeaient": ("arpéger",),
    "arpégeai": ("arpéger",),
    "arpégeais": ("arpéger",),
    "arpégeait": ("arpéger",),
    "arpégea": ("arpéger",),
    "arpégeâmes": ("arpéger",),
    "arpégeant": ("arpéger",),
    "arpégeas": ("arpéger",),
    "arpégeassent": ("arpéger",),
    "arpégeasses": ("arpéger",),
    "arpégeasse": ("arpéger",),
    "arpégeassiez": ("arpéger",),
    "arpégeassions": ("arpéger",),
    "arpégeâtes": ("arpéger",),
    "arpégeât": ("arpéger",),
    "arpégée": ("arpéger",),
    "arpégées": ("arpéger",),
    "arpégé": ("arpéger",),
    "arpègent": ("arpéger",),
    "arpégeons": ("arpéger",),
    "arpège": ("arpéger",),
    "arpégera": ("arpéger",),
    "arpégeraient": ("arpéger",),
    "arpégerai": ("arpéger",),
    "arpégerais": ("arpéger",),
    "arpégerait": ("arpéger",),
    "arpégeras": ("arpéger",),
    "arpégèrent": ("arpéger",),
    "arpégerez": ("arpéger",),
    "arpégeriez": ("arpéger",),
    "arpégerions": ("arpéger",),
    "arpégerons": ("arpéger",),
    "arpégeront": ("arpéger",),
    "arpégés": ("arpéger",),
    "arpèges": ("arpéger",),
    "arpégez": ("arpéger",),
    "arpégiez": ("arpéger",),
    "arpégions": ("arpéger",),
    "arquepinçaient": ("arquepincer",),
    "arquepinçai": ("arquepincer",),
    "arquepinçais": ("arquepincer",),
    "arquepinçait": ("arquepincer",),
    "arquepinça": ("arquepincer",),
    "arquepinçâmes": ("arquepincer",),
    "arquepinçant": ("arquepincer",),
    "arquepinças": ("arquepincer",),
    "arquepinçassent": ("arquepincer",),
    "arquepinçasses": ("arquepincer",),
    "arquepinçasse": ("arquepincer",),
    "arquepinçassiez": ("arquepincer",),
    "arquepinçassions": ("arquepincer",),
    "arquepinçâtes": ("arquepincer",),
    "arquepinçât": ("arquepincer",),
    "arquepincée": ("arquepincer",),
    "arquepincées": ("arquepincer",),
    "arquepincé": ("arquepincer",),
    "arquepincent": ("arquepincer",),
    "arquepince": ("arquepincer",),
    "arquepincera": ("arquepincer",),
    "arquepinceraient": ("arquepincer",),
    "arquepincerai": ("arquepincer",),
    "arquepincerais": ("arquepincer",),
    "arquepincerait": ("arquepincer",),
    "arquepinceras": ("arquepincer",),
    "arquepincèrent": ("arquepincer",),
    "arquepincerez": ("arquepincer",),
    "arquepinceriez": ("arquepincer",),
    "arquepincerions": ("arquepincer",),
    "arquepincerons": ("arquepincer",),
    "arquepinceront": ("arquepincer",),
    "arquepincés": ("arquepincer",),
    "arquepinces": ("arquepincer",),
    "arquepincez": ("arquepincer",),
    "arquepinciez": ("arquepincer",),
    "arquepincions": ("arquepincer",),
    "arquepinçons": ("arquepincer",),
    "arrangeaient": ("arranger",),
    "arrangeai": ("arranger",),
    "arrangeais": ("arranger",),
    "arrangeait": ("arranger",),
    "arrangea": ("arranger",),
    "arrangeâmes": ("arranger",),
    "arrangeant": ("arranger",),
    "arrangeas": ("arranger",),
    "arrangeassent": ("arranger",),
    "arrangeasses": ("arranger",),
    "arrangeasse": ("arranger",),
    "arrangeassiez": ("arranger",),
    "arrangeassions": ("arranger",),
    "arrangeâtes": ("arranger",),
    "arrangeât": ("arranger",),
    "arrangée": ("arranger",),
    "arrangées": ("arranger",),
    "arrangé": ("arranger",),
    "arrangent": ("arranger",),
    "arrangeons": ("arranger",),
    "arrange": ("arranger",),
    "arrangera": ("arranger",),
    "arrangeraient": ("arranger",),
    "arrangerai": ("arranger",),
    "arrangerais": ("arranger",),
    "arrangerait": ("arranger",),
    "arrangeras": ("arranger",),
    "arrangèrent": ("arranger",),
    "arrangerez": ("arranger",),
    "arrangeriez": ("arranger",),
    "arrangerions": ("arranger",),
    "arrangerons": ("arranger",),
    "arrangeront": ("arranger",),
    "arrangés": ("arranger",),
    "arranges": ("arranger",),
    "arrangez": ("arranger",),
    "arrangiez": ("arranger",),
    "arrangions": ("arranger",),
    "arrérageaient": ("arrérager",),
    "arrérageai": ("arrérager",),
    "arrérageais": ("arrérager",),
    "arrérageait": ("arrérager",),
    "arréragea": ("arrérager",),
    "arrérageâmes": ("arrérager",),
    "arrérageant": ("arrérager",),
    "arrérageas": ("arrérager",),
    "arrérageassent": ("arrérager",),
    "arrérageasses": ("arrérager",),
    "arrérageasse": ("arrérager",),
    "arrérageassiez": ("arrérager",),
    "arrérageassions": ("arrérager",),
    "arrérageâtes": ("arrérager",),
    "arrérageât": ("arrérager",),
    "arréragée": ("arrérager",),
    "arréragées": ("arrérager",),
    "arréragé": ("arrérager",),
    "arréragent": ("arrérager",),
    "arrérageons": ("arrérager",),
    "arrérage": ("arrérager",),
    "arréragera": ("arrérager",),
    "arrérageraient": ("arrérager",),
    "arréragerai": ("arrérager",),
    "arréragerais": ("arrérager",),
    "arréragerait": ("arrérager",),
    "arrérageras": ("arrérager",),
    "arréragèrent": ("arrérager",),
    "arréragerez": ("arrérager",),
    "arrérageriez": ("arrérager",),
    "arréragerions": ("arrérager",),
    "arréragerons": ("arrérager",),
    "arrérageront": ("arrérager",),
    "arréragés": ("arrérager",),
    "arrérages": ("arrérager",),
    "arréragez": ("arrérager",),
    "arréragiez": ("arrérager",),
    "arréragions": ("arrérager",),
    "arriéraient": ("arriérer",),
    "arriérai": ("arriérer",),
    "arriérais": ("arriérer",),
    "arriérait": ("arriérer",),
    "arriéra": ("arriérer",),
    "arriérâmes": ("arriérer",),
    "arriérant": ("arriérer",),
    "arriéras": ("arriérer",),
    "arriérassent": ("arriérer",),
    "arriérasses": ("arriérer",),
    "arriérasse": ("arriérer",),
    "arriérassiez": ("arriérer",),
    "arriérassions": ("arriérer",),
    "arriérâtes": ("arriérer",),
    "arriérât": ("arriérer",),
    "arriérée": ("arriérer",),
    "arriérées": ("arriérer",),
    "arriéré": ("arriérer",),
    "arrièrent": ("arriérer",),
    "arrière": ("arriérer",),
    "arriérera": ("arriérer",),
    "arriéreraient": ("arriérer",),
    "arriérerai": ("arriérer",),
    "arriérerais": ("arriérer",),
    "arriérerait": ("arriérer",),
    "arriéreras": ("arriérer",),
    "arriérèrent": ("arriérer",),
    "arriérerez": ("arriérer",),
    "arriéreriez": ("arriérer",),
    "arriérerions": ("arriérer",),
    "arriérerons": ("arriérer",),
    "arriéreront": ("arriérer",),
    "arriérés": ("arriérer",),
    "arrières": ("arriérer",),
    "arriérez": ("arriérer",),
    "arriériez": ("arriérer",),
    "arriérions": ("arriérer",),
    "arriérons": ("arriérer",),
    "arrogeaient": ("arroger",),
    "arrogeai": ("arroger",),
    "arrogeais": ("arroger",),
    "arrogeait": ("arroger",),
    "arrogea": ("arroger",),
    "arrogeâmes": ("arroger",),
    "arrogeant": ("arroger",),
    "arrogeas": ("arroger",),
    "arrogeassent": ("arroger",),
    "arrogeasses": ("arroger",),
    "arrogeasse": ("arroger",),
    "arrogeassiez": ("arroger",),
    "arrogeassions": ("arroger",),
    "arrogeâtes": ("arroger",),
    "arrogeât": ("arroger",),
    "arrogée": ("arroger",),
    "arrogées": ("arroger",),
    "arrogé": ("arroger",),
    "arrogent": ("arroger",),
    "arrogeons": ("arroger",),
    "arroge": ("arroger",),
    "arrogera": ("arroger",),
    "arrogeraient": ("arroger",),
    "arrogerai": ("arroger",),
    "arrogerais": ("arroger",),
    "arrogerait": ("arroger",),
    "arrogeras": ("arroger",),
    "arrogèrent": ("arroger",),
    "arrogerez": ("arroger",),
    "arrogeriez": ("arroger",),
    "arrogerions": ("arroger",),
    "arrogerons": ("arroger",),
    "arrogeront": ("arroger",),
    "arrogés": ("arroger",),
    "arroges": ("arroger",),
    "arrogez": ("arroger",),
    "arrogiez": ("arroger",),
    "arrogions": ("arroger",),
    "arrondie": ("arrondir",),
    "arrondies": ("arrondir",),
    "arrondi": ("arrondir",),
    "arrondîmes": ("arrondir",),
    "arrondira": ("arrondir",),
    "arrondiraient": ("arrondir",),
    "arrondirai": ("arrondir",),
    "arrondirais": ("arrondir",),
    "arrondirait": ("arrondir",),
    "arrondiras": ("arrondir",),
    "arrondirent": ("arrondir",),
    "arrondirez": ("arrondir",),
    "arrondiriez": ("arrondir",),
    "arrondirions": ("arrondir",),
    "arrondirons": ("arrondir",),
    "arrondiront": ("arrondir",),
    "arrondis": ("arrondir",),
    "arrondissaient": ("arrondir",),
    "arrondissais": ("arrondir",),
    "arrondissait": ("arrondir",),
    "arrondissant": ("arrondir",),
    "arrondissent": ("arrondir",),
    "arrondisse": ("arrondir",),
    "arrondisses": ("arrondir",),
    "arrondissez": ("arrondir",),
    "arrondissiez": ("arrondir",),
    "arrondissions": ("arrondir",),
    "arrondissons": ("arrondir",),
    "arrondîtes": ("arrondir",),
    "arrondit": ("arrondir",),
    "arrondît": ("arrondir",),
    "ascendaient": ("ascendre",),
    "ascendais": ("ascendre",),
    "ascendait": ("ascendre",),
    "ascendant": ("ascendre",),
    "ascendent": ("ascendre",),
    "ascende": ("ascendre",),
    "ascendes": ("ascendre",),
    "ascendez": ("ascendre",),
    "ascendiez": ("ascendre",),
    "ascendîmes": ("ascendre",),
    "ascendions": ("ascendre",),
    "ascendirent": ("ascendre",),
    "ascendis": ("ascendre",),
    "ascendissent": ("ascendre",),
    "ascendisses": ("ascendre",),
    "ascendisse": ("ascendre",),
    "ascendissiez": ("ascendre",),
    "ascendissions": ("ascendre",),
    "ascendîtes": ("ascendre",),
    "ascendit": ("ascendre",),
    "ascendît": ("ascendre",),
    "ascendons": ("ascendre",),
    "ascend": ("ascendre",),
    "ascendra": ("ascendre",),
    "ascendraient": ("ascendre",),
    "ascendrai": ("ascendre",),
    "ascendrais": ("ascendre",),
    "ascendrait": ("ascendre",),
    "ascendras": ("ascendre",),
    "ascendrez": ("ascendre",),
    "ascendriez": ("ascendre",),
    "ascendrions": ("ascendre",),
    "ascendrons": ("ascendre",),
    "ascendront": ("ascendre",),
    "ascends": ("ascendre",),
    "ascendue": ("ascendre",),
    "ascendues": ("ascendre",),
    "ascendu": ("ascendre",),
    "ascendus": ("ascendre",),
    "aspergeaient": ("asperger",),
    "aspergeai": ("asperger",),
    "aspergeais": ("asperger",),
    "aspergeait": ("asperger",),
    "aspergea": ("asperger",),
    "aspergeâmes": ("asperger",),
    "aspergeant": ("asperger",),
    "aspergeas": ("asperger",),
    "aspergeassent": ("asperger",),
    "aspergeasses": ("asperger",),
    "aspergeasse": ("asperger",),
    "aspergeassiez": ("asperger",),
    "aspergeassions": ("asperger",),
    "aspergeâtes": ("asperger",),
    "aspergeât": ("asperger",),
    "aspergée": ("asperger",),
    "aspergées": ("asperger",),
    "aspergé": ("asperger",),
    "aspergent": ("asperger",),
    "aspergeons": ("asperger",),
    "asperge": ("asperger",),
    "aspergera": ("asperger",),
    "aspergeraient": ("asperger",),
    "aspergerai": ("asperger",),
    "aspergerais": ("asperger",),
    "aspergerait": ("asperger",),
    "aspergeras": ("asperger",),
    "aspergèrent": ("asperger",),
    "aspergerez": ("asperger",),
    "aspergeriez": ("asperger",),
    "aspergerions": ("asperger",),
    "aspergerons": ("asperger",),
    "aspergeront": ("asperger",),
    "aspergés": ("asperger",),
    "asperges": ("asperger",),
    "aspergez": ("asperger",),
    "aspergiez": ("asperger",),
    "aspergions": ("asperger",),
    "asphyxiaient": ("asphyxier",),
    "asphyxiai": ("asphyxier",),
    "asphyxiais": ("asphyxier",),
    "asphyxiait": ("asphyxier",),
    "asphyxia": ("asphyxier",),
    "asphyxiâmes": ("asphyxier",),
    "asphyxiant": ("asphyxier",),
    "asphyxias": ("asphyxier",),
    "asphyxiassent": ("asphyxier",),
    "asphyxiasses": ("asphyxier",),
    "asphyxiasse": ("asphyxier",),
    "asphyxiassiez": ("asphyxier",),
    "asphyxiassions": ("asphyxier",),
    "asphyxiâtes": ("asphyxier",),
    "asphyxiât": ("asphyxier",),
    "asphyxiée": ("asphyxier",),
    "asphyxiées": ("asphyxier",),
    "asphyxié": ("asphyxier",),
    "asphyxient": ("asphyxier",),
    "asphyxie": ("asphyxier",),
    "asphyxiera": ("asphyxier",),
    "asphyxieraient": ("asphyxier",),
    "asphyxierai": ("asphyxier",),
    "asphyxierais": ("asphyxier",),
    "asphyxierait": ("asphyxier",),
    "asphyxieras": ("asphyxier",),
    "asphyxièrent": ("asphyxier",),
    "asphyxierez": ("asphyxier",),
    "asphyxieriez": ("asphyxier",),
    "asphyxierions": ("asphyxier",),
    "asphyxierons": ("asphyxier",),
    "asphyxieront": ("asphyxier",),
    "asphyxiés": ("asphyxier",),
    "asphyxies": ("asphyxier",),
    "asphyxiez": ("asphyxier",),
    "asphyxiiez": ("asphyxier",),
    "asphyxiions": ("asphyxier",),
    "asphyxions": ("asphyxier",),
    "assagie": ("assagir",),
    "assagies": ("assagir",),
    "assagi": ("assagir",),
    "assagîmes": ("assagir",),
    "assagira": ("assagir",),
    "assagiraient": ("assagir",),
    "assagirai": ("assagir",),
    "assagirais": ("assagir",),
    "assagirait": ("assagir",),
    "assagiras": ("assagir",),
    "assagirent": ("assagir",),
    "assagirez": ("assagir",),
    "assagiriez": ("assagir",),
    "assagirions": ("assagir",),
    "assagirons": ("assagir",),
    "assagiront": ("assagir",),
    "assagis": ("assagir",),
    "assagissaient": ("assagir",),
    "assagissais": ("assagir",),
    "assagissait": ("assagir",),
    "assagissant": ("assagir",),
    "assagissent": ("assagir",),
    "assagisse": ("assagir",),
    "assagisses": ("assagir",),
    "assagissez": ("assagir",),
    "assagissiez": ("assagir",),
    "assagissions": ("assagir",),
    "assagissons": ("assagir",),
    "assagîtes": ("assagir",),
    "assagit": ("assagir",),
    "assagît": ("assagir",),
    "assaillaient": ("assaillir",),
    "assaillais": ("assaillir",),
    "assaillait": ("assaillir",),
    "assaillant": ("assaillir",),
    "assaillent": ("assaillir",),
    "assaille": ("assaillir",),
    "assaillera": ("assaillir",),
    "assailleraient": ("assaillir",),
    "assaillerai": ("assaillir",),
    "assaillerais": ("assaillir",),
    "assaillerait": ("assaillir",),
    "assailleras": ("assaillir",),
    "assaillerez": ("assaillir",),
    "assailleriez": ("assaillir",),
    "assaillerions": ("assaillir",),
    "assaillerons": ("assaillir",),
    "assailleront": ("assaillir",),
    "assailles": ("assaillir",),
    "assaillez": ("assaillir",),
    "assaillie": ("assaillir",),
    "assaillies": ("assaillir",),
    "assailliez": ("assaillir",),
    "assailli": ("assaillir",),
    "assaillîmes": ("assaillir",),
    "assaillions": ("assaillir",),
    "assaillira": ("assaillir",),
    "assailliraient": ("assaillir",),
    "assaillirai": ("assaillir",),
    "assaillirais": ("assaillir",),
    "assaillirait": ("assaillir",),
    "assailliras": ("assaillir",),
    "assaillirent": ("assaillir",),
    "assaillirez": ("assaillir",),
    "assailliriez": ("assaillir",),
    "assaillirions": ("assaillir",),
    "assaillirons": ("assaillir",),
    "assailliront": ("assaillir",),
    "assaillis": ("assaillir",),
    "assaillissent": ("assaillir",),
    "assaillisses": ("assaillir",),
    "assaillisse": ("assaillir",),
    "assaillissiez": ("assaillir",),
    "assaillissions": ("assaillir",),
    "assaillîtes": ("assaillir",),
    "assaillit": ("assaillir",),
    "assaillît": ("assaillir",),
    "assaillons": ("assaillir",),
    "assainie": ("assainir",),
    "assainies": ("assainir",),
    "assaini": ("assainir",),
    "assainîmes": ("assainir",),
    "assainira": ("assainir",),
    "assainiraient": ("assainir",),
    "assainirai": ("assainir",),
    "assainirais": ("assainir",),
    "assainirait": ("assainir",),
    "assainiras": ("assainir",),
    "assainirent": ("assainir",),
    "assainirez": ("assainir",),
    "assainiriez": ("assainir",),
    "assainirions": ("assainir",),
    "assainirons": ("assainir",),
    "assainiront": ("assainir",),
    "assainis": ("assainir",),
    "assainissaient": ("assainir",),
    "assainissais": ("assainir",),
    "assainissait": ("assainir",),
    "assainissant": ("assainir",),
    "assainissent": ("assainir",),
    "assainisse": ("assainir",),
    "assainisses": ("assainir",),
    "assainissez": ("assainir",),
    "assainissiez": ("assainir",),
    "assainissions": ("assainir",),
    "assainissons": ("assainir",),
    "assainîtes": ("assainir",),
    "assainit": ("assainir",),
    "assainît": ("assainir",),
    "assauvagie": ("assauvagir",),
    "assauvagies": ("assauvagir",),
    "assauvagi": ("assauvagir",),
    "assauvagîmes": ("assauvagir",),
    "assauvagira": ("assauvagir",),
    "assauvagiraient": ("assauvagir",),
    "assauvagirai": ("assauvagir",),
    "assauvagirais": ("assauvagir",),
    "assauvagirait": ("assauvagir",),
    "assauvagiras": ("assauvagir",),
    "assauvagirent": ("assauvagir",),
    "assauvagirez": ("assauvagir",),
    "assauvagiriez": ("assauvagir",),
    "assauvagirions": ("assauvagir",),
    "assauvagirons": ("assauvagir",),
    "assauvagiront": ("assauvagir",),
    "assauvagis": ("assauvagir",),
    "assauvagissaient": ("assauvagir",),
    "assauvagissais": ("assauvagir",),
    "assauvagissait": ("assauvagir",),
    "assauvagissant": ("assauvagir",),
    "assauvagissent": ("assauvagir",),
    "assauvagisse": ("assauvagir",),
    "assauvagisses": ("assauvagir",),
    "assauvagissez": ("assauvagir",),
    "assauvagissiez": ("assauvagir",),
    "assauvagissions": ("assauvagir",),
    "assauvagissons": ("assauvagir",),
    "assauvagîtes": ("assauvagir",),
    "assauvagit": ("assauvagir",),
    "assauvagît": ("assauvagir",),
    "asséchaient": ("assécher",),
    "asséchai": ("assécher",),
    "asséchais": ("assécher",),
    "asséchait": ("assécher",),
    "assécha": ("assécher",),
    "asséchâmes": ("assécher",),
    "asséchant": ("assécher",),
    "asséchas": ("assécher",),
    "asséchassent": ("assécher",),
    "asséchasses": ("assécher",),
    "asséchasse": ("assécher",),
    "asséchassiez": ("assécher",),
    "asséchassions": ("assécher",),
    "asséchâtes": ("assécher",),
    "asséchât": ("assécher",),
    "asséchée": ("assécher",),
    "asséchées": ("assécher",),
    "asséché": ("assécher",),
    "assèchent": ("assécher",),
    "assèche": ("assécher",),
    "asséchera": ("assécher",),
    "assécheraient": ("assécher",),
    "assécherai": ("assécher",),
    "assécherais": ("assécher",),
    "assécherait": ("assécher",),
    "assécheras": ("assécher",),
    "asséchèrent": ("assécher",),
    "assécherez": ("assécher",),
    "assécheriez": ("assécher",),
    "assécherions": ("assécher",),
    "assécherons": ("assécher",),
    "assécheront": ("assécher",),
    "asséchés": ("assécher",),
    "assèches": ("assécher",),
    "asséchez": ("assécher",),
    "asséchiez": ("assécher",),
    "asséchions": ("assécher",),
    "asséchons": ("assécher",),
    "assens": ("assentir",),
    "assentaient": ("assentir",),
    "assentais": ("assentir",),
    "assentait": ("assentir",),
    "assentant": ("assentir",),
    "assentent": ("assentir",),
    "assente": ("assentir",),
    "assentes": ("assentir",),
    "assentez": ("assentir",),
    "assentiez": ("assentir",),
    "assenti": ("assentir",),
    "assentîmes": ("assentir",),
    "assentions": ("assentir",),
    "assentira": ("assentir",),
    "assentiraient": ("assentir",),
    "assentirai": ("assentir",),
    "assentirais": ("assentir",),
    "assentirait": ("assentir",),
    "assentiras": ("assentir",),
    "assentirent": ("assentir",),
    "assentirez": ("assentir",),
    "assentiriez": ("assentir",),
    "assentirions": ("assentir",),
    "assentirons": ("assentir",),
    "assentiront": ("assentir",),
    "assentis": ("assentir",),
    "assentissent": ("assentir",),
    "assentisses": ("assentir",),
    "assentisse": ("assentir",),
    "assentissiez": ("assentir",),
    "assentissions": ("assentir",),
    "assentîtes": ("assentir",),
    "assentit": ("assentir",),
    "assentît": ("assentir",),
    "assentons": ("assentir",),
    "assent": ("assentir",),
    "asseyaient": ("asseoir",),
    "asseyais": ("asseoir",),
    "asseyait": ("asseoir",),
    "asseyant": ("asseoir",),
    "asseyent": ("asseoir",),
    "asseye": ("asseoir",),
    "asseyes": ("asseoir",),
    "asseyez": ("asseoir",),
    "asseyiez": ("asseoir",),
    "asseyions": ("asseoir",),
    "asseyons": ("asseoir",),
    "assied": ("asseoir",),
    "assieds": ("asseoir",),
    "assiéra": ("asseoir",),
    "assiéraient": ("asseoir",),
    "assiérai": ("asseoir",),
    "assiérais": ("asseoir",),
    "assiérait": ("asseoir",),
    "assiéras": ("asseoir",),
    "assiérez": ("asseoir",),
    "assiériez": ("asseoir",),
    "assiérions": ("asseoir",),
    "assiérons": ("asseoir",),
    "assiéront": ("asseoir",),
    "assîmes": ("asseoir",),
    "assirent": ("asseoir",),
    "assise": ("asseoir",),
    "assises": ("asseoir",),
    "assis": ("asseoir",),
    "assissent": ("asseoir",),
    "assisses": ("asseoir",),
    "assisse": ("asseoir",),
    "assissiez": ("asseoir",),
    "assissions": ("asseoir",),
    "assîtes": ("asseoir",),
    "assit": ("asseoir",),
    "assît": ("asseoir",),
    "assoient": ("asseoir",),
    "assoie": ("asseoir",),
    "assoies": ("asseoir",),
    "assoira": ("asseoir",),
    "assoiraient": ("asseoir",),
    "assoirai": ("asseoir",),
    "assoirais": ("asseoir",),
    "assoirait": ("asseoir",),
    "assoiras": ("asseoir",),
    "assoirez": ("asseoir",),
    "assoiriez": ("asseoir",),
    "assoirions": ("asseoir",),
    "assoirons": ("asseoir",),
    "assoiront": ("asseoir",),
    "assois": ("asseoir",),
    "assoit": ("asseoir",),
    "assoyaient": ("asseoir",),
    "assoyais": ("asseoir",),
    "assoyait": ("asseoir",),
    "assoyant": ("asseoir",),
    "assoyez": ("asseoir",),
    "assoyiez": ("asseoir",),
    "assoyions": ("asseoir",),
    "assoyons": ("asseoir",),
    "asservie": ("asservir",),
    "asservies": ("asservir",),
    "asservi": ("asservir",),
    "asservîmes": ("asservir",),
    "asservira": ("asservir",),
    "asserviraient": ("asservir",),
    "asservirai": ("asservir",),
    "asservirais": ("asservir",),
    "asservirait": ("asservir",),
    "asserviras": ("asservir",),
    "asservirent": ("asservir",),
    "asservirez": ("asservir",),
    "asserviriez": ("asservir",),
    "asservirions": ("asservir",),
    "asservirons": ("asservir",),
    "asserviront": ("asservir",),
    "asservis": ("asservir",),
    "asservissaient": ("asservir",),
    "asservissais": ("asservir",),
    "asservissait": ("asservir",),
    "asservissant": ("asservir",),
    "asservissent": ("asservir",),
    "asservisse": ("asservir",),
    "asservisses": ("asservir",),
    "asservissez": ("asservir",),
    "asservissiez": ("asservir",),
    "asservissions": ("asservir",),
    "asservissons": ("asservir",),
    "asservîtes": ("asservir",),
    "asservit": ("asservir",),
    "asservît": ("asservir",),
    "assiégeaient": ("assiéger",),
    "assiégeai": ("assiéger",),
    "assiégeais": ("assiéger",),
    "assiégeait": ("assiéger",),
    "assiégea": ("assiéger",),
    "assiégeâmes": ("assiéger",),
    "assiégeant": ("assiéger",),
    "assiégeas": ("assiéger",),
    "assiégeassent": ("assiéger",),
    "assiégeasses": ("assiéger",),
    "assiégeasse": ("assiéger",),
    "assiégeassiez": ("assiéger",),
    "assiégeassions": ("assiéger",),
    "assiégeâtes": ("assiéger",),
    "assiégeât": ("assiéger",),
    "assiégée": ("assiéger",),
    "assiégées": ("assiéger",),
    "assiégé": ("assiéger",),
    "assiègent": ("assiéger",),
    "assiégeons": ("assiéger",),
    "assiège": ("assiéger",),
    "assiégera": ("assiéger",),
    "assiégeraient": ("assiéger",),
    "assiégerai": ("assiéger",),
    "assiégerais": ("assiéger",),
    "assiégerait": ("assiéger",),
    "assiégeras": ("assiéger",),
    "assiégèrent": ("assiéger",),
    "assiégerez": ("assiéger",),
    "assiégeriez": ("assiéger",),
    "assiégerions": ("assiéger",),
    "assiégerons": ("assiéger",),
    "assiégeront": ("assiéger",),
    "assiégés": ("assiéger",),
    "assièges": ("assiéger",),
    "assiégez": ("assiéger",),
    "assiégiez": ("assiéger",),
    "assiégions": ("assiéger",),
    "associaient": ("associer",),
    "associai": ("associer",),
    "associais": ("associer",),
    "associait": ("associer",),
    "associa": ("associer",),
    "associâmes": ("associer",),
    "associant": ("associer",),
    "associas": ("associer",),
    "associassent": ("associer",),
    "associasses": ("associer",),
    "associasse": ("associer",),
    "associassiez": ("associer",),
    "associassions": ("associer",),
    "associâtes": ("associer",),
    "associât": ("associer",),
    "associée": ("associer",),
    "associées": ("associer",),
    "associé": ("associer",),
    "associent": ("associer",),
    "associe": ("associer",),
    "associera": ("associer",),
    "associeraient": ("associer",),
    "associerai": ("associer",),
    "associerais": ("associer",),
    "associerait": ("associer",),
    "associeras": ("associer",),
    "associèrent": ("associer",),
    "associerez": ("associer",),
    "associeriez": ("associer",),
    "associerions": ("associer",),
    "associerons": ("associer",),
    "associeront": ("associer",),
    "associés": ("associer",),
    "associes": ("associer",),
    "associez": ("associer",),
    "associiez": ("associer",),
    "associions": ("associer",),
    "associons": ("associer",),
    "assombrie": ("assombrir",),
    "assombries": ("assombrir",),
    "assombri": ("assombrir",),
    "assombrîmes": ("assombrir",),
    "assombrira": ("assombrir",),
    "assombriraient": ("assombrir",),
    "assombrirai": ("assombrir",),
    "assombrirais": ("assombrir",),
    "assombrirait": ("assombrir",),
    "assombriras": ("assombrir",),
    "assombrirent": ("assombrir",),
    "assombrirez": ("assombrir",),
    "assombririez": ("assombrir",),
    "assombririons": ("assombrir",),
    "assombrirons": ("assombrir",),
    "assombriront": ("assombrir",),
    "assombris": ("assombrir",),
    "assombrissaient": ("assombrir",),
    "assombrissais": ("assombrir",),
    "assombrissait": ("assombrir",),
    "assombrissant": ("assombrir",),
    "assombrissent": ("assombrir",),
    "assombrisse": ("assombrir",),
    "assombrisses": ("assombrir",),
    "assombrissez": ("assombrir",),
    "assombrissiez": ("assombrir",),
    "assombrissions": ("assombrir",),
    "assombrissons": ("assombrir",),
    "assombrîtes": ("assombrir",),
    "assombrit": ("assombrir",),
    "assombrît": ("assombrir",),
    "assonançaient": ("assonancer",),
    "assonançai": ("assonancer",),
    "assonançais": ("assonancer",),
    "assonançait": ("assonancer",),
    "assonança": ("assonancer",),
    "assonançâmes": ("assonancer",),
    "assonançant": ("assonancer",),
    "assonanças": ("assonancer",),
    "assonançassent": ("assonancer",),
    "assonançasses": ("assonancer",),
    "assonançasse": ("assonancer",),
    "assonançassiez": ("assonancer",),
    "assonançassions": ("assonancer",),
    "assonançâtes": ("assonancer",),
    "assonançât": ("assonancer",),
    "assonancée": ("assonancer",),
    "assonancées": ("assonancer",),
    "assonancé": ("assonancer",),
    "assonancent": ("assonancer",),
    "assonance": ("assonancer",),
    "assonancera": ("assonancer",),
    "assonanceraient": ("assonancer",),
    "assonancerai": ("assonancer",),
    "assonancerais": ("assonancer",),
    "assonancerait": ("assonancer",),
    "assonanceras": ("assonancer",),
    "assonancèrent": ("assonancer",),
    "assonancerez": ("assonancer",),
    "assonanceriez": ("assonancer",),
    "assonancerions": ("assonancer",),
    "assonancerons": ("assonancer",),
    "assonanceront": ("assonancer",),
    "assonancés": ("assonancer",),
    "assonances": ("assonancer",),
    "assonancez": ("assonancer",),
    "assonanciez": ("assonancer",),
    "assonancions": ("assonancer",),
    "assonançons": ("assonancer",),
    "assortie": ("assortir",),
    "assorties": ("assortir",),
    "assorti": ("assortir",),
    "assortîmes": ("assortir",),
    "assortira": ("assortir",),
    "assortiraient": ("assortir",),
    "assortirai": ("assortir",),
    "assortirais": ("assortir",),
    "assortirait": ("assortir",),
    "assortiras": ("assortir",),
    "assortirent": ("assortir",),
    "assortirez": ("assortir",),
    "assortiriez": ("assortir",),
    "assortirions": ("assortir",),
    "assortirons": ("assortir",),
    "assortiront": ("assortir",),
    "assortis": ("assortir",),
    "assortissaient": ("assortir",),
    "assortissais": ("assortir",),
    "assortissait": ("assortir",),
    "assortissant": ("assortir",),
    "assortissent": ("assortir",),
    "assortisse": ("assortir",),
    "assortisses": ("assortir",),
    "assortissez": ("assortir",),
    "assortissiez": ("assortir",),
    "assortissions": ("assortir",),
    "assortissons": ("assortir",),
    "assortîtes": ("assortir",),
    "assortit": ("assortir",),
    "assortît": ("assortir",),
    "assoupie": ("assoupir",),
    "assoupies": ("assoupir",),
    "assoupi": ("assoupir",),
    "assoupîmes": ("assoupir",),
    "assoupira": ("assoupir",),
    "assoupiraient": ("assoupir",),
    "assoupirai": ("assoupir",),
    "assoupirais": ("assoupir",),
    "assoupirait": ("assoupir",),
    "assoupiras": ("assoupir",),
    "assoupirent": ("assoupir",),
    "assoupirez": ("assoupir",),
    "assoupiriez": ("assoupir",),
    "assoupirions": ("assoupir",),
    "assoupirons": ("assoupir",),
    "assoupiront": ("assoupir",),
    "assoupis": ("assoupir",),
    "assoupissaient": ("assoupir",),
    "assoupissais": ("assoupir",),
    "assoupissait": ("assoupir",),
    "assoupissant": ("assoupir",),
    "assoupissent": ("assoupir",),
    "assoupisse": ("assoupir",),
    "assoupisses": ("assoupir",),
    "assoupissez": ("assoupir",),
    "assoupissiez": ("assoupir",),
    "assoupissions": ("assoupir",),
    "assoupissons": ("assoupir",),
    "assoupîtes": ("assoupir",),
    "assoupit": ("assoupir",),
    "assoupît": ("assoupir",),
    "assouplie": ("assouplir",),
    "assouplies": ("assouplir",),
    "assoupli": ("assouplir",),
    "assouplîmes": ("assouplir",),
    "assouplira": ("assouplir",),
    "assoupliraient": ("assouplir",),
    "assouplirai": ("assouplir",),
    "assouplirais": ("assouplir",),
    "assouplirait": ("assouplir",),
    "assoupliras": ("assouplir",),
    "assouplirent": ("assouplir",),
    "assouplirez": ("assouplir",),
    "assoupliriez": ("assouplir",),
    "assouplirions": ("assouplir",),
    "assouplirons": ("assouplir",),
    "assoupliront": ("assouplir",),
    "assouplis": ("assouplir",),
    "assouplissaient": ("assouplir",),
    "assouplissais": ("assouplir",),
    "assouplissait": ("assouplir",),
    "assouplissant": ("assouplir",),
    "assouplissent": ("assouplir",),
    "assouplisse": ("assouplir",),
    "assouplisses": ("assouplir",),
    "assouplissez": ("assouplir",),
    "assouplissiez": ("assouplir",),
    "assouplissions": ("assouplir",),
    "assouplissons": ("assouplir",),
    "assouplîtes": ("assouplir",),
    "assouplit": ("assouplir",),
    "assouplît": ("assouplir",),
    "assourdie": ("assourdir",),
    "assourdies": ("assourdir",),
    "assourdi": ("assourdir",),
    "assourdîmes": ("assourdir",),
    "assourdira": ("assourdir",),
    "assourdiraient": ("assourdir",),
    "assourdirai": ("assourdir",),
    "assourdirais": ("assourdir",),
    "assourdirait": ("assourdir",),
    "assourdiras": ("assourdir",),
    "assourdirent": ("assourdir",),
    "assourdirez": ("assourdir",),
    "assourdiriez": ("assourdir",),
    "assourdirions": ("assourdir",),
    "assourdirons": ("assourdir",),
    "assourdiront": ("assourdir",),
    "assourdis": ("assourdir",),
    "assourdissaient": ("assourdir",),
    "assourdissais": ("assourdir",),
    "assourdissait": ("assourdir",),
    "assourdissant": ("assourdir",),
    "assourdissent": ("assourdir",),
    "assourdisse": ("assourdir",),
    "assourdisses": ("assourdir",),
    "assourdissez": ("assourdir",),
    "assourdissiez": ("assourdir",),
    "assourdissions": ("assourdir",),
    "assourdissons": ("assourdir",),
    "assourdîtes": ("assourdir",),
    "assourdit": ("assourdir",),
    "assourdît": ("assourdir",),
    "assouvie": ("assouvir",),
    "assouvies": ("assouvir",),
    "assouvi": ("assouvir",),
    "assouvîmes": ("assouvir",),
    "assouvira": ("assouvir",),
    "assouviraient": ("assouvir",),
    "assouvirai": ("assouvir",),
    "assouvirais": ("assouvir",),
    "assouvirait": ("assouvir",),
    "assouviras": ("assouvir",),
    "assouvirent": ("assouvir",),
    "assouvirez": ("assouvir",),
    "assouviriez": ("assouvir",),
    "assouvirions": ("assouvir",),
    "assouvirons": ("assouvir",),
    "assouviront": ("assouvir",),
    "assouvis": ("assouvir",),
    "assouvissaient": ("assouvir",),
    "assouvissais": ("assouvir",),
    "assouvissait": ("assouvir",),
    "assouvissant": ("assouvir",),
    "assouvissent": ("assouvir",),
    "assouvisse": ("assouvir",),
    "assouvisses": ("assouvir",),
    "assouvissez": ("assouvir",),
    "assouvissiez": ("assouvir",),
    "assouvissions": ("assouvir",),
    "assouvissons": ("assouvir",),
    "assouvîtes": ("assouvir",),
    "assouvit": ("assouvir",),
    "assouvît": ("assouvir",),
    "assujettie": ("assujettir",),
    "assujetties": ("assujettir",),
    "assujetti": ("assujettir",),
    "assujettîmes": ("assujettir",),
    "assujettira": ("assujettir",),
    "assujettiraient": ("assujettir",),
    "assujettirai": ("assujettir",),
    "assujettirais": ("assujettir",),
    "assujettirait": ("assujettir",),
    "assujettiras": ("assujettir",),
    "assujettirent": ("assujettir",),
    "assujettirez": ("assujettir",),
    "assujettiriez": ("assujettir",),
    "assujettirions": ("assujettir",),
    "assujettirons": ("assujettir",),
    "assujettiront": ("assujettir",),
    "assujettis": ("assujettir",),
    "assujettissaient": ("assujettir",),
    "assujettissais": ("assujettir",),
    "assujettissait": ("assujettir",),
    "assujettissant": ("assujettir",),
    "assujettissent": ("assujettir",),
    "assujettisse": ("assujettir",),
    "assujettisses": ("assujettir",),
    "assujettissez": ("assujettir",),
    "assujettissiez": ("assujettir",),
    "assujettissions": ("assujettir",),
    "assujettissons": ("assujettir",),
    "assujettîtes": ("assujettir",),
    "assujettit": ("assujettir",),
    "assujettît": ("assujettir",),
    "astreignaient": ("astreindre",),
    "astreignais": ("astreindre",),
    "astreignait": ("astreindre",),
    "astreignant": ("astreindre",),
    "astreignent": ("astreindre",),
    "astreigne": ("astreindre",),
    "astreignes": ("astreindre",),
    "astreignez": ("astreindre",),
    "astreigniez": ("astreindre",),
    "astreignîmes": ("astreindre",),
    "astreignions": ("astreindre",),
    "astreignirent": ("astreindre",),
    "astreignis": ("astreindre",),
    "astreignissent": ("astreindre",),
    "astreignisses": ("astreindre",),
    "astreignisse": ("astreindre",),
    "astreignissiez": ("astreindre",),
    "astreignissions": ("astreindre",),
    "astreignîtes": ("astreindre",),
    "astreignit": ("astreindre",),
    "astreignît": ("astreindre",),
    "astreignons": ("astreindre",),
    "astreindra": ("astreindre",),
    "astreindraient": ("astreindre",),
    "astreindrai": ("astreindre",),
    "astreindrais": ("astreindre",),
    "astreindrait": ("astreindre",),
    "astreindras": ("astreindre",),
    "astreindrez": ("astreindre",),
    "astreindriez": ("astreindre",),
    "astreindrions": ("astreindre",),
    "astreindrons": ("astreindre",),
    "astreindront": ("astreindre",),
    "astreins": ("astreindre",),
    "astreinte": ("astreindre",),
    "astreintes": ("astreindre",),
    "astreint": ("astreindre",),
    "astreints": ("astreindre",),
    "atermoient": ("atermoyer",),
    "atermoie": ("atermoyer",),
    "atermoiera": ("atermoyer",),
    "atermoieraient": ("atermoyer",),
    "atermoierai": ("atermoyer",),
    "atermoierais": ("atermoyer",),
    "atermoierait": ("atermoyer",),
    "atermoieras": ("atermoyer",),
    "atermoierez": ("atermoyer",),
    "atermoieriez": ("atermoyer",),
    "atermoierions": ("atermoyer",),
    "atermoierons": ("atermoyer",),
    "atermoieront": ("atermoyer",),
    "atermoies": ("atermoyer",),
    "atermoyaient": ("atermoyer",),
    "atermoyai": ("atermoyer",),
    "atermoyais": ("atermoyer",),
    "atermoyait": ("atermoyer",),
    "atermoya": ("atermoyer",),
    "atermoyâmes": ("atermoyer",),
    "atermoyant": ("atermoyer",),
    "atermoyas": ("atermoyer",),
    "atermoyassent": ("atermoyer",),
    "atermoyasses": ("atermoyer",),
    "atermoyasse": ("atermoyer",),
    "atermoyassiez": ("atermoyer",),
    "atermoyassions": ("atermoyer",),
    "atermoyâtes": ("atermoyer",),
    "atermoyât": ("atermoyer",),
    "atermoyé": ("atermoyer",),
    "atermoyèrent": ("atermoyer",),
    "atermoyez": ("atermoyer",),
    "atermoyiez": ("atermoyer",),
    "atermoyions": ("atermoyer",),
    "atermoyons": ("atermoyer",),
    "atigeaient": ("atiger",),
    "atigeai": ("atiger",),
    "atigeais": ("atiger",),
    "atigeait": ("atiger",),
    "atigea": ("atiger",),
    "atigeâmes": ("atiger",),
    "atigeant": ("atiger",),
    "atigeas": ("atiger",),
    "atigeassent": ("atiger",),
    "atigeasses": ("atiger",),
    "atigeasse": ("atiger",),
    "atigeassiez": ("atiger",),
    "atigeassions": ("atiger",),
    "atigeâtes": ("atiger",),
    "atigeât": ("atiger",),
    "atigée": ("atiger",),
    "atigées": ("atiger",),
    "atigé": ("atiger",),
    "atigent": ("atiger",),
    "atigeons": ("atiger",),
    "atige": ("atiger",),
    "atigera": ("atiger",),
    "atigeraient": ("atiger",),
    "atigerai": ("atiger",),
    "atigerais": ("atiger",),
    "atigerait": ("atiger",),
    "atigeras": ("atiger",),
    "atigèrent": ("atiger",),
    "atigerez": ("atiger",),
    "atigeriez": ("atiger",),
    "atigerions": ("atiger",),
    "atigerons": ("atiger",),
    "atigeront": ("atiger",),
    "atigés": ("atiger",),
    "atiges": ("atiger",),
    "atigez": ("atiger",),
    "atigiez": ("atiger",),
    "atigions": ("atiger",),
    "atrophiaient": ("atrophier",),
    "atrophiai": ("atrophier",),
    "atrophiais": ("atrophier",),
    "atrophiait": ("atrophier",),
    "atrophia": ("atrophier",),
    "atrophiâmes": ("atrophier",),
    "atrophiant": ("atrophier",),
    "atrophias": ("atrophier",),
    "atrophiassent": ("atrophier",),
    "atrophiasses": ("atrophier",),
    "atrophiasse": ("atrophier",),
    "atrophiassiez": ("atrophier",),
    "atrophiassions": ("atrophier",),
    "atrophiâtes": ("atrophier",),
    "atrophiât": ("atrophier",),
    "atrophiée": ("atrophier",),
    "atrophiées": ("atrophier",),
    "atrophié": ("atrophier",),
    "atrophient": ("atrophier",),
    "atrophie": ("atrophier",),
    "atrophiera": ("atrophier",),
    "atrophieraient": ("atrophier",),
    "atrophierai": ("atrophier",),
    "atrophierais": ("atrophier",),
    "atrophierait": ("atrophier",),
    "atrophieras": ("atrophier",),
    "atrophièrent": ("atrophier",),
    "atrophierez": ("atrophier",),
    "atrophieriez": ("atrophier",),
    "atrophierions": ("atrophier",),
    "atrophierons": ("atrophier",),
    "atrophieront": ("atrophier",),
    "atrophiés": ("atrophier",),
    "atrophies": ("atrophier",),
    "atrophiez": ("atrophier",),
    "atrophiiez": ("atrophier",),
    "atrophiions": ("atrophier",),
    "atrophions": ("atrophier",),
    "atteignaient": ("atteindre",),
    "atteignais": ("atteindre",),
    "atteignait": ("atteindre",),
    "atteignant": ("atteindre",),
    "atteignent": ("atteindre",),
    "atteigne": ("atteindre",),
    "atteignes": ("atteindre",),
    "atteignez": ("atteindre",),
    "atteigniez": ("atteindre",),
    "atteignîmes": ("atteindre",),
    "atteignions": ("atteindre",),
    "atteignirent": ("atteindre",),
    "atteignis": ("atteindre",),
    "atteignissent": ("atteindre",),
    "atteignisses": ("atteindre",),
    "atteignisse": ("atteindre",),
    "atteignissiez": ("atteindre",),
    "atteignissions": ("atteindre",),
    "atteignîtes": ("atteindre",),
    "atteignit": ("atteindre",),
    "atteignît": ("atteindre",),
    "atteignons": ("atteindre",),
    "atteindra": ("atteindre",),
    "atteindraient": ("atteindre",),
    "atteindrai": ("atteindre",),
    "atteindrais": ("atteindre",),
    "atteindrait": ("atteindre",),
    "atteindras": ("atteindre",),
    "atteindrez": ("atteindre",),
    "atteindriez": ("atteindre",),
    "atteindrions": ("atteindre",),
    "atteindrons": ("atteindre",),
    "atteindront": ("atteindre",),
    "atteins": ("atteindre",),
    "atteinte": ("atteindre",),
    "atteintes": ("atteindre",),
    "atteint": ("atteindre",),
    "atteints": ("atteindre",),
    "attelaient": ("atteler",),
    "attelai": ("atteler",),
    "attelais": ("atteler",),
    "attelait": ("atteler",),
    "attela": ("atteler",),
    "attelâmes": ("atteler",),
    "attelant": ("atteler",),
    "attelas": ("atteler",),
    "attelassent": ("atteler",),
    "attelasses": ("atteler",),
    "attelasse": ("atteler",),
    "attelassiez": ("atteler",),
    "attelassions": ("atteler",),
    "attelâtes": ("atteler",),
    "attelât": ("atteler",),
    "attelée": ("atteler",),
    "attelées": ("atteler",),
    "attelé": ("atteler",),
    "attelèrent": ("atteler",),
    "attelés": ("atteler",),
    "attelez": ("atteler",),
    "atteliez": ("atteler",),
    "attelions": ("atteler",),
    "attellent": ("atteler",),
    "attelle": ("atteler",),
    "attellera": ("atteler",),
    "attelleraient": ("atteler",),
    "attellerai": ("atteler",),
    "attellerais": ("atteler",),
    "attellerait": ("atteler",),
    "attelleras": ("atteler",),
    "attellerez": ("atteler",),
    "attelleriez": ("atteler",),
    "attellerions": ("atteler",),
    "attellerons": ("atteler",),
    "attelleront": ("atteler",),
    "attelles": ("atteler",),
    "attelons": ("atteler",),
    "attendaient": ("attendre",),
    "attendais": ("attendre",),
    "attendait": ("attendre",),
    "attendant": ("attendre",),
    "attendent": ("attendre",),
    "attende": ("attendre",),
    "attendes": ("attendre",),
    "attendez": ("attendre",),
    "attendiez": ("attendre",),
    "attendîmes": ("attendre",),
    "attendions": ("attendre",),
    "attendirent": ("attendre",),
    "attendis": ("attendre",),
    "attendissent": ("attendre",),
    "attendisses": ("attendre",),
    "attendisse": ("attendre",),
    "attendissiez": ("attendre",),
    "attendissions": ("attendre",),
    "attendîtes": ("attendre",),
    "attendit": ("attendre",),
    "attendît": ("attendre",),
    "attendons": ("attendre",),
    "attend": ("attendre",),
    "attendra": ("attendre",),
    "attendraient": ("attendre",),
    "attendrai": ("attendre",),
    "attendrais": ("attendre",),
    "attendrait": ("attendre",),
    "attendras": ("attendre",),
    "attendrez": ("attendre",),
    "attendriez": ("attendre",),
    "attendrions": ("attendre",),
    "attendrons": ("attendre",),
    "attendront": ("attendre",),
    "attends": ("attendre",),
    "attendue": ("attendre",),
    "attendues": ("attendre",),
    "attendu": ("attendre",),
    "attendus": ("attendre",),
    "attendrie": ("attendrir",),
    "attendries": ("attendrir",),
    "attendri": ("attendrir",),
    "attendrîmes": ("attendrir",),
    "attendrira": ("attendrir",),
    "attendriraient": ("attendrir",),
    "attendrirai": ("attendrir",),
    "attendrirais": ("attendrir",),
    "attendrirait": ("attendrir",),
    "attendriras": ("attendrir",),
    "attendrirent": ("attendrir",),
    "attendrirez": ("attendrir",),
    "attendririez": ("attendrir",),
    "attendririons": ("attendrir",),
    "attendrirons": ("attendrir",),
    "attendriront": ("attendrir",),
    "attendris": ("attendrir",),
    "attendrissaient": ("attendrir",),
    "attendrissais": ("attendrir",),
    "attendrissait": ("attendrir",),
    "attendrissant": ("attendrir",),
    "attendrissent": ("attendrir",),
    "attendrisse": ("attendrir",),
    "attendrisses": ("attendrir",),
    "attendrissez": ("attendrir",),
    "attendrissiez": ("attendrir",),
    "attendrissions": ("attendrir",),
    "attendrissons": ("attendrir",),
    "attendrîtes": ("attendrir",),
    "attendrit": ("attendrir",),
    "attendrît": ("attendrir",),
    "attenaient": ("attenir",),
    "attenait": ("attenir",),
    "attenant": ("attenir",),
    "attenu": ("attenir",),
    "attiendra": ("attenir",),
    "attiendraient": ("attenir",),
    "attiendrait": ("attenir",),
    "attiendront": ("attenir",),
    "attiennent": ("attenir",),
    "attienne": ("attenir",),
    "attient": ("attenir",),
    "attinrent": ("attenir",),
    "attinssent": ("attenir",),
    "attint": ("attenir",),
    "attînt": ("attenir",),
    "atterrie": ("atterrir",),
    "atterries": ("atterrir",),
    "atterri": ("atterrir",),
    "atterrîmes": ("atterrir",),
    "atterrira": ("atterrir",),
    "atterriraient": ("atterrir",),
    "atterrirai": ("atterrir",),
    "atterrirais": ("atterrir",),
    "atterrirait": ("atterrir",),
    "atterriras": ("atterrir",),
    "atterrirent": ("atterrir",),
    "atterrirez": ("atterrir",),
    "atterririez": ("atterrir",),
    "atterririons": ("atterrir",),
    "atterrirons": ("atterrir",),
    "atterriront": ("atterrir",),
    "atterris": ("atterrir",),
    "atterrissaient": ("atterrir",),
    "atterrissais": ("atterrir",),
    "atterrissait": ("atterrir",),
    "atterrissant": ("atterrir",),
    "atterrissent": ("atterrir",),
    "atterrisse": ("atterrir",),
    "atterrisses": ("atterrir",),
    "atterrissez": ("atterrir",),
    "atterrissiez": ("atterrir",),
    "atterrissions": ("atterrir",),
    "atterrissons": ("atterrir",),
    "atterrîtes": ("atterrir",),
    "atterrit": ("atterrir",),
    "atterrît": ("atterrir",),
    "attiédie": ("attiédir",),
    "attiédies": ("attiédir",),
    "attiédi": ("attiédir",),
    "attiédîmes": ("attiédir",),
    "attiédira": ("attiédir",),
    "attiédiraient": ("attiédir",),
    "attiédirai": ("attiédir",),
    "attiédirais": ("attiédir",),
    "attiédirait": ("attiédir",),
    "attiédiras": ("attiédir",),
    "attiédirent": ("attiédir",),
    "attiédirez": ("attiédir",),
    "attiédiriez": ("attiédir",),
    "attiédirions": ("attiédir",),
    "attiédirons": ("attiédir",),
    "attiédiront": ("attiédir",),
    "attiédis": ("attiédir",),
    "attiédissaient": ("attiédir",),
    "attiédissais": ("attiédir",),
    "attiédissait": ("attiédir",),
    "attiédissant": ("attiédir",),
    "attiédissent": ("attiédir",),
    "attiédisse": ("attiédir",),
    "attiédisses": ("attiédir",),
    "attiédissez": ("attiédir",),
    "attiédissiez": ("attiédir",),
    "attiédissions": ("attiédir",),
    "attiédissons": ("attiédir",),
    "attiédîtes": ("attiédir",),
    "attiédit": ("attiédir",),
    "attiédît": ("attiédir",),
    "attigeaient": ("attiger",),
    "attigeai": ("attiger",),
    "attigeais": ("attiger",),
    "attigeait": ("attiger",),
    "attigea": ("attiger",),
    "attigeâmes": ("attiger",),
    "attigeant": ("attiger",),
    "attigeas": ("attiger",),
    "attigeassent": ("attiger",),
    "attigeasses": ("attiger",),
    "attigeasse": ("attiger",),
    "attigeassiez": ("attiger",),
    "attigeassions": ("attiger",),
    "attigeâtes": ("attiger",),
    "attigeât": ("attiger",),
    "attigé": ("attiger",),
    "attigent": ("attiger",),
    "attigeons": ("attiger",),
    "attige": ("attiger",),
    "attigera": ("attiger",),
    "attigeraient": ("attiger",),
    "attigerai": ("attiger",),
    "attigerais": ("attiger",),
    "attigerait": ("attiger",),
    "attigeras": ("attiger",),
    "attigèrent": ("attiger",),
    "attigerez": ("attiger",),
    "attigeriez": ("attiger",),
    "attigerions": ("attiger",),
    "attigerons": ("attiger",),
    "attigeront": ("attiger",),
    "attiges": ("attiger",),
    "attigez": ("attiger",),
    "attigiez": ("attiger",),
    "attigions": ("attiger",),
    "aubergeaient": ("auberger",),
    "aubergeai": ("auberger",),
    "aubergeais": ("auberger",),
    "aubergeait": ("auberger",),
    "aubergea": ("auberger",),
    "aubergeâmes": ("auberger",),
    "aubergeant": ("auberger",),
    "aubergeas": ("auberger",),
    "aubergeassent": ("auberger",),
    "aubergeasses": ("auberger",),
    "aubergeasse": ("auberger",),
    "aubergeassiez": ("auberger",),
    "aubergeassions": ("auberger",),
    "aubergeâtes": ("auberger",),
    "aubergeât": ("auberger",),
    "aubergée": ("auberger",),
    "aubergées": ("auberger",),
    "aubergé": ("auberger",),
    "aubergent": ("auberger",),
    "aubergeons": ("auberger",),
    "auberge": ("auberger",),
    "aubergera": ("auberger",),
    "aubergeraient": ("auberger",),
    "aubergerai": ("auberger",),
    "aubergerais": ("auberger",),
    "aubergerait": ("auberger",),
    "aubergeras": ("auberger",),
    "aubergèrent": ("auberger",),
    "aubergerez": ("auberger",),
    "aubergeriez": ("auberger",),
    "aubergerions": ("auberger",),
    "aubergerons": ("auberger",),
    "aubergeront": ("auberger",),
    "aubergés": ("auberger",),
    "auberges": ("auberger",),
    "aubergez": ("auberger",),
    "aubergiez": ("auberger",),
    "aubergions": ("auberger",),
    "audiençaient": ("audiencer",),
    "audiençai": ("audiencer",),
    "audiençais": ("audiencer",),
    "audiençait": ("audiencer",),
    "audiença": ("audiencer",),
    "audiençâmes": ("audiencer",),
    "audiençant": ("audiencer",),
    "audienças": ("audiencer",),
    "audiençassent": ("audiencer",),
    "audiençasses": ("audiencer",),
    "audiençasse": ("audiencer",),
    "audiençassiez": ("audiencer",),
    "audiençassions": ("audiencer",),
    "audiençâtes": ("audiencer",),
    "audiençât": ("audiencer",),
    "audiencée": ("audiencer",),
    "audiencées": ("audiencer",),
    "audiencé": ("audiencer",),
    "audiencent": ("audiencer",),
    "audience": ("audiencer",),
    "audiencera": ("audiencer",),
    "audienceraient": ("audiencer",),
    "audiencerai": ("audiencer",),
    "audiencerais": ("audiencer",),
    "audiencerait": ("audiencer",),
    "audienceras": ("audiencer",),
    "audiencèrent": ("audiencer",),
    "audiencerez": ("audiencer",),
    "audienceriez": ("audiencer",),
    "audiencerions": ("audiencer",),
    "audiencerons": ("audiencer",),
    "audienceront": ("audiencer",),
    "audiencés": ("audiencer",),
    "audiences": ("audiencer",),
    "audiencez": ("audiencer",),
    "audienciez": ("audiencer",),
    "audiencions": ("audiencer",),
    "audiençons": ("audiencer",),
    "augeaient": ("auger",),
    "augeai": ("auger",),
    "augeais": ("auger",),
    "augeait": ("auger",),
    "augea": ("auger",),
    "augeâmes": ("auger",),
    "augeant": ("auger",),
    "augeas": ("auger",),
    "augeassent": ("auger",),
    "augeasses": ("auger",),
    "augeasse": ("auger",),
    "augeassiez": ("auger",),
    "augeassions": ("auger",),
    "augeâtes": ("auger",),
    "augeât": ("auger",),
    "augée": ("auger",),
    "augées": ("auger",),
    "augé": ("auger",),
    "augent": ("auger",),
    "augeons": ("auger",),
    "auge": ("auger",),
    "augera": ("auger",),
    "augeraient": ("auger",),
    "augerai": ("auger",),
    "augerais": ("auger",),
    "augerait": ("auger",),
    "augeras": ("auger",),
    "augèrent": ("auger",),
    "augerez": ("auger",),
    "augeriez": ("auger",),
    "augerions": ("auger",),
    "augerons": ("auger",),
    "augeront": ("auger",),
    "augés": ("auger",),
    "auges": ("auger",),
    "augez": ("auger",),
    "augiez": ("auger",),
    "augions": ("auger",),
    "aurifiaient": ("aurifier",),
    "aurifiai": ("aurifier",),
    "aurifiais": ("aurifier",),
    "aurifiait": ("aurifier",),
    "aurifia": ("aurifier",),
    "aurifiâmes": ("aurifier",),
    "aurifiant": ("aurifier",),
    "aurifias": ("aurifier",),
    "aurifiassent": ("aurifier",),
    "aurifiasses": ("aurifier",),
    "aurifiasse": ("aurifier",),
    "aurifiassiez": ("aurifier",),
    "aurifiassions": ("aurifier",),
    "aurifiâtes": ("aurifier",),
    "aurifiât": ("aurifier",),
    "aurifiée": ("aurifier",),
    "aurifiées": ("aurifier",),
    "aurifié": ("aurifier",),
    "aurifient": ("aurifier",),
    "aurifie": ("aurifier",),
    "aurifiera": ("aurifier",),
    "aurifieraient": ("aurifier",),
    "aurifierai": ("aurifier",),
    "aurifierais": ("aurifier",),
    "aurifierait": ("aurifier",),
    "aurifieras": ("aurifier",),
    "aurifièrent": ("aurifier",),
    "aurifierez": ("aurifier",),
    "aurifieriez": ("aurifier",),
    "aurifierions": ("aurifier",),
    "aurifierons": ("aurifier",),
    "aurifieront": ("aurifier",),
    "aurifiés": ("aurifier",),
    "aurifies": ("aurifier",),
    "aurifiez": ("aurifier",),
    "aurifiiez": ("aurifier",),
    "aurifiions": ("aurifier",),
    "aurifions": ("aurifier",),
    "autenticiaient": ("autenticier",),
    "autenticiai": ("autenticier",),
    "autenticiais": ("autenticier",),
    "autenticiait": ("autenticier",),
    "autenticia": ("autenticier",),
    "autenticiâmes": ("autenticier",),
    "autenticiant": ("autenticier",),
    "autenticias": ("autenticier",),
    "autenticiassent": ("autenticier",),
    "autenticiasses": ("autenticier",),
    "autenticiasse": ("autenticier",),
    "autenticiassiez": ("autenticier",),
    "autenticiassions": ("autenticier",),
    "autenticiâtes": ("autenticier",),
    "autenticiât": ("autenticier",),
    "autenticiée": ("autenticier",),
    "autenticiées": ("autenticier",),
    "autenticié": ("autenticier",),
    "autenticient": ("autenticier",),
    "autenticie": ("autenticier",),
    "autenticiera": ("autenticier",),
    "autenticieraient": ("autenticier",),
    "autenticierai": ("autenticier",),
    "autenticierais": ("autenticier",),
    "autenticierait": ("autenticier",),
    "autenticieras": ("autenticier",),
    "autenticièrent": ("autenticier",),
    "autenticierez": ("autenticier",),
    "autenticieriez": ("autenticier",),
    "autenticierions": ("autenticier",),
    "autenticierons": ("autenticier",),
    "autenticieront": ("autenticier",),
    "autenticiés": ("autenticier",),
    "autenticies": ("autenticier",),
    "autenticiez": ("autenticier",),
    "autenticiiez": ("autenticier",),
    "autenticiions": ("autenticier",),
    "autenticions": ("autenticier",),
    "authentifiaient": ("authentifier",),
    "authentifiai": ("authentifier",),
    "authentifiais": ("authentifier",),
    "authentifiait": ("authentifier",),
    "authentifia": ("authentifier",),
    "authentifiâmes": ("authentifier",),
    "authentifiant": ("authentifier",),
    "authentifias": ("authentifier",),
    "authentifiassent": ("authentifier",),
    "authentifiasses": ("authentifier",),
    "authentifiasse": ("authentifier",),
    "authentifiassiez": ("authentifier",),
    "authentifiassions": ("authentifier",),
    "authentifiâtes": ("authentifier",),
    "authentifiât": ("authentifier",),
    "authentifiée": ("authentifier",),
    "authentifiées": ("authentifier",),
    "authentifié": ("authentifier",),
    "authentifient": ("authentifier",),
    "authentifie": ("authentifier",),
    "authentifiera": ("authentifier",),
    "authentifieraient": ("authentifier",),
    "authentifierai": ("authentifier",),
    "authentifierais": ("authentifier",),
    "authentifierait": ("authentifier",),
    "authentifieras": ("authentifier",),
    "authentifièrent": ("authentifier",),
    "authentifierez": ("authentifier",),
    "authentifieriez": ("authentifier",),
    "authentifierions": ("authentifier",),
    "authentifierons": ("authentifier",),
    "authentifieront": ("authentifier",),
    "authentifiés": ("authentifier",),
    "authentifies": ("authentifier",),
    "authentifiez": ("authentifier",),
    "authentifiiez": ("authentifier",),
    "authentifiions": ("authentifier",),
    "authentifions": ("authentifier",),
    "autoadhéraient": ("autoadhérer",),
    "autoadhérai": ("autoadhérer",),
    "autoadhérais": ("autoadhérer",),
    "autoadhérait": ("autoadhérer",),
    "autoadhéra": ("autoadhérer",),
    "autoadhérâmes": ("autoadhérer",),
    "autoadhérant": ("autoadhérer",),
    "autoadhéras": ("autoadhérer",),
    "autoadhérassent": ("autoadhérer",),
    "autoadhérasses": ("autoadhérer",),
    "autoadhérasse": ("autoadhérer",),
    "autoadhérassiez": ("autoadhérer",),
    "autoadhérassions": ("autoadhérer",),
    "autoadhérâtes": ("autoadhérer",),
    "autoadhérât": ("autoadhérer",),
    "autoadhérée": ("autoadhérer",),
    "autoadhérées": ("autoadhérer",),
    "autoadhéré": ("autoadhérer",),
    "autoadhèrent": ("autoadhérer",),
    "autoadhère": ("autoadhérer",),
    "autoadhérera": ("autoadhérer",),
    "autoadhéreraient": ("autoadhérer",),
    "autoadhérerai": ("autoadhérer",),
    "autoadhérerais": ("autoadhérer",),
    "autoadhérerait": ("autoadhérer",),
    "autoadhéreras": ("autoadhérer",),
    "autoadhérèrent": ("autoadhérer",),
    "autoadhérerez": ("autoadhérer",),
    "autoadhéreriez": ("autoadhérer",),
    "autoadhérerions": ("autoadhérer",),
    "autoadhérerons": ("autoadhérer",),
    "autoadhéreront": ("autoadhérer",),
    "autoadhérés": ("autoadhérer",),
    "autoadhères": ("autoadhérer",),
    "autoadhérez": ("autoadhérer",),
    "autoadhériez": ("autoadhérer",),
    "autoadhérions": ("autoadhérer",),
    "autoadhérons": ("autoadhérer",),
    "autoaggloméraient": ("autoagglomérer",),
    "autoagglomérai": ("autoagglomérer",),
    "autoagglomérais": ("autoagglomérer",),
    "autoagglomérait": ("autoagglomérer",),
    "autoaggloméra": ("autoagglomérer",),
    "autoagglomérâmes": ("autoagglomérer",),
    "autoagglomérant": ("autoagglomérer",),
    "autoaggloméras": ("autoagglomérer",),
    "autoagglomérassent": ("autoagglomérer",),
    "autoagglomérasses": ("autoagglomérer",),
    "autoagglomérasse": ("autoagglomérer",),
    "autoagglomérassiez": ("autoagglomérer",),
    "autoagglomérassions": ("autoagglomérer",),
    "autoagglomérâtes": ("autoagglomérer",),
    "autoagglomérât": ("autoagglomérer",),
    "autoagglomérée": ("autoagglomérer",),
    "autoagglomérées": ("autoagglomérer",),
    "autoaggloméré": ("autoagglomérer",),
    "autoagglomèrent": ("autoagglomérer",),
    "autoagglomère": ("autoagglomérer",),
    "autoagglomérera": ("autoagglomérer",),
    "autoaggloméreraient": ("autoagglomérer",),
    "autoagglomérerai": ("autoagglomérer",),
    "autoagglomérerais": ("autoagglomérer",),
    "autoagglomérerait": ("autoagglomérer",),
    "autoaggloméreras": ("autoagglomérer",),
    "autoagglomérèrent": ("autoagglomérer",),
    "autoagglomérerez": ("autoagglomérer",),
    "autoaggloméreriez": ("autoagglomérer",),
    "autoagglomérerions": ("autoagglomérer",),
    "autoagglomérerons": ("autoagglomérer",),
    "autoaggloméreront": ("autoagglomérer",),
    "autoagglomérés": ("autoagglomérer",),
    "autoagglomères": ("autoagglomérer",),
    "autoagglomérez": ("autoagglomérer",),
    "autoagglomériez": ("autoagglomérer",),
    "autoagglomérions": ("autoagglomérer",),
    "autoagglomérons": ("autoagglomérer",),
    "autoamorçaient": ("autoamorcer",),
    "autoamorçai": ("autoamorcer",),
    "autoamorçais": ("autoamorcer",),
    "autoamorçait": ("autoamorcer",),
    "autoamorça": ("autoamorcer",),
    "autoamorçâmes": ("autoamorcer",),
    "autoamorçant": ("autoamorcer",),
    "autoamorças": ("autoamorcer",),
    "autoamorçassent": ("autoamorcer",),
    "autoamorçasses": ("autoamorcer",),
    "autoamorçasse": ("autoamorcer",),
    "autoamorçassiez": ("autoamorcer",),
    "autoamorçassions": ("autoamorcer",),
    "autoamorçâtes": ("autoamorcer",),
    "autoamorçât": ("autoamorcer",),
    "autoamorcée": ("autoamorcer",),
    "autoamorcées": ("autoamorcer",),
    "autoamorcé": ("autoamorcer",),
    "autoamorcent": ("autoamorcer",),
    "autoamorce": ("autoamorcer",),
    "autoamorcera": ("autoamorcer",),
    "autoamorceraient": ("autoamorcer",),
    "autoamorcerai": ("autoamorcer",),
    "autoamorcerais": ("autoamorcer",),
    "autoamorcerait": ("autoamorcer",),
    "autoamorceras": ("autoamorcer",),
    "autoamorcèrent": ("autoamorcer",),
    "autoamorcerez": ("autoamorcer",),
    "autoamorceriez": ("autoamorcer",),
    "autoamorcerions": ("autoamorcer",),
    "autoamorcerons": ("autoamorcer",),
    "autoamorceront": ("autoamorcer",),
    "autoamorcés": ("autoamorcer",),
    "autoamorces": ("autoamorcer",),
    "autoamorcez": ("autoamorcer",),
    "autoamorciez": ("autoamorcer",),
    "autoamorcions": ("autoamorcer",),
    "autoamorçons": ("autoamorcer",),
    "autoamortie": ("autoamortir",),
    "autoamorties": ("autoamortir",),
    "autoamorti": ("autoamortir",),
    "autoamortîmes": ("autoamortir",),
    "autoamortira": ("autoamortir",),
    "autoamortiraient": ("autoamortir",),
    "autoamortirai": ("autoamortir",),
    "autoamortirais": ("autoamortir",),
    "autoamortirait": ("autoamortir",),
    "autoamortiras": ("autoamortir",),
    "autoamortirent": ("autoamortir",),
    "autoamortirez": ("autoamortir",),
    "autoamortiriez": ("autoamortir",),
    "autoamortirions": ("autoamortir",),
    "autoamortirons": ("autoamortir",),
    "autoamortiront": ("autoamortir",),
    "autoamortis": ("autoamortir",),
    "autoamortissaient": ("autoamortir",),
    "autoamortissais": ("autoamortir",),
    "autoamortissait": ("autoamortir",),
    "autoamortissant": ("autoamortir",),
    "autoamortissent": ("autoamortir",),
    "autoamortisse": ("autoamortir",),
    "autoamortisses": ("autoamortir",),
    "autoamortissez": ("autoamortir",),
    "autoamortissiez": ("autoamortir",),
    "autoamortissions": ("autoamortir",),
    "autoamortissons": ("autoamortir",),
    "autoamortîtes": ("autoamortir",),
    "autoamortit": ("autoamortir",),
    "autoamortît": ("autoamortir",),
    "autoapprenaient": ("autoapprendre",),
    "autoapprenais": ("autoapprendre",),
    "autoapprenait": ("autoapprendre",),
    "autoapprenant": ("autoapprendre",),
    "autoapprend": ("autoapprendre",),
    "autoapprendra": ("autoapprendre",),
    "autoapprendraient": ("autoapprendre",),
    "autoapprendrai": ("autoapprendre",),
    "autoapprendrais": ("autoapprendre",),
    "autoapprendrait": ("autoapprendre",),
    "autoapprendras": ("autoapprendre",),
    "autoapprendrez": ("autoapprendre",),
    "autoapprendriez": ("autoapprendre",),
    "autoapprendrions": ("autoapprendre",),
    "autoapprendrons": ("autoapprendre",),
    "autoapprendront": ("autoapprendre",),
    "autoapprends": ("autoapprendre",),
    "autoapprenez": ("autoapprendre",),
    "autoappreniez": ("autoapprendre",),
    "autoapprenions": ("autoapprendre",),
    "autoapprennent": ("autoapprendre",),
    "autoapprenne": ("autoapprendre",),
    "autoapprennes": ("autoapprendre",),
    "autoapprenons": ("autoapprendre",),
    "autoapprîmes": ("autoapprendre",),
    "autoapprirent": ("autoapprendre",),
    "autoapprise": ("autoapprendre",),
    "autoapprises": ("autoapprendre",),
    "autoappris": ("autoapprendre",),
    "autoapprissent": ("autoapprendre",),
    "autoapprisses": ("autoapprendre",),
    "autoapprisse": ("autoapprendre",),
    "autoapprissiez": ("autoapprendre",),
    "autoapprissions": ("autoapprendre",),
    "autoapprîtes": ("autoapprendre",),
    "autoapprit": ("autoapprendre",),
    "autoapprît": ("autoapprendre",),
    "autocassaient": ("autocasser",),
    "autocassai": ("autocasser",),
    "autocassais": ("autocasser",),
    "autocassait": ("autocasser",),
    "autocassa": ("autocasser",),
    "autocassâmes": ("autocasser",),
    "autocassant": ("autocasser",),
    "autocassas": ("autocasser",),
    "autocassassent": ("autocasser",),
    "autocassasses": ("autocasser",),
    "autocassasse": ("autocasser",),
    "autocassassiez": ("autocasser",),
    "autocassassions": ("autocasser",),
    "autocassâtes": ("autocasser",),
    "autocassât": ("autocasser",),
    "autocassée": ("autocasser",),
    "autocassées": ("autocasser",),
    "autocassé": ("autocasser",),
    "autocassent": ("autocasser",),
    "autocasse": ("autocasser",),
    "autocassera": ("autocasser",),
    "autocasseraient": ("autocasser",),
    "autocasserai": ("autocasser",),
    "autocasserais": ("autocasser",),
    "autocasserait": ("autocasser",),
    "autocasseras": ("autocasser",),
    "autocassèrent": ("autocasser",),
    "autocasserez": ("autocasser",),
    "autocasseriez": ("autocasser",),
    "autocasserions": ("autocasser",),
    "autocasserons": ("autocasser",),
    "autocasseront": ("autocasser",),
    "autocassés": ("autocasser",),
    "autocasses": ("autocasser",),
    "autocassez": ("autocasser",),
    "autocassiez": ("autocasser",),
    "autocassions": ("autocasser",),
    "autocassons": ("autocasser",),
    "autoconcurrençaient": ("autoconcurrencer",),
    "autoconcurrençai": ("autoconcurrencer",),
    "autoconcurrençais": ("autoconcurrencer",),
    "autoconcurrençait": ("autoconcurrencer",),
    "autoconcurrença": ("autoconcurrencer",),
    "autoconcurrençâmes": ("autoconcurrencer",),
    "autoconcurrençant": ("autoconcurrencer",),
    "autoconcurrenças": ("autoconcurrencer",),
    "autoconcurrençassent": ("autoconcurrencer",),
    "autoconcurrençasses": ("autoconcurrencer",),
    "autoconcurrençasse": ("autoconcurrencer",),
    "autoconcurrençassiez": ("autoconcurrencer",),
    "autoconcurrençassions": ("autoconcurrencer",),
    "autoconcurrençâtes": ("autoconcurrencer",),
    "autoconcurrençât": ("autoconcurrencer",),
    "autoconcurrencée": ("autoconcurrencer",),
    "autoconcurrencées": ("autoconcurrencer",),
    "autoconcurrencé": ("autoconcurrencer",),
    "autoconcurrencent": ("autoconcurrencer",),
    "autoconcurrence": ("autoconcurrencer",),
    "autoconcurrencera": ("autoconcurrencer",),
    "autoconcurrenceraient": ("autoconcurrencer",),
    "autoconcurrencerai": ("autoconcurrencer",),
    "autoconcurrencerais": ("autoconcurrencer",),
    "autoconcurrencerait": ("autoconcurrencer",),
    "autoconcurrenceras": ("autoconcurrencer",),
    "autoconcurrencèrent": ("autoconcurrencer",),
    "autoconcurrencerez": ("autoconcurrencer",),
    "autoconcurrenceriez": ("autoconcurrencer",),
    "autoconcurrencerions": ("autoconcurrencer",),
    "autoconcurrencerons": ("autoconcurrencer",),
    "autoconcurrenceront": ("autoconcurrencer",),
    "autoconcurrencés": ("autoconcurrencer",),
    "autoconcurrences": ("autoconcurrencer",),
    "autoconcurrencez": ("autoconcurrencer",),
    "autoconcurrenciez": ("autoconcurrencer",),
    "autoconcurrencions": ("autoconcurrencer",),
    "autoconcurrençons": ("autoconcurrencer",),
    "autoconduira": ("autoconduire",),
    "autoconduiraient": ("autoconduire",),
    "autoconduirai": ("autoconduire",),
    "autoconduirais": ("autoconduire",),
    "autoconduirait": ("autoconduire",),
    "autoconduiras": ("autoconduire",),
    "autoconduirez": ("autoconduire",),
    "autoconduiriez": ("autoconduire",),
    "autoconduirions": ("autoconduire",),
    "autoconduirons": ("autoconduire",),
    "autoconduiront": ("autoconduire",),
    "autoconduisaient": ("autoconduire",),
    "autoconduisais": ("autoconduire",),
    "autoconduisait": ("autoconduire",),
    "autoconduisant": ("autoconduire",),
    "autoconduisent": ("autoconduire",),
    "autoconduise": ("autoconduire",),
    "autoconduises": ("autoconduire",),
    "autoconduisez": ("autoconduire",),
    "autoconduisiez": ("autoconduire",),
    "autoconduisîmes": ("autoconduire",),
    "autoconduisions": ("autoconduire",),
    "autoconduisirent": ("autoconduire",),
    "autoconduisis": ("autoconduire",),
    "autoconduisissent": ("autoconduire",),
    "autoconduisisses": ("autoconduire",),
    "autoconduisisse": ("autoconduire",),
    "autoconduisissiez": ("autoconduire",),
    "autoconduisissions": ("autoconduire",),
    "autoconduisîtes": ("autoconduire",),
    "autoconduisit": ("autoconduire",),
    "autoconduisît": ("autoconduire",),
    "autoconduisons": ("autoconduire",),
    "autoconduis": ("autoconduire",),
    "autoconduite": ("autoconduire",),
    "autoconduites": ("autoconduire",),
    "autoconduit": ("autoconduire",),
    "autoconduits": ("autoconduire",),
    "autocopiaient": ("autocopier",),
    "autocopiai": ("autocopier",),
    "autocopiais": ("autocopier",),
    "autocopiait": ("autocopier",),
    "autocopia": ("autocopier",),
    "autocopiâmes": ("autocopier",),
    "autocopiant": ("autocopier",),
    "autocopias": ("autocopier",),
    "autocopiassent": ("autocopier",),
    "autocopiasses": ("autocopier",),
    "autocopiasse": ("autocopier",),
    "autocopiassiez": ("autocopier",),
    "autocopiassions": ("autocopier",),
    "autocopiâtes": ("autocopier",),
    "autocopiât": ("autocopier",),
    "autocopiée": ("autocopier",),
    "autocopiées": ("autocopier",),
    "autocopié": ("autocopier",),
    "autocopient": ("autocopier",),
    "autocopie": ("autocopier",),
    "autocopiera": ("autocopier",),
    "autocopieraient": ("autocopier",),
    "autocopierai": ("autocopier",),
    "autocopierais": ("autocopier",),
    "autocopierait": ("autocopier",),
    "autocopieras": ("autocopier",),
    "autocopièrent": ("autocopier",),
    "autocopierez": ("autocopier",),
    "autocopieriez": ("autocopier",),
    "autocopierions": ("autocopier",),
    "autocopierons": ("autocopier",),
    "autocopieront": ("autocopier",),
    "autocopiés": ("autocopier",),
    "autocopies": ("autocopier",),
    "autocopiez": ("autocopier",),
    "autocopiiez": ("autocopier",),
    "autocopiions": ("autocopier",),
    "autocopions": ("autocopier",),
    "autocorrigeaient": ("autocorriger",),
    "autocorrigeai": ("autocorriger",),
    "autocorrigeais": ("autocorriger",),
    "autocorrigeait": ("autocorriger",),
    "autocorrigea": ("autocorriger",),
    "autocorrigeâmes": ("autocorriger",),
    "autocorrigeant": ("autocorriger",),
    "autocorrigeas": ("autocorriger",),
    "autocorrigeassent": ("autocorriger",),
    "autocorrigeasses": ("autocorriger",),
    "autocorrigeasse": ("autocorriger",),
    "autocorrigeassiez": ("autocorriger",),
    "autocorrigeassions": ("autocorriger",),
    "autocorrigeâtes": ("autocorriger",),
    "autocorrigeât": ("autocorriger",),
    "autocorrigée": ("autocorriger",),
    "autocorrigées": ("autocorriger",),
    "autocorrigé": ("autocorriger",),
    "autocorrigent": ("autocorriger",),
    "autocorrigeons": ("autocorriger",),
    "autocorrige": ("autocorriger",),
    "autocorrigera": ("autocorriger",),
    "autocorrigeraient": ("autocorriger",),
    "autocorrigerai": ("autocorriger",),
    "autocorrigerais": ("autocorriger",),
    "autocorrigerait": ("autocorriger",),
    "autocorrigeras": ("autocorriger",),
    "autocorrigèrent": ("autocorriger",),
    "autocorrigerez": ("autocorriger",),
    "autocorrigeriez": ("autocorriger",),
    "autocorrigerions": ("autocorriger",),
    "autocorrigerons": ("autocorriger",),
    "autocorrigeront": ("autocorriger",),
    "autocorrigés": ("autocorriger",),
    "autocorriges": ("autocorriger",),
    "autocorrigez": ("autocorriger",),
    "autocorrigiez": ("autocorriger",),
    "autocorrigions": ("autocorriger",),
    "autocuira": ("autocuire",),
    "autocuiraient": ("autocuire",),
    "autocuirai": ("autocuire",),
    "autocuirais": ("autocuire",),
    "autocuirait": ("autocuire",),
    "autocuiras": ("autocuire",),
    "autocuirez": ("autocuire",),
    "autocuiriez": ("autocuire",),
    "autocuirions": ("autocuire",),
    "autocuirons": ("autocuire",),
    "autocuiront": ("autocuire",),
    "autocuisaient": ("autocuire",),
    "autocuisais": ("autocuire",),
    "autocuisait": ("autocuire",),
    "autocuisant": ("autocuire",),
    "autocuisent": ("autocuire",),
    "autocuise": ("autocuire",),
    "autocuises": ("autocuire",),
    "autocuisez": ("autocuire",),
    "autocuisiez": ("autocuire",),
    "autocuisîmes": ("autocuire",),
    "autocuisions": ("autocuire",),
    "autocuisirent": ("autocuire",),
    "autocuisis": ("autocuire",),
    "autocuisissent": ("autocuire",),
    "autocuisisses": ("autocuire",),
    "autocuisisse": ("autocuire",),
    "autocuisissiez": ("autocuire",),
    "autocuisissions": ("autocuire",),
    "autocuisîtes": ("autocuire",),
    "autocuisit": ("autocuire",),
    "autocuisît": ("autocuire",),
    "autocuisons": ("autocuire",),
    "autocuis": ("autocuire",),
    "autocuite": ("autocuire",),
    "autocuites": ("autocuire",),
    "autocuit": ("autocuire",),
    "autocuits": ("autocuire",),
    "autodébraient": ("autodébrayer",),
    "autodébraie": ("autodébrayer",),
    "autodébraiera": ("autodébrayer",),
    "autodébraieraient": ("autodébrayer",),
    "autodébraierait": ("autodébrayer",),
    "autodébraieront": ("autodébrayer",),
    "autodébrayaient": ("autodébrayer",),
    "autodébrayait": ("autodébrayer",),
    "autodébraya": ("autodébrayer",),
    "autodébrayant": ("autodébrayer",),
    "autodébrayassent": ("autodébrayer",),
    "autodébrayât": ("autodébrayer",),
    "autodébrayée": ("autodébrayer",),
    "autodébrayées": ("autodébrayer",),
    "autodébrayé": ("autodébrayer",),
    "autodébrayent": ("autodébrayer",),
    "autodébraye": ("autodébrayer",),
    "autodébrayera": ("autodébrayer",),
    "autodébrayeraient": ("autodébrayer",),
    "autodébrayerait": ("autodébrayer",),
    "autodébrayèrent": ("autodébrayer",),
    "autodébrayeront": ("autodébrayer",),
    "autodébrayés": ("autodébrayer",),
    "autodécrassaient": ("autodécrasser",),
    "autodécrassai": ("autodécrasser",),
    "autodécrassais": ("autodécrasser",),
    "autodécrassait": ("autodécrasser",),
    "autodécrassa": ("autodécrasser",),
    "autodécrassâmes": ("autodécrasser",),
    "autodécrassant": ("autodécrasser",),
    "autodécrassas": ("autodécrasser",),
    "autodécrassassent": ("autodécrasser",),
    "autodécrassasses": ("autodécrasser",),
    "autodécrassasse": ("autodécrasser",),
    "autodécrassassiez": ("autodécrasser",),
    "autodécrassassions": ("autodécrasser",),
    "autodécrassâtes": ("autodécrasser",),
    "autodécrassât": ("autodécrasser",),
    "autodécrassée": ("autodécrasser",),
    "autodécrassées": ("autodécrasser",),
    "autodécrassé": ("autodécrasser",),
    "autodécrassent": ("autodécrasser",),
    "autodécrasse": ("autodécrasser",),
    "autodécrassera": ("autodécrasser",),
    "autodécrasseraient": ("autodécrasser",),
    "autodécrasserai": ("autodécrasser",),
    "autodécrasserais": ("autodécrasser",),
    "autodécrasserait": ("autodécrasser",),
    "autodécrasseras": ("autodécrasser",),
    "autodécrassèrent": ("autodécrasser",),
    "autodécrasserez": ("autodécrasser",),
    "autodécrasseriez": ("autodécrasser",),
    "autodécrasserions": ("autodécrasser",),
    "autodécrasserons": ("autodécrasser",),
    "autodécrasseront": ("autodécrasser",),
    "autodécrassés": ("autodécrasser",),
    "autodécrasses": ("autodécrasser",),
    "autodécrassez": ("autodécrasser",),
    "autodécrassiez": ("autodécrasser",),
    "autodécrassions": ("autodécrasser",),
    "autodécrassons": ("autodécrasser",),
    "autodéfendaient": ("autodéfendre",),
    "autodéfendais": ("autodéfendre",),
    "autodéfendait": ("autodéfendre",),
    "autodéfendant": ("autodéfendre",),
    "autodéfendent": ("autodéfendre",),
    "autodéfende": ("autodéfendre",),
    "autodéfendes": ("autodéfendre",),
    "autodéfendez": ("autodéfendre",),
    "autodéfendiez": ("autodéfendre",),
    "autodéfendîmes": ("autodéfendre",),
    "autodéfendions": ("autodéfendre",),
    "autodéfendirent": ("autodéfendre",),
    "autodéfendis": ("autodéfendre",),
    "autodéfendissent": ("autodéfendre",),
    "autodéfendisses": ("autodéfendre",),
    "autodéfendisse": ("autodéfendre",),
    "autodéfendissiez": ("autodéfendre",),
    "autodéfendissions": ("autodéfendre",),
    "autodéfendîtes": ("autodéfendre",),
    "autodéfendit": ("autodéfendre",),
    "autodéfendît": ("autodéfendre",),
    "autodéfendons": ("autodéfendre",),
    "autodéfend": ("autodéfendre",),
    "autodéfendra": ("autodéfendre",),
    "autodéfendraient": ("autodéfendre",),
    "autodéfendrai": ("autodéfendre",),
    "autodéfendrais": ("autodéfendre",),
    "autodéfendrait": ("autodéfendre",),
    "autodéfendras": ("autodéfendre",),
    "autodéfendrez": ("autodéfendre",),
    "autodéfendriez": ("autodéfendre",),
    "autodéfendrions": ("autodéfendre",),
    "autodéfendrons": ("autodéfendre",),
    "autodéfendront": ("autodéfendre",),
    "autodéfends": ("autodéfendre",),
    "autodéfendue": ("autodéfendre",),
    "autodéfendues": ("autodéfendre",),
    "autodéfendu": ("autodéfendre",),
    "autodéfendus": ("autodéfendre",),
    "autodépréciaient": ("autodéprécier",),
    "autodépréciai": ("autodéprécier",),
    "autodépréciais": ("autodéprécier",),
    "autodépréciait": ("autodéprécier",),
    "autodéprécia": ("autodéprécier",),
    "autodépréciâmes": ("autodéprécier",),
    "autodépréciant": ("autodéprécier",),
    "autodéprécias": ("autodéprécier",),
    "autodépréciassent": ("autodéprécier",),
    "autodépréciasses": ("autodéprécier",),
    "autodépréciasse": ("autodéprécier",),
    "autodépréciassiez": ("autodéprécier",),
    "autodépréciassions": ("autodéprécier",),
    "autodépréciâtes": ("autodéprécier",),
    "autodépréciât": ("autodéprécier",),
    "autodépréciée": ("autodéprécier",),
    "autodépréciées": ("autodéprécier",),
    "autodéprécié": ("autodéprécier",),
    "autodéprécient": ("autodéprécier",),
    "autodéprécie": ("autodéprécier",),
    "autodépréciera": ("autodéprécier",),
    "autodéprécieraient": ("autodéprécier",),
    "autodéprécierai": ("autodéprécier",),
    "autodéprécierais": ("autodéprécier",),
    "autodéprécierait": ("autodéprécier",),
    "autodéprécieras": ("autodéprécier",),
    "autodéprécièrent": ("autodéprécier",),
    "autodéprécierez": ("autodéprécier",),
    "autodéprécieriez": ("autodéprécier",),
    "autodéprécierions": ("autodéprécier",),
    "autodéprécierons": ("autodéprécier",),
    "autodéprécieront": ("autodéprécier",),
    "autodépréciés": ("autodéprécier",),
    "autodéprécies": ("autodéprécier",),
    "autodépréciez": ("autodéprécier",),
    "autodépréciiez": ("autodéprécier",),
    "autodépréciions": ("autodéprécier",),
    "autodéprécions": ("autodéprécier",),
    "autodétruira": ("autodétruire",),
    "autodétruiraient": ("autodétruire",),
    "autodétruirai": ("autodétruire",),
    "autodétruirais": ("autodétruire",),
    "autodétruirait": ("autodétruire",),
    "autodétruiras": ("autodétruire",),
    "autodétruirez": ("autodétruire",),
    "autodétruiriez": ("autodétruire",),
    "autodétruirions": ("autodétruire",),
    "autodétruirons": ("autodétruire",),
    "autodétruiront": ("autodétruire",),
    "autodétruisaient": ("autodétruire",),
    "autodétruisais": ("autodétruire",),
    "autodétruisait": ("autodétruire",),
    "autodétruisant": ("autodétruire",),
    "autodétruisent": ("autodétruire",),
    "autodétruise": ("autodétruire",),
    "autodétruises": ("autodétruire",),
    "autodétruisez": ("autodétruire",),
    "autodétruisiez": ("autodétruire",),
    "autodétruisîmes": ("autodétruire",),
    "autodétruisions": ("autodétruire",),
    "autodétruisirent": ("autodétruire",),
    "autodétruisis": ("autodétruire",),
    "autodétruisissent": ("autodétruire",),
    "autodétruisisses": ("autodétruire",),
    "autodétruisisse": ("autodétruire",),
    "autodétruisissiez": ("autodétruire",),
    "autodétruisissions": ("autodétruire",),
    "autodétruisîtes": ("autodétruire",),
    "autodétruisit": ("autodétruire",),
    "autodétruisît": ("autodétruire",),
    "autodétruisons": ("autodétruire",),
    "autodétruis": ("autodétruire",),
    "autodétruite": ("autodétruire",),
    "autodétruites": ("autodétruire",),
    "autodétruit": ("autodétruire",),
    "autodétruits": ("autodétruire",),
    "autodigéraient": ("autodigérer",),
    "autodigérai": ("autodigérer",),
    "autodigérais": ("autodigérer",),
    "autodigérait": ("autodigérer",),
    "autodigéra": ("autodigérer",),
    "autodigérâmes": ("autodigérer",),
    "autodigérant": ("autodigérer",),
    "autodigéras": ("autodigérer",),
    "autodigérassent": ("autodigérer",),
    "autodigérasses": ("autodigérer",),
    "autodigérasse": ("autodigérer",),
    "autodigérassiez": ("autodigérer",),
    "autodigérassions": ("autodigérer",),
    "autodigérâtes": ("autodigérer",),
    "autodigérât": ("autodigérer",),
    "autodigérée": ("autodigérer",),
    "autodigérées": ("autodigérer",),
    "autodigéré": ("autodigérer",),
    "autodigèrent": ("autodigérer",),
    "autodigère": ("autodigérer",),
    "autodigérera": ("autodigérer",),
    "autodigéreraient": ("autodigérer",),
    "autodigérerai": ("autodigérer",),
    "autodigérerais": ("autodigérer",),
    "autodigérerait": ("autodigérer",),
    "autodigéreras": ("autodigérer",),
    "autodigérèrent": ("autodigérer",),
    "autodigérerez": ("autodigérer",),
    "autodigéreriez": ("autodigérer",),
    "autodigérerions": ("autodigérer",),
    "autodigérerons": ("autodigérer",),
    "autodigéreront": ("autodigérer",),
    "autodigérés": ("autodigérer",),
    "autodigères": ("autodigérer",),
    "autodigérez": ("autodigérer",),
    "autodigériez": ("autodigérer",),
    "autodigérions": ("autodigérer",),
    "autodigérons": ("autodigérer",),
    "autodirigeaient": ("autodiriger",),
    "autodirigeai": ("autodiriger",),
    "autodirigeais": ("autodiriger",),
    "autodirigeait": ("autodiriger",),
    "autodirigea": ("autodiriger",),
    "autodirigeâmes": ("autodiriger",),
    "autodirigeant": ("autodiriger",),
    "autodirigeas": ("autodiriger",),
    "autodirigeassent": ("autodiriger",),
    "autodirigeasses": ("autodiriger",),
    "autodirigeasse": ("autodiriger",),
    "autodirigeassiez": ("autodiriger",),
    "autodirigeassions": ("autodiriger",),
    "autodirigeâtes": ("autodiriger",),
    "autodirigeât": ("autodiriger",),
    "autodirigée": ("autodiriger",),
    "autodirigées": ("autodiriger",),
    "autodirigé": ("autodiriger",),
    "autodirigent": ("autodiriger",),
    "autodirigeons": ("autodiriger",),
    "autodirige": ("autodiriger",),
    "autodirigera": ("autodiriger",),
    "autodirigeraient": ("autodiriger",),
    "autodirigerai": ("autodiriger",),
    "autodirigerais": ("autodiriger",),
    "autodirigerait": ("autodiriger",),
    "autodirigeras": ("autodiriger",),
    "autodirigèrent": ("autodiriger",),
    "autodirigerez": ("autodiriger",),
    "autodirigeriez": ("autodiriger",),
    "autodirigerions": ("autodiriger",),
    "autodirigerons": ("autodiriger",),
    "autodirigeront": ("autodiriger",),
    "autodirigés": ("autodiriger",),
    "autodiriges": ("autodiriger",),
    "autodirigez": ("autodiriger",),
    "autodirigiez": ("autodiriger",),
    "autodirigions": ("autodiriger",),
    "autodissolûmes": ("autodissoudre",),
    "autodissolurent": ("autodissoudre",),
    "autodissolus": ("autodissoudre",),
    "autodissolussent": ("autodissoudre",),
    "autodissolusses": ("autodissoudre",),
    "autodissolusse": ("autodissoudre",),
    "autodissolussiez": ("autodissoudre",),
    "autodissolussions": ("autodissoudre",),
    "autodissolûtes": ("autodissoudre",),
    "autodissolut": ("autodissoudre",),
    "autodissolût": ("autodissoudre",),
    "autodissolvaient": ("autodissoudre",),
    "autodissolvais": ("autodissoudre",),
    "autodissolvait": ("autodissoudre",),
    "autodissolvant": ("autodissoudre",),
    "autodissolvent": ("autodissoudre",),
    "autodissolve": ("autodissoudre",),
    "autodissolves": ("autodissoudre",),
    "autodissolvez": ("autodissoudre",),
    "autodissolviez": ("autodissoudre",),
    "autodissolvions": ("autodissoudre",),
    "autodissolvons": ("autodissoudre",),
    "autodissoudra": ("autodissoudre",),
    "autodissoudraient": ("autodissoudre",),
    "autodissoudrai": ("autodissoudre",),
    "autodissoudrais": ("autodissoudre",),
    "autodissoudrait": ("autodissoudre",),
    "autodissoudras": ("autodissoudre",),
    "autodissoudrez": ("autodissoudre",),
    "autodissoudriez": ("autodissoudre",),
    "autodissoudrions": ("autodissoudre",),
    "autodissoudrons": ("autodissoudre",),
    "autodissoudront": ("autodissoudre",),
    "autodissous": ("autodissoudre",),
    "autodissoute": ("autodissoudre",),
    "autodissoutes": ("autodissoudre",),
    "autodissout": ("autodissoudre",),
    "autoentretenaient": ("autoentretenir",),
    "autoentretenais": ("autoentretenir",),
    "autoentretenait": ("autoentretenir",),
    "autoentretenant": ("autoentretenir",),
    "autoentretenez": ("autoentretenir",),
    "autoentreteniez": ("autoentretenir",),
    "autoentretenions": ("autoentretenir",),
    "autoentretenons": ("autoentretenir",),
    "autoentretenue": ("autoentretenir",),
    "autoentretenues": ("autoentretenir",),
    "autoentretenu": ("autoentretenir",),
    "autoentretenus": ("autoentretenir",),
    "autoentretiendra": ("autoentretenir",),
    "autoentretiendraient": ("autoentretenir",),
    "autoentretiendrai": ("autoentretenir",),
    "autoentretiendrais": ("autoentretenir",),
    "autoentretiendrait": ("autoentretenir",),
    "autoentretiendras": ("autoentretenir",),
    "autoentretiendrez": ("autoentretenir",),
    "autoentretiendriez": ("autoentretenir",),
    "autoentretiendrions": ("autoentretenir",),
    "autoentretiendrons": ("autoentretenir",),
    "autoentretiendront": ("autoentretenir",),
    "autoentretiennent": ("autoentretenir",),
    "autoentretienne": ("autoentretenir",),
    "autoentretiennes": ("autoentretenir",),
    "autoentretiens": ("autoentretenir",),
    "autoentretient": ("autoentretenir",),
    "autoentretînmes": ("autoentretenir",),
    "autoentretinrent": ("autoentretenir",),
    "autoentretins": ("autoentretenir",),
    "autoentretinssent": ("autoentretenir",),
    "autoentretinsses": ("autoentretenir",),
    "autoentretinsse": ("autoentretenir",),
    "autoentretinssiez": ("autoentretenir",),
    "autoentretinssions": ("autoentretenir",),
    "autoentretîntes": ("autoentretenir",),
    "autoentretint": ("autoentretenir",),
    "autoentretînt": ("autoentretenir",),
    "autoéteignaient": ("autoéteindre",),
    "autoéteignais": ("autoéteindre",),
    "autoéteignait": ("autoéteindre",),
    "autoéteignant": ("autoéteindre",),
    "autoéteignent": ("autoéteindre",),
    "autoéteigne": ("autoéteindre",),
    "autoéteignes": ("autoéteindre",),
    "autoéteignez": ("autoéteindre",),
    "autoéteigniez": ("autoéteindre",),
    "autoéteignîmes": ("autoéteindre",),
    "autoéteignions": ("autoéteindre",),
    "autoéteignirent": ("autoéteindre",),
    "autoéteignis": ("autoéteindre",),
    "autoéteignissent": ("autoéteindre",),
    "autoéteignisses": ("autoéteindre",),
    "autoéteignisse": ("autoéteindre",),
    "autoéteignissiez": ("autoéteindre",),
    "autoéteignissions": ("autoéteindre",),
    "autoéteignîtes": ("autoéteindre",),
    "autoéteignit": ("autoéteindre",),
    "autoéteignît": ("autoéteindre",),
    "autoéteignons": ("autoéteindre",),
    "autoéteindra": ("autoéteindre",),
    "autoéteindraient": ("autoéteindre",),
    "autoéteindrai": ("autoéteindre",),
    "autoéteindrais": ("autoéteindre",),
    "autoéteindrait": ("autoéteindre",),
    "autoéteindras": ("autoéteindre",),
    "autoéteindrez": ("autoéteindre",),
    "autoéteindriez": ("autoéteindre",),
    "autoéteindrions": ("autoéteindre",),
    "autoéteindrons": ("autoéteindre",),
    "autoéteindront": ("autoéteindre",),
    "autoéteins": ("autoéteindre",),
    "autoéteinte": ("autoéteindre",),
    "autoéteintes": ("autoéteindre",),
    "autoéteint": ("autoéteindre",),
    "autoéteints": ("autoéteindre",),
    "autofinançaient": ("autofinancer",),
    "autofinançai": ("autofinancer",),
    "autofinançais": ("autofinancer",),
    "autofinançait": ("autofinancer",),
    "autofinança": ("autofinancer",),
    "autofinançâmes": ("autofinancer",),
    "autofinançant": ("autofinancer",),
    "autofinanças": ("autofinancer",),
    "autofinançassent": ("autofinancer",),
    "autofinançasses": ("autofinancer",),
    "autofinançasse": ("autofinancer",),
    "autofinançassiez": ("autofinancer",),
    "autofinançassions": ("autofinancer",),
    "autofinançâtes": ("autofinancer",),
    "autofinançât": ("autofinancer",),
    "autofinancée": ("autofinancer",),
    "autofinancées": ("autofinancer",),
    "autofinancé": ("autofinancer",),
    "autofinancent": ("autofinancer",),
    "autofinance": ("autofinancer",),
    "autofinancera": ("autofinancer",),
    "autofinanceraient": ("autofinancer",),
    "autofinancerai": ("autofinancer",),
    "autofinancerais": ("autofinancer",),
    "autofinancerait": ("autofinancer",),
    "autofinanceras": ("autofinancer",),
    "autofinancèrent": ("autofinancer",),
    "autofinancerez": ("autofinancer",),
    "autofinanceriez": ("autofinancer",),
    "autofinancerions": ("autofinancer",),
    "autofinancerons": ("autofinancer",),
    "autofinanceront": ("autofinancer",),
    "autofinancés": ("autofinancer",),
    "autofinances": ("autofinancer",),
    "autofinancez": ("autofinancer",),
    "autofinanciez": ("autofinancer",),
    "autofinancions": ("autofinancer",),
    "autofinançons": ("autofinancer",),
    "autogéraient": ("autogérer",),
    "autogérai": ("autogérer",),
    "autogérais": ("autogérer",),
    "autogérait": ("autogérer",),
    "autogéra": ("autogérer",),
    "autogérâmes": ("autogérer",),
    "autogérant": ("autogérer",),
    "autogéras": ("autogérer",),
    "autogérassent": ("autogérer",),
    "autogérasses": ("autogérer",),
    "autogérasse": ("autogérer",),
    "autogérassiez": ("autogérer",),
    "autogérassions": ("autogérer",),
    "autogérâtes": ("autogérer",),
    "autogérât": ("autogérer",),
    "autogérée": ("autogérer",),
    "autogérées": ("autogérer",),
    "autogéré": ("autogérer",),
    "autogèrent": ("autogérer",),
    "autogère": ("autogérer",),
    "autogérera": ("autogérer",),
    "autogéreraient": ("autogérer",),
    "autogérerai": ("autogérer",),
    "autogérerais": ("autogérer",),
    "autogérerait": ("autogérer",),
    "autogéreras": ("autogérer",),
    "autogérèrent": ("autogérer",),
    "autogérerez": ("autogérer",),
    "autogéreriez": ("autogérer",),
    "autogérerions": ("autogérer",),
    "autogérerons": ("autogérer",),
    "autogéreront": ("autogérer",),
    "autogérés": ("autogérer",),
    "autogères": ("autogérer",),
    "autogérez": ("autogérer",),
    "autogériez": ("autogérer",),
    "autogérions": ("autogérer",),
    "autogérons": ("autogérer",),
    "autographiaient": ("autographier",),
    "autographiai": ("autographier",),
    "autographiais": ("autographier",),
    "autographiait": ("autographier",),
    "autographia": ("autographier",),
    "autographiâmes": ("autographier",),
    "autographiant": ("autographier",),
    "autographias": ("autographier",),
    "autographiassent": ("autographier",),
    "autographiasses": ("autographier",),
    "autographiasse": ("autographier",),
    "autographiassiez": ("autographier",),
    "autographiassions": ("autographier",),
    "autographiâtes": ("autographier",),
    "autographiât": ("autographier",),
    "autographiée": ("autographier",),
    "autographiées": ("autographier",),
    "autographié": ("autographier",),
    "autographient": ("autographier",),
    "autographie": ("autographier",),
    "autographiera": ("autographier",),
    "autographieraient": ("autographier",),
    "autographierai": ("autographier",),
    "autographierais": ("autographier",),
    "autographierait": ("autographier",),
    "autographieras": ("autographier",),
    "autographièrent": ("autographier",),
    "autographierez": ("autographier",),
    "autographieriez": ("autographier",),
    "autographierions": ("autographier",),
    "autographierons": ("autographier",),
    "autographieront": ("autographier",),
    "autographiés": ("autographier",),
    "autographies": ("autographier",),
    "autographiez": ("autographier",),
    "autographiiez": ("autographier",),
    "autographiions": ("autographier",),
    "autographions": ("autographier",),
    "autojustifiaient": ("autojustifier",),
    "autojustifiai": ("autojustifier",),
    "autojustifiais": ("autojustifier",),
    "autojustifiait": ("autojustifier",),
    "autojustifia": ("autojustifier",),
    "autojustifiâmes": ("autojustifier",),
    "autojustifiant": ("autojustifier",),
    "autojustifias": ("autojustifier",),
    "autojustifiassent": ("autojustifier",),
    "autojustifiasses": ("autojustifier",),
    "autojustifiasse": ("autojustifier",),
    "autojustifiassiez": ("autojustifier",),
    "autojustifiassions": ("autojustifier",),
    "autojustifiâtes": ("autojustifier",),
    "autojustifiât": ("autojustifier",),
    "autojustifiée": ("autojustifier",),
    "autojustifiées": ("autojustifier",),
    "autojustifié": ("autojustifier",),
    "autojustifient": ("autojustifier",),
    "autojustifie": ("autojustifier",),
    "autojustifiera": ("autojustifier",),
    "autojustifieraient": ("autojustifier",),
    "autojustifierai": ("autojustifier",),
    "autojustifierais": ("autojustifier",),
    "autojustifierait": ("autojustifier",),
    "autojustifieras": ("autojustifier",),
    "autojustifièrent": ("autojustifier",),
    "autojustifierez": ("autojustifier",),
    "autojustifieriez": ("autojustifier",),
    "autojustifierions": ("autojustifier",),
    "autojustifierons": ("autojustifier",),
    "autojustifieront": ("autojustifier",),
    "autojustifiés": ("autojustifier",),
    "autojustifies": ("autojustifier",),
    "autojustifiez": ("autojustifier",),
    "autojustifiiez": ("autojustifier",),
    "autojustifiions": ("autojustifier",),
    "autojustifions": ("autojustifier",),
    "autolubrifiaient": ("autolubrifier",),
    "autolubrifiai": ("autolubrifier",),
    "autolubrifiais": ("autolubrifier",),
    "autolubrifiait": ("autolubrifier",),
    "autolubrifia": ("autolubrifier",),
    "autolubrifiâmes": ("autolubrifier",),
    "autolubrifiant": ("autolubrifier",),
    "autolubrifias": ("autolubrifier",),
    "autolubrifiassent": ("autolubrifier",),
    "autolubrifiasses": ("autolubrifier",),
    "autolubrifiasse": ("autolubrifier",),
    "autolubrifiassiez": ("autolubrifier",),
    "autolubrifiassions": ("autolubrifier",),
    "autolubrifiâtes": ("autolubrifier",),
    "autolubrifiât": ("autolubrifier",),
    "autolubrifiée": ("autolubrifier",),
    "autolubrifiées": ("autolubrifier",),
    "autolubrifié": ("autolubrifier",),
    "autolubrifient": ("autolubrifier",),
    "autolubrifie": ("autolubrifier",),
    "autolubrifiera": ("autolubrifier",),
    "autolubrifieraient": ("autolubrifier",),
    "autolubrifierai": ("autolubrifier",),
    "autolubrifierais": ("autolubrifier",),
    "autolubrifierait": ("autolubrifier",),
    "autolubrifieras": ("autolubrifier",),
    "autolubrifièrent": ("autolubrifier",),
    "autolubrifierez": ("autolubrifier",),
    "autolubrifieriez": ("autolubrifier",),
    "autolubrifierions": ("autolubrifier",),
    "autolubrifierons": ("autolubrifier",),
    "autolubrifieront": ("autolubrifier",),
    "autolubrifiés": ("autolubrifier",),
    "autolubrifies": ("autolubrifier",),
    "autolubrifiez": ("autolubrifier",),
    "autolubrifiiez": ("autolubrifier",),
    "autolubrifiions": ("autolubrifier",),
    "autolubrifions": ("autolubrifier",),
    "automassaient": ("automasser",),
    "automassai": ("automasser",),
    "automassais": ("automasser",),
    "automassait": ("automasser",),
    "automassa": ("automasser",),
    "automassâmes": ("automasser",),
    "automassant": ("automasser",),
    "automassas": ("automasser",),
    "automassassent": ("automasser",),
    "automassasses": ("automasser",),
    "automassasse": ("automasser",),
    "automassassiez": ("automasser",),
    "automassassions": ("automasser",),
    "automassâtes": ("automasser",),
    "automassât": ("automasser",),
    "automassée": ("automasser",),
    "automassées": ("automasser",),
    "automassé": ("automasser",),
    "automassent": ("automasser",),
    "automasse": ("automasser",),
    "automassera": ("automasser",),
    "automasseraient": ("automasser",),
    "automasserai": ("automasser",),
    "automasserais": ("automasser",),
    "automasserait": ("automasser",),
    "automasseras": ("automasser",),
    "automassèrent": ("automasser",),
    "automasserez": ("automasser",),
    "automasseriez": ("automasser",),
    "automasserions": ("automasser",),
    "automasserons": ("automasser",),
    "automasseront": ("automasser",),
    "automassés": ("automasser",),
    "automasses": ("automasser",),
    "automassez": ("automasser",),
    "automassiez": ("automasser",),
    "automassions": ("automasser",),
    "automassons": ("automasser",),
    "automodifiaient": ("automodifier",),
    "automodifiai": ("automodifier",),
    "automodifiais": ("automodifier",),
    "automodifiait": ("automodifier",),
    "automodifia": ("automodifier",),
    "automodifiâmes": ("automodifier",),
    "automodifiant": ("automodifier",),
    "automodifias": ("automodifier",),
    "automodifiassent": ("automodifier",),
    "automodifiasses": ("automodifier",),
    "automodifiasse": ("automodifier",),
    "automodifiassiez": ("automodifier",),
    "automodifiassions": ("automodifier",),
    "automodifiâtes": ("automodifier",),
    "automodifiât": ("automodifier",),
    "automodifiée": ("automodifier",),
    "automodifiées": ("automodifier",),
    "automodifié": ("automodifier",),
    "automodifient": ("automodifier",),
    "automodifie": ("automodifier",),
    "automodifiera": ("automodifier",),
    "automodifieraient": ("automodifier",),
    "automodifierai": ("automodifier",),
    "automodifierais": ("automodifier",),
    "automodifierait": ("automodifier",),
    "automodifieras": ("automodifier",),
    "automodifièrent": ("automodifier",),
    "automodifierez": ("automodifier",),
    "automodifieriez": ("automodifier",),
    "automodifierions": ("automodifier",),
    "automodifierons": ("automodifier",),
    "automodifieront": ("automodifier",),
    "automodifiés": ("automodifier",),
    "automodifies": ("automodifier",),
    "automodifiez": ("automodifier",),
    "automodifiiez": ("automodifier",),
    "automodifiions": ("automodifier",),
    "automodifions": ("automodifier",),
    "autonettoient": ("autonettoyer",),
    "autonettoie": ("autonettoyer",),
    "autonettoiera": ("autonettoyer",),
    "autonettoieraient": ("autonettoyer",),
    "autonettoierai": ("autonettoyer",),
    "autonettoierais": ("autonettoyer",),
    "autonettoierait": ("autonettoyer",),
    "autonettoieras": ("autonettoyer",),
    "autonettoierez": ("autonettoyer",),
    "autonettoieriez": ("autonettoyer",),
    "autonettoierions": ("autonettoyer",),
    "autonettoierons": ("autonettoyer",),
    "autonettoieront": ("autonettoyer",),
    "autonettoies": ("autonettoyer",),
    "autonettoyaient": ("autonettoyer",),
    "autonettoyai": ("autonettoyer",),
    "autonettoyais": ("autonettoyer",),
    "autonettoyait": ("autonettoyer",),
    "autonettoya": ("autonettoyer",),
    "autonettoyâmes": ("autonettoyer",),
    "autonettoyant": ("autonettoyer",),
    "autonettoyas": ("autonettoyer",),
    "autonettoyassent": ("autonettoyer",),
    "autonettoyasses": ("autonettoyer",),
    "autonettoyasse": ("autonettoyer",),
    "autonettoyassiez": ("autonettoyer",),
    "autonettoyassions": ("autonettoyer",),
    "autonettoyâtes": ("autonettoyer",),
    "autonettoyât": ("autonettoyer",),
    "autonettoyée": ("autonettoyer",),
    "autonettoyées": ("autonettoyer",),
    "autonettoyé": ("autonettoyer",),
    "autonettoyèrent": ("autonettoyer",),
    "autonettoyés": ("autonettoyer",),
    "autonettoyez": ("autonettoyer",),
    "autonettoyiez": ("autonettoyer",),
    "autonettoyions": ("autonettoyer",),
    "autonettoyons": ("autonettoyer",),
    "autopromeus": ("autopromouvoir",),
    "autopromeut": ("autopromouvoir",),
    "autopromeuvent": ("autopromouvoir",),
    "autopromeuve": ("autopromouvoir",),
    "autopromeuves": ("autopromouvoir",),
    "autopromouvaient": ("autopromouvoir",),
    "autopromouvais": ("autopromouvoir",),
    "autopromouvait": ("autopromouvoir",),
    "autopromouvant": ("autopromouvoir",),
    "autopromouvez": ("autopromouvoir",),
    "autopromouviez": ("autopromouvoir",),
    "autopromouvions": ("autopromouvoir",),
    "autopromouvons": ("autopromouvoir",),
    "autopromouvra": ("autopromouvoir",),
    "autopromouvraient": ("autopromouvoir",),
    "autopromouvrai": ("autopromouvoir",),
    "autopromouvrais": ("autopromouvoir",),
    "autopromouvrait": ("autopromouvoir",),
    "autopromouvras": ("autopromouvoir",),
    "autopromouvrez": ("autopromouvoir",),
    "autopromouvriez": ("autopromouvoir",),
    "autopromouvrions": ("autopromouvoir",),
    "autopromouvrons": ("autopromouvoir",),
    "autopromouvront": ("autopromouvoir",),
    "autopromue": ("autopromouvoir",),
    "autopromues": ("autopromouvoir",),
    "autopromu": ("autopromouvoir",),
    "autopromûmes": ("autopromouvoir",),
    "autopromurent": ("autopromouvoir",),
    "autopromus": ("autopromouvoir",),
    "autopromussent": ("autopromouvoir",),
    "autopromusses": ("autopromouvoir",),
    "autopromusse": ("autopromouvoir",),
    "autopromussiez": ("autopromouvoir",),
    "autopromussions": ("autopromouvoir",),
    "autopromûtes": ("autopromouvoir",),
    "autopromut": ("autopromouvoir",),
    "autopromût": ("autopromouvoir",),
    "autoprotégeaient": ("autoprotéger",),
    "autoprotégeai": ("autoprotéger",),
    "autoprotégeais": ("autoprotéger",),
    "autoprotégeait": ("autoprotéger",),
    "autoprotégea": ("autoprotéger",),
    "autoprotégeâmes": ("autoprotéger",),
    "autoprotégeant": ("autoprotéger",),
    "autoprotégeas": ("autoprotéger",),
    "autoprotégeassent": ("autoprotéger",),
    "autoprotégeasses": ("autoprotéger",),
    "autoprotégeasse": ("autoprotéger",),
    "autoprotégeassiez": ("autoprotéger",),
    "autoprotégeassions": ("autoprotéger",),
    "autoprotégeâtes": ("autoprotéger",),
    "autoprotégeât": ("autoprotéger",),
    "autoprotégée": ("autoprotéger",),
    "autoprotégées": ("autoprotéger",),
    "autoprotégé": ("autoprotéger",),
    "autoprotègent": ("autoprotéger",),
    "autoprotégeons": ("autoprotéger",),
    "autoprotège": ("autoprotéger",),
    "autoprotégera": ("autoprotéger",),
    "autoprotégeraient": ("autoprotéger",),
    "autoprotégerai": ("autoprotéger",),
    "autoprotégerais": ("autoprotéger",),
    "autoprotégerait": ("autoprotéger",),
    "autoprotégeras": ("autoprotéger",),
    "autoprotégèrent": ("autoprotéger",),
    "autoprotégerez": ("autoprotéger",),
    "autoprotégeriez": ("autoprotéger",),
    "autoprotégerions": ("autoprotéger",),
    "autoprotégerons": ("autoprotéger",),
    "autoprotégeront": ("autoprotéger",),
    "autoprotégés": ("autoprotéger",),
    "autoprotèges": ("autoprotéger",),
    "autoprotégez": ("autoprotéger",),
    "autoprotégiez": ("autoprotéger",),
    "autoprotégions": ("autoprotéger",),
    "autopsiaient": ("autopsier",),
    "autopsiai": ("autopsier",),
    "autopsiais": ("autopsier",),
    "autopsiait": ("autopsier",),
    "autopsia": ("autopsier",),
    "autopsiâmes": ("autopsier",),
    "autopsiant": ("autopsier",),
    "autopsias": ("autopsier",),
    "autopsiassent": ("autopsier",),
    "autopsiasses": ("autopsier",),
    "autopsiasse": ("autopsier",),
    "autopsiassiez": ("autopsier",),
    "autopsiassions": ("autopsier",),
    "autopsiâtes": ("autopsier",),
    "autopsiât": ("autopsier",),
    "autopsiée": ("autopsier",),
    "autopsiées": ("autopsier",),
    "autopsié": ("autopsier",),
    "autopsient": ("autopsier",),
    "autopsie": ("autopsier",),
    "autopsiera": ("autopsier",),
    "autopsieraient": ("autopsier",),
    "autopsierai": ("autopsier",),
    "autopsierais": ("autopsier",),
    "autopsierait": ("autopsier",),
    "autopsieras": ("autopsier",),
    "autopsièrent": ("autopsier",),
    "autopsierez": ("autopsier",),
    "autopsieriez": ("autopsier",),
    "autopsierions": ("autopsier",),
    "autopsierons": ("autopsier",),
    "autopsieront": ("autopsier",),
    "autopsiés": ("autopsier",),
    "autopsies": ("autopsier",),
    "autopsiez": ("autopsier",),
    "autopsiiez": ("autopsier",),
    "autopsiions": ("autopsier",),
    "autopsions": ("autopsier",),
    "autopunie": ("autopunir",),
    "autopunies": ("autopunir",),
    "autopuni": ("autopunir",),
    "autopunîmes": ("autopunir",),
    "autopunira": ("autopunir",),
    "autopuniraient": ("autopunir",),
    "autopunirai": ("autopunir",),
    "autopunirais": ("autopunir",),
    "autopunirait": ("autopunir",),
    "autopuniras": ("autopunir",),
    "autopunirent": ("autopunir",),
    "autopunirez": ("autopunir",),
    "autopuniriez": ("autopunir",),
    "autopunirions": ("autopunir",),
    "autopunirons": ("autopunir",),
    "autopuniront": ("autopunir",),
    "autopunis": ("autopunir",),
    "autopunissaient": ("autopunir",),
    "autopunissais": ("autopunir",),
    "autopunissait": ("autopunir",),
    "autopunissant": ("autopunir",),
    "autopunissent": ("autopunir",),
    "autopunisse": ("autopunir",),
    "autopunisses": ("autopunir",),
    "autopunissez": ("autopunir",),
    "autopunissiez": ("autopunir",),
    "autopunissions": ("autopunir",),
    "autopunissons": ("autopunir",),
    "autopunîtes": ("autopunir",),
    "autopunit": ("autopunir",),
    "autopunît": ("autopunir",),
    "autoradiographiaient": ("autoradiographier",),
    "autoradiographiai": ("autoradiographier",),
    "autoradiographiais": ("autoradiographier",),
    "autoradiographiait": ("autoradiographier",),
    "autoradiographia": ("autoradiographier",),
    "autoradiographiâmes": ("autoradiographier",),
    "autoradiographiant": ("autoradiographier",),
    "autoradiographias": ("autoradiographier",),
    "autoradiographiassent": ("autoradiographier",),
    "autoradiographiasses": ("autoradiographier",),
    "autoradiographiasse": ("autoradiographier",),
    "autoradiographiassiez": ("autoradiographier",),
    "autoradiographiassions": ("autoradiographier",),
    "autoradiographiâtes": ("autoradiographier",),
    "autoradiographiât": ("autoradiographier",),
    "autoradiographiée": ("autoradiographier",),
    "autoradiographiées": ("autoradiographier",),
    "autoradiographié": ("autoradiographier",),
    "autoradiographient": ("autoradiographier",),
    "autoradiographie": ("autoradiographier",),
    "autoradiographiera": ("autoradiographier",),
    "autoradiographieraient": ("autoradiographier",),
    "autoradiographierai": ("autoradiographier",),
    "autoradiographierais": ("autoradiographier",),
    "autoradiographierait": ("autoradiographier",),
    "autoradiographieras": ("autoradiographier",),
    "autoradiographièrent": ("autoradiographier",),
    "autoradiographierez": ("autoradiographier",),
    "autoradiographieriez": ("autoradiographier",),
    "autoradiographierions": ("autoradiographier",),
    "autoradiographierons": ("autoradiographier",),
    "autoradiographieront": ("autoradiographier",),
    "autoradiographiés": ("autoradiographier",),
    "autoradiographies": ("autoradiographier",),
    "autoradiographiez": ("autoradiographier",),
    "autoradiographiiez": ("autoradiographier",),
    "autoradiographiions": ("autoradiographier",),
    "autoradiographions": ("autoradiographier",),
    "autoréféraient": ("autoréférer",),
    "autoréférai": ("autoréférer",),
    "autoréférais": ("autoréférer",),
    "autoréférait": ("autoréférer",),
    "autoréféra": ("autoréférer",),
    "autoréférâmes": ("autoréférer",),
    "autoréférant": ("autoréférer",),
    "autoréféras": ("autoréférer",),
    "autoréférassent": ("autoréférer",),
    "autoréférasses": ("autoréférer",),
    "autoréférasse": ("autoréférer",),
    "autoréférassiez": ("autoréférer",),
    "autoréférassions": ("autoréférer",),
    "autoréférâtes": ("autoréférer",),
    "autoréférât": ("autoréférer",),
    "autoréférée": ("autoréférer",),
    "autoréférées": ("autoréférer",),
    "autoréféré": ("autoréférer",),
    "autoréfèrent": ("autoréférer",),
    "autoréfère": ("autoréférer",),
    "autoréférera": ("autoréférer",),
    "autoréféreraient": ("autoréférer",),
    "autoréférerai": ("autoréférer",),
    "autoréférerais": ("autoréférer",),
    "autoréférerait": ("autoréférer",),
    "autoréféreras": ("autoréférer",),
    "autoréférèrent": ("autoréférer",),
    "autoréférerez": ("autoréférer",),
    "autoréféreriez": ("autoréférer",),
    "autoréférerions": ("autoréférer",),
    "autoréférerons": ("autoréférer",),
    "autoréféreront": ("autoréférer",),
    "autoréférés": ("autoréférer",),
    "autoréfères": ("autoréférer",),
    "autoréférez": ("autoréférer",),
    "autoréfériez": ("autoréférer",),
    "autoréférions": ("autoréférer",),
    "autoréférons": ("autoréférer",),
    "autoréglaient": ("autorégler",),
    "autoréglai": ("autorégler",),
    "autoréglais": ("autorégler",),
    "autoréglait": ("autorégler",),
    "autorégla": ("autorégler",),
    "autoréglâmes": ("autorégler",),
    "autoréglant": ("autorégler",),
    "autoréglas": ("autorégler",),
    "autoréglassent": ("autorégler",),
    "autoréglasses": ("autorégler",),
    "autoréglasse": ("autorégler",),
    "autoréglassiez": ("autorégler",),
    "autoréglassions": ("autorégler",),
    "autoréglâtes": ("autorégler",),
    "autoréglât": ("autorégler",),
    "autoréglée": ("autorégler",),
    "autoréglées": ("autorégler",),
    "autoréglé": ("autorégler",),
    "autorèglent": ("autorégler",),
    "autorègle": ("autorégler",),
    "autoréglera": ("autorégler",),
    "autorégleraient": ("autorégler",),
    "autoréglerai": ("autorégler",),
    "autoréglerais": ("autorégler",),
    "autoréglerait": ("autorégler",),
    "autorégleras": ("autorégler",),
    "autoréglèrent": ("autorégler",),
    "autoréglerez": ("autorégler",),
    "autorégleriez": ("autorégler",),
    "autoréglerions": ("autorégler",),
    "autoréglerons": ("autorégler",),
    "autorégleront": ("autorégler",),
    "autoréglés": ("autorégler",),
    "autorègles": ("autorégler",),
    "autoréglez": ("autorégler",),
    "autorégliez": ("autorégler",),
    "autoréglions": ("autorégler",),
    "autoréglons": ("autorégler",),
    "autoremblaient": ("autoremblayer",),
    "autoremblaie": ("autoremblayer",),
    "autoremblaiera": ("autoremblayer",),
    "autoremblaieraient": ("autoremblayer",),
    "autoremblaierai": ("autoremblayer",),
    "autoremblaierais": ("autoremblayer",),
    "autoremblaierait": ("autoremblayer",),
    "autoremblaieras": ("autoremblayer",),
    "autoremblaierez": ("autoremblayer",),
    "autoremblaieriez": ("autoremblayer",),
    "autoremblaierions": ("autoremblayer",),
    "autoremblaierons": ("autoremblayer",),
    "autoremblaieront": ("autoremblayer",),
    "autoremblaies": ("autoremblayer",),
    "autoremblayaient": ("autoremblayer",),
    "autoremblayai": ("autoremblayer",),
    "autoremblayais": ("autoremblayer",),
    "autoremblayait": ("autoremblayer",),
    "autoremblaya": ("autoremblayer",),
    "autoremblayâmes": ("autoremblayer",),
    "autoremblayant": ("autoremblayer",),
    "autoremblayas": ("autoremblayer",),
    "autoremblayassent": ("autoremblayer",),
    "autoremblayasses": ("autoremblayer",),
    "autoremblayasse": ("autoremblayer",),
    "autoremblayassiez": ("autoremblayer",),
    "autoremblayassions": ("autoremblayer",),
    "autoremblayâtes": ("autoremblayer",),
    "autoremblayât": ("autoremblayer",),
    "autoremblayée": ("autoremblayer",),
    "autoremblayées": ("autoremblayer",),
    "autoremblayé": ("autoremblayer",),
    "autoremblayent": ("autoremblayer",),
    "autoremblaye": ("autoremblayer",),
    "autoremblayera": ("autoremblayer",),
    "autoremblayeraient": ("autoremblayer",),
    "autoremblayerai": ("autoremblayer",),
    "autoremblayerais": ("autoremblayer",),
    "autoremblayerait": ("autoremblayer",),
    "autoremblayeras": ("autoremblayer",),
    "autoremblayèrent": ("autoremblayer",),
    "autoremblayerez": ("autoremblayer",),
    "autoremblayeriez": ("autoremblayer",),
    "autoremblayerions": ("autoremblayer",),
    "autoremblayerons": ("autoremblayer",),
    "autoremblayeront": ("autoremblayer",),
    "autoremblayés": ("autoremblayer",),
    "autoremblayes": ("autoremblayer",),
    "autoremblayez": ("autoremblayer",),
    "autoremblayiez": ("autoremblayer",),
    "autoremblayions": ("autoremblayer",),
    "autoremblayons": ("autoremblayer",),
    "autorenforçaient": ("autorenforcer",),
    "autorenforçai": ("autorenforcer",),
    "autorenforçais": ("autorenforcer",),
    "autorenforçait": ("autorenforcer",),
    "autorenforça": ("autorenforcer",),
    "autorenforçâmes": ("autorenforcer",),
    "autorenforçant": ("autorenforcer",),
    "autorenforças": ("autorenforcer",),
    "autorenforçassent": ("autorenforcer",),
    "autorenforçasses": ("autorenforcer",),
    "autorenforçasse": ("autorenforcer",),
    "autorenforçassiez": ("autorenforcer",),
    "autorenforçassions": ("autorenforcer",),
    "autorenforçâtes": ("autorenforcer",),
    "autorenforçât": ("autorenforcer",),
    "autorenforcée": ("autorenforcer",),
    "autorenforcées": ("autorenforcer",),
    "autorenforcé": ("autorenforcer",),
    "autorenforcent": ("autorenforcer",),
    "autorenforce": ("autorenforcer",),
    "autorenforcera": ("autorenforcer",),
    "autorenforceraient": ("autorenforcer",),
    "autorenforcerai": ("autorenforcer",),
    "autorenforcerais": ("autorenforcer",),
    "autorenforcerait": ("autorenforcer",),
    "autorenforceras": ("autorenforcer",),
    "autorenforcèrent": ("autorenforcer",),
    "autorenforcerez": ("autorenforcer",),
    "autorenforceriez": ("autorenforcer",),
    "autorenforcerions": ("autorenforcer",),
    "autorenforcerons": ("autorenforcer",),
    "autorenforceront": ("autorenforcer",),
    "autorenforcés": ("autorenforcer",),
    "autorenforces": ("autorenforcer",),
    "autorenforcez": ("autorenforcer",),
    "autorenforciez": ("autorenforcer",),
    "autorenforcions": ("autorenforcer",),
    "autorenforçons": ("autorenforcer",),
    "autoreproduira": ("autoreproduire",),
    "autoreproduiraient": ("autoreproduire",),
    "autoreproduirai": ("autoreproduire",),
    "autoreproduirais": ("autoreproduire",),
    "autoreproduirait": ("autoreproduire",),
    "autoreproduiras": ("autoreproduire",),
    "autoreproduirez": ("autoreproduire",),
    "autoreproduiriez": ("autoreproduire",),
    "autoreproduirions": ("autoreproduire",),
    "autoreproduirons": ("autoreproduire",),
    "autoreproduiront": ("autoreproduire",),
    "autoreproduisaient": ("autoreproduire",),
    "autoreproduisais": ("autoreproduire",),
    "autoreproduisait": ("autoreproduire",),
    "autoreproduisant": ("autoreproduire",),
    "autoreproduisent": ("autoreproduire",),
    "autoreproduise": ("autoreproduire",),
    "autoreproduises": ("autoreproduire",),
    "autoreproduisez": ("autoreproduire",),
    "autoreproduisiez": ("autoreproduire",),
    "autoreproduisîmes": ("autoreproduire",),
    "autoreproduisions": ("autoreproduire",),
    "autoreproduisirent": ("autoreproduire",),
    "autoreproduisis": ("autoreproduire",),
    "autoreproduisissent": ("autoreproduire",),
    "autoreproduisisses": ("autoreproduire",),
    "autoreproduisisse": ("autoreproduire",),
    "autoreproduisissiez": ("autoreproduire",),
    "autoreproduisissions": ("autoreproduire",),
    "autoreproduisîtes": ("autoreproduire",),
    "autoreproduisit": ("autoreproduire",),
    "autoreproduisît": ("autoreproduire",),
    "autoreproduisons": ("autoreproduire",),
    "autoreproduis": ("autoreproduire",),
    "autoreproduite": ("autoreproduire",),
    "autoreproduites": ("autoreproduire",),
    "autoreproduit": ("autoreproduire",),
    "autoreproduits": ("autoreproduire",),
    "autosatisfaisaient": ("autosatisfaire",),
    "autosatisfaisais": ("autosatisfaire",),
    "autosatisfaisait": ("autosatisfaire",),
    "autosatisfaisant": ("autosatisfaire",),
    "autosatisfaisiez": ("autosatisfaire",),
    "autosatisfaisions": ("autosatisfaire",),
    "autosatisfaisons": ("autosatisfaire",),
    "autosatisfais": ("autosatisfaire",),
    "autosatisfaite": ("autosatisfaire",),
    "autosatisfaites": ("autosatisfaire",),
    "autosatisfait": ("autosatisfaire",),
    "autosatisfaits": ("autosatisfaire",),
    "autosatisfassent": ("autosatisfaire",),
    "autosatisfasse": ("autosatisfaire",),
    "autosatisfasses": ("autosatisfaire",),
    "autosatisfassiez": ("autosatisfaire",),
    "autosatisfassions": ("autosatisfaire",),
    "autosatisfera": ("autosatisfaire",),
    "autosatisferaient": ("autosatisfaire",),
    "autosatisferai": ("autosatisfaire",),
    "autosatisferais": ("autosatisfaire",),
    "autosatisferait": ("autosatisfaire",),
    "autosatisferas": ("autosatisfaire",),
    "autosatisferez": ("autosatisfaire",),
    "autosatisferiez": ("autosatisfaire",),
    "autosatisferions": ("autosatisfaire",),
    "autosatisferons": ("autosatisfaire",),
    "autosatisferont": ("autosatisfaire",),
    "autosatisfîmes": ("autosatisfaire",),
    "autosatisfirent": ("autosatisfaire",),
    "autosatisfis": ("autosatisfaire",),
    "autosatisfissent": ("autosatisfaire",),
    "autosatisfisses": ("autosatisfaire",),
    "autosatisfisse": ("autosatisfaire",),
    "autosatisfissiez": ("autosatisfaire",),
    "autosatisfissions": ("autosatisfaire",),
    "autosatisfîtes": ("autosatisfaire",),
    "autosatisfit": ("autosatisfaire",),
    "autosatisfît": ("autosatisfaire",),
    "autosatisfont": ("autosatisfaire",),
    "autosuffi": ("autosuffire",),
    "autosuffîmes": ("autosuffire",),
    "autosuffira": ("autosuffire",),
    "autosuffiraient": ("autosuffire",),
    "autosuffirai": ("autosuffire",),
    "autosuffirais": ("autosuffire",),
    "autosuffirait": ("autosuffire",),
    "autosuffiras": ("autosuffire",),
    "autosuffirent": ("autosuffire",),
    "autosuffirez": ("autosuffire",),
    "autosuffiriez": ("autosuffire",),
    "autosuffirions": ("autosuffire",),
    "autosuffirons": ("autosuffire",),
    "autosuffiront": ("autosuffire",),
    "autosuffisaient": ("autosuffire",),
    "autosuffisais": ("autosuffire",),
    "autosuffisait": ("autosuffire",),
    "autosuffisant": ("autosuffire",),
    "autosuffisent": ("autosuffire",),
    "autosuffise": ("autosuffire",),
    "autosuffises": ("autosuffire",),
    "autosuffisez": ("autosuffire",),
    "autosuffisiez": ("autosuffire",),
    "autosuffisions": ("autosuffire",),
    "autosuffisons": ("autosuffire",),
    "autosuffis": ("autosuffire",),
    "autosuffissent": ("autosuffire",),
    "autosuffisses": ("autosuffire",),
    "autosuffisse": ("autosuffire",),
    "autosuffissiez": ("autosuffire",),
    "autosuffissions": ("autosuffire",),
    "autosuffîtes": ("autosuffire",),
    "autosuffit": ("autosuffire",),
    "autosuffît": ("autosuffire",),
    "autosuggéraient": ("autosuggérer",),
    "autosuggérai": ("autosuggérer",),
    "autosuggérais": ("autosuggérer",),
    "autosuggérait": ("autosuggérer",),
    "autosuggéra": ("autosuggérer",),
    "autosuggérâmes": ("autosuggérer",),
    "autosuggérant": ("autosuggérer",),
    "autosuggéras": ("autosuggérer",),
    "autosuggérassent": ("autosuggérer",),
    "autosuggérasses": ("autosuggérer",),
    "autosuggérasse": ("autosuggérer",),
    "autosuggérassiez": ("autosuggérer",),
    "autosuggérassions": ("autosuggérer",),
    "autosuggérâtes": ("autosuggérer",),
    "autosuggérât": ("autosuggérer",),
    "autosuggérée": ("autosuggérer",),
    "autosuggérées": ("autosuggérer",),
    "autosuggéré": ("autosuggérer",),
    "autosuggèrent": ("autosuggérer",),
    "autosuggère": ("autosuggérer",),
    "autosuggérera": ("autosuggérer",),
    "autosuggéreraient": ("autosuggérer",),
    "autosuggérerai": ("autosuggérer",),
    "autosuggérerais": ("autosuggérer",),
    "autosuggérerait": ("autosuggérer",),
    "autosuggéreras": ("autosuggérer",),
    "autosuggérèrent": ("autosuggérer",),
    "autosuggérerez": ("autosuggérer",),
    "autosuggéreriez": ("autosuggérer",),
    "autosuggérerions": ("autosuggérer",),
    "autosuggérerons": ("autosuggérer",),
    "autosuggéreront": ("autosuggérer",),
    "autosuggérés": ("autosuggérer",),
    "autosuggères": ("autosuggérer",),
    "autosuggérez": ("autosuggérer",),
    "autosuggériez": ("autosuggérer",),
    "autosuggérions": ("autosuggérer",),
    "autosuggérons": ("autosuggérer",),
    "autovérifiaient": ("autovérifier",),
    "autovérifiai": ("autovérifier",),
    "autovérifiais": ("autovérifier",),
    "autovérifiait": ("autovérifier",),
    "autovérifia": ("autovérifier",),
    "autovérifiâmes": ("autovérifier",),
    "autovérifiant": ("autovérifier",),
    "autovérifias": ("autovérifier",),
    "autovérifiassent": ("autovérifier",),
    "autovérifiasses": ("autovérifier",),
    "autovérifiasse": ("autovérifier",),
    "autovérifiassiez": ("autovérifier",),
    "autovérifiassions": ("autovérifier",),
    "autovérifiâtes": ("autovérifier",),
    "autovérifiât": ("autovérifier",),
    "autovérifiée": ("autovérifier",),
    "autovérifiées": ("autovérifier",),
    "autovérifié": ("autovérifier",),
    "autovérifient": ("autovérifier",),
    "autovérifie": ("autovérifier",),
    "autovérifiera": ("autovérifier",),
    "autovérifieraient": ("autovérifier",),
    "autovérifierai": ("autovérifier",),
    "autovérifierais": ("autovérifier",),
    "autovérifierait": ("autovérifier",),
    "autovérifieras": ("autovérifier",),
    "autovérifièrent": ("autovérifier",),
    "autovérifierez": ("autovérifier",),
    "autovérifieriez": ("autovérifier",),
    "autovérifierions": ("autovérifier",),
    "autovérifierons": ("autovérifier",),
    "autovérifieront": ("autovérifier",),
    "autovérifiés": ("autovérifier",),
    "autovérifies": ("autovérifier",),
    "autovérifiez": ("autovérifier",),
    "autovérifiiez": ("autovérifier",),
    "autovérifiions": ("autovérifier",),
    "autovérifions": ("autovérifier",),
    "avachie": ("avachir",),
    "avachies": ("avachir",),
    "avachi": ("avachir",),
    "avachîmes": ("avachir",),
    "avachira": ("avachir",),
    "avachiraient": ("avachir",),
    "avachirai": ("avachir",),
    "avachirais": ("avachir",),
    "avachirait": ("avachir",),
    "avachiras": ("avachir",),
    "avachirent": ("avachir",),
    "avachirez": ("avachir",),
    "avachiriez": ("avachir",),
    "avachirions": ("avachir",),
    "avachirons": ("avachir",),
    "avachiront": ("avachir",),
    "avachis": ("avachir",),
    "avachissaient": ("avachir",),
    "avachissais": ("avachir",),
    "avachissait": ("avachir",),
    "avachissant": ("avachir",),
    "avachissent": ("avachir",),
    "avachisse": ("avachir",),
    "avachisses": ("avachir",),
    "avachissez": ("avachir",),
    "avachissiez": ("avachir",),
    "avachissions": ("avachir",),
    "avachissons": ("avachir",),
    "avachîtes": ("avachir",),
    "avachit": ("avachir",),
    "avachît": ("avachir",),
    "avançaient": ("avancer",),
    "avançai": ("avancer",),
    "avançais": ("avancer",),
    "avançait": ("avancer",),
    "avança": ("avancer",),
    "avançâmes": ("avancer",),
    "avançant": ("avancer",),
    "avanças": ("avancer",),
    "avançassent": ("avancer",),
    "avançasses": ("avancer",),
    "avançasse": ("avancer",),
    "avançassiez": ("avancer",),
    "avançassions": ("avancer",),
    "avançâtes": ("avancer",),
    "avançât": ("avancer",),
    "avancée": ("avancer",),
    "avancées": ("avancer",),
    "avancé": ("avancer",),
    "avancent": ("avancer",),
    "avance": ("avancer",),
    "avancera": ("avancer",),
    "avanceraient": ("avancer",),
    "avancerai": ("avancer",),
    "avancerais": ("avancer",),
    "avancerait": ("avancer",),
    "avanceras": ("avancer",),
    "avancèrent": ("avancer",),
    "avancerez": ("avancer",),
    "avanceriez": ("avancer",),
    "avancerions": ("avancer",),
    "avancerons": ("avancer",),
    "avanceront": ("avancer",),
    "avancés": ("avancer",),
    "avances": ("avancer",),
    "avancez": ("avancer",),
    "avanciez": ("avancer",),
    "avancions": ("avancer",),
    "avançons": ("avancer",),
    "avantageaient": ("avantager",),
    "avantageai": ("avantager",),
    "avantageais": ("avantager",),
    "avantageait": ("avantager",),
    "avantagea": ("avantager",),
    "avantageâmes": ("avantager",),
    "avantageant": ("avantager",),
    "avantageas": ("avantager",),
    "avantageassent": ("avantager",),
    "avantageasses": ("avantager",),
    "avantageasse": ("avantager",),
    "avantageassiez": ("avantager",),
    "avantageassions": ("avantager",),
    "avantageâtes": ("avantager",),
    "avantageât": ("avantager",),
    "avantagée": ("avantager",),
    "avantagées": ("avantager",),
    "avantagé": ("avantager",),
    "avantagent": ("avantager",),
    "avantageons": ("avantager",),
    "avantage": ("avantager",),
    "avantagera": ("avantager",),
    "avantageraient": ("avantager",),
    "avantagerai": ("avantager",),
    "avantagerais": ("avantager",),
    "avantagerait": ("avantager",),
    "avantageras": ("avantager",),
    "avantagèrent": ("avantager",),
    "avantagerez": ("avantager",),
    "avantageriez": ("avantager",),
    "avantagerions": ("avantager",),
    "avantagerons": ("avantager",),
    "avantageront": ("avantager",),
    "avantagés": ("avantager",),
    "avantages": ("avantager",),
    "avantagez": ("avantager",),
    "avantagiez": ("avantager",),
    "avantagions": ("avantager",),
    "avariaient": ("avarier",),
    "avariai": ("avarier",),
    "avariais": ("avarier",),
    "avariait": ("avarier",),
    "avaria": ("avarier",),
    "avariâmes": ("avarier",),
    "avariant": ("avarier",),
    "avarias": ("avarier",),
    "avariassent": ("avarier",),
    "avariasses": ("avarier",),
    "avariasse": ("avarier",),
    "avariassiez": ("avarier",),
    "avariassions": ("avarier",),
    "avariâtes": ("avarier",),
    "avariât": ("avarier",),
    "avariée": ("avarier",),
    "avariées": ("avarier",),
    "avarié": ("avarier",),
    "avarient": ("avarier",),
    "avarie": ("avarier",),
    "avariera": ("avarier",),
    "avarieraient": ("avarier",),
    "avarierai": ("avarier",),
    "avarierais": ("avarier",),
    "avarierait": ("avarier",),
    "avarieras": ("avarier",),
    "avarièrent": ("avarier",),
    "avarierez": ("avarier",),
    "avarieriez": ("avarier",),
    "avarierions": ("avarier",),
    "avarierons": ("avarier",),
    "avarieront": ("avarier",),
    "avariés": ("avarier",),
    "avaries": ("avarier",),
    "avariez": ("avarier",),
    "avariiez": ("avarier",),
    "avariions": ("avarier",),
    "avarions": ("avarier",),
    "aveignaient": ("aveindre",),
    "aveignais": ("aveindre",),
    "aveignait": ("aveindre",),
    "aveignant": ("aveindre",),
    "aveignent": ("aveindre",),
    "aveigne": ("aveindre",),
    "aveignes": ("aveindre",),
    "aveignez": ("aveindre",),
    "aveigniez": ("aveindre",),
    "aveignîmes": ("aveindre",),
    "aveignions": ("aveindre",),
    "aveignirent": ("aveindre",),
    "aveignis": ("aveindre",),
    "aveignissent": ("aveindre",),
    "aveignisses": ("aveindre",),
    "aveignisse": ("aveindre",),
    "aveignissiez": ("aveindre",),
    "aveignissions": ("aveindre",),
    "aveignîtes": ("aveindre",),
    "aveignit": ("aveindre",),
    "aveignît": ("aveindre",),
    "aveignons": ("aveindre",),
    "aveindra": ("aveindre",),
    "aveindraient": ("aveindre",),
    "aveindrai": ("aveindre",),
    "aveindrais": ("aveindre",),
    "aveindrait": ("aveindre",),
    "aveindras": ("aveindre",),
    "aveindrez": ("aveindre",),
    "aveindriez": ("aveindre",),
    "aveindrions": ("aveindre",),
    "aveindrons": ("aveindre",),
    "aveindront": ("aveindre",),
    "aveins": ("aveindre",),
    "aveinte": ("aveindre",),
    "aveintes": ("aveindre",),
    "aveint": ("aveindre",),
    "aveints": ("aveindre",),
    "avéraient": ("avérer",),
    "avérait": ("avérer",),
    "avéra": ("avérer",),
    "avérant": ("avérer",),
    "avérassent": ("avérer",),
    "avérât": ("avérer",),
    "avérée": ("avérer",),
    "avérées": ("avérer",),
    "avéré": ("avérer",),
    "avèrent": ("avérer",),
    "avère": ("avérer",),
    "avérera": ("avérer",),
    "avéreraient": ("avérer",),
    "avérerait": ("avérer",),
    "avérèrent": ("avérer",),
    "avéreront": ("avérer",),
    "avérés": ("avérer",),
    "avertie": ("avertir",),
    "averties": ("avertir",),
    "averti": ("avertir",),
    "avertîmes": ("avertir",),
    "avertira": ("avertir",),
    "avertiraient": ("avertir",),
    "avertirai": ("avertir",),
    "avertirais": ("avertir",),
    "avertirait": ("avertir",),
    "avertiras": ("avertir",),
    "avertirent": ("avertir",),
    "avertirez": ("avertir",),
    "avertiriez": ("avertir",),
    "avertirions": ("avertir",),
    "avertirons": ("avertir",),
    "avertiront": ("avertir",),
    "avertis": ("avertir",),
    "avertissaient": ("avertir",),
    "avertissais": ("avertir",),
    "avertissait": ("avertir",),
    "avertissant": ("avertir",),
    "avertissent": ("avertir",),
    "avertisse": ("avertir",),
    "avertisses": ("avertir",),
    "avertissez": ("avertir",),
    "avertissiez": ("avertir",),
    "avertissions": ("avertir",),
    "avertissons": ("avertir",),
    "avertîtes": ("avertir",),
    "avertit": ("avertir",),
    "avertît": ("avertir",),
    "aveulie": ("aveulir",),
    "aveulies": ("aveulir",),
    "aveuli": ("aveulir",),
    "aveulîmes": ("aveulir",),
    "aveulira": ("aveulir",),
    "aveuliraient": ("aveulir",),
    "aveulirai": ("aveulir",),
    "aveulirais": ("aveulir",),
    "aveulirait": ("aveulir",),
    "aveuliras": ("aveulir",),
    "aveulirent": ("aveulir",),
    "aveulirez": ("aveulir",),
    "aveuliriez": ("aveulir",),
    "aveulirions": ("aveulir",),
    "aveulirons": ("aveulir",),
    "aveuliront": ("aveulir",),
    "aveulis": ("aveulir",),
    "aveulissaient": ("aveulir",),
    "aveulissais": ("aveulir",),
    "aveulissait": ("aveulir",),
    "aveulissant": ("aveulir",),
    "aveulissent": ("aveulir",),
    "aveulisse": ("aveulir",),
    "aveulisses": ("aveulir",),
    "aveulissez": ("aveulir",),
    "aveulissiez": ("aveulir",),
    "aveulissions": ("aveulir",),
    "aveulissons": ("aveulir",),
    "aveulîtes": ("aveulir",),
    "aveulit": ("aveulir",),
    "aveulît": ("aveulir",),
    "avilie": ("avilir",),
    "avilies": ("avilir",),
    "avili": ("avilir",),
    "avilîmes": ("avilir",),
    "avilira": ("avilir",),
    "aviliraient": ("avilir",),
    "avilirai": ("avilir",),
    "avilirais": ("avilir",),
    "avilirait": ("avilir",),
    "aviliras": ("avilir",),
    "avilirent": ("avilir",),
    "avilirez": ("avilir",),
    "aviliriez": ("avilir",),
    "avilirions": ("avilir",),
    "avilirons": ("avilir",),
    "aviliront": ("avilir",),
    "avilis": ("avilir",),
    "avilissaient": ("avilir",),
    "avilissais": ("avilir",),
    "avilissait": ("avilir",),
    "avilissant": ("avilir",),
    "avilissent": ("avilir",),
    "avilisse": ("avilir",),
    "avilisses": ("avilir",),
    "avilissez": ("avilir",),
    "avilissiez": ("avilir",),
    "avilissions": ("avilir",),
    "avilissons": ("avilir",),
    "avilîtes": ("avilir",),
    "avilit": ("avilir",),
    "avilît": ("avilir",),
    "avie": ("avir",),
    "avies": ("avir",),
    "avi": ("avir",),
    "avîmes": ("avir",),
    "avira": ("avir",),
    "aviraient": ("avir",),
    "avirai": ("avir",),
    "avirais": ("avir",),
    "avirait": ("avir",),
    "aviras": ("avir",),
    "avirent": ("avir",),
    "avirez": ("avir",),
    "aviriez": ("avir",),
    "avirions": ("avir",),
    "avirons": ("avir",),
    "aviront": ("avir",),
    "avis": ("avir",),
    "avissaient": ("avir",),
    "avissais": ("avir",),
    "avissait": ("avir",),
    "avissant": ("avir",),
    "avissent": ("avir",),
    "avisse": ("avir",),
    "avisses": ("avir",),
    "avissez": ("avir",),
    "avissiez": ("avir",),
    "avissions": ("avir",),
    "avissons": ("avir",),
    "avîtes": ("avir",),
    "avit": ("avir",),
    "avît": ("avir",),
    "avocassaient": ("avocasser",),
    "avocassai": ("avocasser",),
    "avocassais": ("avocasser",),
    "avocassait": ("avocasser",),
    "avocassa": ("avocasser",),
    "avocassâmes": ("avocasser",),
    "avocassant": ("avocasser",),
    "avocassas": ("avocasser",),
    "avocassassent": ("avocasser",),
    "avocassasses": ("avocasser",),
    "avocassasse": ("avocasser",),
    "avocassassiez": ("avocasser",),
    "avocassassions": ("avocasser",),
    "avocassâtes": ("avocasser",),
    "avocassât": ("avocasser",),
    "avocassée": ("avocasser",),
    "avocassées": ("avocasser",),
    "avocassé": ("avocasser",),
    "avocassent": ("avocasser",),
    "avocasse": ("avocasser",),
    "avocassera": ("avocasser",),
    "avocasseraient": ("avocasser",),
    "avocasserai": ("avocasser",),
    "avocasserais": ("avocasser",),
    "avocasserait": ("avocasser",),
    "avocasseras": ("avocasser",),
    "avocassèrent": ("avocasser",),
    "avocasserez": ("avocasser",),
    "avocasseriez": ("avocasser",),
    "avocasserions": ("avocasser",),
    "avocasserons": ("avocasser",),
    "avocasseront": ("avocasser",),
    "avocassés": ("avocasser",),
    "avocasses": ("avocasser",),
    "avocassez": ("avocasser",),
    "avocassiez": ("avocasser",),
    "avocassions": ("avocasser",),
    "avocassons": ("avocasser",),
    "aient": ("avoir",),
    "aie": ("avoir",),
    "aies": ("avoir",),
    "ai": ("avoir",),
    "ait": ("avoir",),
    "a": ("avoir",),
    "as": ("avoir",),
    "aura": ("avoir",),
    "auraient": ("avoir",),
    "aurai": ("avoir",),
    "aurais": ("avoir",),
    "aurait": ("avoir",),
    "auras": ("avoir",),
    "aurez": ("avoir",),
    "auriez": ("avoir",),
    "aurions": ("avoir",),
    "aurons": ("avoir",),
    "auront": ("avoir",),
    "avaient": ("avoir",),
    "avais": ("avoir",),
    "avait": ("avoir",),
    "avez": ("avoir",),
    "aviez": ("avoir",),
    "avions": ("avoir",),
    "avons": ("avoir",),
    "ayant": ("avoir",),
    "ayez": ("avoir",),
    "ayons": ("avoir",),
    "eue": ("avoir",),
    "eues": ("avoir",),
    "eu": ("avoir",),
    "eûmes": ("avoir",),
    "eurent": ("avoir",),
    "eus": ("avoir",),
    "eussent": ("avoir",),
    "eusses": ("avoir",),
    "eusse": ("avoir",),
    "eussé": ("avoir",),
    "eussiez": ("avoir",),
    "eussions": ("avoir",),
    "eûtes": ("avoir",),
    "eut": ("avoir",),
    "eût": ("avoir",),
    "ont": ("avoir",),
    "avoient": ("avoyer",),
    "avoie": ("avoyer",),
    "avoiera": ("avoyer",),
    "avoieraient": ("avoyer",),
    "avoierai": ("avoyer",),
    "avoierais": ("avoyer",),
    "avoierait": ("avoyer",),
    "avoieras": ("avoyer",),
    "avoierez": ("avoyer",),
    "avoieriez": ("avoyer",),
    "avoierions": ("avoyer",),
    "avoierons": ("avoyer",),
    "avoieront": ("avoyer",),
    "avoies": ("avoyer",),
    "avoyaient": ("avoyer",),
    "avoyai": ("avoyer",),
    "avoyais": ("avoyer",),
    "avoyait": ("avoyer",),
    "avoya": ("avoyer",),
    "avoyâmes": ("avoyer",),
    "avoyant": ("avoyer",),
    "avoyas": ("avoyer",),
    "avoyassent": ("avoyer",),
    "avoyasses": ("avoyer",),
    "avoyasse": ("avoyer",),
    "avoyassiez": ("avoyer",),
    "avoyassions": ("avoyer",),
    "avoyâtes": ("avoyer",),
    "avoyât": ("avoyer",),
    "avoyée": ("avoyer",),
    "avoyées": ("avoyer",),
    "avoyé": ("avoyer",),
    "avoyèrent": ("avoyer",),
    "avoyés": ("avoyer",),
    "avoyez": ("avoyer",),
    "avoyiez": ("avoyer",),
    "avoyions": ("avoyer",),
    "avoyons": ("avoyer",),
    "badgeaient": ("badger",),
    "badgeai": ("badger",),
    "badgeais": ("badger",),
    "badgeait": ("badger",),
    "badgea": ("badger",),
    "badgeâmes": ("badger",),
    "badgeant": ("badger",),
    "badgeas": ("badger",),
    "badgeassent": ("badger",),
    "badgeasses": ("badger",),
    "badgeasse": ("badger",),
    "badgeassiez": ("badger",),
    "badgeassions": ("badger",),
    "badgeâtes": ("badger",),
    "badgeât": ("badger",),
    "badgée": ("badger",),
    "badgées": ("badger",),
    "badgé": ("badger",),
    "badgent": ("badger",),
    "badgeons": ("badger",),
    "badge": ("badger",),
    "badgera": ("badger",),
    "badgeraient": ("badger",),
    "badgerai": ("badger",),
    "badgerais": ("badger",),
    "badgerait": ("badger",),
    "badgeras": ("badger",),
    "badgèrent": ("badger",),
    "badgerez": ("badger",),
    "badgeriez": ("badger",),
    "badgerions": ("badger",),
    "badgerons": ("badger",),
    "badgeront": ("badger",),
    "badgés": ("badger",),
    "badges": ("badger",),
    "badgez": ("badger",),
    "badgiez": ("badger",),
    "badgions": ("badger",),
    "balançaient": ("balancer",),
    "balançai": ("balancer",),
    "balançais": ("balancer",),
    "balançait": ("balancer",),
    "balança": ("balancer",),
    "balançâmes": ("balancer",),
    "balançant": ("balancer",),
    "balanças": ("balancer",),
    "balançassent": ("balancer",),
    "balançasses": ("balancer",),
    "balançasse": ("balancer",),
    "balançassiez": ("balancer",),
    "balançassions": ("balancer",),
    "balançâtes": ("balancer",),
    "balançât": ("balancer",),
    "balancée": ("balancer",),
    "balancées": ("balancer",),
    "balancé": ("balancer",),
    "balancent": ("balancer",),
    "balance": ("balancer",),
    "balancera": ("balancer",),
    "balanceraient": ("balancer",),
    "balancerai": ("balancer",),
    "balancerais": ("balancer",),
    "balancerait": ("balancer",),
    "balanceras": ("balancer",),
    "balancèrent": ("balancer",),
    "balancerez": ("balancer",),
    "balanceriez": ("balancer",),
    "balancerions": ("balancer",),
    "balancerons": ("balancer",),
    "balanceront": ("balancer",),
    "balancés": ("balancer",),
    "balances": ("balancer",),
    "balancez": ("balancer",),
    "balanciez": ("balancer",),
    "balancions": ("balancer",),
    "balançons": ("balancer",),
    "balaient": ("balayer",),
    "balaie": ("balayer",),
    "balaiera": ("balayer",),
    "balaieraient": ("balayer",),
    "balaierai": ("balayer",),
    "balaierais": ("balayer",),
    "balaierait": ("balayer",),
    "balaieras": ("balayer",),
    "balaierez": ("balayer",),
    "balaieriez": ("balayer",),
    "balaierions": ("balayer",),
    "balaierons": ("balayer",),
    "balaieront": ("balayer",),
    "balaies": ("balayer",),
    "balayaient": ("balayer",),
    "balayai": ("balayer",),
    "balayais": ("balayer",),
    "balayait": ("balayer",),
    "balaya": ("balayer",),
    "balayâmes": ("balayer",),
    "balayant": ("balayer",),
    "balayas": ("balayer",),
    "balayassent": ("balayer",),
    "balayasses": ("balayer",),
    "balayasse": ("balayer",),
    "balayassiez": ("balayer",),
    "balayassions": ("balayer",),
    "balayâtes": ("balayer",),
    "balayât": ("balayer",),
    "balayée": ("balayer",),
    "balayées": ("balayer",),
    "balayé": ("balayer",),
    "balayent": ("balayer",),
    "balaye": ("balayer",),
    "balayera": ("balayer",),
    "balayeraient": ("balayer",),
    "balayerai": ("balayer",),
    "balayerais": ("balayer",),
    "balayerait": ("balayer",),
    "balayeras": ("balayer",),
    "balayèrent": ("balayer",),
    "balayerez": ("balayer",),
    "balayeriez": ("balayer",),
    "balayerions": ("balayer",),
    "balayerons": ("balayer",),
    "balayeront": ("balayer",),
    "balayés": ("balayer",),
    "balayes": ("balayer",),
    "balayez": ("balayer",),
    "balayiez": ("balayer",),
    "balayions": ("balayer",),
    "balayons": ("balayer",),
    "balbutiaient": ("balbutier",),
    "balbutiai": ("balbutier",),
    "balbutiais": ("balbutier",),
    "balbutiait": ("balbutier",),
    "balbutia": ("balbutier",),
    "balbutiâmes": ("balbutier",),
    "balbutiant": ("balbutier",),
    "balbutias": ("balbutier",),
    "balbutiassent": ("balbutier",),
    "balbutiasses": ("balbutier",),
    "balbutiasse": ("balbutier",),
    "balbutiassiez": ("balbutier",),
    "balbutiassions": ("balbutier",),
    "balbutiâtes": ("balbutier",),
    "balbutiât": ("balbutier",),
    "balbutiée": ("balbutier",),
    "balbutiées": ("balbutier",),
    "balbutié": ("balbutier",),
    "balbutient": ("balbutier",),
    "balbutie": ("balbutier",),
    "balbutiera": ("balbutier",),
    "balbutieraient": ("balbutier",),
    "balbutierai": ("balbutier",),
    "balbutierais": ("balbutier",),
    "balbutierait": ("balbutier",),
    "balbutieras": ("balbutier",),
    "balbutièrent": ("balbutier",),
    "balbutierez": ("balbutier",),
    "balbutieriez": ("balbutier",),
    "balbutierions": ("balbutier",),
    "balbutierons": ("balbutier",),
    "balbutieront": ("balbutier",),
    "balbutiés": ("balbutier",),
    "balbuties": ("balbutier",),
    "balbutiez": ("balbutier",),
    "balbutiiez": ("balbutier",),
    "balbutiions": ("balbutier",),
    "balbutions": ("balbutier",),
    "bannie": ("bannir",),
    "bannies": ("bannir",),
    "banni": ("bannir",),
    "bannîmes": ("bannir",),
    "bannira": ("bannir",),
    "banniraient": ("bannir",),
    "bannirai": ("bannir",),
    "bannirais": ("bannir",),
    "bannirait": ("bannir",),
    "banniras": ("bannir",),
    "bannirent": ("bannir",),
    "bannirez": ("bannir",),
    "banniriez": ("bannir",),
    "bannirions": ("bannir",),
    "bannirons": ("bannir",),
    "banniront": ("bannir",),
    "bannis": ("bannir",),
    "bannissaient": ("bannir",),
    "bannissais": ("bannir",),
    "bannissait": ("bannir",),
    "bannissant": ("bannir",),
    "bannissent": ("bannir",),
    "bannisse": ("bannir",),
    "bannisses": ("bannir",),
    "bannissez": ("bannir",),
    "bannissiez": ("bannir",),
    "bannissions": ("bannir",),
    "bannissons": ("bannir",),
    "bannîtes": ("bannir",),
    "bannit": ("bannir",),
    "bannît": ("bannir",),
    "banquetaient": ("banqueter",),
    "banquetai": ("banqueter",),
    "banquetais": ("banqueter",),
    "banquetait": ("banqueter",),
    "banqueta": ("banqueter",),
    "banquetâmes": ("banqueter",),
    "banquetant": ("banqueter",),
    "banquetas": ("banqueter",),
    "banquetassent": ("banqueter",),
    "banquetasses": ("banqueter",),
    "banquetasse": ("banqueter",),
    "banquetassiez": ("banqueter",),
    "banquetassions": ("banqueter",),
    "banquetâtes": ("banqueter",),
    "banquetât": ("banqueter",),
    "banqueté": ("banqueter",),
    "banquetèrent": ("banqueter",),
    "banquetez": ("banqueter",),
    "banquetiez": ("banqueter",),
    "banquetions": ("banqueter",),
    "banquetons": ("banqueter",),
    "banquettent": ("banqueter",),
    "banquette": ("banqueter",),
    "banquettera": ("banqueter",),
    "banquetteraient": ("banqueter",),
    "banquetterai": ("banqueter",),
    "banquetterais": ("banqueter",),
    "banquetterait": ("banqueter",),
    "banquetteras": ("banqueter",),
    "banquetterez": ("banqueter",),
    "banquetteriez": ("banqueter",),
    "banquetterions": ("banqueter",),
    "banquetterons": ("banqueter",),
    "banquetteront": ("banqueter",),
    "banquettes": ("banqueter",),
    "baquetaient": ("baqueter",),
    "baquetai": ("baqueter",),
    "baquetais": ("baqueter",),
    "baquetait": ("baqueter",),
    "baqueta": ("baqueter",),
    "baquetâmes": ("baqueter",),
    "baquetant": ("baqueter",),
    "baquetas": ("baqueter",),
    "baquetassent": ("baqueter",),
    "baquetasses": ("baqueter",),
    "baquetasse": ("baqueter",),
    "baquetassiez": ("baqueter",),
    "baquetassions": ("baqueter",),
    "baquetâtes": ("baqueter",),
    "baquetât": ("baqueter",),
    "baquetée": ("baqueter",),
    "baquetées": ("baqueter",),
    "baqueté": ("baqueter",),
    "baquetèrent": ("baqueter",),
    "baquetés": ("baqueter",),
    "baquetez": ("baqueter",),
    "baquetiez": ("baqueter",),
    "baquetions": ("baqueter",),
    "baquetons": ("baqueter",),
    "baquettent": ("baqueter",),
    "baquette": ("baqueter",),
    "baquettera": ("baqueter",),
    "baquetteraient": ("baqueter",),
    "baquetterai": ("baqueter",),
    "baquetterais": ("baqueter",),
    "baquetterait": ("baqueter",),
    "baquetteras": ("baqueter",),
    "baquetterez": ("baqueter",),
    "baquetteriez": ("baqueter",),
    "baquetterions": ("baqueter",),
    "baquetterons": ("baqueter",),
    "baquetteront": ("baqueter",),
    "baquettes": ("baqueter",),
    "barbelaient": ("barbeler",),
    "barbelai": ("barbeler",),
    "barbelais": ("barbeler",),
    "barbelait": ("barbeler",),
    "barbela": ("barbeler",),
    "barbelâmes": ("barbeler",),
    "barbelant": ("barbeler",),
    "barbelas": ("barbeler",),
    "barbelassent": ("barbeler",),
    "barbelasses": ("barbeler",),
    "barbelasse": ("barbeler",),
    "barbelassiez": ("barbeler",),
    "barbelassions": ("barbeler",),
    "barbelâtes": ("barbeler",),
    "barbelât": ("barbeler",),
    "barbelée": ("barbeler",),
    "barbelées": ("barbeler",),
    "barbelé": ("barbeler",),
    "barbèlent": ("barbeler",),
    "barbèle": ("barbeler",),
    "barbèlera": ("barbeler",),
    "barbèleraient": ("barbeler",),
    "barbèlerai": ("barbeler",),
    "barbèlerais": ("barbeler",),
    "barbèlerait": ("barbeler",),
    "barbèleras": ("barbeler",),
    "barbelèrent": ("barbeler",),
    "barbèlerez": ("barbeler",),
    "barbèleriez": ("barbeler",),
    "barbèlerions": ("barbeler",),
    "barbèlerons": ("barbeler",),
    "barbèleront": ("barbeler",),
    "barbelés": ("barbeler",),
    "barbèles": ("barbeler",),
    "barbelez": ("barbeler",),
    "barbeliez": ("barbeler",),
    "barbelions": ("barbeler",),
    "barbelons": ("barbeler",),
    "barbifiaient": ("barbifier",),
    "barbifiai": ("barbifier",),
    "barbifiais": ("barbifier",),
    "barbifiait": ("barbifier",),
    "barbifia": ("barbifier",),
    "barbifiâmes": ("barbifier",),
    "barbifiant": ("barbifier",),
    "barbifias": ("barbifier",),
    "barbifiassent": ("barbifier",),
    "barbifiasses": ("barbifier",),
    "barbifiasse": ("barbifier",),
    "barbifiassiez": ("barbifier",),
    "barbifiassions": ("barbifier",),
    "barbifiâtes": ("barbifier",),
    "barbifiât": ("barbifier",),
    "barbifiée": ("barbifier",),
    "barbifiées": ("barbifier",),
    "barbifié": ("barbifier",),
    "barbifient": ("barbifier",),
    "barbifie": ("barbifier",),
    "barbifiera": ("barbifier",),
    "barbifieraient": ("barbifier",),
    "barbifierai": ("barbifier",),
    "barbifierais": ("barbifier",),
    "barbifierait": ("barbifier",),
    "barbifieras": ("barbifier",),
    "barbifièrent": ("barbifier",),
    "barbifierez": ("barbifier",),
    "barbifieriez": ("barbifier",),
    "barbifierions": ("barbifier",),
    "barbifierons": ("barbifier",),
    "barbifieront": ("barbifier",),
    "barbifiés": ("barbifier",),
    "barbifies": ("barbifier",),
    "barbifiez": ("barbifier",),
    "barbifiiez": ("barbifier",),
    "barbifiions": ("barbifier",),
    "barbifions": ("barbifier",),
    "bardassaient": ("bardasser",),
    "bardassai": ("bardasser",),
    "bardassais": ("bardasser",),
    "bardassait": ("bardasser",),
    "bardassa": ("bardasser",),
    "bardassâmes": ("bardasser",),
    "bardassant": ("bardasser",),
    "bardassas": ("bardasser",),
    "bardassassent": ("bardasser",),
    "bardassasses": ("bardasser",),
    "bardassasse": ("bardasser",),
    "bardassassiez": ("bardasser",),
    "bardassassions": ("bardasser",),
    "bardassâtes": ("bardasser",),
    "bardassât": ("bardasser",),
    "bardassée": ("bardasser",),
    "bardassées": ("bardasser",),
    "bardassé": ("bardasser",),
    "bardassent": ("bardasser",),
    "bardasse": ("bardasser",),
    "bardassera": ("bardasser",),
    "bardasseraient": ("bardasser",),
    "bardasserai": ("bardasser",),
    "bardasserais": ("bardasser",),
    "bardasserait": ("bardasser",),
    "bardasseras": ("bardasser",),
    "bardassèrent": ("bardasser",),
    "bardasserez": ("bardasser",),
    "bardasseriez": ("bardasser",),
    "bardasserions": ("bardasser",),
    "bardasserons": ("bardasser",),
    "bardasseront": ("bardasser",),
    "bardassés": ("bardasser",),
    "bardasses": ("bardasser",),
    "bardassez": ("bardasser",),
    "bardassiez": ("bardasser",),
    "bardassions": ("bardasser",),
    "bardassons": ("bardasser",),
    "barémaient": ("barémer",),
    "barémai": ("barémer",),
    "barémais": ("barémer",),
    "barémait": ("barémer",),
    "baréma": ("barémer",),
    "barémâmes": ("barémer",),
    "barémant": ("barémer",),
    "barémas": ("barémer",),
    "barémassent": ("barémer",),
    "barémasses": ("barémer",),
    "barémasse": ("barémer",),
    "barémassiez": ("barémer",),
    "barémassions": ("barémer",),
    "barémâtes": ("barémer",),
    "barémât": ("barémer",),
    "barémée": ("barémer",),
    "barémées": ("barémer",),
    "barémé": ("barémer",),
    "barèment": ("barémer",),
    "barème": ("barémer",),
    "barémera": ("barémer",),
    "barémeraient": ("barémer",),
    "barémerai": ("barémer",),
    "barémerais": ("barémer",),
    "barémerait": ("barémer",),
    "barémeras": ("barémer",),
    "barémèrent": ("barémer",),
    "barémerez": ("barémer",),
    "barémeriez": ("barémer",),
    "barémerions": ("barémer",),
    "barémerons": ("barémer",),
    "barémeront": ("barémer",),
    "barémés": ("barémer",),
    "barèmes": ("barémer",),
    "barémez": ("barémer",),
    "barémiez": ("barémer",),
    "barémions": ("barémer",),
    "barémons": ("barémer",),
    "barétaient": ("baréter",),
    "barétai": ("baréter",),
    "barétais": ("baréter",),
    "barétait": ("baréter",),
    "baréta": ("baréter",),
    "barétâmes": ("baréter",),
    "barétant": ("baréter",),
    "barétas": ("baréter",),
    "barétassent": ("baréter",),
    "barétasses": ("baréter",),
    "barétasse": ("baréter",),
    "barétassiez": ("baréter",),
    "barétassions": ("baréter",),
    "barétâtes": ("baréter",),
    "barétât": ("baréter",),
    "barété": ("baréter",),
    "barètent": ("baréter",),
    "barète": ("baréter",),
    "barétera": ("baréter",),
    "baréteraient": ("baréter",),
    "baréterai": ("baréter",),
    "baréterais": ("baréter",),
    "baréterait": ("baréter",),
    "baréteras": ("baréter",),
    "barétèrent": ("baréter",),
    "baréterez": ("baréter",),
    "baréteriez": ("baréter",),
    "baréterions": ("baréter",),
    "baréterons": ("baréter",),
    "baréteront": ("baréter",),
    "barètes": ("baréter",),
    "barétez": ("baréter",),
    "barétiez": ("baréter",),
    "barétions": ("baréter",),
    "barétons": ("baréter",),
    "baronifiaient": ("baronifier",),
    "baronifiai": ("baronifier",),
    "baronifiais": ("baronifier",),
    "baronifiait": ("baronifier",),
    "baronifia": ("baronifier",),
    "baronifiâmes": ("baronifier",),
    "baronifiant": ("baronifier",),
    "baronifias": ("baronifier",),
    "baronifiassent": ("baronifier",),
    "baronifiasses": ("baronifier",),
    "baronifiasse": ("baronifier",),
    "baronifiassiez": ("baronifier",),
    "baronifiassions": ("baronifier",),
    "baronifiâtes": ("baronifier",),
    "baronifiât": ("baronifier",),
    "baronifiée": ("baronifier",),
    "baronifiées": ("baronifier",),
    "baronifié": ("baronifier",),
    "baronifient": ("baronifier",),
    "baronifie": ("baronifier",),
    "baronifiera": ("baronifier",),
    "baronifieraient": ("baronifier",),
    "baronifierai": ("baronifier",),
    "baronifierais": ("baronifier",),
    "baronifierait": ("baronifier",),
    "baronifieras": ("baronifier",),
    "baronifièrent": ("baronifier",),
    "baronifierez": ("baronifier",),
    "baronifieriez": ("baronifier",),
    "baronifierions": ("baronifier",),
    "baronifierons": ("baronifier",),
    "baronifieront": ("baronifier",),
    "baronifiés": ("baronifier",),
    "baronifies": ("baronifier",),
    "baronifiez": ("baronifier",),
    "baronifiiez": ("baronifier",),
    "baronifiions": ("baronifier",),
    "baronifions": ("baronifier",),
    "barrie": ("barrir",),
    "barries": ("barrir",),
    "barri": ("barrir",),
    "barrîmes": ("barrir",),
    "barrira": ("barrir",),
    "barriraient": ("barrir",),
    "barrirai": ("barrir",),
    "barrirais": ("barrir",),
    "barrirait": ("barrir",),
    "barriras": ("barrir",),
    "barrirent": ("barrir",),
    "barrirez": ("barrir",),
    "barririez": ("barrir",),
    "barririons": ("barrir",),
    "barrirons": ("barrir",),
    "barriront": ("barrir",),
    "barris": ("barrir",),
    "barrissaient": ("barrir",),
    "barrissais": ("barrir",),
    "barrissait": ("barrir",),
    "barrissant": ("barrir",),
    "barrissent": ("barrir",),
    "barrisse": ("barrir",),
    "barrisses": ("barrir",),
    "barrissez": ("barrir",),
    "barrissiez": ("barrir",),
    "barrissions": ("barrir",),
    "barrissons": ("barrir",),
    "barrîtes": ("barrir",),
    "barrit": ("barrir",),
    "barrît": ("barrir",),
    "basifiaient": ("basifier",),
    "basifiai": ("basifier",),
    "basifiais": ("basifier",),
    "basifiait": ("basifier",),
    "basifia": ("basifier",),
    "basifiâmes": ("basifier",),
    "basifiant": ("basifier",),
    "basifias": ("basifier",),
    "basifiassent": ("basifier",),
    "basifiasses": ("basifier",),
    "basifiasse": ("basifier",),
    "basifiassiez": ("basifier",),
    "basifiassions": ("basifier",),
    "basifiâtes": ("basifier",),
    "basifiât": ("basifier",),
    "basifiée": ("basifier",),
    "basifiées": ("basifier",),
    "basifié": ("basifier",),
    "basifient": ("basifier",),
    "basifie": ("basifier",),
    "basifiera": ("basifier",),
    "basifieraient": ("basifier",),
    "basifierai": ("basifier",),
    "basifierais": ("basifier",),
    "basifierait": ("basifier",),
    "basifieras": ("basifier",),
    "basifièrent": ("basifier",),
    "basifierez": ("basifier",),
    "basifieriez": ("basifier",),
    "basifierions": ("basifier",),
    "basifierons": ("basifier",),
    "basifieront": ("basifier",),
    "basifiés": ("basifier",),
    "basifies": ("basifier",),
    "basifiez": ("basifier",),
    "basifiiez": ("basifier",),
    "basifiions": ("basifier",),
    "basifions": ("basifier",),
    "bastie": ("bastir",),
    "basties": ("bastir",),
    "basti": ("bastir",),
    "bastîmes": ("bastir",),
    "bastira": ("bastir",),
    "bastiraient": ("bastir",),
    "bastirai": ("bastir",),
    "bastirais": ("bastir",),
    "bastirait": ("bastir",),
    "bastiras": ("bastir",),
    "bastirent": ("bastir",),
    "bastirez": ("bastir",),
    "bastiriez": ("bastir",),
    "bastirions": ("bastir",),
    "bastirons": ("bastir",),
    "bastiront": ("bastir",),
    "bastis": ("bastir",),
    "bastissaient": ("bastir",),
    "bastissais": ("bastir",),
    "bastissait": ("bastir",),
    "bastissant": ("bastir",),
    "bastissent": ("bastir",),
    "bastisse": ("bastir",),
    "bastisses": ("bastir",),
    "bastissez": ("bastir",),
    "bastissiez": ("bastir",),
    "bastissions": ("bastir",),
    "bastissons": ("bastir",),
    "bastîtes": ("bastir",),
    "bastit": ("bastir",),
    "bastît": ("bastir",),
    "batelaient": ("bateler",),
    "batelai": ("bateler",),
    "batelais": ("bateler",),
    "batelait": ("bateler",),
    "batela": ("bateler",),
    "batelâmes": ("bateler",),
    "batelant": ("bateler",),
    "batelas": ("bateler",),
    "batelassent": ("bateler",),
    "batelasses": ("bateler",),
    "batelasse": ("bateler",),
    "batelassiez": ("bateler",),
    "batelassions": ("bateler",),
    "batelâtes": ("bateler",),
    "batelât": ("bateler",),
    "batelée": ("bateler",),
    "batelées": ("bateler",),
    "batelé": ("bateler",),
    "batelèrent": ("bateler",),
    "batelés": ("bateler",),
    "batelez": ("bateler",),
    "bateliez": ("bateler",),
    "batelions": ("bateler",),
    "batellent": ("bateler",),
    "batelle": ("bateler",),
    "batellera": ("bateler",),
    "batelleraient": ("bateler",),
    "batellerai": ("bateler",),
    "batellerais": ("bateler",),
    "batellerait": ("bateler",),
    "batelleras": ("bateler",),
    "batellerez": ("bateler",),
    "batelleriez": ("bateler",),
    "batellerions": ("bateler",),
    "batellerons": ("bateler",),
    "batelleront": ("bateler",),
    "batelles": ("bateler",),
    "batelons": ("bateler",),
    "bâtaient": ("bâter",),
    "bâtai": ("bâter",),
    "bâtais": ("bâter",),
    "bâtait": ("bâter",),
    "bâta": ("bâter",),
    "bâtâmes": ("bâter",),
    "bâtant": ("bâter",),
    "bâtas": ("bâter",),
    "bâtassent": ("bâter",),
    "bâtasses": ("bâter",),
    "bâtasse": ("bâter",),
    "bâtassiez": ("bâter",),
    "bâtassions": ("bâter",),
    "bâtâtes": ("bâter",),
    "bâtât": ("bâter",),
    "bâtée": ("bâter",),
    "bâtées": ("bâter",),
    "bâté": ("bâter",),
    "bâtent": ("bâter",),
    "bâte": ("bâter",),
    "bâtera": ("bâter",),
    "bâteraient": ("bâter",),
    "bâterai": ("bâter",),
    "bâterais": ("bâter",),
    "bâterait": ("bâter",),
    "bâteras": ("bâter",),
    "bâtèrent": ("bâter",),
    "bâterez": ("bâter",),
    "bâteriez": ("bâter",),
    "bâterions": ("bâter",),
    "bâterons": ("bâter",),
    "bâteront": ("bâter",),
    "bâtés": ("bâter",),
    "bâtes": ("bâter",),
    "bâtez": ("bâter",),
    "bâtiez": ("bâter",),
    "bâtions": ("bâter",),
    "bâtons": ("bâter",),
    "bâtie": ("bâtir",),
    "bâties": ("bâtir",),
    "bâti": ("bâtir",),
    "bâtîmes": ("bâtir",),
    "bâtira": ("bâtir",),
    "bâtiraient": ("bâtir",),
    "bâtirai": ("bâtir",),
    "bâtirais": ("bâtir",),
    "bâtirait": ("bâtir",),
    "bâtiras": ("bâtir",),
    "bâtirent": ("bâtir",),
    "bâtirez": ("bâtir",),
    "bâtiriez": ("bâtir",),
    "bâtirions": ("bâtir",),
    "bâtirons": ("bâtir",),
    "bâtiront": ("bâtir",),
    "bâtis": ("bâtir",),
    "bâtissaient": ("bâtir",),
    "bâtissais": ("bâtir",),
    "bâtissait": ("bâtir",),
    "bâtissant": ("bâtir",),
    "bâtissent": ("bâtir",),
    "bâtisse": ("bâtir",),
    "bâtisses": ("bâtir",),
    "bâtissez": ("bâtir",),
    "bâtissiez": ("bâtir",),
    "bâtissions": ("bâtir",),
    "bâtissons": ("bâtir",),
    "bâtîtes": ("bâtir",),
    "bâtit": ("bâtir",),
    "bâtît": ("bâtir",),
    "bat": ("battre",),
    "bats": ("battre",),
    "battaient": ("battre",),
    "battais": ("battre",),
    "battait": ("battre",),
    "battant": ("battre",),
    "battent": ("battre",),
    "batte": ("battre",),
    "battes": ("battre",),
    "battez": ("battre",),
    "battiez": ("battre",),
    "battîmes": ("battre",),
    "battions": ("battre",),
    "battirent": ("battre",),
    "battis": ("battre",),
    "battissent": ("battre",),
    "battisses": ("battre",),
    "battisse": ("battre",),
    "battissiez": ("battre",),
    "battissions": ("battre",),
    "battîtes": ("battre",),
    "battit": ("battre",),
    "battît": ("battre",),
    "battons": ("battre",),
    "battra": ("battre",),
    "battraient": ("battre",),
    "battrai": ("battre",),
    "battrais": ("battre",),
    "battrait": ("battre",),
    "battras": ("battre",),
    "battrez": ("battre",),
    "battriez": ("battre",),
    "battrions": ("battre",),
    "battrons": ("battre",),
    "battront": ("battre",),
    "battue": ("battre",),
    "battues": ("battre",),
    "battu": ("battre",),
    "battus": ("battre",),
    "baudie": ("baudir",),
    "baudies": ("baudir",),
    "baudi": ("baudir",),
    "baudîmes": ("baudir",),
    "baudira": ("baudir",),
    "baudiraient": ("baudir",),
    "baudirai": ("baudir",),
    "baudirais": ("baudir",),
    "baudirait": ("baudir",),
    "baudiras": ("baudir",),
    "baudirent": ("baudir",),
    "baudirez": ("baudir",),
    "baudiriez": ("baudir",),
    "baudirions": ("baudir",),
    "baudirons": ("baudir",),
    "baudiront": ("baudir",),
    "baudis": ("baudir",),
    "baudissaient": ("baudir",),
    "baudissais": ("baudir",),
    "baudissait": ("baudir",),
    "baudissant": ("baudir",),
    "baudissent": ("baudir",),
    "baudisse": ("baudir",),
    "baudisses": ("baudir",),
    "baudissez": ("baudir",),
    "baudissiez": ("baudir",),
    "baudissions": ("baudir",),
    "baudissons": ("baudir",),
    "baudîtes": ("baudir",),
    "baudit": ("baudir",),
    "baudît": ("baudir",),
    "baugeaient": ("bauger",),
    "baugeai": ("bauger",),
    "baugeais": ("bauger",),
    "baugeait": ("bauger",),
    "baugea": ("bauger",),
    "baugeâmes": ("bauger",),
    "baugeant": ("bauger",),
    "baugeas": ("bauger",),
    "baugeassent": ("bauger",),
    "baugeasses": ("bauger",),
    "baugeasse": ("bauger",),
    "baugeassiez": ("bauger",),
    "baugeassions": ("bauger",),
    "baugeâtes": ("bauger",),
    "baugeât": ("bauger",),
    "baugée": ("bauger",),
    "baugées": ("bauger",),
    "baugé": ("bauger",),
    "baugent": ("bauger",),
    "baugeons": ("bauger",),
    "bauge": ("bauger",),
    "baugera": ("bauger",),
    "baugeraient": ("bauger",),
    "baugerai": ("bauger",),
    "baugerais": ("bauger",),
    "baugerait": ("bauger",),
    "baugeras": ("bauger",),
    "baugèrent": ("bauger",),
    "baugerez": ("bauger",),
    "baugeriez": ("bauger",),
    "baugerions": ("bauger",),
    "baugerons": ("bauger",),
    "baugeront": ("bauger",),
    "baugés": ("bauger",),
    "bauges": ("bauger",),
    "baugez": ("bauger",),
    "baugiez": ("bauger",),
    "baugions": ("bauger",),
    "bavassaient": ("bavasser",),
    "bavassai": ("bavasser",),
    "bavassais": ("bavasser",),
    "bavassait": ("bavasser",),
    "bavassa": ("bavasser",),
    "bavassâmes": ("bavasser",),
    "bavassant": ("bavasser",),
    "bavassas": ("bavasser",),
    "bavassassent": ("bavasser",),
    "bavassasses": ("bavasser",),
    "bavassasse": ("bavasser",),
    "bavassassiez": ("bavasser",),
    "bavassassions": ("bavasser",),
    "bavassâtes": ("bavasser",),
    "bavassât": ("bavasser",),
    "bavassé": ("bavasser",),
    "bavassent": ("bavasser",),
    "bavasse": ("bavasser",),
    "bavassera": ("bavasser",),
    "bavasseraient": ("bavasser",),
    "bavasserai": ("bavasser",),
    "bavasserais": ("bavasser",),
    "bavasserait": ("bavasser",),
    "bavasseras": ("bavasser",),
    "bavassèrent": ("bavasser",),
    "bavasserez": ("bavasser",),
    "bavasseriez": ("bavasser",),
    "bavasserions": ("bavasser",),
    "bavasserons": ("bavasser",),
    "bavasseront": ("bavasser",),
    "bavasses": ("bavasser",),
    "bavassez": ("bavasser",),
    "bavassiez": ("bavasser",),
    "bavassions": ("bavasser",),
    "bavassons": ("bavasser",),
    "béatifiaient": ("béatifier",),
    "béatifiai": ("béatifier",),
    "béatifiais": ("béatifier",),
    "béatifiait": ("béatifier",),
    "béatifia": ("béatifier",),
    "béatifiâmes": ("béatifier",),
    "béatifiant": ("béatifier",),
    "béatifias": ("béatifier",),
    "béatifiassent": ("béatifier",),
    "béatifiasses": ("béatifier",),
    "béatifiasse": ("béatifier",),
    "béatifiassiez": ("béatifier",),
    "béatifiassions": ("béatifier",),
    "béatifiâtes": ("béatifier",),
    "béatifiât": ("béatifier",),
    "béatifiée": ("béatifier",),
    "béatifiées": ("béatifier",),
    "béatifié": ("béatifier",),
    "béatifient": ("béatifier",),
    "béatifie": ("béatifier",),
    "béatifiera": ("béatifier",),
    "béatifieraient": ("béatifier",),
    "béatifierai": ("béatifier",),
    "béatifierais": ("béatifier",),
    "béatifierait": ("béatifier",),
    "béatifieras": ("béatifier",),
    "béatifièrent": ("béatifier",),
    "béatifierez": ("béatifier",),
    "béatifieriez": ("béatifier",),
    "béatifierions": ("béatifier",),
    "béatifierons": ("béatifier",),
    "béatifieront": ("béatifier",),
    "béatifiés": ("béatifier",),
    "béatifies": ("béatifier",),
    "béatifiez": ("béatifier",),
    "béatifiiez": ("béatifier",),
    "béatifiions": ("béatifier",),
    "béatifions": ("béatifier",),
    "beausie": ("beausir",),
    "beausies": ("beausir",),
    "beausi": ("beausir",),
    "beausîmes": ("beausir",),
    "beausira": ("beausir",),
    "beausiraient": ("beausir",),
    "beausirai": ("beausir",),
    "beausirais": ("beausir",),
    "beausirait": ("beausir",),
    "beausiras": ("beausir",),
    "beausirent": ("beausir",),
    "beausirez": ("beausir",),
    "beausiriez": ("beausir",),
    "beausirions": ("beausir",),
    "beausirons": ("beausir",),
    "beausiront": ("beausir",),
    "beausis": ("beausir",),
    "beausissaient": ("beausir",),
    "beausissais": ("beausir",),
    "beausissait": ("beausir",),
    "beausissant": ("beausir",),
    "beausissent": ("beausir",),
    "beausisse": ("beausir",),
    "beausisses": ("beausir",),
    "beausissez": ("beausir",),
    "beausissiez": ("beausir",),
    "beausissions": ("beausir",),
    "beausissons": ("beausir",),
    "beausîtes": ("beausir",),
    "beausit": ("beausir",),
    "beausît": ("beausir",),
    "bêchevetaient": ("bêcheveter",),
    "bêchevetai": ("bêcheveter",),
    "bêchevetais": ("bêcheveter",),
    "bêchevetait": ("bêcheveter",),
    "bêcheveta": ("bêcheveter",),
    "bêchevetâmes": ("bêcheveter",),
    "bêchevetant": ("bêcheveter",),
    "bêchevetas": ("bêcheveter",),
    "bêchevetassent": ("bêcheveter",),
    "bêchevetasses": ("bêcheveter",),
    "bêchevetasse": ("bêcheveter",),
    "bêchevetassiez": ("bêcheveter",),
    "bêchevetassions": ("bêcheveter",),
    "bêchevetâtes": ("bêcheveter",),
    "bêchevetât": ("bêcheveter",),
    "bêchevetée": ("bêcheveter",),
    "bêchevetées": ("bêcheveter",),
    "bêcheveté": ("bêcheveter",),
    "bêchevetèrent": ("bêcheveter",),
    "bêchevetés": ("bêcheveter",),
    "bêchevetez": ("bêcheveter",),
    "bêchevetiez": ("bêcheveter",),
    "bêchevetions": ("bêcheveter",),
    "bêchevetons": ("bêcheveter",),
    "bêchevettent": ("bêcheveter",),
    "bêchevette": ("bêcheveter",),
    "bêchevettera": ("bêcheveter",),
    "bêchevetteraient": ("bêcheveter",),
    "bêchevetterai": ("bêcheveter",),
    "bêchevetterais": ("bêcheveter",),
    "bêchevetterait": ("bêcheveter",),
    "bêchevetteras": ("bêcheveter",),
    "bêchevetterez": ("bêcheveter",),
    "bêchevetteriez": ("bêcheveter",),
    "bêchevetterions": ("bêcheveter",),
    "bêchevetterons": ("bêcheveter",),
    "bêchevetteront": ("bêcheveter",),
    "bêchevettes": ("bêcheveter",),
    "becquetaient": ("becqueter",),
    "becquetai": ("becqueter",),
    "becquetais": ("becqueter",),
    "becquetait": ("becqueter",),
    "becqueta": ("becqueter",),
    "becquetâmes": ("becqueter",),
    "becquetant": ("becqueter",),
    "becquetas": ("becqueter",),
    "becquetassent": ("becqueter",),
    "becquetasses": ("becqueter",),
    "becquetasse": ("becqueter",),
    "becquetassiez": ("becqueter",),
    "becquetassions": ("becqueter",),
    "becquetâtes": ("becqueter",),
    "becquetât": ("becqueter",),
    "becquetée": ("becqueter",),
    "becquetées": ("becqueter",),
    "becqueté": ("becqueter",),
    "becquetèrent": ("becqueter",),
    "becquetés": ("becqueter",),
    "becquetez": ("becqueter",),
    "becquetiez": ("becqueter",),
    "becquetions": ("becqueter",),
    "becquetons": ("becqueter",),
    "becquettent": ("becqueter",),
    "becquette": ("becqueter",),
    "becquettera": ("becqueter",),
    "becquetteraient": ("becqueter",),
    "becquetterai": ("becqueter",),
    "becquetterais": ("becqueter",),
    "becquetterait": ("becqueter",),
    "becquetteras": ("becqueter",),
    "becquetterez": ("becqueter",),
    "becquetteriez": ("becqueter",),
    "becquetterions": ("becqueter",),
    "becquetterons": ("becqueter",),
    "becquetteront": ("becqueter",),
    "becquettes": ("becqueter",),
    "bedaient": ("beder",),
    "bedai": ("beder",),
    "bedais": ("beder",),
    "bedait": ("beder",),
    "beda": ("beder",),
    "bedâmes": ("beder",),
    "bedant": ("beder",),
    "bedas": ("beder",),
    "bedassent": ("beder",),
    "bedasses": ("beder",),
    "bedasse": ("beder",),
    "bedassiez": ("beder",),
    "bedassions": ("beder",),
    "bedâtes": ("beder",),
    "bedât": ("beder",),
    "bedée": ("beder",),
    "bedées": ("beder",),
    "bedé": ("beder",),
    "bèdent": ("beder",),
    "bède": ("beder",),
    "bèdera": ("beder",),
    "bèderaient": ("beder",),
    "bèderai": ("beder",),
    "bèderais": ("beder",),
    "bèderait": ("beder",),
    "bèderas": ("beder",),
    "bedèrent": ("beder",),
    "bèderez": ("beder",),
    "bèderiez": ("beder",),
    "bèderions": ("beder",),
    "bèderons": ("beder",),
    "bèderont": ("beder",),
    "bedés": ("beder",),
    "bèdes": ("beder",),
    "bedez": ("beder",),
    "bediez": ("beder",),
    "bedions": ("beder",),
    "bedons": ("beder",),
    "béaient": ("béer",),
    "béai": ("béer",),
    "béais": ("béer",),
    "béait": ("béer",),
    "béa": ("béer",),
    "béâmes": ("béer",),
    "béant": ("béer",),
    "béas": ("béer",),
    "béassent": ("béer",),
    "béasses": ("béer",),
    "béasse": ("béer",),
    "béassiez": ("béer",),
    "béassions": ("béer",),
    "béâtes": ("béer",),
    "béât": ("béer",),
    "béé": ("béer",),
    "béent": ("béer",),
    "bée": ("béer",),
    "béera": ("béer",),
    "béeraient": ("béer",),
    "béerai": ("béer",),
    "béerais": ("béer",),
    "béerait": ("béer",),
    "béeras": ("béer",),
    "béèrent": ("béer",),
    "béerez": ("béer",),
    "béeriez": ("béer",),
    "béerions": ("béer",),
    "béerons": ("béer",),
    "béeront": ("béer",),
    "bées": ("béer",),
    "béez": ("béer",),
    "béiez": ("béer",),
    "béions": ("béer",),
    "béons": ("béer",),
    "bégaient": ("bégayer",),
    "bégaie": ("bégayer",),
    "bégaiera": ("bégayer",),
    "bégaieraient": ("bégayer",),
    "bégaierai": ("bégayer",),
    "bégaierais": ("bégayer",),
    "bégaierait": ("bégayer",),
    "bégaieras": ("bégayer",),
    "bégaierez": ("bégayer",),
    "bégaieriez": ("bégayer",),
    "bégaierions": ("bégayer",),
    "bégaierons": ("bégayer",),
    "bégaieront": ("bégayer",),
    "bégaies": ("bégayer",),
    "bégayaient": ("bégayer",),
    "bégayai": ("bégayer",),
    "bégayais": ("bégayer",),
    "bégayait": ("bégayer",),
    "bégaya": ("bégayer",),
    "bégayâmes": ("bégayer",),
    "bégayant": ("bégayer",),
    "bégayas": ("bégayer",),
    "bégayassent": ("bégayer",),
    "bégayasses": ("bégayer",),
    "bégayasse": ("bégayer",),
    "bégayassiez": ("bégayer",),
    "bégayassions": ("bégayer",),
    "bégayâtes": ("bégayer",),
    "bégayât": ("bégayer",),
    "bégayée": ("bégayer",),
    "bégayées": ("bégayer",),
    "bégayé": ("bégayer",),
    "bégayent": ("bégayer",),
    "bégaye": ("bégayer",),
    "bégayera": ("bégayer",),
    "bégayeraient": ("bégayer",),
    "bégayerai": ("bégayer",),
    "bégayerais": ("bégayer",),
    "bégayerait": ("bégayer",),
    "bégayeras": ("bégayer",),
    "bégayèrent": ("bégayer",),
    "bégayerez": ("bégayer",),
    "bégayeriez": ("bégayer",),
    "bégayerions": ("bégayer",),
    "bégayerons": ("bégayer",),
    "bégayeront": ("bégayer",),
    "bégayés": ("bégayer",),
    "bégayes": ("bégayer",),
    "bégayez": ("bégayer",),
    "bégayiez": ("bégayer",),
    "bégayions": ("bégayer",),
    "bégayons": ("bégayer",),
    "béguetaient": ("bégueter",),
    "béguetai": ("bégueter",),
    "béguetais": ("bégueter",),
    "béguetait": ("bégueter",),
    "bégueta": ("bégueter",),
    "béguetâmes": ("bégueter",),
    "béguetant": ("bégueter",),
    "béguetas": ("bégueter",),
    "béguetassent": ("bégueter",),
    "béguetasses": ("bégueter",),
    "béguetasse": ("bégueter",),
    "béguetassiez": ("bégueter",),
    "béguetassions": ("bégueter",),
    "béguetâtes": ("bégueter",),
    "béguetât": ("bégueter",),
    "béguetée": ("bégueter",),
    "béguetées": ("bégueter",),
    "bégueté": ("bégueter",),
    "béguetèrent": ("bégueter",),
    "béguetés": ("bégueter",),
    "béguetez": ("bégueter",),
    "béguetiez": ("bégueter",),
    "béguetions": ("bégueter",),
    "béguetons": ("bégueter",),
    "béguettent": ("bégueter",),
    "béguette": ("bégueter",),
    "béguettera": ("bégueter",),
    "béguetteraient": ("bégueter",),
    "béguetterai": ("bégueter",),
    "béguetterais": ("bégueter",),
    "béguetterait": ("bégueter",),
    "béguetteras": ("bégueter",),
    "béguetterez": ("bégueter",),
    "béguetteriez": ("bégueter",),
    "béguetterions": ("bégueter",),
    "béguetterons": ("bégueter",),
    "béguetteront": ("bégueter",),
    "béguettes": ("bégueter",),
    "bénéficiaient": ("bénéficier",),
    "bénéficiai": ("bénéficier",),
    "bénéficiais": ("bénéficier",),
    "bénéficiait": ("bénéficier",),
    "bénéficia": ("bénéficier",),
    "bénéficiâmes": ("bénéficier",),
    "bénéficiant": ("bénéficier",),
    "bénéficias": ("bénéficier",),
    "bénéficiassent": ("bénéficier",),
    "bénéficiasses": ("bénéficier",),
    "bénéficiasse": ("bénéficier",),
    "bénéficiassiez": ("bénéficier",),
    "bénéficiassions": ("bénéficier",),
    "bénéficiâtes": ("bénéficier",),
    "bénéficiât": ("bénéficier",),
    "bénéficié": ("bénéficier",),
    "bénéficient": ("bénéficier",),
    "bénéficie": ("bénéficier",),
    "bénéficiera": ("bénéficier",),
    "bénéficieraient": ("bénéficier",),
    "bénéficierai": ("bénéficier",),
    "bénéficierais": ("bénéficier",),
    "bénéficierait": ("bénéficier",),
    "bénéficieras": ("bénéficier",),
    "bénéficièrent": ("bénéficier",),
    "bénéficierez": ("bénéficier",),
    "bénéficieriez": ("bénéficier",),
    "bénéficierions": ("bénéficier",),
    "bénéficierons": ("bénéficier",),
    "bénéficieront": ("bénéficier",),
    "bénéficies": ("bénéficier",),
    "bénéficiez": ("bénéficier",),
    "bénéficiiez": ("bénéficier",),
    "bénéficiions": ("bénéficier",),
    "bénéficions": ("bénéficier",),
    "bénie": ("bénir",),
    "bénies": ("bénir",),
    "béni": ("bénir",),
    "bénîmes": ("bénir",),
    "bénira": ("bénir",),
    "béniraient": ("bénir",),
    "bénirai": ("bénir",),
    "bénirais": ("bénir",),
    "bénirait": ("bénir",),
    "béniras": ("bénir",),
    "bénirent": ("bénir",),
    "bénirez": ("bénir",),
    "béniriez": ("bénir",),
    "bénirions": ("bénir",),
    "bénirons": ("bénir",),
    "béniront": ("bénir",),
    "bénis": ("bénir",),
    "bénissaient": ("bénir",),
    "bénissais": ("bénir",),
    "bénissait": ("bénir",),
    "bénissant": ("bénir",),
    "bénissent": ("bénir",),
    "bénisse": ("bénir",),
    "bénisses": ("bénir",),
    "bénissez": ("bénir",),
    "bénissiez": ("bénir",),
    "bénissions": ("bénir",),
    "bénissons": ("bénir",),
    "bénîtes": ("bénir",),
    "bénit": ("bénir",),
    "bénît": ("bénir",),
    "béquaient": ("béquer",),
    "béquai": ("béquer",),
    "béquais": ("béquer",),
    "béquait": ("béquer",),
    "béqua": ("béquer",),
    "béquâmes": ("béquer",),
    "béquant": ("béquer",),
    "béquas": ("béquer",),
    "béquassent": ("béquer",),
    "béquasses": ("béquer",),
    "béquasse": ("béquer",),
    "béquassiez": ("béquer",),
    "béquassions": ("béquer",),
    "béquâtes": ("béquer",),
    "béquât": ("béquer",),
    "béquée": ("béquer",),
    "béquées": ("béquer",),
    "béqué": ("béquer",),
    "bèquent": ("béquer",),
    "bèque": ("béquer",),
    "béquera": ("béquer",),
    "béqueraient": ("béquer",),
    "béquerai": ("béquer",),
    "béquerais": ("béquer",),
    "béquerait": ("béquer",),
    "béqueras": ("béquer",),
    "béquèrent": ("béquer",),
    "béquerez": ("béquer",),
    "béqueriez": ("béquer",),
    "béquerions": ("béquer",),
    "béquerons": ("béquer",),
    "béqueront": ("béquer",),
    "béqués": ("béquer",),
    "bèques": ("béquer",),
    "béquez": ("béquer",),
    "béquiez": ("béquer",),
    "béquions": ("béquer",),
    "béquons": ("béquer",),
    "béquetaient": ("béqueter",),
    "béquetai": ("béqueter",),
    "béquetais": ("béqueter",),
    "béquetait": ("béqueter",),
    "béqueta": ("béqueter",),
    "béquetâmes": ("béqueter",),
    "béquetant": ("béqueter",),
    "béquetas": ("béqueter",),
    "béquetassent": ("béqueter",),
    "béquetasses": ("béqueter",),
    "béquetasse": ("béqueter",),
    "béquetassiez": ("béqueter",),
    "béquetassions": ("béqueter",),
    "béquetâtes": ("béqueter",),
    "béquetât": ("béqueter",),
    "béquetée": ("béqueter",),
    "béquetées": ("béqueter",),
    "béqueté": ("béqueter",),
    "béquetèrent": ("béqueter",),
    "béquetés": ("béqueter",),
    "béquetez": ("béqueter",),
    "béquetiez": ("béqueter",),
    "béquetions": ("béqueter",),
    "béquetons": ("béqueter",),
    "béquettent": ("béqueter",),
    "béquette": ("béqueter",),
    "béquettera": ("béqueter",),
    "béquetteraient": ("béqueter",),
    "béquetterai": ("béqueter",),
    "béquetterais": ("béqueter",),
    "béquetterait": ("béqueter",),
    "béquetteras": ("béqueter",),
    "béquetterez": ("béqueter",),
    "béquetteriez": ("béqueter",),
    "béquetterions": ("béqueter",),
    "béquetterons": ("béqueter",),
    "béquetteront": ("béqueter",),
    "béquettes": ("béqueter",),
    "berçaient": ("bercer",),
    "berçai": ("bercer",),
    "berçais": ("bercer",),
    "berçait": ("bercer",),
    "berça": ("bercer",),
    "berçâmes": ("bercer",),
    "berçant": ("bercer",),
    "berças": ("bercer",),
    "berçassent": ("bercer",),
    "berçasses": ("bercer",),
    "berçasse": ("bercer",),
    "berçassiez": ("bercer",),
    "berçassions": ("bercer",),
    "berçâtes": ("bercer",),
    "berçât": ("bercer",),
    "bercée": ("bercer",),
    "bercées": ("bercer",),
    "bercé": ("bercer",),
    "bercent": ("bercer",),
    "berce": ("bercer",),
    "bercera": ("bercer",),
    "berceraient": ("bercer",),
    "bercerai": ("bercer",),
    "bercerais": ("bercer",),
    "bercerait": ("bercer",),
    "berceras": ("bercer",),
    "bercèrent": ("bercer",),
    "bercerez": ("bercer",),
    "berceriez": ("bercer",),
    "bercerions": ("bercer",),
    "bercerons": ("bercer",),
    "berceront": ("bercer",),
    "bercés": ("bercer",),
    "berces": ("bercer",),
    "bercez": ("bercer",),
    "berciez": ("bercer",),
    "bercions": ("bercer",),
    "berçons": ("bercer",),
    "bêtifiaient": ("bêtifier",),
    "bêtifiai": ("bêtifier",),
    "bêtifiais": ("bêtifier",),
    "bêtifiait": ("bêtifier",),
    "bêtifia": ("bêtifier",),
    "bêtifiâmes": ("bêtifier",),
    "bêtifiant": ("bêtifier",),
    "bêtifias": ("bêtifier",),
    "bêtifiassent": ("bêtifier",),
    "bêtifiasses": ("bêtifier",),
    "bêtifiasse": ("bêtifier",),
    "bêtifiassiez": ("bêtifier",),
    "bêtifiassions": ("bêtifier",),
    "bêtifiâtes": ("bêtifier",),
    "bêtifiât": ("bêtifier",),
    "bêtifié": ("bêtifier",),
    "bêtifient": ("bêtifier",),
    "bêtifie": ("bêtifier",),
    "bêtifiera": ("bêtifier",),
    "bêtifieraient": ("bêtifier",),
    "bêtifierai": ("bêtifier",),
    "bêtifierais": ("bêtifier",),
    "bêtifierait": ("bêtifier",),
    "bêtifieras": ("bêtifier",),
    "bêtifièrent": ("bêtifier",),
    "bêtifierez": ("bêtifier",),
    "bêtifieriez": ("bêtifier",),
    "bêtifierions": ("bêtifier",),
    "bêtifierons": ("bêtifier",),
    "bêtifieront": ("bêtifier",),
    "bêtifies": ("bêtifier",),
    "bêtifiez": ("bêtifier",),
    "bêtifiiez": ("bêtifier",),
    "bêtifiions": ("bêtifier",),
    "bêtifions": ("bêtifier",),
    "bibliographiaient": ("bibliographier",),
    "bibliographiai": ("bibliographier",),
    "bibliographiais": ("bibliographier",),
    "bibliographiait": ("bibliographier",),
    "bibliographia": ("bibliographier",),
    "bibliographiâmes": ("bibliographier",),
    "bibliographiant": ("bibliographier",),
    "bibliographias": ("bibliographier",),
    "bibliographiassent": ("bibliographier",),
    "bibliographiasses": ("bibliographier",),
    "bibliographiasse": ("bibliographier",),
    "bibliographiassiez": ("bibliographier",),
    "bibliographiassions": ("bibliographier",),
    "bibliographiâtes": ("bibliographier",),
    "bibliographiât": ("bibliographier",),
    "bibliographiée": ("bibliographier",),
    "bibliographiées": ("bibliographier",),
    "bibliographié": ("bibliographier",),
    "bibliographient": ("bibliographier",),
    "bibliographie": ("bibliographier",),
    "bibliographiera": ("bibliographier",),
    "bibliographieraient": ("bibliographier",),
    "bibliographierai": ("bibliographier",),
    "bibliographierais": ("bibliographier",),
    "bibliographierait": ("bibliographier",),
    "bibliographieras": ("bibliographier",),
    "bibliographièrent": ("bibliographier",),
    "bibliographierez": ("bibliographier",),
    "bibliographieriez": ("bibliographier",),
    "bibliographierions": ("bibliographier",),
    "bibliographierons": ("bibliographier",),
    "bibliographieront": ("bibliographier",),
    "bibliographiés": ("bibliographier",),
    "bibliographies": ("bibliographier",),
    "bibliographiez": ("bibliographier",),
    "bibliographiiez": ("bibliographier",),
    "bibliographiions": ("bibliographier",),
    "bibliographions": ("bibliographier",),
    "bigeaient": ("biger",),
    "bigeai": ("biger",),
    "bigeais": ("biger",),
    "bigeait": ("biger",),
    "bigea": ("biger",),
    "bigeâmes": ("biger",),
    "bigeant": ("biger",),
    "bigeas": ("biger",),
    "bigeassent": ("biger",),
    "bigeasses": ("biger",),
    "bigeasse": ("biger",),
    "bigeassiez": ("biger",),
    "bigeassions": ("biger",),
    "bigeâtes": ("biger",),
    "bigeât": ("biger",),
    "bigée": ("biger",),
    "bigées": ("biger",),
    "bigé": ("biger",),
    "bigent": ("biger",),
    "bigeons": ("biger",),
    "bige": ("biger",),
    "bigera": ("biger",),
    "bigeraient": ("biger",),
    "bigerai": ("biger",),
    "bigerais": ("biger",),
    "bigerait": ("biger",),
    "bigeras": ("biger",),
    "bigèrent": ("biger",),
    "bigerez": ("biger",),
    "bigeriez": ("biger",),
    "bigerions": ("biger",),
    "bigerons": ("biger",),
    "bigeront": ("biger",),
    "bigés": ("biger",),
    "biges": ("biger",),
    "bigez": ("biger",),
    "bigiez": ("biger",),
    "bigions": ("biger",),
    "billetaient": ("billeter",),
    "billetai": ("billeter",),
    "billetais": ("billeter",),
    "billetait": ("billeter",),
    "billeta": ("billeter",),
    "billetâmes": ("billeter",),
    "billetant": ("billeter",),
    "billetas": ("billeter",),
    "billetassent": ("billeter",),
    "billetasses": ("billeter",),
    "billetasse": ("billeter",),
    "billetassiez": ("billeter",),
    "billetassions": ("billeter",),
    "billetâtes": ("billeter",),
    "billetât": ("billeter",),
    "billetée": ("billeter",),
    "billetées": ("billeter",),
    "billeté": ("billeter",),
    "billetèrent": ("billeter",),
    "billetés": ("billeter",),
    "billetez": ("billeter",),
    "billetiez": ("billeter",),
    "billetions": ("billeter",),
    "billetons": ("billeter",),
    "billettent": ("billeter",),
    "billette": ("billeter",),
    "billettera": ("billeter",),
    "billetteraient": ("billeter",),
    "billetterai": ("billeter",),
    "billetterais": ("billeter",),
    "billetterait": ("billeter",),
    "billetteras": ("billeter",),
    "billetterez": ("billeter",),
    "billetteriez": ("billeter",),
    "billetterions": ("billeter",),
    "billetterons": ("billeter",),
    "billetteront": ("billeter",),
    "billettes": ("billeter",),
    "biographiaient": ("biographier",),
    "biographiai": ("biographier",),
    "biographiais": ("biographier",),
    "biographiait": ("biographier",),
    "biographia": ("biographier",),
    "biographiâmes": ("biographier",),
    "biographiant": ("biographier",),
    "biographias": ("biographier",),
    "biographiassent": ("biographier",),
    "biographiasses": ("biographier",),
    "biographiasse": ("biographier",),
    "biographiassiez": ("biographier",),
    "biographiassions": ("biographier",),
    "biographiâtes": ("biographier",),
    "biographiât": ("biographier",),
    "biographiée": ("biographier",),
    "biographiées": ("biographier",),
    "biographié": ("biographier",),
    "biographient": ("biographier",),
    "biographie": ("biographier",),
    "biographiera": ("biographier",),
    "biographieraient": ("biographier",),
    "biographierai": ("biographier",),
    "biographierais": ("biographier",),
    "biographierait": ("biographier",),
    "biographieras": ("biographier",),
    "biographièrent": ("biographier",),
    "biographierez": ("biographier",),
    "biographieriez": ("biographier",),
    "biographierions": ("biographier",),
    "biographierons": ("biographier",),
    "biographieront": ("biographier",),
    "biographiés": ("biographier",),
    "biographies": ("biographier",),
    "biographiez": ("biographier",),
    "biographiiez": ("biographier",),
    "biographiions": ("biographier",),
    "biographions": ("biographier",),
    "bipassaient": ("bipasser",),
    "bipassai": ("bipasser",),
    "bipassais": ("bipasser",),
    "bipassait": ("bipasser",),
    "bipassa": ("bipasser",),
    "bipassâmes": ("bipasser",),
    "bipassant": ("bipasser",),
    "bipassas": ("bipasser",),
    "bipassassent": ("bipasser",),
    "bipassasses": ("bipasser",),
    "bipassasse": ("bipasser",),
    "bipassassiez": ("bipasser",),
    "bipassassions": ("bipasser",),
    "bipassâtes": ("bipasser",),
    "bipassât": ("bipasser",),
    "bipassée": ("bipasser",),
    "bipassées": ("bipasser",),
    "bipassé": ("bipasser",),
    "bipassent": ("bipasser",),
    "bipasse": ("bipasser",),
    "bipassera": ("bipasser",),
    "bipasseraient": ("bipasser",),
    "bipasserai": ("bipasser",),
    "bipasserais": ("bipasser",),
    "bipasserait": ("bipasser",),
    "bipasseras": ("bipasser",),
    "bipassèrent": ("bipasser",),
    "bipasserez": ("bipasser",),
    "bipasseriez": ("bipasser",),
    "bipasserions": ("bipasser",),
    "bipasserons": ("bipasser",),
    "bipasseront": ("bipasser",),
    "bipassés": ("bipasser",),
    "bipasses": ("bipasser",),
    "bipassez": ("bipasser",),
    "bipassiez": ("bipasser",),
    "bipassions": ("bipasser",),
    "bipassons": ("bipasser",),
    "biquetaient": ("biqueter",),
    "biquetai": ("biqueter",),
    "biquetais": ("biqueter",),
    "biquetait": ("biqueter",),
    "biqueta": ("biqueter",),
    "biquetâmes": ("biqueter",),
    "biquetant": ("biqueter",),
    "biquetas": ("biqueter",),
    "biquetassent": ("biqueter",),
    "biquetasses": ("biqueter",),
    "biquetasse": ("biqueter",),
    "biquetassiez": ("biqueter",),
    "biquetassions": ("biqueter",),
    "biquetâtes": ("biqueter",),
    "biquetât": ("biqueter",),
    "biqueté": ("biqueter",),
    "biquetèrent": ("biqueter",),
    "biquetez": ("biqueter",),
    "biquetiez": ("biqueter",),
    "biquetions": ("biqueter",),
    "biquetons": ("biqueter",),
    "biquettent": ("biqueter",),
    "biquette": ("biqueter",),
    "biquettera": ("biqueter",),
    "biquetteraient": ("biqueter",),
    "biquetterai": ("biqueter",),
    "biquetterais": ("biqueter",),
    "biquetterait": ("biqueter",),
    "biquetteras": ("biqueter",),
    "biquetterez": ("biqueter",),
    "biquetteriez": ("biqueter",),
    "biquetterions": ("biqueter",),
    "biquetterons": ("biqueter",),
    "biquetteront": ("biqueter",),
    "biquettes": ("biqueter",),
    "blâmaient": ("blâmer",),
    "blâmai": ("blâmer",),
    "blâmais": ("blâmer",),
    "blâmait": ("blâmer",),
    "blâma": ("blâmer",),
    "blâmâmes": ("blâmer",),
    "blâmant": ("blâmer",),
    "blâmas": ("blâmer",),
    "blâmassent": ("blâmer",),
    "blâmasses": ("blâmer",),
    "blâmasse": ("blâmer",),
    "blâmassiez": ("blâmer",),
    "blâmassions": ("blâmer",),
    "blâmâtes": ("blâmer",),
    "blâmât": ("blâmer",),
    "blâmée": ("blâmer",),
    "blâmées": ("blâmer",),
    "blâmé": ("blâmer",),
    "blâment": ("blâmer",),
    "blâme": ("blâmer",),
    "blâmera": ("blâmer",),
    "blâmeraient": ("blâmer",),
    "blâmerai": ("blâmer",),
    "blâmerais": ("blâmer",),
    "blâmerait": ("blâmer",),
    "blâmeras": ("blâmer",),
    "blâmèrent": ("blâmer",),
    "blâmerez": ("blâmer",),
    "blâmeriez": ("blâmer",),
    "blâmerions": ("blâmer",),
    "blâmerons": ("blâmer",),
    "blâmeront": ("blâmer",),
    "blâmés": ("blâmer",),
    "blâmes": ("blâmer",),
    "blâmez": ("blâmer",),
    "blâmiez": ("blâmer",),
    "blâmions": ("blâmer",),
    "blâmons": ("blâmer",),
    "blanchie": ("blanchir",),
    "blanchies": ("blanchir",),
    "blanchi": ("blanchir",),
    "blanchîmes": ("blanchir",),
    "blanchira": ("blanchir",),
    "blanchiraient": ("blanchir",),
    "blanchirai": ("blanchir",),
    "blanchirais": ("blanchir",),
    "blanchirait": ("blanchir",),
    "blanchiras": ("blanchir",),
    "blanchirent": ("blanchir",),
    "blanchirez": ("blanchir",),
    "blanchiriez": ("blanchir",),
    "blanchirions": ("blanchir",),
    "blanchirons": ("blanchir",),
    "blanchiront": ("blanchir",),
    "blanchis": ("blanchir",),
    "blanchissaient": ("blanchir",),
    "blanchissais": ("blanchir",),
    "blanchissait": ("blanchir",),
    "blanchissant": ("blanchir",),
    "blanchissent": ("blanchir",),
    "blanchisse": ("blanchir",),
    "blanchisses": ("blanchir",),
    "blanchissez": ("blanchir",),
    "blanchissiez": ("blanchir",),
    "blanchissions": ("blanchir",),
    "blanchissons": ("blanchir",),
    "blanchîtes": ("blanchir",),
    "blanchit": ("blanchir",),
    "blanchît": ("blanchir",),
    "blanchoient": ("blanchoyer",),
    "blanchoie": ("blanchoyer",),
    "blanchoiera": ("blanchoyer",),
    "blanchoieraient": ("blanchoyer",),
    "blanchoierai": ("blanchoyer",),
    "blanchoierais": ("blanchoyer",),
    "blanchoierait": ("blanchoyer",),
    "blanchoieras": ("blanchoyer",),
    "blanchoierez": ("blanchoyer",),
    "blanchoieriez": ("blanchoyer",),
    "blanchoierions": ("blanchoyer",),
    "blanchoierons": ("blanchoyer",),
    "blanchoieront": ("blanchoyer",),
    "blanchoies": ("blanchoyer",),
    "blanchoyaient": ("blanchoyer",),
    "blanchoyai": ("blanchoyer",),
    "blanchoyais": ("blanchoyer",),
    "blanchoyait": ("blanchoyer",),
    "blanchoya": ("blanchoyer",),
    "blanchoyâmes": ("blanchoyer",),
    "blanchoyant": ("blanchoyer",),
    "blanchoyas": ("blanchoyer",),
    "blanchoyassent": ("blanchoyer",),
    "blanchoyasses": ("blanchoyer",),
    "blanchoyasse": ("blanchoyer",),
    "blanchoyassiez": ("blanchoyer",),
    "blanchoyassions": ("blanchoyer",),
    "blanchoyâtes": ("blanchoyer",),
    "blanchoyât": ("blanchoyer",),
    "blanchoyée": ("blanchoyer",),
    "blanchoyées": ("blanchoyer",),
    "blanchoyé": ("blanchoyer",),
    "blanchoyèrent": ("blanchoyer",),
    "blanchoyés": ("blanchoyer",),
    "blanchoyez": ("blanchoyer",),
    "blanchoyiez": ("blanchoyer",),
    "blanchoyions": ("blanchoyer",),
    "blanchoyons": ("blanchoyer",),
    "blasphémaient": ("blasphémer",),
    "blasphémai": ("blasphémer",),
    "blasphémais": ("blasphémer",),
    "blasphémait": ("blasphémer",),
    "blasphéma": ("blasphémer",),
    "blasphémâmes": ("blasphémer",),
    "blasphémant": ("blasphémer",),
    "blasphémas": ("blasphémer",),
    "blasphémassent": ("blasphémer",),
    "blasphémasses": ("blasphémer",),
    "blasphémasse": ("blasphémer",),
    "blasphémassiez": ("blasphémer",),
    "blasphémassions": ("blasphémer",),
    "blasphémâtes": ("blasphémer",),
    "blasphémât": ("blasphémer",),
    "blasphémée": ("blasphémer",),
    "blasphémées": ("blasphémer",),
    "blasphémé": ("blasphémer",),
    "blasphèment": ("blasphémer",),
    "blasphème": ("blasphémer",),
    "blasphémera": ("blasphémer",),
    "blasphémeraient": ("blasphémer",),
    "blasphémerai": ("blasphémer",),
    "blasphémerais": ("blasphémer",),
    "blasphémerait": ("blasphémer",),
    "blasphémeras": ("blasphémer",),
    "blasphémèrent": ("blasphémer",),
    "blasphémerez": ("blasphémer",),
    "blasphémeriez": ("blasphémer",),
    "blasphémerions": ("blasphémer",),
    "blasphémerons": ("blasphémer",),
    "blasphémeront": ("blasphémer",),
    "blasphémés": ("blasphémer",),
    "blasphèmes": ("blasphémer",),
    "blasphémez": ("blasphémer",),
    "blasphémiez": ("blasphémer",),
    "blasphémions": ("blasphémer",),
    "blasphémons": ("blasphémer",),
    "blatéraient": ("blatérer",),
    "blatérai": ("blatérer",),
    "blatérais": ("blatérer",),
    "blatérait": ("blatérer",),
    "blatéra": ("blatérer",),
    "blatérâmes": ("blatérer",),
    "blatérant": ("blatérer",),
    "blatéras": ("blatérer",),
    "blatérassent": ("blatérer",),
    "blatérasses": ("blatérer",),
    "blatérasse": ("blatérer",),
    "blatérassiez": ("blatérer",),
    "blatérassions": ("blatérer",),
    "blatérâtes": ("blatérer",),
    "blatérât": ("blatérer",),
    "blatérée": ("blatérer",),
    "blatérées": ("blatérer",),
    "blatéré": ("blatérer",),
    "blatèrent": ("blatérer",),
    "blatère": ("blatérer",),
    "blatérera": ("blatérer",),
    "blatéreraient": ("blatérer",),
    "blatérerai": ("blatérer",),
    "blatérerais": ("blatérer",),
    "blatérerait": ("blatérer",),
    "blatéreras": ("blatérer",),
    "blatérèrent": ("blatérer",),
    "blatérerez": ("blatérer",),
    "blatéreriez": ("blatérer",),
    "blatérerions": ("blatérer",),
    "blatérerons": ("blatérer",),
    "blatéreront": ("blatérer",),
    "blatérés": ("blatérer",),
    "blatères": ("blatérer",),
    "blatérez": ("blatérer",),
    "blatériez": ("blatérer",),
    "blatérions": ("blatérer",),
    "blatérons": ("blatérer",),
    "bléaient": ("bléer",),
    "bléai": ("bléer",),
    "bléais": ("bléer",),
    "bléait": ("bléer",),
    "bléa": ("bléer",),
    "bléâmes": ("bléer",),
    "bléant": ("bléer",),
    "bléas": ("bléer",),
    "bléassent": ("bléer",),
    "bléasses": ("bléer",),
    "bléasse": ("bléer",),
    "bléassiez": ("bléer",),
    "bléassions": ("bléer",),
    "bléâtes": ("bléer",),
    "bléât": ("bléer",),
    "bléée": ("bléer",),
    "bléées": ("bléer",),
    "bléé": ("bléer",),
    "bléent": ("bléer",),
    "blée": ("bléer",),
    "bléera": ("bléer",),
    "bléeraient": ("bléer",),
    "bléerai": ("bléer",),
    "bléerais": ("bléer",),
    "bléerait": ("bléer",),
    "bléeras": ("bléer",),
    "bléèrent": ("bléer",),
    "bléerez": ("bléer",),
    "bléeriez": ("bléer",),
    "bléerions": ("bléer",),
    "bléerons": ("bléer",),
    "bléeront": ("bléer",),
    "bléés": ("bléer",),
    "blées": ("bléer",),
    "bléez": ("bléer",),
    "bléiez": ("bléer",),
    "bléions": ("bléer",),
    "bléons": ("bléer",),
    "blêmie": ("blêmir",),
    "blêmies": ("blêmir",),
    "blêmi": ("blêmir",),
    "blêmîmes": ("blêmir",),
    "blêmira": ("blêmir",),
    "blêmiraient": ("blêmir",),
    "blêmirai": ("blêmir",),
    "blêmirais": ("blêmir",),
    "blêmirait": ("blêmir",),
    "blêmiras": ("blêmir",),
    "blêmirent": ("blêmir",),
    "blêmirez": ("blêmir",),
    "blêmiriez": ("blêmir",),
    "blêmirions": ("blêmir",),
    "blêmirons": ("blêmir",),
    "blêmiront": ("blêmir",),
    "blêmis": ("blêmir",),
    "blêmissaient": ("blêmir",),
    "blêmissais": ("blêmir",),
    "blêmissait": ("blêmir",),
    "blêmissant": ("blêmir",),
    "blêmissent": ("blêmir",),
    "blêmisse": ("blêmir",),
    "blêmisses": ("blêmir",),
    "blêmissez": ("blêmir",),
    "blêmissiez": ("blêmir",),
    "blêmissions": ("blêmir",),
    "blêmissons": ("blêmir",),
    "blêmîtes": ("blêmir",),
    "blêmit": ("blêmir",),
    "blêmît": ("blêmir",),
    "blésaient": ("bléser",),
    "blésai": ("bléser",),
    "blésais": ("bléser",),
    "blésait": ("bléser",),
    "blésa": ("bléser",),
    "blésâmes": ("bléser",),
    "blésant": ("bléser",),
    "blésas": ("bléser",),
    "blésassent": ("bléser",),
    "blésasses": ("bléser",),
    "blésasse": ("bléser",),
    "blésassiez": ("bléser",),
    "blésassions": ("bléser",),
    "blésâtes": ("bléser",),
    "blésât": ("bléser",),
    "blésée": ("bléser",),
    "blésées": ("bléser",),
    "blésé": ("bléser",),
    "blèsent": ("bléser",),
    "blèse": ("bléser",),
    "blésera": ("bléser",),
    "bléseraient": ("bléser",),
    "bléserai": ("bléser",),
    "bléserais": ("bléser",),
    "bléserait": ("bléser",),
    "bléseras": ("bléser",),
    "blésèrent": ("bléser",),
    "bléserez": ("bléser",),
    "bléseriez": ("bléser",),
    "bléserions": ("bléser",),
    "bléserons": ("bléser",),
    "bléseront": ("bléser",),
    "blésés": ("bléser",),
    "blèses": ("bléser",),
    "blésez": ("bléser",),
    "blésiez": ("bléser",),
    "blésions": ("bléser",),
    "blésons": ("bléser",),
    "blettie": ("blettir",),
    "bletties": ("blettir",),
    "bletti": ("blettir",),
    "blettîmes": ("blettir",),
    "blettira": ("blettir",),
    "blettiraient": ("blettir",),
    "blettirai": ("blettir",),
    "blettirais": ("blettir",),
    "blettirait": ("blettir",),
    "blettiras": ("blettir",),
    "blettirent": ("blettir",),
    "blettirez": ("blettir",),
    "blettiriez": ("blettir",),
    "blettirions": ("blettir",),
    "blettirons": ("blettir",),
    "blettiront": ("blettir",),
    "blettis": ("blettir",),
    "blettissaient": ("blettir",),
    "blettissais": ("blettir",),
    "blettissait": ("blettir",),
    "blettissant": ("blettir",),
    "blettissent": ("blettir",),
    "blettisse": ("blettir",),
    "blettisses": ("blettir",),
    "blettissez": ("blettir",),
    "blettissiez": ("blettir",),
    "blettissions": ("blettir",),
    "blettissons": ("blettir",),
    "blettîtes": ("blettir",),
    "blettit": ("blettir",),
    "blettît": ("blettir",),
    "bleuie": ("bleuir",),
    "bleuies": ("bleuir",),
    "bleui": ("bleuir",),
    "bleuîmes": ("bleuir",),
    "bleuira": ("bleuir",),
    "bleuiraient": ("bleuir",),
    "bleuirai": ("bleuir",),
    "bleuirais": ("bleuir",),
    "bleuirait": ("bleuir",),
    "bleuiras": ("bleuir",),
    "bleuirent": ("bleuir",),
    "bleuirez": ("bleuir",),
    "bleuiriez": ("bleuir",),
    "bleuirions": ("bleuir",),
    "bleuirons": ("bleuir",),
    "bleuiront": ("bleuir",),
    "bleuis": ("bleuir",),
    "bleuissaient": ("bleuir",),
    "bleuissais": ("bleuir",),
    "bleuissait": ("bleuir",),
    "bleuissant": ("bleuir",),
    "bleuissent": ("bleuir",),
    "bleuisse": ("bleuir",),
    "bleuisses": ("bleuir",),
    "bleuissez": ("bleuir",),
    "bleuissiez": ("bleuir",),
    "bleuissions": ("bleuir",),
    "bleuissons": ("bleuir",),
    "bleuîtes": ("bleuir",),
    "bleuit": ("bleuir",),
    "bleuît": ("bleuir",),
    "blondie": ("blondir",),
    "blondies": ("blondir",),
    "blondi": ("blondir",),
    "blondîmes": ("blondir",),
    "blondira": ("blondir",),
    "blondiraient": ("blondir",),
    "blondirai": ("blondir",),
    "blondirais": ("blondir",),
    "blondirait": ("blondir",),
    "blondiras": ("blondir",),
    "blondirent": ("blondir",),
    "blondirez": ("blondir",),
    "blondiriez": ("blondir",),
    "blondirions": ("blondir",),
    "blondirons": ("blondir",),
    "blondiront": ("blondir",),
    "blondis": ("blondir",),
    "blondissaient": ("blondir",),
    "blondissais": ("blondir",),
    "blondissait": ("blondir",),
    "blondissant": ("blondir",),
    "blondissent": ("blondir",),
    "blondisse": ("blondir",),
    "blondisses": ("blondir",),
    "blondissez": ("blondir",),
    "blondissiez": ("blondir",),
    "blondissions": ("blondir",),
    "blondissons": ("blondir",),
    "blondîtes": ("blondir",),
    "blondit": ("blondir",),
    "blondît": ("blondir",),
    "blondoient": ("blondoyer",),
    "blondoie": ("blondoyer",),
    "blondoiera": ("blondoyer",),
    "blondoieraient": ("blondoyer",),
    "blondoierai": ("blondoyer",),
    "blondoierais": ("blondoyer",),
    "blondoierait": ("blondoyer",),
    "blondoieras": ("blondoyer",),
    "blondoierez": ("blondoyer",),
    "blondoieriez": ("blondoyer",),
    "blondoierions": ("blondoyer",),
    "blondoierons": ("blondoyer",),
    "blondoieront": ("blondoyer",),
    "blondoies": ("blondoyer",),
    "blondoyaient": ("blondoyer",),
    "blondoyai": ("blondoyer",),
    "blondoyais": ("blondoyer",),
    "blondoyait": ("blondoyer",),
    "blondoya": ("blondoyer",),
    "blondoyâmes": ("blondoyer",),
    "blondoyant": ("blondoyer",),
    "blondoyas": ("blondoyer",),
    "blondoyassent": ("blondoyer",),
    "blondoyasses": ("blondoyer",),
    "blondoyasse": ("blondoyer",),
    "blondoyassiez": ("blondoyer",),
    "blondoyassions": ("blondoyer",),
    "blondoyâtes": ("blondoyer",),
    "blondoyât": ("blondoyer",),
    "blondoyée": ("blondoyer",),
    "blondoyées": ("blondoyer",),
    "blondoyé": ("blondoyer",),
    "blondoyèrent": ("blondoyer",),
    "blondoyés": ("blondoyer",),
    "blondoyez": ("blondoyer",),
    "blondoyiez": ("blondoyer",),
    "blondoyions": ("blondoyer",),
    "blondoyons": ("blondoyer",),
    "blottie": ("blottir",),
    "blotties": ("blottir",),
    "blotti": ("blottir",),
    "blottîmes": ("blottir",),
    "blottira": ("blottir",),
    "blottiraient": ("blottir",),
    "blottirai": ("blottir",),
    "blottirais": ("blottir",),
    "blottirait": ("blottir",),
    "blottiras": ("blottir",),
    "blottirent": ("blottir",),
    "blottirez": ("blottir",),
    "blottiriez": ("blottir",),
    "blottirions": ("blottir",),
    "blottirons": ("blottir",),
    "blottiront": ("blottir",),
    "blottis": ("blottir",),
    "blottissaient": ("blottir",),
    "blottissais": ("blottir",),
    "blottissait": ("blottir",),
    "blottissant": ("blottir",),
    "blottissent": ("blottir",),
    "blottisse": ("blottir",),
    "blottisses": ("blottir",),
    "blottissez": ("blottir",),
    "blottissiez": ("blottir",),
    "blottissions": ("blottir",),
    "blottissons": ("blottir",),
    "blottîtes": ("blottir",),
    "blottit": ("blottir",),
    "blottît": ("blottir",),
    "boira": ("boire",),
    "boiraient": ("boire",),
    "boirai": ("boire",),
    "boirais": ("boire",),
    "boirait": ("boire",),
    "boiras": ("boire",),
    "boirez": ("boire",),
    "boiriez": ("boire",),
    "boirions": ("boire",),
    "boirons": ("boire",),
    "boiront": ("boire",),
    "bois": ("boire",),
    "boit": ("boire",),
    "boivent": ("boire",),
    "boive": ("boire",),
    "boives": ("boire",),
    "bue": ("boire",),
    "bues": ("boire",),
    "bu": ("boire",),
    "bûmes": ("boire",),
    "burent": ("boire",),
    "bus": ("boire",),
    "bussent": ("boire",),
    "busses": ("boire",),
    "busse": ("boire",),
    "bussiez": ("boire",),
    "bussions": ("boire",),
    "bûtes": ("boire",),
    "but": ("boire",),
    "bût": ("boire",),
    "buvaient": ("boire",),
    "buvais": ("boire",),
    "buvait": ("boire",),
    "buvant": ("boire",),
    "buvez": ("boire",),
    "buviez": ("boire",),
    "buvions": ("boire",),
    "buvons": ("boire",),
    "boisselaient": ("boisseler",),
    "boisselai": ("boisseler",),
    "boisselais": ("boisseler",),
    "boisselait": ("boisseler",),
    "boissela": ("boisseler",),
    "boisselâmes": ("boisseler",),
    "boisselant": ("boisseler",),
    "boisselas": ("boisseler",),
    "boisselassent": ("boisseler",),
    "boisselasses": ("boisseler",),
    "boisselasse": ("boisseler",),
    "boisselassiez": ("boisseler",),
    "boisselassions": ("boisseler",),
    "boisselâtes": ("boisseler",),
    "boisselât": ("boisseler",),
    "boisselée": ("boisseler",),
    "boisselées": ("boisseler",),
    "boisselé": ("boisseler",),
    "boisselèrent": ("boisseler",),
    "boisselés": ("boisseler",),
    "boisselez": ("boisseler",),
    "boisseliez": ("boisseler",),
    "boisselions": ("boisseler",),
    "boissellent": ("boisseler",),
    "boisselle": ("boisseler",),
    "boissellera": ("boisseler",),
    "boisselleraient": ("boisseler",),
    "boissellerai": ("boisseler",),
    "boissellerais": ("boisseler",),
    "boissellerait": ("boisseler",),
    "boisselleras": ("boisseler",),
    "boissellerez": ("boisseler",),
    "boisselleriez": ("boisseler",),
    "boissellerions": ("boisseler",),
    "boissellerons": ("boisseler",),
    "boisselleront": ("boisseler",),
    "boisselles": ("boisseler",),
    "boisselons": ("boisseler",),
    "bombançaient": ("bombancer",),
    "bombançai": ("bombancer",),
    "bombançais": ("bombancer",),
    "bombançait": ("bombancer",),
    "bombança": ("bombancer",),
    "bombançâmes": ("bombancer",),
    "bombançant": ("bombancer",),
    "bombanças": ("bombancer",),
    "bombançassent": ("bombancer",),
    "bombançasses": ("bombancer",),
    "bombançasse": ("bombancer",),
    "bombançassiez": ("bombancer",),
    "bombançassions": ("bombancer",),
    "bombançâtes": ("bombancer",),
    "bombançât": ("bombancer",),
    "bombancée": ("bombancer",),
    "bombancées": ("bombancer",),
    "bombancé": ("bombancer",),
    "bombancent": ("bombancer",),
    "bombance": ("bombancer",),
    "bombancera": ("bombancer",),
    "bombanceraient": ("bombancer",),
    "bombancerai": ("bombancer",),
    "bombancerais": ("bombancer",),
    "bombancerait": ("bombancer",),
    "bombanceras": ("bombancer",),
    "bombancèrent": ("bombancer",),
    "bombancerez": ("bombancer",),
    "bombanceriez": ("bombancer",),
    "bombancerions": ("bombancer",),
    "bombancerons": ("bombancer",),
    "bombanceront": ("bombancer",),
    "bombancés": ("bombancer",),
    "bombances": ("bombancer",),
    "bombancez": ("bombancer",),
    "bombanciez": ("bombancer",),
    "bombancions": ("bombancer",),
    "bombançons": ("bombancer",),
    "bondi": ("bondir",),
    "bondîmes": ("bondir",),
    "bondira": ("bondir",),
    "bondiraient": ("bondir",),
    "bondirai": ("bondir",),
    "bondirais": ("bondir",),
    "bondirait": ("bondir",),
    "bondiras": ("bondir",),
    "bondirent": ("bondir",),
    "bondirez": ("bondir",),
    "bondiriez": ("bondir",),
    "bondirions": ("bondir",),
    "bondirons": ("bondir",),
    "bondiront": ("bondir",),
    "bondis": ("bondir",),
    "bondissaient": ("bondir",),
    "bondissais": ("bondir",),
    "bondissait": ("bondir",),
    "bondissant": ("bondir",),
    "bondissent": ("bondir",),
    "bondisse": ("bondir",),
    "bondisses": ("bondir",),
    "bondissez": ("bondir",),
    "bondissiez": ("bondir",),
    "bondissions": ("bondir",),
    "bondissons": ("bondir",),
    "bondîtes": ("bondir",),
    "bondit": ("bondir",),
    "bondît": ("bondir",),
    "bonifiaient": ("bonifier",),
    "bonifiai": ("bonifier",),
    "bonifiais": ("bonifier",),
    "bonifiait": ("bonifier",),
    "bonifia": ("bonifier",),
    "bonifiâmes": ("bonifier",),
    "bonifiant": ("bonifier",),
    "bonifias": ("bonifier",),
    "bonifiassent": ("bonifier",),
    "bonifiasses": ("bonifier",),
    "bonifiasse": ("bonifier",),
    "bonifiassiez": ("bonifier",),
    "bonifiassions": ("bonifier",),
    "bonifiâtes": ("bonifier",),
    "bonifiât": ("bonifier",),
    "bonifiée": ("bonifier",),
    "bonifiées": ("bonifier",),
    "bonifié": ("bonifier",),
    "bonifient": ("bonifier",),
    "bonifie": ("bonifier",),
    "bonifiera": ("bonifier",),
    "bonifieraient": ("bonifier",),
    "bonifierai": ("bonifier",),
    "bonifierais": ("bonifier",),
    "bonifierait": ("bonifier",),
    "bonifieras": ("bonifier",),
    "bonifièrent": ("bonifier",),
    "bonifierez": ("bonifier",),
    "bonifieriez": ("bonifier",),
    "bonifierions": ("bonifier",),
    "bonifierons": ("bonifier",),
    "bonifieront": ("bonifier",),
    "bonifiés": ("bonifier",),
    "bonifies": ("bonifier",),
    "bonifiez": ("bonifier",),
    "bonifiiez": ("bonifier",),
    "bonifiions": ("bonifier",),
    "bonifions": ("bonifier",),
    "bonie": ("bonir",),
    "bonies": ("bonir",),
    "boni": ("bonir",),
    "bonîmes": ("bonir",),
    "bonira": ("bonir",),
    "boniraient": ("bonir",),
    "bonirai": ("bonir",),
    "bonirais": ("bonir",),
    "bonirait": ("bonir",),
    "boniras": ("bonir",),
    "bonirent": ("bonir",),
    "bonirez": ("bonir",),
    "boniriez": ("bonir",),
    "bonirions": ("bonir",),
    "bonirons": ("bonir",),
    "boniront": ("bonir",),
    "bonis": ("bonir",),
    "bonissaient": ("bonir",),
    "bonissais": ("bonir",),
    "bonissait": ("bonir",),
    "bonissant": ("bonir",),
    "bonissent": ("bonir",),
    "bonisse": ("bonir",),
    "bonisses": ("bonir",),
    "bonissez": ("bonir",),
    "bonissiez": ("bonir",),
    "bonissions": ("bonir",),
    "bonissons": ("bonir",),
    "bonîtes": ("bonir",),
    "bonit": ("bonir",),
    "bonît": ("bonir",),
    "bonnetaient": ("bonneter",),
    "bonnetai": ("bonneter",),
    "bonnetais": ("bonneter",),
    "bonnetait": ("bonneter",),
    "bonneta": ("bonneter",),
    "bonnetâmes": ("bonneter",),
    "bonnetant": ("bonneter",),
    "bonnetas": ("bonneter",),
    "bonnetassent": ("bonneter",),
    "bonnetasses": ("bonneter",),
    "bonnetasse": ("bonneter",),
    "bonnetassiez": ("bonneter",),
    "bonnetassions": ("bonneter",),
    "bonnetâtes": ("bonneter",),
    "bonnetât": ("bonneter",),
    "bonnetée": ("bonneter",),
    "bonnetées": ("bonneter",),
    "bonneté": ("bonneter",),
    "bonnetèrent": ("bonneter",),
    "bonnetés": ("bonneter",),
    "bonnetez": ("bonneter",),
    "bonnetiez": ("bonneter",),
    "bonnetions": ("bonneter",),
    "bonnetons": ("bonneter",),
    "bonnettent": ("bonneter",),
    "bonnette": ("bonneter",),
    "bonnettera": ("bonneter",),
    "bonnetteraient": ("bonneter",),
    "bonnetterai": ("bonneter",),
    "bonnetterais": ("bonneter",),
    "bonnetterait": ("bonneter",),
    "bonnetteras": ("bonneter",),
    "bonnetterez": ("bonneter",),
    "bonnetteriez": ("bonneter",),
    "bonnetterions": ("bonneter",),
    "bonnetterons": ("bonneter",),
    "bonnetteront": ("bonneter",),
    "bonnettes": ("bonneter",),
    "bonnie": ("bonnir",),
    "bonnies": ("bonnir",),
    "bonni": ("bonnir",),
    "bonnîmes": ("bonnir",),
    "bonnira": ("bonnir",),
    "bonniraient": ("bonnir",),
    "bonnirai": ("bonnir",),
    "bonnirais": ("bonnir",),
    "bonnirait": ("bonnir",),
    "bonniras": ("bonnir",),
    "bonnirent": ("bonnir",),
    "bonnirez": ("bonnir",),
    "bonniriez": ("bonnir",),
    "bonnirions": ("bonnir",),
    "bonnirons": ("bonnir",),
    "bonniront": ("bonnir",),
    "bonnis": ("bonnir",),
    "bonnissaient": ("bonnir",),
    "bonnissais": ("bonnir",),
    "bonnissait": ("bonnir",),
    "bonnissant": ("bonnir",),
    "bonnissent": ("bonnir",),
    "bonnisse": ("bonnir",),
    "bonnisses": ("bonnir",),
    "bonnissez": ("bonnir",),
    "bonnissiez": ("bonnir",),
    "bonnissions": ("bonnir",),
    "bonnissons": ("bonnir",),
    "bonnîtes": ("bonnir",),
    "bonnit": ("bonnir",),
    "bonnît": ("bonnir",),
    "bordaient": ("bordayer",),
    "bordaie": ("bordayer",),
    "bordaiera": ("bordayer",),
    "bordaieraient": ("bordayer",),
    "bordaierai": ("bordayer",),
    "bordaierais": ("bordayer",),
    "bordaierait": ("bordayer",),
    "bordaieras": ("bordayer",),
    "bordaierez": ("bordayer",),
    "bordaieriez": ("bordayer",),
    "bordaierions": ("bordayer",),
    "bordaierons": ("bordayer",),
    "bordaieront": ("bordayer",),
    "bordaies": ("bordayer",),
    "bordayaient": ("bordayer",),
    "bordayai": ("bordayer",),
    "bordayais": ("bordayer",),
    "bordayait": ("bordayer",),
    "bordaya": ("bordayer",),
    "bordayâmes": ("bordayer",),
    "bordayant": ("bordayer",),
    "bordayas": ("bordayer",),
    "bordayassent": ("bordayer",),
    "bordayasses": ("bordayer",),
    "bordayasse": ("bordayer",),
    "bordayassiez": ("bordayer",),
    "bordayassions": ("bordayer",),
    "bordayâtes": ("bordayer",),
    "bordayât": ("bordayer",),
    "bordayé": ("bordayer",),
    "bordayent": ("bordayer",),
    "bordaye": ("bordayer",),
    "bordayera": ("bordayer",),
    "bordayeraient": ("bordayer",),
    "bordayerai": ("bordayer",),
    "bordayerais": ("bordayer",),
    "bordayerait": ("bordayer",),
    "bordayeras": ("bordayer",),
    "bordayèrent": ("bordayer",),
    "bordayerez": ("bordayer",),
    "bordayeriez": ("bordayer",),
    "bordayerions": ("bordayer",),
    "bordayerons": ("bordayer",),
    "bordayeront": ("bordayer",),
    "bordayes": ("bordayer",),
    "bordayez": ("bordayer",),
    "bordayiez": ("bordayer",),
    "bordayions": ("bordayer",),
    "bordayons": ("bordayer",),
    "bordoient": ("bordoyer",),
    "bordoie": ("bordoyer",),
    "bordoiera": ("bordoyer",),
    "bordoieraient": ("bordoyer",),
    "bordoierai": ("bordoyer",),
    "bordoierais": ("bordoyer",),
    "bordoierait": ("bordoyer",),
    "bordoieras": ("bordoyer",),
    "bordoierez": ("bordoyer",),
    "bordoieriez": ("bordoyer",),
    "bordoierions": ("bordoyer",),
    "bordoierons": ("bordoyer",),
    "bordoieront": ("bordoyer",),
    "bordoies": ("bordoyer",),
    "bordoyaient": ("bordoyer",),
    "bordoyai": ("bordoyer",),
    "bordoyais": ("bordoyer",),
    "bordoyait": ("bordoyer",),
    "bordoya": ("bordoyer",),
    "bordoyâmes": ("bordoyer",),
    "bordoyant": ("bordoyer",),
    "bordoyas": ("bordoyer",),
    "bordoyassent": ("bordoyer",),
    "bordoyasses": ("bordoyer",),
    "bordoyasse": ("bordoyer",),
    "bordoyassiez": ("bordoyer",),
    "bordoyassions": ("bordoyer",),
    "bordoyâtes": ("bordoyer",),
    "bordoyât": ("bordoyer",),
    "bordoyée": ("bordoyer",),
    "bordoyées": ("bordoyer",),
    "bordoyé": ("bordoyer",),
    "bordoyèrent": ("bordoyer",),
    "bordoyés": ("bordoyer",),
    "bordoyez": ("bordoyer",),
    "bordoyiez": ("bordoyer",),
    "bordoyions": ("bordoyer",),
    "bordoyons": ("bordoyer",),
    "bornoient": ("bornoyer",),
    "bornoie": ("bornoyer",),
    "bornoiera": ("bornoyer",),
    "bornoieraient": ("bornoyer",),
    "bornoierai": ("bornoyer",),
    "bornoierais": ("bornoyer",),
    "bornoierait": ("bornoyer",),
    "bornoieras": ("bornoyer",),
    "bornoierez": ("bornoyer",),
    "bornoieriez": ("bornoyer",),
    "bornoierions": ("bornoyer",),
    "bornoierons": ("bornoyer",),
    "bornoieront": ("bornoyer",),
    "bornoies": ("bornoyer",),
    "bornoyaient": ("bornoyer",),
    "bornoyai": ("bornoyer",),
    "bornoyais": ("bornoyer",),
    "bornoyait": ("bornoyer",),
    "bornoya": ("bornoyer",),
    "bornoyâmes": ("bornoyer",),
    "bornoyant": ("bornoyer",),
    "bornoyas": ("bornoyer",),
    "bornoyassent": ("bornoyer",),
    "bornoyasses": ("bornoyer",),
    "bornoyasse": ("bornoyer",),
    "bornoyassiez": ("bornoyer",),
    "bornoyassions": ("bornoyer",),
    "bornoyâtes": ("bornoyer",),
    "bornoyât": ("bornoyer",),
    "bornoyée": ("bornoyer",),
    "bornoyées": ("bornoyer",),
    "bornoyé": ("bornoyer",),
    "bornoyèrent": ("bornoyer",),
    "bornoyés": ("bornoyer",),
    "bornoyez": ("bornoyer",),
    "bornoyiez": ("bornoyer",),
    "bornoyions": ("bornoyer",),
    "bornoyons": ("bornoyer",),
    "bosselaient": ("bosseler",),
    "bosselai": ("bosseler",),
    "bosselais": ("bosseler",),
    "bosselait": ("bosseler",),
    "bossela": ("bosseler",),
    "bosselâmes": ("bosseler",),
    "bosselant": ("bosseler",),
    "bosselas": ("bosseler",),
    "bosselassent": ("bosseler",),
    "bosselasses": ("bosseler",),
    "bosselasse": ("bosseler",),
    "bosselassiez": ("bosseler",),
    "bosselassions": ("bosseler",),
    "bosselâtes": ("bosseler",),
    "bosselât": ("bosseler",),
    "bosselée": ("bosseler",),
    "bosselées": ("bosseler",),
    "bosselé": ("bosseler",),
    "bosselèrent": ("bosseler",),
    "bosselés": ("bosseler",),
    "bosselez": ("bosseler",),
    "bosseliez": ("bosseler",),
    "bosselions": ("bosseler",),
    "bossellent": ("bosseler",),
    "bosselle": ("bosseler",),
    "bossellera": ("bosseler",),
    "bosselleraient": ("bosseler",),
    "bossellerai": ("bosseler",),
    "bossellerais": ("bosseler",),
    "bossellerait": ("bosseler",),
    "bosselleras": ("bosseler",),
    "bossellerez": ("bosseler",),
    "bosselleriez": ("bosseler",),
    "bossellerions": ("bosseler",),
    "bossellerons": ("bosseler",),
    "bosselleront": ("bosseler",),
    "bosselles": ("bosseler",),
    "bosselons": ("bosseler",),
    "bottelaient": ("botteler",),
    "bottelai": ("botteler",),
    "bottelais": ("botteler",),
    "bottelait": ("botteler",),
    "bottela": ("botteler",),
    "bottelâmes": ("botteler",),
    "bottelant": ("botteler",),
    "bottelas": ("botteler",),
    "bottelassent": ("botteler",),
    "bottelasses": ("botteler",),
    "bottelasse": ("botteler",),
    "bottelassiez": ("botteler",),
    "bottelassions": ("botteler",),
    "bottelâtes": ("botteler",),
    "bottelât": ("botteler",),
    "bottelée": ("botteler",),
    "bottelées": ("botteler",),
    "bottelé": ("botteler",),
    "bottelèrent": ("botteler",),
    "bottelés": ("botteler",),
    "bottelez": ("botteler",),
    "botteliez": ("botteler",),
    "bottelions": ("botteler",),
    "bottellent": ("botteler",),
    "bottelle": ("botteler",),
    "bottellera": ("botteler",),
    "bottelleraient": ("botteler",),
    "bottellerai": ("botteler",),
    "bottellerais": ("botteler",),
    "bottellerait": ("botteler",),
    "bottelleras": ("botteler",),
    "bottellerez": ("botteler",),
    "bottelleriez": ("botteler",),
    "bottellerions": ("botteler",),
    "bottellerons": ("botteler",),
    "bottelleront": ("botteler",),
    "bottelles": ("botteler",),
    "bottelons": ("botteler",),
    "bouchoient": ("bouchoyer",),
    "bouchoie": ("bouchoyer",),
    "bouchoiera": ("bouchoyer",),
    "bouchoieraient": ("bouchoyer",),
    "bouchoierai": ("bouchoyer",),
    "bouchoierais": ("bouchoyer",),
    "bouchoierait": ("bouchoyer",),
    "bouchoieras": ("bouchoyer",),
    "bouchoierez": ("bouchoyer",),
    "bouchoieriez": ("bouchoyer",),
    "bouchoierions": ("bouchoyer",),
    "bouchoierons": ("bouchoyer",),
    "bouchoieront": ("bouchoyer",),
    "bouchoies": ("bouchoyer",),
    "bouchoyaient": ("bouchoyer",),
    "bouchoyai": ("bouchoyer",),
    "bouchoyais": ("bouchoyer",),
    "bouchoyait": ("bouchoyer",),
    "bouchoya": ("bouchoyer",),
    "bouchoyâmes": ("bouchoyer",),
    "bouchoyant": ("bouchoyer",),
    "bouchoyas": ("bouchoyer",),
    "bouchoyassent": ("bouchoyer",),
    "bouchoyasses": ("bouchoyer",),
    "bouchoyasse": ("bouchoyer",),
    "bouchoyassiez": ("bouchoyer",),
    "bouchoyassions": ("bouchoyer",),
    "bouchoyâtes": ("bouchoyer",),
    "bouchoyât": ("bouchoyer",),
    "bouchoyée": ("bouchoyer",),
    "bouchoyées": ("bouchoyer",),
    "bouchoyé": ("bouchoyer",),
    "bouchoyèrent": ("bouchoyer",),
    "bouchoyés": ("bouchoyer",),
    "bouchoyez": ("bouchoyer",),
    "bouchoyiez": ("bouchoyer",),
    "bouchoyions": ("bouchoyer",),
    "bouchoyons": ("bouchoyer",),
    "bouffie": ("bouffir",),
    "bouffies": ("bouffir",),
    "bouffi": ("bouffir",),
    "bouffîmes": ("bouffir",),
    "bouffira": ("bouffir",),
    "bouffiraient": ("bouffir",),
    "bouffirai": ("bouffir",),
    "bouffirais": ("bouffir",),
    "bouffirait": ("bouffir",),
    "bouffiras": ("bouffir",),
    "bouffirent": ("bouffir",),
    "bouffirez": ("bouffir",),
    "bouffiriez": ("bouffir",),
    "bouffirions": ("bouffir",),
    "bouffirons": ("bouffir",),
    "bouffiront": ("bouffir",),
    "bouffis": ("bouffir",),
    "bouffissaient": ("bouffir",),
    "bouffissais": ("bouffir",),
    "bouffissait": ("bouffir",),
    "bouffissant": ("bouffir",),
    "bouffissent": ("bouffir",),
    "bouffisse": ("bouffir",),
    "bouffisses": ("bouffir",),
    "bouffissez": ("bouffir",),
    "bouffissiez": ("bouffir",),
    "bouffissions": ("bouffir",),
    "bouffissons": ("bouffir",),
    "bouffîtes": ("bouffir",),
    "bouffit": ("bouffir",),
    "bouffît": ("bouffir",),
    "bougeaient": ("bouger",),
    "bougeai": ("bouger",),
    "bougeais": ("bouger",),
    "bougeait": ("bouger",),
    "bougea": ("bouger",),
    "bougeâmes": ("bouger",),
    "bougeant": ("bouger",),
    "bougeas": ("bouger",),
    "bougeassent": ("bouger",),
    "bougeasses": ("bouger",),
    "bougeasse": ("bouger",),
    "bougeassiez": ("bouger",),
    "bougeassions": ("bouger",),
    "bougeâtes": ("bouger",),
    "bougeât": ("bouger",),
    "bougée": ("bouger",),
    "bougées": ("bouger",),
    "bougé": ("bouger",),
    "bougent": ("bouger",),
    "bougeons": ("bouger",),
    "bouge": ("bouger",),
    "bougera": ("bouger",),
    "bougeraient": ("bouger",),
    "bougerai": ("bouger",),
    "bougerais": ("bouger",),
    "bougerait": ("bouger",),
    "bougeras": ("bouger",),
    "bougèrent": ("bouger",),
    "bougerez": ("bouger",),
    "bougeriez": ("bouger",),
    "bougerions": ("bouger",),
    "bougerons": ("bouger",),
    "bougeront": ("bouger",),
    "bougés": ("bouger",),
    "bouges": ("bouger",),
    "bougez": ("bouger",),
    "bougiez": ("bougier",),
    "bougions": ("bougier",),
    "bougiaient": ("bougier",),
    "bougiai": ("bougier",),
    "bougiais": ("bougier",),
    "bougiait": ("bougier",),
    "bougia": ("bougier",),
    "bougiâmes": ("bougier",),
    "bougiant": ("bougier",),
    "bougias": ("bougier",),
    "bougiassent": ("bougier",),
    "bougiasses": ("bougier",),
    "bougiasse": ("bougier",),
    "bougiassiez": ("bougier",),
    "bougiassions": ("bougier",),
    "bougiâtes": ("bougier",),
    "bougiât": ("bougier",),
    "bougiée": ("bougier",),
    "bougiées": ("bougier",),
    "bougié": ("bougier",),
    "bougient": ("bougier",),
    "bougie": ("bougier",),
    "bougiera": ("bougier",),
    "bougieraient": ("bougier",),
    "bougierai": ("bougier",),
    "bougierais": ("bougier",),
    "bougierait": ("bougier",),
    "bougieras": ("bougier",),
    "bougièrent": ("bougier",),
    "bougierez": ("bougier",),
    "bougieriez": ("bougier",),
    "bougierions": ("bougier",),
    "bougierons": ("bougier",),
    "bougieront": ("bougier",),
    "bougiés": ("bougier",),
    "bougies": ("bougier",),
    "bougiiez": ("bougier",),
    "bougiions": ("bougier",),
    "bouillaient": ("bouillir",),
    "bouillais": ("bouillir",),
    "bouillait": ("bouillir",),
    "bouillant": ("bouillir",),
    "bouillent": ("bouillir",),
    "bouille": ("bouillir",),
    "bouilles": ("bouillir",),
    "bouillez": ("bouillir",),
    "bouillie": ("bouillir",),
    "bouillies": ("bouillir",),
    "bouilliez": ("bouillir",),
    "bouilli": ("bouillir",),
    "bouillîmes": ("bouillir",),
    "bouillions": ("bouillir",),
    "bouillira": ("bouillir",),
    "bouilliraient": ("bouillir",),
    "bouillirai": ("bouillir",),
    "bouillirais": ("bouillir",),
    "bouillirait": ("bouillir",),
    "bouilliras": ("bouillir",),
    "bouillirent": ("bouillir",),
    "bouillirez": ("bouillir",),
    "bouilliriez": ("bouillir",),
    "bouillirions": ("bouillir",),
    "bouillirons": ("bouillir",),
    "bouilliront": ("bouillir",),
    "bouillis": ("bouillir",),
    "bouillissent": ("bouillir",),
    "bouillisses": ("bouillir",),
    "bouillisse": ("bouillir",),
    "bouillissiez": ("bouillir",),
    "bouillissions": ("bouillir",),
    "bouillîtes": ("bouillir",),
    "bouillit": ("bouillir",),
    "bouillît": ("bouillir",),
    "bouillons": ("bouillir",),
    "bous": ("bouillir",),
    "bout": ("bouillir",),
    "boulangeaient": ("boulanger",),
    "boulangeai": ("boulanger",),
    "boulangeais": ("boulanger",),
    "boulangeait": ("boulanger",),
    "boulangea": ("boulanger",),
    "boulangeâmes": ("boulanger",),
    "boulangeant": ("boulanger",),
    "boulangeas": ("boulanger",),
    "boulangeassent": ("boulanger",),
    "boulangeasses": ("boulanger",),
    "boulangeasse": ("boulanger",),
    "boulangeassiez": ("boulanger",),
    "boulangeassions": ("boulanger",),
    "boulangeâtes": ("boulanger",),
    "boulangeât": ("boulanger",),
    "boulangée": ("boulanger",),
    "boulangées": ("boulanger",),
    "boulangé": ("boulanger",),
    "boulangent": ("boulanger",),
    "boulangeons": ("boulanger",),
    "boulange": ("boulanger",),
    "boulangera": ("boulanger",),
    "boulangeraient": ("boulanger",),
    "boulangerai": ("boulanger",),
    "boulangerais": ("boulanger",),
    "boulangerait": ("boulanger",),
    "boulangeras": ("boulanger",),
    "boulangèrent": ("boulanger",),
    "boulangerez": ("boulanger",),
    "boulangeriez": ("boulanger",),
    "boulangerions": ("boulanger",),
    "boulangerons": ("boulanger",),
    "boulangeront": ("boulanger",),
    "boulangés": ("boulanger",),
    "boulanges": ("boulanger",),
    "boulangez": ("boulanger",),
    "boulangiez": ("boulanger",),
    "boulangions": ("boulanger",),
    "bouletaient": ("bouleter",),
    "bouletai": ("bouleter",),
    "bouletais": ("bouleter",),
    "bouletait": ("bouleter",),
    "bouleta": ("bouleter",),
    "bouletâmes": ("bouleter",),
    "bouletant": ("bouleter",),
    "bouletas": ("bouleter",),
    "bouletassent": ("bouleter",),
    "bouletasses": ("bouleter",),
    "bouletasse": ("bouleter",),
    "bouletassiez": ("bouleter",),
    "bouletassions": ("bouleter",),
    "bouletâtes": ("bouleter",),
    "bouletât": ("bouleter",),
    "bouletée": ("bouleter",),
    "bouletées": ("bouleter",),
    "bouleté": ("bouleter",),
    "bouletèrent": ("bouleter",),
    "bouletés": ("bouleter",),
    "bouletez": ("bouleter",),
    "bouletiez": ("bouleter",),
    "bouletions": ("bouleter",),
    "bouletons": ("bouleter",),
    "boulettent": ("bouleter",),
    "boulette": ("bouleter",),
    "boulettera": ("bouleter",),
    "bouletteraient": ("bouleter",),
    "bouletterai": ("bouleter",),
    "bouletterais": ("bouleter",),
    "bouletterait": ("bouleter",),
    "bouletteras": ("bouleter",),
    "bouletterez": ("bouleter",),
    "bouletteriez": ("bouleter",),
    "bouletterions": ("bouleter",),
    "bouletterons": ("bouleter",),
    "bouletteront": ("bouleter",),
    "boulettes": ("bouleter",),
    "bourrassaient": ("bourrasser",),
    "bourrassai": ("bourrasser",),
    "bourrassais": ("bourrasser",),
    "bourrassait": ("bourrasser",),
    "bourrassa": ("bourrasser",),
    "bourrassâmes": ("bourrasser",),
    "bourrassant": ("bourrasser",),
    "bourrassas": ("bourrasser",),
    "bourrassassent": ("bourrasser",),
    "bourrassasses": ("bourrasser",),
    "bourrassasse": ("bourrasser",),
    "bourrassassiez": ("bourrasser",),
    "bourrassassions": ("bourrasser",),
    "bourrassâtes": ("bourrasser",),
    "bourrassât": ("bourrasser",),
    "bourrassé": ("bourrasser",),
    "bourrassent": ("bourrasser",),
    "bourrasse": ("bourrasser",),
    "bourrassera": ("bourrasser",),
    "bourrasseraient": ("bourrasser",),
    "bourrasserai": ("bourrasser",),
    "bourrasserais": ("bourrasser",),
    "bourrasserait": ("bourrasser",),
    "bourrasseras": ("bourrasser",),
    "bourrassèrent": ("bourrasser",),
    "bourrasserez": ("bourrasser",),
    "bourrasseriez": ("bourrasser",),
    "bourrasserions": ("bourrasser",),
    "bourrasserons": ("bourrasser",),
    "bourrasseront": ("bourrasser",),
    "bourrasses": ("bourrasser",),
    "bourrassez": ("bourrasser",),
    "bourrassiez": ("bourrasser",),
    "bourrassions": ("bourrasser",),
    "bourrassons": ("bourrasser",),
    "bourrelaient": ("bourreler",),
    "bourrelai": ("bourreler",),
    "bourrelais": ("bourreler",),
    "bourrelait": ("bourreler",),
    "bourrela": ("bourreler",),
    "bourrelâmes": ("bourreler",),
    "bourrelant": ("bourreler",),
    "bourrelas": ("bourreler",),
    "bourrelassent": ("bourreler",),
    "bourrelasses": ("bourreler",),
    "bourrelasse": ("bourreler",),
    "bourrelassiez": ("bourreler",),
    "bourrelassions": ("bourreler",),
    "bourrelâtes": ("bourreler",),
    "bourrelât": ("bourreler",),
    "bourrelée": ("bourreler",),
    "bourrelées": ("bourreler",),
    "bourrelé": ("bourreler",),
    "bourrelèrent": ("bourreler",),
    "bourrelés": ("bourreler",),
    "bourrelez": ("bourreler",),
    "bourreliez": ("bourreler",),
    "bourrelions": ("bourreler",),
    "bourrellent": ("bourreler",),
    "bourrelle": ("bourreler",),
    "bourrellera": ("bourreler",),
    "bourrelleraient": ("bourreler",),
    "bourrellerai": ("bourreler",),
    "bourrellerais": ("bourreler",),
    "bourrellerait": ("bourreler",),
    "bourrelleras": ("bourreler",),
    "bourrellerez": ("bourreler",),
    "bourrelleriez": ("bourreler",),
    "bourrellerions": ("bourreler",),
    "bourrellerons": ("bourreler",),
    "bourrelleront": ("bourreler",),
    "bourrelles": ("bourreler",),
    "bourrelons": ("bourreler",),
    "bouvetaient": ("bouveter",),
    "bouvetai": ("bouveter",),
    "bouvetais": ("bouveter",),
    "bouvetait": ("bouveter",),
    "bouveta": ("bouveter",),
    "bouvetâmes": ("bouveter",),
    "bouvetant": ("bouveter",),
    "bouvetas": ("bouveter",),
    "bouvetassent": ("bouveter",),
    "bouvetasses": ("bouveter",),
    "bouvetasse": ("bouveter",),
    "bouvetassiez": ("bouveter",),
    "bouvetassions": ("bouveter",),
    "bouvetâtes": ("bouveter",),
    "bouvetât": ("bouveter",),
    "bouvetée": ("bouveter",),
    "bouvetées": ("bouveter",),
    "bouveté": ("bouveter",),
    "bouvetèrent": ("bouveter",),
    "bouvetés": ("bouveter",),
    "bouvetez": ("bouveter",),
    "bouvetiez": ("bouveter",),
    "bouvetions": ("bouveter",),
    "bouvetons": ("bouveter",),
    "bouvettent": ("bouveter",),
    "bouvette": ("bouveter",),
    "bouvettera": ("bouveter",),
    "bouvetteraient": ("bouveter",),
    "bouvetterai": ("bouveter",),
    "bouvetterais": ("bouveter",),
    "bouvetterait": ("bouveter",),
    "bouvetteras": ("bouveter",),
    "bouvetterez": ("bouveter",),
    "bouvetteriez": ("bouveter",),
    "bouvetterions": ("bouveter",),
    "bouvetterons": ("bouveter",),
    "bouvetteront": ("bouveter",),
    "bouvettes": ("bouveter",),
    "braient": ("brayer",),
    "braira": ("braire",),
    "brairaient": ("braire",),
    "brairait": ("braire",),
    "brairont": ("braire",),
    "brait": ("braire",),
    "brandie": ("brandir",),
    "brandies": ("brandir",),
    "brandi": ("brandir",),
    "brandîmes": ("brandir",),
    "brandira": ("brandir",),
    "brandiraient": ("brandir",),
    "brandirai": ("brandir",),
    "brandirais": ("brandir",),
    "brandirait": ("brandir",),
    "brandiras": ("brandir",),
    "brandirent": ("brandir",),
    "brandirez": ("brandir",),
    "brandiriez": ("brandir",),
    "brandirions": ("brandir",),
    "brandirons": ("brandir",),
    "brandiront": ("brandir",),
    "brandis": ("brandir",),
    "brandissaient": ("brandir",),
    "brandissais": ("brandir",),
    "brandissait": ("brandir",),
    "brandissant": ("brandir",),
    "brandissent": ("brandir",),
    "brandisse": ("brandir",),
    "brandisses": ("brandir",),
    "brandissez": ("brandir",),
    "brandissiez": ("brandir",),
    "brandissions": ("brandir",),
    "brandissons": ("brandir",),
    "brandîtes": ("brandir",),
    "brandit": ("brandir",),
    "brandît": ("brandir",),
    "brassaient": ("brasser",),
    "brassai": ("brasser",),
    "brassais": ("brasser",),
    "brassait": ("brasser",),
    "brassa": ("brasser",),
    "brassâmes": ("brasser",),
    "brassant": ("brasser",),
    "brassas": ("brasser",),
    "brassassent": ("brasser",),
    "brassasses": ("brasser",),
    "brassasse": ("brasser",),
    "brassassiez": ("brasser",),
    "brassassions": ("brasser",),
    "brassâtes": ("brasser",),
    "brassât": ("brasser",),
    "brassée": ("brasser",),
    "brassées": ("brasser",),
    "brassé": ("brasser",),
    "brassent": ("brasser",),
    "brasse": ("brasser",),
    "brassera": ("brasser",),
    "brasseraient": ("brasser",),
    "brasserai": ("brasser",),
    "brasserais": ("brasser",),
    "brasserait": ("brasser",),
    "brasseras": ("brasser",),
    "brassèrent": ("brasser",),
    "brasserez": ("brasser",),
    "brasseriez": ("brasser",),
    "brasserions": ("brasser",),
    "brasserons": ("brasser",),
    "brasseront": ("brasser",),
    "brassés": ("brasser",),
    "brasses": ("brasser",),
    "brassez": ("brasser",),
    "brassiez": ("brasser",),
    "brassions": ("brasser",),
    "brassons": ("brasser",),
    "braie": ("brayer",),
    "braiera": ("brayer",),
    "braieraient": ("brayer",),
    "braierai": ("brayer",),
    "braierais": ("brayer",),
    "braierait": ("brayer",),
    "braieras": ("brayer",),
    "braierez": ("brayer",),
    "braieriez": ("brayer",),
    "braierions": ("brayer",),
    "braierons": ("brayer",),
    "braieront": ("brayer",),
    "braies": ("brayer",),
    "brayaient": ("brayer",),
    "brayai": ("brayer",),
    "brayais": ("brayer",),
    "brayait": ("brayer",),
    "braya": ("brayer",),
    "brayâmes": ("brayer",),
    "brayant": ("brayer",),
    "brayas": ("brayer",),
    "brayassent": ("brayer",),
    "brayasses": ("brayer",),
    "brayasse": ("brayer",),
    "brayassiez": ("brayer",),
    "brayassions": ("brayer",),
    "brayâtes": ("brayer",),
    "brayât": ("brayer",),
    "brayée": ("brayer",),
    "brayées": ("brayer",),
    "brayé": ("brayer",),
    "brayent": ("brayer",),
    "braye": ("brayer",),
    "brayera": ("brayer",),
    "brayeraient": ("brayer",),
    "brayerai": ("brayer",),
    "brayerais": ("brayer",),
    "brayerait": ("brayer",),
    "brayeras": ("brayer",),
    "brayèrent": ("brayer",),
    "brayerez": ("brayer",),
    "brayeriez": ("brayer",),
    "brayerions": ("brayer",),
    "brayerons": ("brayer",),
    "brayeront": ("brayer",),
    "brayés": ("brayer",),
    "brayes": ("brayer",),
    "brayez": ("brayer",),
    "brayiez": ("brayer",),
    "brayions": ("brayer",),
    "brayons": ("brayer",),
    "brédie": ("brédir",),
    "brédies": ("brédir",),
    "brédi": ("brédir",),
    "brédîmes": ("brédir",),
    "brédira": ("brédir",),
    "brédiraient": ("brédir",),
    "brédirai": ("brédir",),
    "brédirais": ("brédir",),
    "brédirait": ("brédir",),
    "brédiras": ("brédir",),
    "brédirent": ("brédir",),
    "brédirez": ("brédir",),
    "brédiriez": ("brédir",),
    "brédirions": ("brédir",),
    "brédirons": ("brédir",),
    "brédiront": ("brédir",),
    "brédis": ("brédir",),
    "brédissaient": ("brédir",),
    "brédissais": ("brédir",),
    "brédissait": ("brédir",),
    "brédissant": ("brédir",),
    "brédissent": ("brédir",),
    "brédisse": ("brédir",),
    "brédisses": ("brédir",),
    "brédissez": ("brédir",),
    "brédissiez": ("brédir",),
    "brédissions": ("brédir",),
    "brédissons": ("brédir",),
    "brédîtes": ("brédir",),
    "brédit": ("brédir",),
    "brédît": ("brédir",),
    "brettelaient": ("bretteler",),
    "brettelai": ("bretteler",),
    "brettelais": ("bretteler",),
    "brettelait": ("bretteler",),
    "brettela": ("bretteler",),
    "brettelâmes": ("bretteler",),
    "brettelant": ("bretteler",),
    "brettelas": ("bretteler",),
    "brettelassent": ("bretteler",),
    "brettelasses": ("bretteler",),
    "brettelasse": ("bretteler",),
    "brettelassiez": ("bretteler",),
    "brettelassions": ("bretteler",),
    "brettelâtes": ("bretteler",),
    "brettelât": ("bretteler",),
    "brettelée": ("bretteler",),
    "brettelées": ("bretteler",),
    "brettelé": ("bretteler",),
    "brettelèrent": ("bretteler",),
    "brettelés": ("bretteler",),
    "brettelez": ("bretteler",),
    "bretteliez": ("bretteler",),
    "brettelions": ("bretteler",),
    "brettellent": ("bretteler",),
    "brettelle": ("bretteler",),
    "brettellera": ("bretteler",),
    "brettelleraient": ("bretteler",),
    "brettellerai": ("bretteler",),
    "brettellerais": ("bretteler",),
    "brettellerait": ("bretteler",),
    "brettelleras": ("bretteler",),
    "brettellerez": ("bretteler",),
    "brettelleriez": ("bretteler",),
    "brettellerions": ("bretteler",),
    "brettellerons": ("bretteler",),
    "brettelleront": ("bretteler",),
    "brettelles": ("bretteler",),
    "brettelons": ("bretteler",),
    "brevetaient": ("breveter",),
    "brevetai": ("breveter",),
    "brevetais": ("breveter",),
    "brevetait": ("breveter",),
    "breveta": ("breveter",),
    "brevetâmes": ("breveter",),
    "brevetant": ("breveter",),
    "brevetas": ("breveter",),
    "brevetassent": ("breveter",),
    "brevetasses": ("breveter",),
    "brevetasse": ("breveter",),
    "brevetassiez": ("breveter",),
    "brevetassions": ("breveter",),
    "brevetâtes": ("breveter",),
    "brevetât": ("breveter",),
    "brevetée": ("breveter",),
    "brevetées": ("breveter",),
    "breveté": ("breveter",),
    "brevetèrent": ("breveter",),
    "brevetés": ("breveter",),
    "brevetez": ("breveter",),
    "brevetiez": ("breveter",),
    "brevetions": ("breveter",),
    "brevetons": ("breveter",),
    "brevettent": ("breveter",),
    "brevette": ("breveter",),
    "brevettera": ("breveter",),
    "brevetteraient": ("breveter",),
    "brevetterai": ("breveter",),
    "brevetterais": ("breveter",),
    "brevetterait": ("breveter",),
    "brevetteras": ("breveter",),
    "brevetterez": ("breveter",),
    "brevetteriez": ("breveter",),
    "brevetterions": ("breveter",),
    "brevetterons": ("breveter",),
    "brevetteront": ("breveter",),
    "brevettes": ("breveter",),
    "bridgeaient": ("bridger",),
    "bridgeai": ("bridger",),
    "bridgeais": ("bridger",),
    "bridgeait": ("bridger",),
    "bridgea": ("bridger",),
    "bridgeâmes": ("bridger",),
    "bridgeant": ("bridger",),
    "bridgeas": ("bridger",),
    "bridgeassent": ("bridger",),
    "bridgeasses": ("bridger",),
    "bridgeasse": ("bridger",),
    "bridgeassiez": ("bridger",),
    "bridgeassions": ("bridger",),
    "bridgeâtes": ("bridger",),
    "bridgeât": ("bridger",),
    "bridgé": ("bridger",),
    "bridgent": ("bridger",),
    "bridgeons": ("bridger",),
    "bridge": ("bridger",),
    "bridgera": ("bridger",),
    "bridgeraient": ("bridger",),
    "bridgerai": ("bridger",),
    "bridgerais": ("bridger",),
    "bridgerait": ("bridger",),
    "bridgeras": ("bridger",),
    "bridgèrent": ("bridger",),
    "bridgerez": ("bridger",),
    "bridgeriez": ("bridger",),
    "bridgerions": ("bridger",),
    "bridgerons": ("bridger",),
    "bridgeront": ("bridger",),
    "bridges": ("bridger",),
    "bridgez": ("bridger",),
    "bridgiez": ("bridger",),
    "bridgions": ("bridger",),
    "briaient": ("brier",),
    "briai": ("brier",),
    "briais": ("brier",),
    "briait": ("brier",),
    "bria": ("brier",),
    "briâmes": ("brier",),
    "briant": ("brier",),
    "brias": ("brier",),
    "briassent": ("brier",),
    "briasses": ("brier",),
    "briasse": ("brier",),
    "briassiez": ("brier",),
    "briassions": ("brier",),
    "briâtes": ("brier",),
    "briât": ("brier",),
    "briée": ("brier",),
    "briées": ("brier",),
    "brié": ("brier",),
    "brient": ("brier",),
    "brie": ("brier",),
    "briera": ("brier",),
    "brieraient": ("brier",),
    "brierai": ("brier",),
    "brierais": ("brier",),
    "brierait": ("brier",),
    "brieras": ("brier",),
    "brièrent": ("brier",),
    "brierez": ("brier",),
    "brieriez": ("brier",),
    "brierions": ("brier",),
    "brierons": ("brier",),
    "brieront": ("brier",),
    "briés": ("brier",),
    "bries": ("brier",),
    "briez": ("brier",),
    "briiez": ("brier",),
    "briions": ("brier",),
    "brions": ("brier",),
    "briquetaient": ("briqueter",),
    "briquetai": ("briqueter",),
    "briquetais": ("briqueter",),
    "briquetait": ("briqueter",),
    "briqueta": ("briqueter",),
    "briquetâmes": ("briqueter",),
    "briquetant": ("briqueter",),
    "briquetas": ("briqueter",),
    "briquetassent": ("briqueter",),
    "briquetasses": ("briqueter",),
    "briquetasse": ("briqueter",),
    "briquetassiez": ("briqueter",),
    "briquetassions": ("briqueter",),
    "briquetâtes": ("briqueter",),
    "briquetât": ("briqueter",),
    "briquetée": ("briqueter",),
    "briquetées": ("briqueter",),
    "briqueté": ("briqueter",),
    "briquetèrent": ("briqueter",),
    "briquetés": ("briqueter",),
    "briquetez": ("briqueter",),
    "briquetiez": ("briqueter",),
    "briquetions": ("briqueter",),
    "briquetons": ("briqueter",),
    "briquettent": ("briqueter",),
    "briquette": ("briqueter",),
    "briquettera": ("briqueter",),
    "briquetteraient": ("briqueter",),
    "briquetterai": ("briqueter",),
    "briquetterais": ("briqueter",),
    "briquetterait": ("briqueter",),
    "briquetteras": ("briqueter",),
    "briquetterez": ("briqueter",),
    "briquetteriez": ("briqueter",),
    "briquetterions": ("briqueter",),
    "briquetterons": ("briqueter",),
    "briquetteront": ("briqueter",),
    "briquettes": ("briqueter",),
    "brochetaient": ("brocheter",),
    "brochetai": ("brocheter",),
    "brochetais": ("brocheter",),
    "brochetait": ("brocheter",),
    "brocheta": ("brocheter",),
    "brochetâmes": ("brocheter",),
    "brochetant": ("brocheter",),
    "brochetas": ("brocheter",),
    "brochetassent": ("brocheter",),
    "brochetasses": ("brocheter",),
    "brochetasse": ("brocheter",),
    "brochetassiez": ("brocheter",),
    "brochetassions": ("brocheter",),
    "brochetâtes": ("brocheter",),
    "brochetât": ("brocheter",),
    "brochetée": ("brocheter",),
    "brochetées": ("brocheter",),
    "brocheté": ("brocheter",),
    "brochetèrent": ("brocheter",),
    "brochetés": ("brocheter",),
    "brochetez": ("brocheter",),
    "brochetiez": ("brocheter",),
    "brochetions": ("brocheter",),
    "brochetons": ("brocheter",),
    "brochettent": ("brocheter",),
    "brochette": ("brocheter",),
    "brochettera": ("brocheter",),
    "brochetteraient": ("brocheter",),
    "brochetterai": ("brocheter",),
    "brochetterais": ("brocheter",),
    "brochetterait": ("brocheter",),
    "brochetteras": ("brocheter",),
    "brochetterez": ("brocheter",),
    "brochetteriez": ("brocheter",),
    "brochetterions": ("brocheter",),
    "brochetterons": ("brocheter",),
    "brochetteront": ("brocheter",),
    "brochettes": ("brocheter",),
    "brondi": ("brondir",),
    "brondîmes": ("brondir",),
    "brondira": ("brondir",),
    "brondiraient": ("brondir",),
    "brondirai": ("brondir",),
    "brondirais": ("brondir",),
    "brondirait": ("brondir",),
    "brondiras": ("brondir",),
    "brondirent": ("brondir",),
    "brondirez": ("brondir",),
    "brondiriez": ("brondir",),
    "brondirions": ("brondir",),
    "brondirons": ("brondir",),
    "brondiront": ("brondir",),
    "brondis": ("brondir",),
    "brondissaient": ("brondir",),
    "brondissais": ("brondir",),
    "brondissait": ("brondir",),
    "brondissant": ("brondir",),
    "brondissent": ("brondir",),
    "brondisse": ("brondir",),
    "brondisses": ("brondir",),
    "brondissez": ("brondir",),
    "brondissiez": ("brondir",),
    "brondissions": ("brondir",),
    "brondissons": ("brondir",),
    "brondîtes": ("brondir",),
    "brondit": ("brondir",),
    "brondît": ("brondir",),
    "brouillassaient": ("brouillasser",),
    "brouillassait": ("brouillasser",),
    "brouillassa": ("brouillasser",),
    "brouillassant": ("brouillasser",),
    "brouillassassent": ("brouillasser",),
    "brouillassât": ("brouillasser",),
    "brouillassé": ("brouillasser",),
    "brouillassent": ("brouillasser",),
    "brouillasse": ("brouillasser",),
    "brouillassera": ("brouillasser",),
    "brouillasseraient": ("brouillasser",),
    "brouillasserait": ("brouillasser",),
    "brouillassèrent": ("brouillasser",),
    "brouillasseront": ("brouillasser",),
    "brouie": ("brouir",),
    "brouies": ("brouir",),
    "broui": ("brouir",),
    "brouîmes": ("brouir",),
    "brouira": ("brouir",),
    "brouiraient": ("brouir",),
    "brouirai": ("brouir",),
    "brouirais": ("brouir",),
    "brouirait": ("brouir",),
    "brouiras": ("brouir",),
    "brouirent": ("brouir",),
    "brouirez": ("brouir",),
    "brouiriez": ("brouir",),
    "brouirions": ("brouir",),
    "brouirons": ("brouir",),
    "brouiront": ("brouir",),
    "brouis": ("brouir",),
    "brouissaient": ("brouir",),
    "brouissais": ("brouir",),
    "brouissait": ("brouir",),
    "brouissant": ("brouir",),
    "brouissent": ("brouir",),
    "brouisse": ("brouir",),
    "brouisses": ("brouir",),
    "brouissez": ("brouir",),
    "brouissiez": ("brouir",),
    "brouissions": ("brouir",),
    "brouissons": ("brouir",),
    "brouîtes": ("brouir",),
    "brouit": ("brouir",),
    "brouît": ("brouir",),
    "broient": ("broyer",),
    "broie": ("broyer",),
    "broiera": ("broyer",),
    "broieraient": ("broyer",),
    "broierai": ("broyer",),
    "broierais": ("broyer",),
    "broierait": ("broyer",),
    "broieras": ("broyer",),
    "broierez": ("broyer",),
    "broieriez": ("broyer",),
    "broierions": ("broyer",),
    "broierons": ("broyer",),
    "broieront": ("broyer",),
    "broies": ("broyer",),
    "broyaient": ("broyer",),
    "broyai": ("broyer",),
    "broyais": ("broyer",),
    "broyait": ("broyer",),
    "broya": ("broyer",),
    "broyâmes": ("broyer",),
    "broyant": ("broyer",),
    "broyas": ("broyer",),
    "broyassent": ("broyer",),
    "broyasses": ("broyer",),
    "broyasse": ("broyer",),
    "broyassiez": ("broyer",),
    "broyassions": ("broyer",),
    "broyâtes": ("broyer",),
    "broyât": ("broyer",),
    "broyée": ("broyer",),
    "broyées": ("broyer",),
    "broyé": ("broyer",),
    "broyèrent": ("broyer",),
    "broyés": ("broyer",),
    "broyez": ("broyer",),
    "broyiez": ("broyer",),
    "broyions": ("broyer",),
    "broyons": ("broyer",),
    "bruira": ("bruir",),
    "bruiraient": ("bruir",),
    "bruirai": ("bruir",),
    "bruirais": ("bruir",),
    "bruirait": ("bruir",),
    "bruiras": ("bruir",),
    "bruirez": ("bruir",),
    "bruiriez": ("bruir",),
    "bruirions": ("bruir",),
    "bruirons": ("bruir",),
    "bruiront": ("bruir",),
    "bruis": ("bruir",),
    "bruit": ("bruir",),
    "bruyaient": ("bruire",),
    "bruyais": ("bruire",),
    "bruyait": ("bruire",),
    "bruyiez": ("bruire",),
    "bruyions": ("bruire",),
    "bruie": ("bruir",),
    "bruies": ("bruir",),
    "brui": ("bruir",),
    "bruîmes": ("bruir",),
    "bruirent": ("bruir",),
    "bruissaient": ("bruir",),
    "bruissais": ("bruir",),
    "bruissait": ("bruir",),
    "bruissant": ("bruir",),
    "bruissent": ("bruir",),
    "bruisse": ("bruir",),
    "bruisses": ("bruir",),
    "bruissez": ("bruir",),
    "bruissiez": ("bruir",),
    "bruissions": ("bruir",),
    "bruissons": ("bruir",),
    "bruîtes": ("bruir",),
    "bruît": ("bruir",),
    "brumassaient": ("brumasser",),
    "brumassait": ("brumasser",),
    "brumassa": ("brumasser",),
    "brumassant": ("brumasser",),
    "brumassassent": ("brumasser",),
    "brumassât": ("brumasser",),
    "brumassée": ("brumasser",),
    "brumassées": ("brumasser",),
    "brumassé": ("brumasser",),
    "brumassent": ("brumasser",),
    "brumasse": ("brumasser",),
    "brumassera": ("brumasser",),
    "brumasseraient": ("brumasser",),
    "brumasserait": ("brumasser",),
    "brumassèrent": ("brumasser",),
    "brumasseront": ("brumasser",),
    "brumassés": ("brumasser",),
    "brunie": ("brunir",),
    "brunies": ("brunir",),
    "bruni": ("brunir",),
    "brunîmes": ("brunir",),
    "brunira": ("brunir",),
    "bruniraient": ("brunir",),
    "brunirai": ("brunir",),
    "brunirais": ("brunir",),
    "brunirait": ("brunir",),
    "bruniras": ("brunir",),
    "brunirent": ("brunir",),
    "brunirez": ("brunir",),
    "bruniriez": ("brunir",),
    "brunirions": ("brunir",),
    "brunirons": ("brunir",),
    "bruniront": ("brunir",),
    "brunis": ("brunir",),
    "brunissaient": ("brunir",),
    "brunissais": ("brunir",),
    "brunissait": ("brunir",),
    "brunissant": ("brunir",),
    "brunissent": ("brunir",),
    "brunisse": ("brunir",),
    "brunisses": ("brunir",),
    "brunissez": ("brunir",),
    "brunissiez": ("brunir",),
    "brunissions": ("brunir",),
    "brunissons": ("brunir",),
    "brunîtes": ("brunir",),
    "brunit": ("brunir",),
    "brunît": ("brunir",),
    "budgétaient": ("budgéter",),
    "budgétai": ("budgéter",),
    "budgétais": ("budgéter",),
    "budgétait": ("budgéter",),
    "budgéta": ("budgéter",),
    "budgétâmes": ("budgéter",),
    "budgétant": ("budgéter",),
    "budgétas": ("budgéter",),
    "budgétassent": ("budgéter",),
    "budgétasses": ("budgéter",),
    "budgétasse": ("budgéter",),
    "budgétassiez": ("budgéter",),
    "budgétassions": ("budgéter",),
    "budgétâtes": ("budgéter",),
    "budgétât": ("budgéter",),
    "budgétée": ("budgéter",),
    "budgétées": ("budgéter",),
    "budgété": ("budgéter",),
    "budgètent": ("budgéter",),
    "budgète": ("budgéter",),
    "budgétera": ("budgéter",),
    "budgéteraient": ("budgéter",),
    "budgéterai": ("budgéter",),
    "budgéterais": ("budgéter",),
    "budgéterait": ("budgéter",),
    "budgéteras": ("budgéter",),
    "budgétèrent": ("budgéter",),
    "budgéterez": ("budgéter",),
    "budgéteriez": ("budgéter",),
    "budgéterions": ("budgéter",),
    "budgéterons": ("budgéter",),
    "budgéteront": ("budgéter",),
    "budgétés": ("budgéter",),
    "budgètes": ("budgéter",),
    "budgétez": ("budgéter",),
    "budgétiez": ("budgéter",),
    "budgétions": ("budgéter",),
    "budgétons": ("budgéter",),
    "buffetaient": ("buffeter",),
    "buffetai": ("buffeter",),
    "buffetais": ("buffeter",),
    "buffetait": ("buffeter",),
    "buffeta": ("buffeter",),
    "buffetâmes": ("buffeter",),
    "buffetant": ("buffeter",),
    "buffetas": ("buffeter",),
    "buffetassent": ("buffeter",),
    "buffetasses": ("buffeter",),
    "buffetasse": ("buffeter",),
    "buffetassiez": ("buffeter",),
    "buffetassions": ("buffeter",),
    "buffetâtes": ("buffeter",),
    "buffetât": ("buffeter",),
    "buffetée": ("buffeter",),
    "buffetées": ("buffeter",),
    "buffeté": ("buffeter",),
    "buffetèrent": ("buffeter",),
    "buffetés": ("buffeter",),
    "buffetez": ("buffeter",),
    "buffetiez": ("buffeter",),
    "buffetions": ("buffeter",),
    "buffetons": ("buffeter",),
    "buffettent": ("buffeter",),
    "buffette": ("buffeter",),
    "buffettera": ("buffeter",),
    "buffetteraient": ("buffeter",),
    "buffetterai": ("buffeter",),
    "buffetterais": ("buffeter",),
    "buffetterait": ("buffeter",),
    "buffetteras": ("buffeter",),
    "buffetterez": ("buffeter",),
    "buffetteriez": ("buffeter",),
    "buffetterions": ("buffeter",),
    "buffetterons": ("buffeter",),
    "buffetteront": ("buffeter",),
    "buffettes": ("buffeter",),
    "burgeaient": ("burger",),
    "burgeai": ("burger",),
    "burgeais": ("burger",),
    "burgeait": ("burger",),
    "burgea": ("burger",),
    "burgeâmes": ("burger",),
    "burgeant": ("burger",),
    "burgeas": ("burger",),
    "burgeassent": ("burger",),
    "burgeasses": ("burger",),
    "burgeasse": ("burger",),
    "burgeassiez": ("burger",),
    "burgeassions": ("burger",),
    "burgeâtes": ("burger",),
    "burgeât": ("burger",),
    "burgé": ("burger",),
    "burgent": ("burger",),
    "burgeons": ("burger",),
    "burge": ("burger",),
    "burgera": ("burger",),
    "burgeraient": ("burger",),
    "burgerai": ("burger",),
    "burgerais": ("burger",),
    "burgerait": ("burger",),
    "burgeras": ("burger",),
    "burgèrent": ("burger",),
    "burgerez": ("burger",),
    "burgeriez": ("burger",),
    "burgerions": ("burger",),
    "burgerons": ("burger",),
    "burgeront": ("burger",),
    "burges": ("burger",),
    "burgez": ("burger",),
    "burgiez": ("burger",),
    "burgions": ("burger",),
    "cacassaient": ("cacasser",),
    "cacassai": ("cacasser",),
    "cacassais": ("cacasser",),
    "cacassait": ("cacasser",),
    "cacassa": ("cacasser",),
    "cacassâmes": ("cacasser",),
    "cacassant": ("cacasser",),
    "cacassas": ("cacasser",),
    "cacassassent": ("cacasser",),
    "cacassasses": ("cacasser",),
    "cacassasse": ("cacasser",),
    "cacassassiez": ("cacasser",),
    "cacassassions": ("cacasser",),
    "cacassâtes": ("cacasser",),
    "cacassât": ("cacasser",),
    "cacassé": ("cacasser",),
    "cacassent": ("cacasser",),
    "cacasse": ("cacasser",),
    "cacassera": ("cacasser",),
    "cacasseraient": ("cacasser",),
    "cacasserai": ("cacasser",),
    "cacasserais": ("cacasser",),
    "cacasserait": ("cacasser",),
    "cacasseras": ("cacasser",),
    "cacassèrent": ("cacasser",),
    "cacasserez": ("cacasser",),
    "cacasseriez": ("cacasser",),
    "cacasserions": ("cacasser",),
    "cacasserons": ("cacasser",),
    "cacasseront": ("cacasser",),
    "cacasses": ("cacasser",),
    "cacassez": ("cacasser",),
    "cacassiez": ("cacasser",),
    "cacassions": ("cacasser",),
    "cacassons": ("cacasser",),
    "cachetaient": ("cacheter",),
    "cachetai": ("cacheter",),
    "cachetais": ("cacheter",),
    "cachetait": ("cacheter",),
    "cacheta": ("cacheter",),
    "cachetâmes": ("cacheter",),
    "cachetant": ("cacheter",),
    "cachetas": ("cacheter",),
    "cachetassent": ("cacheter",),
    "cachetasses": ("cacheter",),
    "cachetasse": ("cacheter",),
    "cachetassiez": ("cacheter",),
    "cachetassions": ("cacheter",),
    "cachetâtes": ("cacheter",),
    "cachetât": ("cacheter",),
    "cachetée": ("cacheter",),
    "cachetées": ("cacheter",),
    "cacheté": ("cacheter",),
    "cachetèrent": ("cacheter",),
    "cachetés": ("cacheter",),
    "cachetez": ("cacheter",),
    "cachetiez": ("cacheter",),
    "cachetions": ("cacheter",),
    "cachetons": ("cacheter",),
    "cachettent": ("cacheter",),
    "cachette": ("cacheter",),
    "cachettera": ("cacheter",),
    "cachetteraient": ("cacheter",),
    "cachetterai": ("cacheter",),
    "cachetterais": ("cacheter",),
    "cachetterait": ("cacheter",),
    "cachetteras": ("cacheter",),
    "cachetterez": ("cacheter",),
    "cachetteriez": ("cacheter",),
    "cachetterions": ("cacheter",),
    "cachetterons": ("cacheter",),
    "cachetteront": ("cacheter",),
    "cachettes": ("cacheter",),
    "cadelaient": ("cadeler",),
    "cadelai": ("cadeler",),
    "cadelais": ("cadeler",),
    "cadelait": ("cadeler",),
    "cadela": ("cadeler",),
    "cadelâmes": ("cadeler",),
    "cadelant": ("cadeler",),
    "cadelas": ("cadeler",),
    "cadelassent": ("cadeler",),
    "cadelasses": ("cadeler",),
    "cadelasse": ("cadeler",),
    "cadelassiez": ("cadeler",),
    "cadelassions": ("cadeler",),
    "cadelâtes": ("cadeler",),
    "cadelât": ("cadeler",),
    "cadelée": ("cadeler",),
    "cadelées": ("cadeler",),
    "cadelé": ("cadeler",),
    "cadelèrent": ("cadeler",),
    "cadelés": ("cadeler",),
    "cadelez": ("cadeler",),
    "cadeliez": ("cadeler",),
    "cadelions": ("cadeler",),
    "cadellent": ("cadeler",),
    "cadelle": ("cadeler",),
    "cadellera": ("cadeler",),
    "cadelleraient": ("cadeler",),
    "cadellerai": ("cadeler",),
    "cadellerais": ("cadeler",),
    "cadellerait": ("cadeler",),
    "cadelleras": ("cadeler",),
    "cadellerez": ("cadeler",),
    "cadelleriez": ("cadeler",),
    "cadellerions": ("cadeler",),
    "cadellerons": ("cadeler",),
    "cadelleront": ("cadeler",),
    "cadelles": ("cadeler",),
    "cadelons": ("cadeler",),
    "cadenassaient": ("cadenasser",),
    "cadenassai": ("cadenasser",),
    "cadenassais": ("cadenasser",),
    "cadenassait": ("cadenasser",),
    "cadenassa": ("cadenasser",),
    "cadenassâmes": ("cadenasser",),
    "cadenassant": ("cadenasser",),
    "cadenassas": ("cadenasser",),
    "cadenassassent": ("cadenasser",),
    "cadenassasses": ("cadenasser",),
    "cadenassasse": ("cadenasser",),
    "cadenassassiez": ("cadenasser",),
    "cadenassassions": ("cadenasser",),
    "cadenassâtes": ("cadenasser",),
    "cadenassât": ("cadenasser",),
    "cadenassée": ("cadenasser",),
    "cadenassées": ("cadenasser",),
    "cadenassé": ("cadenasser",),
    "cadenassent": ("cadenasser",),
    "cadenasse": ("cadenasser",),
    "cadenassera": ("cadenasser",),
    "cadenasseraient": ("cadenasser",),
    "cadenasserai": ("cadenasser",),
    "cadenasserais": ("cadenasser",),
    "cadenasserait": ("cadenasser",),
    "cadenasseras": ("cadenasser",),
    "cadenassèrent": ("cadenasser",),
    "cadenasserez": ("cadenasser",),
    "cadenasseriez": ("cadenasser",),
    "cadenasserions": ("cadenasser",),
    "cadenasserons": ("cadenasser",),
    "cadenasseront": ("cadenasser",),
    "cadenassés": ("cadenasser",),
    "cadenasses": ("cadenasser",),
    "cadenassez": ("cadenasser",),
    "cadenassiez": ("cadenasser",),
    "cadenassions": ("cadenasser",),
    "cadenassons": ("cadenasser",),
    "cadençaient": ("cadencer",),
    "cadençai": ("cadencer",),
    "cadençais": ("cadencer",),
    "cadençait": ("cadencer",),
    "cadença": ("cadencer",),
    "cadençâmes": ("cadencer",),
    "cadençant": ("cadencer",),
    "cadenças": ("cadencer",),
    "cadençassent": ("cadencer",),
    "cadençasses": ("cadencer",),
    "cadençasse": ("cadencer",),
    "cadençassiez": ("cadencer",),
    "cadençassions": ("cadencer",),
    "cadençâtes": ("cadencer",),
    "cadençât": ("cadencer",),
    "cadencée": ("cadencer",),
    "cadencées": ("cadencer",),
    "cadencé": ("cadencer",),
    "cadencent": ("cadencer",),
    "cadence": ("cadencer",),
    "cadencera": ("cadencer",),
    "cadenceraient": ("cadencer",),
    "cadencerai": ("cadencer",),
    "cadencerais": ("cadencer",),
    "cadencerait": ("cadencer",),
    "cadenceras": ("cadencer",),
    "cadencèrent": ("cadencer",),
    "cadencerez": ("cadencer",),
    "cadenceriez": ("cadencer",),
    "cadencerions": ("cadencer",),
    "cadencerons": ("cadencer",),
    "cadenceront": ("cadencer",),
    "cadencés": ("cadencer",),
    "cadences": ("cadencer",),
    "cadencez": ("cadencer",),
    "cadenciez": ("cadencer",),
    "cadencions": ("cadencer",),
    "cadençons": ("cadencer",),
    "cadmiaient": ("cadmier",),
    "cadmiai": ("cadmier",),
    "cadmiais": ("cadmier",),
    "cadmiait": ("cadmier",),
    "cadmia": ("cadmier",),
    "cadmiâmes": ("cadmier",),
    "cadmiant": ("cadmier",),
    "cadmias": ("cadmier",),
    "cadmiassent": ("cadmier",),
    "cadmiasses": ("cadmier",),
    "cadmiasse": ("cadmier",),
    "cadmiassiez": ("cadmier",),
    "cadmiassions": ("cadmier",),
    "cadmiâtes": ("cadmier",),
    "cadmiât": ("cadmier",),
    "cadmiée": ("cadmier",),
    "cadmiées": ("cadmier",),
    "cadmié": ("cadmier",),
    "cadmient": ("cadmier",),
    "cadmie": ("cadmier",),
    "cadmiera": ("cadmier",),
    "cadmieraient": ("cadmier",),
    "cadmierai": ("cadmier",),
    "cadmierais": ("cadmier",),
    "cadmierait": ("cadmier",),
    "cadmieras": ("cadmier",),
    "cadmièrent": ("cadmier",),
    "cadmierez": ("cadmier",),
    "cadmieriez": ("cadmier",),
    "cadmierions": ("cadmier",),
    "cadmierons": ("cadmier",),
    "cadmieront": ("cadmier",),
    "cadmiés": ("cadmier",),
    "cadmies": ("cadmier",),
    "cadmiez": ("cadmier",),
    "cadmiiez": ("cadmier",),
    "cadmiions": ("cadmier",),
    "cadmions": ("cadmier",),
    "cailletaient": ("cailleter",),
    "cailletai": ("cailleter",),
    "cailletais": ("cailleter",),
    "cailletait": ("cailleter",),
    "cailleta": ("cailleter",),
    "cailletâmes": ("cailleter",),
    "cailletant": ("cailleter",),
    "cailletas": ("cailleter",),
    "cailletassent": ("cailleter",),
    "cailletasses": ("cailleter",),
    "cailletasse": ("cailleter",),
    "cailletassiez": ("cailleter",),
    "cailletassions": ("cailleter",),
    "cailletâtes": ("cailleter",),
    "cailletât": ("cailleter",),
    "cailletée": ("cailleter",),
    "cailletées": ("cailleter",),
    "cailleté": ("cailleter",),
    "cailletèrent": ("cailleter",),
    "cailletés": ("cailleter",),
    "cailletez": ("cailleter",),
    "cailletiez": ("cailleter",),
    "cailletions": ("cailleter",),
    "cailletons": ("cailleter",),
    "caillettent": ("cailleter",),
    "caillette": ("cailleter",),
    "caillettera": ("cailleter",),
    "cailletteraient": ("cailleter",),
    "cailletterai": ("cailleter",),
    "cailletterais": ("cailleter",),
    "cailletterait": ("cailleter",),
    "cailletteras": ("cailleter",),
    "cailletterez": ("cailleter",),
    "cailletteriez": ("cailleter",),
    "cailletterions": ("cailleter",),
    "cailletterons": ("cailleter",),
    "cailletteront": ("cailleter",),
    "caillettes": ("cailleter",),
    "calçaient": ("calcer",),
    "calçai": ("calcer",),
    "calçais": ("calcer",),
    "calçait": ("calcer",),
    "calça": ("calcer",),
    "calçâmes": ("calcer",),
    "calçant": ("calcer",),
    "calças": ("calcer",),
    "calçassent": ("calcer",),
    "calçasses": ("calcer",),
    "calçasse": ("calcer",),
    "calçassiez": ("calcer",),
    "calçassions": ("calcer",),
    "calçâtes": ("calcer",),
    "calçât": ("calcer",),
    "calcée": ("calcer",),
    "calcées": ("calcer",),
    "calcé": ("calcer",),
    "calcent": ("calcer",),
    "calce": ("calcer",),
    "calcera": ("calcer",),
    "calceraient": ("calcer",),
    "calcerai": ("calcer",),
    "calcerais": ("calcer",),
    "calcerait": ("calcer",),
    "calceras": ("calcer",),
    "calcèrent": ("calcer",),
    "calcerez": ("calcer",),
    "calceriez": ("calcer",),
    "calcerions": ("calcer",),
    "calcerons": ("calcer",),
    "calceront": ("calcer",),
    "calcés": ("calcer",),
    "calces": ("calcer",),
    "calcez": ("calcer",),
    "calciez": ("calcer",),
    "calcions": ("calcer",),
    "calçons": ("calcer",),
    "calcifiaient": ("calcifier",),
    "calcifiai": ("calcifier",),
    "calcifiais": ("calcifier",),
    "calcifiait": ("calcifier",),
    "calcifia": ("calcifier",),
    "calcifiâmes": ("calcifier",),
    "calcifiant": ("calcifier",),
    "calcifias": ("calcifier",),
    "calcifiassent": ("calcifier",),
    "calcifiasses": ("calcifier",),
    "calcifiasse": ("calcifier",),
    "calcifiassiez": ("calcifier",),
    "calcifiassions": ("calcifier",),
    "calcifiâtes": ("calcifier",),
    "calcifiât": ("calcifier",),
    "calcifiée": ("calcifier",),
    "calcifiées": ("calcifier",),
    "calcifié": ("calcifier",),
    "calcifient": ("calcifier",),
    "calcifie": ("calcifier",),
    "calcifiera": ("calcifier",),
    "calcifieraient": ("calcifier",),
    "calcifierai": ("calcifier",),
    "calcifierais": ("calcifier",),
    "calcifierait": ("calcifier",),
    "calcifieras": ("calcifier",),
    "calcifièrent": ("calcifier",),
    "calcifierez": ("calcifier",),
    "calcifieriez": ("calcifier",),
    "calcifierions": ("calcifier",),
    "calcifierons": ("calcifier",),
    "calcifieront": ("calcifier",),
    "calcifiés": ("calcifier",),
    "calcifies": ("calcifier",),
    "calcifiez": ("calcifier",),
    "calcifiiez": ("calcifier",),
    "calcifiions": ("calcifier",),
    "calcifions": ("calcifier",),
    "caletaient": ("caleter",),
    "caletai": ("caleter",),
    "caletais": ("caleter",),
    "caletait": ("caleter",),
    "caleta": ("caleter",),
    "caletâmes": ("caleter",),
    "caletant": ("caleter",),
    "caletas": ("caleter",),
    "caletassent": ("caleter",),
    "caletasses": ("caleter",),
    "caletasse": ("caleter",),
    "caletassiez": ("caleter",),
    "caletassions": ("caleter",),
    "caletâtes": ("caleter",),
    "caletât": ("caleter",),
    "caletée": ("caleter",),
    "caletées": ("caleter",),
    "caleté": ("caleter",),
    "caletèrent": ("caleter",),
    "caletés": ("caleter",),
    "caletez": ("caleter",),
    "caletiez": ("caleter",),
    "caletions": ("caleter",),
    "caletons": ("caleter",),
    "calettent": ("caleter",),
    "calette": ("caleter",),
    "calettera": ("caleter",),
    "caletteraient": ("caleter",),
    "caletterai": ("caleter",),
    "caletterais": ("caleter",),
    "caletterait": ("caleter",),
    "caletteras": ("caleter",),
    "caletterez": ("caleter",),
    "caletteriez": ("caleter",),
    "caletterions": ("caleter",),
    "caletterons": ("caleter",),
    "caletteront": ("caleter",),
    "calettes": ("caleter",),
    "calligraphiaient": ("calligraphier",),
    "calligraphiai": ("calligraphier",),
    "calligraphiais": ("calligraphier",),
    "calligraphiait": ("calligraphier",),
    "calligraphia": ("calligraphier",),
    "calligraphiâmes": ("calligraphier",),
    "calligraphiant": ("calligraphier",),
    "calligraphias": ("calligraphier",),
    "calligraphiassent": ("calligraphier",),
    "calligraphiasses": ("calligraphier",),
    "calligraphiasse": ("calligraphier",),
    "calligraphiassiez": ("calligraphier",),
    "calligraphiassions": ("calligraphier",),
    "calligraphiâtes": ("calligraphier",),
    "calligraphiât": ("calligraphier",),
    "calligraphiée": ("calligraphier",),
    "calligraphiées": ("calligraphier",),
    "calligraphié": ("calligraphier",),
    "calligraphient": ("calligraphier",),
    "calligraphie": ("calligraphier",),
    "calligraphiera": ("calligraphier",),
    "calligraphieraient": ("calligraphier",),
    "calligraphierai": ("calligraphier",),
    "calligraphierais": ("calligraphier",),
    "calligraphierait": ("calligraphier",),
    "calligraphieras": ("calligraphier",),
    "calligraphièrent": ("calligraphier",),
    "calligraphierez": ("calligraphier",),
    "calligraphieriez": ("calligraphier",),
    "calligraphierions": ("calligraphier",),
    "calligraphierons": ("calligraphier",),
    "calligraphieront": ("calligraphier",),
    "calligraphiés": ("calligraphier",),
    "calligraphies": ("calligraphier",),
    "calligraphiez": ("calligraphier",),
    "calligraphiiez": ("calligraphier",),
    "calligraphiions": ("calligraphier",),
    "calligraphions": ("calligraphier",),
    "calmie": ("calmir",),
    "calmies": ("calmir",),
    "calmi": ("calmir",),
    "calmîmes": ("calmir",),
    "calmira": ("calmir",),
    "calmiraient": ("calmir",),
    "calmirai": ("calmir",),
    "calmirais": ("calmir",),
    "calmirait": ("calmir",),
    "calmiras": ("calmir",),
    "calmirent": ("calmir",),
    "calmirez": ("calmir",),
    "calmiriez": ("calmir",),
    "calmirions": ("calmir",),
    "calmirons": ("calmir",),
    "calmiront": ("calmir",),
    "calmis": ("calmir",),
    "calmissaient": ("calmir",),
    "calmissais": ("calmir",),
    "calmissait": ("calmir",),
    "calmissant": ("calmir",),
    "calmissent": ("calmir",),
    "calmisse": ("calmir",),
    "calmisses": ("calmir",),
    "calmissez": ("calmir",),
    "calmissiez": ("calmir",),
    "calmissions": ("calmir",),
    "calmissons": ("calmir",),
    "calmîtes": ("calmir",),
    "calmit": ("calmir",),
    "calmît": ("calmir",),
    "calomniaient": ("calomnier",),
    "calomniai": ("calomnier",),
    "calomniais": ("calomnier",),
    "calomniait": ("calomnier",),
    "calomnia": ("calomnier",),
    "calomniâmes": ("calomnier",),
    "calomniant": ("calomnier",),
    "calomnias": ("calomnier",),
    "calomniassent": ("calomnier",),
    "calomniasses": ("calomnier",),
    "calomniasse": ("calomnier",),
    "calomniassiez": ("calomnier",),
    "calomniassions": ("calomnier",),
    "calomniâtes": ("calomnier",),
    "calomniât": ("calomnier",),
    "calomniée": ("calomnier",),
    "calomniées": ("calomnier",),
    "calomnié": ("calomnier",),
    "calomnient": ("calomnier",),
    "calomnie": ("calomnier",),
    "calomniera": ("calomnier",),
    "calomnieraient": ("calomnier",),
    "calomnierai": ("calomnier",),
    "calomnierais": ("calomnier",),
    "calomnierait": ("calomnier",),
    "calomnieras": ("calomnier",),
    "calomnièrent": ("calomnier",),
    "calomnierez": ("calomnier",),
    "calomnieriez": ("calomnier",),
    "calomnierions": ("calomnier",),
    "calomnierons": ("calomnier",),
    "calomnieront": ("calomnier",),
    "calomniés": ("calomnier",),
    "calomnies": ("calomnier",),
    "calomniez": ("calomnier",),
    "calomniiez": ("calomnier",),
    "calomniions": ("calomnier",),
    "calomnions": ("calomnier",),
    "calorifiaient": ("calorifier",),
    "calorifiai": ("calorifier",),
    "calorifiais": ("calorifier",),
    "calorifiait": ("calorifier",),
    "calorifia": ("calorifier",),
    "calorifiâmes": ("calorifier",),
    "calorifiant": ("calorifier",),
    "calorifias": ("calorifier",),
    "calorifiassent": ("calorifier",),
    "calorifiasses": ("calorifier",),
    "calorifiasse": ("calorifier",),
    "calorifiassiez": ("calorifier",),
    "calorifiassions": ("calorifier",),
    "calorifiâtes": ("calorifier",),
    "calorifiât": ("calorifier",),
    "calorifiée": ("calorifier",),
    "calorifiées": ("calorifier",),
    "calorifié": ("calorifier",),
    "calorifient": ("calorifier",),
    "calorifie": ("calorifier",),
    "calorifiera": ("calorifier",),
    "calorifieraient": ("calorifier",),
    "calorifierai": ("calorifier",),
    "calorifierais": ("calorifier",),
    "calorifierait": ("calorifier",),
    "calorifieras": ("calorifier",),
    "calorifièrent": ("calorifier",),
    "calorifierez": ("calorifier",),
    "calorifieriez": ("calorifier",),
    "calorifierions": ("calorifier",),
    "calorifierons": ("calorifier",),
    "calorifieront": ("calorifier",),
    "calorifiés": ("calorifier",),
    "calorifies": ("calorifier",),
    "calorifiez": ("calorifier",),
    "calorifiiez": ("calorifier",),
    "calorifiions": ("calorifier",),
    "calorifions": ("calorifier",),
    "calorifugeaient": ("calorifuger",),
    "calorifugeai": ("calorifuger",),
    "calorifugeais": ("calorifuger",),
    "calorifugeait": ("calorifuger",),
    "calorifugea": ("calorifuger",),
    "calorifugeâmes": ("calorifuger",),
    "calorifugeant": ("calorifuger",),
    "calorifugeas": ("calorifuger",),
    "calorifugeassent": ("calorifuger",),
    "calorifugeasses": ("calorifuger",),
    "calorifugeasse": ("calorifuger",),
    "calorifugeassiez": ("calorifuger",),
    "calorifugeassions": ("calorifuger",),
    "calorifugeâtes": ("calorifuger",),
    "calorifugeât": ("calorifuger",),
    "calorifugée": ("calorifuger",),
    "calorifugées": ("calorifuger",),
    "calorifugé": ("calorifuger",),
    "calorifugent": ("calorifuger",),
    "calorifugeons": ("calorifuger",),
    "calorifuge": ("calorifuger",),
    "calorifugera": ("calorifuger",),
    "calorifugeraient": ("calorifuger",),
    "calorifugerai": ("calorifuger",),
    "calorifugerais": ("calorifuger",),
    "calorifugerait": ("calorifuger",),
    "calorifugeras": ("calorifuger",),
    "calorifugèrent": ("calorifuger",),
    "calorifugerez": ("calorifuger",),
    "calorifugeriez": ("calorifuger",),
    "calorifugerions": ("calorifuger",),
    "calorifugerons": ("calorifuger",),
    "calorifugeront": ("calorifuger",),
    "calorifugés": ("calorifuger",),
    "calorifuges": ("calorifuger",),
    "calorifugez": ("calorifuger",),
    "calorifugiez": ("calorifuger",),
    "calorifugions": ("calorifuger",),
    "candie": ("candir",),
    "candies": ("candir",),
    "candi": ("candir",),
    "candîmes": ("candir",),
    "candira": ("candir",),
    "candiraient": ("candir",),
    "candirai": ("candir",),
    "candirais": ("candir",),
    "candirait": ("candir",),
    "candiras": ("candir",),
    "candirent": ("candir",),
    "candirez": ("candir",),
    "candiriez": ("candir",),
    "candirions": ("candir",),
    "candirons": ("candir",),
    "candiront": ("candir",),
    "candis": ("candir",),
    "candissaient": ("candir",),
    "candissais": ("candir",),
    "candissait": ("candir",),
    "candissant": ("candir",),
    "candissent": ("candir",),
    "candisse": ("candir",),
    "candisses": ("candir",),
    "candissez": ("candir",),
    "candissiez": ("candir",),
    "candissions": ("candir",),
    "candissons": ("candir",),
    "candîtes": ("candir",),
    "candit": ("candir",),
    "candît": ("candir",),
    "canetaient": ("caneter",),
    "canetai": ("caneter",),
    "canetais": ("caneter",),
    "canetait": ("caneter",),
    "caneta": ("caneter",),
    "canetâmes": ("caneter",),
    "canetant": ("caneter",),
    "canetas": ("caneter",),
    "canetassent": ("caneter",),
    "canetasses": ("caneter",),
    "canetasse": ("caneter",),
    "canetassiez": ("caneter",),
    "canetassions": ("caneter",),
    "canetâtes": ("caneter",),
    "canetât": ("caneter",),
    "canetée": ("caneter",),
    "canetées": ("caneter",),
    "caneté": ("caneter",),
    "canetèrent": ("caneter",),
    "canetés": ("caneter",),
    "canetez": ("caneter",),
    "canetiez": ("caneter",),
    "canetions": ("caneter",),
    "canetons": ("caneter",),
    "canettent": ("caneter",),
    "canette": ("caneter",),
    "canettera": ("caneter",),
    "canetteraient": ("caneter",),
    "canetterai": ("caneter",),
    "canetterais": ("caneter",),
    "canetterait": ("caneter",),
    "canetteras": ("caneter",),
    "canetterez": ("caneter",),
    "canetteriez": ("caneter",),
    "canetterions": ("caneter",),
    "canetterons": ("caneter",),
    "canetteront": ("caneter",),
    "canettes": ("caneter",),
    "canevassaient": ("canevasser",),
    "canevassai": ("canevasser",),
    "canevassais": ("canevasser",),
    "canevassait": ("canevasser",),
    "canevassa": ("canevasser",),
    "canevassâmes": ("canevasser",),
    "canevassant": ("canevasser",),
    "canevassas": ("canevasser",),
    "canevassassent": ("canevasser",),
    "canevassasses": ("canevasser",),
    "canevassasse": ("canevasser",),
    "canevassassiez": ("canevasser",),
    "canevassassions": ("canevasser",),
    "canevassâtes": ("canevasser",),
    "canevassât": ("canevasser",),
    "canevassée": ("canevasser",),
    "canevassées": ("canevasser",),
    "canevassé": ("canevasser",),
    "canevassent": ("canevasser",),
    "canevasse": ("canevasser",),
    "canevassera": ("canevasser",),
    "canevasseraient": ("canevasser",),
    "canevasserai": ("canevasser",),
    "canevasserais": ("canevasser",),
    "canevasserait": ("canevasser",),
    "canevasseras": ("canevasser",),
    "canevassèrent": ("canevasser",),
    "canevasserez": ("canevasser",),
    "canevasseriez": ("canevasser",),
    "canevasserions": ("canevasser",),
    "canevasserons": ("canevasser",),
    "canevasseront": ("canevasser",),
    "canevassés": ("canevasser",),
    "canevasses": ("canevasser",),
    "canevassez": ("canevasser",),
    "canevassiez": ("canevasser",),
    "canevassions": ("canevasser",),
    "canevassons": ("canevasser",),
    "cannelaient": ("canneler",),
    "cannelai": ("canneler",),
    "cannelais": ("canneler",),
    "cannelait": ("canneler",),
    "cannela": ("canneler",),
    "cannelâmes": ("canneler",),
    "cannelant": ("canneler",),
    "cannelas": ("canneler",),
    "cannelassent": ("canneler",),
    "cannelasses": ("canneler",),
    "cannelasse": ("canneler",),
    "cannelassiez": ("canneler",),
    "cannelassions": ("canneler",),
    "cannelâtes": ("canneler",),
    "cannelât": ("canneler",),
    "cannelée": ("canneler",),
    "cannelées": ("canneler",),
    "cannelé": ("canneler",),
    "cannelèrent": ("canneler",),
    "cannelés": ("canneler",),
    "cannelez": ("canneler",),
    "canneliez": ("canneler",),
    "cannelions": ("canneler",),
    "cannellent": ("canneler",),
    "cannelle": ("canneler",),
    "cannellera": ("canneler",),
    "cannelleraient": ("canneler",),
    "cannellerai": ("canneler",),
    "cannellerais": ("canneler",),
    "cannellerait": ("canneler",),
    "cannelleras": ("canneler",),
    "cannellerez": ("canneler",),
    "cannelleriez": ("canneler",),
    "cannellerions": ("canneler",),
    "cannellerons": ("canneler",),
    "cannelleront": ("canneler",),
    "cannelles": ("canneler",),
    "cannelons": ("canneler",),
    "cannetaient": ("canneter",),
    "cannetai": ("canneter",),
    "cannetais": ("canneter",),
    "cannetait": ("canneter",),
    "canneta": ("canneter",),
    "cannetâmes": ("canneter",),
    "cannetant": ("canneter",),
    "cannetas": ("canneter",),
    "cannetassent": ("canneter",),
    "cannetasses": ("canneter",),
    "cannetasse": ("canneter",),
    "cannetassiez": ("canneter",),
    "cannetassions": ("canneter",),
    "cannetâtes": ("canneter",),
    "cannetât": ("canneter",),
    "cannetée": ("canneter",),
    "cannetées": ("canneter",),
    "canneté": ("canneter",),
    "cannetèrent": ("canneter",),
    "cannetés": ("canneter",),
    "cannetez": ("canneter",),
    "cannetiez": ("canneter",),
    "cannetions": ("canneter",),
    "cannetons": ("canneter",),
    "cannettent": ("canneter",),
    "cannette": ("canneter",),
    "cannettera": ("canneter",),
    "cannetteraient": ("canneter",),
    "cannetterai": ("canneter",),
    "cannetterais": ("canneter",),
    "cannetterait": ("canneter",),
    "cannetteras": ("canneter",),
    "cannetterez": ("canneter",),
    "cannetteriez": ("canneter",),
    "cannetterions": ("canneter",),
    "cannetterons": ("canneter",),
    "cannetteront": ("canneter",),
    "cannettes": ("canneter",),
    "canquetaient": ("canqueter",),
    "canquetai": ("canqueter",),
    "canquetais": ("canqueter",),
    "canquetait": ("canqueter",),
    "canqueta": ("canqueter",),
    "canquetâmes": ("canqueter",),
    "canquetant": ("canqueter",),
    "canquetas": ("canqueter",),
    "canquetassent": ("canqueter",),
    "canquetasses": ("canqueter",),
    "canquetasse": ("canqueter",),
    "canquetassiez": ("canqueter",),
    "canquetassions": ("canqueter",),
    "canquetâtes": ("canqueter",),
    "canquetât": ("canqueter",),
    "canquetée": ("canqueter",),
    "canquetées": ("canqueter",),
    "canqueté": ("canqueter",),
    "canquetèrent": ("canqueter",),
    "canquetés": ("canqueter",),
    "canquetez": ("canqueter",),
    "canquetiez": ("canqueter",),
    "canquetions": ("canqueter",),
    "canquetons": ("canqueter",),
    "canquettent": ("canqueter",),
    "canquette": ("canqueter",),
    "canquettera": ("canqueter",),
    "canquetteraient": ("canqueter",),
    "canquetterai": ("canqueter",),
    "canquetterais": ("canqueter",),
    "canquetterait": ("canqueter",),
    "canquetteras": ("canqueter",),
    "canquetterez": ("canqueter",),
    "canquetteriez": ("canqueter",),
    "canquetterions": ("canqueter",),
    "canquetterons": ("canqueter",),
    "canquetteront": ("canqueter",),
    "canquettes": ("canqueter",),
    "capéaient": ("capéer",),
    "capéai": ("capéer",),
    "capéais": ("capéer",),
    "capéait": ("capéer",),
    "capéa": ("capéer",),
    "capéâmes": ("capéer",),
    "capéant": ("capéer",),
    "capéas": ("capéer",),
    "capéassent": ("capéer",),
    "capéasses": ("capéer",),
    "capéasse": ("capéer",),
    "capéassiez": ("capéer",),
    "capéassions": ("capéer",),
    "capéâtes": ("capéer",),
    "capéât": ("capéer",),
    "capéé": ("capéer",),
    "capéent": ("capéer",),
    "capée": ("capéer",),
    "capéera": ("capéer",),
    "capéeraient": ("capéer",),
    "capéerai": ("capéer",),
    "capéerais": ("capéer",),
    "capéerait": ("capéer",),
    "capéeras": ("capéer",),
    "capéèrent": ("capéer",),
    "capéerez": ("capéer",),
    "capéeriez": ("capéer",),
    "capéerions": ("capéer",),
    "capéerons": ("capéer",),
    "capéeront": ("capéer",),
    "capées": ("capéer",),
    "capéez": ("capéer",),
    "capéiez": ("capéer",),
    "capéions": ("capéer",),
    "capéons": ("capéer",),
    "capelaient": ("capeler",),
    "capelai": ("capeler",),
    "capelais": ("capeler",),
    "capelait": ("capeler",),
    "capela": ("capeler",),
    "capelâmes": ("capeler",),
    "capelant": ("capeler",),
    "capelas": ("capeler",),
    "capelassent": ("capeler",),
    "capelasses": ("capeler",),
    "capelasse": ("capeler",),
    "capelassiez": ("capeler",),
    "capelassions": ("capeler",),
    "capelâtes": ("capeler",),
    "capelât": ("capeler",),
    "capelée": ("capeler",),
    "capelées": ("capeler",),
    "capelé": ("capeler",),
    "capelèrent": ("capeler",),
    "capelés": ("capeler",),
    "capelez": ("capeler",),
    "capeliez": ("capeler",),
    "capelions": ("capeler",),
    "capellent": ("capeler",),
    "capelle": ("capeler",),
    "capellera": ("capeler",),
    "capelleraient": ("capeler",),
    "capellerai": ("capeler",),
    "capellerais": ("capeler",),
    "capellerait": ("capeler",),
    "capelleras": ("capeler",),
    "capellerez": ("capeler",),
    "capelleriez": ("capeler",),
    "capellerions": ("capeler",),
    "capellerons": ("capeler",),
    "capelleront": ("capeler",),
    "capelles": ("capeler",),
    "capelons": ("capeler",),
    "capiaient": ("capier",),
    "capiai": ("capier",),
    "capiais": ("capier",),
    "capiait": ("capier",),
    "capia": ("capier",),
    "capiâmes": ("capier",),
    "capiant": ("capier",),
    "capias": ("capier",),
    "capiassent": ("capier",),
    "capiasses": ("capier",),
    "capiasse": ("capier",),
    "capiassiez": ("capier",),
    "capiassions": ("capier",),
    "capiâtes": ("capier",),
    "capiât": ("capier",),
    "capiée": ("capier",),
    "capiées": ("capier",),
    "capié": ("capier",),
    "capient": ("capier",),
    "capie": ("capier",),
    "capiera": ("capier",),
    "capieraient": ("capier",),
    "capierai": ("capier",),
    "capierais": ("capier",),
    "capierait": ("capier",),
    "capieras": ("capier",),
    "capièrent": ("capier",),
    "capierez": ("capier",),
    "capieriez": ("capier",),
    "capierions": ("capier",),
    "capierons": ("capier",),
    "capieront": ("capier",),
    "capiés": ("capier",),
    "capies": ("capier",),
    "capiez": ("capier",),
    "capiiez": ("capier",),
    "capiions": ("capier",),
    "capions": ("capier",),
    "caprifiaient": ("caprifier",),
    "caprifiai": ("caprifier",),
    "caprifiais": ("caprifier",),
    "caprifiait": ("caprifier",),
    "caprifia": ("caprifier",),
    "caprifiâmes": ("caprifier",),
    "caprifiant": ("caprifier",),
    "caprifias": ("caprifier",),
    "caprifiassent": ("caprifier",),
    "caprifiasses": ("caprifier",),
    "caprifiasse": ("caprifier",),
    "caprifiassiez": ("caprifier",),
    "caprifiassions": ("caprifier",),
    "caprifiâtes": ("caprifier",),
    "caprifiât": ("caprifier",),
    "caprifiée": ("caprifier",),
    "caprifiées": ("caprifier",),
    "caprifié": ("caprifier",),
    "caprifient": ("caprifier",),
    "caprifie": ("caprifier",),
    "caprifiera": ("caprifier",),
    "caprifieraient": ("caprifier",),
    "caprifierai": ("caprifier",),
    "caprifierais": ("caprifier",),
    "caprifierait": ("caprifier",),
    "caprifieras": ("caprifier",),
    "caprifièrent": ("caprifier",),
    "caprifierez": ("caprifier",),
    "caprifieriez": ("caprifier",),
    "caprifierions": ("caprifier",),
    "caprifierons": ("caprifier",),
    "caprifieront": ("caprifier",),
    "caprifiés": ("caprifier",),
    "caprifies": ("caprifier",),
    "caprifiez": ("caprifier",),
    "caprifiiez": ("caprifier",),
    "caprifiions": ("caprifier",),
    "caprifions": ("caprifier",),
    "caquetaient": ("caqueter",),
    "caquetai": ("caqueter",),
    "caquetais": ("caqueter",),
    "caquetait": ("caqueter",),
    "caqueta": ("caqueter",),
    "caquetâmes": ("caqueter",),
    "caquetant": ("caqueter",),
    "caquetas": ("caqueter",),
    "caquetassent": ("caqueter",),
    "caquetasses": ("caqueter",),
    "caquetasse": ("caqueter",),
    "caquetassiez": ("caqueter",),
    "caquetassions": ("caqueter",),
    "caquetâtes": ("caqueter",),
    "caquetât": ("caqueter",),
    "caquetée": ("caqueter",),
    "caquetées": ("caqueter",),
    "caqueté": ("caqueter",),
    "caquetèrent": ("caqueter",),
    "caquetés": ("caqueter",),
    "caquetez": ("caqueter",),
    "caquetiez": ("caqueter",),
    "caquetions": ("caqueter",),
    "caquetons": ("caqueter",),
    "caquettent": ("caqueter",),
    "caquette": ("caqueter",),
    "caquettera": ("caqueter",),
    "caquetteraient": ("caqueter",),
    "caquetterai": ("caqueter",),
    "caquetterais": ("caqueter",),
    "caquetterait": ("caqueter",),
    "caquetteras": ("caqueter",),
    "caquetterez": ("caqueter",),
    "caquetteriez": ("caqueter",),
    "caquetterions": ("caqueter",),
    "caquetterons": ("caqueter",),
    "caquetteront": ("caqueter",),
    "caquettes": ("caqueter",),
    "carençaient": ("carencer",),
    "carençai": ("carencer",),
    "carençais": ("carencer",),
    "carençait": ("carencer",),
    "carença": ("carencer",),
    "carençâmes": ("carencer",),
    "carençant": ("carencer",),
    "carenças": ("carencer",),
    "carençassent": ("carencer",),
    "carençasses": ("carencer",),
    "carençasse": ("carencer",),
    "carençassiez": ("carencer",),
    "carençassions": ("carencer",),
    "carençâtes": ("carencer",),
    "carençât": ("carencer",),
    "carencée": ("carencer",),
    "carencées": ("carencer",),
    "carencé": ("carencer",),
    "carencent": ("carencer",),
    "carence": ("carencer",),
    "carencera": ("carencer",),
    "carenceraient": ("carencer",),
    "carencerai": ("carencer",),
    "carencerais": ("carencer",),
    "carencerait": ("carencer",),
    "carenceras": ("carencer",),
    "carencèrent": ("carencer",),
    "carencerez": ("carencer",),
    "carenceriez": ("carencer",),
    "carencerions": ("carencer",),
    "carencerons": ("carencer",),
    "carenceront": ("carencer",),
    "carencés": ("carencer",),
    "carences": ("carencer",),
    "carencez": ("carencer",),
    "carenciez": ("carencer",),
    "carencions": ("carencer",),
    "carençons": ("carencer",),
    "carénaient": ("caréner",),
    "carénai": ("caréner",),
    "carénais": ("caréner",),
    "carénait": ("caréner",),
    "caréna": ("caréner",),
    "carénâmes": ("caréner",),
    "carénant": ("caréner",),
    "carénas": ("caréner",),
    "carénassent": ("caréner",),
    "carénasses": ("caréner",),
    "carénasse": ("caréner",),
    "carénassiez": ("caréner",),
    "carénassions": ("caréner",),
    "carénâtes": ("caréner",),
    "carénât": ("caréner",),
    "carénée": ("caréner",),
    "carénées": ("caréner",),
    "caréné": ("caréner",),
    "carènent": ("caréner",),
    "carène": ("caréner",),
    "carénera": ("caréner",),
    "caréneraient": ("caréner",),
    "carénerai": ("caréner",),
    "carénerais": ("caréner",),
    "carénerait": ("caréner",),
    "caréneras": ("caréner",),
    "carénèrent": ("caréner",),
    "carénerez": ("caréner",),
    "caréneriez": ("caréner",),
    "carénerions": ("caréner",),
    "carénerons": ("caréner",),
    "caréneront": ("caréner",),
    "carénés": ("caréner",),
    "carènes": ("caréner",),
    "carénez": ("caréner",),
    "caréniez": ("caréner",),
    "carénions": ("caréner",),
    "carénons": ("caréner",),
    "cariaient": ("carier",),
    "cariai": ("carier",),
    "cariais": ("carier",),
    "cariait": ("carier",),
    "caria": ("carier",),
    "cariâmes": ("carier",),
    "cariant": ("carier",),
    "carias": ("carier",),
    "cariassent": ("carier",),
    "cariasses": ("carier",),
    "cariasse": ("carier",),
    "cariassiez": ("carier",),
    "cariassions": ("carier",),
    "cariâtes": ("carier",),
    "cariât": ("carier",),
    "cariée": ("carier",),
    "cariées": ("carier",),
    "carié": ("carier",),
    "carient": ("carier",),
    "carie": ("carier",),
    "cariera": ("carier",),
    "carieraient": ("carier",),
    "carierai": ("carier",),
    "carierais": ("carier",),
    "carierait": ("carier",),
    "carieras": ("carier",),
    "carièrent": ("carier",),
    "carierez": ("carier",),
    "carieriez": ("carier",),
    "carierions": ("carier",),
    "carierons": ("carier",),
    "carieront": ("carier",),
    "cariés": ("carier",),
    "caries": ("carier",),
    "cariez": ("carier",),
    "cariiez": ("carier",),
    "cariions": ("carier",),
    "carions": ("carier",),
    "carnelaient": ("carneler",),
    "carnelai": ("carneler",),
    "carnelais": ("carneler",),
    "carnelait": ("carneler",),
    "carnela": ("carneler",),
    "carnelâmes": ("carneler",),
    "carnelant": ("carneler",),
    "carnelas": ("carneler",),
    "carnelassent": ("carneler",),
    "carnelasses": ("carneler",),
    "carnelasse": ("carneler",),
    "carnelassiez": ("carneler",),
    "carnelassions": ("carneler",),
    "carnelâtes": ("carneler",),
    "carnelât": ("carneler",),
    "carnelée": ("carneler",),
    "carnelées": ("carneler",),
    "carnelé": ("carneler",),
    "carnèlent": ("carneler",),
    "carnèle": ("carneler",),
    "carnèlera": ("carneler",),
    "carnèleraient": ("carneler",),
    "carnèlerai": ("carneler",),
    "carnèlerais": ("carneler",),
    "carnèlerait": ("carneler",),
    "carnèleras": ("carneler",),
    "carnelèrent": ("carneler",),
    "carnèlerez": ("carneler",),
    "carnèleriez": ("carneler",),
    "carnèlerions": ("carneler",),
    "carnèlerons": ("carneler",),
    "carnèleront": ("carneler",),
    "carnelés": ("carneler",),
    "carnèles": ("carneler",),
    "carnelez": ("carneler",),
    "carneliez": ("carneler",),
    "carnelions": ("carneler",),
    "carnelons": ("carneler",),
    "carnifiaient": ("carnifier",),
    "carnifiai": ("carnifier",),
    "carnifiais": ("carnifier",),
    "carnifiait": ("carnifier",),
    "carnifia": ("carnifier",),
    "carnifiâmes": ("carnifier",),
    "carnifiant": ("carnifier",),
    "carnifias": ("carnifier",),
    "carnifiassent": ("carnifier",),
    "carnifiasses": ("carnifier",),
    "carnifiasse": ("carnifier",),
    "carnifiassiez": ("carnifier",),
    "carnifiassions": ("carnifier",),
    "carnifiâtes": ("carnifier",),
    "carnifiât": ("carnifier",),
    "carnifiée": ("carnifier",),
    "carnifiées": ("carnifier",),
    "carnifié": ("carnifier",),
    "carnifient": ("carnifier",),
    "carnifie": ("carnifier",),
    "carnifiera": ("carnifier",),
    "carnifieraient": ("carnifier",),
    "carnifierai": ("carnifier",),
    "carnifierais": ("carnifier",),
    "carnifierait": ("carnifier",),
    "carnifieras": ("carnifier",),
    "carnifièrent": ("carnifier",),
    "carnifierez": ("carnifier",),
    "carnifieriez": ("carnifier",),
    "carnifierions": ("carnifier",),
    "carnifierons": ("carnifier",),
    "carnifieront": ("carnifier",),
    "carnifiés": ("carnifier",),
    "carnifies": ("carnifier",),
    "carnifiez": ("carnifier",),
    "carnifiiez": ("carnifier",),
    "carnifiions": ("carnifier",),
    "carnifions": ("carnifier",),
    "carrelaient": ("carreler",),
    "carrelai": ("carreler",),
    "carrelais": ("carreler",),
    "carrelait": ("carreler",),
    "carrela": ("carreler",),
    "carrelâmes": ("carreler",),
    "carrelant": ("carreler",),
    "carrelas": ("carreler",),
    "carrelassent": ("carreler",),
    "carrelasses": ("carreler",),
    "carrelasse": ("carreler",),
    "carrelassiez": ("carreler",),
    "carrelassions": ("carreler",),
    "carrelâtes": ("carreler",),
    "carrelât": ("carreler",),
    "carrelée": ("carreler",),
    "carrelées": ("carreler",),
    "carrelé": ("carreler",),
    "carrelèrent": ("carreler",),
    "carrelés": ("carreler",),
    "carrelez": ("carreler",),
    "carreliez": ("carreler",),
    "carrelions": ("carreler",),
    "carrellent": ("carreler",),
    "carrelle": ("carreler",),
    "carrellera": ("carreler",),
    "carrelleraient": ("carreler",),
    "carrellerai": ("carreler",),
    "carrellerais": ("carreler",),
    "carrellerait": ("carreler",),
    "carrelleras": ("carreler",),
    "carrellerez": ("carreler",),
    "carrelleriez": ("carreler",),
    "carrellerions": ("carreler",),
    "carrellerons": ("carreler",),
    "carrelleront": ("carreler",),
    "carrelles": ("carreler",),
    "carrelons": ("carreler",),
    "carroient": ("carroyer",),
    "carroie": ("carroyer",),
    "carroiera": ("carroyer",),
    "carroieraient": ("carroyer",),
    "carroierai": ("carroyer",),
    "carroierais": ("carroyer",),
    "carroierait": ("carroyer",),
    "carroieras": ("carroyer",),
    "carroierez": ("carroyer",),
    "carroieriez": ("carroyer",),
    "carroierions": ("carroyer",),
    "carroierons": ("carroyer",),
    "carroieront": ("carroyer",),
    "carroies": ("carroyer",),
    "carroyaient": ("carroyer",),
    "carroyai": ("carroyer",),
    "carroyais": ("carroyer",),
    "carroyait": ("carroyer",),
    "carroya": ("carroyer",),
    "carroyâmes": ("carroyer",),
    "carroyant": ("carroyer",),
    "carroyas": ("carroyer",),
    "carroyassent": ("carroyer",),
    "carroyasses": ("carroyer",),
    "carroyasse": ("carroyer",),
    "carroyassiez": ("carroyer",),
    "carroyassions": ("carroyer",),
    "carroyâtes": ("carroyer",),
    "carroyât": ("carroyer",),
    "carroyée": ("carroyer",),
    "carroyées": ("carroyer",),
    "carroyé": ("carroyer",),
    "carroyèrent": ("carroyer",),
    "carroyés": ("carroyer",),
    "carroyez": ("carroyer",),
    "carroyiez": ("carroyer",),
    "carroyions": ("carroyer",),
    "carroyons": ("carroyer",),
    "cartaient": ("cartayer",),
    "cartaie": ("cartayer",),
    "cartaiera": ("cartayer",),
    "cartaieraient": ("cartayer",),
    "cartaierai": ("cartayer",),
    "cartaierais": ("cartayer",),
    "cartaierait": ("cartayer",),
    "cartaieras": ("cartayer",),
    "cartaierez": ("cartayer",),
    "cartaieriez": ("cartayer",),
    "cartaierions": ("cartayer",),
    "cartaierons": ("cartayer",),
    "cartaieront": ("cartayer",),
    "cartaies": ("cartayer",),
    "cartayaient": ("cartayer",),
    "cartayai": ("cartayer",),
    "cartayais": ("cartayer",),
    "cartayait": ("cartayer",),
    "cartaya": ("cartayer",),
    "cartayâmes": ("cartayer",),
    "cartayant": ("cartayer",),
    "cartayas": ("cartayer",),
    "cartayassent": ("cartayer",),
    "cartayasses": ("cartayer",),
    "cartayasse": ("cartayer",),
    "cartayassiez": ("cartayer",),
    "cartayassions": ("cartayer",),
    "cartayâtes": ("cartayer",),
    "cartayât": ("cartayer",),
    "cartayé": ("cartayer",),
    "cartayent": ("cartayer",),
    "cartaye": ("cartayer",),
    "cartayera": ("cartayer",),
    "cartayeraient": ("cartayer",),
    "cartayerai": ("cartayer",),
    "cartayerais": ("cartayer",),
    "cartayerait": ("cartayer",),
    "cartayeras": ("cartayer",),
    "cartayèrent": ("cartayer",),
    "cartayerez": ("cartayer",),
    "cartayeriez": ("cartayer",),
    "cartayerions": ("cartayer",),
    "cartayerons": ("cartayer",),
    "cartayeront": ("cartayer",),
    "cartayes": ("cartayer",),
    "cartayez": ("cartayer",),
    "cartayiez": ("cartayer",),
    "cartayions": ("cartayer",),
    "cartayons": ("cartayer",),
    "cartographiaient": ("cartographier",),
    "cartographiai": ("cartographier",),
    "cartographiais": ("cartographier",),
    "cartographiait": ("cartographier",),
    "cartographia": ("cartographier",),
    "cartographiâmes": ("cartographier",),
    "cartographiant": ("cartographier",),
    "cartographias": ("cartographier",),
    "cartographiassent": ("cartographier",),
    "cartographiasses": ("cartographier",),
    "cartographiasse": ("cartographier",),
    "cartographiassiez": ("cartographier",),
    "cartographiassions": ("cartographier",),
    "cartographiâtes": ("cartographier",),
    "cartographiât": ("cartographier",),
    "cartographiée": ("cartographier",),
    "cartographiées": ("cartographier",),
    "cartographié": ("cartographier",),
    "cartographient": ("cartographier",),
    "cartographie": ("cartographier",),
    "cartographiera": ("cartographier",),
    "cartographieraient": ("cartographier",),
    "cartographierai": ("cartographier",),
    "cartographierais": ("cartographier",),
    "cartographierait": ("cartographier",),
    "cartographieras": ("cartographier",),
    "cartographièrent": ("cartographier",),
    "cartographierez": ("cartographier",),
    "cartographieriez": ("cartographier",),
    "cartographierions": ("cartographier",),
    "cartographierons": ("cartographier",),
    "cartographieront": ("cartographier",),
    "cartographiés": ("cartographier",),
    "cartographies": ("cartographier",),
    "cartographiez": ("cartographier",),
    "cartographiiez": ("cartographier",),
    "cartographiions": ("cartographier",),
    "cartographions": ("cartographier",),
    "caséifiaient": ("caséifier",),
    "caséifiai": ("caséifier",),
    "caséifiais": ("caséifier",),
    "caséifiait": ("caséifier",),
    "caséifia": ("caséifier",),
    "caséifiâmes": ("caséifier",),
    "caséifiant": ("caséifier",),
    "caséifias": ("caséifier",),
    "caséifiassent": ("caséifier",),
    "caséifiasses": ("caséifier",),
    "caséifiasse": ("caséifier",),
    "caséifiassiez": ("caséifier",),
    "caséifiassions": ("caséifier",),
    "caséifiâtes": ("caséifier",),
    "caséifiât": ("caséifier",),
    "caséifiée": ("caséifier",),
    "caséifiées": ("caséifier",),
    "caséifié": ("caséifier",),
    "caséifient": ("caséifier",),
    "caséifie": ("caséifier",),
    "caséifiera": ("caséifier",),
    "caséifieraient": ("caséifier",),
    "caséifierai": ("caséifier",),
    "caséifierais": ("caséifier",),
    "caséifierait": ("caséifier",),
    "caséifieras": ("caséifier",),
    "caséifièrent": ("caséifier",),
    "caséifierez": ("caséifier",),
    "caséifieriez": ("caséifier",),
    "caséifierions": ("caséifier",),
    "caséifierons": ("caséifier",),
    "caséifieront": ("caséifier",),
    "caséifiés": ("caséifier",),
    "caséifies": ("caséifier",),
    "caséifiez": ("caséifier",),
    "caséifiiez": ("caséifier",),
    "caséifiions": ("caséifier",),
    "caséifions": ("caséifier",),
    "cassaient": ("casser",),
    "cassai": ("casser",),
    "cassais": ("casser",),
    "cassait": ("casser",),
    "cassa": ("casser",),
    "cassâmes": ("casser",),
    "cassant": ("casser",),
    "cassas": ("casser",),
    "cassassent": ("casser",),
    "cassasses": ("casser",),
    "cassasse": ("casser",),
    "cassassiez": ("casser",),
    "cassassions": ("casser",),
    "cassâtes": ("casser",),
    "cassât": ("casser",),
    "cassée": ("casser",),
    "cassées": ("casser",),
    "cassé": ("casser",),
    "cassent": ("casser",),
    "casse": ("casser",),
    "cassera": ("casser",),
    "casseraient": ("casser",),
    "casserai": ("casser",),
    "casserais": ("casser",),
    "casserait": ("casser",),
    "casseras": ("casser",),
    "cassèrent": ("casser",),
    "casserez": ("casser",),
    "casseriez": ("casser",),
    "casserions": ("casser",),
    "casserons": ("casser",),
    "casseront": ("casser",),
    "cassés": ("casser",),
    "casses": ("casser",),
    "cassez": ("casser",),
    "cassiez": ("casser",),
    "cassions": ("casser",),
    "cassons": ("casser",),
    "catie": ("catir",),
    "caties": ("catir",),
    "cati": ("catir",),
    "catîmes": ("catir",),
    "catira": ("catir",),
    "catiraient": ("catir",),
    "catirai": ("catir",),
    "catirais": ("catir",),
    "catirait": ("catir",),
    "catiras": ("catir",),
    "catirent": ("catir",),
    "catirez": ("catir",),
    "catiriez": ("catir",),
    "catirions": ("catir",),
    "catirons": ("catir",),
    "catiront": ("catir",),
    "catis": ("catir",),
    "catissaient": ("catir",),
    "catissais": ("catir",),
    "catissait": ("catir",),
    "catissant": ("catir",),
    "catissent": ("catir",),
    "catisse": ("catir",),
    "catisses": ("catir",),
    "catissez": ("catir",),
    "catissiez": ("catir",),
    "catissions": ("catir",),
    "catissons": ("catir",),
    "catîtes": ("catir",),
    "catit": ("catir",),
    "catît": ("catir",),
    "caustifiaient": ("caustifier",),
    "caustifiai": ("caustifier",),
    "caustifiais": ("caustifier",),
    "caustifiait": ("caustifier",),
    "caustifia": ("caustifier",),
    "caustifiâmes": ("caustifier",),
    "caustifiant": ("caustifier",),
    "caustifias": ("caustifier",),
    "caustifiassent": ("caustifier",),
    "caustifiasses": ("caustifier",),
    "caustifiasse": ("caustifier",),
    "caustifiassiez": ("caustifier",),
    "caustifiassions": ("caustifier",),
    "caustifiâtes": ("caustifier",),
    "caustifiât": ("caustifier",),
    "caustifiée": ("caustifier",),
    "caustifiées": ("caustifier",),
    "caustifié": ("caustifier",),
    "caustifient": ("caustifier",),
    "caustifie": ("caustifier",),
    "caustifiera": ("caustifier",),
    "caustifieraient": ("caustifier",),
    "caustifierai": ("caustifier",),
    "caustifierais": ("caustifier",),
    "caustifierait": ("caustifier",),
    "caustifieras": ("caustifier",),
    "caustifièrent": ("caustifier",),
    "caustifierez": ("caustifier",),
    "caustifieriez": ("caustifier",),
    "caustifierions": ("caustifier",),
    "caustifierons": ("caustifier",),
    "caustifieront": ("caustifier",),
    "caustifiés": ("caustifier",),
    "caustifies": ("caustifier",),
    "caustifiez": ("caustifier",),
    "caustifiiez": ("caustifier",),
    "caustifiions": ("caustifier",),
    "caustifions": ("caustifier",),
    "cédaient": ("céder",),
    "cédai": ("céder",),
    "cédais": ("céder",),
    "cédait": ("céder",),
    "céda": ("céder",),
    "cédâmes": ("céder",),
    "cédant": ("céder",),
    "cédas": ("céder",),
    "cédassent": ("céder",),
    "cédasses": ("céder",),
    "cédasse": ("céder",),
    "cédassiez": ("céder",),
    "cédassions": ("céder",),
    "cédâtes": ("céder",),
    "cédât": ("céder",),
    "cédée": ("céder",),
    "cédées": ("céder",),
    "cédé": ("céder",),
    "cèdent": ("céder",),
    "cède": ("céder",),
    "cédera": ("céder",),
    "céderaient": ("céder",),
    "céderai": ("céder",),
    "céderais": ("céder",),
    "céderait": ("céder",),
    "céderas": ("céder",),
    "cédèrent": ("céder",),
    "céderez": ("céder",),
    "céderiez": ("céder",),
    "céderions": ("céder",),
    "céderons": ("céder",),
    "céderont": ("céder",),
    "cédés": ("céder",),
    "cèdes": ("céder",),
    "cédez": ("céder",),
    "cédiez": ("céder",),
    "cédions": ("céder",),
    "cédons": ("céder",),
    "ceignaient": ("ceindre",),
    "ceignais": ("ceindre",),
    "ceignait": ("ceindre",),
    "ceignant": ("ceindre",),
    "ceignent": ("ceindre",),
    "ceigne": ("ceindre",),
    "ceignes": ("ceindre",),
    "ceignez": ("ceindre",),
    "ceigniez": ("ceindre",),
    "ceignîmes": ("ceindre",),
    "ceignions": ("ceindre",),
    "ceignirent": ("ceindre",),
    "ceignis": ("ceindre",),
    "ceignissent": ("ceindre",),
    "ceignisses": ("ceindre",),
    "ceignisse": ("ceindre",),
    "ceignissiez": ("ceindre",),
    "ceignissions": ("ceindre",),
    "ceignîtes": ("ceindre",),
    "ceignit": ("ceindre",),
    "ceignît": ("ceindre",),
    "ceignons": ("ceindre",),
    "ceindra": ("ceindre",),
    "ceindraient": ("ceindre",),
    "ceindrai": ("ceindre",),
    "ceindrais": ("ceindre",),
    "ceindrait": ("ceindre",),
    "ceindras": ("ceindre",),
    "ceindrez": ("ceindre",),
    "ceindriez": ("ceindre",),
    "ceindrions": ("ceindre",),
    "ceindrons": ("ceindre",),
    "ceindront": ("ceindre",),
    "ceins": ("ceindre",),
    "ceinte": ("ceindre",),
    "ceintes": ("ceindre",),
    "ceint": ("ceindre",),
    "ceints": ("ceindre",),
    "célébraient": ("célébrer",),
    "célébrai": ("célébrer",),
    "célébrais": ("célébrer",),
    "célébrait": ("célébrer",),
    "célébra": ("célébrer",),
    "célébrâmes": ("célébrer",),
    "célébrant": ("célébrer",),
    "célébras": ("célébrer",),
    "célébrassent": ("célébrer",),
    "célébrasses": ("célébrer",),
    "célébrasse": ("célébrer",),
    "célébrassiez": ("célébrer",),
    "célébrassions": ("célébrer",),
    "célébrâtes": ("célébrer",),
    "célébrât": ("célébrer",),
    "célébrée": ("célébrer",),
    "célébrées": ("célébrer",),
    "célébré": ("célébrer",),
    "célèbrent": ("célébrer",),
    "célèbre": ("célébrer",),
    "célébrera": ("célébrer",),
    "célébreraient": ("célébrer",),
    "célébrerai": ("célébrer",),
    "célébrerais": ("célébrer",),
    "célébrerait": ("célébrer",),
    "célébreras": ("célébrer",),
    "célébrèrent": ("célébrer",),
    "célébrerez": ("célébrer",),
    "célébreriez": ("célébrer",),
    "célébrerions": ("célébrer",),
    "célébrerons": ("célébrer",),
    "célébreront": ("célébrer",),
    "célébrés": ("célébrer",),
    "célèbres": ("célébrer",),
    "célébrez": ("célébrer",),
    "célébriez": ("célébrer",),
    "célébrions": ("célébrer",),
    "célébrons": ("célébrer",),
    "celaient": ("celer",),
    "celai": ("celer",),
    "celais": ("celer",),
    "celait": ("celer",),
    "cela": ("celer",),
    "celâmes": ("celer",),
    "celant": ("celer",),
    "celas": ("celer",),
    "celassent": ("celer",),
    "celasses": ("celer",),
    "celasse": ("celer",),
    "celassiez": ("celer",),
    "celassions": ("celer",),
    "celâtes": ("celer",),
    "celât": ("celer",),
    "celée": ("celer",),
    "celées": ("celer",),
    "celé": ("celer",),
    "cèlent": ("celer",),
    "cèle": ("celer",),
    "cèlera": ("celer",),
    "cèleraient": ("celer",),
    "cèlerai": ("celer",),
    "cèlerais": ("celer",),
    "cèlerait": ("celer",),
    "cèleras": ("celer",),
    "celèrent": ("celer",),
    "cèlerez": ("celer",),
    "cèleriez": ("celer",),
    "cèlerions": ("celer",),
    "cèlerons": ("celer",),
    "cèleront": ("celer",),
    "celés": ("celer",),
    "cèles": ("celer",),
    "celez": ("celer",),
    "celiez": ("celer",),
    "celions": ("celer",),
    "celons": ("celer",),
    "centrifugeaient": ("centrifuger",),
    "centrifugeai": ("centrifuger",),
    "centrifugeais": ("centrifuger",),
    "centrifugeait": ("centrifuger",),
    "centrifugea": ("centrifuger",),
    "centrifugeâmes": ("centrifuger",),
    "centrifugeant": ("centrifuger",),
    "centrifugeas": ("centrifuger",),
    "centrifugeassent": ("centrifuger",),
    "centrifugeasses": ("centrifuger",),
    "centrifugeasse": ("centrifuger",),
    "centrifugeassiez": ("centrifuger",),
    "centrifugeassions": ("centrifuger",),
    "centrifugeâtes": ("centrifuger",),
    "centrifugeât": ("centrifuger",),
    "centrifugée": ("centrifuger",),
    "centrifugées": ("centrifuger",),
    "centrifugé": ("centrifuger",),
    "centrifugent": ("centrifuger",),
    "centrifugeons": ("centrifuger",),
    "centrifuge": ("centrifuger",),
    "centrifugera": ("centrifuger",),
    "centrifugeraient": ("centrifuger",),
    "centrifugerai": ("centrifuger",),
    "centrifugerais": ("centrifuger",),
    "centrifugerait": ("centrifuger",),
    "centrifugeras": ("centrifuger",),
    "centrifugèrent": ("centrifuger",),
    "centrifugerez": ("centrifuger",),
    "centrifugeriez": ("centrifuger",),
    "centrifugerions": ("centrifuger",),
    "centrifugerons": ("centrifuger",),
    "centrifugeront": ("centrifuger",),
    "centrifugés": ("centrifuger",),
    "centrifuges": ("centrifuger",),
    "centrifugez": ("centrifuger",),
    "centrifugiez": ("centrifuger",),
    "centrifugions": ("centrifuger",),
    "cérifiaient": ("cérifier",),
    "cérifiai": ("cérifier",),
    "cérifiais": ("cérifier",),
    "cérifiait": ("cérifier",),
    "cérifia": ("cérifier",),
    "cérifiâmes": ("cérifier",),
    "cérifiant": ("cérifier",),
    "cérifias": ("cérifier",),
    "cérifiassent": ("cérifier",),
    "cérifiasses": ("cérifier",),
    "cérifiasse": ("cérifier",),
    "cérifiassiez": ("cérifier",),
    "cérifiassions": ("cérifier",),
    "cérifiâtes": ("cérifier",),
    "cérifiât": ("cérifier",),
    "cérifiée": ("cérifier",),
    "cérifiées": ("cérifier",),
    "cérifié": ("cérifier",),
    "cérifient": ("cérifier",),
    "cérifie": ("cérifier",),
    "cérifiera": ("cérifier",),
    "cérifieraient": ("cérifier",),
    "cérifierai": ("cérifier",),
    "cérifierais": ("cérifier",),
    "cérifierait": ("cérifier",),
    "cérifieras": ("cérifier",),
    "cérifièrent": ("cérifier",),
    "cérifierez": ("cérifier",),
    "cérifieriez": ("cérifier",),
    "cérifierions": ("cérifier",),
    "cérifierons": ("cérifier",),
    "cérifieront": ("cérifier",),
    "cérifiés": ("cérifier",),
    "cérifies": ("cérifier",),
    "cérifiez": ("cérifier",),
    "cérifiiez": ("cérifier",),
    "cérifiions": ("cérifier",),
    "cérifions": ("cérifier",),
    "certifiaient": ("certifier",),
    "certifiai": ("certifier",),
    "certifiais": ("certifier",),
    "certifiait": ("certifier",),
    "certifia": ("certifier",),
    "certifiâmes": ("certifier",),
    "certifiant": ("certifier",),
    "certifias": ("certifier",),
    "certifiassent": ("certifier",),
    "certifiasses": ("certifier",),
    "certifiasse": ("certifier",),
    "certifiassiez": ("certifier",),
    "certifiassions": ("certifier",),
    "certifiâtes": ("certifier",),
    "certifiât": ("certifier",),
    "certifiée": ("certifier",),
    "certifiées": ("certifier",),
    "certifié": ("certifier",),
    "certifient": ("certifier",),
    "certifie": ("certifier",),
    "certifiera": ("certifier",),
    "certifieraient": ("certifier",),
    "certifierai": ("certifier",),
    "certifierais": ("certifier",),
    "certifierait": ("certifier",),
    "certifieras": ("certifier",),
    "certifièrent": ("certifier",),
    "certifierez": ("certifier",),
    "certifieriez": ("certifier",),
    "certifierions": ("certifier",),
    "certifierons": ("certifier",),
    "certifieront": ("certifier",),
    "certifiés": ("certifier",),
    "certifies": ("certifier",),
    "certifiez": ("certifier",),
    "certifiiez": ("certifier",),
    "certifiions": ("certifier",),
    "certifions": ("certifier",),
    "chalcographiaient": ("chalcographier",),
    "chalcographiai": ("chalcographier",),
    "chalcographiais": ("chalcographier",),
    "chalcographiait": ("chalcographier",),
    "chalcographia": ("chalcographier",),
    "chalcographiâmes": ("chalcographier",),
    "chalcographiant": ("chalcographier",),
    "chalcographias": ("chalcographier",),
    "chalcographiassent": ("chalcographier",),
    "chalcographiasses": ("chalcographier",),
    "chalcographiasse": ("chalcographier",),
    "chalcographiassiez": ("chalcographier",),
    "chalcographiassions": ("chalcographier",),
    "chalcographiâtes": ("chalcographier",),
    "chalcographiât": ("chalcographier",),
    "chalcographiée": ("chalcographier",),
    "chalcographiées": ("chalcographier",),
    "chalcographié": ("chalcographier",),
    "chalcographient": ("chalcographier",),
    "chalcographie": ("chalcographier",),
    "chalcographiera": ("chalcographier",),
    "chalcographieraient": ("chalcographier",),
    "chalcographierai": ("chalcographier",),
    "chalcographierais": ("chalcographier",),
    "chalcographierait": ("chalcographier",),
    "chalcographieras": ("chalcographier",),
    "chalcographièrent": ("chalcographier",),
    "chalcographierez": ("chalcographier",),
    "chalcographieriez": ("chalcographier",),
    "chalcographierions": ("chalcographier",),
    "chalcographierons": ("chalcographier",),
    "chalcographieront": ("chalcographier",),
    "chalcographiés": ("chalcographier",),
    "chalcographies": ("chalcographier",),
    "chalcographiez": ("chalcographier",),
    "chalcographiiez": ("chalcographier",),
    "chalcographiions": ("chalcographier",),
    "chalcographions": ("chalcographier",),
    "challengeaient": ("challenger",),
    "challengeai": ("challenger",),
    "challengeais": ("challenger",),
    "challengeait": ("challenger",),
    "challengea": ("challenger",),
    "challengeâmes": ("challenger",),
    "challengeant": ("challenger",),
    "challengeas": ("challenger",),
    "challengeassent": ("challenger",),
    "challengeasses": ("challenger",),
    "challengeasse": ("challenger",),
    "challengeassiez": ("challenger",),
    "challengeassions": ("challenger",),
    "challengeâtes": ("challenger",),
    "challengeât": ("challenger",),
    "challengée": ("challenger",),
    "challengées": ("challenger",),
    "challengé": ("challenger",),
    "challengent": ("challenger",),
    "challengeons": ("challenger",),
    "challenge": ("challenger",),
    "challengera": ("challenger",),
    "challengeraient": ("challenger",),
    "challengerai": ("challenger",),
    "challengerais": ("challenger",),
    "challengerait": ("challenger",),
    "challengeras": ("challenger",),
    "challengèrent": ("challenger",),
    "challengerez": ("challenger",),
    "challengeriez": ("challenger",),
    "challengerions": ("challenger",),
    "challengerons": ("challenger",),
    "challengeront": ("challenger",),
    "challengés": ("challenger",),
    "challenges": ("challenger",),
    "challengez": ("challenger",),
    "challengiez": ("challenger",),
    "challengions": ("challenger",),
    "chaut": ("chaloir",),
    "champlevaient": ("champlever",),
    "champlevai": ("champlever",),
    "champlevais": ("champlever",),
    "champlevait": ("champlever",),
    "champleva": ("champlever",),
    "champlevâmes": ("champlever",),
    "champlevant": ("champlever",),
    "champlevas": ("champlever",),
    "champlevassent": ("champlever",),
    "champlevasses": ("champlever",),
    "champlevasse": ("champlever",),
    "champlevassiez": ("champlever",),
    "champlevassions": ("champlever",),
    "champlevâtes": ("champlever",),
    "champlevât": ("champlever",),
    "champlevée": ("champlever",),
    "champlevées": ("champlever",),
    "champlevé": ("champlever",),
    "champlèvent": ("champlever",),
    "champlève": ("champlever",),
    "champlèvera": ("champlever",),
    "champlèveraient": ("champlever",),
    "champlèverai": ("champlever",),
    "champlèverais": ("champlever",),
    "champlèverait": ("champlever",),
    "champlèveras": ("champlever",),
    "champlevèrent": ("champlever",),
    "champlèverez": ("champlever",),
    "champlèveriez": ("champlever",),
    "champlèverions": ("champlever",),
    "champlèverons": ("champlever",),
    "champlèveront": ("champlever",),
    "champlevés": ("champlever",),
    "champlèves": ("champlever",),
    "champlevez": ("champlever",),
    "champleviez": ("champlever",),
    "champlevions": ("champlever",),
    "champlevons": ("champlever",),
    "chancelaient": ("chanceler",),
    "chancelai": ("chanceler",),
    "chancelais": ("chanceler",),
    "chancelait": ("chanceler",),
    "chancela": ("chanceler",),
    "chancelâmes": ("chanceler",),
    "chancelant": ("chanceler",),
    "chancelas": ("chanceler",),
    "chancelassent": ("chanceler",),
    "chancelasses": ("chanceler",),
    "chancelasse": ("chanceler",),
    "chancelassiez": ("chanceler",),
    "chancelassions": ("chanceler",),
    "chancelâtes": ("chanceler",),
    "chancelât": ("chanceler",),
    "chancelé": ("chanceler",),
    "chancelèrent": ("chanceler",),
    "chancelez": ("chanceler",),
    "chanceliez": ("chanceler",),
    "chancelions": ("chanceler",),
    "chancellent": ("chanceler",),
    "chancelle": ("chanceler",),
    "chancellera": ("chanceler",),
    "chancelleraient": ("chanceler",),
    "chancellerai": ("chanceler",),
    "chancellerais": ("chanceler",),
    "chancellerait": ("chanceler",),
    "chancelleras": ("chanceler",),
    "chancellerez": ("chanceler",),
    "chancelleriez": ("chanceler",),
    "chancellerions": ("chanceler",),
    "chancellerons": ("chanceler",),
    "chancelleront": ("chanceler",),
    "chancelles": ("chanceler",),
    "chancelons": ("chanceler",),
    "chancie": ("chancir",),
    "chancies": ("chancir",),
    "chanci": ("chancir",),
    "chancîmes": ("chancir",),
    "chancira": ("chancir",),
    "chanciraient": ("chancir",),
    "chancirai": ("chancir",),
    "chancirais": ("chancir",),
    "chancirait": ("chancir",),
    "chanciras": ("chancir",),
    "chancirent": ("chancir",),
    "chancirez": ("chancir",),
    "chanciriez": ("chancir",),
    "chancirions": ("chancir",),
    "chancirons": ("chancir",),
    "chanciront": ("chancir",),
    "chancis": ("chancir",),
    "chancissaient": ("chancir",),
    "chancissais": ("chancir",),
    "chancissait": ("chancir",),
    "chancissant": ("chancir",),
    "chancissent": ("chancir",),
    "chancisse": ("chancir",),
    "chancisses": ("chancir",),
    "chancissez": ("chancir",),
    "chancissiez": ("chancir",),
    "chancissions": ("chancir",),
    "chancissons": ("chancir",),
    "chancîtes": ("chancir",),
    "chancit": ("chancir",),
    "chancît": ("chancir",),
    "changeaient": ("changer",),
    "changeai": ("changer",),
    "changeais": ("changer",),
    "changeait": ("changer",),
    "changea": ("changer",),
    "changeâmes": ("changer",),
    "changeant": ("changer",),
    "changeas": ("changer",),
    "changeassent": ("changer",),
    "changeasses": ("changer",),
    "changeasse": ("changer",),
    "changeassiez": ("changer",),
    "changeassions": ("changer",),
    "changeâtes": ("changer",),
    "changeât": ("changer",),
    "changée": ("changer",),
    "changées": ("changer",),
    "changé": ("changer",),
    "changent": ("changer",),
    "changeons": ("changer",),
    "change": ("changer",),
    "changera": ("changer",),
    "changeraient": ("changer",),
    "changerai": ("changer",),
    "changerais": ("changer",),
    "changerait": ("changer",),
    "changeras": ("changer",),
    "changèrent": ("changer",),
    "changerez": ("changer",),
    "changeriez": ("changer",),
    "changerions": ("changer",),
    "changerons": ("changer",),
    "changeront": ("changer",),
    "changés": ("changer",),
    "changes": ("changer",),
    "changez": ("changer",),
    "changiez": ("changer",),
    "changions": ("changer",),
    "chapelaient": ("chapeler",),
    "chapelai": ("chapeler",),
    "chapelais": ("chapeler",),
    "chapelait": ("chapeler",),
    "chapela": ("chapeler",),
    "chapelâmes": ("chapeler",),
    "chapelant": ("chapeler",),
    "chapelas": ("chapeler",),
    "chapelassent": ("chapeler",),
    "chapelasses": ("chapeler",),
    "chapelasse": ("chapeler",),
    "chapelassiez": ("chapeler",),
    "chapelassions": ("chapeler",),
    "chapelâtes": ("chapeler",),
    "chapelât": ("chapeler",),
    "chapelée": ("chapeler",),
    "chapelées": ("chapeler",),
    "chapelé": ("chapeler",),
    "chapelèrent": ("chapeler",),
    "chapelés": ("chapeler",),
    "chapelez": ("chapeler",),
    "chapeliez": ("chapeler",),
    "chapelions": ("chapeler",),
    "chapellent": ("chapeler",),
    "chapelle": ("chapeler",),
    "chapellera": ("chapeler",),
    "chapelleraient": ("chapeler",),
    "chapellerai": ("chapeler",),
    "chapellerais": ("chapeler",),
    "chapellerait": ("chapeler",),
    "chapelleras": ("chapeler",),
    "chapellerez": ("chapeler",),
    "chapelleriez": ("chapeler",),
    "chapellerions": ("chapeler",),
    "chapellerons": ("chapeler",),
    "chapelleront": ("chapeler",),
    "chapelles": ("chapeler",),
    "chapelons": ("chapeler",),
    "chargeaient": ("charger",),
    "chargeai": ("charger",),
    "chargeais": ("charger",),
    "chargeait": ("charger",),
    "chargea": ("charger",),
    "chargeâmes": ("charger",),
    "chargeant": ("charger",),
    "chargeas": ("charger",),
    "chargeassent": ("charger",),
    "chargeasses": ("charger",),
    "chargeasse": ("charger",),
    "chargeassiez": ("charger",),
    "chargeassions": ("charger",),
    "chargeâtes": ("charger",),
    "chargeât": ("charger",),
    "chargée": ("charger",),
    "chargées": ("charger",),
    "chargé": ("charger",),
    "chargent": ("charger",),
    "chargeons": ("charger",),
    "charge": ("charger",),
    "chargera": ("charger",),
    "chargeraient": ("charger",),
    "chargerai": ("charger",),
    "chargerais": ("charger",),
    "chargerait": ("charger",),
    "chargeras": ("charger",),
    "chargèrent": ("charger",),
    "chargerez": ("charger",),
    "chargeriez": ("charger",),
    "chargerions": ("charger",),
    "chargerons": ("charger",),
    "chargeront": ("charger",),
    "chargés": ("charger",),
    "charges": ("charger",),
    "chargez": ("charger",),
    "chargiez": ("charger",),
    "chargions": ("charger",),
    "charpie": ("charpir",),
    "charpies": ("charpir",),
    "charpi": ("charpir",),
    "charpîmes": ("charpir",),
    "charpira": ("charpir",),
    "charpiraient": ("charpir",),
    "charpirai": ("charpir",),
    "charpirais": ("charpir",),
    "charpirait": ("charpir",),
    "charpiras": ("charpir",),
    "charpirent": ("charpir",),
    "charpirez": ("charpir",),
    "charpiriez": ("charpir",),
    "charpirions": ("charpir",),
    "charpirons": ("charpir",),
    "charpiront": ("charpir",),
    "charpis": ("charpir",),
    "charpissaient": ("charpir",),
    "charpissais": ("charpir",),
    "charpissait": ("charpir",),
    "charpissant": ("charpir",),
    "charpissent": ("charpir",),
    "charpisse": ("charpir",),
    "charpisses": ("charpir",),
    "charpissez": ("charpir",),
    "charpissiez": ("charpir",),
    "charpissions": ("charpir",),
    "charpissons": ("charpir",),
    "charpîtes": ("charpir",),
    "charpit": ("charpir",),
    "charpît": ("charpir",),
    "charriaient": ("charrier",),
    "charriai": ("charrier",),
    "charriais": ("charrier",),
    "charriait": ("charrier",),
    "charria": ("charrier",),
    "charriâmes": ("charrier",),
    "charriant": ("charrier",),
    "charrias": ("charrier",),
    "charriassent": ("charrier",),
    "charriasses": ("charrier",),
    "charriasse": ("charrier",),
    "charriassiez": ("charrier",),
    "charriassions": ("charrier",),
    "charriâtes": ("charrier",),
    "charriât": ("charrier",),
    "charriée": ("charrier",),
    "charriées": ("charrier",),
    "charrié": ("charrier",),
    "charrient": ("charrier",),
    "charrie": ("charrier",),
    "charriera": ("charrier",),
    "charrieraient": ("charrier",),
    "charrierai": ("charrier",),
    "charrierais": ("charrier",),
    "charrierait": ("charrier",),
    "charrieras": ("charrier",),
    "charrièrent": ("charrier",),
    "charrierez": ("charrier",),
    "charrieriez": ("charrier",),
    "charrierions": ("charrier",),
    "charrierons": ("charrier",),
    "charrieront": ("charrier",),
    "charriés": ("charrier",),
    "charries": ("charrier",),
    "charriez": ("charrier",),
    "charriiez": ("charrier",),
    "charriions": ("charrier",),
    "charrions": ("charrier",),
    "charroient": ("charroyer",),
    "charroie": ("charroyer",),
    "charroiera": ("charroyer",),
    "charroieraient": ("charroyer",),
    "charroierai": ("charroyer",),
    "charroierais": ("charroyer",),
    "charroierait": ("charroyer",),
    "charroieras": ("charroyer",),
    "charroierez": ("charroyer",),
    "charroieriez": ("charroyer",),
    "charroierions": ("charroyer",),
    "charroierons": ("charroyer",),
    "charroieront": ("charroyer",),
    "charroies": ("charroyer",),
    "charroyaient": ("charroyer",),
    "charroyai": ("charroyer",),
    "charroyais": ("charroyer",),
    "charroyait": ("charroyer",),
    "charroya": ("charroyer",),
    "charroyâmes": ("charroyer",),
    "charroyant": ("charroyer",),
    "charroyas": ("charroyer",),
    "charroyassent": ("charroyer",),
    "charroyasses": ("charroyer",),
    "charroyasse": ("charroyer",),
    "charroyassiez": ("charroyer",),
    "charroyassions": ("charroyer",),
    "charroyâtes": ("charroyer",),
    "charroyât": ("charroyer",),
    "charroyée": ("charroyer",),
    "charroyées": ("charroyer",),
    "charroyé": ("charroyer",),
    "charroyèrent": ("charroyer",),
    "charroyés": ("charroyer",),
    "charroyez": ("charroyer",),
    "charroyiez": ("charroyer",),
    "charroyions": ("charroyer",),
    "charroyons": ("charroyer",),
    "chassaient": ("chasser",),
    "chassai": ("chasser",),
    "chassais": ("chasser",),
    "chassait": ("chasser",),
    "chassa": ("chasser",),
    "chassâmes": ("chasser",),
    "chassant": ("chasser",),
    "chassas": ("chasser",),
    "chassassent": ("chasser",),
    "chassasses": ("chasser",),
    "chassasse": ("chasser",),
    "chassassiez": ("chasser",),
    "chassassions": ("chasser",),
    "chassâtes": ("chasser",),
    "chassât": ("chasser",),
    "chassée": ("chasser",),
    "chassées": ("chasser",),
    "chassé": ("chasser",),
    "chassent": ("chasser",),
    "chasse": ("chasser",),
    "chassera": ("chasser",),
    "chasseraient": ("chasser",),
    "chasserai": ("chasser",),
    "chasserais": ("chasser",),
    "chasserait": ("chasser",),
    "chasseras": ("chasser",),
    "chassèrent": ("chasser",),
    "chasserez": ("chasser",),
    "chasseriez": ("chasser",),
    "chasserions": ("chasser",),
    "chasserons": ("chasser",),
    "chasseront": ("chasser",),
    "chassés": ("chasser",),
    "chasses": ("chasser",),
    "chassez": ("chasser",),
    "chassiez": ("chasser",),
    "chassions": ("chasser",),
    "chassons": ("chasser",),
    "châtiaient": ("châtier",),
    "châtiai": ("châtier",),
    "châtiais": ("châtier",),
    "châtiait": ("châtier",),
    "châtia": ("châtier",),
    "châtiâmes": ("châtier",),
    "châtiant": ("châtier",),
    "châtias": ("châtier",),
    "châtiassent": ("châtier",),
    "châtiasses": ("châtier",),
    "châtiasse": ("châtier",),
    "châtiassiez": ("châtier",),
    "châtiassions": ("châtier",),
    "châtiâtes": ("châtier",),
    "châtiât": ("châtier",),
    "châtiée": ("châtier",),
    "châtiées": ("châtier",),
    "châtié": ("châtier",),
    "châtient": ("châtier",),
    "châtie": ("châtier",),
    "châtiera": ("châtier",),
    "châtieraient": ("châtier",),
    "châtierai": ("châtier",),
    "châtierais": ("châtier",),
    "châtierait": ("châtier",),
    "châtieras": ("châtier",),
    "châtièrent": ("châtier",),
    "châtierez": ("châtier",),
    "châtieriez": ("châtier",),
    "châtierions": ("châtier",),
    "châtierons": ("châtier",),
    "châtieront": ("châtier",),
    "châtiés": ("châtier",),
    "châties": ("châtier",),
    "châtiez": ("châtier",),
    "châtiiez": ("châtier",),
    "châtiions": ("châtier",),
    "châtions": ("châtier",),
    "chatoient": ("chatoyer",),
    "chatoie": ("chatoyer",),
    "chatoiera": ("chatoyer",),
    "chatoieraient": ("chatoyer",),
    "chatoierai": ("chatoyer",),
    "chatoierais": ("chatoyer",),
    "chatoierait": ("chatoyer",),
    "chatoieras": ("chatoyer",),
    "chatoierez": ("chatoyer",),
    "chatoieriez": ("chatoyer",),
    "chatoierions": ("chatoyer",),
    "chatoierons": ("chatoyer",),
    "chatoieront": ("chatoyer",),
    "chatoies": ("chatoyer",),
    "chatoyaient": ("chatoyer",),
    "chatoyai": ("chatoyer",),
    "chatoyais": ("chatoyer",),
    "chatoyait": ("chatoyer",),
    "chatoya": ("chatoyer",),
    "chatoyâmes": ("chatoyer",),
    "chatoyant": ("chatoyer",),
    "chatoyas": ("chatoyer",),
    "chatoyassent": ("chatoyer",),
    "chatoyasses": ("chatoyer",),
    "chatoyasse": ("chatoyer",),
    "chatoyassiez": ("chatoyer",),
    "chatoyassions": ("chatoyer",),
    "chatoyâtes": ("chatoyer",),
    "chatoyât": ("chatoyer",),
    "chatoyé": ("chatoyer",),
    "chatoyèrent": ("chatoyer",),
    "chatoyez": ("chatoyer",),
    "chatoyiez": ("chatoyer",),
    "chatoyions": ("chatoyer",),
    "chatoyons": ("chatoyer",),
    "chauvaient": ("chauvir",),
    "chauvais": ("chauvir",),
    "chauvait": ("chauvir",),
    "chauvant": ("chauvir",),
    "chauvent": ("chauvir",),
    "chauve": ("chauvir",),
    "chauves": ("chauvir",),
    "chauvez": ("chauvir",),
    "chauviez": ("chauvir",),
    "chauvi": ("chauvir",),
    "chauvîmes": ("chauvir",),
    "chauvions": ("chauvir",),
    "chauvira": ("chauvir",),
    "chauviraient": ("chauvir",),
    "chauvirai": ("chauvir",),
    "chauvirais": ("chauvir",),
    "chauvirait": ("chauvir",),
    "chauviras": ("chauvir",),
    "chauvirent": ("chauvir",),
    "chauvirez": ("chauvir",),
    "chauviriez": ("chauvir",),
    "chauvirions": ("chauvir",),
    "chauvirons": ("chauvir",),
    "chauviront": ("chauvir",),
    "chauvis": ("chauvir",),
    "chauvissent": ("chauvir",),
    "chauvisses": ("chauvir",),
    "chauvisse": ("chauvir",),
    "chauvissiez": ("chauvir",),
    "chauvissions": ("chauvir",),
    "chauvîtes": ("chauvir",),
    "chauvit": ("chauvir",),
    "chauvît": ("chauvir",),
    "chauvons": ("chauvir",),
    "chéraient": ("chérer",),
    "chérai": ("chérer",),
    "chérais": ("chérer",),
    "chérait": ("chérer",),
    "chéra": ("chérer",),
    "chérâmes": ("chérer",),
    "chérant": ("chérer",),
    "chéras": ("chérer",),
    "chérassent": ("chérer",),
    "chérasses": ("chérer",),
    "chérasse": ("chérer",),
    "chérassiez": ("chérer",),
    "chérassions": ("chérer",),
    "chérâtes": ("chérer",),
    "chérât": ("chérer",),
    "chérée": ("chérer",),
    "chérées": ("chérer",),
    "chéré": ("chérer",),
    "chèrent": ("chérer",),
    "chère": ("chérer",),
    "chérera": ("chérer",),
    "chéreraient": ("chérer",),
    "chérerai": ("chérer",),
    "chérerais": ("chérer",),
    "chérerait": ("chérer",),
    "chéreras": ("chérer",),
    "chérèrent": ("chérer",),
    "chérerez": ("chérer",),
    "chéreriez": ("chérer",),
    "chérerions": ("chérer",),
    "chérerons": ("chérer",),
    "chéreront": ("chérer",),
    "chérés": ("chérer",),
    "chères": ("chérer",),
    "chérez": ("chérer",),
    "chériez": ("chérer",),
    "chérions": ("chérer",),
    "chérons": ("chérer",),
    "chérie": ("chérir",),
    "chéries": ("chérir",),
    "chéri": ("chérir",),
    "chérîmes": ("chérir",),
    "chérira": ("chérir",),
    "chériraient": ("chérir",),
    "chérirai": ("chérir",),
    "chérirais": ("chérir",),
    "chérirait": ("chérir",),
    "chériras": ("chérir",),
    "chérirent": ("chérir",),
    "chérirez": ("chérir",),
    "chéririez": ("chérir",),
    "chéririons": ("chérir",),
    "chérirons": ("chérir",),
    "chériront": ("chérir",),
    "chéris": ("chérir",),
    "chérissaient": ("chérir",),
    "chérissais": ("chérir",),
    "chérissait": ("chérir",),
    "chérissant": ("chérir",),
    "chérissent": ("chérir",),
    "chérisse": ("chérir",),
    "chérisses": ("chérir",),
    "chérissez": ("chérir",),
    "chérissiez": ("chérir",),
    "chérissions": ("chérir",),
    "chérissons": ("chérir",),
    "chérîtes": ("chérir",),
    "chérit": ("chérir",),
    "chérît": ("chérir",),
    "chevaient": ("chever",),
    "chevai": ("chever",),
    "chevais": ("chever",),
    "chevait": ("chever",),
    "cheva": ("chever",),
    "chevâmes": ("chever",),
    "chevant": ("chever",),
    "chevas": ("chever",),
    "chevassent": ("chever",),
    "chevasses": ("chever",),
    "chevasse": ("chever",),
    "chevassiez": ("chever",),
    "chevassions": ("chever",),
    "chevâtes": ("chever",),
    "chevât": ("chever",),
    "chevée": ("chever",),
    "chevées": ("chever",),
    "chevé": ("chever",),
    "chèvent": ("chever",),
    "chève": ("chever",),
    "chèvera": ("chever",),
    "chèveraient": ("chever",),
    "chèverai": ("chever",),
    "chèverais": ("chever",),
    "chèverait": ("chever",),
    "chèveras": ("chever",),
    "chevèrent": ("chever",),
    "chèverez": ("chever",),
    "chèveriez": ("chever",),
    "chèverions": ("chever",),
    "chèverons": ("chever",),
    "chèveront": ("chever",),
    "chevés": ("chever",),
    "chèves": ("chever",),
    "chevez": ("chever",),
    "cheviez": ("chever",),
    "chevions": ("chever",),
    "chevons": ("chever",),
    "chevie": ("chevir",),
    "chevies": ("chevir",),
    "chevi": ("chevir",),
    "chevîmes": ("chevir",),
    "chevira": ("chevir",),
    "cheviraient": ("chevir",),
    "chevirai": ("chevir",),
    "chevirais": ("chevir",),
    "chevirait": ("chevir",),
    "cheviras": ("chevir",),
    "chevirent": ("chevir",),
    "chevirez": ("chevir",),
    "cheviriez": ("chevir",),
    "chevirions": ("chevir",),
    "chevirons": ("chevir",),
    "cheviront": ("chevir",),
    "chevis": ("chevir",),
    "chevissaient": ("chevir",),
    "chevissais": ("chevir",),
    "chevissait": ("chevir",),
    "chevissant": ("chevir",),
    "chevissent": ("chevir",),
    "chevisse": ("chevir",),
    "chevisses": ("chevir",),
    "chevissez": ("chevir",),
    "chevissiez": ("chevir",),
    "chevissions": ("chevir",),
    "chevissons": ("chevir",),
    "chevîtes": ("chevir",),
    "chevit": ("chevir",),
    "chevît": ("chevir",),
    "chevretaient": ("chevreter",),
    "chevretai": ("chevreter",),
    "chevretais": ("chevreter",),
    "chevretait": ("chevreter",),
    "chevreta": ("chevreter",),
    "chevretâmes": ("chevreter",),
    "chevretant": ("chevreter",),
    "chevretas": ("chevreter",),
    "chevretassent": ("chevreter",),
    "chevretasses": ("chevreter",),
    "chevretasse": ("chevreter",),
    "chevretassiez": ("chevreter",),
    "chevretassions": ("chevreter",),
    "chevretâtes": ("chevreter",),
    "chevretât": ("chevreter",),
    "chevretée": ("chevreter",),
    "chevretées": ("chevreter",),
    "chevreté": ("chevreter",),
    "chevretèrent": ("chevreter",),
    "chevretés": ("chevreter",),
    "chevretez": ("chevreter",),
    "chevretiez": ("chevreter",),
    "chevretions": ("chevreter",),
    "chevretons": ("chevreter",),
    "chevrettent": ("chevreter",),
    "chevrette": ("chevreter",),
    "chevrettera": ("chevreter",),
    "chevretteraient": ("chevreter",),
    "chevretterai": ("chevreter",),
    "chevretterais": ("chevreter",),
    "chevretterait": ("chevreter",),
    "chevretteras": ("chevreter",),
    "chevretterez": ("chevreter",),
    "chevretteriez": ("chevreter",),
    "chevretterions": ("chevreter",),
    "chevretterons": ("chevreter",),
    "chevretteront": ("chevreter",),
    "chevrettes": ("chevreter",),
    "chiaient": ("chier",),
    "chiai": ("chier",),
    "chiais": ("chier",),
    "chiait": ("chier",),
    "chia": ("chier",),
    "chiâmes": ("chier",),
    "chiant": ("chier",),
    "chias": ("chier",),
    "chiassent": ("chier",),
    "chiasses": ("chier",),
    "chiasse": ("chier",),
    "chiassiez": ("chier",),
    "chiassions": ("chier",),
    "chiâtes": ("chier",),
    "chiât": ("chier",),
    "chiée": ("chier",),
    "chiées": ("chier",),
    "chié": ("chier",),
    "chient": ("chier",),
    "chie": ("chier",),
    "chiera": ("chier",),
    "chieraient": ("chier",),
    "chierai": ("chier",),
    "chierais": ("chier",),
    "chierait": ("chier",),
    "chieras": ("chier",),
    "chièrent": ("chier",),
    "chierez": ("chier",),
    "chieriez": ("chier",),
    "chierions": ("chier",),
    "chierons": ("chier",),
    "chieront": ("chier",),
    "chiés": ("chier",),
    "chies": ("chier",),
    "chiez": ("chier",),
    "chiiez": ("chier",),
    "chiions": ("chier",),
    "chions": ("chier",),
    "chiméraient": ("chimérer",),
    "chimérai": ("chimérer",),
    "chimérais": ("chimérer",),
    "chimérait": ("chimérer",),
    "chiméra": ("chimérer",),
    "chimérâmes": ("chimérer",),
    "chimérant": ("chimérer",),
    "chiméras": ("chimérer",),
    "chimérassent": ("chimérer",),
    "chimérasses": ("chimérer",),
    "chimérasse": ("chimérer",),
    "chimérassiez": ("chimérer",),
    "chimérassions": ("chimérer",),
    "chimérâtes": ("chimérer",),
    "chimérât": ("chimérer",),
    "chimérée": ("chimérer",),
    "chimérées": ("chimérer",),
    "chiméré": ("chimérer",),
    "chimèrent": ("chimérer",),
    "chimère": ("chimérer",),
    "chimérera": ("chimérer",),
    "chiméreraient": ("chimérer",),
    "chimérerai": ("chimérer",),
    "chimérerais": ("chimérer",),
    "chimérerait": ("chimérer",),
    "chiméreras": ("chimérer",),
    "chimérèrent": ("chimérer",),
    "chimérerez": ("chimérer",),
    "chiméreriez": ("chimérer",),
    "chimérerions": ("chimérer",),
    "chimérerons": ("chimérer",),
    "chiméreront": ("chimérer",),
    "chimérés": ("chimérer",),
    "chimères": ("chimérer",),
    "chimérez": ("chimérer",),
    "chimériez": ("chimérer",),
    "chimérions": ("chimérer",),
    "chimérons": ("chimérer",),
    "chiquetaient": ("chiqueter",),
    "chiquetai": ("chiqueter",),
    "chiquetais": ("chiqueter",),
    "chiquetait": ("chiqueter",),
    "chiqueta": ("chiqueter",),
    "chiquetâmes": ("chiqueter",),
    "chiquetant": ("chiqueter",),
    "chiquetas": ("chiqueter",),
    "chiquetassent": ("chiqueter",),
    "chiquetasses": ("chiqueter",),
    "chiquetasse": ("chiqueter",),
    "chiquetassiez": ("chiqueter",),
    "chiquetassions": ("chiqueter",),
    "chiquetâtes": ("chiqueter",),
    "chiquetât": ("chiqueter",),
    "chiquetée": ("chiqueter",),
    "chiquetées": ("chiqueter",),
    "chiqueté": ("chiqueter",),
    "chiquetèrent": ("chiqueter",),
    "chiquetés": ("chiqueter",),
    "chiquetez": ("chiqueter",),
    "chiquetiez": ("chiqueter",),
    "chiquetions": ("chiqueter",),
    "chiquetons": ("chiqueter",),
    "chiquettent": ("chiqueter",),
    "chiquette": ("chiqueter",),
    "chiquettera": ("chiqueter",),
    "chiquetteraient": ("chiqueter",),
    "chiquetterai": ("chiqueter",),
    "chiquetterais": ("chiqueter",),
    "chiquetterait": ("chiqueter",),
    "chiquetteras": ("chiqueter",),
    "chiquetterez": ("chiqueter",),
    "chiquetteriez": ("chiqueter",),
    "chiquetterions": ("chiqueter",),
    "chiquetterons": ("chiqueter",),
    "chiquetteront": ("chiqueter",),
    "chiquettes": ("chiqueter",),
    "chirographiaient": ("chirographier",),
    "chirographiai": ("chirographier",),
    "chirographiais": ("chirographier",),
    "chirographiait": ("chirographier",),
    "chirographia": ("chirographier",),
    "chirographiâmes": ("chirographier",),
    "chirographiant": ("chirographier",),
    "chirographias": ("chirographier",),
    "chirographiassent": ("chirographier",),
    "chirographiasses": ("chirographier",),
    "chirographiasse": ("chirographier",),
    "chirographiassiez": ("chirographier",),
    "chirographiassions": ("chirographier",),
    "chirographiâtes": ("chirographier",),
    "chirographiât": ("chirographier",),
    "chirographiée": ("chirographier",),
    "chirographiées": ("chirographier",),
    "chirographié": ("chirographier",),
    "chirographient": ("chirographier",),
    "chirographie": ("chirographier",),
    "chirographiera": ("chirographier",),
    "chirographieraient": ("chirographier",),
    "chirographierai": ("chirographier",),
    "chirographierais": ("chirographier",),
    "chirographierait": ("chirographier",),
    "chirographieras": ("chirographier",),
    "chirographièrent": ("chirographier",),
    "chirographierez": ("chirographier",),
    "chirographieriez": ("chirographier",),
    "chirographierions": ("chirographier",),
    "chirographierons": ("chirographier",),
    "chirographieront": ("chirographier",),
    "chirographiés": ("chirographier",),
    "chirographies": ("chirographier",),
    "chirographiez": ("chirographier",),
    "chirographiiez": ("chirographier",),
    "chirographiions": ("chirographier",),
    "chirographions": ("chirographier",),
    "cherra": ("choir",),
    "cherraient": ("choir",),
    "cherrai": ("choir",),
    "cherrais": ("choir",),
    "cherrait": ("choir",),
    "cherras": ("choir",),
    "cherrez": ("choir",),
    "cherriez": ("choir",),
    "cherrions": ("choir",),
    "cherrons": ("choir",),
    "cherront": ("choir",),
    "choient": ("choyer",),
    "choira": ("choir",),
    "choiraient": ("choir",),
    "choirai": ("choir",),
    "choirais": ("choir",),
    "choirait": ("choir",),
    "choiras": ("choir",),
    "choirez": ("choir",),
    "choiriez": ("choir",),
    "choirions": ("choir",),
    "choirons": ("choir",),
    "choiront": ("choir",),
    "chois": ("choir",),
    "choit": ("choir",),
    "chue": ("choir",),
    "chues": ("choir",),
    "chu": ("choir",),
    "chûmes": ("choir",),
    "churent": ("choir",),
    "chus": ("choir",),
    "chûtes": ("choir",),
    "chut": ("choir",),
    "chût": ("choir",),
    "choisie": ("choisir",),
    "choisies": ("choisir",),
    "choisi": ("choisir",),
    "choisîmes": ("choisir",),
    "choisira": ("choisir",),
    "choisiraient": ("choisir",),
    "choisirai": ("choisir",),
    "choisirais": ("choisir",),
    "choisirait": ("choisir",),
    "choisiras": ("choisir",),
    "choisirent": ("choisir",),
    "choisirez": ("choisir",),
    "choisiriez": ("choisir",),
    "choisirions": ("choisir",),
    "choisirons": ("choisir",),
    "choisiront": ("choisir",),
    "choisis": ("choisir",),
    "choisissaient": ("choisir",),
    "choisissais": ("choisir",),
    "choisissait": ("choisir",),
    "choisissant": ("choisir",),
    "choisissent": ("choisir",),
    "choisisse": ("choisir",),
    "choisisses": ("choisir",),
    "choisissez": ("choisir",),
    "choisissiez": ("choisir",),
    "choisissions": ("choisir",),
    "choisissons": ("choisir",),
    "choisîtes": ("choisir",),
    "choisit": ("choisir",),
    "choisît": ("choisir",),
    "chondrifiaient": ("chondrifier",),
    "chondrifiai": ("chondrifier",),
    "chondrifiais": ("chondrifier",),
    "chondrifiait": ("chondrifier",),
    "chondrifia": ("chondrifier",),
    "chondrifiâmes": ("chondrifier",),
    "chondrifiant": ("chondrifier",),
    "chondrifias": ("chondrifier",),
    "chondrifiassent": ("chondrifier",),
    "chondrifiasses": ("chondrifier",),
    "chondrifiasse": ("chondrifier",),
    "chondrifiassiez": ("chondrifier",),
    "chondrifiassions": ("chondrifier",),
    "chondrifiâtes": ("chondrifier",),
    "chondrifiât": ("chondrifier",),
    "chondrifiée": ("chondrifier",),
    "chondrifiées": ("chondrifier",),
    "chondrifié": ("chondrifier",),
    "chondrifient": ("chondrifier",),
    "chondrifie": ("chondrifier",),
    "chondrifiera": ("chondrifier",),
    "chondrifieraient": ("chondrifier",),
    "chondrifierai": ("chondrifier",),
    "chondrifierais": ("chondrifier",),
    "chondrifierait": ("chondrifier",),
    "chondrifieras": ("chondrifier",),
    "chondrifièrent": ("chondrifier",),
    "chondrifierez": ("chondrifier",),
    "chondrifieriez": ("chondrifier",),
    "chondrifierions": ("chondrifier",),
    "chondrifierons": ("chondrifier",),
    "chondrifieront": ("chondrifier",),
    "chondrifiés": ("chondrifier",),
    "chondrifies": ("chondrifier",),
    "chondrifiez": ("chondrifier",),
    "chondrifiiez": ("chondrifier",),
    "chondrifiions": ("chondrifier",),
    "chondrifions": ("chondrifier",),
    "chorégraphiaient": ("chorégraphier",),
    "chorégraphiai": ("chorégraphier",),
    "chorégraphiais": ("chorégraphier",),
    "chorégraphiait": ("chorégraphier",),
    "chorégraphia": ("chorégraphier",),
    "chorégraphiâmes": ("chorégraphier",),
    "chorégraphiant": ("chorégraphier",),
    "chorégraphias": ("chorégraphier",),
    "chorégraphiassent": ("chorégraphier",),
    "chorégraphiasses": ("chorégraphier",),
    "chorégraphiasse": ("chorégraphier",),
    "chorégraphiassiez": ("chorégraphier",),
    "chorégraphiassions": ("chorégraphier",),
    "chorégraphiâtes": ("chorégraphier",),
    "chorégraphiât": ("chorégraphier",),
    "chorégraphiée": ("chorégraphier",),
    "chorégraphiées": ("chorégraphier",),
    "chorégraphié": ("chorégraphier",),
    "chorégraphient": ("chorégraphier",),
    "chorégraphie": ("chorégraphier",),
    "chorégraphiera": ("chorégraphier",),
    "chorégraphieraient": ("chorégraphier",),
    "chorégraphierai": ("chorégraphier",),
    "chorégraphierais": ("chorégraphier",),
    "chorégraphierait": ("chorégraphier",),
    "chorégraphieras": ("chorégraphier",),
    "chorégraphièrent": ("chorégraphier",),
    "chorégraphierez": ("chorégraphier",),
    "chorégraphieriez": ("chorégraphier",),
    "chorégraphierions": ("chorégraphier",),
    "chorégraphierons": ("chorégraphier",),
    "chorégraphieront": ("chorégraphier",),
    "chorégraphiés": ("chorégraphier",),
    "chorégraphies": ("chorégraphier",),
    "chorégraphiez": ("chorégraphier",),
    "chorégraphiiez": ("chorégraphier",),
    "chorégraphiions": ("chorégraphier",),
    "chorégraphions": ("chorégraphier",),
    "choséifiaient": ("choséifier",),
    "choséifiai": ("choséifier",),
    "choséifiais": ("choséifier",),
    "choséifiait": ("choséifier",),
    "choséifia": ("choséifier",),
    "choséifiâmes": ("choséifier",),
    "choséifiant": ("choséifier",),
    "choséifias": ("choséifier",),
    "choséifiassent": ("choséifier",),
    "choséifiasses": ("choséifier",),
    "choséifiasse": ("choséifier",),
    "choséifiassiez": ("choséifier",),
    "choséifiassions": ("choséifier",),
    "choséifiâtes": ("choséifier",),
    "choséifiât": ("choséifier",),
    "choséifiée": ("choséifier",),
    "choséifiées": ("choséifier",),
    "choséifié": ("choséifier",),
    "choséifient": ("choséifier",),
    "choséifie": ("choséifier",),
    "choséifiera": ("choséifier",),
    "choséifieraient": ("choséifier",),
    "choséifierai": ("choséifier",),
    "choséifierais": ("choséifier",),
    "choséifierait": ("choséifier",),
    "choséifieras": ("choséifier",),
    "choséifièrent": ("choséifier",),
    "choséifierez": ("choséifier",),
    "choséifieriez": ("choséifier",),
    "choséifierions": ("choséifier",),
    "choséifierons": ("choséifier",),
    "choséifieront": ("choséifier",),
    "choséifiés": ("choséifier",),
    "choséifies": ("choséifier",),
    "choséifiez": ("choséifier",),
    "choséifiiez": ("choséifier",),
    "choséifiions": ("choséifier",),
    "choséifions": ("choséifier",),
    "chosifiaient": ("chosifier",),
    "chosifiai": ("chosifier",),
    "chosifiais": ("chosifier",),
    "chosifiait": ("chosifier",),
    "chosifia": ("chosifier",),
    "chosifiâmes": ("chosifier",),
    "chosifiant": ("chosifier",),
    "chosifias": ("chosifier",),
    "chosifiassent": ("chosifier",),
    "chosifiasses": ("chosifier",),
    "chosifiasse": ("chosifier",),
    "chosifiassiez": ("chosifier",),
    "chosifiassions": ("chosifier",),
    "chosifiâtes": ("chosifier",),
    "chosifiât": ("chosifier",),
    "chosifiée": ("chosifier",),
    "chosifiées": ("chosifier",),
    "chosifié": ("chosifier",),
    "chosifient": ("chosifier",),
    "chosifie": ("chosifier",),
    "chosifiera": ("chosifier",),
    "chosifieraient": ("chosifier",),
    "chosifierai": ("chosifier",),
    "chosifierais": ("chosifier",),
    "chosifierait": ("chosifier",),
    "chosifieras": ("chosifier",),
    "chosifièrent": ("chosifier",),
    "chosifierez": ("chosifier",),
    "chosifieriez": ("chosifier",),
    "chosifierions": ("chosifier",),
    "chosifierons": ("chosifier",),
    "chosifieront": ("chosifier",),
    "chosifiés": ("chosifier",),
    "chosifies": ("chosifier",),
    "chosifiez": ("chosifier",),
    "chosifiiez": ("chosifier",),
    "chosifiions": ("chosifier",),
    "chosifions": ("chosifier",),
    "choie": ("choyer",),
    "choiera": ("choyer",),
    "choieraient": ("choyer",),
    "choierai": ("choyer",),
    "choierais": ("choyer",),
    "choierait": ("choyer",),
    "choieras": ("choyer",),
    "choierez": ("choyer",),
    "choieriez": ("choyer",),
    "choierions": ("choyer",),
    "choierons": ("choyer",),
    "choieront": ("choyer",),
    "choies": ("choyer",),
    "choyaient": ("choyer",),
    "choyai": ("choyer",),
    "choyais": ("choyer",),
    "choyait": ("choyer",),
    "choya": ("choyer",),
    "choyâmes": ("choyer",),
    "choyant": ("choyer",),
    "choyas": ("choyer",),
    "choyassent": ("choyer",),
    "choyasses": ("choyer",),
    "choyasse": ("choyer",),
    "choyassiez": ("choyer",),
    "choyassions": ("choyer",),
    "choyâtes": ("choyer",),
    "choyât": ("choyer",),
    "choyée": ("choyer",),
    "choyées": ("choyer",),
    "choyé": ("choyer",),
    "choyèrent": ("choyer",),
    "choyés": ("choyer",),
    "choyez": ("choyer",),
    "choyiez": ("choyer",),
    "choyions": ("choyer",),
    "choyons": ("choyer",),
    "chronométraient": ("chronométrer",),
    "chronométrai": ("chronométrer",),
    "chronométrais": ("chronométrer",),
    "chronométrait": ("chronométrer",),
    "chronométra": ("chronométrer",),
    "chronométrâmes": ("chronométrer",),
    "chronométrant": ("chronométrer",),
    "chronométras": ("chronométrer",),
    "chronométrassent": ("chronométrer",),
    "chronométrasses": ("chronométrer",),
    "chronométrasse": ("chronométrer",),
    "chronométrassiez": ("chronométrer",),
    "chronométrassions": ("chronométrer",),
    "chronométrâtes": ("chronométrer",),
    "chronométrât": ("chronométrer",),
    "chronométrée": ("chronométrer",),
    "chronométrées": ("chronométrer",),
    "chronométré": ("chronométrer",),
    "chronomètrent": ("chronométrer",),
    "chronomètre": ("chronométrer",),
    "chronométrera": ("chronométrer",),
    "chronométreraient": ("chronométrer",),
    "chronométrerai": ("chronométrer",),
    "chronométrerais": ("chronométrer",),
    "chronométrerait": ("chronométrer",),
    "chronométreras": ("chronométrer",),
    "chronométrèrent": ("chronométrer",),
    "chronométrerez": ("chronométrer",),
    "chronométreriez": ("chronométrer",),
    "chronométrerions": ("chronométrer",),
    "chronométrerons": ("chronométrer",),
    "chronométreront": ("chronométrer",),
    "chronométrés": ("chronométrer",),
    "chronomètres": ("chronométrer",),
    "chronométrez": ("chronométrer",),
    "chronométriez": ("chronométrer",),
    "chronométrions": ("chronométrer",),
    "chronométrons": ("chronométrer",),
    "chuchetaient": ("chucheter",),
    "chuchetai": ("chucheter",),
    "chuchetais": ("chucheter",),
    "chuchetait": ("chucheter",),
    "chucheta": ("chucheter",),
    "chuchetâmes": ("chucheter",),
    "chuchetant": ("chucheter",),
    "chuchetas": ("chucheter",),
    "chuchetassent": ("chucheter",),
    "chuchetasses": ("chucheter",),
    "chuchetasse": ("chucheter",),
    "chuchetassiez": ("chucheter",),
    "chuchetassions": ("chucheter",),
    "chuchetâtes": ("chucheter",),
    "chuchetât": ("chucheter",),
    "chuchetée": ("chucheter",),
    "chuchetées": ("chucheter",),
    "chucheté": ("chucheter",),
    "chuchetèrent": ("chucheter",),
    "chuchetés": ("chucheter",),
    "chuchetez": ("chucheter",),
    "chuchetiez": ("chucheter",),
    "chuchetions": ("chucheter",),
    "chuchetons": ("chucheter",),
    "chuchettent": ("chucheter",),
    "chuchette": ("chucheter",),
    "chuchettera": ("chucheter",),
    "chuchetteraient": ("chucheter",),
    "chuchetterai": ("chucheter",),
    "chuchetterais": ("chucheter",),
    "chuchetterait": ("chucheter",),
    "chuchetteras": ("chucheter",),
    "chuchetterez": ("chucheter",),
    "chuchetteriez": ("chucheter",),
    "chuchetterions": ("chucheter",),
    "chuchetterons": ("chucheter",),
    "chuchetteront": ("chucheter",),
    "chuchettes": ("chucheter",),
    "chylifiaient": ("chylifier",),
    "chylifiai": ("chylifier",),
    "chylifiais": ("chylifier",),
    "chylifiait": ("chylifier",),
    "chylifia": ("chylifier",),
    "chylifiâmes": ("chylifier",),
    "chylifiant": ("chylifier",),
    "chylifias": ("chylifier",),
    "chylifiassent": ("chylifier",),
    "chylifiasses": ("chylifier",),
    "chylifiasse": ("chylifier",),
    "chylifiassiez": ("chylifier",),
    "chylifiassions": ("chylifier",),
    "chylifiâtes": ("chylifier",),
    "chylifiât": ("chylifier",),
    "chylifiée": ("chylifier",),
    "chylifiées": ("chylifier",),
    "chylifié": ("chylifier",),
    "chylifient": ("chylifier",),
    "chylifie": ("chylifier",),
    "chylifiera": ("chylifier",),
    "chylifieraient": ("chylifier",),
    "chylifierai": ("chylifier",),
    "chylifierais": ("chylifier",),
    "chylifierait": ("chylifier",),
    "chylifieras": ("chylifier",),
    "chylifièrent": ("chylifier",),
    "chylifierez": ("chylifier",),
    "chylifieriez": ("chylifier",),
    "chylifierions": ("chylifier",),
    "chylifierons": ("chylifier",),
    "chylifieront": ("chylifier",),
    "chylifiés": ("chylifier",),
    "chylifies": ("chylifier",),
    "chylifiez": ("chylifier",),
    "chylifiiez": ("chylifier",),
    "chylifiions": ("chylifier",),
    "chylifions": ("chylifier",),
    "chymifiaient": ("chymifier",),
    "chymifiai": ("chymifier",),
    "chymifiais": ("chymifier",),
    "chymifiait": ("chymifier",),
    "chymifia": ("chymifier",),
    "chymifiâmes": ("chymifier",),
    "chymifiant": ("chymifier",),
    "chymifias": ("chymifier",),
    "chymifiassent": ("chymifier",),
    "chymifiasses": ("chymifier",),
    "chymifiasse": ("chymifier",),
    "chymifiassiez": ("chymifier",),
    "chymifiassions": ("chymifier",),
    "chymifiâtes": ("chymifier",),
    "chymifiât": ("chymifier",),
    "chymifiée": ("chymifier",),
    "chymifiées": ("chymifier",),
    "chymifié": ("chymifier",),
    "chymifient": ("chymifier",),
    "chymifie": ("chymifier",),
    "chymifiera": ("chymifier",),
    "chymifieraient": ("chymifier",),
    "chymifierai": ("chymifier",),
    "chymifierais": ("chymifier",),
    "chymifierait": ("chymifier",),
    "chymifieras": ("chymifier",),
    "chymifièrent": ("chymifier",),
    "chymifierez": ("chymifier",),
    "chymifieriez": ("chymifier",),
    "chymifierions": ("chymifier",),
    "chymifierons": ("chymifier",),
    "chymifieront": ("chymifier",),
    "chymifiés": ("chymifier",),
    "chymifies": ("chymifier",),
    "chymifiez": ("chymifier",),
    "chymifiiez": ("chymifier",),
    "chymifiions": ("chymifier",),
    "chymifions": ("chymifier",),
    "cinégraphiaient": ("cinégraphier",),
    "cinégraphiai": ("cinégraphier",),
    "cinégraphiais": ("cinégraphier",),
    "cinégraphiait": ("cinégraphier",),
    "cinégraphia": ("cinégraphier",),
    "cinégraphiâmes": ("cinégraphier",),
    "cinégraphiant": ("cinégraphier",),
    "cinégraphias": ("cinégraphier",),
    "cinégraphiassent": ("cinégraphier",),
    "cinégraphiasses": ("cinégraphier",),
    "cinégraphiasse": ("cinégraphier",),
    "cinégraphiassiez": ("cinégraphier",),
    "cinégraphiassions": ("cinégraphier",),
    "cinégraphiâtes": ("cinégraphier",),
    "cinégraphiât": ("cinégraphier",),
    "cinégraphiée": ("cinégraphier",),
    "cinégraphiées": ("cinégraphier",),
    "cinégraphié": ("cinégraphier",),
    "cinégraphient": ("cinégraphier",),
    "cinégraphie": ("cinégraphier",),
    "cinégraphiera": ("cinégraphier",),
    "cinégraphieraient": ("cinégraphier",),
    "cinégraphierai": ("cinégraphier",),
    "cinégraphierais": ("cinégraphier",),
    "cinégraphierait": ("cinégraphier",),
    "cinégraphieras": ("cinégraphier",),
    "cinégraphièrent": ("cinégraphier",),
    "cinégraphierez": ("cinégraphier",),
    "cinégraphieriez": ("cinégraphier",),
    "cinégraphierions": ("cinégraphier",),
    "cinégraphierons": ("cinégraphier",),
    "cinégraphieront": ("cinégraphier",),
    "cinégraphiés": ("cinégraphier",),
    "cinégraphies": ("cinégraphier",),
    "cinégraphiez": ("cinégraphier",),
    "cinégraphiiez": ("cinégraphier",),
    "cinégraphiions": ("cinégraphier",),
    "cinégraphions": ("cinégraphier",),
    "cinématographiaient": ("cinématographier",),
    "cinématographiai": ("cinématographier",),
    "cinématographiais": ("cinématographier",),
    "cinématographiait": ("cinématographier",),
    "cinématographia": ("cinématographier",),
    "cinématographiâmes": ("cinématographier",),
    "cinématographiant": ("cinématographier",),
    "cinématographias": ("cinématographier",),
    "cinématographiassent": ("cinématographier",),
    "cinématographiasses": ("cinématographier",),
    "cinématographiasse": ("cinématographier",),
    "cinématographiassiez": ("cinématographier",),
    "cinématographiassions": ("cinématographier",),
    "cinématographiâtes": ("cinématographier",),
    "cinématographiât": ("cinématographier",),
    "cinématographiée": ("cinématographier",),
    "cinématographiées": ("cinématographier",),
    "cinématographié": ("cinématographier",),
    "cinématographient": ("cinématographier",),
    "cinématographie": ("cinématographier",),
    "cinématographiera": ("cinématographier",),
    "cinématographieraient": ("cinématographier",),
    "cinématographierai": ("cinématographier",),
    "cinématographierais": ("cinématographier",),
    "cinématographierait": ("cinématographier",),
    "cinématographieras": ("cinématographier",),
    "cinématographièrent": ("cinématographier",),
    "cinématographierez": ("cinématographier",),
    "cinématographieriez": ("cinématographier",),
    "cinématographierions": ("cinématographier",),
    "cinématographierons": ("cinématographier",),
    "cinématographieront": ("cinématographier",),
    "cinématographiés": ("cinématographier",),
    "cinématographies": ("cinématographier",),
    "cinématographiez": ("cinématographier",),
    "cinématographiiez": ("cinématographier",),
    "cinématographiions": ("cinématographier",),
    "cinématographions": ("cinématographier",),
    "circoncîmes": ("circoncire",),
    "circoncira": ("circoncire",),
    "circonciraient": ("circoncire",),
    "circoncirai": ("circoncire",),
    "circoncirais": ("circoncire",),
    "circoncirait": ("circoncire",),
    "circonciras": ("circoncire",),
    "circoncirent": ("circoncire",),
    "circoncirez": ("circoncire",),
    "circonciriez": ("circoncire",),
    "circoncirions": ("circoncire",),
    "circoncirons": ("circoncire",),
    "circonciront": ("circoncire",),
    "circoncisaient": ("circoncire",),
    "circoncisais": ("circoncire",),
    "circoncisait": ("circoncire",),
    "circoncisant": ("circoncire",),
    "circoncise": ("circoncire",),
    "circoncisent": ("circoncire",),
    "circoncises": ("circoncire",),
    "circoncisez": ("circoncire",),
    "circoncisiez": ("circoncire",),
    "circoncisions": ("circoncire",),
    "circoncis": ("circoncire",),
    "circoncisons": ("circoncire",),
    "circoncissent": ("circoncire",),
    "circoncisses": ("circoncire",),
    "circoncisse": ("circoncire",),
    "circoncissiez": ("circoncire",),
    "circoncissions": ("circoncire",),
    "circoncîtes": ("circoncire",),
    "circoncit": ("circoncire",),
    "circoncît": ("circoncire",),
    "circonscrira": ("circonscrire",),
    "circonscriraient": ("circonscrire",),
    "circonscrirai": ("circonscrire",),
    "circonscrirais": ("circonscrire",),
    "circonscrirait": ("circonscrire",),
    "circonscriras": ("circonscrire",),
    "circonscrirez": ("circonscrire",),
    "circonscririez": ("circonscrire",),
    "circonscririons": ("circonscrire",),
    "circonscrirons": ("circonscrire",),
    "circonscriront": ("circonscrire",),
    "circonscris": ("circonscrire",),
    "circonscrite": ("circonscrire",),
    "circonscrites": ("circonscrire",),
    "circonscrit": ("circonscrire",),
    "circonscrits": ("circonscrire",),
    "circonscrivaient": ("circonscrire",),
    "circonscrivais": ("circonscrire",),
    "circonscrivait": ("circonscrire",),
    "circonscrivant": ("circonscrire",),
    "circonscrivent": ("circonscrire",),
    "circonscrive": ("circonscrire",),
    "circonscrives": ("circonscrire",),
    "circonscrivez": ("circonscrire",),
    "circonscriviez": ("circonscrire",),
    "circonscrivîmes": ("circonscrire",),
    "circonscrivions": ("circonscrire",),
    "circonscrivirent": ("circonscrire",),
    "circonscrivis": ("circonscrire",),
    "circonscrivissent": ("circonscrire",),
    "circonscrivisses": ("circonscrire",),
    "circonscrivisse": ("circonscrire",),
    "circonscrivissiez": ("circonscrire",),
    "circonscrivissions": ("circonscrire",),
    "circonscrivîtes": ("circonscrire",),
    "circonscrivit": ("circonscrire",),
    "circonscrivît": ("circonscrire",),
    "circonscrivons": ("circonscrire",),
    "circonstanciaient": ("circonstancier",),
    "circonstanciai": ("circonstancier",),
    "circonstanciais": ("circonstancier",),
    "circonstanciait": ("circonstancier",),
    "circonstancia": ("circonstancier",),
    "circonstanciâmes": ("circonstancier",),
    "circonstanciant": ("circonstancier",),
    "circonstancias": ("circonstancier",),
    "circonstanciassent": ("circonstancier",),
    "circonstanciasses": ("circonstancier",),
    "circonstanciasse": ("circonstancier",),
    "circonstanciassiez": ("circonstancier",),
    "circonstanciassions": ("circonstancier",),
    "circonstanciâtes": ("circonstancier",),
    "circonstanciât": ("circonstancier",),
    "circonstanciée": ("circonstancier",),
    "circonstanciées": ("circonstancier",),
    "circonstancié": ("circonstancier",),
    "circonstancient": ("circonstancier",),
    "circonstancie": ("circonstancier",),
    "circonstanciera": ("circonstancier",),
    "circonstancieraient": ("circonstancier",),
    "circonstancierai": ("circonstancier",),
    "circonstancierais": ("circonstancier",),
    "circonstancierait": ("circonstancier",),
    "circonstancieras": ("circonstancier",),
    "circonstancièrent": ("circonstancier",),
    "circonstancierez": ("circonstancier",),
    "circonstancieriez": ("circonstancier",),
    "circonstancierions": ("circonstancier",),
    "circonstancierons": ("circonstancier",),
    "circonstancieront": ("circonstancier",),
    "circonstanciés": ("circonstancier",),
    "circonstancies": ("circonstancier",),
    "circonstanciez": ("circonstancier",),
    "circonstanciiez": ("circonstancier",),
    "circonstanciions": ("circonstancier",),
    "circonstancions": ("circonstancier",),
    "circonvenaient": ("circonvenir",),
    "circonvenais": ("circonvenir",),
    "circonvenait": ("circonvenir",),
    "circonvenant": ("circonvenir",),
    "circonvenez": ("circonvenir",),
    "circonveniez": ("circonvenir",),
    "circonvenions": ("circonvenir",),
    "circonvenons": ("circonvenir",),
    "circonvenue": ("circonvenir",),
    "circonvenues": ("circonvenir",),
    "circonvenu": ("circonvenir",),
    "circonvenus": ("circonvenir",),
    "circonviendra": ("circonvenir",),
    "circonviendraient": ("circonvenir",),
    "circonviendrai": ("circonvenir",),
    "circonviendrais": ("circonvenir",),
    "circonviendrait": ("circonvenir",),
    "circonviendras": ("circonvenir",),
    "circonviendrez": ("circonvenir",),
    "circonviendriez": ("circonvenir",),
    "circonviendrions": ("circonvenir",),
    "circonviendrons": ("circonvenir",),
    "circonviendront": ("circonvenir",),
    "circonviennent": ("circonvenir",),
    "circonvienne": ("circonvenir",),
    "circonviennes": ("circonvenir",),
    "circonviens": ("circonvenir",),
    "circonvient": ("circonvenir",),
    "circonvînmes": ("circonvenir",),
    "circonvinrent": ("circonvenir",),
    "circonvins": ("circonvenir",),
    "circonvinssent": ("circonvenir",),
    "circonvinsses": ("circonvenir",),
    "circonvinsse": ("circonvenir",),
    "circonvinssiez": ("circonvenir",),
    "circonvinssions": ("circonvenir",),
    "circonvîntes": ("circonvenir",),
    "circonvint": ("circonvenir",),
    "circonvînt": ("circonvenir",),
    "ciselaient": ("ciseler",),
    "ciselai": ("ciseler",),
    "ciselais": ("ciseler",),
    "ciselait": ("ciseler",),
    "cisela": ("ciseler",),
    "ciselâmes": ("ciseler",),
    "ciselant": ("ciseler",),
    "ciselas": ("ciseler",),
    "ciselassent": ("ciseler",),
    "ciselasses": ("ciseler",),
    "ciselasse": ("ciseler",),
    "ciselassiez": ("ciseler",),
    "ciselassions": ("ciseler",),
    "ciselâtes": ("ciseler",),
    "ciselât": ("ciseler",),
    "ciselée": ("ciseler",),
    "ciselées": ("ciseler",),
    "ciselé": ("ciseler",),
    "cisèlent": ("ciseler",),
    "cisèle": ("ciseler",),
    "cisèlera": ("ciseler",),
    "cisèleraient": ("ciseler",),
    "cisèlerai": ("ciseler",),
    "cisèlerais": ("ciseler",),
    "cisèlerait": ("ciseler",),
    "cisèleras": ("ciseler",),
    "ciselèrent": ("ciseler",),
    "cisèlerez": ("ciseler",),
    "cisèleriez": ("ciseler",),
    "cisèlerions": ("ciseler",),
    "cisèlerons": ("ciseler",),
    "cisèleront": ("ciseler",),
    "ciselés": ("ciseler",),
    "cisèles": ("ciseler",),
    "ciselez": ("ciseler",),
    "ciseliez": ("ciseler",),
    "ciselions": ("ciseler",),
    "ciselons": ("ciseler",),
    "clairçaient": ("claircer",),
    "clairçai": ("claircer",),
    "clairçais": ("claircer",),
    "clairçait": ("claircer",),
    "clairça": ("claircer",),
    "clairçâmes": ("claircer",),
    "clairçant": ("claircer",),
    "clairças": ("claircer",),
    "clairçassent": ("claircer",),
    "clairçasses": ("claircer",),
    "clairçasse": ("claircer",),
    "clairçassiez": ("claircer",),
    "clairçassions": ("claircer",),
    "clairçâtes": ("claircer",),
    "clairçât": ("claircer",),
    "claircée": ("claircer",),
    "claircées": ("claircer",),
    "claircé": ("claircer",),
    "claircent": ("claircer",),
    "clairce": ("claircer",),
    "claircera": ("claircer",),
    "clairceraient": ("claircer",),
    "claircerai": ("claircer",),
    "claircerais": ("claircer",),
    "claircerait": ("claircer",),
    "clairceras": ("claircer",),
    "claircèrent": ("claircer",),
    "claircerez": ("claircer",),
    "clairceriez": ("claircer",),
    "claircerions": ("claircer",),
    "claircerons": ("claircer",),
    "clairceront": ("claircer",),
    "claircés": ("claircer",),
    "clairces": ("claircer",),
    "claircez": ("claircer",),
    "clairciez": ("claircer",),
    "claircions": ("claircer",),
    "clairçons": ("claircer",),
    "claircie": ("claircir",),
    "claircies": ("claircir",),
    "clairci": ("claircir",),
    "claircîmes": ("claircir",),
    "claircira": ("claircir",),
    "clairciraient": ("claircir",),
    "claircirai": ("claircir",),
    "claircirais": ("claircir",),
    "claircirait": ("claircir",),
    "clairciras": ("claircir",),
    "claircirent": ("claircir",),
    "claircirez": ("claircir",),
    "clairciriez": ("claircir",),
    "claircirions": ("claircir",),
    "claircirons": ("claircir",),
    "clairciront": ("claircir",),
    "claircis": ("claircir",),
    "claircissaient": ("claircir",),
    "claircissais": ("claircir",),
    "claircissait": ("claircir",),
    "claircissant": ("claircir",),
    "claircissent": ("claircir",),
    "claircisse": ("claircir",),
    "claircisses": ("claircir",),
    "claircissez": ("claircir",),
    "claircissiez": ("claircir",),
    "claircissions": ("claircir",),
    "claircissons": ("claircir",),
    "claircîtes": ("claircir",),
    "claircit": ("claircir",),
    "claircît": ("claircir",),
    "clairsemaient": ("clairsemer",),
    "clairsemai": ("clairsemer",),
    "clairsemais": ("clairsemer",),
    "clairsemait": ("clairsemer",),
    "clairsema": ("clairsemer",),
    "clairsemâmes": ("clairsemer",),
    "clairsemant": ("clairsemer",),
    "clairsemas": ("clairsemer",),
    "clairsemassent": ("clairsemer",),
    "clairsemasses": ("clairsemer",),
    "clairsemasse": ("clairsemer",),
    "clairsemassiez": ("clairsemer",),
    "clairsemassions": ("clairsemer",),
    "clairsemâtes": ("clairsemer",),
    "clairsemât": ("clairsemer",),
    "clairsemée": ("clairsemer",),
    "clairsemées": ("clairsemer",),
    "clairsemé": ("clairsemer",),
    "clairsèment": ("clairsemer",),
    "clairsème": ("clairsemer",),
    "clairsèmera": ("clairsemer",),
    "clairsèmeraient": ("clairsemer",),
    "clairsèmerai": ("clairsemer",),
    "clairsèmerais": ("clairsemer",),
    "clairsèmerait": ("clairsemer",),
    "clairsèmeras": ("clairsemer",),
    "clairsemèrent": ("clairsemer",),
    "clairsèmerez": ("clairsemer",),
    "clairsèmeriez": ("clairsemer",),
    "clairsèmerions": ("clairsemer",),
    "clairsèmerons": ("clairsemer",),
    "clairsèmeront": ("clairsemer",),
    "clairsemés": ("clairsemer",),
    "clairsèmes": ("clairsemer",),
    "clairsemez": ("clairsemer",),
    "clairsemiez": ("clairsemer",),
    "clairsemions": ("clairsemer",),
    "clairsemons": ("clairsemer",),
    "clamçaient": ("clamcer",),
    "clamçai": ("clamcer",),
    "clamçais": ("clamcer",),
    "clamçait": ("clamcer",),
    "clamça": ("clamcer",),
    "clamçâmes": ("clamcer",),
    "clamçant": ("clamcer",),
    "clamças": ("clamcer",),
    "clamçassent": ("clamcer",),
    "clamçasses": ("clamcer",),
    "clamçasse": ("clamcer",),
    "clamçassiez": ("clamcer",),
    "clamçassions": ("clamcer",),
    "clamçâtes": ("clamcer",),
    "clamçât": ("clamcer",),
    "clamcé": ("clamcer",),
    "clamcent": ("clamcer",),
    "clamce": ("clamcer",),
    "clamcera": ("clamcer",),
    "clamceraient": ("clamcer",),
    "clamcerai": ("clamcer",),
    "clamcerais": ("clamcer",),
    "clamcerait": ("clamcer",),
    "clamceras": ("clamcer",),
    "clamcèrent": ("clamcer",),
    "clamcerez": ("clamcer",),
    "clamceriez": ("clamcer",),
    "clamcerions": ("clamcer",),
    "clamcerons": ("clamcer",),
    "clamceront": ("clamcer",),
    "clamces": ("clamcer",),
    "clamcez": ("clamcer",),
    "clamciez": ("clamcer",),
    "clamcions": ("clamcer",),
    "clamçons": ("clamcer",),
    "clameçaient": ("clamecer",),
    "clameçai": ("clamecer",),
    "clameçais": ("clamecer",),
    "clameçait": ("clamecer",),
    "clameça": ("clamecer",),
    "clameçâmes": ("clamecer",),
    "clameçant": ("clamecer",),
    "clameças": ("clamecer",),
    "clameçassent": ("clamecer",),
    "clameçasses": ("clamecer",),
    "clameçasse": ("clamecer",),
    "clameçassiez": ("clamecer",),
    "clameçassions": ("clamecer",),
    "clameçâtes": ("clamecer",),
    "clameçât": ("clamecer",),
    "clamecé": ("clamecer",),
    "clamecent": ("clamecer",),
    "clamece": ("clamecer",),
    "clamecera": ("clamecer",),
    "clameceraient": ("clamecer",),
    "clamecerai": ("clamecer",),
    "clamecerais": ("clamecer",),
    "clamecerait": ("clamecer",),
    "clameceras": ("clamecer",),
    "clamecèrent": ("clamecer",),
    "clamecerez": ("clamecer",),
    "clameceriez": ("clamecer",),
    "clamecerions": ("clamecer",),
    "clamecerons": ("clamecer",),
    "clameceront": ("clamecer",),
    "clameces": ("clamecer",),
    "clamecez": ("clamecer",),
    "clameciez": ("clamecer",),
    "clamecions": ("clamecer",),
    "clameçons": ("clamecer",),
    "clapi": ("clapir",),
    "clapîmes": ("clapir",),
    "clapira": ("clapir",),
    "clapiraient": ("clapir",),
    "clapirai": ("clapir",),
    "clapirais": ("clapir",),
    "clapirait": ("clapir",),
    "clapiras": ("clapir",),
    "clapirent": ("clapir",),
    "clapirez": ("clapir",),
    "clapiriez": ("clapir",),
    "clapirions": ("clapir",),
    "clapirons": ("clapir",),
    "clapiront": ("clapir",),
    "clapis": ("clapir",),
    "clapissaient": ("clapir",),
    "clapissais": ("clapir",),
    "clapissait": ("clapir",),
    "clapissant": ("clapir",),
    "clapissent": ("clapir",),
    "clapisse": ("clapir",),
    "clapisses": ("clapir",),
    "clapissez": ("clapir",),
    "clapissiez": ("clapir",),
    "clapissions": ("clapir",),
    "clapissons": ("clapir",),
    "clapîtes": ("clapir",),
    "clapit": ("clapir",),
    "clapît": ("clapir",),
    "claquetaient": ("claqueter",),
    "claquetai": ("claqueter",),
    "claquetais": ("claqueter",),
    "claquetait": ("claqueter",),
    "claqueta": ("claqueter",),
    "claquetâmes": ("claqueter",),
    "claquetant": ("claqueter",),
    "claquetas": ("claqueter",),
    "claquetassent": ("claqueter",),
    "claquetasses": ("claqueter",),
    "claquetasse": ("claqueter",),
    "claquetassiez": ("claqueter",),
    "claquetassions": ("claqueter",),
    "claquetâtes": ("claqueter",),
    "claquetât": ("claqueter",),
    "claquetée": ("claqueter",),
    "claquetées": ("claqueter",),
    "claqueté": ("claqueter",),
    "claquetèrent": ("claqueter",),
    "claquetés": ("claqueter",),
    "claquetez": ("claqueter",),
    "claquetiez": ("claqueter",),
    "claquetions": ("claqueter",),
    "claquetons": ("claqueter",),
    "claquettent": ("claqueter",),
    "claquette": ("claqueter",),
    "claquettera": ("claqueter",),
    "claquetteraient": ("claqueter",),
    "claquetterai": ("claqueter",),
    "claquetterais": ("claqueter",),
    "claquetterait": ("claqueter",),
    "claquetteras": ("claqueter",),
    "claquetterez": ("claqueter",),
    "claquetteriez": ("claqueter",),
    "claquetterions": ("claqueter",),
    "claquetterons": ("claqueter",),
    "claquetteront": ("claqueter",),
    "claquettes": ("claqueter",),
    "clarifiaient": ("clarifier",),
    "clarifiai": ("clarifier",),
    "clarifiais": ("clarifier",),
    "clarifiait": ("clarifier",),
    "clarifia": ("clarifier",),
    "clarifiâmes": ("clarifier",),
    "clarifiant": ("clarifier",),
    "clarifias": ("clarifier",),
    "clarifiassent": ("clarifier",),
    "clarifiasses": ("clarifier",),
    "clarifiasse": ("clarifier",),
    "clarifiassiez": ("clarifier",),
    "clarifiassions": ("clarifier",),
    "clarifiâtes": ("clarifier",),
    "clarifiât": ("clarifier",),
    "clarifiée": ("clarifier",),
    "clarifiées": ("clarifier",),
    "clarifié": ("clarifier",),
    "clarifient": ("clarifier",),
    "clarifie": ("clarifier",),
    "clarifiera": ("clarifier",),
    "clarifieraient": ("clarifier",),
    "clarifierai": ("clarifier",),
    "clarifierais": ("clarifier",),
    "clarifierait": ("clarifier",),
    "clarifieras": ("clarifier",),
    "clarifièrent": ("clarifier",),
    "clarifierez": ("clarifier",),
    "clarifieriez": ("clarifier",),
    "clarifierions": ("clarifier",),
    "clarifierons": ("clarifier",),
    "clarifieront": ("clarifier",),
    "clarifiés": ("clarifier",),
    "clarifies": ("clarifier",),
    "clarifiez": ("clarifier",),
    "clarifiiez": ("clarifier",),
    "clarifiions": ("clarifier",),
    "clarifions": ("clarifier",),
    "classaient": ("classer",),
    "classai": ("classer",),
    "classais": ("classer",),
    "classait": ("classer",),
    "classa": ("classer",),
    "classâmes": ("classer",),
    "classant": ("classer",),
    "classas": ("classer",),
    "classassent": ("classer",),
    "classasses": ("classer",),
    "classasse": ("classer",),
    "classassiez": ("classer",),
    "classassions": ("classer",),
    "classâtes": ("classer",),
    "classât": ("classer",),
    "classée": ("classer",),
    "classées": ("classer",),
    "classé": ("classer",),
    "classent": ("classer",),
    "classe": ("classer",),
    "classera": ("classer",),
    "classeraient": ("classer",),
    "classerai": ("classer",),
    "classerais": ("classer",),
    "classerait": ("classer",),
    "classeras": ("classer",),
    "classèrent": ("classer",),
    "classerez": ("classer",),
    "classeriez": ("classer",),
    "classerions": ("classer",),
    "classerons": ("classer",),
    "classeront": ("classer",),
    "classés": ("classer",),
    "classes": ("classer",),
    "classez": ("classer",),
    "classiez": ("classer",),
    "classions": ("classer",),
    "classons": ("classer",),
    "classifiaient": ("classifier",),
    "classifiai": ("classifier",),
    "classifiais": ("classifier",),
    "classifiait": ("classifier",),
    "classifia": ("classifier",),
    "classifiâmes": ("classifier",),
    "classifiant": ("classifier",),
    "classifias": ("classifier",),
    "classifiassent": ("classifier",),
    "classifiasses": ("classifier",),
    "classifiasse": ("classifier",),
    "classifiassiez": ("classifier",),
    "classifiassions": ("classifier",),
    "classifiâtes": ("classifier",),
    "classifiât": ("classifier",),
    "classifiée": ("classifier",),
    "classifiées": ("classifier",),
    "classifié": ("classifier",),
    "classifient": ("classifier",),
    "classifie": ("classifier",),
    "classifiera": ("classifier",),
    "classifieraient": ("classifier",),
    "classifierai": ("classifier",),
    "classifierais": ("classifier",),
    "classifierait": ("classifier",),
    "classifieras": ("classifier",),
    "classifièrent": ("classifier",),
    "classifierez": ("classifier",),
    "classifieriez": ("classifier",),
    "classifierions": ("classifier",),
    "classifierons": ("classifier",),
    "classifieront": ("classifier",),
    "classifiés": ("classifier",),
    "classifies": ("classifier",),
    "classifiez": ("classifier",),
    "classifiiez": ("classifier",),
    "classifiions": ("classifier",),
    "classifions": ("classifier",),
    "clati": ("clatir",),
    "clatîmes": ("clatir",),
    "clatira": ("clatir",),
    "clatiraient": ("clatir",),
    "clatirai": ("clatir",),
    "clatirais": ("clatir",),
    "clatirait": ("clatir",),
    "clatiras": ("clatir",),
    "clatirent": ("clatir",),
    "clatirez": ("clatir",),
    "clatiriez": ("clatir",),
    "clatirions": ("clatir",),
    "clatirons": ("clatir",),
    "clatiront": ("clatir",),
    "clatis": ("clatir",),
    "clatissaient": ("clatir",),
    "clatissais": ("clatir",),
    "clatissait": ("clatir",),
    "clatissant": ("clatir",),
    "clatissent": ("clatir",),
    "clatisse": ("clatir",),
    "clatisses": ("clatir",),
    "clatissez": ("clatir",),
    "clatissiez": ("clatir",),
    "clatissions": ("clatir",),
    "clatissons": ("clatir",),
    "clatîtes": ("clatir",),
    "clatit": ("clatir",),
    "clatît": ("clatir",),
    "clavetaient": ("claveter",),
    "clavetai": ("claveter",),
    "clavetais": ("claveter",),
    "clavetait": ("claveter",),
    "claveta": ("claveter",),
    "clavetâmes": ("claveter",),
    "clavetant": ("claveter",),
    "clavetas": ("claveter",),
    "clavetassent": ("claveter",),
    "clavetasses": ("claveter",),
    "clavetasse": ("claveter",),
    "clavetassiez": ("claveter",),
    "clavetassions": ("claveter",),
    "clavetâtes": ("claveter",),
    "clavetât": ("claveter",),
    "clavetée": ("claveter",),
    "clavetées": ("claveter",),
    "claveté": ("claveter",),
    "clavetèrent": ("claveter",),
    "clavetés": ("claveter",),
    "clavetez": ("claveter",),
    "clavetiez": ("claveter",),
    "clavetions": ("claveter",),
    "clavetons": ("claveter",),
    "clavettent": ("claveter",),
    "clavette": ("claveter",),
    "clavettera": ("claveter",),
    "clavetteraient": ("claveter",),
    "clavetterai": ("claveter",),
    "clavetterais": ("claveter",),
    "clavetterait": ("claveter",),
    "clavetteras": ("claveter",),
    "clavetterez": ("claveter",),
    "clavetteriez": ("claveter",),
    "clavetterions": ("claveter",),
    "clavetterons": ("claveter",),
    "clavetteront": ("claveter",),
    "clavettes": ("claveter",),
    "cliquetaient": ("cliqueter",),
    "cliquetai": ("cliqueter",),
    "cliquetais": ("cliqueter",),
    "cliquetait": ("cliqueter",),
    "cliqueta": ("cliqueter",),
    "cliquetâmes": ("cliqueter",),
    "cliquetant": ("cliqueter",),
    "cliquetas": ("cliqueter",),
    "cliquetassent": ("cliqueter",),
    "cliquetasses": ("cliqueter",),
    "cliquetasse": ("cliqueter",),
    "cliquetassiez": ("cliqueter",),
    "cliquetassions": ("cliqueter",),
    "cliquetâtes": ("cliqueter",),
    "cliquetât": ("cliqueter",),
    "cliquetée": ("cliqueter",),
    "cliquetées": ("cliqueter",),
    "cliqueté": ("cliqueter",),
    "cliquetèrent": ("cliqueter",),
    "cliquetés": ("cliqueter",),
    "cliquetez": ("cliqueter",),
    "cliquetiez": ("cliqueter",),
    "cliquetions": ("cliqueter",),
    "cliquetons": ("cliqueter",),
    "cliquettent": ("cliqueter",),
    "cliquette": ("cliqueter",),
    "cliquettera": ("cliqueter",),
    "cliquetteraient": ("cliqueter",),
    "cliquetterai": ("cliqueter",),
    "cliquetterais": ("cliqueter",),
    "cliquetterait": ("cliqueter",),
    "cliquetteras": ("cliqueter",),
    "cliquetterez": ("cliqueter",),
    "cliquetteriez": ("cliqueter",),
    "cliquetterions": ("cliqueter",),
    "cliquetterons": ("cliqueter",),
    "cliquetteront": ("cliqueter",),
    "cliquettes": ("cliqueter",),
    "clochetaient": ("clocheter",),
    "clochetai": ("clocheter",),
    "clochetais": ("clocheter",),
    "clochetait": ("clocheter",),
    "clocheta": ("clocheter",),
    "clochetâmes": ("clocheter",),
    "clochetant": ("clocheter",),
    "clochetas": ("clocheter",),
    "clochetassent": ("clocheter",),
    "clochetasses": ("clocheter",),
    "clochetasse": ("clocheter",),
    "clochetassiez": ("clocheter",),
    "clochetassions": ("clocheter",),
    "clochetâtes": ("clocheter",),
    "clochetât": ("clocheter",),
    "clochetée": ("clocheter",),
    "clochetées": ("clocheter",),
    "clocheté": ("clocheter",),
    "clochetèrent": ("clocheter",),
    "clochetés": ("clocheter",),
    "clochetez": ("clocheter",),
    "clochetiez": ("clocheter",),
    "clochetions": ("clocheter",),
    "clochetons": ("clocheter",),
    "clochettent": ("clocheter",),
    "clochette": ("clocheter",),
    "clochettera": ("clocheter",),
    "clochetteraient": ("clocheter",),
    "clochetterai": ("clocheter",),
    "clochetterais": ("clocheter",),
    "clochetterait": ("clocheter",),
    "clochetteras": ("clocheter",),
    "clochetterez": ("clocheter",),
    "clochetteriez": ("clocheter",),
    "clochetterions": ("clocheter",),
    "clochetterons": ("clocheter",),
    "clochetteront": ("clocheter",),
    "clochettes": ("clocheter",),
    "clora": ("clore",),
    "cloraient": ("clore",),
    "clorai": ("clore",),
    "clorais": ("clore",),
    "clorait": ("clore",),
    "cloras": ("clore",),
    "clorez": ("clore",),
    "cloriez": ("clore",),
    "clorions": ("clore",),
    "clorons": ("clore",),
    "cloront": ("clore",),
    "closant": ("clore",),
    "close": ("clore",),
    "closent": ("clore",),
    "closes": ("clore",),
    "closez": ("clore",),
    "closiez": ("clore",),
    "closions": ("clore",),
    "clos": ("clore",),
    "closons": ("clore",),
    "clôt": ("clore",),
    "coacquéraient": ("coacquérir",),
    "coacquérais": ("coacquérir",),
    "coacquérait": ("coacquérir",),
    "coacquérant": ("coacquérir",),
    "coacquérez": ("coacquérir",),
    "coacquériez": ("coacquérir",),
    "coacquérions": ("coacquérir",),
    "coacquérons": ("coacquérir",),
    "coacquerra": ("coacquérir",),
    "coacquerraient": ("coacquérir",),
    "coacquerrai": ("coacquérir",),
    "coacquerrais": ("coacquérir",),
    "coacquerrait": ("coacquérir",),
    "coacquerras": ("coacquérir",),
    "coacquerrez": ("coacquérir",),
    "coacquerriez": ("coacquérir",),
    "coacquerrions": ("coacquérir",),
    "coacquerrons": ("coacquérir",),
    "coacquerront": ("coacquérir",),
    "coacquièrent": ("coacquérir",),
    "coacquière": ("coacquérir",),
    "coacquières": ("coacquérir",),
    "coacquiers": ("coacquérir",),
    "coacquiert": ("coacquérir",),
    "coacquîmes": ("coacquérir",),
    "coacquirent": ("coacquérir",),
    "coacquise": ("coacquérir",),
    "coacquises": ("coacquérir",),
    "coacquis": ("coacquérir",),
    "coacquissent": ("coacquérir",),
    "coacquisses": ("coacquérir",),
    "coacquisse": ("coacquérir",),
    "coacquissiez": ("coacquérir",),
    "coacquissions": ("coacquérir",),
    "coacquîtes": ("coacquérir",),
    "coacquit": ("coacquérir",),
    "coacquît": ("coacquérir",),
    "coalesçaient": ("coalescer",),
    "coalesçai": ("coalescer",),
    "coalesçais": ("coalescer",),
    "coalesçait": ("coalescer",),
    "coalesça": ("coalescer",),
    "coalesçâmes": ("coalescer",),
    "coalesçant": ("coalescer",),
    "coalesças": ("coalescer",),
    "coalesçassent": ("coalescer",),
    "coalesçasses": ("coalescer",),
    "coalesçasse": ("coalescer",),
    "coalesçassiez": ("coalescer",),
    "coalesçassions": ("coalescer",),
    "coalesçâtes": ("coalescer",),
    "coalesçât": ("coalescer",),
    "coalescée": ("coalescer",),
    "coalescées": ("coalescer",),
    "coalescé": ("coalescer",),
    "coalescent": ("coalescer",),
    "coalesce": ("coalescer",),
    "coalescera": ("coalescer",),
    "coalesceraient": ("coalescer",),
    "coalescerai": ("coalescer",),
    "coalescerais": ("coalescer",),
    "coalescerait": ("coalescer",),
    "coalesceras": ("coalescer",),
    "coalescèrent": ("coalescer",),
    "coalescerez": ("coalescer",),
    "coalesceriez": ("coalescer",),
    "coalescerions": ("coalescer",),
    "coalescerons": ("coalescer",),
    "coalesceront": ("coalescer",),
    "coalescés": ("coalescer",),
    "coalesces": ("coalescer",),
    "coalescez": ("coalescer",),
    "coalesciez": ("coalescer",),
    "coalescions": ("coalescer",),
    "coalesçons": ("coalescer",),
    "coassaient": ("coasser",),
    "coassai": ("coasser",),
    "coassais": ("coasser",),
    "coassait": ("coasser",),
    "coassa": ("coasser",),
    "coassâmes": ("coasser",),
    "coassant": ("coasser",),
    "coassas": ("coasser",),
    "coassassent": ("coasser",),
    "coassasses": ("coasser",),
    "coassasse": ("coasser",),
    "coassassiez": ("coasser",),
    "coassassions": ("coasser",),
    "coassâtes": ("coasser",),
    "coassât": ("coasser",),
    "coassée": ("coasser",),
    "coassées": ("coasser",),
    "coassé": ("coasser",),
    "coassent": ("coasser",),
    "coasse": ("coasser",),
    "coassera": ("coasser",),
    "coasseraient": ("coasser",),
    "coasserai": ("coasser",),
    "coasserais": ("coasser",),
    "coasserait": ("coasser",),
    "coasseras": ("coasser",),
    "coassèrent": ("coasser",),
    "coasserez": ("coasser",),
    "coasseriez": ("coasser",),
    "coasserions": ("coasser",),
    "coasserons": ("coasser",),
    "coasseront": ("coasser",),
    "coassés": ("coasser",),
    "coasses": ("coasser",),
    "coassez": ("coasser",),
    "coassiez": ("coasser",),
    "coassions": ("coasser",),
    "coassons": ("coasser",),
    "coassociaient": ("coassocier",),
    "coassociai": ("coassocier",),
    "coassociais": ("coassocier",),
    "coassociait": ("coassocier",),
    "coassocia": ("coassocier",),
    "coassociâmes": ("coassocier",),
    "coassociant": ("coassocier",),
    "coassocias": ("coassocier",),
    "coassociassent": ("coassocier",),
    "coassociasses": ("coassocier",),
    "coassociasse": ("coassocier",),
    "coassociassiez": ("coassocier",),
    "coassociassions": ("coassocier",),
    "coassociâtes": ("coassocier",),
    "coassociât": ("coassocier",),
    "coassociée": ("coassocier",),
    "coassociées": ("coassocier",),
    "coassocié": ("coassocier",),
    "coassocient": ("coassocier",),
    "coassocie": ("coassocier",),
    "coassociera": ("coassocier",),
    "coassocieraient": ("coassocier",),
    "coassocierai": ("coassocier",),
    "coassocierais": ("coassocier",),
    "coassocierait": ("coassocier",),
    "coassocieras": ("coassocier",),
    "coassocièrent": ("coassocier",),
    "coassocierez": ("coassocier",),
    "coassocieriez": ("coassocier",),
    "coassocierions": ("coassocier",),
    "coassocierons": ("coassocier",),
    "coassocieront": ("coassocier",),
    "coassociés": ("coassocier",),
    "coassocies": ("coassocier",),
    "coassociez": ("coassocier",),
    "coassociiez": ("coassocier",),
    "coassociions": ("coassocier",),
    "coassocions": ("coassocier",),
    "cocufiaient": ("cocufier",),
    "cocufiai": ("cocufier",),
    "cocufiais": ("cocufier",),
    "cocufiait": ("cocufier",),
    "cocufia": ("cocufier",),
    "cocufiâmes": ("cocufier",),
    "cocufiant": ("cocufier",),
    "cocufias": ("cocufier",),
    "cocufiassent": ("cocufier",),
    "cocufiasses": ("cocufier",),
    "cocufiasse": ("cocufier",),
    "cocufiassiez": ("cocufier",),
    "cocufiassions": ("cocufier",),
    "cocufiâtes": ("cocufier",),
    "cocufiât": ("cocufier",),
    "cocufiée": ("cocufier",),
    "cocufiées": ("cocufier",),
    "cocufié": ("cocufier",),
    "cocufient": ("cocufier",),
    "cocufie": ("cocufier",),
    "cocufiera": ("cocufier",),
    "cocufieraient": ("cocufier",),
    "cocufierai": ("cocufier",),
    "cocufierais": ("cocufier",),
    "cocufierait": ("cocufier",),
    "cocufieras": ("cocufier",),
    "cocufièrent": ("cocufier",),
    "cocufierez": ("cocufier",),
    "cocufieriez": ("cocufier",),
    "cocufierions": ("cocufier",),
    "cocufierons": ("cocufier",),
    "cocufieront": ("cocufier",),
    "cocufiés": ("cocufier",),
    "cocufies": ("cocufier",),
    "cocufiez": ("cocufier",),
    "cocufiiez": ("cocufier",),
    "cocufiions": ("cocufier",),
    "cocufions": ("cocufier",),
    "codifiaient": ("codifier",),
    "codifiai": ("codifier",),
    "codifiais": ("codifier",),
    "codifiait": ("codifier",),
    "codifia": ("codifier",),
    "codifiâmes": ("codifier",),
    "codifiant": ("codifier",),
    "codifias": ("codifier",),
    "codifiassent": ("codifier",),
    "codifiasses": ("codifier",),
    "codifiasse": ("codifier",),
    "codifiassiez": ("codifier",),
    "codifiassions": ("codifier",),
    "codifiâtes": ("codifier",),
    "codifiât": ("codifier",),
    "codifiée": ("codifier",),
    "codifiées": ("codifier",),
    "codifié": ("codifier",),
    "codifient": ("codifier",),
    "codifie": ("codifier",),
    "codifiera": ("codifier",),
    "codifieraient": ("codifier",),
    "codifierai": ("codifier",),
    "codifierais": ("codifier",),
    "codifierait": ("codifier",),
    "codifieras": ("codifier",),
    "codifièrent": ("codifier",),
    "codifierez": ("codifier",),
    "codifieriez": ("codifier",),
    "codifierions": ("codifier",),
    "codifierons": ("codifier",),
    "codifieront": ("codifier",),
    "codifiés": ("codifier",),
    "codifies": ("codifier",),
    "codifiez": ("codifier",),
    "codifiiez": ("codifier",),
    "codifiions": ("codifier",),
    "codifions": ("codifier",),
    "codirigeaient": ("codiriger",),
    "codirigeai": ("codiriger",),
    "codirigeais": ("codiriger",),
    "codirigeait": ("codiriger",),
    "codirigea": ("codiriger",),
    "codirigeâmes": ("codiriger",),
    "codirigeant": ("codiriger",),
    "codirigeas": ("codiriger",),
    "codirigeassent": ("codiriger",),
    "codirigeasses": ("codiriger",),
    "codirigeasse": ("codiriger",),
    "codirigeassiez": ("codiriger",),
    "codirigeassions": ("codiriger",),
    "codirigeâtes": ("codiriger",),
    "codirigeât": ("codiriger",),
    "codirigée": ("codiriger",),
    "codirigées": ("codiriger",),
    "codirigé": ("codiriger",),
    "codirigent": ("codiriger",),
    "codirigeons": ("codiriger",),
    "codirige": ("codiriger",),
    "codirigera": ("codiriger",),
    "codirigeraient": ("codiriger",),
    "codirigerai": ("codiriger",),
    "codirigerais": ("codiriger",),
    "codirigerait": ("codiriger",),
    "codirigeras": ("codiriger",),
    "codirigèrent": ("codiriger",),
    "codirigerez": ("codiriger",),
    "codirigeriez": ("codiriger",),
    "codirigerions": ("codiriger",),
    "codirigerons": ("codiriger",),
    "codirigeront": ("codiriger",),
    "codirigés": ("codiriger",),
    "codiriges": ("codiriger",),
    "codirigez": ("codiriger",),
    "codirigiez": ("codiriger",),
    "codirigions": ("codiriger",),
    "coéchangeaient": ("coéchanger",),
    "coéchangeai": ("coéchanger",),
    "coéchangeais": ("coéchanger",),
    "coéchangeait": ("coéchanger",),
    "coéchangea": ("coéchanger",),
    "coéchangeâmes": ("coéchanger",),
    "coéchangeant": ("coéchanger",),
    "coéchangeas": ("coéchanger",),
    "coéchangeassent": ("coéchanger",),
    "coéchangeasses": ("coéchanger",),
    "coéchangeasse": ("coéchanger",),
    "coéchangeassiez": ("coéchanger",),
    "coéchangeassions": ("coéchanger",),
    "coéchangeâtes": ("coéchanger",),
    "coéchangeât": ("coéchanger",),
    "coéchangée": ("coéchanger",),
    "coéchangées": ("coéchanger",),
    "coéchangé": ("coéchanger",),
    "coéchangent": ("coéchanger",),
    "coéchangeons": ("coéchanger",),
    "coéchange": ("coéchanger",),
    "coéchangera": ("coéchanger",),
    "coéchangeraient": ("coéchanger",),
    "coéchangerai": ("coéchanger",),
    "coéchangerais": ("coéchanger",),
    "coéchangerait": ("coéchanger",),
    "coéchangeras": ("coéchanger",),
    "coéchangèrent": ("coéchanger",),
    "coéchangerez": ("coéchanger",),
    "coéchangeriez": ("coéchanger",),
    "coéchangerions": ("coéchanger",),
    "coéchangerons": ("coéchanger",),
    "coéchangeront": ("coéchanger",),
    "coéchangés": ("coéchanger",),
    "coéchanges": ("coéchanger",),
    "coéchangez": ("coéchanger",),
    "coéchangiez": ("coéchanger",),
    "coéchangions": ("coéchanger",),
    "coécrira": ("coécrire",),
    "coécriraient": ("coécrire",),
    "coécrirai": ("coécrire",),
    "coécrirais": ("coécrire",),
    "coécrirait": ("coécrire",),
    "coécriras": ("coécrire",),
    "coécrirez": ("coécrire",),
    "coécririez": ("coécrire",),
    "coécririons": ("coécrire",),
    "coécrirons": ("coécrire",),
    "coécriront": ("coécrire",),
    "coécris": ("coécrire",),
    "coécrite": ("coécrire",),
    "coécrites": ("coécrire",),
    "coécrit": ("coécrire",),
    "coécrits": ("coécrire",),
    "coécrivaient": ("coécrire",),
    "coécrivais": ("coécrire",),
    "coécrivait": ("coécrire",),
    "coécrivant": ("coécrire",),
    "coécrivent": ("coécrire",),
    "coécrive": ("coécrire",),
    "coécrives": ("coécrire",),
    "coécrivez": ("coécrire",),
    "coécriviez": ("coécrire",),
    "coécrivîmes": ("coécrire",),
    "coécrivions": ("coécrire",),
    "coécrivirent": ("coécrire",),
    "coécrivis": ("coécrire",),
    "coécrivissent": ("coécrire",),
    "coécrivisses": ("coécrire",),
    "coécrivisse": ("coécrire",),
    "coécrivissiez": ("coécrire",),
    "coécrivissions": ("coécrire",),
    "coécrivîtes": ("coécrire",),
    "coécrivit": ("coécrire",),
    "coécrivît": ("coécrire",),
    "coécrivons": ("coécrire",),
    "cofinançaient": ("cofinancer",),
    "cofinançai": ("cofinancer",),
    "cofinançais": ("cofinancer",),
    "cofinançait": ("cofinancer",),
    "cofinança": ("cofinancer",),
    "cofinançâmes": ("cofinancer",),
    "cofinançant": ("cofinancer",),
    "cofinanças": ("cofinancer",),
    "cofinançassent": ("cofinancer",),
    "cofinançasses": ("cofinancer",),
    "cofinançasse": ("cofinancer",),
    "cofinançassiez": ("cofinancer",),
    "cofinançassions": ("cofinancer",),
    "cofinançâtes": ("cofinancer",),
    "cofinançât": ("cofinancer",),
    "cofinancée": ("cofinancer",),
    "cofinancées": ("cofinancer",),
    "cofinancé": ("cofinancer",),
    "cofinancent": ("cofinancer",),
    "cofinance": ("cofinancer",),
    "cofinancera": ("cofinancer",),
    "cofinanceraient": ("cofinancer",),
    "cofinancerai": ("cofinancer",),
    "cofinancerais": ("cofinancer",),
    "cofinancerait": ("cofinancer",),
    "cofinanceras": ("cofinancer",),
    "cofinancèrent": ("cofinancer",),
    "cofinancerez": ("cofinancer",),
    "cofinanceriez": ("cofinancer",),
    "cofinancerions": ("cofinancer",),
    "cofinancerons": ("cofinancer",),
    "cofinanceront": ("cofinancer",),
    "cofinancés": ("cofinancer",),
    "cofinances": ("cofinancer",),
    "cofinancez": ("cofinancer",),
    "cofinanciez": ("cofinancer",),
    "cofinancions": ("cofinancer",),
    "cofinançons": ("cofinancer",),
    "cogénéraient": ("cogénérer",),
    "cogénérai": ("cogénérer",),
    "cogénérais": ("cogénérer",),
    "cogénérait": ("cogénérer",),
    "cogénéra": ("cogénérer",),
    "cogénérâmes": ("cogénérer",),
    "cogénérant": ("cogénérer",),
    "cogénéras": ("cogénérer",),
    "cogénérassent": ("cogénérer",),
    "cogénérasses": ("cogénérer",),
    "cogénérasse": ("cogénérer",),
    "cogénérassiez": ("cogénérer",),
    "cogénérassions": ("cogénérer",),
    "cogénérâtes": ("cogénérer",),
    "cogénérât": ("cogénérer",),
    "cogénérée": ("cogénérer",),
    "cogénérées": ("cogénérer",),
    "cogénéré": ("cogénérer",),
    "cogénèrent": ("cogénérer",),
    "cogénère": ("cogénérer",),
    "cogénérera": ("cogénérer",),
    "cogénéreraient": ("cogénérer",),
    "cogénérerai": ("cogénérer",),
    "cogénérerais": ("cogénérer",),
    "cogénérerait": ("cogénérer",),
    "cogénéreras": ("cogénérer",),
    "cogénérèrent": ("cogénérer",),
    "cogénérerez": ("cogénérer",),
    "cogénéreriez": ("cogénérer",),
    "cogénérerions": ("cogénérer",),
    "cogénérerons": ("cogénérer",),
    "cogénéreront": ("cogénérer",),
    "cogénérés": ("cogénérer",),
    "cogénères": ("cogénérer",),
    "cogénérez": ("cogénérer",),
    "cogénériez": ("cogénérer",),
    "cogénérions": ("cogénérer",),
    "cogénérons": ("cogénérer",),
    "cogéraient": ("cogérer",),
    "cogérai": ("cogérer",),
    "cogérais": ("cogérer",),
    "cogérait": ("cogérer",),
    "cogéra": ("cogérer",),
    "cogérâmes": ("cogérer",),
    "cogérant": ("cogérer",),
    "cogéras": ("cogérer",),
    "cogérassent": ("cogérer",),
    "cogérasses": ("cogérer",),
    "cogérasse": ("cogérer",),
    "cogérassiez": ("cogérer",),
    "cogérassions": ("cogérer",),
    "cogérâtes": ("cogérer",),
    "cogérât": ("cogérer",),
    "cogérée": ("cogérer",),
    "cogérées": ("cogérer",),
    "cogéré": ("cogérer",),
    "cogèrent": ("cogérer",),
    "cogère": ("cogérer",),
    "cogérera": ("cogérer",),
    "cogéreraient": ("cogérer",),
    "cogérerai": ("cogérer",),
    "cogérerais": ("cogérer",),
    "cogérerait": ("cogérer",),
    "cogéreras": ("cogérer",),
    "cogérèrent": ("cogérer",),
    "cogérerez": ("cogérer",),
    "cogéreriez": ("cogérer",),
    "cogérerions": ("cogérer",),
    "cogérerons": ("cogérer",),
    "cogéreront": ("cogérer",),
    "cogérés": ("cogérer",),
    "cogères": ("cogérer",),
    "cogérez": ("cogérer",),
    "cogériez": ("cogérer",),
    "cogérions": ("cogérer",),
    "cogérons": ("cogérer",),
    "cohéraient": ("cohérer",),
    "cohérai": ("cohérer",),
    "cohérais": ("cohérer",),
    "cohérait": ("cohérer",),
    "cohéra": ("cohérer",),
    "cohérâmes": ("cohérer",),
    "cohérant": ("cohérer",),
    "cohéras": ("cohérer",),
    "cohérassent": ("cohérer",),
    "cohérasses": ("cohérer",),
    "cohérasse": ("cohérer",),
    "cohérassiez": ("cohérer",),
    "cohérassions": ("cohérer",),
    "cohérâtes": ("cohérer",),
    "cohérât": ("cohérer",),
    "cohérée": ("cohérer",),
    "cohérées": ("cohérer",),
    "cohéré": ("cohérer",),
    "cohèrent": ("cohérer",),
    "cohère": ("cohérer",),
    "cohérera": ("cohérer",),
    "cohéreraient": ("cohérer",),
    "cohérerai": ("cohérer",),
    "cohérerais": ("cohérer",),
    "cohérerait": ("cohérer",),
    "cohéreras": ("cohérer",),
    "cohérèrent": ("cohérer",),
    "cohérerez": ("cohérer",),
    "cohéreriez": ("cohérer",),
    "cohérerions": ("cohérer",),
    "cohérerons": ("cohérer",),
    "cohéreront": ("cohérer",),
    "cohérés": ("cohérer",),
    "cohères": ("cohérer",),
    "cohérez": ("cohérer",),
    "cohériez": ("cohérer",),
    "cohérions": ("cohérer",),
    "cohérons": ("cohérer",),
    "coinçaient": ("coincer",),
    "coinçai": ("coincer",),
    "coinçais": ("coincer",),
    "coinçait": ("coincer",),
    "coinça": ("coincer",),
    "coinçâmes": ("coincer",),
    "coinçant": ("coincer",),
    "coinças": ("coincer",),
    "coinçassent": ("coincer",),
    "coinçasses": ("coincer",),
    "coinçasse": ("coincer",),
    "coinçassiez": ("coincer",),
    "coinçassions": ("coincer",),
    "coinçâtes": ("coincer",),
    "coinçât": ("coincer",),
    "coincée": ("coincer",),
    "coincées": ("coincer",),
    "coincé": ("coincer",),
    "coincent": ("coincer",),
    "coince": ("coincer",),
    "coincera": ("coincer",),
    "coinceraient": ("coincer",),
    "coincerai": ("coincer",),
    "coincerais": ("coincer",),
    "coincerait": ("coincer",),
    "coinceras": ("coincer",),
    "coincèrent": ("coincer",),
    "coincerez": ("coincer",),
    "coinceriez": ("coincer",),
    "coincerions": ("coincer",),
    "coincerons": ("coincer",),
    "coinceront": ("coincer",),
    "coincés": ("coincer",),
    "coinces": ("coincer",),
    "coincez": ("coincer",),
    "coinciez": ("coincer",),
    "coincions": ("coincer",),
    "coinçons": ("coincer",),
    "cokéfiaient": ("cokéfier",),
    "cokéfiai": ("cokéfier",),
    "cokéfiais": ("cokéfier",),
    "cokéfiait": ("cokéfier",),
    "cokéfia": ("cokéfier",),
    "cokéfiâmes": ("cokéfier",),
    "cokéfiant": ("cokéfier",),
    "cokéfias": ("cokéfier",),
    "cokéfiassent": ("cokéfier",),
    "cokéfiasses": ("cokéfier",),
    "cokéfiasse": ("cokéfier",),
    "cokéfiassiez": ("cokéfier",),
    "cokéfiassions": ("cokéfier",),
    "cokéfiâtes": ("cokéfier",),
    "cokéfiât": ("cokéfier",),
    "cokéfiée": ("cokéfier",),
    "cokéfiées": ("cokéfier",),
    "cokéfié": ("cokéfier",),
    "cokéfient": ("cokéfier",),
    "cokéfie": ("cokéfier",),
    "cokéfiera": ("cokéfier",),
    "cokéfieraient": ("cokéfier",),
    "cokéfierai": ("cokéfier",),
    "cokéfierais": ("cokéfier",),
    "cokéfierait": ("cokéfier",),
    "cokéfieras": ("cokéfier",),
    "cokéfièrent": ("cokéfier",),
    "cokéfierez": ("cokéfier",),
    "cokéfieriez": ("cokéfier",),
    "cokéfierions": ("cokéfier",),
    "cokéfierons": ("cokéfier",),
    "cokéfieront": ("cokéfier",),
    "cokéfiés": ("cokéfier",),
    "cokéfies": ("cokéfier",),
    "cokéfiez": ("cokéfier",),
    "cokéfiiez": ("cokéfier",),
    "cokéfiions": ("cokéfier",),
    "cokéfions": ("cokéfier",),
    "coléraient": ("colérer",),
    "colérai": ("colérer",),
    "colérais": ("colérer",),
    "colérait": ("colérer",),
    "coléra": ("colérer",),
    "colérâmes": ("colérer",),
    "colérant": ("colérer",),
    "coléras": ("colérer",),
    "colérassent": ("colérer",),
    "colérasses": ("colérer",),
    "colérasse": ("colérer",),
    "colérassiez": ("colérer",),
    "colérassions": ("colérer",),
    "colérâtes": ("colérer",),
    "colérât": ("colérer",),
    "colérée": ("colérer",),
    "colérées": ("colérer",),
    "coléré": ("colérer",),
    "colèrent": ("colérer",),
    "colère": ("colérer",),
    "colérera": ("colérer",),
    "coléreraient": ("colérer",),
    "colérerai": ("colérer",),
    "colérerais": ("colérer",),
    "colérerait": ("colérer",),
    "coléreras": ("colérer",),
    "colérèrent": ("colérer",),
    "colérerez": ("colérer",),
    "coléreriez": ("colérer",),
    "colérerions": ("colérer",),
    "colérerons": ("colérer",),
    "coléreront": ("colérer",),
    "colérés": ("colérer",),
    "colères": ("colérer",),
    "colérez": ("colérer",),
    "colériez": ("colérer",),
    "colérions": ("colérer",),
    "colérons": ("colérer",),
    "colletaient": ("colleter",),
    "colletai": ("colleter",),
    "colletais": ("colleter",),
    "colletait": ("colleter",),
    "colleta": ("colleter",),
    "colletâmes": ("colleter",),
    "colletant": ("colleter",),
    "colletas": ("colleter",),
    "colletassent": ("colleter",),
    "colletasses": ("colleter",),
    "colletasse": ("colleter",),
    "colletassiez": ("colleter",),
    "colletassions": ("colleter",),
    "colletâtes": ("colleter",),
    "colletât": ("colleter",),
    "colletée": ("colleter",),
    "colletées": ("colleter",),
    "colleté": ("colleter",),
    "colletèrent": ("colleter",),
    "colletés": ("colleter",),
    "colletez": ("colleter",),
    "colletiez": ("colleter",),
    "colletions": ("colleter",),
    "colletons": ("colleter",),
    "collettent": ("colleter",),
    "collette": ("colleter",),
    "collettera": ("colleter",),
    "colletteraient": ("colleter",),
    "colletterai": ("colleter",),
    "colletterais": ("colleter",),
    "colletterait": ("colleter",),
    "colletteras": ("colleter",),
    "colletterez": ("colleter",),
    "colletteriez": ("colleter",),
    "colletterions": ("colleter",),
    "colletterons": ("colleter",),
    "colletteront": ("colleter",),
    "collettes": ("colleter",),
    "colligeaient": ("colliger",),
    "colligeai": ("colliger",),
    "colligeais": ("colliger",),
    "colligeait": ("colliger",),
    "colligea": ("colliger",),
    "colligeâmes": ("colliger",),
    "colligeant": ("colliger",),
    "colligeas": ("colliger",),
    "colligeassent": ("colliger",),
    "colligeasses": ("colliger",),
    "colligeasse": ("colliger",),
    "colligeassiez": ("colliger",),
    "colligeassions": ("colliger",),
    "colligeâtes": ("colliger",),
    "colligeât": ("colliger",),
    "colligée": ("colliger",),
    "colligées": ("colliger",),
    "colligé": ("colliger",),
    "colligent": ("colliger",),
    "colligeons": ("colliger",),
    "collige": ("colliger",),
    "colligera": ("colliger",),
    "colligeraient": ("colliger",),
    "colligerai": ("colliger",),
    "colligerais": ("colliger",),
    "colligerait": ("colliger",),
    "colligeras": ("colliger",),
    "colligèrent": ("colliger",),
    "colligerez": ("colliger",),
    "colligeriez": ("colliger",),
    "colligerions": ("colliger",),
    "colligerons": ("colliger",),
    "colligeront": ("colliger",),
    "colligés": ("colliger",),
    "colliges": ("colliger",),
    "colligez": ("colliger",),
    "colligiez": ("colliger",),
    "colligions": ("colliger",),
    "colloient": ("colloyer",),
    "colloie": ("colloyer",),
    "colloiera": ("colloyer",),
    "colloieraient": ("colloyer",),
    "colloierai": ("colloyer",),
    "colloierais": ("colloyer",),
    "colloierait": ("colloyer",),
    "colloieras": ("colloyer",),
    "colloierez": ("colloyer",),
    "colloieriez": ("colloyer",),
    "colloierions": ("colloyer",),
    "colloierons": ("colloyer",),
    "colloieront": ("colloyer",),
    "colloies": ("colloyer",),
    "colloyaient": ("colloyer",),
    "colloyai": ("colloyer",),
    "colloyais": ("colloyer",),
    "colloyait": ("colloyer",),
    "colloya": ("colloyer",),
    "colloyâmes": ("colloyer",),
    "colloyant": ("colloyer",),
    "colloyas": ("colloyer",),
    "colloyassent": ("colloyer",),
    "colloyasses": ("colloyer",),
    "colloyasse": ("colloyer",),
    "colloyassiez": ("colloyer",),
    "colloyassions": ("colloyer",),
    "colloyâtes": ("colloyer",),
    "colloyât": ("colloyer",),
    "colloyée": ("colloyer",),
    "colloyées": ("colloyer",),
    "colloyé": ("colloyer",),
    "colloyèrent": ("colloyer",),
    "colloyés": ("colloyer",),
    "colloyez": ("colloyer",),
    "colloyiez": ("colloyer",),
    "colloyions": ("colloyer",),
    "colloyons": ("colloyer",),
    "coloriaient": ("colorier",),
    "coloriai": ("colorier",),
    "coloriais": ("colorier",),
    "coloriait": ("colorier",),
    "coloria": ("colorier",),
    "coloriâmes": ("colorier",),
    "coloriant": ("colorier",),
    "colorias": ("colorier",),
    "coloriassent": ("colorier",),
    "coloriasses": ("colorier",),
    "coloriasse": ("colorier",),
    "coloriassiez": ("colorier",),
    "coloriassions": ("colorier",),
    "coloriâtes": ("colorier",),
    "coloriât": ("colorier",),
    "coloriée": ("colorier",),
    "coloriées": ("colorier",),
    "colorié": ("colorier",),
    "colorient": ("colorier",),
    "colorie": ("colorier",),
    "coloriera": ("colorier",),
    "colorieraient": ("colorier",),
    "colorierai": ("colorier",),
    "colorierais": ("colorier",),
    "colorierait": ("colorier",),
    "colorieras": ("colorier",),
    "colorièrent": ("colorier",),
    "colorierez": ("colorier",),
    "colorieriez": ("colorier",),
    "colorierions": ("colorier",),
    "colorierons": ("colorier",),
    "colorieront": ("colorier",),
    "coloriés": ("colorier",),
    "colories": ("colorier",),
    "coloriez": ("colorier",),
    "coloriiez": ("colorier",),
    "coloriions": ("colorier",),
    "colorions": ("colorier",),
    "combat": ("combattre",),
    "combats": ("combattre",),
    "combattaient": ("combattre",),
    "combattais": ("combattre",),
    "combattait": ("combattre",),
    "combattant": ("combattre",),
    "combattent": ("combattre",),
    "combatte": ("combattre",),
    "combattes": ("combattre",),
    "combattez": ("combattre",),
    "combattiez": ("combattre",),
    "combattîmes": ("combattre",),
    "combattions": ("combattre",),
    "combattirent": ("combattre",),
    "combattis": ("combattre",),
    "combattissent": ("combattre",),
    "combattisses": ("combattre",),
    "combattisse": ("combattre",),
    "combattissiez": ("combattre",),
    "combattissions": ("combattre",),
    "combattîtes": ("combattre",),
    "combattit": ("combattre",),
    "combattît": ("combattre",),
    "combattons": ("combattre",),
    "combattra": ("combattre",),
    "combattraient": ("combattre",),
    "combattrai": ("combattre",),
    "combattrais": ("combattre",),
    "combattrait": ("combattre",),
    "combattras": ("combattre",),
    "combattrez": ("combattre",),
    "combattriez": ("combattre",),
    "combattrions": ("combattre",),
    "combattrons": ("combattre",),
    "combattront": ("combattre",),
    "combattue": ("combattre",),
    "combattues": ("combattre",),
    "combattu": ("combattre",),
    "combattus": ("combattre",),
    "combugeaient": ("combuger",),
    "combugeai": ("combuger",),
    "combugeais": ("combuger",),
    "combugeait": ("combuger",),
    "combugea": ("combuger",),
    "combugeâmes": ("combuger",),
    "combugeant": ("combuger",),
    "combugeas": ("combuger",),
    "combugeassent": ("combuger",),
    "combugeasses": ("combuger",),
    "combugeasse": ("combuger",),
    "combugeassiez": ("combuger",),
    "combugeassions": ("combuger",),
    "combugeâtes": ("combuger",),
    "combugeât": ("combuger",),
    "combugée": ("combuger",),
    "combugées": ("combuger",),
    "combugé": ("combuger",),
    "combugent": ("combuger",),
    "combugeons": ("combuger",),
    "combuge": ("combuger",),
    "combugera": ("combuger",),
    "combugeraient": ("combuger",),
    "combugerai": ("combuger",),
    "combugerais": ("combuger",),
    "combugerait": ("combuger",),
    "combugeras": ("combuger",),
    "combugèrent": ("combuger",),
    "combugerez": ("combuger",),
    "combugeriez": ("combuger",),
    "combugerions": ("combuger",),
    "combugerons": ("combuger",),
    "combugeront": ("combuger",),
    "combugés": ("combuger",),
    "combuges": ("combuger",),
    "combugez": ("combuger",),
    "combugiez": ("combuger",),
    "combugions": ("combuger",),
    "commençaient": ("commencer",),
    "commençai": ("commencer",),
    "commençais": ("commencer",),
    "commençait": ("commencer",),
    "commença": ("commencer",),
    "commençâmes": ("commencer",),
    "commençant": ("commencer",),
    "commenças": ("commencer",),
    "commençassent": ("commencer",),
    "commençasses": ("commencer",),
    "commençasse": ("commencer",),
    "commençassiez": ("commencer",),
    "commençassions": ("commencer",),
    "commençâtes": ("commencer",),
    "commençât": ("commencer",),
    "commencée": ("commencer",),
    "commencées": ("commencer",),
    "commencé": ("commencer",),
    "commencent": ("commencer",),
    "commence": ("commencer",),
    "commencera": ("commencer",),
    "commenceraient": ("commencer",),
    "commencerai": ("commencer",),
    "commencerais": ("commencer",),
    "commencerait": ("commencer",),
    "commenceras": ("commencer",),
    "commencèrent": ("commencer",),
    "commencerez": ("commencer",),
    "commenceriez": ("commencer",),
    "commencerions": ("commencer",),
    "commencerons": ("commencer",),
    "commenceront": ("commencer",),
    "commencés": ("commencer",),
    "commences": ("commencer",),
    "commencez": ("commencer",),
    "commenciez": ("commencer",),
    "commencions": ("commencer",),
    "commençons": ("commencer",),
    "commerçaient": ("commercer",),
    "commerçai": ("commercer",),
    "commerçais": ("commercer",),
    "commerçait": ("commercer",),
    "commerça": ("commercer",),
    "commerçâmes": ("commercer",),
    "commerçant": ("commercer",),
    "commerças": ("commercer",),
    "commerçassent": ("commercer",),
    "commerçasses": ("commercer",),
    "commerçasse": ("commercer",),
    "commerçassiez": ("commercer",),
    "commerçassions": ("commercer",),
    "commerçâtes": ("commercer",),
    "commerçât": ("commercer",),
    "commercé": ("commercer",),
    "commercent": ("commercer",),
    "commerce": ("commercer",),
    "commercera": ("commercer",),
    "commerceraient": ("commercer",),
    "commercerai": ("commercer",),
    "commercerais": ("commercer",),
    "commercerait": ("commercer",),
    "commerceras": ("commercer",),
    "commercèrent": ("commercer",),
    "commercerez": ("commercer",),
    "commerceriez": ("commercer",),
    "commercerions": ("commercer",),
    "commercerons": ("commercer",),
    "commerceront": ("commercer",),
    "commerces": ("commercer",),
    "commercez": ("commercer",),
    "commerciez": ("commercer",),
    "commercions": ("commercer",),
    "commerçons": ("commercer",),
    "comméraient": ("commérer",),
    "commérai": ("commérer",),
    "commérais": ("commérer",),
    "commérait": ("commérer",),
    "comméra": ("commérer",),
    "commérâmes": ("commérer",),
    "commérant": ("commérer",),
    "comméras": ("commérer",),
    "commérassent": ("commérer",),
    "commérasses": ("commérer",),
    "commérasse": ("commérer",),
    "commérassiez": ("commérer",),
    "commérassions": ("commérer",),
    "commérâtes": ("commérer",),
    "commérât": ("commérer",),
    "comméré": ("commérer",),
    "commèrent": ("commérer",),
    "commère": ("commérer",),
    "commérera": ("commérer",),
    "comméreraient": ("commérer",),
    "commérerai": ("commérer",),
    "commérerais": ("commérer",),
    "commérerait": ("commérer",),
    "comméreras": ("commérer",),
    "commérèrent": ("commérer",),
    "commérerez": ("commérer",),
    "comméreriez": ("commérer",),
    "commérerions": ("commérer",),
    "commérerons": ("commérer",),
    "comméreront": ("commérer",),
    "commères": ("commérer",),
    "commérez": ("commérer",),
    "commériez": ("commérer",),
    "commérions": ("commérer",),
    "commérons": ("commérer",),
    "commet": ("commettre",),
    "commets": ("commettre",),
    "commettaient": ("commettre",),
    "commettais": ("commettre",),
    "commettait": ("commettre",),
    "commettant": ("commettre",),
    "commettent": ("commettre",),
    "commette": ("commettre",),
    "commettes": ("commettre",),
    "commettez": ("commettre",),
    "commettiez": ("commettre",),
    "commettions": ("commettre",),
    "commettons": ("commettre",),
    "commettra": ("commettre",),
    "commettraient": ("commettre",),
    "commettrai": ("commettre",),
    "commettrais": ("commettre",),
    "commettrait": ("commettre",),
    "commettras": ("commettre",),
    "commettrez": ("commettre",),
    "commettriez": ("commettre",),
    "commettrions": ("commettre",),
    "commettrons": ("commettre",),
    "commettront": ("commettre",),
    "commîmes": ("commettre",),
    "commirent": ("commettre",),
    "commise": ("commettre",),
    "commises": ("commettre",),
    "commis": ("commettre",),
    "commissent": ("commettre",),
    "commisses": ("commettre",),
    "commisse": ("commettre",),
    "commissiez": ("commettre",),
    "commissions": ("commettre",),
    "commîtes": ("commettre",),
    "commit": ("commettre",),
    "commît": ("commettre",),
    "communiaient": ("communier",),
    "communiai": ("communier",),
    "communiais": ("communier",),
    "communiait": ("communier",),
    "communia": ("communier",),
    "communiâmes": ("communier",),
    "communiant": ("communier",),
    "communias": ("communier",),
    "communiassent": ("communier",),
    "communiasses": ("communier",),
    "communiasse": ("communier",),
    "communiassiez": ("communier",),
    "communiassions": ("communier",),
    "communiâtes": ("communier",),
    "communiât": ("communier",),
    "communiée": ("communier",),
    "communiées": ("communier",),
    "communié": ("communier",),
    "communient": ("communier",),
    "communie": ("communier",),
    "communiera": ("communier",),
    "communieraient": ("communier",),
    "communierai": ("communier",),
    "communierais": ("communier",),
    "communierait": ("communier",),
    "communieras": ("communier",),
    "communièrent": ("communier",),
    "communierez": ("communier",),
    "communieriez": ("communier",),
    "communierions": ("communier",),
    "communierons": ("communier",),
    "communieront": ("communier",),
    "communiés": ("communier",),
    "communies": ("communier",),
    "communiez": ("communier",),
    "communiiez": ("communier",),
    "communiions": ("communier",),
    "communions": ("communier",),
    "compactifiaient": ("compactifier",),
    "compactifiai": ("compactifier",),
    "compactifiais": ("compactifier",),
    "compactifiait": ("compactifier",),
    "compactifia": ("compactifier",),
    "compactifiâmes": ("compactifier",),
    "compactifiant": ("compactifier",),
    "compactifias": ("compactifier",),
    "compactifiassent": ("compactifier",),
    "compactifiasses": ("compactifier",),
    "compactifiasse": ("compactifier",),
    "compactifiassiez": ("compactifier",),
    "compactifiassions": ("compactifier",),
    "compactifiâtes": ("compactifier",),
    "compactifiât": ("compactifier",),
    "compactifiée": ("compactifier",),
    "compactifiées": ("compactifier",),
    "compactifié": ("compactifier",),
    "compactifient": ("compactifier",),
    "compactifie": ("compactifier",),
    "compactifiera": ("compactifier",),
    "compactifieraient": ("compactifier",),
    "compactifierai": ("compactifier",),
    "compactifierais": ("compactifier",),
    "compactifierait": ("compactifier",),
    "compactifieras": ("compactifier",),
    "compactifièrent": ("compactifier",),
    "compactifierez": ("compactifier",),
    "compactifieriez": ("compactifier",),
    "compactifierions": ("compactifier",),
    "compactifierons": ("compactifier",),
    "compactifieront": ("compactifier",),
    "compactifiés": ("compactifier",),
    "compactifies": ("compactifier",),
    "compactifiez": ("compactifier",),
    "compactifiiez": ("compactifier",),
    "compactifiions": ("compactifier",),
    "compactifions": ("compactifier",),
    "comparais": ("comparaître",),
    "comparaissaient": ("comparaître",),
    "comparaissais": ("comparaître",),
    "comparaissait": ("comparaître",),
    "comparaissant": ("comparaître",),
    "comparaissent": ("comparaître",),
    "comparaisse": ("comparaître",),
    "comparaisses": ("comparaître",),
    "comparaissez": ("comparaître",),
    "comparaissiez": ("comparaître",),
    "comparaissions": ("comparaître",),
    "comparaissons": ("comparaître",),
    "comparaît": ("comparaître",),
    "comparaîtra": ("comparaître",),
    "comparaîtraient": ("comparaître",),
    "comparaîtrai": ("comparaître",),
    "comparaîtrais": ("comparaître",),
    "comparaîtrait": ("comparaître",),
    "comparaîtras": ("comparaître",),
    "comparaîtrez": ("comparaître",),
    "comparaîtriez": ("comparaître",),
    "comparaîtrions": ("comparaître",),
    "comparaîtrons": ("comparaître",),
    "comparaîtront": ("comparaître",),
    "comparue": ("comparaître",),
    "comparues": ("comparaître",),
    "comparu": ("comparaître",),
    "comparûmes": ("comparaître",),
    "comparurent": ("comparaître",),
    "comparus": ("comparaître",),
    "comparussent": ("comparaître",),
    "comparusses": ("comparaître",),
    "comparusse": ("comparaître",),
    "comparussiez": ("comparaître",),
    "comparussions": ("comparaître",),
    "comparûtes": ("comparaître",),
    "comparut": ("comparaître",),
    "comparût": ("comparaître",),
    "compassaient": ("compasser",),
    "compassai": ("compasser",),
    "compassais": ("compasser",),
    "compassait": ("compasser",),
    "compassa": ("compasser",),
    "compassâmes": ("compasser",),
    "compassant": ("compasser",),
    "compassas": ("compasser",),
    "compassassent": ("compasser",),
    "compassasses": ("compasser",),
    "compassasse": ("compasser",),
    "compassassiez": ("compasser",),
    "compassassions": ("compasser",),
    "compassâtes": ("compasser",),
    "compassât": ("compasser",),
    "compassée": ("compasser",),
    "compassées": ("compasser",),
    "compassé": ("compasser",),
    "compassent": ("compasser",),
    "compasse": ("compasser",),
    "compassera": ("compasser",),
    "compasseraient": ("compasser",),
    "compasserai": ("compasser",),
    "compasserais": ("compasser",),
    "compasserait": ("compasser",),
    "compasseras": ("compasser",),
    "compassèrent": ("compasser",),
    "compasserez": ("compasser",),
    "compasseriez": ("compasser",),
    "compasserions": ("compasser",),
    "compasserons": ("compasser",),
    "compasseront": ("compasser",),
    "compassés": ("compasser",),
    "compasses": ("compasser",),
    "compassez": ("compasser",),
    "compassiez": ("compasser",),
    "compassions": ("compasser",),
    "compassons": ("compasser",),
    "compati": ("compatir",),
    "compatîmes": ("compatir",),
    "compatira": ("compatir",),
    "compatiraient": ("compatir",),
    "compatirai": ("compatir",),
    "compatirais": ("compatir",),
    "compatirait": ("compatir",),
    "compatiras": ("compatir",),
    "compatirent": ("compatir",),
    "compatirez": ("compatir",),
    "compatiriez": ("compatir",),
    "compatirions": ("compatir",),
    "compatirons": ("compatir",),
    "compatiront": ("compatir",),
    "compatis": ("compatir",),
    "compatissaient": ("compatir",),
    "compatissais": ("compatir",),
    "compatissait": ("compatir",),
    "compatissant": ("compatir",),
    "compatissent": ("compatir",),
    "compatisse": ("compatir",),
    "compatisses": ("compatir",),
    "compatissez": ("compatir",),
    "compatissiez": ("compatir",),
    "compatissions": ("compatir",),
    "compatissons": ("compatir",),
    "compatîtes": ("compatir",),
    "compatit": ("compatir",),
    "compatît": ("compatir",),
    "compénétraient": ("compénétrer",),
    "compénétrai": ("compénétrer",),
    "compénétrais": ("compénétrer",),
    "compénétrait": ("compénétrer",),
    "compénétra": ("compénétrer",),
    "compénétrâmes": ("compénétrer",),
    "compénétrant": ("compénétrer",),
    "compénétras": ("compénétrer",),
    "compénétrassent": ("compénétrer",),
    "compénétrasses": ("compénétrer",),
    "compénétrasse": ("compénétrer",),
    "compénétrassiez": ("compénétrer",),
    "compénétrassions": ("compénétrer",),
    "compénétrâtes": ("compénétrer",),
    "compénétrât": ("compénétrer",),
    "compénétrée": ("compénétrer",),
    "compénétrées": ("compénétrer",),
    "compénétré": ("compénétrer",),
    "compénètrent": ("compénétrer",),
    "compénètre": ("compénétrer",),
    "compénétrera": ("compénétrer",),
    "compénétreraient": ("compénétrer",),
    "compénétrerai": ("compénétrer",),
    "compénétrerais": ("compénétrer",),
    "compénétrerait": ("compénétrer",),
    "compénétreras": ("compénétrer",),
    "compénétrèrent": ("compénétrer",),
    "compénétrerez": ("compénétrer",),
    "compénétreriez": ("compénétrer",),
    "compénétrerions": ("compénétrer",),
    "compénétrerons": ("compénétrer",),
    "compénétreront": ("compénétrer",),
    "compénétrés": ("compénétrer",),
    "compénètres": ("compénétrer",),
    "compénétrez": ("compénétrer",),
    "compénétriez": ("compénétrer",),
    "compénétrions": ("compénétrer",),
    "compénétrons": ("compénétrer",),
    "compétaient": ("compéter",),
    "compétai": ("compéter",),
    "compétais": ("compéter",),
    "compétait": ("compéter",),
    "compéta": ("compéter",),
    "compétâmes": ("compéter",),
    "compétant": ("compéter",),
    "compétas": ("compéter",),
    "compétassent": ("compéter",),
    "compétasses": ("compéter",),
    "compétasse": ("compéter",),
    "compétassiez": ("compéter",),
    "compétassions": ("compéter",),
    "compétâtes": ("compéter",),
    "compétât": ("compéter",),
    "compétée": ("compéter",),
    "compétées": ("compéter",),
    "compété": ("compéter",),
    "compètent": ("compéter",),
    "compète": ("compéter",),
    "compétera": ("compéter",),
    "compéteraient": ("compéter",),
    "compéterai": ("compéter",),
    "compéterais": ("compéter",),
    "compéterait": ("compéter",),
    "compéteras": ("compéter",),
    "compétèrent": ("compéter",),
    "compéterez": ("compéter",),
    "compéteriez": ("compéter",),
    "compéterions": ("compéter",),
    "compéterons": ("compéter",),
    "compéteront": ("compéter",),
    "compétés": ("compéter",),
    "compètes": ("compéter",),
    "compétez": ("compéter",),
    "compétiez": ("compéter",),
    "compétions": ("compéter",),
    "compétons": ("compéter",),
    "complaignaient": ("complaindre",),
    "complaignais": ("complaindre",),
    "complaignait": ("complaindre",),
    "complaignant": ("complaindre",),
    "complaignent": ("complaindre",),
    "complaigne": ("complaindre",),
    "complaignes": ("complaindre",),
    "complaignez": ("complaindre",),
    "complaigniez": ("complaindre",),
    "complaignîmes": ("complaindre",),
    "complaignions": ("complaindre",),
    "complaignirent": ("complaindre",),
    "complaignis": ("complaindre",),
    "complaignissent": ("complaindre",),
    "complaignisses": ("complaindre",),
    "complaignisse": ("complaindre",),
    "complaignissiez": ("complaindre",),
    "complaignissions": ("complaindre",),
    "complaignîtes": ("complaindre",),
    "complaignit": ("complaindre",),
    "complaignît": ("complaindre",),
    "complaignons": ("complaindre",),
    "complaindra": ("complaindre",),
    "complaindraient": ("complaindre",),
    "complaindrai": ("complaindre",),
    "complaindrais": ("complaindre",),
    "complaindrait": ("complaindre",),
    "complaindras": ("complaindre",),
    "complaindrez": ("complaindre",),
    "complaindriez": ("complaindre",),
    "complaindrions": ("complaindre",),
    "complaindrons": ("complaindre",),
    "complaindront": ("complaindre",),
    "complains": ("complaindre",),
    "complainte": ("complaindre",),
    "complaintes": ("complaindre",),
    "complaint": ("complaindre",),
    "complaints": ("complaindre",),
    "complaira": ("complaire",),
    "complairaient": ("complaire",),
    "complairai": ("complaire",),
    "complairais": ("complaire",),
    "complairait": ("complaire",),
    "complairas": ("complaire",),
    "complairez": ("complaire",),
    "complairiez": ("complaire",),
    "complairions": ("complaire",),
    "complairons": ("complaire",),
    "complairont": ("complaire",),
    "complaisaient": ("complaire",),
    "complaisais": ("complaire",),
    "complaisait": ("complaire",),
    "complaisant": ("complaire",),
    "complaisent": ("complaire",),
    "complaise": ("complaire",),
    "complaises": ("complaire",),
    "complaisez": ("complaire",),
    "complaisiez": ("complaire",),
    "complaisions": ("complaire",),
    "complaisons": ("complaire",),
    "complais": ("complaire",),
    "complaît": ("complaire",),
    "complue": ("complaire",),
    "complues": ("complaire",),
    "complu": ("complaire",),
    "complûmes": ("complaire",),
    "complurent": ("complaire",),
    "complus": ("complaire",),
    "complussent": ("complaire",),
    "complusses": ("complaire",),
    "complusse": ("complaire",),
    "complussiez": ("complaire",),
    "complussions": ("complaire",),
    "complûtes": ("complaire",),
    "complut": ("complaire",),
    "complût": ("complaire",),
    "complétaient": ("compléter",),
    "complétai": ("compléter",),
    "complétais": ("compléter",),
    "complétait": ("compléter",),
    "compléta": ("compléter",),
    "complétâmes": ("compléter",),
    "complétant": ("compléter",),
    "complétas": ("compléter",),
    "complétassent": ("compléter",),
    "complétasses": ("compléter",),
    "complétasse": ("compléter",),
    "complétassiez": ("compléter",),
    "complétassions": ("compléter",),
    "complétâtes": ("compléter",),
    "complétât": ("compléter",),
    "complétée": ("compléter",),
    "complétées": ("compléter",),
    "complété": ("compléter",),
    "complètent": ("compléter",),
    "complète": ("compléter",),
    "complétera": ("compléter",),
    "compléteraient": ("compléter",),
    "compléterai": ("compléter",),
    "compléterais": ("compléter",),
    "compléterait": ("compléter",),
    "compléteras": ("compléter",),
    "complétèrent": ("compléter",),
    "compléterez": ("compléter",),
    "compléteriez": ("compléter",),
    "compléterions": ("compléter",),
    "compléterons": ("compléter",),
    "compléteront": ("compléter",),
    "complétés": ("compléter",),
    "complètes": ("compléter",),
    "complétez": ("compléter",),
    "complétiez": ("compléter",),
    "complétions": ("compléter",),
    "complétons": ("compléter",),
    "complexifiaient": ("complexifier",),
    "complexifiai": ("complexifier",),
    "complexifiais": ("complexifier",),
    "complexifiait": ("complexifier",),
    "complexifia": ("complexifier",),
    "complexifiâmes": ("complexifier",),
    "complexifiant": ("complexifier",),
    "complexifias": ("complexifier",),
    "complexifiassent": ("complexifier",),
    "complexifiasses": ("complexifier",),
    "complexifiasse": ("complexifier",),
    "complexifiassiez": ("complexifier",),
    "complexifiassions": ("complexifier",),
    "complexifiâtes": ("complexifier",),
    "complexifiât": ("complexifier",),
    "complexifiée": ("complexifier",),
    "complexifiées": ("complexifier",),
    "complexifié": ("complexifier",),
    "complexifient": ("complexifier",),
    "complexifie": ("complexifier",),
    "complexifiera": ("complexifier",),
    "complexifieraient": ("complexifier",),
    "complexifierai": ("complexifier",),
    "complexifierais": ("complexifier",),
    "complexifierait": ("complexifier",),
    "complexifieras": ("complexifier",),
    "complexifièrent": ("complexifier",),
    "complexifierez": ("complexifier",),
    "complexifieriez": ("complexifier",),
    "complexifierions": ("complexifier",),
    "complexifierons": ("complexifier",),
    "complexifieront": ("complexifier",),
    "complexifiés": ("complexifier",),
    "complexifies": ("complexifier",),
    "complexifiez": ("complexifier",),
    "complexifiiez": ("complexifier",),
    "complexifiions": ("complexifier",),
    "complexifions": ("complexifier",),
    "comprenaient": ("comprendre",),
    "comprenais": ("comprendre",),
    "comprenait": ("comprendre",),
    "comprenant": ("comprendre",),
    "comprend": ("comprendre",),
    "comprendra": ("comprendre",),
    "comprendraient": ("comprendre",),
    "comprendrai": ("comprendre",),
    "comprendrais": ("comprendre",),
    "comprendrait": ("comprendre",),
    "comprendras": ("comprendre",),
    "comprendrez": ("comprendre",),
    "comprendriez": ("comprendre",),
    "comprendrions": ("comprendre",),
    "comprendrons": ("comprendre",),
    "comprendront": ("comprendre",),
    "comprends": ("comprendre",),
    "comprenez": ("comprendre",),
    "compreniez": ("comprendre",),
    "comprenions": ("comprendre",),
    "comprennent": ("comprendre",),
    "comprenne": ("comprendre",),
    "comprennes": ("comprendre",),
    "comprenons": ("comprendre",),
    "comprîmes": ("comprendre",),
    "comprirent": ("comprendre",),
    "comprise": ("comprendre",),
    "comprises": ("comprendre",),
    "compris": ("comprendre",),
    "comprissent": ("comprendre",),
    "comprisses": ("comprendre",),
    "comprisse": ("comprendre",),
    "comprissiez": ("comprendre",),
    "comprissions": ("comprendre",),
    "comprîtes": ("comprendre",),
    "comprit": ("comprendre",),
    "comprît": ("comprendre",),
    "compromet": ("compromettre",),
    "compromets": ("compromettre",),
    "compromettaient": ("compromettre",),
    "compromettais": ("compromettre",),
    "compromettait": ("compromettre",),
    "compromettant": ("compromettre",),
    "compromettent": ("compromettre",),
    "compromette": ("compromettre",),
    "compromettes": ("compromettre",),
    "compromettez": ("compromettre",),
    "compromettiez": ("compromettre",),
    "compromettions": ("compromettre",),
    "compromettons": ("compromettre",),
    "compromettra": ("compromettre",),
    "compromettraient": ("compromettre",),
    "compromettrai": ("compromettre",),
    "compromettrais": ("compromettre",),
    "compromettrait": ("compromettre",),
    "compromettras": ("compromettre",),
    "compromettrez": ("compromettre",),
    "compromettriez": ("compromettre",),
    "compromettrions": ("compromettre",),
    "compromettrons": ("compromettre",),
    "compromettront": ("compromettre",),
    "compromîmes": ("compromettre",),
    "compromirent": ("compromettre",),
    "compromise": ("compromettre",),
    "compromises": ("compromettre",),
    "compromis": ("compromettre",),
    "compromissent": ("compromettre",),
    "compromisses": ("compromettre",),
    "compromisse": ("compromettre",),
    "compromissiez": ("compromettre",),
    "compromissions": ("compromettre",),
    "compromîtes": ("compromettre",),
    "compromit": ("compromettre",),
    "compromît": ("compromettre",),
    "concassaient": ("concasser",),
    "concassai": ("concasser",),
    "concassais": ("concasser",),
    "concassait": ("concasser",),
    "concassa": ("concasser",),
    "concassâmes": ("concasser",),
    "concassant": ("concasser",),
    "concassas": ("concasser",),
    "concassassent": ("concasser",),
    "concassasses": ("concasser",),
    "concassasse": ("concasser",),
    "concassassiez": ("concasser",),
    "concassassions": ("concasser",),
    "concassâtes": ("concasser",),
    "concassât": ("concasser",),
    "concassée": ("concasser",),
    "concassées": ("concasser",),
    "concassé": ("concasser",),
    "concassent": ("concasser",),
    "concasse": ("concasser",),
    "concassera": ("concasser",),
    "concasseraient": ("concasser",),
    "concasserai": ("concasser",),
    "concasserais": ("concasser",),
    "concasserait": ("concasser",),
    "concasseras": ("concasser",),
    "concassèrent": ("concasser",),
    "concasserez": ("concasser",),
    "concasseriez": ("concasser",),
    "concasserions": ("concasser",),
    "concasserons": ("concasser",),
    "concasseront": ("concasser",),
    "concassés": ("concasser",),
    "concasses": ("concasser",),
    "concassez": ("concasser",),
    "concassiez": ("concasser",),
    "concassions": ("concasser",),
    "concassons": ("concasser",),
    "concaténaient": ("concaténer",),
    "concaténai": ("concaténer",),
    "concaténais": ("concaténer",),
    "concaténait": ("concaténer",),
    "concaténa": ("concaténer",),
    "concaténâmes": ("concaténer",),
    "concaténant": ("concaténer",),
    "concaténas": ("concaténer",),
    "concaténassent": ("concaténer",),
    "concaténasses": ("concaténer",),
    "concaténasse": ("concaténer",),
    "concaténassiez": ("concaténer",),
    "concaténassions": ("concaténer",),
    "concaténâtes": ("concaténer",),
    "concaténât": ("concaténer",),
    "concaténée": ("concaténer",),
    "concaténées": ("concaténer",),
    "concaténé": ("concaténer",),
    "concatènent": ("concaténer",),
    "concatène": ("concaténer",),
    "concaténera": ("concaténer",),
    "concaténeraient": ("concaténer",),
    "concaténerai": ("concaténer",),
    "concaténerais": ("concaténer",),
    "concaténerait": ("concaténer",),
    "concaténeras": ("concaténer",),
    "concaténèrent": ("concaténer",),
    "concaténerez": ("concaténer",),
    "concaténeriez": ("concaténer",),
    "concaténerions": ("concaténer",),
    "concaténerons": ("concaténer",),
    "concaténeront": ("concaténer",),
    "concaténés": ("concaténer",),
    "concatènes": ("concaténer",),
    "concaténez": ("concaténer",),
    "concaténiez": ("concaténer",),
    "concaténions": ("concaténer",),
    "concaténons": ("concaténer",),
    "concédaient": ("concéder",),
    "concédai": ("concéder",),
    "concédais": ("concéder",),
    "concédait": ("concéder",),
    "concéda": ("concéder",),
    "concédâmes": ("concéder",),
    "concédant": ("concéder",),
    "concédas": ("concéder",),
    "concédassent": ("concéder",),
    "concédasses": ("concéder",),
    "concédasse": ("concéder",),
    "concédassiez": ("concéder",),
    "concédassions": ("concéder",),
    "concédâtes": ("concéder",),
    "concédât": ("concéder",),
    "concédée": ("concéder",),
    "concédées": ("concéder",),
    "concédé": ("concéder",),
    "concèdent": ("concéder",),
    "concède": ("concéder",),
    "concédera": ("concéder",),
    "concéderaient": ("concéder",),
    "concéderai": ("concéder",),
    "concéderais": ("concéder",),
    "concéderait": ("concéder",),
    "concéderas": ("concéder",),
    "concédèrent": ("concéder",),
    "concéderez": ("concéder",),
    "concéderiez": ("concéder",),
    "concéderions": ("concéder",),
    "concéderons": ("concéder",),
    "concéderont": ("concéder",),
    "concédés": ("concéder",),
    "concèdes": ("concéder",),
    "concédez": ("concéder",),
    "concédiez": ("concéder",),
    "concédions": ("concéder",),
    "concédons": ("concéder",),
    "concélébraient": ("concélébrer",),
    "concélébrai": ("concélébrer",),
    "concélébrais": ("concélébrer",),
    "concélébrait": ("concélébrer",),
    "concélébra": ("concélébrer",),
    "concélébrâmes": ("concélébrer",),
    "concélébrant": ("concélébrer",),
    "concélébras": ("concélébrer",),
    "concélébrassent": ("concélébrer",),
    "concélébrasses": ("concélébrer",),
    "concélébrasse": ("concélébrer",),
    "concélébrassiez": ("concélébrer",),
    "concélébrassions": ("concélébrer",),
    "concélébrâtes": ("concélébrer",),
    "concélébrât": ("concélébrer",),
    "concélébrée": ("concélébrer",),
    "concélébrées": ("concélébrer",),
    "concélébré": ("concélébrer",),
    "concélèbrent": ("concélébrer",),
    "concélèbre": ("concélébrer",),
    "concélébrera": ("concélébrer",),
    "concélébreraient": ("concélébrer",),
    "concélébrerai": ("concélébrer",),
    "concélébrerais": ("concélébrer",),
    "concélébrerait": ("concélébrer",),
    "concélébreras": ("concélébrer",),
    "concélébrèrent": ("concélébrer",),
    "concélébrerez": ("concélébrer",),
    "concélébreriez": ("concélébrer",),
    "concélébrerions": ("concélébrer",),
    "concélébrerons": ("concélébrer",),
    "concélébreront": ("concélébrer",),
    "concélébrés": ("concélébrer",),
    "concélèbres": ("concélébrer",),
    "concélébrez": ("concélébrer",),
    "concélébriez": ("concélébrer",),
    "concélébrions": ("concélébrer",),
    "concélébrons": ("concélébrer",),
    "concevaient": ("concevoir",),
    "concevais": ("concevoir",),
    "concevait": ("concevoir",),
    "concevant": ("concevoir",),
    "concevez": ("concevoir",),
    "conceviez": ("concevoir",),
    "concevions": ("concevoir",),
    "concevons": ("concevoir",),
    "concevra": ("concevoir",),
    "concevraient": ("concevoir",),
    "concevrai": ("concevoir",),
    "concevrais": ("concevoir",),
    "concevrait": ("concevoir",),
    "concevras": ("concevoir",),
    "concevrez": ("concevoir",),
    "concevriez": ("concevoir",),
    "concevrions": ("concevoir",),
    "concevrons": ("concevoir",),
    "concevront": ("concevoir",),
    "conçois": ("concevoir",),
    "conçoit": ("concevoir",),
    "conçoivent": ("concevoir",),
    "conçoive": ("concevoir",),
    "conçoives": ("concevoir",),
    "conçue": ("concevoir",),
    "conçues": ("concevoir",),
    "conçu": ("concevoir",),
    "conçûmes": ("concevoir",),
    "conçurent": ("concevoir",),
    "conçus": ("concevoir",),
    "conçussent": ("concevoir",),
    "conçusses": ("concevoir",),
    "conçusse": ("concevoir",),
    "conçussiez": ("concevoir",),
    "conçussions": ("concevoir",),
    "conçûtes": ("concevoir",),
    "conçut": ("concevoir",),
    "conçût": ("concevoir",),
    "conchiaient": ("conchier",),
    "conchiai": ("conchier",),
    "conchiais": ("conchier",),
    "conchiait": ("conchier",),
    "conchia": ("conchier",),
    "conchiâmes": ("conchier",),
    "conchiant": ("conchier",),
    "conchias": ("conchier",),
    "conchiassent": ("conchier",),
    "conchiasses": ("conchier",),
    "conchiasse": ("conchier",),
    "conchiassiez": ("conchier",),
    "conchiassions": ("conchier",),
    "conchiâtes": ("conchier",),
    "conchiât": ("conchier",),
    "conchiée": ("conchier",),
    "conchiées": ("conchier",),
    "conchié": ("conchier",),
    "conchient": ("conchier",),
    "conchie": ("conchier",),
    "conchiera": ("conchier",),
    "conchieraient": ("conchier",),
    "conchierai": ("conchier",),
    "conchierais": ("conchier",),
    "conchierait": ("conchier",),
    "conchieras": ("conchier",),
    "conchièrent": ("conchier",),
    "conchierez": ("conchier",),
    "conchieriez": ("conchier",),
    "conchierions": ("conchier",),
    "conchierons": ("conchier",),
    "conchieront": ("conchier",),
    "conchiés": ("conchier",),
    "conchies": ("conchier",),
    "conchiez": ("conchier",),
    "conchiiez": ("conchier",),
    "conchiions": ("conchier",),
    "conchions": ("conchier",),
    "conciliaient": ("concilier",),
    "conciliai": ("concilier",),
    "conciliais": ("concilier",),
    "conciliait": ("concilier",),
    "concilia": ("concilier",),
    "conciliâmes": ("concilier",),
    "conciliant": ("concilier",),
    "concilias": ("concilier",),
    "conciliassent": ("concilier",),
    "conciliasses": ("concilier",),
    "conciliasse": ("concilier",),
    "conciliassiez": ("concilier",),
    "conciliassions": ("concilier",),
    "conciliâtes": ("concilier",),
    "conciliât": ("concilier",),
    "conciliée": ("concilier",),
    "conciliées": ("concilier",),
    "concilié": ("concilier",),
    "concilient": ("concilier",),
    "concilie": ("concilier",),
    "conciliera": ("concilier",),
    "concilieraient": ("concilier",),
    "concilierai": ("concilier",),
    "concilierais": ("concilier",),
    "concilierait": ("concilier",),
    "concilieras": ("concilier",),
    "concilièrent": ("concilier",),
    "concilierez": ("concilier",),
    "concilieriez": ("concilier",),
    "concilierions": ("concilier",),
    "concilierons": ("concilier",),
    "concilieront": ("concilier",),
    "conciliés": ("concilier",),
    "concilies": ("concilier",),
    "conciliez": ("concilier",),
    "conciliiez": ("concilier",),
    "conciliions": ("concilier",),
    "concilions": ("concilier",),
    "concluaient": ("conclure",),
    "concluais": ("conclure",),
    "concluait": ("conclure",),
    "concluant": ("conclure",),
    "conclue": ("conclure",),
    "concluent": ("conclure",),
    "conclues": ("conclure",),
    "concluez": ("conclure",),
    "concluiez": ("conclure",),
    "concluions": ("conclure",),
    "conclu": ("conclure",),
    "conclûmes": ("conclure",),
    "concluons": ("conclure",),
    "conclura": ("conclure",),
    "concluraient": ("conclure",),
    "conclurai": ("conclure",),
    "conclurais": ("conclure",),
    "conclurait": ("conclure",),
    "concluras": ("conclure",),
    "conclurent": ("conclure",),
    "conclurez": ("conclure",),
    "concluriez": ("conclure",),
    "conclurions": ("conclure",),
    "conclurons": ("conclure",),
    "concluront": ("conclure",),
    "conclus": ("conclure",),
    "conclussent": ("conclure",),
    "conclusses": ("conclure",),
    "conclusse": ("conclure",),
    "conclussiez": ("conclure",),
    "conclussions": ("conclure",),
    "conclûtes": ("conclure",),
    "conclut": ("conclure",),
    "conclût": ("conclure",),
    "concouraient": ("concourir",),
    "concourais": ("concourir",),
    "concourait": ("concourir",),
    "concourant": ("concourir",),
    "concourent": ("concourir",),
    "concoure": ("concourir",),
    "concoures": ("concourir",),
    "concourez": ("concourir",),
    "concouriez": ("concourir",),
    "concourions": ("concourir",),
    "concourons": ("concourir",),
    "concourra": ("concourir",),
    "concourraient": ("concourir",),
    "concourrai": ("concourir",),
    "concourrais": ("concourir",),
    "concourrait": ("concourir",),
    "concourras": ("concourir",),
    "concourrez": ("concourir",),
    "concourriez": ("concourir",),
    "concourrions": ("concourir",),
    "concourrons": ("concourir",),
    "concourront": ("concourir",),
    "concours": ("concourir",),
    "concourt": ("concourir",),
    "concouru": ("concourir",),
    "concourûmes": ("concourir",),
    "concoururent": ("concourir",),
    "concourus": ("concourir",),
    "concourussent": ("concourir",),
    "concourusses": ("concourir",),
    "concourusse": ("concourir",),
    "concourussiez": ("concourir",),
    "concourussions": ("concourir",),
    "concourûtes": ("concourir",),
    "concourut": ("concourir",),
    "concourût": ("concourir",),
    "concrétaient": ("concréter",),
    "concrétai": ("concréter",),
    "concrétais": ("concréter",),
    "concrétait": ("concréter",),
    "concréta": ("concréter",),
    "concrétâmes": ("concréter",),
    "concrétant": ("concréter",),
    "concrétas": ("concréter",),
    "concrétassent": ("concréter",),
    "concrétasses": ("concréter",),
    "concrétasse": ("concréter",),
    "concrétassiez": ("concréter",),
    "concrétassions": ("concréter",),
    "concrétâtes": ("concréter",),
    "concrétât": ("concréter",),
    "concrétée": ("concréter",),
    "concrétées": ("concréter",),
    "concrété": ("concréter",),
    "concrètent": ("concréter",),
    "concrète": ("concréter",),
    "concrétera": ("concréter",),
    "concréteraient": ("concréter",),
    "concréterai": ("concréter",),
    "concréterais": ("concréter",),
    "concréterait": ("concréter",),
    "concréteras": ("concréter",),
    "concrétèrent": ("concréter",),
    "concréterez": ("concréter",),
    "concréteriez": ("concréter",),
    "concréterions": ("concréter",),
    "concréterons": ("concréter",),
    "concréteront": ("concréter",),
    "concrétés": ("concréter",),
    "concrètes": ("concréter",),
    "concrétez": ("concréter",),
    "concrétiez": ("concréter",),
    "concrétions": ("concréter",),
    "concrétons": ("concréter",),
    "concupisçaient": ("concupiscer",),
    "concupisçai": ("concupiscer",),
    "concupisçais": ("concupiscer",),
    "concupisçait": ("concupiscer",),
    "concupisça": ("concupiscer",),
    "concupisçâmes": ("concupiscer",),
    "concupisçant": ("concupiscer",),
    "concupisças": ("concupiscer",),
    "concupisçassent": ("concupiscer",),
    "concupisçasses": ("concupiscer",),
    "concupisçasse": ("concupiscer",),
    "concupisçassiez": ("concupiscer",),
    "concupisçassions": ("concupiscer",),
    "concupisçâtes": ("concupiscer",),
    "concupisçât": ("concupiscer",),
    "concupiscée": ("concupiscer",),
    "concupiscées": ("concupiscer",),
    "concupiscé": ("concupiscer",),
    "concupiscent": ("concupiscer",),
    "concupisce": ("concupiscer",),
    "concupiscera": ("concupiscer",),
    "concupisceraient": ("concupiscer",),
    "concupiscerai": ("concupiscer",),
    "concupiscerais": ("concupiscer",),
    "concupiscerait": ("concupiscer",),
    "concupisceras": ("concupiscer",),
    "concupiscèrent": ("concupiscer",),
    "concupiscerez": ("concupiscer",),
    "concupisceriez": ("concupiscer",),
    "concupiscerions": ("concupiscer",),
    "concupiscerons": ("concupiscer",),
    "concupisceront": ("concupiscer",),
    "concupiscés": ("concupiscer",),
    "concupisces": ("concupiscer",),
    "concupiscez": ("concupiscer",),
    "concupisciez": ("concupiscer",),
    "concupiscions": ("concupiscer",),
    "concupisçons": ("concupiscer",),
    "concurrençaient": ("concurrencer",),
    "concurrençai": ("concurrencer",),
    "concurrençais": ("concurrencer",),
    "concurrençait": ("concurrencer",),
    "concurrença": ("concurrencer",),
    "concurrençâmes": ("concurrencer",),
    "concurrençant": ("concurrencer",),
    "concurrenças": ("concurrencer",),
    "concurrençassent": ("concurrencer",),
    "concurrençasses": ("concurrencer",),
    "concurrençasse": ("concurrencer",),
    "concurrençassiez": ("concurrencer",),
    "concurrençassions": ("concurrencer",),
    "concurrençâtes": ("concurrencer",),
    "concurrençât": ("concurrencer",),
    "concurrencée": ("concurrencer",),
    "concurrencées": ("concurrencer",),
    "concurrencé": ("concurrencer",),
    "concurrencent": ("concurrencer",),
    "concurrence": ("concurrencer",),
    "concurrencera": ("concurrencer",),
    "concurrenceraient": ("concurrencer",),
    "concurrencerai": ("concurrencer",),
    "concurrencerais": ("concurrencer",),
    "concurrencerait": ("concurrencer",),
    "concurrenceras": ("concurrencer",),
    "concurrencèrent": ("concurrencer",),
    "concurrencerez": ("concurrencer",),
    "concurrenceriez": ("concurrencer",),
    "concurrencerions": ("concurrencer",),
    "concurrencerons": ("concurrencer",),
    "concurrenceront": ("concurrencer",),
    "concurrencés": ("concurrencer",),
    "concurrences": ("concurrencer",),
    "concurrencez": ("concurrencer",),
    "concurrenciez": ("concurrencer",),
    "concurrencions": ("concurrencer",),
    "concurrençons": ("concurrencer",),
    "condescendaient": ("condescendre",),
    "condescendais": ("condescendre",),
    "condescendait": ("condescendre",),
    "condescendant": ("condescendre",),
    "condescendent": ("condescendre",),
    "condescende": ("condescendre",),
    "condescendes": ("condescendre",),
    "condescendez": ("condescendre",),
    "condescendiez": ("condescendre",),
    "condescendîmes": ("condescendre",),
    "condescendions": ("condescendre",),
    "condescendirent": ("condescendre",),
    "condescendis": ("condescendre",),
    "condescendissent": ("condescendre",),
    "condescendisses": ("condescendre",),
    "condescendisse": ("condescendre",),
    "condescendissiez": ("condescendre",),
    "condescendissions": ("condescendre",),
    "condescendîtes": ("condescendre",),
    "condescendit": ("condescendre",),
    "condescendît": ("condescendre",),
    "condescendons": ("condescendre",),
    "condescend": ("condescendre",),
    "condescendra": ("condescendre",),
    "condescendraient": ("condescendre",),
    "condescendrai": ("condescendre",),
    "condescendrais": ("condescendre",),
    "condescendrait": ("condescendre",),
    "condescendras": ("condescendre",),
    "condescendrez": ("condescendre",),
    "condescendriez": ("condescendre",),
    "condescendrions": ("condescendre",),
    "condescendrons": ("condescendre",),
    "condescendront": ("condescendre",),
    "condescends": ("condescendre",),
    "condescendu": ("condescendre",),
    "condoléançaient": ("condoléancer",),
    "condoléançai": ("condoléancer",),
    "condoléançais": ("condoléancer",),
    "condoléançait": ("condoléancer",),
    "condoléança": ("condoléancer",),
    "condoléançâmes": ("condoléancer",),
    "condoléançant": ("condoléancer",),
    "condoléanças": ("condoléancer",),
    "condoléançassent": ("condoléancer",),
    "condoléançasses": ("condoléancer",),
    "condoléançasse": ("condoléancer",),
    "condoléançassiez": ("condoléancer",),
    "condoléançassions": ("condoléancer",),
    "condoléançâtes": ("condoléancer",),
    "condoléançât": ("condoléancer",),
    "condoléancée": ("condoléancer",),
    "condoléancées": ("condoléancer",),
    "condoléancé": ("condoléancer",),
    "condoléancent": ("condoléancer",),
    "condoléance": ("condoléancer",),
    "condoléancera": ("condoléancer",),
    "condoléanceraient": ("condoléancer",),
    "condoléancerai": ("condoléancer",),
    "condoléancerais": ("condoléancer",),
    "condoléancerait": ("condoléancer",),
    "condoléanceras": ("condoléancer",),
    "condoléancèrent": ("condoléancer",),
    "condoléancerez": ("condoléancer",),
    "condoléanceriez": ("condoléancer",),
    "condoléancerions": ("condoléancer",),
    "condoléancerons": ("condoléancer",),
    "condoléanceront": ("condoléancer",),
    "condoléancés": ("condoléancer",),
    "condoléances": ("condoléancer",),
    "condoléancez": ("condoléancer",),
    "condoléanciez": ("condoléancer",),
    "condoléancions": ("condoléancer",),
    "condoléançons": ("condoléancer",),
    "conduira": ("conduire",),
    "conduiraient": ("conduire",),
    "conduirai": ("conduire",),
    "conduirais": ("conduire",),
    "conduirait": ("conduire",),
    "conduiras": ("conduire",),
    "conduirez": ("conduire",),
    "conduiriez": ("conduire",),
    "conduirions": ("conduire",),
    "conduirons": ("conduire",),
    "conduiront": ("conduire",),
    "conduisaient": ("conduire",),
    "conduisais": ("conduire",),
    "conduisait": ("conduire",),
    "conduisant": ("conduire",),
    "conduisent": ("conduire",),
    "conduise": ("conduire",),
    "conduises": ("conduire",),
    "conduisez": ("conduire",),
    "conduisiez": ("conduire",),
    "conduisîmes": ("conduire",),
    "conduisions": ("conduire",),
    "conduisirent": ("conduire",),
    "conduisis": ("conduire",),
    "conduisissent": ("conduire",),
    "conduisisses": ("conduire",),
    "conduisisse": ("conduire",),
    "conduisissiez": ("conduire",),
    "conduisissions": ("conduire",),
    "conduisîtes": ("conduire",),
    "conduisit": ("conduire",),
    "conduisît": ("conduire",),
    "conduisons": ("conduire",),
    "conduis": ("conduire",),
    "conduite": ("conduire",),
    "conduites": ("conduire",),
    "conduit": ("conduire",),
    "conduits": ("conduire",),
    "confédéraient": ("confédérer",),
    "confédérai": ("confédérer",),
    "confédérais": ("confédérer",),
    "confédérait": ("confédérer",),
    "confédéra": ("confédérer",),
    "confédérâmes": ("confédérer",),
    "confédérant": ("confédérer",),
    "confédéras": ("confédérer",),
    "confédérassent": ("confédérer",),
    "confédérasses": ("confédérer",),
    "confédérasse": ("confédérer",),
    "confédérassiez": ("confédérer",),
    "confédérassions": ("confédérer",),
    "confédérâtes": ("confédérer",),
    "confédérât": ("confédérer",),
    "confédérée": ("confédérer",),
    "confédérées": ("confédérer",),
    "confédéré": ("confédérer",),
    "confédèrent": ("confédérer",),
    "confédère": ("confédérer",),
    "confédérera": ("confédérer",),
    "confédéreraient": ("confédérer",),
    "confédérerai": ("confédérer",),
    "confédérerais": ("confédérer",),
    "confédérerait": ("confédérer",),
    "confédéreras": ("confédérer",),
    "confédérèrent": ("confédérer",),
    "confédérerez": ("confédérer",),
    "confédéreriez": ("confédérer",),
    "confédérerions": ("confédérer",),
    "confédérerons": ("confédérer",),
    "confédéreront": ("confédérer",),
    "confédérés": ("confédérer",),
    "confédères": ("confédérer",),
    "confédérez": ("confédérer",),
    "confédériez": ("confédérer",),
    "confédérions": ("confédérer",),
    "confédérons": ("confédérer",),
    "conféraient": ("conférer",),
    "conférai": ("conférer",),
    "conférais": ("conférer",),
    "conférait": ("conférer",),
    "conféra": ("conférer",),
    "conférâmes": ("conférer",),
    "conférant": ("conférer",),
    "conféras": ("conférer",),
    "conférassent": ("conférer",),
    "conférasses": ("conférer",),
    "conférasse": ("conférer",),
    "conférassiez": ("conférer",),
    "conférassions": ("conférer",),
    "conférâtes": ("conférer",),
    "conférât": ("conférer",),
    "conférée": ("conférer",),
    "conférées": ("conférer",),
    "conféré": ("conférer",),
    "confèrent": ("conférer",),
    "confère": ("conférer",),
    "conférera": ("conférer",),
    "conféreraient": ("conférer",),
    "conférerai": ("conférer",),
    "conférerais": ("conférer",),
    "conférerait": ("conférer",),
    "conféreras": ("conférer",),
    "conférèrent": ("conférer",),
    "conférerez": ("conférer",),
    "conféreriez": ("conférer",),
    "conférerions": ("conférer",),
    "conférerons": ("conférer",),
    "conféreront": ("conférer",),
    "conférés": ("conférer",),
    "confères": ("conférer",),
    "conférez": ("conférer",),
    "confériez": ("conférer",),
    "conférions": ("conférer",),
    "conférons": ("conférer",),
    "confiaient": ("confier",),
    "confiai": ("confier",),
    "confiais": ("confier",),
    "confiait": ("confier",),
    "confia": ("confier",),
    "confiâmes": ("confier",),
    "confiant": ("confier",),
    "confias": ("confier",),
    "confiassent": ("confier",),
    "confiasses": ("confier",),
    "confiasse": ("confier",),
    "confiassiez": ("confier",),
    "confiassions": ("confier",),
    "confiâtes": ("confier",),
    "confiât": ("confier",),
    "confiée": ("confier",),
    "confiées": ("confier",),
    "confié": ("confier",),
    "confient": ("confier",),
    "confie": ("confier",),
    "confiera": ("confier",),
    "confieraient": ("confier",),
    "confierai": ("confier",),
    "confierais": ("confier",),
    "confierait": ("confier",),
    "confieras": ("confier",),
    "confièrent": ("confier",),
    "confierez": ("confier",),
    "confieriez": ("confier",),
    "confierions": ("confier",),
    "confierons": ("confier",),
    "confieront": ("confier",),
    "confiés": ("confier",),
    "confies": ("confier",),
    "confiez": ("confier",),
    "confiiez": ("confier",),
    "confiions": ("confier",),
    "confions": ("confier",),
    "confîmes": ("confire",),
    "confira": ("confire",),
    "confiraient": ("confire",),
    "confirai": ("confire",),
    "confirais": ("confire",),
    "confirait": ("confire",),
    "confiras": ("confire",),
    "confirent": ("confire",),
    "confirez": ("confire",),
    "confiriez": ("confire",),
    "confirions": ("confire",),
    "confirons": ("confire",),
    "confiront": ("confire",),
    "confisaient": ("confire",),
    "confisais": ("confire",),
    "confisait": ("confire",),
    "confisant": ("confire",),
    "confisent": ("confire",),
    "confise": ("confire",),
    "confises": ("confire",),
    "confisez": ("confire",),
    "confisiez": ("confire",),
    "confisions": ("confire",),
    "confisons": ("confire",),
    "confis": ("confire",),
    "confissent": ("confire",),
    "confisses": ("confire",),
    "confisse": ("confire",),
    "confissiez": ("confire",),
    "confissions": ("confire",),
    "confite": ("confire",),
    "confîtes": ("confire",),
    "confites": ("confire",),
    "confit": ("confire",),
    "confits": ("confire",),
    "confît": ("confire",),
    "confondaient": ("confondre",),
    "confondais": ("confondre",),
    "confondait": ("confondre",),
    "confondant": ("confondre",),
    "confondent": ("confondre",),
    "confonde": ("confondre",),
    "confondes": ("confondre",),
    "confondez": ("confondre",),
    "confondiez": ("confondre",),
    "confondîmes": ("confondre",),
    "confondions": ("confondre",),
    "confondirent": ("confondre",),
    "confondis": ("confondre",),
    "confondissent": ("confondre",),
    "confondisses": ("confondre",),
    "confondisse": ("confondre",),
    "confondissiez": ("confondre",),
    "confondissions": ("confondre",),
    "confondîtes": ("confondre",),
    "confondit": ("confondre",),
    "confondît": ("confondre",),
    "confondons": ("confondre",),
    "confond": ("confondre",),
    "confondra": ("confondre",),
    "confondraient": ("confondre",),
    "confondrai": ("confondre",),
    "confondrais": ("confondre",),
    "confondrait": ("confondre",),
    "confondras": ("confondre",),
    "confondrez": ("confondre",),
    "confondriez": ("confondre",),
    "confondrions": ("confondre",),
    "confondrons": ("confondre",),
    "confondront": ("confondre",),
    "confonds": ("confondre",),
    "confondue": ("confondre",),
    "confondues": ("confondre",),
    "confondu": ("confondre",),
    "confondus": ("confondre",),
    "congédiaient": ("congédier",),
    "congédiai": ("congédier",),
    "congédiais": ("congédier",),
    "congédiait": ("congédier",),
    "congédia": ("congédier",),
    "congédiâmes": ("congédier",),
    "congédiant": ("congédier",),
    "congédias": ("congédier",),
    "congédiassent": ("congédier",),
    "congédiasses": ("congédier",),
    "congédiasse": ("congédier",),
    "congédiassiez": ("congédier",),
    "congédiassions": ("congédier",),
    "congédiâtes": ("congédier",),
    "congédiât": ("congédier",),
    "congédiée": ("congédier",),
    "congédiées": ("congédier",),
    "congédié": ("congédier",),
    "congédient": ("congédier",),
    "congédie": ("congédier",),
    "congédiera": ("congédier",),
    "congédieraient": ("congédier",),
    "congédierai": ("congédier",),
    "congédierais": ("congédier",),
    "congédierait": ("congédier",),
    "congédieras": ("congédier",),
    "congédièrent": ("congédier",),
    "congédierez": ("congédier",),
    "congédieriez": ("congédier",),
    "congédierions": ("congédier",),
    "congédierons": ("congédier",),
    "congédieront": ("congédier",),
    "congédiés": ("congédier",),
    "congédies": ("congédier",),
    "congédiez": ("congédier",),
    "congédiiez": ("congédier",),
    "congédiions": ("congédier",),
    "congédions": ("congédier",),
    "congelaient": ("congeler",),
    "congelai": ("congeler",),
    "congelais": ("congeler",),
    "congelait": ("congeler",),
    "congela": ("congeler",),
    "congelâmes": ("congeler",),
    "congelant": ("congeler",),
    "congelas": ("congeler",),
    "congelassent": ("congeler",),
    "congelasses": ("congeler",),
    "congelasse": ("congeler",),
    "congelassiez": ("congeler",),
    "congelassions": ("congeler",),
    "congelâtes": ("congeler",),
    "congelât": ("congeler",),
    "congelée": ("congeler",),
    "congelées": ("congeler",),
    "congelé": ("congeler",),
    "congèlent": ("congeler",),
    "congèle": ("congeler",),
    "congèlera": ("congeler",),
    "congèleraient": ("congeler",),
    "congèlerai": ("congeler",),
    "congèlerais": ("congeler",),
    "congèlerait": ("congeler",),
    "congèleras": ("congeler",),
    "congelèrent": ("congeler",),
    "congèlerez": ("congeler",),
    "congèleriez": ("congeler",),
    "congèlerions": ("congeler",),
    "congèlerons": ("congeler",),
    "congèleront": ("congeler",),
    "congelés": ("congeler",),
    "congèles": ("congeler",),
    "congelez": ("congeler",),
    "congeliez": ("congeler",),
    "congelions": ("congeler",),
    "congelons": ("congeler",),
    "congloméraient": ("conglomérer",),
    "conglomérai": ("conglomérer",),
    "conglomérais": ("conglomérer",),
    "conglomérait": ("conglomérer",),
    "congloméra": ("conglomérer",),
    "conglomérâmes": ("conglomérer",),
    "conglomérant": ("conglomérer",),
    "congloméras": ("conglomérer",),
    "conglomérassent": ("conglomérer",),
    "conglomérasses": ("conglomérer",),
    "conglomérasse": ("conglomérer",),
    "conglomérassiez": ("conglomérer",),
    "conglomérassions": ("conglomérer",),
    "conglomérâtes": ("conglomérer",),
    "conglomérât": ("conglomérer",),
    "conglomérée": ("conglomérer",),
    "conglomérées": ("conglomérer",),
    "congloméré": ("conglomérer",),
    "conglomèrent": ("conglomérer",),
    "conglomère": ("conglomérer",),
    "conglomérera": ("conglomérer",),
    "congloméreraient": ("conglomérer",),
    "conglomérerai": ("conglomérer",),
    "conglomérerais": ("conglomérer",),
    "conglomérerait": ("conglomérer",),
    "congloméreras": ("conglomérer",),
    "conglomérèrent": ("conglomérer",),
    "conglomérerez": ("conglomérer",),
    "congloméreriez": ("conglomérer",),
    "conglomérerions": ("conglomérer",),
    "conglomérerons": ("conglomérer",),
    "congloméreront": ("conglomérer",),
    "conglomérés": ("conglomérer",),
    "conglomères": ("conglomérer",),
    "conglomérez": ("conglomérer",),
    "conglomériez": ("conglomérer",),
    "conglomérions": ("conglomérer",),
    "conglomérons": ("conglomérer",),
    "congréaient": ("congréer",),
    "congréai": ("congréer",),
    "congréais": ("congréer",),
    "congréait": ("congréer",),
    "congréa": ("congréer",),
    "congréâmes": ("congréer",),
    "congréant": ("congréer",),
    "congréas": ("congréer",),
    "congréassent": ("congréer",),
    "congréasses": ("congréer",),
    "congréasse": ("congréer",),
    "congréassiez": ("congréer",),
    "congréassions": ("congréer",),
    "congréâtes": ("congréer",),
    "congréât": ("congréer",),
    "congréée": ("congréer",),
    "congréées": ("congréer",),
    "congréé": ("congréer",),
    "congréent": ("congréer",),
    "congrée": ("congréer",),
    "congréera": ("congréer",),
    "congréeraient": ("congréer",),
    "congréerai": ("congréer",),
    "congréerais": ("congréer",),
    "congréerait": ("congréer",),
    "congréeras": ("congréer",),
    "congréèrent": ("congréer",),
    "congréerez": ("congréer",),
    "congréeriez": ("congréer",),
    "congréerions": ("congréer",),
    "congréerons": ("congréer",),
    "congréeront": ("congréer",),
    "congréés": ("congréer",),
    "congrées": ("congréer",),
    "congréez": ("congréer",),
    "congréiez": ("congréer",),
    "congréions": ("congréer",),
    "congréons": ("congréer",),
    "conjoignaient": ("conjoindre",),
    "conjoignais": ("conjoindre",),
    "conjoignait": ("conjoindre",),
    "conjoignant": ("conjoindre",),
    "conjoignent": ("conjoindre",),
    "conjoigne": ("conjoindre",),
    "conjoignes": ("conjoindre",),
    "conjoignez": ("conjoindre",),
    "conjoigniez": ("conjoindre",),
    "conjoignîmes": ("conjoindre",),
    "conjoignions": ("conjoindre",),
    "conjoignirent": ("conjoindre",),
    "conjoignis": ("conjoindre",),
    "conjoignissent": ("conjoindre",),
    "conjoignisses": ("conjoindre",),
    "conjoignisse": ("conjoindre",),
    "conjoignissiez": ("conjoindre",),
    "conjoignissions": ("conjoindre",),
    "conjoignîtes": ("conjoindre",),
    "conjoignit": ("conjoindre",),
    "conjoignît": ("conjoindre",),
    "conjoignons": ("conjoindre",),
    "conjoindra": ("conjoindre",),
    "conjoindraient": ("conjoindre",),
    "conjoindrai": ("conjoindre",),
    "conjoindrais": ("conjoindre",),
    "conjoindrait": ("conjoindre",),
    "conjoindras": ("conjoindre",),
    "conjoindrez": ("conjoindre",),
    "conjoindriez": ("conjoindre",),
    "conjoindrions": ("conjoindre",),
    "conjoindrons": ("conjoindre",),
    "conjoindront": ("conjoindre",),
    "conjoins": ("conjoindre",),
    "conjointe": ("conjoindre",),
    "conjointes": ("conjoindre",),
    "conjoint": ("conjoindre",),
    "conjoints": ("conjoindre",),
    "conjouie": ("conjouir",),
    "conjouies": ("conjouir",),
    "conjoui": ("conjouir",),
    "conjouîmes": ("conjouir",),
    "conjouira": ("conjouir",),
    "conjouiraient": ("conjouir",),
    "conjouirai": ("conjouir",),
    "conjouirais": ("conjouir",),
    "conjouirait": ("conjouir",),
    "conjouiras": ("conjouir",),
    "conjouirent": ("conjouir",),
    "conjouirez": ("conjouir",),
    "conjouiriez": ("conjouir",),
    "conjouirions": ("conjouir",),
    "conjouirons": ("conjouir",),
    "conjouiront": ("conjouir",),
    "conjouis": ("conjouir",),
    "conjouissaient": ("conjouir",),
    "conjouissais": ("conjouir",),
    "conjouissait": ("conjouir",),
    "conjouissant": ("conjouir",),
    "conjouissent": ("conjouir",),
    "conjouisse": ("conjouir",),
    "conjouisses": ("conjouir",),
    "conjouissez": ("conjouir",),
    "conjouissiez": ("conjouir",),
    "conjouissions": ("conjouir",),
    "conjouissons": ("conjouir",),
    "conjouîtes": ("conjouir",),
    "conjouit": ("conjouir",),
    "conjouît": ("conjouir",),
    "connais": ("connaître",),
    "connaissaient": ("connaître",),
    "connaissais": ("connaître",),
    "connaissait": ("connaître",),
    "connaissant": ("connaître",),
    "connaissent": ("connaître",),
    "connaisse": ("connaître",),
    "connaisses": ("connaître",),
    "connaissez": ("connaître",),
    "connaissiez": ("connaître",),
    "connaissions": ("connaître",),
    "connaissons": ("connaître",),
    "connaît": ("connaître",),
    "connaîtra": ("connaître",),
    "connaîtraient": ("connaître",),
    "connaîtrai": ("connaître",),
    "connaîtrais": ("connaître",),
    "connaîtrait": ("connaître",),
    "connaîtras": ("connaître",),
    "connaîtrez": ("connaître",),
    "connaîtriez": ("connaître",),
    "connaîtrions": ("connaître",),
    "connaîtrons": ("connaître",),
    "connaîtront": ("connaître",),
    "connue": ("connaître",),
    "connues": ("connaître",),
    "connu": ("connaître",),
    "connûmes": ("connaître",),
    "connurent": ("connaître",),
    "connus": ("connaître",),
    "connussent": ("connaître",),
    "connusses": ("connaître",),
    "connusse": ("connaître",),
    "connussiez": ("connaître",),
    "connussions": ("connaître",),
    "connûtes": ("connaître",),
    "connut": ("connaître",),
    "connût": ("connaître",),
    "conquéraient": ("conquérir",),
    "conquérais": ("conquérir",),
    "conquérait": ("conquérir",),
    "conquérant": ("conquérir",),
    "conquérez": ("conquérir",),
    "conquériez": ("conquérir",),
    "conquérions": ("conquérir",),
    "conquérons": ("conquérir",),
    "conquerra": ("conquérir",),
    "conquerraient": ("conquérir",),
    "conquerrai": ("conquérir",),
    "conquerrais": ("conquérir",),
    "conquerrait": ("conquérir",),
    "conquerras": ("conquérir",),
    "conquerrez": ("conquérir",),
    "conquerriez": ("conquérir",),
    "conquerrions": ("conquérir",),
    "conquerrons": ("conquérir",),
    "conquerront": ("conquérir",),
    "conquièrent": ("conquérir",),
    "conquière": ("conquérir",),
    "conquières": ("conquérir",),
    "conquiers": ("conquérir",),
    "conquiert": ("conquérir",),
    "conquîmes": ("conquérir",),
    "conquirent": ("conquérir",),
    "conquise": ("conquérir",),
    "conquises": ("conquérir",),
    "conquis": ("conquérir",),
    "conquissent": ("conquérir",),
    "conquisses": ("conquérir",),
    "conquisse": ("conquérir",),
    "conquissiez": ("conquérir",),
    "conquissions": ("conquérir",),
    "conquîtes": ("conquérir",),
    "conquit": ("conquérir",),
    "conquît": ("conquérir",),
    "consens": ("consentir",),
    "consentaient": ("consentir",),
    "consentais": ("consentir",),
    "consentait": ("consentir",),
    "consentant": ("consentir",),
    "consentent": ("consentir",),
    "consente": ("consentir",),
    "consentes": ("consentir",),
    "consentez": ("consentir",),
    "consentie": ("consentir",),
    "consenties": ("consentir",),
    "consentiez": ("consentir",),
    "consenti": ("consentir",),
    "consentîmes": ("consentir",),
    "consentions": ("consentir",),
    "consentira": ("consentir",),
    "consentiraient": ("consentir",),
    "consentirai": ("consentir",),
    "consentirais": ("consentir",),
    "consentirait": ("consentir",),
    "consentiras": ("consentir",),
    "consentirent": ("consentir",),
    "consentirez": ("consentir",),
    "consentiriez": ("consentir",),
    "consentirions": ("consentir",),
    "consentirons": ("consentir",),
    "consentiront": ("consentir",),
    "consentis": ("consentir",),
    "consentissent": ("consentir",),
    "consentisses": ("consentir",),
    "consentisse": ("consentir",),
    "consentissiez": ("consentir",),
    "consentissions": ("consentir",),
    "consentîtes": ("consentir",),
    "consentit": ("consentir",),
    "consentît": ("consentir",),
    "consentons": ("consentir",),
    "consent": ("consentir",),
    "considéraient": ("considérer",),
    "considérai": ("considérer",),
    "considérais": ("considérer",),
    "considérait": ("considérer",),
    "considéra": ("considérer",),
    "considérâmes": ("considérer",),
    "considérant": ("considérer",),
    "considéras": ("considérer",),
    "considérassent": ("considérer",),
    "considérasses": ("considérer",),
    "considérasse": ("considérer",),
    "considérassiez": ("considérer",),
    "considérassions": ("considérer",),
    "considérâtes": ("considérer",),
    "considérât": ("considérer",),
    "considérée": ("considérer",),
    "considérées": ("considérer",),
    "considéré": ("considérer",),
    "considèrent": ("considérer",),
    "considère": ("considérer",),
    "considérera": ("considérer",),
    "considéreraient": ("considérer",),
    "considérerai": ("considérer",),
    "considérerais": ("considérer",),
    "considérerait": ("considérer",),
    "considéreras": ("considérer",),
    "considérèrent": ("considérer",),
    "considérerez": ("considérer",),
    "considéreriez": ("considérer",),
    "considérerions": ("considérer",),
    "considérerons": ("considérer",),
    "considéreront": ("considérer",),
    "considérés": ("considérer",),
    "considères": ("considérer",),
    "considérez": ("considérer",),
    "considériez": ("considérer",),
    "considérions": ("considérer",),
    "considérons": ("considérer",),
    "consonantifiaient": ("consonantifier",),
    "consonantifiai": ("consonantifier",),
    "consonantifiais": ("consonantifier",),
    "consonantifiait": ("consonantifier",),
    "consonantifia": ("consonantifier",),
    "consonantifiâmes": ("consonantifier",),
    "consonantifiant": ("consonantifier",),
    "consonantifias": ("consonantifier",),
    "consonantifiassent": ("consonantifier",),
    "consonantifiasses": ("consonantifier",),
    "consonantifiasse": ("consonantifier",),
    "consonantifiassiez": ("consonantifier",),
    "consonantifiassions": ("consonantifier",),
    "consonantifiâtes": ("consonantifier",),
    "consonantifiât": ("consonantifier",),
    "consonantifiée": ("consonantifier",),
    "consonantifiées": ("consonantifier",),
    "consonantifié": ("consonantifier",),
    "consonantifient": ("consonantifier",),
    "consonantifie": ("consonantifier",),
    "consonantifiera": ("consonantifier",),
    "consonantifieraient": ("consonantifier",),
    "consonantifierai": ("consonantifier",),
    "consonantifierais": ("consonantifier",),
    "consonantifierait": ("consonantifier",),
    "consonantifieras": ("consonantifier",),
    "consonantifièrent": ("consonantifier",),
    "consonantifierez": ("consonantifier",),
    "consonantifieriez": ("consonantifier",),
    "consonantifierions": ("consonantifier",),
    "consonantifierons": ("consonantifier",),
    "consonantifieront": ("consonantifier",),
    "consonantifiés": ("consonantifier",),
    "consonantifies": ("consonantifier",),
    "consonantifiez": ("consonantifier",),
    "consonantifiiez": ("consonantifier",),
    "consonantifiions": ("consonantifier",),
    "consonantifions": ("consonantifier",),
    "consonifiaient": ("consonifier",),
    "consonifiai": ("consonifier",),
    "consonifiais": ("consonifier",),
    "consonifiait": ("consonifier",),
    "consonifia": ("consonifier",),
    "consonifiâmes": ("consonifier",),
    "consonifiant": ("consonifier",),
    "consonifias": ("consonifier",),
    "consonifiassent": ("consonifier",),
    "consonifiasses": ("consonifier",),
    "consonifiasse": ("consonifier",),
    "consonifiassiez": ("consonifier",),
    "consonifiassions": ("consonifier",),
    "consonifiâtes": ("consonifier",),
    "consonifiât": ("consonifier",),
    "consonifiée": ("consonifier",),
    "consonifiées": ("consonifier",),
    "consonifié": ("consonifier",),
    "consonifient": ("consonifier",),
    "consonifie": ("consonifier",),
    "consonifiera": ("consonifier",),
    "consonifieraient": ("consonifier",),
    "consonifierai": ("consonifier",),
    "consonifierais": ("consonifier",),
    "consonifierait": ("consonifier",),
    "consonifieras": ("consonifier",),
    "consonifièrent": ("consonifier",),
    "consonifierez": ("consonifier",),
    "consonifieriez": ("consonifier",),
    "consonifierions": ("consonifier",),
    "consonifierons": ("consonifier",),
    "consonifieront": ("consonifier",),
    "consonifiés": ("consonifier",),
    "consonifies": ("consonifier",),
    "consonifiez": ("consonifier",),
    "consonifiiez": ("consonifier",),
    "consonifiions": ("consonifier",),
    "consonifions": ("consonifier",),
    "construira": ("construire",),
    "construiraient": ("construire",),
    "construirai": ("construire",),
    "construirais": ("construire",),
    "construirait": ("construire",),
    "construiras": ("construire",),
    "construirez": ("construire",),
    "construiriez": ("construire",),
    "construirions": ("construire",),
    "construirons": ("construire",),
    "construiront": ("construire",),
    "construisaient": ("construire",),
    "construisais": ("construire",),
    "construisait": ("construire",),
    "construisant": ("construire",),
    "construisent": ("construire",),
    "construise": ("construire",),
    "construises": ("construire",),
    "construisez": ("construire",),
    "construisiez": ("construire",),
    "construisîmes": ("construire",),
    "construisions": ("construire",),
    "construisirent": ("construire",),
    "construisis": ("construire",),
    "construisissent": ("construire",),
    "construisisses": ("construire",),
    "construisisse": ("construire",),
    "construisissiez": ("construire",),
    "construisissions": ("construire",),
    "construisîtes": ("construire",),
    "construisit": ("construire",),
    "construisît": ("construire",),
    "construisons": ("construire",),
    "construis": ("construire",),
    "construite": ("construire",),
    "construites": ("construire",),
    "construit": ("construire",),
    "construits": ("construire",),
    "contenaient": ("contenir",),
    "contenais": ("contenir",),
    "contenait": ("contenir",),
    "contenant": ("contenir",),
    "contenez": ("contenir",),
    "conteniez": ("contenir",),
    "contenions": ("contenir",),
    "contenons": ("contenir",),
    "contenue": ("contenir",),
    "contenues": ("contenir",),
    "contenu": ("contenir",),
    "contenus": ("contenir",),
    "contiendra": ("contenir",),
    "contiendraient": ("contenir",),
    "contiendrai": ("contenir",),
    "contiendrais": ("contenir",),
    "contiendrait": ("contenir",),
    "contiendras": ("contenir",),
    "contiendrez": ("contenir",),
    "contiendriez": ("contenir",),
    "contiendrions": ("contenir",),
    "contiendrons": ("contenir",),
    "contiendront": ("contenir",),
    "contiennent": ("contenir",),
    "contienne": ("contenir",),
    "contiennes": ("contenir",),
    "contiens": ("contenir",),
    "contient": ("contenir",),
    "contînmes": ("contenir",),
    "continrent": ("contenir",),
    "contins": ("contenir",),
    "continssent": ("contenir",),
    "continsses": ("contenir",),
    "continsse": ("contenir",),
    "continssiez": ("contenir",),
    "continssions": ("contenir",),
    "contîntes": ("contenir",),
    "contint": ("contenir",),
    "contînt": ("contenir",),
    "contraignaient": ("contraindre",),
    "contraignais": ("contraindre",),
    "contraignait": ("contraindre",),
    "contraignant": ("contraindre",),
    "contraignent": ("contraindre",),
    "contraigne": ("contraindre",),
    "contraignes": ("contraindre",),
    "contraignez": ("contraindre",),
    "contraigniez": ("contraindre",),
    "contraignîmes": ("contraindre",),
    "contraignions": ("contraindre",),
    "contraignirent": ("contraindre",),
    "contraignis": ("contraindre",),
    "contraignissent": ("contraindre",),
    "contraignisses": ("contraindre",),
    "contraignisse": ("contraindre",),
    "contraignissiez": ("contraindre",),
    "contraignissions": ("contraindre",),
    "contraignîtes": ("contraindre",),
    "contraignit": ("contraindre",),
    "contraignît": ("contraindre",),
    "contraignons": ("contraindre",),
    "contraindra": ("contraindre",),
    "contraindraient": ("contraindre",),
    "contraindrai": ("contraindre",),
    "contraindrais": ("contraindre",),
    "contraindrait": ("contraindre",),
    "contraindras": ("contraindre",),
    "contraindrez": ("contraindre",),
    "contraindriez": ("contraindre",),
    "contraindrions": ("contraindre",),
    "contraindrons": ("contraindre",),
    "contraindront": ("contraindre",),
    "contrains": ("contraindre",),
    "contrainte": ("contraindre",),
    "contraintes": ("contraindre",),
    "contraint": ("contraindre",),
    "contraints": ("contraindre",),
    "contrariaient": ("contrarier",),
    "contrariai": ("contrarier",),
    "contrariais": ("contrarier",),
    "contrariait": ("contrarier",),
    "contraria": ("contrarier",),
    "contrariâmes": ("contrarier",),
    "contrariant": ("contrarier",),
    "contrarias": ("contrarier",),
    "contrariassent": ("contrarier",),
    "contrariasses": ("contrarier",),
    "contrariasse": ("contrarier",),
    "contrariassiez": ("contrarier",),
    "contrariassions": ("contrarier",),
    "contrariâtes": ("contrarier",),
    "contrariât": ("contrarier",),
    "contrariée": ("contrarier",),
    "contrariées": ("contrarier",),
    "contrarié": ("contrarier",),
    "contrarient": ("contrarier",),
    "contrarie": ("contrarier",),
    "contrariera": ("contrarier",),
    "contrarieraient": ("contrarier",),
    "contrarierai": ("contrarier",),
    "contrarierais": ("contrarier",),
    "contrarierait": ("contrarier",),
    "contrarieras": ("contrarier",),
    "contrarièrent": ("contrarier",),
    "contrarierez": ("contrarier",),
    "contrarieriez": ("contrarier",),
    "contrarierions": ("contrarier",),
    "contrarierons": ("contrarier",),
    "contrarieront": ("contrarier",),
    "contrariés": ("contrarier",),
    "contraries": ("contrarier",),
    "contrariez": ("contrarier",),
    "contrariiez": ("contrarier",),
    "contrariions": ("contrarier",),
    "contrarions": ("contrarier",),
    "contrebalançaient": ("contrebalancer",),
    "contrebalançai": ("contrebalancer",),
    "contrebalançais": ("contrebalancer",),
    "contrebalançait": ("contrebalancer",),
    "contrebalança": ("contrebalancer",),
    "contrebalançâmes": ("contrebalancer",),
    "contrebalançant": ("contrebalancer",),
    "contrebalanças": ("contrebalancer",),
    "contrebalançassent": ("contrebalancer",),
    "contrebalançasses": ("contrebalancer",),
    "contrebalançasse": ("contrebalancer",),
    "contrebalançassiez": ("contrebalancer",),
    "contrebalançassions": ("contrebalancer",),
    "contrebalançâtes": ("contrebalancer",),
    "contrebalançât": ("contrebalancer",),
    "contrebalancée": ("contrebalancer",),
    "contrebalancées": ("contrebalancer",),
    "contrebalancé": ("contrebalancer",),
    "contrebalancent": ("contrebalancer",),
    "contrebalance": ("contrebalancer",),
    "contrebalancera": ("contrebalancer",),
    "contrebalanceraient": ("contrebalancer",),
    "contrebalancerai": ("contrebalancer",),
    "contrebalancerais": ("contrebalancer",),
    "contrebalancerait": ("contrebalancer",),
    "contrebalanceras": ("contrebalancer",),
    "contrebalancèrent": ("contrebalancer",),
    "contrebalancerez": ("contrebalancer",),
    "contrebalanceriez": ("contrebalancer",),
    "contrebalancerions": ("contrebalancer",),
    "contrebalancerons": ("contrebalancer",),
    "contrebalanceront": ("contrebalancer",),
    "contrebalancés": ("contrebalancer",),
    "contrebalances": ("contrebalancer",),
    "contrebalancez": ("contrebalancer",),
    "contrebalanciez": ("contrebalancer",),
    "contrebalancions": ("contrebalancer",),
    "contrebalançons": ("contrebalancer",),
    "contrebat": ("contrebattre",),
    "contrebats": ("contrebattre",),
    "contrebattaient": ("contrebattre",),
    "contrebattais": ("contrebattre",),
    "contrebattait": ("contrebattre",),
    "contrebattant": ("contrebattre",),
    "contrebattent": ("contrebattre",),
    "contrebatte": ("contrebattre",),
    "contrebattes": ("contrebattre",),
    "contrebattez": ("contrebattre",),
    "contrebattiez": ("contrebattre",),
    "contrebattîmes": ("contrebattre",),
    "contrebattions": ("contrebattre",),
    "contrebattirent": ("contrebattre",),
    "contrebattis": ("contrebattre",),
    "contrebattissent": ("contrebattre",),
    "contrebattisses": ("contrebattre",),
    "contrebattisse": ("contrebattre",),
    "contrebattissiez": ("contrebattre",),
    "contrebattissions": ("contrebattre",),
    "contrebattîtes": ("contrebattre",),
    "contrebattit": ("contrebattre",),
    "contrebattît": ("contrebattre",),
    "contrebattons": ("contrebattre",),
    "contrebattra": ("contrebattre",),
    "contrebattraient": ("contrebattre",),
    "contrebattrai": ("contrebattre",),
    "contrebattrais": ("contrebattre",),
    "contrebattrait": ("contrebattre",),
    "contrebattras": ("contrebattre",),
    "contrebattrez": ("contrebattre",),
    "contrebattriez": ("contrebattre",),
    "contrebattrions": ("contrebattre",),
    "contrebattrons": ("contrebattre",),
    "contrebattront": ("contrebattre",),
    "contrebattue": ("contrebattre",),
    "contrebattues": ("contrebattre",),
    "contrebattu": ("contrebattre",),
    "contrebattus": ("contrebattre",),
    "contredégageaient": ("contredégager",),
    "contredégageai": ("contredégager",),
    "contredégageais": ("contredégager",),
    "contredégageait": ("contredégager",),
    "contredégagea": ("contredégager",),
    "contredégageâmes": ("contredégager",),
    "contredégageant": ("contredégager",),
    "contredégageas": ("contredégager",),
    "contredégageassent": ("contredégager",),
    "contredégageasses": ("contredégager",),
    "contredégageasse": ("contredégager",),
    "contredégageassiez": ("contredégager",),
    "contredégageassions": ("contredégager",),
    "contredégageâtes": ("contredégager",),
    "contredégageât": ("contredégager",),
    "contredégagée": ("contredégager",),
    "contredégagées": ("contredégager",),
    "contredégagé": ("contredégager",),
    "contredégagent": ("contredégager",),
    "contredégageons": ("contredégager",),
    "contredégage": ("contredégager",),
    "contredégagera": ("contredégager",),
    "contredégageraient": ("contredégager",),
    "contredégagerai": ("contredégager",),
    "contredégagerais": ("contredégager",),
    "contredégagerait": ("contredégager",),
    "contredégageras": ("contredégager",),
    "contredégagèrent": ("contredégager",),
    "contredégagerez": ("contredégager",),
    "contredégageriez": ("contredégager",),
    "contredégagerions": ("contredégager",),
    "contredégagerons": ("contredégager",),
    "contredégageront": ("contredégager",),
    "contredégagés": ("contredégager",),
    "contredégages": ("contredégager",),
    "contredégagez": ("contredégager",),
    "contredégagiez": ("contredégager",),
    "contredégagions": ("contredégager",),
    "contredîmes": ("contredire",),
    "contredira": ("contredire",),
    "contrediraient": ("contredire",),
    "contredirai": ("contredire",),
    "contredirais": ("contredire",),
    "contredirait": ("contredire",),
    "contrediras": ("contredire",),
    "contredirent": ("contredire",),
    "contredirez": ("contredire",),
    "contrediriez": ("contredire",),
    "contredirions": ("contredire",),
    "contredirons": ("contredire",),
    "contrediront": ("contredire",),
    "contredisaient": ("contredire",),
    "contredisais": ("contredire",),
    "contredisait": ("contredire",),
    "contredisant": ("contredire",),
    "contredisent": ("contredire",),
    "contredise": ("contredire",),
    "contredises": ("contredire",),
    "contredisez": ("contredire",),
    "contredisiez": ("contredire",),
    "contredisions": ("contredire",),
    "contredisons": ("contredire",),
    "contredis": ("contredire",),
    "contredissent": ("contredire",),
    "contredisses": ("contredire",),
    "contredisse": ("contredire",),
    "contredissiez": ("contredire",),
    "contredissions": ("contredire",),
    "contredite": ("contredire",),
    "contredîtes": ("contredire",),
    "contredites": ("contredire",),
    "contredit": ("contredire",),
    "contredits": ("contredire",),
    "contredît": ("contredire",),
    "contrefaisaient": ("contrefaire",),
    "contrefaisais": ("contrefaire",),
    "contrefaisait": ("contrefaire",),
    "contrefaisant": ("contrefaire",),
    "contrefaisiez": ("contrefaire",),
    "contrefaisions": ("contrefaire",),
    "contrefaisons": ("contrefaire",),
    "contrefais": ("contrefaire",),
    "contrefaite": ("contrefaire",),
    "contrefaites": ("contrefaire",),
    "contrefait": ("contrefaire",),
    "contrefaits": ("contrefaire",),
    "contrefassent": ("contrefaire",),
    "contrefasse": ("contrefaire",),
    "contrefasses": ("contrefaire",),
    "contrefassiez": ("contrefaire",),
    "contrefassions": ("contrefaire",),
    "contrefera": ("contrefaire",),
    "contreferaient": ("contrefaire",),
    "contreferai": ("contrefaire",),
    "contreferais": ("contrefaire",),
    "contreferait": ("contrefaire",),
    "contreferas": ("contrefaire",),
    "contreferez": ("contrefaire",),
    "contreferiez": ("contrefaire",),
    "contreferions": ("contrefaire",),
    "contreferons": ("contrefaire",),
    "contreferont": ("contrefaire",),
    "contrefîmes": ("contrefaire",),
    "contrefirent": ("contrefaire",),
    "contrefis": ("contrefaire",),
    "contrefissent": ("contrefaire",),
    "contrefisses": ("contrefaire",),
    "contrefisse": ("contrefaire",),
    "contrefissiez": ("contrefaire",),
    "contrefissions": ("contrefaire",),
    "contrefîtes": ("contrefaire",),
    "contrefit": ("contrefaire",),
    "contrefît": ("contrefaire",),
    "contrefont": ("contrefaire",),
    "contrefous": ("contrefoutre",),
    "contrefoutaient": ("contrefoutre",),
    "contrefoutais": ("contrefoutre",),
    "contrefoutait": ("contrefoutre",),
    "contrefoutant": ("contrefoutre",),
    "contrefoutent": ("contrefoutre",),
    "contrefoute": ("contrefoutre",),
    "contrefoutes": ("contrefoutre",),
    "contrefoutez": ("contrefoutre",),
    "contrefoutiez": ("contrefoutre",),
    "contrefoutions": ("contrefoutre",),
    "contrefoutissent": ("contrefoutre",),
    "contrefoutisses": ("contrefoutre",),
    "contrefoutisse": ("contrefoutre",),
    "contrefoutissiez": ("contrefoutre",),
    "contrefoutissions": ("contrefoutre",),
    "contrefoutît": ("contrefoutre",),
    "contrefoutons": ("contrefoutre",),
    "contrefout": ("contrefoutre",),
    "contrefoutra": ("contrefoutre",),
    "contrefoutraient": ("contrefoutre",),
    "contrefoutrai": ("contrefoutre",),
    "contrefoutrais": ("contrefoutre",),
    "contrefoutrait": ("contrefoutre",),
    "contrefoutras": ("contrefoutre",),
    "contrefoutrez": ("contrefoutre",),
    "contrefoutriez": ("contrefoutre",),
    "contrefoutrions": ("contrefoutre",),
    "contrefoutrons": ("contrefoutre",),
    "contrefoutront": ("contrefoutre",),
    "contrefoutue": ("contrefoutre",),
    "contrefoutues": ("contrefoutre",),
    "contrefoutu": ("contrefoutre",),
    "contrefoutus": ("contrefoutre",),
    "contrepesaient": ("contrepeser",),
    "contrepesai": ("contrepeser",),
    "contrepesais": ("contrepeser",),
    "contrepesait": ("contrepeser",),
    "contrepesa": ("contrepeser",),
    "contrepesâmes": ("contrepeser",),
    "contrepesant": ("contrepeser",),
    "contrepesas": ("contrepeser",),
    "contrepesassent": ("contrepeser",),
    "contrepesasses": ("contrepeser",),
    "contrepesasse": ("contrepeser",),
    "contrepesassiez": ("contrepeser",),
    "contrepesassions": ("contrepeser",),
    "contrepesâtes": ("contrepeser",),
    "contrepesât": ("contrepeser",),
    "contrepesée": ("contrepeser",),
    "contrepesées": ("contrepeser",),
    "contrepesé": ("contrepeser",),
    "contrepèsent": ("contrepeser",),
    "contrepèse": ("contrepeser",),
    "contrepèsera": ("contrepeser",),
    "contrepèseraient": ("contrepeser",),
    "contrepèserai": ("contrepeser",),
    "contrepèserais": ("contrepeser",),
    "contrepèserait": ("contrepeser",),
    "contrepèseras": ("contrepeser",),
    "contrepesèrent": ("contrepeser",),
    "contrepèserez": ("contrepeser",),
    "contrepèseriez": ("contrepeser",),
    "contrepèserions": ("contrepeser",),
    "contrepèserons": ("contrepeser",),
    "contrepèseront": ("contrepeser",),
    "contrepesés": ("contrepeser",),
    "contrepèses": ("contrepeser",),
    "contrepesez": ("contrepeser",),
    "contrepesiez": ("contrepeser",),
    "contrepesions": ("contrepeser",),
    "contrepesons": ("contrepeser",),
    "contrevenaient": ("contrevenir",),
    "contrevenais": ("contrevenir",),
    "contrevenait": ("contrevenir",),
    "contrevenant": ("contrevenir",),
    "contrevenez": ("contrevenir",),
    "contreveniez": ("contrevenir",),
    "contrevenions": ("contrevenir",),
    "contrevenons": ("contrevenir",),
    "contrevenu": ("contrevenir",),
    "contreviendra": ("contrevenir",),
    "contreviendraient": ("contrevenir",),
    "contreviendrai": ("contrevenir",),
    "contreviendrais": ("contrevenir",),
    "contreviendrait": ("contrevenir",),
    "contreviendras": ("contrevenir",),
    "contreviendrez": ("contrevenir",),
    "contreviendriez": ("contrevenir",),
    "contreviendrions": ("contrevenir",),
    "contreviendrons": ("contrevenir",),
    "contreviendront": ("contrevenir",),
    "contreviennent": ("contrevenir",),
    "contrevienne": ("contrevenir",),
    "contreviennes": ("contrevenir",),
    "contreviens": ("contrevenir",),
    "contrevient": ("contrevenir",),
    "contrevînmes": ("contrevenir",),
    "contrevinrent": ("contrevenir",),
    "contrevins": ("contrevenir",),
    "contrevinssent": ("contrevenir",),
    "contrevinsses": ("contrevenir",),
    "contrevinsse": ("contrevenir",),
    "contrevinssiez": ("contrevenir",),
    "contrevinssions": ("contrevenir",),
    "contrevîntes": ("contrevenir",),
    "contrevint": ("contrevenir",),
    "contrevînt": ("contrevenir",),
    "contrite": ("contrire",),
    "contrites": ("contrire",),
    "contrit": ("contrire",),
    "contrits": ("contrire",),
    "convainc": ("convaincre",),
    "convaincra": ("convaincre",),
    "convaincraient": ("convaincre",),
    "convaincrai": ("convaincre",),
    "convaincrais": ("convaincre",),
    "convaincrait": ("convaincre",),
    "convaincras": ("convaincre",),
    "convaincrez": ("convaincre",),
    "convaincriez": ("convaincre",),
    "convaincrions": ("convaincre",),
    "convaincrons": ("convaincre",),
    "convaincront": ("convaincre",),
    "convaincs": ("convaincre",),
    "convaincue": ("convaincre",),
    "convaincues": ("convaincre",),
    "convaincu": ("convaincre",),
    "convaincus": ("convaincre",),
    "convainquaient": ("convaincre",),
    "convainquais": ("convaincre",),
    "convainquait": ("convaincre",),
    "convainquant": ("convaincre",),
    "convainquent": ("convaincre",),
    "convainque": ("convaincre",),
    "convainques": ("convaincre",),
    "convainquez": ("convaincre",),
    "convainquiez": ("convaincre",),
    "convainquîmes": ("convaincre",),
    "convainquions": ("convaincre",),
    "convainquirent": ("convaincre",),
    "convainquis": ("convaincre",),
    "convainquissent": ("convaincre",),
    "convainquisses": ("convaincre",),
    "convainquisse": ("convaincre",),
    "convainquissiez": ("convaincre",),
    "convainquissions": ("convaincre",),
    "convainquîtes": ("convaincre",),
    "convainquit": ("convaincre",),
    "convainquît": ("convaincre",),
    "convainquons": ("convaincre",),
    "convenaient": ("convenir",),
    "convenais": ("convenir",),
    "convenait": ("convenir",),
    "convenant": ("convenir",),
    "convenez": ("convenir",),
    "conveniez": ("convenir",),
    "convenions": ("convenir",),
    "convenons": ("convenir",),
    "convenue": ("convenir",),
    "convenues": ("convenir",),
    "convenu": ("convenir",),
    "convenus": ("convenir",),
    "conviendra": ("convenir",),
    "conviendraient": ("convenir",),
    "conviendrai": ("convenir",),
    "conviendrais": ("convenir",),
    "conviendrait": ("convenir",),
    "conviendras": ("convenir",),
    "conviendrez": ("convenir",),
    "conviendriez": ("convenir",),
    "conviendrions": ("convenir",),
    "conviendrons": ("convenir",),
    "conviendront": ("convenir",),
    "conviennent": ("convenir",),
    "convienne": ("convenir",),
    "conviennes": ("convenir",),
    "conviens": ("convenir",),
    "convient": ("convier",),
    "convînmes": ("convenir",),
    "convinrent": ("convenir",),
    "convins": ("convenir",),
    "convinssent": ("convenir",),
    "convinsses": ("convenir",),
    "convinsse": ("convenir",),
    "convinssiez": ("convenir",),
    "convinssions": ("convenir",),
    "convîntes": ("convenir",),
    "convint": ("convenir",),
    "convînt": ("convenir",),
    "convergeaient": ("converger",),
    "convergeai": ("converger",),
    "convergeais": ("converger",),
    "convergeait": ("converger",),
    "convergea": ("converger",),
    "convergeâmes": ("converger",),
    "convergeant": ("converger",),
    "convergeas": ("converger",),
    "convergeassent": ("converger",),
    "convergeasses": ("converger",),
    "convergeasse": ("converger",),
    "convergeassiez": ("converger",),
    "convergeassions": ("converger",),
    "convergeâtes": ("converger",),
    "convergeât": ("converger",),
    "convergé": ("converger",),
    "convergent": ("converger",),
    "convergeons": ("converger",),
    "converge": ("converger",),
    "convergera": ("converger",),
    "convergeraient": ("converger",),
    "convergerai": ("converger",),
    "convergerais": ("converger",),
    "convergerait": ("converger",),
    "convergeras": ("converger",),
    "convergèrent": ("converger",),
    "convergerez": ("converger",),
    "convergeriez": ("converger",),
    "convergerions": ("converger",),
    "convergerons": ("converger",),
    "convergeront": ("converger",),
    "converges": ("converger",),
    "convergez": ("converger",),
    "convergiez": ("converger",),
    "convergions": ("converger",),
    "convertie": ("convertir",),
    "converties": ("convertir",),
    "converti": ("convertir",),
    "convertîmes": ("convertir",),
    "convertira": ("convertir",),
    "convertiraient": ("convertir",),
    "convertirai": ("convertir",),
    "convertirais": ("convertir",),
    "convertirait": ("convertir",),
    "convertiras": ("convertir",),
    "convertirent": ("convertir",),
    "convertirez": ("convertir",),
    "convertiriez": ("convertir",),
    "convertirions": ("convertir",),
    "convertirons": ("convertir",),
    "convertiront": ("convertir",),
    "convertis": ("convertir",),
    "convertissaient": ("convertir",),
    "convertissais": ("convertir",),
    "convertissait": ("convertir",),
    "convertissant": ("convertir",),
    "convertissent": ("convertir",),
    "convertisse": ("convertir",),
    "convertisses": ("convertir",),
    "convertissez": ("convertir",),
    "convertissiez": ("convertir",),
    "convertissions": ("convertir",),
    "convertissons": ("convertir",),
    "convertîtes": ("convertir",),
    "convertit": ("convertir",),
    "convertît": ("convertir",),
    "conviaient": ("convier",),
    "conviai": ("convier",),
    "conviais": ("convier",),
    "conviait": ("convier",),
    "convia": ("convier",),
    "conviâmes": ("convier",),
    "conviant": ("convier",),
    "convias": ("convier",),
    "conviassent": ("convier",),
    "conviasses": ("convier",),
    "conviasse": ("convier",),
    "conviassiez": ("convier",),
    "conviassions": ("convier",),
    "conviâtes": ("convier",),
    "conviât": ("convier",),
    "conviée": ("convier",),
    "conviées": ("convier",),
    "convié": ("convier",),
    "convie": ("convier",),
    "conviera": ("convier",),
    "convieraient": ("convier",),
    "convierai": ("convier",),
    "convierais": ("convier",),
    "convierait": ("convier",),
    "convieras": ("convier",),
    "convièrent": ("convier",),
    "convierez": ("convier",),
    "convieriez": ("convier",),
    "convierions": ("convier",),
    "convierons": ("convier",),
    "convieront": ("convier",),
    "conviés": ("convier",),
    "convies": ("convier",),
    "conviez": ("convier",),
    "conviiez": ("convier",),
    "conviions": ("convier",),
    "convions": ("convier",),
    "convoient": ("convoyer",),
    "convoie": ("convoyer",),
    "convoiera": ("convoyer",),
    "convoieraient": ("convoyer",),
    "convoierai": ("convoyer",),
    "convoierais": ("convoyer",),
    "convoierait": ("convoyer",),
    "convoieras": ("convoyer",),
    "convoierez": ("convoyer",),
    "convoieriez": ("convoyer",),
    "convoierions": ("convoyer",),
    "convoierons": ("convoyer",),
    "convoieront": ("convoyer",),
    "convoies": ("convoyer",),
    "convoyaient": ("convoyer",),
    "convoyai": ("convoyer",),
    "convoyais": ("convoyer",),
    "convoyait": ("convoyer",),
    "convoya": ("convoyer",),
    "convoyâmes": ("convoyer",),
    "convoyant": ("convoyer",),
    "convoyas": ("convoyer",),
    "convoyassent": ("convoyer",),
    "convoyasses": ("convoyer",),
    "convoyasse": ("convoyer",),
    "convoyassiez": ("convoyer",),
    "convoyassions": ("convoyer",),
    "convoyâtes": ("convoyer",),
    "convoyât": ("convoyer",),
    "convoyée": ("convoyer",),
    "convoyées": ("convoyer",),
    "convoyé": ("convoyer",),
    "convoyèrent": ("convoyer",),
    "convoyés": ("convoyer",),
    "convoyez": ("convoyer",),
    "convoyiez": ("convoyer",),
    "convoyions": ("convoyer",),
    "convoyons": ("convoyer",),
    "coobligeaient": ("coobliger",),
    "coobligeai": ("coobliger",),
    "coobligeais": ("coobliger",),
    "coobligeait": ("coobliger",),
    "coobligea": ("coobliger",),
    "coobligeâmes": ("coobliger",),
    "coobligeant": ("coobliger",),
    "coobligeas": ("coobliger",),
    "coobligeassent": ("coobliger",),
    "coobligeasses": ("coobliger",),
    "coobligeasse": ("coobliger",),
    "coobligeassiez": ("coobliger",),
    "coobligeassions": ("coobliger",),
    "coobligeâtes": ("coobliger",),
    "coobligeât": ("coobliger",),
    "coobligée": ("coobliger",),
    "coobligées": ("coobliger",),
    "coobligé": ("coobliger",),
    "coobligent": ("coobliger",),
    "coobligeons": ("coobliger",),
    "cooblige": ("coobliger",),
    "coobligera": ("coobliger",),
    "coobligeraient": ("coobliger",),
    "coobligerai": ("coobliger",),
    "coobligerais": ("coobliger",),
    "coobligerait": ("coobliger",),
    "coobligeras": ("coobliger",),
    "coobligèrent": ("coobliger",),
    "coobligerez": ("coobliger",),
    "coobligeriez": ("coobliger",),
    "coobligerions": ("coobliger",),
    "coobligerons": ("coobliger",),
    "coobligeront": ("coobliger",),
    "coobligés": ("coobliger",),
    "coobliges": ("coobliger",),
    "coobligez": ("coobliger",),
    "coobligiez": ("coobliger",),
    "coobligions": ("coobliger",),
    "coopéraient": ("coopérer",),
    "coopérai": ("coopérer",),
    "coopérais": ("coopérer",),
    "coopérait": ("coopérer",),
    "coopéra": ("coopérer",),
    "coopérâmes": ("coopérer",),
    "coopérant": ("coopérer",),
    "coopéras": ("coopérer",),
    "coopérassent": ("coopérer",),
    "coopérasses": ("coopérer",),
    "coopérasse": ("coopérer",),
    "coopérassiez": ("coopérer",),
    "coopérassions": ("coopérer",),
    "coopérâtes": ("coopérer",),
    "coopérât": ("coopérer",),
    "coopéré": ("coopérer",),
    "coopèrent": ("coopérer",),
    "coopère": ("coopérer",),
    "coopérera": ("coopérer",),
    "coopéreraient": ("coopérer",),
    "coopérerai": ("coopérer",),
    "coopérerais": ("coopérer",),
    "coopérerait": ("coopérer",),
    "coopéreras": ("coopérer",),
    "coopérèrent": ("coopérer",),
    "coopérerez": ("coopérer",),
    "coopéreriez": ("coopérer",),
    "coopérerions": ("coopérer",),
    "coopérerons": ("coopérer",),
    "coopéreront": ("coopérer",),
    "coopères": ("coopérer",),
    "coopérez": ("coopérer",),
    "coopériez": ("coopérer",),
    "coopérions": ("coopérer",),
    "coopérons": ("coopérer",),
    "copartageaient": ("copartager",),
    "copartageai": ("copartager",),
    "copartageais": ("copartager",),
    "copartageait": ("copartager",),
    "copartagea": ("copartager",),
    "copartageâmes": ("copartager",),
    "copartageant": ("copartager",),
    "copartageas": ("copartager",),
    "copartageassent": ("copartager",),
    "copartageasses": ("copartager",),
    "copartageasse": ("copartager",),
    "copartageassiez": ("copartager",),
    "copartageassions": ("copartager",),
    "copartageâtes": ("copartager",),
    "copartageât": ("copartager",),
    "copartagée": ("copartager",),
    "copartagées": ("copartager",),
    "copartagé": ("copartager",),
    "copartagent": ("copartager",),
    "copartageons": ("copartager",),
    "copartage": ("copartager",),
    "copartagera": ("copartager",),
    "copartageraient": ("copartager",),
    "copartagerai": ("copartager",),
    "copartagerais": ("copartager",),
    "copartagerait": ("copartager",),
    "copartageras": ("copartager",),
    "copartagèrent": ("copartager",),
    "copartagerez": ("copartager",),
    "copartageriez": ("copartager",),
    "copartagerions": ("copartager",),
    "copartagerons": ("copartager",),
    "copartageront": ("copartager",),
    "copartagés": ("copartager",),
    "copartages": ("copartager",),
    "copartagez": ("copartager",),
    "copartagiez": ("copartager",),
    "copartagions": ("copartager",),
    "copiaient": ("copier",),
    "copiai": ("copier",),
    "copiais": ("copier",),
    "copiait": ("copier",),
    "copia": ("copier",),
    "copiâmes": ("copier",),
    "copiant": ("copier",),
    "copias": ("copier",),
    "copiassent": ("copier",),
    "copiasses": ("copier",),
    "copiasse": ("copier",),
    "copiassiez": ("copier",),
    "copiassions": ("copier",),
    "copiâtes": ("copier",),
    "copiât": ("copier",),
    "copiée": ("copier",),
    "copiées": ("copier",),
    "copié": ("copier",),
    "copient": ("copier",),
    "copie": ("copier",),
    "copiera": ("copier",),
    "copieraient": ("copier",),
    "copierai": ("copier",),
    "copierais": ("copier",),
    "copierait": ("copier",),
    "copieras": ("copier",),
    "copièrent": ("copier",),
    "copierez": ("copier",),
    "copieriez": ("copier",),
    "copierions": ("copier",),
    "copierons": ("copier",),
    "copieront": ("copier",),
    "copiés": ("copier",),
    "copies": ("copier",),
    "copiez": ("copier",),
    "copiiez": ("copier",),
    "copiions": ("copier",),
    "copions": ("copier",),
    "copossédaient": ("coposséder",),
    "copossédai": ("coposséder",),
    "copossédais": ("coposséder",),
    "copossédait": ("coposséder",),
    "coposséda": ("coposséder",),
    "copossédâmes": ("coposséder",),
    "copossédant": ("coposséder",),
    "copossédas": ("coposséder",),
    "copossédassent": ("coposséder",),
    "copossédasses": ("coposséder",),
    "copossédasse": ("coposséder",),
    "copossédassiez": ("coposséder",),
    "copossédassions": ("coposséder",),
    "copossédâtes": ("coposséder",),
    "copossédât": ("coposséder",),
    "copossédée": ("coposséder",),
    "copossédées": ("coposséder",),
    "copossédé": ("coposséder",),
    "copossèdent": ("coposséder",),
    "copossède": ("coposséder",),
    "copossédera": ("coposséder",),
    "coposséderaient": ("coposséder",),
    "coposséderai": ("coposséder",),
    "coposséderais": ("coposséder",),
    "coposséderait": ("coposséder",),
    "coposséderas": ("coposséder",),
    "copossédèrent": ("coposséder",),
    "coposséderez": ("coposséder",),
    "coposséderiez": ("coposséder",),
    "coposséderions": ("coposséder",),
    "coposséderons": ("coposséder",),
    "coposséderont": ("coposséder",),
    "copossédés": ("coposséder",),
    "copossèdes": ("coposséder",),
    "copossédez": ("coposséder",),
    "copossédiez": ("coposséder",),
    "copossédions": ("coposséder",),
    "copossédons": ("coposséder",),
    "coproduira": ("coproduire",),
    "coproduiraient": ("coproduire",),
    "coproduirai": ("coproduire",),
    "coproduirais": ("coproduire",),
    "coproduirait": ("coproduire",),
    "coproduiras": ("coproduire",),
    "coproduirez": ("coproduire",),
    "coproduiriez": ("coproduire",),
    "coproduirions": ("coproduire",),
    "coproduirons": ("coproduire",),
    "coproduiront": ("coproduire",),
    "coproduisaient": ("coproduire",),
    "coproduisais": ("coproduire",),
    "coproduisait": ("coproduire",),
    "coproduisant": ("coproduire",),
    "coproduisent": ("coproduire",),
    "coproduise": ("coproduire",),
    "coproduises": ("coproduire",),
    "coproduisez": ("coproduire",),
    "coproduisiez": ("coproduire",),
    "coproduisîmes": ("coproduire",),
    "coproduisions": ("coproduire",),
    "coproduisirent": ("coproduire",),
    "coproduisis": ("coproduire",),
    "coproduisissent": ("coproduire",),
    "coproduisisses": ("coproduire",),
    "coproduisisse": ("coproduire",),
    "coproduisissiez": ("coproduire",),
    "coproduisissions": ("coproduire",),
    "coproduisîtes": ("coproduire",),
    "coproduisit": ("coproduire",),
    "coproduisît": ("coproduire",),
    "coproduisons": ("coproduire",),
    "coproduis": ("coproduire",),
    "coproduite": ("coproduire",),
    "coproduites": ("coproduire",),
    "coproduit": ("coproduire",),
    "coproduits": ("coproduire",),
    "copubliaient": ("copublier",),
    "copubliai": ("copublier",),
    "copubliais": ("copublier",),
    "copubliait": ("copublier",),
    "copublia": ("copublier",),
    "copubliâmes": ("copublier",),
    "copubliant": ("copublier",),
    "copublias": ("copublier",),
    "copubliassent": ("copublier",),
    "copubliasses": ("copublier",),
    "copubliasse": ("copublier",),
    "copubliassiez": ("copublier",),
    "copubliassions": ("copublier",),
    "copubliâtes": ("copublier",),
    "copubliât": ("copublier",),
    "copubliée": ("copublier",),
    "copubliées": ("copublier",),
    "copublié": ("copublier",),
    "copublient": ("copublier",),
    "copublie": ("copublier",),
    "copubliera": ("copublier",),
    "copublieraient": ("copublier",),
    "copublierai": ("copublier",),
    "copublierais": ("copublier",),
    "copublierait": ("copublier",),
    "copublieras": ("copublier",),
    "copublièrent": ("copublier",),
    "copublierez": ("copublier",),
    "copublieriez": ("copublier",),
    "copublierions": ("copublier",),
    "copublierons": ("copublier",),
    "copublieront": ("copublier",),
    "copubliés": ("copublier",),
    "copublies": ("copublier",),
    "copubliez": ("copublier",),
    "copubliiez": ("copublier",),
    "copubliions": ("copublier",),
    "copublions": ("copublier",),
    "coquetaient": ("coqueter",),
    "coquetai": ("coqueter",),
    "coquetais": ("coqueter",),
    "coquetait": ("coqueter",),
    "coqueta": ("coqueter",),
    "coquetâmes": ("coqueter",),
    "coquetant": ("coqueter",),
    "coquetas": ("coqueter",),
    "coquetassent": ("coqueter",),
    "coquetasses": ("coqueter",),
    "coquetasse": ("coqueter",),
    "coquetassiez": ("coqueter",),
    "coquetassions": ("coqueter",),
    "coquetâtes": ("coqueter",),
    "coquetât": ("coqueter",),
    "coquetée": ("coqueter",),
    "coquetées": ("coqueter",),
    "coqueté": ("coqueter",),
    "coquetèrent": ("coqueter",),
    "coquetés": ("coqueter",),
    "coquetez": ("coqueter",),
    "coquetiez": ("coqueter",),
    "coquetions": ("coqueter",),
    "coquetons": ("coqueter",),
    "coquettent": ("coqueter",),
    "coquette": ("coqueter",),
    "coquettera": ("coqueter",),
    "coquetteraient": ("coqueter",),
    "coquetterai": ("coqueter",),
    "coquetterais": ("coqueter",),
    "coquetterait": ("coqueter",),
    "coquetteras": ("coqueter",),
    "coquetterez": ("coqueter",),
    "coquetteriez": ("coqueter",),
    "coquetterions": ("coqueter",),
    "coquetterons": ("coqueter",),
    "coquetteront": ("coqueter",),
    "coquettes": ("coqueter",),
    "cordageaient": ("cordager",),
    "cordageai": ("cordager",),
    "cordageais": ("cordager",),
    "cordageait": ("cordager",),
    "cordagea": ("cordager",),
    "cordageâmes": ("cordager",),
    "cordageant": ("cordager",),
    "cordageas": ("cordager",),
    "cordageassent": ("cordager",),
    "cordageasses": ("cordager",),
    "cordageasse": ("cordager",),
    "cordageassiez": ("cordager",),
    "cordageassions": ("cordager",),
    "cordageâtes": ("cordager",),
    "cordageât": ("cordager",),
    "cordagée": ("cordager",),
    "cordagées": ("cordager",),
    "cordagé": ("cordager",),
    "cordagent": ("cordager",),
    "cordageons": ("cordager",),
    "cordage": ("cordager",),
    "cordagera": ("cordager",),
    "cordageraient": ("cordager",),
    "cordagerai": ("cordager",),
    "cordagerais": ("cordager",),
    "cordagerait": ("cordager",),
    "cordageras": ("cordager",),
    "cordagèrent": ("cordager",),
    "cordagerez": ("cordager",),
    "cordageriez": ("cordager",),
    "cordagerions": ("cordager",),
    "cordagerons": ("cordager",),
    "cordageront": ("cordager",),
    "cordagés": ("cordager",),
    "cordages": ("cordager",),
    "cordagez": ("cordager",),
    "cordagiez": ("cordager",),
    "cordagions": ("cordager",),
    "cordelaient": ("cordeler",),
    "cordelai": ("cordeler",),
    "cordelais": ("cordeler",),
    "cordelait": ("cordeler",),
    "cordela": ("cordeler",),
    "cordelâmes": ("cordeler",),
    "cordelant": ("cordeler",),
    "cordelas": ("cordeler",),
    "cordelassent": ("cordeler",),
    "cordelasses": ("cordeler",),
    "cordelasse": ("cordeler",),
    "cordelassiez": ("cordeler",),
    "cordelassions": ("cordeler",),
    "cordelâtes": ("cordeler",),
    "cordelât": ("cordeler",),
    "cordelée": ("cordeler",),
    "cordelées": ("cordeler",),
    "cordelé": ("cordeler",),
    "cordelèrent": ("cordeler",),
    "cordelés": ("cordeler",),
    "cordelez": ("cordeler",),
    "cordeliez": ("cordeler",),
    "cordelions": ("cordeler",),
    "cordellent": ("cordeler",),
    "cordelle": ("cordeler",),
    "cordellera": ("cordeler",),
    "cordelleraient": ("cordeler",),
    "cordellerai": ("cordeler",),
    "cordellerais": ("cordeler",),
    "cordellerait": ("cordeler",),
    "cordelleras": ("cordeler",),
    "cordellerez": ("cordeler",),
    "cordelleriez": ("cordeler",),
    "cordellerions": ("cordeler",),
    "cordellerons": ("cordeler",),
    "cordelleront": ("cordeler",),
    "cordelles": ("cordeler",),
    "cordelons": ("cordeler",),
    "cornetaient": ("corneter",),
    "cornetai": ("corneter",),
    "cornetais": ("corneter",),
    "cornetait": ("corneter",),
    "corneta": ("corneter",),
    "cornetâmes": ("corneter",),
    "cornetant": ("corneter",),
    "cornetas": ("corneter",),
    "cornetassent": ("corneter",),
    "cornetasses": ("corneter",),
    "cornetasse": ("corneter",),
    "cornetassiez": ("corneter",),
    "cornetassions": ("corneter",),
    "cornetâtes": ("corneter",),
    "cornetât": ("corneter",),
    "cornetée": ("corneter",),
    "cornetées": ("corneter",),
    "corneté": ("corneter",),
    "cornetèrent": ("corneter",),
    "cornetés": ("corneter",),
    "cornetez": ("corneter",),
    "cornetiez": ("corneter",),
    "cornetions": ("corneter",),
    "cornetons": ("corneter",),
    "cornettent": ("corneter",),
    "cornette": ("corneter",),
    "cornettera": ("corneter",),
    "cornetteraient": ("corneter",),
    "cornetterai": ("corneter",),
    "cornetterais": ("corneter",),
    "cornetterait": ("corneter",),
    "cornetteras": ("corneter",),
    "cornetterez": ("corneter",),
    "cornetteriez": ("corneter",),
    "cornetterions": ("corneter",),
    "cornetterons": ("corneter",),
    "cornetteront": ("corneter",),
    "cornettes": ("corneter",),
    "corporifiaient": ("corporifier",),
    "corporifiai": ("corporifier",),
    "corporifiais": ("corporifier",),
    "corporifiait": ("corporifier",),
    "corporifia": ("corporifier",),
    "corporifiâmes": ("corporifier",),
    "corporifiant": ("corporifier",),
    "corporifias": ("corporifier",),
    "corporifiassent": ("corporifier",),
    "corporifiasses": ("corporifier",),
    "corporifiasse": ("corporifier",),
    "corporifiassiez": ("corporifier",),
    "corporifiassions": ("corporifier",),
    "corporifiâtes": ("corporifier",),
    "corporifiât": ("corporifier",),
    "corporifiée": ("corporifier",),
    "corporifiées": ("corporifier",),
    "corporifié": ("corporifier",),
    "corporifient": ("corporifier",),
    "corporifie": ("corporifier",),
    "corporifiera": ("corporifier",),
    "corporifieraient": ("corporifier",),
    "corporifierai": ("corporifier",),
    "corporifierais": ("corporifier",),
    "corporifierait": ("corporifier",),
    "corporifieras": ("corporifier",),
    "corporifièrent": ("corporifier",),
    "corporifierez": ("corporifier",),
    "corporifieriez": ("corporifier",),
    "corporifierions": ("corporifier",),
    "corporifierons": ("corporifier",),
    "corporifieront": ("corporifier",),
    "corporifiés": ("corporifier",),
    "corporifies": ("corporifier",),
    "corporifiez": ("corporifier",),
    "corporifiiez": ("corporifier",),
    "corporifiions": ("corporifier",),
    "corporifions": ("corporifier",),
    "correspondaient": ("correspondre",),
    "correspondais": ("correspondre",),
    "correspondait": ("correspondre",),
    "correspondant": ("correspondre",),
    "correspondent": ("correspondre",),
    "corresponde": ("correspondre",),
    "correspondes": ("correspondre",),
    "correspondez": ("correspondre",),
    "correspondiez": ("correspondre",),
    "correspondîmes": ("correspondre",),
    "correspondions": ("correspondre",),
    "correspondirent": ("correspondre",),
    "correspondis": ("correspondre",),
    "correspondissent": ("correspondre",),
    "correspondisses": ("correspondre",),
    "correspondisse": ("correspondre",),
    "correspondissiez": ("correspondre",),
    "correspondissions": ("correspondre",),
    "correspondîtes": ("correspondre",),
    "correspondit": ("correspondre",),
    "correspondît": ("correspondre",),
    "correspondons": ("correspondre",),
    "correspond": ("correspondre",),
    "correspondra": ("correspondre",),
    "correspondraient": ("correspondre",),
    "correspondrai": ("correspondre",),
    "correspondrais": ("correspondre",),
    "correspondrait": ("correspondre",),
    "correspondras": ("correspondre",),
    "correspondrez": ("correspondre",),
    "correspondriez": ("correspondre",),
    "correspondrions": ("correspondre",),
    "correspondrons": ("correspondre",),
    "correspondront": ("correspondre",),
    "corresponds": ("correspondre",),
    "correspondu": ("correspondre",),
    "corrigeaient": ("corriger",),
    "corrigeai": ("corriger",),
    "corrigeais": ("corriger",),
    "corrigeait": ("corriger",),
    "corrigea": ("corriger",),
    "corrigeâmes": ("corriger",),
    "corrigeant": ("corriger",),
    "corrigeas": ("corriger",),
    "corrigeassent": ("corriger",),
    "corrigeasses": ("corriger",),
    "corrigeasse": ("corriger",),
    "corrigeassiez": ("corriger",),
    "corrigeassions": ("corriger",),
    "corrigeâtes": ("corriger",),
    "corrigeât": ("corriger",),
    "corrigée": ("corriger",),
    "corrigées": ("corriger",),
    "corrigé": ("corriger",),
    "corrigent": ("corriger",),
    "corrigeons": ("corriger",),
    "corrige": ("corriger",),
    "corrigera": ("corriger",),
    "corrigeraient": ("corriger",),
    "corrigerai": ("corriger",),
    "corrigerais": ("corriger",),
    "corrigerait": ("corriger",),
    "corrigeras": ("corriger",),
    "corrigèrent": ("corriger",),
    "corrigerez": ("corriger",),
    "corrigeriez": ("corriger",),
    "corrigerions": ("corriger",),
    "corrigerons": ("corriger",),
    "corrigeront": ("corriger",),
    "corrigés": ("corriger",),
    "corriges": ("corriger",),
    "corrigez": ("corriger",),
    "corrigiez": ("corriger",),
    "corrigions": ("corriger",),
    "corrompaient": ("corrompre",),
    "corrompais": ("corrompre",),
    "corrompait": ("corrompre",),
    "corrompant": ("corrompre",),
    "corrompent": ("corrompre",),
    "corrompe": ("corrompre",),
    "corrompes": ("corrompre",),
    "corrompez": ("corrompre",),
    "corrompiez": ("corrompre",),
    "corrompîmes": ("corrompre",),
    "corrompions": ("corrompre",),
    "corrompirent": ("corrompre",),
    "corrompis": ("corrompre",),
    "corrompissent": ("corrompre",),
    "corrompisses": ("corrompre",),
    "corrompisse": ("corrompre",),
    "corrompissiez": ("corrompre",),
    "corrompissions": ("corrompre",),
    "corrompîtes": ("corrompre",),
    "corrompit": ("corrompre",),
    "corrompît": ("corrompre",),
    "corrompons": ("corrompre",),
    "corrompra": ("corrompre",),
    "corrompraient": ("corrompre",),
    "corromprai": ("corrompre",),
    "corromprais": ("corrompre",),
    "corromprait": ("corrompre",),
    "corrompras": ("corrompre",),
    "corromprez": ("corrompre",),
    "corrompriez": ("corrompre",),
    "corromprions": ("corrompre",),
    "corromprons": ("corrompre",),
    "corrompront": ("corrompre",),
    "corromps": ("corrompre",),
    "corrompt": ("corrompre",),
    "corrompue": ("corrompre",),
    "corrompues": ("corrompre",),
    "corrompu": ("corrompre",),
    "corrompus": ("corrompre",),
    "corroient": ("corroyer",),
    "corroie": ("corroyer",),
    "corroiera": ("corroyer",),
    "corroieraient": ("corroyer",),
    "corroierai": ("corroyer",),
    "corroierais": ("corroyer",),
    "corroierait": ("corroyer",),
    "corroieras": ("corroyer",),
    "corroierez": ("corroyer",),
    "corroieriez": ("corroyer",),
    "corroierions": ("corroyer",),
    "corroierons": ("corroyer",),
    "corroieront": ("corroyer",),
    "corroies": ("corroyer",),
    "corroyaient": ("corroyer",),
    "corroyai": ("corroyer",),
    "corroyais": ("corroyer",),
    "corroyait": ("corroyer",),
    "corroya": ("corroyer",),
    "corroyâmes": ("corroyer",),
    "corroyant": ("corroyer",),
    "corroyas": ("corroyer",),
    "corroyassent": ("corroyer",),
    "corroyasses": ("corroyer",),
    "corroyasse": ("corroyer",),
    "corroyassiez": ("corroyer",),
    "corroyassions": ("corroyer",),
    "corroyâtes": ("corroyer",),
    "corroyât": ("corroyer",),
    "corroyée": ("corroyer",),
    "corroyées": ("corroyer",),
    "corroyé": ("corroyer",),
    "corroyèrent": ("corroyer",),
    "corroyés": ("corroyer",),
    "corroyez": ("corroyer",),
    "corroyiez": ("corroyer",),
    "corroyions": ("corroyer",),
    "corroyons": ("corroyer",),
    "corsetaient": ("corseter",),
    "corsetai": ("corseter",),
    "corsetais": ("corseter",),
    "corsetait": ("corseter",),
    "corseta": ("corseter",),
    "corsetâmes": ("corseter",),
    "corsetant": ("corseter",),
    "corsetas": ("corseter",),
    "corsetassent": ("corseter",),
    "corsetasses": ("corseter",),
    "corsetasse": ("corseter",),
    "corsetassiez": ("corseter",),
    "corsetassions": ("corseter",),
    "corsetâtes": ("corseter",),
    "corsetât": ("corseter",),
    "corsetée": ("corseter",),
    "corsetées": ("corseter",),
    "corseté": ("corseter",),
    "corsètent": ("corseter",),
    "corsète": ("corseter",),
    "corsètera": ("corseter",),
    "corsèteraient": ("corseter",),
    "corsèterai": ("corseter",),
    "corsèterais": ("corseter",),
    "corsèterait": ("corseter",),
    "corsèteras": ("corseter",),
    "corsetèrent": ("corseter",),
    "corsèterez": ("corseter",),
    "corsèteriez": ("corseter",),
    "corsèterions": ("corseter",),
    "corsèterons": ("corseter",),
    "corsèteront": ("corseter",),
    "corsetés": ("corseter",),
    "corsètes": ("corseter",),
    "corsetez": ("corseter",),
    "corsetiez": ("corseter",),
    "corsetions": ("corseter",),
    "corsetons": ("corseter",),
    "cortégeaient": ("cortéger",),
    "cortégeai": ("cortéger",),
    "cortégeais": ("cortéger",),
    "cortégeait": ("cortéger",),
    "cortégea": ("cortéger",),
    "cortégeâmes": ("cortéger",),
    "cortégeant": ("cortéger",),
    "cortégeas": ("cortéger",),
    "cortégeassent": ("cortéger",),
    "cortégeasses": ("cortéger",),
    "cortégeasse": ("cortéger",),
    "cortégeassiez": ("cortéger",),
    "cortégeassions": ("cortéger",),
    "cortégeâtes": ("cortéger",),
    "cortégeât": ("cortéger",),
    "cortégée": ("cortéger",),
    "cortégées": ("cortéger",),
    "cortégé": ("cortéger",),
    "cortègent": ("cortéger",),
    "cortégeons": ("cortéger",),
    "cortège": ("cortéger",),
    "cortégera": ("cortéger",),
    "cortégeraient": ("cortéger",),
    "cortégerai": ("cortéger",),
    "cortégerais": ("cortéger",),
    "cortégerait": ("cortéger",),
    "cortégeras": ("cortéger",),
    "cortégèrent": ("cortéger",),
    "cortégerez": ("cortéger",),
    "cortégeriez": ("cortéger",),
    "cortégerions": ("cortéger",),
    "cortégerons": ("cortéger",),
    "cortégeront": ("cortéger",),
    "cortégés": ("cortéger",),
    "cortèges": ("cortéger",),
    "cortégez": ("cortéger",),
    "cortégiez": ("cortéger",),
    "cortégions": ("cortéger",),
    "cosmifiaient": ("cosmifier",),
    "cosmifiai": ("cosmifier",),
    "cosmifiais": ("cosmifier",),
    "cosmifiait": ("cosmifier",),
    "cosmifia": ("cosmifier",),
    "cosmifiâmes": ("cosmifier",),
    "cosmifiant": ("cosmifier",),
    "cosmifias": ("cosmifier",),
    "cosmifiassent": ("cosmifier",),
    "cosmifiasses": ("cosmifier",),
    "cosmifiasse": ("cosmifier",),
    "cosmifiassiez": ("cosmifier",),
    "cosmifiassions": ("cosmifier",),
    "cosmifiâtes": ("cosmifier",),
    "cosmifiât": ("cosmifier",),
    "cosmifiée": ("cosmifier",),
    "cosmifiées": ("cosmifier",),
    "cosmifié": ("cosmifier",),
    "cosmifient": ("cosmifier",),
    "cosmifie": ("cosmifier",),
    "cosmifiera": ("cosmifier",),
    "cosmifieraient": ("cosmifier",),
    "cosmifierai": ("cosmifier",),
    "cosmifierais": ("cosmifier",),
    "cosmifierait": ("cosmifier",),
    "cosmifieras": ("cosmifier",),
    "cosmifièrent": ("cosmifier",),
    "cosmifierez": ("cosmifier",),
    "cosmifieriez": ("cosmifier",),
    "cosmifierions": ("cosmifier",),
    "cosmifierons": ("cosmifier",),
    "cosmifieront": ("cosmifier",),
    "cosmifiés": ("cosmifier",),
    "cosmifies": ("cosmifier",),
    "cosmifiez": ("cosmifier",),
    "cosmifiiez": ("cosmifier",),
    "cosmifiions": ("cosmifier",),
    "cosmifions": ("cosmifier",),
    "cotie": ("cotir",),
    "coties": ("cotir",),
    "coti": ("cotir",),
    "cotîmes": ("cotir",),
    "cotira": ("cotir",),
    "cotiraient": ("cotir",),
    "cotirai": ("cotir",),
    "cotirais": ("cotir",),
    "cotirait": ("cotir",),
    "cotiras": ("cotir",),
    "cotirent": ("cotir",),
    "cotirez": ("cotir",),
    "cotiriez": ("cotir",),
    "cotirions": ("cotir",),
    "cotirons": ("cotir",),
    "cotiront": ("cotir",),
    "cotis": ("cotir",),
    "cotissaient": ("cotir",),
    "cotissais": ("cotir",),
    "cotissait": ("cotir",),
    "cotissant": ("cotir",),
    "cotissent": ("cotir",),
    "cotisse": ("cotir",),
    "cotisses": ("cotir",),
    "cotissez": ("cotir",),
    "cotissiez": ("cotir",),
    "cotissions": ("cotir",),
    "cotissons": ("cotir",),
    "cotîtes": ("cotir",),
    "cotit": ("cotir",),
    "cotît": ("cotir",),
    "côtoient": ("côtoyer",),
    "côtoie": ("côtoyer",),
    "côtoiera": ("côtoyer",),
    "côtoieraient": ("côtoyer",),
    "côtoierai": ("côtoyer",),
    "côtoierais": ("côtoyer",),
    "côtoierait": ("côtoyer",),
    "côtoieras": ("côtoyer",),
    "côtoierez": ("côtoyer",),
    "côtoieriez": ("côtoyer",),
    "côtoierions": ("côtoyer",),
    "côtoierons": ("côtoyer",),
    "côtoieront": ("côtoyer",),
    "côtoies": ("côtoyer",),
    "côtoyaient": ("côtoyer",),
    "côtoyai": ("côtoyer",),
    "côtoyais": ("côtoyer",),
    "côtoyait": ("côtoyer",),
    "côtoya": ("côtoyer",),
    "côtoyâmes": ("côtoyer",),
    "côtoyant": ("côtoyer",),
    "côtoyas": ("côtoyer",),
    "côtoyassent": ("côtoyer",),
    "côtoyasses": ("côtoyer",),
    "côtoyasse": ("côtoyer",),
    "côtoyassiez": ("côtoyer",),
    "côtoyassions": ("côtoyer",),
    "côtoyâtes": ("côtoyer",),
    "côtoyât": ("côtoyer",),
    "côtoyée": ("côtoyer",),
    "côtoyées": ("côtoyer",),
    "côtoyé": ("côtoyer",),
    "côtoyèrent": ("côtoyer",),
    "côtoyés": ("côtoyer",),
    "côtoyez": ("côtoyer",),
    "côtoyiez": ("côtoyer",),
    "côtoyions": ("côtoyer",),
    "côtoyons": ("côtoyer",),
    "coudoient": ("coudoyer",),
    "coudoie": ("coudoyer",),
    "coudoiera": ("coudoyer",),
    "coudoieraient": ("coudoyer",),
    "coudoierai": ("coudoyer",),
    "coudoierais": ("coudoyer",),
    "coudoierait": ("coudoyer",),
    "coudoieras": ("coudoyer",),
    "coudoierez": ("coudoyer",),
    "coudoieriez": ("coudoyer",),
    "coudoierions": ("coudoyer",),
    "coudoierons": ("coudoyer",),
    "coudoieront": ("coudoyer",),
    "coudoies": ("coudoyer",),
    "coudoyaient": ("coudoyer",),
    "coudoyai": ("coudoyer",),
    "coudoyais": ("coudoyer",),
    "coudoyait": ("coudoyer",),
    "coudoya": ("coudoyer",),
    "coudoyâmes": ("coudoyer",),
    "coudoyant": ("coudoyer",),
    "coudoyas": ("coudoyer",),
    "coudoyassent": ("coudoyer",),
    "coudoyasses": ("coudoyer",),
    "coudoyasse": ("coudoyer",),
    "coudoyassiez": ("coudoyer",),
    "coudoyassions": ("coudoyer",),
    "coudoyâtes": ("coudoyer",),
    "coudoyât": ("coudoyer",),
    "coudoyée": ("coudoyer",),
    "coudoyées": ("coudoyer",),
    "coudoyé": ("coudoyer",),
    "coudoyèrent": ("coudoyer",),
    "coudoyés": ("coudoyer",),
    "coudoyez": ("coudoyer",),
    "coudoyiez": ("coudoyer",),
    "coudoyions": ("coudoyer",),
    "coudoyons": ("coudoyer",),
    "coud": ("coudre",),
    "coudra": ("coudre",),
    "coudraient": ("coudre",),
    "coudrai": ("coudre",),
    "coudrais": ("coudre",),
    "coudrait": ("coudre",),
    "coudras": ("coudre",),
    "coudrez": ("coudre",),
    "coudriez": ("coudre",),
    "coudrions": ("coudre",),
    "coudrons": ("coudre",),
    "coudront": ("coudre",),
    "couds": ("coudre",),
    "cousaient": ("coudre",),
    "cousais": ("coudre",),
    "cousait": ("coudre",),
    "cousant": ("coudre",),
    "cousent": ("coudre",),
    "couse": ("coudre",),
    "couses": ("coudre",),
    "cousez": ("coudre",),
    "cousiez": ("coudre",),
    "cousîmes": ("coudre",),
    "cousions": ("coudre",),
    "cousirent": ("coudre",),
    "cousis": ("coudre",),
    "cousissent": ("coudre",),
    "cousisses": ("coudre",),
    "cousisse": ("coudre",),
    "cousissiez": ("coudre",),
    "cousissions": ("coudre",),
    "cousîtes": ("coudre",),
    "cousit": ("coudre",),
    "cousît": ("coudre",),
    "cousons": ("coudre",),
    "cousue": ("coudre",),
    "cousues": ("coudre",),
    "cousu": ("coudre",),
    "cousus": ("coudre",),
    "coupetaient": ("coupeter",),
    "coupetai": ("coupeter",),
    "coupetais": ("coupeter",),
    "coupetait": ("coupeter",),
    "coupeta": ("coupeter",),
    "coupetâmes": ("coupeter",),
    "coupetant": ("coupeter",),
    "coupetas": ("coupeter",),
    "coupetassent": ("coupeter",),
    "coupetasses": ("coupeter",),
    "coupetasse": ("coupeter",),
    "coupetassiez": ("coupeter",),
    "coupetassions": ("coupeter",),
    "coupetâtes": ("coupeter",),
    "coupetât": ("coupeter",),
    "coupetée": ("coupeter",),
    "coupetées": ("coupeter",),
    "coupeté": ("coupeter",),
    "coupetèrent": ("coupeter",),
    "coupetés": ("coupeter",),
    "coupetez": ("coupeter",),
    "coupetiez": ("coupeter",),
    "coupetions": ("coupeter",),
    "coupetons": ("coupeter",),
    "coupettent": ("coupeter",),
    "coupette": ("coupeter",),
    "coupettera": ("coupeter",),
    "coupetteraient": ("coupeter",),
    "coupetterai": ("coupeter",),
    "coupetterais": ("coupeter",),
    "coupetterait": ("coupeter",),
    "coupetteras": ("coupeter",),
    "coupetterez": ("coupeter",),
    "coupetteriez": ("coupeter",),
    "coupetterions": ("coupeter",),
    "coupetterons": ("coupeter",),
    "coupetteront": ("coupeter",),
    "coupettes": ("coupeter",),
    "coupletaient": ("coupleter",),
    "coupletai": ("coupleter",),
    "coupletais": ("coupleter",),
    "coupletait": ("coupleter",),
    "coupleta": ("coupleter",),
    "coupletâmes": ("coupleter",),
    "coupletant": ("coupleter",),
    "coupletas": ("coupleter",),
    "coupletassent": ("coupleter",),
    "coupletasses": ("coupleter",),
    "coupletasse": ("coupleter",),
    "coupletassiez": ("coupleter",),
    "coupletassions": ("coupleter",),
    "coupletâtes": ("coupleter",),
    "coupletât": ("coupleter",),
    "coupletée": ("coupleter",),
    "coupletées": ("coupleter",),
    "coupleté": ("coupleter",),
    "coupletèrent": ("coupleter",),
    "coupletés": ("coupleter",),
    "coupletez": ("coupleter",),
    "coupletiez": ("coupleter",),
    "coupletions": ("coupleter",),
    "coupletons": ("coupleter",),
    "couplettent": ("coupleter",),
    "couplette": ("coupleter",),
    "couplettera": ("coupleter",),
    "coupletteraient": ("coupleter",),
    "coupletterai": ("coupleter",),
    "coupletterais": ("coupleter",),
    "coupletterait": ("coupleter",),
    "coupletteras": ("coupleter",),
    "coupletterez": ("coupleter",),
    "coupletteriez": ("coupleter",),
    "coupletterions": ("coupleter",),
    "coupletterons": ("coupleter",),
    "coupletteront": ("coupleter",),
    "couplettes": ("coupleter",),
    "couraient": ("courir",),
    "courais": ("courir",),
    "courait": ("courir",),
    "courant": ("courir",),
    "courent": ("courir",),
    "coure": ("courir",),
    "coures": ("courir",),
    "courez": ("courir",),
    "couriez": ("courir",),
    "courions": ("courir",),
    "courons": ("courir",),
    "courra": ("courir",),
    "courraient": ("courir",),
    "courrai": ("courir",),
    "courrais": ("courir",),
    "courrait": ("courir",),
    "courras": ("courir",),
    "courrez": ("courir",),
    "courriez": ("courir",),
    "courrions": ("courir",),
    "courrons": ("courir",),
    "courront": ("courir",),
    "cours": ("courir",),
    "court": ("courir",),
    "courue": ("courir",),
    "courues": ("courir",),
    "couru": ("courir",),
    "courûmes": ("courir",),
    "coururent": ("courir",),
    "courus": ("courir",),
    "courussent": ("courir",),
    "courusses": ("courir",),
    "courusse": ("courir",),
    "courussiez": ("courir",),
    "courussions": ("courir",),
    "courûtes": ("courir",),
    "courut": ("courir",),
    "courût": ("courir",),
    "courrouçaient": ("courroucer",),
    "courrouçai": ("courroucer",),
    "courrouçais": ("courroucer",),
    "courrouçait": ("courroucer",),
    "courrouça": ("courroucer",),
    "courrouçâmes": ("courroucer",),
    "courrouçant": ("courroucer",),
    "courrouças": ("courroucer",),
    "courrouçassent": ("courroucer",),
    "courrouçasses": ("courroucer",),
    "courrouçasse": ("courroucer",),
    "courrouçassiez": ("courroucer",),
    "courrouçassions": ("courroucer",),
    "courrouçâtes": ("courroucer",),
    "courrouçât": ("courroucer",),
    "courroucée": ("courroucer",),
    "courroucées": ("courroucer",),
    "courroucé": ("courroucer",),
    "courroucent": ("courroucer",),
    "courrouce": ("courroucer",),
    "courroucera": ("courroucer",),
    "courrouceraient": ("courroucer",),
    "courroucerai": ("courroucer",),
    "courroucerais": ("courroucer",),
    "courroucerait": ("courroucer",),
    "courrouceras": ("courroucer",),
    "courroucèrent": ("courroucer",),
    "courroucerez": ("courroucer",),
    "courrouceriez": ("courroucer",),
    "courroucerions": ("courroucer",),
    "courroucerons": ("courroucer",),
    "courrouceront": ("courroucer",),
    "courroucés": ("courroucer",),
    "courrouces": ("courroucer",),
    "courroucez": ("courroucer",),
    "courrouciez": ("courroucer",),
    "courroucions": ("courroucer",),
    "courrouçons": ("courroucer",),
    "coutelaient": ("couteler",),
    "coutelai": ("couteler",),
    "coutelais": ("couteler",),
    "coutelait": ("couteler",),
    "coutela": ("couteler",),
    "coutelâmes": ("couteler",),
    "coutelant": ("couteler",),
    "coutelas": ("couteler",),
    "coutelassent": ("couteler",),
    "coutelasses": ("couteler",),
    "coutelasse": ("couteler",),
    "coutelassiez": ("couteler",),
    "coutelassions": ("couteler",),
    "coutelâtes": ("couteler",),
    "coutelât": ("couteler",),
    "coutelée": ("couteler",),
    "coutelées": ("couteler",),
    "coutelé": ("couteler",),
    "coutèlent": ("couteler",),
    "coutèle": ("couteler",),
    "coutèlera": ("couteler",),
    "coutèleraient": ("couteler",),
    "coutèlerai": ("couteler",),
    "coutèlerais": ("couteler",),
    "coutèlerait": ("couteler",),
    "coutèleras": ("couteler",),
    "coutelèrent": ("couteler",),
    "coutèlerez": ("couteler",),
    "coutèleriez": ("couteler",),
    "coutèlerions": ("couteler",),
    "coutèlerons": ("couteler",),
    "coutèleront": ("couteler",),
    "coutelés": ("couteler",),
    "coutèles": ("couteler",),
    "coutelez": ("couteler",),
    "couteliez": ("couteler",),
    "coutelions": ("couteler",),
    "coutelons": ("couteler",),
    "couverte": ("couvrir",),
    "couvertes": ("couvrir",),
    "couvert": ("couvrir",),
    "couverts": ("couvrir",),
    "couvraient": ("couvrir",),
    "couvrais": ("couvrir",),
    "couvrait": ("couvrir",),
    "couvrant": ("couvrir",),
    "couvrent": ("couvrir",),
    "couvre": ("couvrir",),
    "couvres": ("couvrir",),
    "couvrez": ("couvrir",),
    "couvriez": ("couvrir",),
    "couvrîmes": ("couvrir",),
    "couvrions": ("couvrir",),
    "couvrira": ("couvrir",),
    "couvriraient": ("couvrir",),
    "couvrirai": ("couvrir",),
    "couvrirais": ("couvrir",),
    "couvrirait": ("couvrir",),
    "couvriras": ("couvrir",),
    "couvrirent": ("couvrir",),
    "couvrirez": ("couvrir",),
    "couvririez": ("couvrir",),
    "couvririons": ("couvrir",),
    "couvrirons": ("couvrir",),
    "couvriront": ("couvrir",),
    "couvris": ("couvrir",),
    "couvrissent": ("couvrir",),
    "couvrisses": ("couvrir",),
    "couvrisse": ("couvrir",),
    "couvrissiez": ("couvrir",),
    "couvrissions": ("couvrir",),
    "couvrîtes": ("couvrir",),
    "couvrit": ("couvrir",),
    "couvrît": ("couvrir",),
    "couvrons": ("couvrir",),
    "covariaient": ("covarier",),
    "covariai": ("covarier",),
    "covariais": ("covarier",),
    "covariait": ("covarier",),
    "covaria": ("covarier",),
    "covariâmes": ("covarier",),
    "covariant": ("covarier",),
    "covarias": ("covarier",),
    "covariassent": ("covarier",),
    "covariasses": ("covarier",),
    "covariasse": ("covarier",),
    "covariassiez": ("covarier",),
    "covariassions": ("covarier",),
    "covariâtes": ("covarier",),
    "covariât": ("covarier",),
    "covariée": ("covarier",),
    "covariées": ("covarier",),
    "covarié": ("covarier",),
    "covarient": ("covarier",),
    "covarie": ("covarier",),
    "covariera": ("covarier",),
    "covarieraient": ("covarier",),
    "covarierai": ("covarier",),
    "covarierais": ("covarier",),
    "covarierait": ("covarier",),
    "covarieras": ("covarier",),
    "covarièrent": ("covarier",),
    "covarierez": ("covarier",),
    "covarieriez": ("covarier",),
    "covarierions": ("covarier",),
    "covarierons": ("covarier",),
    "covarieront": ("covarier",),
    "covariés": ("covarier",),
    "covaries": ("covarier",),
    "covariez": ("covarier",),
    "covariiez": ("covarier",),
    "covariions": ("covarier",),
    "covarions": ("covarier",),
    "craignaient": ("craindre",),
    "craignais": ("craindre",),
    "craignait": ("craindre",),
    "craignant": ("craindre",),
    "craignent": ("craindre",),
    "craigne": ("craindre",),
    "craignes": ("craindre",),
    "craignez": ("craindre",),
    "craigniez": ("craindre",),
    "craignîmes": ("craindre",),
    "craignions": ("craindre",),
    "craignirent": ("craindre",),
    "craignis": ("craindre",),
    "craignissent": ("craindre",),
    "craignisses": ("craindre",),
    "craignisse": ("craindre",),
    "craignissiez": ("craindre",),
    "craignissions": ("craindre",),
    "craignîtes": ("craindre",),
    "craignit": ("craindre",),
    "craignît": ("craindre",),
    "craignons": ("craindre",),
    "craindra": ("craindre",),
    "craindraient": ("craindre",),
    "craindrai": ("craindre",),
    "craindrais": ("craindre",),
    "craindrait": ("craindre",),
    "craindras": ("craindre",),
    "craindrez": ("craindre",),
    "craindriez": ("craindre",),
    "craindrions": ("craindre",),
    "craindrons": ("craindre",),
    "craindront": ("craindre",),
    "crains": ("craindre",),
    "crainte": ("craindre",),
    "craintes": ("craindre",),
    "craint": ("craindre",),
    "craints": ("craindre",),
    "cramoisie": ("cramoisir",),
    "cramoisies": ("cramoisir",),
    "cramoisi": ("cramoisir",),
    "cramoisîmes": ("cramoisir",),
    "cramoisira": ("cramoisir",),
    "cramoisiraient": ("cramoisir",),
    "cramoisirai": ("cramoisir",),
    "cramoisirais": ("cramoisir",),
    "cramoisirait": ("cramoisir",),
    "cramoisiras": ("cramoisir",),
    "cramoisirent": ("cramoisir",),
    "cramoisirez": ("cramoisir",),
    "cramoisiriez": ("cramoisir",),
    "cramoisirions": ("cramoisir",),
    "cramoisirons": ("cramoisir",),
    "cramoisiront": ("cramoisir",),
    "cramoisis": ("cramoisir",),
    "cramoisissaient": ("cramoisir",),
    "cramoisissais": ("cramoisir",),
    "cramoisissait": ("cramoisir",),
    "cramoisissant": ("cramoisir",),
    "cramoisissent": ("cramoisir",),
    "cramoisisse": ("cramoisir",),
    "cramoisisses": ("cramoisir",),
    "cramoisissez": ("cramoisir",),
    "cramoisissiez": ("cramoisir",),
    "cramoisissions": ("cramoisir",),
    "cramoisissons": ("cramoisir",),
    "cramoisîtes": ("cramoisir",),
    "cramoisit": ("cramoisir",),
    "cramoisît": ("cramoisir",),
    "craquelaient": ("craqueler",),
    "craquelai": ("craqueler",),
    "craquelais": ("craqueler",),
    "craquelait": ("craqueler",),
    "craquela": ("craqueler",),
    "craquelâmes": ("craqueler",),
    "craquelant": ("craqueler",),
    "craquelas": ("craqueler",),
    "craquelassent": ("craqueler",),
    "craquelasses": ("craqueler",),
    "craquelasse": ("craqueler",),
    "craquelassiez": ("craqueler",),
    "craquelassions": ("craqueler",),
    "craquelâtes": ("craqueler",),
    "craquelât": ("craqueler",),
    "craquelée": ("craqueler",),
    "craquelées": ("craqueler",),
    "craquelé": ("craqueler",),
    "craquelèrent": ("craqueler",),
    "craquelés": ("craqueler",),
    "craquelez": ("craqueler",),
    "craqueliez": ("craqueler",),
    "craquelions": ("craqueler",),
    "craquellent": ("craqueler",),
    "craquelle": ("craqueler",),
    "craquellera": ("craqueler",),
    "craquelleraient": ("craqueler",),
    "craquellerai": ("craqueler",),
    "craquellerais": ("craqueler",),
    "craquellerait": ("craqueler",),
    "craquelleras": ("craqueler",),
    "craquellerez": ("craqueler",),
    "craquelleriez": ("craqueler",),
    "craquellerions": ("craqueler",),
    "craquellerons": ("craqueler",),
    "craquelleront": ("craqueler",),
    "craquelles": ("craqueler",),
    "craquelons": ("craqueler",),
    "craquetaient": ("craqueter",),
    "craquetai": ("craqueter",),
    "craquetais": ("craqueter",),
    "craquetait": ("craqueter",),
    "craqueta": ("craqueter",),
    "craquetâmes": ("craqueter",),
    "craquetant": ("craqueter",),
    "craquetas": ("craqueter",),
    "craquetassent": ("craqueter",),
    "craquetasses": ("craqueter",),
    "craquetasse": ("craqueter",),
    "craquetassiez": ("craqueter",),
    "craquetassions": ("craqueter",),
    "craquetâtes": ("craqueter",),
    "craquetât": ("craqueter",),
    "craqueté": ("craqueter",),
    "craquetèrent": ("craqueter",),
    "craquetez": ("craqueter",),
    "craquetiez": ("craqueter",),
    "craquetions": ("craqueter",),
    "craquetons": ("craqueter",),
    "craquettent": ("craqueter",),
    "craquette": ("craqueter",),
    "craquettera": ("craqueter",),
    "craquetteraient": ("craqueter",),
    "craquetterai": ("craqueter",),
    "craquetterais": ("craqueter",),
    "craquetterait": ("craqueter",),
    "craquetteras": ("craqueter",),
    "craquetterez": ("craqueter",),
    "craquetteriez": ("craqueter",),
    "craquetterions": ("craqueter",),
    "craquetterons": ("craqueter",),
    "craquetteront": ("craqueter",),
    "craquettes": ("craqueter",),
    "crassaient": ("crasser",),
    "crassai": ("crasser",),
    "crassais": ("crasser",),
    "crassait": ("crasser",),
    "crassa": ("crasser",),
    "crassâmes": ("crasser",),
    "crassant": ("crasser",),
    "crassas": ("crasser",),
    "crassassent": ("crasser",),
    "crassasses": ("crasser",),
    "crassasse": ("crasser",),
    "crassassiez": ("crasser",),
    "crassassions": ("crasser",),
    "crassâtes": ("crasser",),
    "crassât": ("crasser",),
    "crassée": ("crasser",),
    "crassées": ("crasser",),
    "crassé": ("crasser",),
    "crassent": ("crasser",),
    "crasse": ("crasser",),
    "crassera": ("crasser",),
    "crasseraient": ("crasser",),
    "crasserai": ("crasser",),
    "crasserais": ("crasser",),
    "crasserait": ("crasser",),
    "crasseras": ("crasser",),
    "crassèrent": ("crasser",),
    "crasserez": ("crasser",),
    "crasseriez": ("crasser",),
    "crasserions": ("crasser",),
    "crasserons": ("crasser",),
    "crasseront": ("crasser",),
    "crassés": ("crasser",),
    "crasses": ("crasser",),
    "crassez": ("crasser",),
    "crassiez": ("crasser",),
    "crassions": ("crasser",),
    "crassons": ("crasser",),
    "créançaient": ("créancer",),
    "créançai": ("créancer",),
    "créançais": ("créancer",),
    "créançait": ("créancer",),
    "créança": ("créancer",),
    "créançâmes": ("créancer",),
    "créançant": ("créancer",),
    "créanças": ("créancer",),
    "créançassent": ("créancer",),
    "créançasses": ("créancer",),
    "créançasse": ("créancer",),
    "créançassiez": ("créancer",),
    "créançassions": ("créancer",),
    "créançâtes": ("créancer",),
    "créançât": ("créancer",),
    "créancée": ("créancer",),
    "créancées": ("créancer",),
    "créancé": ("créancer",),
    "créancent": ("créancer",),
    "créance": ("créancer",),
    "créancera": ("créancer",),
    "créanceraient": ("créancer",),
    "créancerai": ("créancer",),
    "créancerais": ("créancer",),
    "créancerait": ("créancer",),
    "créanceras": ("créancer",),
    "créancèrent": ("créancer",),
    "créancerez": ("créancer",),
    "créanceriez": ("créancer",),
    "créancerions": ("créancer",),
    "créancerons": ("créancer",),
    "créanceront": ("créancer",),
    "créancés": ("créancer",),
    "créances": ("créancer",),
    "créancez": ("créancer",),
    "créanciez": ("créancer",),
    "créancions": ("créancer",),
    "créançons": ("créancer",),
    "créchaient": ("crécher",),
    "créchai": ("crécher",),
    "créchais": ("crécher",),
    "créchait": ("crécher",),
    "crécha": ("crécher",),
    "créchâmes": ("crécher",),
    "créchant": ("crécher",),
    "créchas": ("crécher",),
    "créchassent": ("crécher",),
    "créchasses": ("crécher",),
    "créchasse": ("crécher",),
    "créchassiez": ("crécher",),
    "créchassions": ("crécher",),
    "créchâtes": ("crécher",),
    "créchât": ("crécher",),
    "créchée": ("crécher",),
    "créchées": ("crécher",),
    "créché": ("crécher",),
    "crèchent": ("crécher",),
    "crèche": ("crécher",),
    "créchera": ("crécher",),
    "crécheraient": ("crécher",),
    "crécherai": ("crécher",),
    "crécherais": ("crécher",),
    "crécherait": ("crécher",),
    "crécheras": ("crécher",),
    "créchèrent": ("crécher",),
    "crécherez": ("crécher",),
    "crécheriez": ("crécher",),
    "crécherions": ("crécher",),
    "crécherons": ("crécher",),
    "crécheront": ("crécher",),
    "créchés": ("crécher",),
    "crèches": ("crécher",),
    "créchez": ("crécher",),
    "créchiez": ("crécher",),
    "créchions": ("crécher",),
    "créchons": ("crécher",),
    "créaient": ("créer",),
    "créai": ("créer",),
    "créais": ("créer",),
    "créait": ("créer",),
    "créa": ("créer",),
    "créâmes": ("créer",),
    "créant": ("créer",),
    "créas": ("créer",),
    "créassent": ("créer",),
    "créasses": ("créer",),
    "créasse": ("créer",),
    "créassiez": ("créer",),
    "créassions": ("créer",),
    "créâtes": ("créer",),
    "créât": ("créer",),
    "créée": ("créer",),
    "créées": ("créer",),
    "créé": ("créer",),
    "créent": ("créer",),
    "crée": ("créer",),
    "créera": ("créer",),
    "créeraient": ("créer",),
    "créerai": ("créer",),
    "créerais": ("créer",),
    "créerait": ("créer",),
    "créeras": ("créer",),
    "créèrent": ("créer",),
    "créerez": ("créer",),
    "créeriez": ("créer",),
    "créerions": ("créer",),
    "créerons": ("créer",),
    "créeront": ("créer",),
    "créés": ("créer",),
    "crées": ("créer",),
    "créez": ("créer",),
    "créiez": ("créer",),
    "créions": ("créer",),
    "créons": ("créer",),
    "crémaient": ("crémer",),
    "crémai": ("crémer",),
    "crémais": ("crémer",),
    "crémait": ("crémer",),
    "créma": ("crémer",),
    "crémâmes": ("crémer",),
    "crémant": ("crémer",),
    "crémas": ("crémer",),
    "crémassent": ("crémer",),
    "crémasses": ("crémer",),
    "crémasse": ("crémer",),
    "crémassiez": ("crémer",),
    "crémassions": ("crémer",),
    "crémâtes": ("crémer",),
    "crémât": ("crémer",),
    "crémée": ("crémer",),
    "crémées": ("crémer",),
    "crémé": ("crémer",),
    "crèment": ("crémer",),
    "crème": ("crémer",),
    "crémera": ("crémer",),
    "crémeraient": ("crémer",),
    "crémerai": ("crémer",),
    "crémerais": ("crémer",),
    "crémerait": ("crémer",),
    "crémeras": ("crémer",),
    "crémèrent": ("crémer",),
    "crémerez": ("crémer",),
    "crémeriez": ("crémer",),
    "crémerions": ("crémer",),
    "crémerons": ("crémer",),
    "crémeront": ("crémer",),
    "crémés": ("crémer",),
    "crèmes": ("crémer",),
    "crémez": ("crémer",),
    "crémiez": ("crémer",),
    "crémions": ("crémer",),
    "crémons": ("crémer",),
    "crénelaient": ("créneler",),
    "crénelai": ("créneler",),
    "crénelais": ("créneler",),
    "crénelait": ("créneler",),
    "crénela": ("créneler",),
    "crénelâmes": ("créneler",),
    "crénelant": ("créneler",),
    "crénelas": ("créneler",),
    "crénelassent": ("créneler",),
    "crénelasses": ("créneler",),
    "crénelasse": ("créneler",),
    "crénelassiez": ("créneler",),
    "crénelassions": ("créneler",),
    "crénelâtes": ("créneler",),
    "crénelât": ("créneler",),
    "crénelée": ("créneler",),
    "crénelées": ("créneler",),
    "crénelé": ("créneler",),
    "crénelèrent": ("créneler",),
    "crénelés": ("créneler",),
    "crénelez": ("créneler",),
    "créneliez": ("créneler",),
    "crénelions": ("créneler",),
    "crénellent": ("créneler",),
    "crénelle": ("créneler",),
    "crénellera": ("créneler",),
    "crénelleraient": ("créneler",),
    "crénellerai": ("créneler",),
    "crénellerais": ("créneler",),
    "crénellerait": ("créneler",),
    "crénelleras": ("créneler",),
    "crénellerez": ("créneler",),
    "crénelleriez": ("créneler",),
    "crénellerions": ("créneler",),
    "crénellerons": ("créneler",),
    "crénelleront": ("créneler",),
    "crénelles": ("créneler",),
    "crénelons": ("créneler",),
    "crénaient": ("créner",),
    "crénai": ("créner",),
    "crénais": ("créner",),
    "crénait": ("créner",),
    "créna": ("créner",),
    "crénâmes": ("créner",),
    "crénant": ("créner",),
    "crénas": ("créner",),
    "crénassent": ("créner",),
    "crénasses": ("créner",),
    "crénasse": ("créner",),
    "crénassiez": ("créner",),
    "crénassions": ("créner",),
    "crénâtes": ("créner",),
    "crénât": ("créner",),
    "crénée": ("créner",),
    "crénées": ("créner",),
    "créné": ("créner",),
    "crènent": ("créner",),
    "crène": ("créner",),
    "crénera": ("créner",),
    "créneraient": ("créner",),
    "crénerai": ("créner",),
    "crénerais": ("créner",),
    "crénerait": ("créner",),
    "créneras": ("créner",),
    "crénèrent": ("créner",),
    "crénerez": ("créner",),
    "créneriez": ("créner",),
    "crénerions": ("créner",),
    "crénerons": ("créner",),
    "créneront": ("créner",),
    "crénés": ("créner",),
    "crènes": ("créner",),
    "crénez": ("créner",),
    "créniez": ("créner",),
    "crénions": ("créner",),
    "crénons": ("créner",),
    "crêpelaient": ("crêpeler",),
    "crêpelai": ("crêpeler",),
    "crêpelais": ("crêpeler",),
    "crêpelait": ("crêpeler",),
    "crêpela": ("crêpeler",),
    "crêpelâmes": ("crêpeler",),
    "crêpelant": ("crêpeler",),
    "crêpelas": ("crêpeler",),
    "crêpelassent": ("crêpeler",),
    "crêpelasses": ("crêpeler",),
    "crêpelasse": ("crêpeler",),
    "crêpelassiez": ("crêpeler",),
    "crêpelassions": ("crêpeler",),
    "crêpelâtes": ("crêpeler",),
    "crêpelât": ("crêpeler",),
    "crêpelée": ("crêpeler",),
    "crêpelées": ("crêpeler",),
    "crêpelé": ("crêpeler",),
    "crêpelèrent": ("crêpeler",),
    "crêpelés": ("crêpeler",),
    "crêpelez": ("crêpeler",),
    "crêpeliez": ("crêpeler",),
    "crêpelions": ("crêpeler",),
    "crêpellent": ("crêpeler",),
    "crêpelle": ("crêpeler",),
    "crêpellera": ("crêpeler",),
    "crêpelleraient": ("crêpeler",),
    "crêpellerai": ("crêpeler",),
    "crêpellerais": ("crêpeler",),
    "crêpellerait": ("crêpeler",),
    "crêpelleras": ("crêpeler",),
    "crêpellerez": ("crêpeler",),
    "crêpelleriez": ("crêpeler",),
    "crêpellerions": ("crêpeler",),
    "crêpellerons": ("crêpeler",),
    "crêpelleront": ("crêpeler",),
    "crêpelles": ("crêpeler",),
    "crêpelons": ("crêpeler",),
    "crépie": ("crépir",),
    "crépies": ("crépir",),
    "crépi": ("crépir",),
    "crépîmes": ("crépir",),
    "crépira": ("crépir",),
    "crépiraient": ("crépir",),
    "crépirai": ("crépir",),
    "crépirais": ("crépir",),
    "crépirait": ("crépir",),
    "crépiras": ("crépir",),
    "crépirent": ("crépir",),
    "crépirez": ("crépir",),
    "crépiriez": ("crépir",),
    "crépirions": ("crépir",),
    "crépirons": ("crépir",),
    "crépiront": ("crépir",),
    "crépis": ("crépir",),
    "crépissaient": ("crépir",),
    "crépissais": ("crépir",),
    "crépissait": ("crépir",),
    "crépissant": ("crépir",),
    "crépissent": ("crépir",),
    "crépisse": ("crépir",),
    "crépisses": ("crépir",),
    "crépissez": ("crépir",),
    "crépissiez": ("crépir",),
    "crépissions": ("crépir",),
    "crépissons": ("crépir",),
    "crépîtes": ("crépir",),
    "crépit": ("crépir",),
    "crépît": ("crépir",),
    "crespelaient": ("crespeler",),
    "crespelai": ("crespeler",),
    "crespelais": ("crespeler",),
    "crespelait": ("crespeler",),
    "crespela": ("crespeler",),
    "crespelâmes": ("crespeler",),
    "crespelant": ("crespeler",),
    "crespelas": ("crespeler",),
    "crespelassent": ("crespeler",),
    "crespelasses": ("crespeler",),
    "crespelasse": ("crespeler",),
    "crespelassiez": ("crespeler",),
    "crespelassions": ("crespeler",),
    "crespelâtes": ("crespeler",),
    "crespelât": ("crespeler",),
    "crespelée": ("crespeler",),
    "crespelées": ("crespeler",),
    "crespelé": ("crespeler",),
    "crespèlent": ("crespeler",),
    "crespèle": ("crespeler",),
    "crespèlera": ("crespeler",),
    "crespèleraient": ("crespeler",),
    "crespèlerai": ("crespeler",),
    "crespèlerais": ("crespeler",),
    "crespèlerait": ("crespeler",),
    "crespèleras": ("crespeler",),
    "crespelèrent": ("crespeler",),
    "crespèlerez": ("crespeler",),
    "crespèleriez": ("crespeler",),
    "crespèlerions": ("crespeler",),
    "crespèlerons": ("crespeler",),
    "crespèleront": ("crespeler",),
    "crespelés": ("crespeler",),
    "crespèles": ("crespeler",),
    "crespelez": ("crespeler",),
    "crespeliez": ("crespeler",),
    "crespelions": ("crespeler",),
    "crespelons": ("crespeler",),
    "crételaient": ("crételer",),
    "crételai": ("crételer",),
    "crételais": ("crételer",),
    "crételait": ("crételer",),
    "crétela": ("crételer",),
    "crételâmes": ("crételer",),
    "crételant": ("crételer",),
    "crételas": ("crételer",),
    "crételassent": ("crételer",),
    "crételasses": ("crételer",),
    "crételasse": ("crételer",),
    "crételassiez": ("crételer",),
    "crételassions": ("crételer",),
    "crételâtes": ("crételer",),
    "crételât": ("crételer",),
    "crételée": ("crételer",),
    "crételées": ("crételer",),
    "crételé": ("crételer",),
    "crételèrent": ("crételer",),
    "crételés": ("crételer",),
    "crételez": ("crételer",),
    "crételiez": ("crételer",),
    "crételions": ("crételer",),
    "crétellent": ("crételer",),
    "crételle": ("crételer",),
    "crétellera": ("crételer",),
    "crételleraient": ("crételer",),
    "crétellerai": ("crételer",),
    "crétellerais": ("crételer",),
    "crétellerait": ("crételer",),
    "crételleras": ("crételer",),
    "crétellerez": ("crételer",),
    "crételleriez": ("crételer",),
    "crétellerions": ("crételer",),
    "crétellerons": ("crételer",),
    "crételleront": ("crételer",),
    "crételles": ("crételer",),
    "crételons": ("crételer",),
    "crevassaient": ("crevasser",),
    "crevassai": ("crevasser",),
    "crevassais": ("crevasser",),
    "crevassait": ("crevasser",),
    "crevassa": ("crevasser",),
    "crevassâmes": ("crevasser",),
    "crevassant": ("crevasser",),
    "crevassas": ("crevasser",),
    "crevassassent": ("crevasser",),
    "crevassasses": ("crevasser",),
    "crevassasse": ("crevasser",),
    "crevassassiez": ("crevasser",),
    "crevassassions": ("crevasser",),
    "crevassâtes": ("crevasser",),
    "crevassât": ("crevasser",),
    "crevassée": ("crevasser",),
    "crevassées": ("crevasser",),
    "crevassé": ("crevasser",),
    "crevassent": ("crever",),
    "crevasse": ("crever",),
    "crevassera": ("crevasser",),
    "crevasseraient": ("crevasser",),
    "crevasserai": ("crevasser",),
    "crevasserais": ("crevasser",),
    "crevasserait": ("crevasser",),
    "crevasseras": ("crevasser",),
    "crevassèrent": ("crevasser",),
    "crevasserez": ("crevasser",),
    "crevasseriez": ("crevasser",),
    "crevasserions": ("crevasser",),
    "crevasserons": ("crevasser",),
    "crevasseront": ("crevasser",),
    "crevassés": ("crevasser",),
    "crevasses": ("crever",),
    "crevassez": ("crevasser",),
    "crevassiez": ("crever",),
    "crevassions": ("crever",),
    "crevassons": ("crevasser",),
    "crevaient": ("crever",),
    "crevai": ("crever",),
    "crevais": ("crever",),
    "crevait": ("crever",),
    "creva": ("crever",),
    "crevâmes": ("crever",),
    "crevant": ("crever",),
    "crevas": ("crever",),
    "crevâtes": ("crever",),
    "crevât": ("crever",),
    "crevée": ("crever",),
    "crevées": ("crever",),
    "crevé": ("crever",),
    "crèvent": ("crever",),
    "crève": ("crever",),
    "crèvera": ("crever",),
    "crèveraient": ("crever",),
    "crèverai": ("crever",),
    "crèverais": ("crever",),
    "crèverait": ("crever",),
    "crèveras": ("crever",),
    "crevèrent": ("crever",),
    "crèverez": ("crever",),
    "crèveriez": ("crever",),
    "crèverions": ("crever",),
    "crèverons": ("crever",),
    "crèveront": ("crever",),
    "crevés": ("crever",),
    "crèves": ("crever",),
    "crevez": ("crever",),
    "creviez": ("crever",),
    "crevions": ("crever",),
    "crevons": ("crever",),
    "criaient": ("crier",),
    "criai": ("crier",),
    "criais": ("crier",),
    "criait": ("crier",),
    "cria": ("crier",),
    "criâmes": ("crier",),
    "criant": ("crier",),
    "crias": ("crier",),
    "criassent": ("crier",),
    "criasses": ("crier",),
    "criasse": ("crier",),
    "criassiez": ("crier",),
    "criassions": ("crier",),
    "criâtes": ("crier",),
    "criât": ("crier",),
    "criée": ("crier",),
    "criées": ("crier",),
    "crié": ("crier",),
    "crient": ("crier",),
    "crie": ("crier",),
    "criera": ("crier",),
    "crieraient": ("crier",),
    "crierai": ("crier",),
    "crierais": ("crier",),
    "crierait": ("crier",),
    "crieras": ("crier",),
    "crièrent": ("crier",),
    "crierez": ("crier",),
    "crieriez": ("crier",),
    "crierions": ("crier",),
    "crierons": ("crier",),
    "crieront": ("crier",),
    "criés": ("crier",),
    "cries": ("crier",),
    "criez": ("crier",),
    "criiez": ("crier",),
    "criions": ("crier",),
    "crions": ("crier",),
    "croassaient": ("croasser",),
    "croassai": ("croasser",),
    "croassais": ("croasser",),
    "croassait": ("croasser",),
    "croassa": ("croasser",),
    "croassâmes": ("croasser",),
    "croassant": ("croasser",),
    "croassas": ("croasser",),
    "croassassent": ("croasser",),
    "croassasses": ("croasser",),
    "croassasse": ("croasser",),
    "croassassiez": ("croasser",),
    "croassassions": ("croasser",),
    "croassâtes": ("croasser",),
    "croassât": ("croasser",),
    "croassée": ("croasser",),
    "croassées": ("croasser",),
    "croassé": ("croasser",),
    "croassent": ("croasser",),
    "croasse": ("croasser",),
    "croassera": ("croasser",),
    "croasseraient": ("croasser",),
    "croasserai": ("croasser",),
    "croasserais": ("croasser",),
    "croasserait": ("croasser",),
    "croasseras": ("croasser",),
    "croassèrent": ("croasser",),
    "croasserez": ("croasser",),
    "croasseriez": ("croasser",),
    "croasserions": ("croasser",),
    "croasserons": ("croasser",),
    "croasseront": ("croasser",),
    "croassés": ("croasser",),
    "croasses": ("croasser",),
    "croassez": ("croasser",),
    "croassiez": ("croasser",),
    "croassions": ("croasser",),
    "croassons": ("croasser",),
    "crochetaient": ("crocheter",),
    "crochetai": ("crocheter",),
    "crochetais": ("crocheter",),
    "crochetait": ("crocheter",),
    "crocheta": ("crocheter",),
    "crochetâmes": ("crocheter",),
    "crochetant": ("crocheter",),
    "crochetas": ("crocheter",),
    "crochetassent": ("crocheter",),
    "crochetasses": ("crocheter",),
    "crochetasse": ("crocheter",),
    "crochetassiez": ("crocheter",),
    "crochetassions": ("crocheter",),
    "crochetâtes": ("crocheter",),
    "crochetât": ("crocheter",),
    "crochetée": ("crocheter",),
    "crochetées": ("crocheter",),
    "crocheté": ("crocheter",),
    "crochètent": ("crocheter",),
    "crochète": ("crocheter",),
    "crochètera": ("crocheter",),
    "crochèteraient": ("crocheter",),
    "crochèterai": ("crocheter",),
    "crochèterais": ("crocheter",),
    "crochèterait": ("crocheter",),
    "crochèteras": ("crocheter",),
    "crochetèrent": ("crocheter",),
    "crochèterez": ("crocheter",),
    "crochèteriez": ("crocheter",),
    "crochèterions": ("crocheter",),
    "crochèterons": ("crocheter",),
    "crochèteront": ("crocheter",),
    "crochetés": ("crocheter",),
    "crochètes": ("crocheter",),
    "crochetez": ("crocheter",),
    "crochetiez": ("crocheter",),
    "crochetions": ("crocheter",),
    "crochetons": ("crocheter",),
    "crochie": ("crochir",),
    "crochies": ("crochir",),
    "crochi": ("crochir",),
    "crochîmes": ("crochir",),
    "crochira": ("crochir",),
    "crochiraient": ("crochir",),
    "crochirai": ("crochir",),
    "crochirais": ("crochir",),
    "crochirait": ("crochir",),
    "crochiras": ("crochir",),
    "crochirent": ("crochir",),
    "crochirez": ("crochir",),
    "crochiriez": ("crochir",),
    "crochirions": ("crochir",),
    "crochirons": ("crochir",),
    "crochiront": ("crochir",),
    "crochis": ("crochir",),
    "crochissaient": ("crochir",),
    "crochissais": ("crochir",),
    "crochissait": ("crochir",),
    "crochissant": ("crochir",),
    "crochissent": ("crochir",),
    "crochisse": ("crochir",),
    "crochisses": ("crochir",),
    "crochissez": ("crochir",),
    "crochissiez": ("crochir",),
    "crochissions": ("crochir",),
    "crochissons": ("crochir",),
    "crochîtes": ("crochir",),
    "crochit": ("crochir",),
    "crochît": ("crochir",),
    "croient": ("croire",),
    "croie": ("croire",),
    "croies": ("croire",),
    "croira": ("croire",),
    "croiraient": ("croire",),
    "croirai": ("croire",),
    "croirais": ("croire",),
    "croirait": ("croire",),
    "croiras": ("croire",),
    "croirez": ("croire",),
    "croiriez": ("croire",),
    "croirions": ("croire",),
    "croirons": ("croire",),
    "croiront": ("croire",),
    "crois": ("croire",),
    "croit": ("croire",),
    "croyaient": ("croire",),
    "croyais": ("croire",),
    "croyait": ("croire",),
    "croyant": ("croire",),
    "croyez": ("croire",),
    "croyiez": ("croire",),
    "croyions": ("croire",),
    "croyons": ("croire",),
    "crue": ("croire",),
    "crues": ("croire",),
    "cru": ("croire",),
    "crûmes": ("croître",),
    "crurent": ("croire",),
    "crus": ("croire",),
    "crussent": ("croître",),
    "crusses": ("croître",),
    "crusse": ("croître",),
    "crussiez": ("croître",),
    "crussions": ("croître",),
    "crûtes": ("croître",),
    "crut": ("croire",),
    "crût": ("croître",),
    "croîs": ("croître",),
    "croissaient": ("croître",),
    "croissais": ("croître",),
    "croissait": ("croître",),
    "croissant": ("croître",),
    "croissent": ("croître",),
    "croisse": ("croître",),
    "croisses": ("croître",),
    "croissez": ("croître",),
    "croissiez": ("croître",),
    "croissions": ("croître",),
    "croissons": ("croître",),
    "croît": ("croître",),
    "croîtra": ("croître",),
    "croîtraient": ("croître",),
    "croîtrai": ("croître",),
    "croîtrais": ("croître",),
    "croîtrait": ("croître",),
    "croîtras": ("croître",),
    "croîtrez": ("croître",),
    "croîtriez": ("croître",),
    "croîtrions": ("croître",),
    "croîtrons": ("croître",),
    "croîtront": ("croître",),
    "crû": ("croître",),
    "crûrent": ("croître",),
    "crûs": ("croître",),
    "crûssent": ("croître",),
    "crûsses": ("croître",),
    "crûsse": ("croître",),
    "crûssiez": ("croître",),
    "crûssions": ("croître",),
    "croni": ("cronir",),
    "crôni": ("crônir",),
    "cronîmes": ("cronir",),
    "crônîmes": ("crônir",),
    "cronira": ("cronir",),
    "crônira": ("crônir",),
    "croniraient": ("cronir",),
    "crôniraient": ("crônir",),
    "cronirai": ("cronir",),
    "crônirai": ("crônir",),
    "cronirais": ("cronir",),
    "crônirais": ("crônir",),
    "cronirait": ("cronir",),
    "crônirait": ("crônir",),
    "croniras": ("cronir",),
    "crôniras": ("crônir",),
    "cronirent": ("cronir",),
    "crônirent": ("crônir",),
    "cronirez": ("cronir",),
    "crônirez": ("crônir",),
    "croniriez": ("cronir",),
    "crôniriez": ("crônir",),
    "cronirions": ("cronir",),
    "crônirions": ("crônir",),
    "cronirons": ("cronir",),
    "crônirons": ("crônir",),
    "croniront": ("cronir",),
    "crôniront": ("crônir",),
    "cronis": ("cronir",),
    "crônis": ("crônir",),
    "cronissaient": ("cronir",),
    "crônissaient": ("crônir",),
    "cronissais": ("cronir",),
    "crônissais": ("crônir",),
    "cronissait": ("cronir",),
    "crônissait": ("crônir",),
    "cronissant": ("cronir",),
    "crônissant": ("crônir",),
    "cronissent": ("cronir",),
    "crônissent": ("crônir",),
    "cronisse": ("cronir",),
    "crônisse": ("crônir",),
    "cronisses": ("cronir",),
    "crônisses": ("crônir",),
    "cronissez": ("cronir",),
    "crônissez": ("crônir",),
    "cronissiez": ("cronir",),
    "crônissiez": ("crônir",),
    "cronissions": ("cronir",),
    "crônissions": ("crônir",),
    "cronissons": ("cronir",),
    "crônissons": ("crônir",),
    "cronîtes": ("cronir",),
    "crônîtes": ("crônir",),
    "cronit": ("cronir",),
    "crônit": ("crônir",),
    "cronît": ("cronir",),
    "crônît": ("crônir",),
    "croupi": ("croupir",),
    "croupîmes": ("croupir",),
    "croupira": ("croupir",),
    "croupiraient": ("croupir",),
    "croupirai": ("croupir",),
    "croupirais": ("croupir",),
    "croupirait": ("croupir",),
    "croupiras": ("croupir",),
    "croupirent": ("croupir",),
    "croupirez": ("croupir",),
    "croupiriez": ("croupir",),
    "croupirions": ("croupir",),
    "croupirons": ("croupir",),
    "croupiront": ("croupir",),
    "croupis": ("croupir",),
    "croupissaient": ("croupir",),
    "croupissais": ("croupir",),
    "croupissait": ("croupir",),
    "croupissant": ("croupir",),
    "croupissent": ("croupir",),
    "croupisse": ("croupir",),
    "croupisses": ("croupir",),
    "croupissez": ("croupir",),
    "croupissiez": ("croupir",),
    "croupissions": ("croupir",),
    "croupissons": ("croupir",),
    "croupîtes": ("croupir",),
    "croupit": ("croupir",),
    "croupît": ("croupir",),
    "crucifiaient": ("crucifier",),
    "crucifiai": ("crucifier",),
    "crucifiais": ("crucifier",),
    "crucifiait": ("crucifier",),
    "crucifia": ("crucifier",),
    "crucifiâmes": ("crucifier",),
    "crucifiant": ("crucifier",),
    "crucifias": ("crucifier",),
    "crucifiassent": ("crucifier",),
    "crucifiasses": ("crucifier",),
    "crucifiasse": ("crucifier",),
    "crucifiassiez": ("crucifier",),
    "crucifiassions": ("crucifier",),
    "crucifiâtes": ("crucifier",),
    "crucifiât": ("crucifier",),
    "crucifiée": ("crucifier",),
    "crucifiées": ("crucifier",),
    "crucifié": ("crucifier",),
    "crucifient": ("crucifier",),
    "crucifie": ("crucifier",),
    "crucifiera": ("crucifier",),
    "crucifieraient": ("crucifier",),
    "crucifierai": ("crucifier",),
    "crucifierais": ("crucifier",),
    "crucifierait": ("crucifier",),
    "crucifieras": ("crucifier",),
    "crucifièrent": ("crucifier",),
    "crucifierez": ("crucifier",),
    "crucifieriez": ("crucifier",),
    "crucifierions": ("crucifier",),
    "crucifierons": ("crucifier",),
    "crucifieront": ("crucifier",),
    "crucifiés": ("crucifier",),
    "crucifies": ("crucifier",),
    "crucifiez": ("crucifier",),
    "crucifiiez": ("crucifier",),
    "crucifiions": ("crucifier",),
    "crucifions": ("crucifier",),
    "cryobroient": ("cryobroyer",),
    "cryobroie": ("cryobroyer",),
    "cryobroiera": ("cryobroyer",),
    "cryobroieraient": ("cryobroyer",),
    "cryobroierai": ("cryobroyer",),
    "cryobroierais": ("cryobroyer",),
    "cryobroierait": ("cryobroyer",),
    "cryobroieras": ("cryobroyer",),
    "cryobroierez": ("cryobroyer",),
    "cryobroieriez": ("cryobroyer",),
    "cryobroierions": ("cryobroyer",),
    "cryobroierons": ("cryobroyer",),
    "cryobroieront": ("cryobroyer",),
    "cryobroies": ("cryobroyer",),
    "cryobroyaient": ("cryobroyer",),
    "cryobroyai": ("cryobroyer",),
    "cryobroyais": ("cryobroyer",),
    "cryobroyait": ("cryobroyer",),
    "cryobroya": ("cryobroyer",),
    "cryobroyâmes": ("cryobroyer",),
    "cryobroyant": ("cryobroyer",),
    "cryobroyas": ("cryobroyer",),
    "cryobroyassent": ("cryobroyer",),
    "cryobroyasses": ("cryobroyer",),
    "cryobroyasse": ("cryobroyer",),
    "cryobroyassiez": ("cryobroyer",),
    "cryobroyassions": ("cryobroyer",),
    "cryobroyâtes": ("cryobroyer",),
    "cryobroyât": ("cryobroyer",),
    "cryobroyée": ("cryobroyer",),
    "cryobroyées": ("cryobroyer",),
    "cryobroyé": ("cryobroyer",),
    "cryobroyèrent": ("cryobroyer",),
    "cryobroyés": ("cryobroyer",),
    "cryobroyez": ("cryobroyer",),
    "cryobroyiez": ("cryobroyer",),
    "cryobroyions": ("cryobroyer",),
    "cryobroyons": ("cryobroyer",),
    "cryoextraient": ("cryoextraire",),
    "cryoextraie": ("cryoextraire",),
    "cryoextraies": ("cryoextraire",),
    "cryoextraira": ("cryoextraire",),
    "cryoextrairaient": ("cryoextraire",),
    "cryoextrairai": ("cryoextraire",),
    "cryoextrairais": ("cryoextraire",),
    "cryoextrairait": ("cryoextraire",),
    "cryoextrairas": ("cryoextraire",),
    "cryoextrairez": ("cryoextraire",),
    "cryoextrairiez": ("cryoextraire",),
    "cryoextrairions": ("cryoextraire",),
    "cryoextrairons": ("cryoextraire",),
    "cryoextrairont": ("cryoextraire",),
    "cryoextrais": ("cryoextraire",),
    "cryoextraite": ("cryoextraire",),
    "cryoextraites": ("cryoextraire",),
    "cryoextrait": ("cryoextraire",),
    "cryoextraits": ("cryoextraire",),
    "cryoextrayaient": ("cryoextraire",),
    "cryoextrayais": ("cryoextraire",),
    "cryoextrayait": ("cryoextraire",),
    "cryoextrayant": ("cryoextraire",),
    "cryoextrayez": ("cryoextraire",),
    "cryoextrayiez": ("cryoextraire",),
    "cryoextrayions": ("cryoextraire",),
    "cryoextrayons": ("cryoextraire",),
    "cryomassaient": ("cryomasser",),
    "cryomassai": ("cryomasser",),
    "cryomassais": ("cryomasser",),
    "cryomassait": ("cryomasser",),
    "cryomassa": ("cryomasser",),
    "cryomassâmes": ("cryomasser",),
    "cryomassant": ("cryomasser",),
    "cryomassas": ("cryomasser",),
    "cryomassassent": ("cryomasser",),
    "cryomassasses": ("cryomasser",),
    "cryomassasse": ("cryomasser",),
    "cryomassassiez": ("cryomasser",),
    "cryomassassions": ("cryomasser",),
    "cryomassâtes": ("cryomasser",),
    "cryomassât": ("cryomasser",),
    "cryomassée": ("cryomasser",),
    "cryomassées": ("cryomasser",),
    "cryomassé": ("cryomasser",),
    "cryomassent": ("cryomasser",),
    "cryomasse": ("cryomasser",),
    "cryomassera": ("cryomasser",),
    "cryomasseraient": ("cryomasser",),
    "cryomasserai": ("cryomasser",),
    "cryomasserais": ("cryomasser",),
    "cryomasserait": ("cryomasser",),
    "cryomasseras": ("cryomasser",),
    "cryomassèrent": ("cryomasser",),
    "cryomasserez": ("cryomasser",),
    "cryomasseriez": ("cryomasser",),
    "cryomasserions": ("cryomasser",),
    "cryomasserons": ("cryomasser",),
    "cryomasseront": ("cryomasser",),
    "cryomassés": ("cryomasser",),
    "cryomasses": ("cryomasser",),
    "cryomassez": ("cryomasser",),
    "cryomassiez": ("cryomasser",),
    "cryomassions": ("cryomasser",),
    "cryomassons": ("cryomasser",),
    "cryptographiaient": ("cryptographier",),
    "cryptographiai": ("cryptographier",),
    "cryptographiais": ("cryptographier",),
    "cryptographiait": ("cryptographier",),
    "cryptographia": ("cryptographier",),
    "cryptographiâmes": ("cryptographier",),
    "cryptographiant": ("cryptographier",),
    "cryptographias": ("cryptographier",),
    "cryptographiassent": ("cryptographier",),
    "cryptographiasses": ("cryptographier",),
    "cryptographiasse": ("cryptographier",),
    "cryptographiassiez": ("cryptographier",),
    "cryptographiassions": ("cryptographier",),
    "cryptographiâtes": ("cryptographier",),
    "cryptographiât": ("cryptographier",),
    "cryptographiée": ("cryptographier",),
    "cryptographiées": ("cryptographier",),
    "cryptographié": ("cryptographier",),
    "cryptographient": ("cryptographier",),
    "cryptographie": ("cryptographier",),
    "cryptographiera": ("cryptographier",),
    "cryptographieraient": ("cryptographier",),
    "cryptographierai": ("cryptographier",),
    "cryptographierais": ("cryptographier",),
    "cryptographierait": ("cryptographier",),
    "cryptographieras": ("cryptographier",),
    "cryptographièrent": ("cryptographier",),
    "cryptographierez": ("cryptographier",),
    "cryptographieriez": ("cryptographier",),
    "cryptographierions": ("cryptographier",),
    "cryptographierons": ("cryptographier",),
    "cryptographieront": ("cryptographier",),
    "cryptographiés": ("cryptographier",),
    "cryptographies": ("cryptographier",),
    "cryptographiez": ("cryptographier",),
    "cryptographiiez": ("cryptographier",),
    "cryptographiions": ("cryptographier",),
    "cryptographions": ("cryptographier",),
    "cueillaient": ("cueillir",),
    "cueillais": ("cueillir",),
    "cueillait": ("cueillir",),
    "cueillant": ("cueillir",),
    "cueillent": ("cueillir",),
    "cueille": ("cueillir",),
    "cueillera": ("cueillir",),
    "cueilleraient": ("cueillir",),
    "cueillerai": ("cueillir",),
    "cueillerais": ("cueillir",),
    "cueillerait": ("cueillir",),
    "cueilleras": ("cueillir",),
    "cueillerez": ("cueillir",),
    "cueilleriez": ("cueillir",),
    "cueillerions": ("cueillir",),
    "cueillerons": ("cueillir",),
    "cueilleront": ("cueillir",),
    "cueilles": ("cueillir",),
    "cueillez": ("cueillir",),
    "cueillie": ("cueillir",),
    "cueillies": ("cueillir",),
    "cueilliez": ("cueillir",),
    "cueilli": ("cueillir",),
    "cueillîmes": ("cueillir",),
    "cueillions": ("cueillir",),
    "cueillirent": ("cueillir",),
    "cueillis": ("cueillir",),
    "cueillissent": ("cueillir",),
    "cueillisses": ("cueillir",),
    "cueillisse": ("cueillir",),
    "cueillissiez": ("cueillir",),
    "cueillissions": ("cueillir",),
    "cueillîtes": ("cueillir",),
    "cueillit": ("cueillir",),
    "cueillît": ("cueillir",),
    "cueillons": ("cueillir",),
    "cuirassaient": ("cuirasser",),
    "cuirassai": ("cuirasser",),
    "cuirassais": ("cuirasser",),
    "cuirassait": ("cuirasser",),
    "cuirassa": ("cuirasser",),
    "cuirassâmes": ("cuirasser",),
    "cuirassant": ("cuirasser",),
    "cuirassas": ("cuirasser",),
    "cuirassassent": ("cuirasser",),
    "cuirassasses": ("cuirasser",),
    "cuirassasse": ("cuirasser",),
    "cuirassassiez": ("cuirasser",),
    "cuirassassions": ("cuirasser",),
    "cuirassâtes": ("cuirasser",),
    "cuirassât": ("cuirasser",),
    "cuirassée": ("cuirasser",),
    "cuirassées": ("cuirasser",),
    "cuirassé": ("cuirasser",),
    "cuirassent": ("cuirasser",),
    "cuirasse": ("cuirasser",),
    "cuirassera": ("cuirasser",),
    "cuirasseraient": ("cuirasser",),
    "cuirasserai": ("cuirasser",),
    "cuirasserais": ("cuirasser",),
    "cuirasserait": ("cuirasser",),
    "cuirasseras": ("cuirasser",),
    "cuirassèrent": ("cuirasser",),
    "cuirasserez": ("cuirasser",),
    "cuirasseriez": ("cuirasser",),
    "cuirasserions": ("cuirasser",),
    "cuirasserons": ("cuirasser",),
    "cuirasseront": ("cuirasser",),
    "cuirassés": ("cuirasser",),
    "cuirasses": ("cuirasser",),
    "cuirassez": ("cuirasser",),
    "cuirassiez": ("cuirasser",),
    "cuirassions": ("cuirasser",),
    "cuirassons": ("cuirasser",),
    "cuira": ("cuire",),
    "cuiraient": ("cuire",),
    "cuirai": ("cuire",),
    "cuirais": ("cuire",),
    "cuirait": ("cuire",),
    "cuiras": ("cuire",),
    "cuirez": ("cuire",),
    "cuiriez": ("cuire",),
    "cuirions": ("cuire",),
    "cuirons": ("cuire",),
    "cuiront": ("cuire",),
    "cuisaient": ("cuire",),
    "cuisais": ("cuire",),
    "cuisait": ("cuire",),
    "cuisant": ("cuire",),
    "cuisent": ("cuire",),
    "cuise": ("cuire",),
    "cuises": ("cuire",),
    "cuisez": ("cuire",),
    "cuisiez": ("cuire",),
    "cuisîmes": ("cuire",),
    "cuisions": ("cuire",),
    "cuisirent": ("cuire",),
    "cuisis": ("cuire",),
    "cuisissent": ("cuire",),
    "cuisisses": ("cuire",),
    "cuisisse": ("cuire",),
    "cuisissiez": ("cuire",),
    "cuisissions": ("cuire",),
    "cuisîtes": ("cuire",),
    "cuisit": ("cuire",),
    "cuisît": ("cuire",),
    "cuisons": ("cuire",),
    "cuis": ("cuire",),
    "cuite": ("cuire",),
    "cuites": ("cuire",),
    "cuit": ("cuire",),
    "cuits": ("cuire",),
    "culassaient": ("culasser",),
    "culassai": ("culasser",),
    "culassais": ("culasser",),
    "culassait": ("culasser",),
    "culassa": ("culasser",),
    "culassâmes": ("culasser",),
    "culassant": ("culasser",),
    "culassas": ("culasser",),
    "culassassent": ("culasser",),
    "culassasses": ("culasser",),
    "culassasse": ("culasser",),
    "culassassiez": ("culasser",),
    "culassassions": ("culasser",),
    "culassâtes": ("culasser",),
    "culassât": ("culasser",),
    "culassée": ("culasser",),
    "culassées": ("culasser",),
    "culassé": ("culasser",),
    "culassent": ("culasser",),
    "culasse": ("culasser",),
    "culassera": ("culasser",),
    "culasseraient": ("culasser",),
    "culasserai": ("culasser",),
    "culasserais": ("culasser",),
    "culasserait": ("culasser",),
    "culasseras": ("culasser",),
    "culassèrent": ("culasser",),
    "culasserez": ("culasser",),
    "culasseriez": ("culasser",),
    "culasserions": ("culasser",),
    "culasserons": ("culasser",),
    "culasseront": ("culasser",),
    "culassés": ("culasser",),
    "culasses": ("culasser",),
    "culassez": ("culasser",),
    "culassiez": ("culasser",),
    "culassions": ("culasser",),
    "culassons": ("culasser",),
    "curetaient": ("cureter",),
    "curetai": ("cureter",),
    "curetais": ("cureter",),
    "curetait": ("cureter",),
    "cureta": ("cureter",),
    "curetâmes": ("cureter",),
    "curetant": ("cureter",),
    "curetas": ("cureter",),
    "curetassent": ("cureter",),
    "curetasses": ("cureter",),
    "curetasse": ("cureter",),
    "curetassiez": ("cureter",),
    "curetassions": ("cureter",),
    "curetâtes": ("cureter",),
    "curetât": ("cureter",),
    "curetée": ("cureter",),
    "curetées": ("cureter",),
    "cureté": ("cureter",),
    "curetèrent": ("cureter",),
    "curetés": ("cureter",),
    "curetez": ("cureter",),
    "curetiez": ("cureter",),
    "curetions": ("cureter",),
    "curetons": ("cureter",),
    "curettent": ("cureter",),
    "curette": ("cureter",),
    "curettera": ("cureter",),
    "curetteraient": ("cureter",),
    "curetterai": ("cureter",),
    "curetterais": ("cureter",),
    "curetterait": ("cureter",),
    "curetteras": ("cureter",),
    "curetterez": ("cureter",),
    "curetteriez": ("cureter",),
    "curetterions": ("cureter",),
    "curetterons": ("cureter",),
    "curetteront": ("cureter",),
    "curettes": ("cureter",),
    "cuvelaient": ("cuveler",),
    "cuvelai": ("cuveler",),
    "cuvelais": ("cuveler",),
    "cuvelait": ("cuveler",),
    "cuvela": ("cuveler",),
    "cuvelâmes": ("cuveler",),
    "cuvelant": ("cuveler",),
    "cuvelas": ("cuveler",),
    "cuvelassent": ("cuveler",),
    "cuvelasses": ("cuveler",),
    "cuvelasse": ("cuveler",),
    "cuvelassiez": ("cuveler",),
    "cuvelassions": ("cuveler",),
    "cuvelâtes": ("cuveler",),
    "cuvelât": ("cuveler",),
    "cuvelée": ("cuveler",),
    "cuvelées": ("cuveler",),
    "cuvelé": ("cuveler",),
    "cuvelèrent": ("cuveler",),
    "cuvelés": ("cuveler",),
    "cuvelez": ("cuveler",),
    "cuveliez": ("cuveler",),
    "cuvelions": ("cuveler",),
    "cuvellent": ("cuveler",),
    "cuvelle": ("cuveler",),
    "cuvellera": ("cuveler",),
    "cuvelleraient": ("cuveler",),
    "cuvellerai": ("cuveler",),
    "cuvellerais": ("cuveler",),
    "cuvellerait": ("cuveler",),
    "cuvelleras": ("cuveler",),
    "cuvellerez": ("cuveler",),
    "cuvelleriez": ("cuveler",),
    "cuvellerions": ("cuveler",),
    "cuvellerons": ("cuveler",),
    "cuvelleront": ("cuveler",),
    "cuvelles": ("cuveler",),
    "cuvelons": ("cuveler",),
    "dactylographiaient": ("dactylographier",),
    "dactylographiai": ("dactylographier",),
    "dactylographiais": ("dactylographier",),
    "dactylographiait": ("dactylographier",),
    "dactylographia": ("dactylographier",),
    "dactylographiâmes": ("dactylographier",),
    "dactylographiant": ("dactylographier",),
    "dactylographias": ("dactylographier",),
    "dactylographiassent": ("dactylographier",),
    "dactylographiasses": ("dactylographier",),
    "dactylographiasse": ("dactylographier",),
    "dactylographiassiez": ("dactylographier",),
    "dactylographiassions": ("dactylographier",),
    "dactylographiâtes": ("dactylographier",),
    "dactylographiât": ("dactylographier",),
    "dactylographiée": ("dactylographier",),
    "dactylographiées": ("dactylographier",),
    "dactylographié": ("dactylographier",),
    "dactylographient": ("dactylographier",),
    "dactylographie": ("dactylographier",),
    "dactylographiera": ("dactylographier",),
    "dactylographieraient": ("dactylographier",),
    "dactylographierai": ("dactylographier",),
    "dactylographierais": ("dactylographier",),
    "dactylographierait": ("dactylographier",),
    "dactylographieras": ("dactylographier",),
    "dactylographièrent": ("dactylographier",),
    "dactylographierez": ("dactylographier",),
    "dactylographieriez": ("dactylographier",),
    "dactylographierions": ("dactylographier",),
    "dactylographierons": ("dactylographier",),
    "dactylographieront": ("dactylographier",),
    "dactylographiés": ("dactylographier",),
    "dactylographies": ("dactylographier",),
    "dactylographiez": ("dactylographier",),
    "dactylographiiez": ("dactylographier",),
    "dactylographiions": ("dactylographier",),
    "dactylographions": ("dactylographier",),
    "damassaient": ("damasser",),
    "damassai": ("damasser",),
    "damassais": ("damasser",),
    "damassait": ("damasser",),
    "damassa": ("damasser",),
    "damassâmes": ("damasser",),
    "damassant": ("damasser",),
    "damassas": ("damasser",),
    "damassassent": ("damasser",),
    "damassasses": ("damasser",),
    "damassasse": ("damasser",),
    "damassassiez": ("damasser",),
    "damassassions": ("damasser",),
    "damassâtes": ("damasser",),
    "damassât": ("damasser",),
    "damassée": ("damasser",),
    "damassées": ("damasser",),
    "damassé": ("damasser",),
    "damassent": ("damasser",),
    "damasse": ("damasser",),
    "damassera": ("damasser",),
    "damasseraient": ("damasser",),
    "damasserai": ("damasser",),
    "damasserais": ("damasser",),
    "damasserait": ("damasser",),
    "damasseras": ("damasser",),
    "damassèrent": ("damasser",),
    "damasserez": ("damasser",),
    "damasseriez": ("damasser",),
    "damasserions": ("damasser",),
    "damasserons": ("damasser",),
    "damasseront": ("damasser",),
    "damassés": ("damasser",),
    "damasses": ("damasser",),
    "damassez": ("damasser",),
    "damassiez": ("damasser",),
    "damassions": ("damasser",),
    "damassons": ("damasser",),
    "débalançaient": ("débalancer",),
    "débalançai": ("débalancer",),
    "débalançais": ("débalancer",),
    "débalançait": ("débalancer",),
    "débalança": ("débalancer",),
    "débalançâmes": ("débalancer",),
    "débalançant": ("débalancer",),
    "débalanças": ("débalancer",),
    "débalançassent": ("débalancer",),
    "débalançasses": ("débalancer",),
    "débalançasse": ("débalancer",),
    "débalançassiez": ("débalancer",),
    "débalançassions": ("débalancer",),
    "débalançâtes": ("débalancer",),
    "débalançât": ("débalancer",),
    "débalancée": ("débalancer",),
    "débalancées": ("débalancer",),
    "débalancé": ("débalancer",),
    "débalancent": ("débalancer",),
    "débalance": ("débalancer",),
    "débalancera": ("débalancer",),
    "débalanceraient": ("débalancer",),
    "débalancerai": ("débalancer",),
    "débalancerais": ("débalancer",),
    "débalancerait": ("débalancer",),
    "débalanceras": ("débalancer",),
    "débalancèrent": ("débalancer",),
    "débalancerez": ("débalancer",),
    "débalanceriez": ("débalancer",),
    "débalancerions": ("débalancer",),
    "débalancerons": ("débalancer",),
    "débalanceront": ("débalancer",),
    "débalancés": ("débalancer",),
    "débalances": ("débalancer",),
    "débalancez": ("débalancer",),
    "débalanciez": ("débalancer",),
    "débalancions": ("débalancer",),
    "débalançons": ("débalancer",),
    "débarrassaient": ("débarrasser",),
    "débarrassai": ("débarrasser",),
    "débarrassais": ("débarrasser",),
    "débarrassait": ("débarrasser",),
    "débarrassa": ("débarrasser",),
    "débarrassâmes": ("débarrasser",),
    "débarrassant": ("débarrasser",),
    "débarrassas": ("débarrasser",),
    "débarrassassent": ("débarrasser",),
    "débarrassasses": ("débarrasser",),
    "débarrassasse": ("débarrasser",),
    "débarrassassiez": ("débarrasser",),
    "débarrassassions": ("débarrasser",),
    "débarrassâtes": ("débarrasser",),
    "débarrassât": ("débarrasser",),
    "débarrassée": ("débarrasser",),
    "débarrassées": ("débarrasser",),
    "débarrassé": ("débarrasser",),
    "débarrassent": ("débarrasser",),
    "débarrasse": ("débarrasser",),
    "débarrassera": ("débarrasser",),
    "débarrasseraient": ("débarrasser",),
    "débarrasserai": ("débarrasser",),
    "débarrasserais": ("débarrasser",),
    "débarrasserait": ("débarrasser",),
    "débarrasseras": ("débarrasser",),
    "débarrassèrent": ("débarrasser",),
    "débarrasserez": ("débarrasser",),
    "débarrasseriez": ("débarrasser",),
    "débarrasserions": ("débarrasser",),
    "débarrasserons": ("débarrasser",),
    "débarrasseront": ("débarrasser",),
    "débarrassés": ("débarrasser",),
    "débarrasses": ("débarrasser",),
    "débarrassez": ("débarrasser",),
    "débarrassiez": ("débarrasser",),
    "débarrassions": ("débarrasser",),
    "débarrassons": ("débarrasser",),
    "débâtaient": ("débâter",),
    "débâtai": ("débâter",),
    "débâtais": ("débâter",),
    "débâtait": ("débâter",),
    "débâta": ("débâter",),
    "débâtâmes": ("débâter",),
    "débâtant": ("débâter",),
    "débâtas": ("débâter",),
    "débâtassent": ("débâter",),
    "débâtasses": ("débâter",),
    "débâtasse": ("débâter",),
    "débâtassiez": ("débâter",),
    "débâtassions": ("débâter",),
    "débâtâtes": ("débâter",),
    "débâtât": ("débâter",),
    "débâtée": ("débâter",),
    "débâtées": ("débâter",),
    "débâté": ("débâter",),
    "débâtent": ("débâter",),
    "débâte": ("débâter",),
    "débâtera": ("débâter",),
    "débâteraient": ("débâter",),
    "débâterai": ("débâter",),
    "débâterais": ("débâter",),
    "débâterait": ("débâter",),
    "débâteras": ("débâter",),
    "débâtèrent": ("débâter",),
    "débâterez": ("débâter",),
    "débâteriez": ("débâter",),
    "débâterions": ("débâter",),
    "débâterons": ("débâter",),
    "débâteront": ("débâter",),
    "débâtés": ("débâter",),
    "débâtes": ("débâter",),
    "débâtez": ("débâter",),
    "débâtiez": ("débâter",),
    "débâtions": ("débâter",),
    "débâtons": ("débâter",),
    "débâtie": ("débâtir",),
    "débâties": ("débâtir",),
    "débâti": ("débâtir",),
    "débâtîmes": ("débâtir",),
    "débâtira": ("débâtir",),
    "débâtiraient": ("débâtir",),
    "débâtirai": ("débâtir",),
    "débâtirais": ("débâtir",),
    "débâtirait": ("débâtir",),
    "débâtiras": ("débâtir",),
    "débâtirent": ("débâtir",),
    "débâtirez": ("débâtir",),
    "débâtiriez": ("débâtir",),
    "débâtirions": ("débâtir",),
    "débâtirons": ("débâtir",),
    "débâtiront": ("débâtir",),
    "débâtis": ("débâtir",),
    "débâtissaient": ("débâtir",),
    "débâtissais": ("débâtir",),
    "débâtissait": ("débâtir",),
    "débâtissant": ("débâtir",),
    "débâtissent": ("débâtir",),
    "débâtisse": ("débâtir",),
    "débâtisses": ("débâtir",),
    "débâtissez": ("débâtir",),
    "débâtissiez": ("débâtir",),
    "débâtissions": ("débâtir",),
    "débâtissons": ("débâtir",),
    "débâtîtes": ("débâtir",),
    "débâtit": ("débâtir",),
    "débâtît": ("débâtir",),
    "débat": ("débattre",),
    "débats": ("débattre",),
    "débattaient": ("débattre",),
    "débattais": ("débattre",),
    "débattait": ("débattre",),
    "débattant": ("débattre",),
    "débattent": ("débattre",),
    "débatte": ("débattre",),
    "débattes": ("débattre",),
    "débattez": ("débattre",),
    "débattiez": ("débattre",),
    "débattîmes": ("débattre",),
    "débattions": ("débattre",),
    "débattirent": ("débattre",),
    "débattis": ("débattre",),
    "débattissent": ("débattre",),
    "débattisses": ("débattre",),
    "débattisse": ("débattre",),
    "débattissiez": ("débattre",),
    "débattissions": ("débattre",),
    "débattîtes": ("débattre",),
    "débattit": ("débattre",),
    "débattît": ("débattre",),
    "débattons": ("débattre",),
    "débattra": ("débattre",),
    "débattraient": ("débattre",),
    "débattrai": ("débattre",),
    "débattrais": ("débattre",),
    "débattrait": ("débattre",),
    "débattras": ("débattre",),
    "débattrez": ("débattre",),
    "débattriez": ("débattre",),
    "débattrions": ("débattre",),
    "débattrons": ("débattre",),
    "débattront": ("débattre",),
    "débattue": ("débattre",),
    "débattues": ("débattre",),
    "débattu": ("débattre",),
    "débattus": ("débattre",),
    "débaugeaient": ("débauger",),
    "débaugeai": ("débauger",),
    "débaugeais": ("débauger",),
    "débaugeait": ("débauger",),
    "débaugea": ("débauger",),
    "débaugeâmes": ("débauger",),
    "débaugeant": ("débauger",),
    "débaugeas": ("débauger",),
    "débaugeassent": ("débauger",),
    "débaugeasses": ("débauger",),
    "débaugeasse": ("débauger",),
    "débaugeassiez": ("débauger",),
    "débaugeassions": ("débauger",),
    "débaugeâtes": ("débauger",),
    "débaugeât": ("débauger",),
    "débaugée": ("débauger",),
    "débaugées": ("débauger",),
    "débaugé": ("débauger",),
    "débaugent": ("débauger",),
    "débaugeons": ("débauger",),
    "débauge": ("débauger",),
    "débaugera": ("débauger",),
    "débaugeraient": ("débauger",),
    "débaugerai": ("débauger",),
    "débaugerais": ("débauger",),
    "débaugerait": ("débauger",),
    "débaugeras": ("débauger",),
    "débaugèrent": ("débauger",),
    "débaugerez": ("débauger",),
    "débaugeriez": ("débauger",),
    "débaugerions": ("débauger",),
    "débaugerons": ("débauger",),
    "débaugeront": ("débauger",),
    "débaugés": ("débauger",),
    "débauges": ("débauger",),
    "débaugez": ("débauger",),
    "débaugiez": ("débauger",),
    "débaugions": ("débauger",),
    "débéquetaient": ("débéqueter",),
    "débéquetai": ("débéqueter",),
    "débéquetais": ("débéqueter",),
    "débéquetait": ("débéqueter",),
    "débéqueta": ("débéqueter",),
    "débéquetâmes": ("débéqueter",),
    "débéquetant": ("débéqueter",),
    "débéquetas": ("débéqueter",),
    "débéquetassent": ("débéqueter",),
    "débéquetasses": ("débéqueter",),
    "débéquetasse": ("débéqueter",),
    "débéquetassiez": ("débéqueter",),
    "débéquetassions": ("débéqueter",),
    "débéquetâtes": ("débéqueter",),
    "débéquetât": ("débéqueter",),
    "débéquetée": ("débéqueter",),
    "débéquetées": ("débéqueter",),
    "débéqueté": ("débéqueter",),
    "débéquetèrent": ("débéqueter",),
    "débéquetés": ("débéqueter",),
    "débéquetez": ("débéqueter",),
    "débéquetiez": ("débéqueter",),
    "débéquetions": ("débéqueter",),
    "débéquetons": ("débéqueter",),
    "débéquettent": ("débéqueter",),
    "débéquette": ("débéqueter",),
    "débéquettera": ("débéqueter",),
    "débéquetteraient": ("débéqueter",),
    "débéquetterai": ("débéqueter",),
    "débéquetterais": ("débéqueter",),
    "débéquetterait": ("débéqueter",),
    "débéquetteras": ("débéqueter",),
    "débéquetterez": ("débéqueter",),
    "débéquetteriez": ("débéqueter",),
    "débéquetterions": ("débéqueter",),
    "débéquetterons": ("débéqueter",),
    "débéquetteront": ("débéqueter",),
    "débéquettes": ("débéqueter",),
    "débêtie": ("débêtir",),
    "débêties": ("débêtir",),
    "débêti": ("débêtir",),
    "débêtîmes": ("débêtir",),
    "débêtira": ("débêtir",),
    "débêtiraient": ("débêtir",),
    "débêtirai": ("débêtir",),
    "débêtirais": ("débêtir",),
    "débêtirait": ("débêtir",),
    "débêtiras": ("débêtir",),
    "débêtirent": ("débêtir",),
    "débêtirez": ("débêtir",),
    "débêtiriez": ("débêtir",),
    "débêtirions": ("débêtir",),
    "débêtirons": ("débêtir",),
    "débêtiront": ("débêtir",),
    "débêtis": ("débêtir",),
    "débêtissaient": ("débêtir",),
    "débêtissais": ("débêtir",),
    "débêtissait": ("débêtir",),
    "débêtissant": ("débêtir",),
    "débêtissent": ("débêtir",),
    "débêtisse": ("débêtir",),
    "débêtisses": ("débêtir",),
    "débêtissez": ("débêtir",),
    "débêtissiez": ("débêtir",),
    "débêtissions": ("débêtir",),
    "débêtissons": ("débêtir",),
    "débêtîtes": ("débêtir",),
    "débêtit": ("débêtir",),
    "débêtît": ("débêtir",),
    "déblanchie": ("déblanchir",),
    "déblanchies": ("déblanchir",),
    "déblanchi": ("déblanchir",),
    "déblanchîmes": ("déblanchir",),
    "déblanchira": ("déblanchir",),
    "déblanchiraient": ("déblanchir",),
    "déblanchirai": ("déblanchir",),
    "déblanchirais": ("déblanchir",),
    "déblanchirait": ("déblanchir",),
    "déblanchiras": ("déblanchir",),
    "déblanchirent": ("déblanchir",),
    "déblanchirez": ("déblanchir",),
    "déblanchiriez": ("déblanchir",),
    "déblanchirions": ("déblanchir",),
    "déblanchirons": ("déblanchir",),
    "déblanchiront": ("déblanchir",),
    "déblanchis": ("déblanchir",),
    "déblanchissaient": ("déblanchir",),
    "déblanchissais": ("déblanchir",),
    "déblanchissait": ("déblanchir",),
    "déblanchissant": ("déblanchir",),
    "déblanchissent": ("déblanchir",),
    "déblanchisse": ("déblanchir",),
    "déblanchisses": ("déblanchir",),
    "déblanchissez": ("déblanchir",),
    "déblanchissiez": ("déblanchir",),
    "déblanchissions": ("déblanchir",),
    "déblanchissons": ("déblanchir",),
    "déblanchîtes": ("déblanchir",),
    "déblanchit": ("déblanchir",),
    "déblanchît": ("déblanchir",),
    "déblatéraient": ("déblatérer",),
    "déblatérai": ("déblatérer",),
    "déblatérais": ("déblatérer",),
    "déblatérait": ("déblatérer",),
    "déblatéra": ("déblatérer",),
    "déblatérâmes": ("déblatérer",),
    "déblatérant": ("déblatérer",),
    "déblatéras": ("déblatérer",),
    "déblatérassent": ("déblatérer",),
    "déblatérasses": ("déblatérer",),
    "déblatérasse": ("déblatérer",),
    "déblatérassiez": ("déblatérer",),
    "déblatérassions": ("déblatérer",),
    "déblatérâtes": ("déblatérer",),
    "déblatérât": ("déblatérer",),
    "déblatéré": ("déblatérer",),
    "déblatèrent": ("déblatérer",),
    "déblatère": ("déblatérer",),
    "déblatérera": ("déblatérer",),
    "déblatéreraient": ("déblatérer",),
    "déblatérerai": ("déblatérer",),
    "déblatérerais": ("déblatérer",),
    "déblatérerait": ("déblatérer",),
    "déblatéreras": ("déblatérer",),
    "déblatérèrent": ("déblatérer",),
    "déblatérerez": ("déblatérer",),
    "déblatéreriez": ("déblatérer",),
    "déblatérerions": ("déblatérer",),
    "déblatérerons": ("déblatérer",),
    "déblatéreront": ("déblatérer",),
    "déblatères": ("déblatérer",),
    "déblatérez": ("déblatérer",),
    "déblatériez": ("déblatérer",),
    "déblatérions": ("déblatérer",),
    "déblatérons": ("déblatérer",),
    "déblaient": ("déblayer",),
    "déblaie": ("déblayer",),
    "déblaiera": ("déblayer",),
    "déblaieraient": ("déblayer",),
    "déblaierai": ("déblayer",),
    "déblaierais": ("déblayer",),
    "déblaierait": ("déblayer",),
    "déblaieras": ("déblayer",),
    "déblaierez": ("déblayer",),
    "déblaieriez": ("déblayer",),
    "déblaierions": ("déblayer",),
    "déblaierons": ("déblayer",),
    "déblaieront": ("déblayer",),
    "déblaies": ("déblayer",),
    "déblayaient": ("déblayer",),
    "déblayai": ("déblayer",),
    "déblayais": ("déblayer",),
    "déblayait": ("déblayer",),
    "déblaya": ("déblayer",),
    "déblayâmes": ("déblayer",),
    "déblayant": ("déblayer",),
    "déblayas": ("déblayer",),
    "déblayassent": ("déblayer",),
    "déblayasses": ("déblayer",),
    "déblayasse": ("déblayer",),
    "déblayassiez": ("déblayer",),
    "déblayassions": ("déblayer",),
    "déblayâtes": ("déblayer",),
    "déblayât": ("déblayer",),
    "déblayée": ("déblayer",),
    "déblayées": ("déblayer",),
    "déblayé": ("déblayer",),
    "déblayent": ("déblayer",),
    "déblaye": ("déblayer",),
    "déblayera": ("déblayer",),
    "déblayeraient": ("déblayer",),
    "déblayerai": ("déblayer",),
    "déblayerais": ("déblayer",),
    "déblayerait": ("déblayer",),
    "déblayeras": ("déblayer",),
    "déblayèrent": ("déblayer",),
    "déblayerez": ("déblayer",),
    "déblayeriez": ("déblayer",),
    "déblayerions": ("déblayer",),
    "déblayerons": ("déblayer",),
    "déblayeront": ("déblayer",),
    "déblayés": ("déblayer",),
    "déblayes": ("déblayer",),
    "déblayez": ("déblayer",),
    "déblayiez": ("déblayer",),
    "déblayions": ("déblayer",),
    "déblayons": ("déblayer",),
    "débleuie": ("débleuir",),
    "débleuies": ("débleuir",),
    "débleui": ("débleuir",),
    "débleuîmes": ("débleuir",),
    "débleuira": ("débleuir",),
    "débleuiraient": ("débleuir",),
    "débleuirai": ("débleuir",),
    "débleuirais": ("débleuir",),
    "débleuirait": ("débleuir",),
    "débleuiras": ("débleuir",),
    "débleuirent": ("débleuir",),
    "débleuirez": ("débleuir",),
    "débleuiriez": ("débleuir",),
    "débleuirions": ("débleuir",),
    "débleuirons": ("débleuir",),
    "débleuiront": ("débleuir",),
    "débleuis": ("débleuir",),
    "débleuissaient": ("débleuir",),
    "débleuissais": ("débleuir",),
    "débleuissait": ("débleuir",),
    "débleuissant": ("débleuir",),
    "débleuissent": ("débleuir",),
    "débleuisse": ("débleuir",),
    "débleuisses": ("débleuir",),
    "débleuissez": ("débleuir",),
    "débleuissiez": ("débleuir",),
    "débleuissions": ("débleuir",),
    "débleuissons": ("débleuir",),
    "débleuîtes": ("débleuir",),
    "débleuit": ("débleuir",),
    "débleuît": ("débleuir",),
    "déblondie": ("déblondir",),
    "déblondies": ("déblondir",),
    "déblondi": ("déblondir",),
    "déblondîmes": ("déblondir",),
    "déblondira": ("déblondir",),
    "déblondiraient": ("déblondir",),
    "déblondirai": ("déblondir",),
    "déblondirais": ("déblondir",),
    "déblondirait": ("déblondir",),
    "déblondiras": ("déblondir",),
    "déblondirent": ("déblondir",),
    "déblondirez": ("déblondir",),
    "déblondiriez": ("déblondir",),
    "déblondirions": ("déblondir",),
    "déblondirons": ("déblondir",),
    "déblondiront": ("déblondir",),
    "déblondis": ("déblondir",),
    "déblondissaient": ("déblondir",),
    "déblondissais": ("déblondir",),
    "déblondissait": ("déblondir",),
    "déblondissant": ("déblondir",),
    "déblondissent": ("déblondir",),
    "déblondisse": ("déblondir",),
    "déblondisses": ("déblondir",),
    "déblondissez": ("déblondir",),
    "déblondissiez": ("déblondir",),
    "déblondissions": ("déblondir",),
    "déblondissons": ("déblondir",),
    "déblondîtes": ("déblondir",),
    "déblondit": ("déblondir",),
    "déblondît": ("déblondir",),
    "débosselaient": ("débosseler",),
    "débosselai": ("débosseler",),
    "débosselais": ("débosseler",),
    "débosselait": ("débosseler",),
    "débossela": ("débosseler",),
    "débosselâmes": ("débosseler",),
    "débosselant": ("débosseler",),
    "débosselas": ("débosseler",),
    "débosselassent": ("débosseler",),
    "débosselasses": ("débosseler",),
    "débosselasse": ("débosseler",),
    "débosselassiez": ("débosseler",),
    "débosselassions": ("débosseler",),
    "débosselâtes": ("débosseler",),
    "débosselât": ("débosseler",),
    "débosselée": ("débosseler",),
    "débosselées": ("débosseler",),
    "débosselé": ("débosseler",),
    "débosselèrent": ("débosseler",),
    "débosselés": ("débosseler",),
    "débosselez": ("débosseler",),
    "débosseliez": ("débosseler",),
    "débosselions": ("débosseler",),
    "débossellent": ("débosseler",),
    "débosselle": ("débosseler",),
    "débossellera": ("débosseler",),
    "débosselleraient": ("débosseler",),
    "débossellerai": ("débosseler",),
    "débossellerais": ("débosseler",),
    "débossellerait": ("débosseler",),
    "débosselleras": ("débosseler",),
    "débossellerez": ("débosseler",),
    "débosselleriez": ("débosseler",),
    "débossellerions": ("débosseler",),
    "débossellerons": ("débosseler",),
    "débosselleront": ("débosseler",),
    "débosselles": ("débosseler",),
    "débosselons": ("débosseler",),
    "débottelaient": ("débotteler",),
    "débottelai": ("débotteler",),
    "débottelais": ("débotteler",),
    "débottelait": ("débotteler",),
    "débottela": ("débotteler",),
    "débottelâmes": ("débotteler",),
    "débottelant": ("débotteler",),
    "débottelas": ("débotteler",),
    "débottelassent": ("débotteler",),
    "débottelasses": ("débotteler",),
    "débottelasse": ("débotteler",),
    "débottelassiez": ("débotteler",),
    "débottelassions": ("débotteler",),
    "débottelâtes": ("débotteler",),
    "débottelât": ("débotteler",),
    "débottelée": ("débotteler",),
    "débottelées": ("débotteler",),
    "débottelé": ("débotteler",),
    "débottelèrent": ("débotteler",),
    "débottelés": ("débotteler",),
    "débottelez": ("débotteler",),
    "débotteliez": ("débotteler",),
    "débottelions": ("débotteler",),
    "débottellent": ("débotteler",),
    "débottelle": ("débotteler",),
    "débottellera": ("débotteler",),
    "débottelleraient": ("débotteler",),
    "débottellerai": ("débotteler",),
    "débottellerais": ("débotteler",),
    "débottellerait": ("débotteler",),
    "débottelleras": ("débotteler",),
    "débottellerez": ("débotteler",),
    "débottelleriez": ("débotteler",),
    "débottellerions": ("débotteler",),
    "débottellerons": ("débotteler",),
    "débottelleront": ("débotteler",),
    "débottelles": ("débotteler",),
    "débottelons": ("débotteler",),
    "débouillaient": ("débouillir",),
    "débouillais": ("débouillir",),
    "débouillait": ("débouillir",),
    "débouillant": ("débouillir",),
    "débouillent": ("débouillir",),
    "débouille": ("débouillir",),
    "débouilles": ("débouillir",),
    "débouillez": ("débouillir",),
    "débouillie": ("débouillir",),
    "débouillies": ("débouillir",),
    "débouilliez": ("débouillir",),
    "débouilli": ("débouillir",),
    "débouillîmes": ("débouillir",),
    "débouillions": ("débouillir",),
    "débouillira": ("débouillir",),
    "débouilliraient": ("débouillir",),
    "débouillirai": ("débouillir",),
    "débouillirais": ("débouillir",),
    "débouillirait": ("débouillir",),
    "débouilliras": ("débouillir",),
    "débouillirent": ("débouillir",),
    "débouillirez": ("débouillir",),
    "débouilliriez": ("débouillir",),
    "débouillirions": ("débouillir",),
    "débouillirons": ("débouillir",),
    "débouilliront": ("débouillir",),
    "débouillis": ("débouillir",),
    "débouillissent": ("débouillir",),
    "débouillisses": ("débouillir",),
    "débouillisse": ("débouillir",),
    "débouillissiez": ("débouillir",),
    "débouillissions": ("débouillir",),
    "débouillîtes": ("débouillir",),
    "débouillit": ("débouillir",),
    "débouillît": ("débouillir",),
    "débouillons": ("débouillir",),
    "débous": ("débouillir",),
    "débout": ("débouillir",),
    "débraient": ("débrayer",),
    "débraie": ("débrayer",),
    "débraiera": ("débrayer",),
    "débraieraient": ("débrayer",),
    "débraierai": ("débrayer",),
    "débraierais": ("débrayer",),
    "débraierait": ("débrayer",),
    "débraieras": ("débrayer",),
    "débraierez": ("débrayer",),
    "débraieriez": ("débrayer",),
    "débraierions": ("débrayer",),
    "débraierons": ("débrayer",),
    "débraieront": ("débrayer",),
    "débraies": ("débrayer",),
    "débrayaient": ("débrayer",),
    "débrayai": ("débrayer",),
    "débrayais": ("débrayer",),
    "débrayait": ("débrayer",),
    "débraya": ("débrayer",),
    "débrayâmes": ("débrayer",),
    "débrayant": ("débrayer",),
    "débrayas": ("débrayer",),
    "débrayassent": ("débrayer",),
    "débrayasses": ("débrayer",),
    "débrayasse": ("débrayer",),
    "débrayassiez": ("débrayer",),
    "débrayassions": ("débrayer",),
    "débrayâtes": ("débrayer",),
    "débrayât": ("débrayer",),
    "débrayée": ("débrayer",),
    "débrayées": ("débrayer",),
    "débrayé": ("débrayer",),
    "débrayent": ("débrayer",),
    "débraye": ("débrayer",),
    "débrayera": ("débrayer",),
    "débrayeraient": ("débrayer",),
    "débrayerai": ("débrayer",),
    "débrayerais": ("débrayer",),
    "débrayerait": ("débrayer",),
    "débrayeras": ("débrayer",),
    "débrayèrent": ("débrayer",),
    "débrayerez": ("débrayer",),
    "débrayeriez": ("débrayer",),
    "débrayerions": ("débrayer",),
    "débrayerons": ("débrayer",),
    "débrayeront": ("débrayer",),
    "débrayés": ("débrayer",),
    "débrayes": ("débrayer",),
    "débrayez": ("débrayer",),
    "débrayiez": ("débrayer",),
    "débrayions": ("débrayer",),
    "débrayons": ("débrayer",),
    "débrutie": ("débrutir",),
    "débruties": ("débrutir",),
    "débruti": ("débrutir",),
    "débrutîmes": ("débrutir",),
    "débrutira": ("débrutir",),
    "débrutiraient": ("débrutir",),
    "débrutirai": ("débrutir",),
    "débrutirais": ("débrutir",),
    "débrutirait": ("débrutir",),
    "débrutiras": ("débrutir",),
    "débrutirent": ("débrutir",),
    "débrutirez": ("débrutir",),
    "débrutiriez": ("débrutir",),
    "débrutirions": ("débrutir",),
    "débrutirons": ("débrutir",),
    "débrutiront": ("débrutir",),
    "débrutis": ("débrutir",),
    "débrutissaient": ("débrutir",),
    "débrutissais": ("débrutir",),
    "débrutissait": ("débrutir",),
    "débrutissant": ("débrutir",),
    "débrutissent": ("débrutir",),
    "débrutisse": ("débrutir",),
    "débrutisses": ("débrutir",),
    "débrutissez": ("débrutir",),
    "débrutissiez": ("débrutir",),
    "débrutissions": ("débrutir",),
    "débrutissons": ("débrutir",),
    "débrutîtes": ("débrutir",),
    "débrutit": ("débrutir",),
    "débrutît": ("débrutir",),
    "débudgétaient": ("débudgéter",),
    "débudgétai": ("débudgéter",),
    "débudgétais": ("débudgéter",),
    "débudgétait": ("débudgéter",),
    "débudgéta": ("débudgéter",),
    "débudgétâmes": ("débudgéter",),
    "débudgétant": ("débudgéter",),
    "débudgétas": ("débudgéter",),
    "débudgétassent": ("débudgéter",),
    "débudgétasses": ("débudgéter",),
    "débudgétasse": ("débudgéter",),
    "débudgétassiez": ("débudgéter",),
    "débudgétassions": ("débudgéter",),
    "débudgétâtes": ("débudgéter",),
    "débudgétât": ("débudgéter",),
    "débudgétée": ("débudgéter",),
    "débudgétées": ("débudgéter",),
    "débudgété": ("débudgéter",),
    "débudgètent": ("débudgéter",),
    "débudgète": ("débudgéter",),
    "débudgétera": ("débudgéter",),
    "débudgéteraient": ("débudgéter",),
    "débudgéterai": ("débudgéter",),
    "débudgéterais": ("débudgéter",),
    "débudgéterait": ("débudgéter",),
    "débudgéteras": ("débudgéter",),
    "débudgétèrent": ("débudgéter",),
    "débudgéterez": ("débudgéter",),
    "débudgéteriez": ("débudgéter",),
    "débudgéterions": ("débudgéter",),
    "débudgéterons": ("débudgéter",),
    "débudgéteront": ("débudgéter",),
    "débudgétés": ("débudgéter",),
    "débudgètes": ("débudgéter",),
    "débudgétez": ("débudgéter",),
    "débudgétiez": ("débudgéter",),
    "débudgétions": ("débudgéter",),
    "débudgétons": ("débudgéter",),
    "décachetaient": ("décacheter",),
    "décachetai": ("décacheter",),
    "décachetais": ("décacheter",),
    "décachetait": ("décacheter",),
    "décacheta": ("décacheter",),
    "décachetâmes": ("décacheter",),
    "décachetant": ("décacheter",),
    "décachetas": ("décacheter",),
    "décachetassent": ("décacheter",),
    "décachetasses": ("décacheter",),
    "décachetasse": ("décacheter",),
    "décachetassiez": ("décacheter",),
    "décachetassions": ("décacheter",),
    "décachetâtes": ("décacheter",),
    "décachetât": ("décacheter",),
    "décachetée": ("décacheter",),
    "décachetées": ("décacheter",),
    "décacheté": ("décacheter",),
    "décachetèrent": ("décacheter",),
    "décachetés": ("décacheter",),
    "décachetez": ("décacheter",),
    "décachetiez": ("décacheter",),
    "décachetions": ("décacheter",),
    "décachetons": ("décacheter",),
    "décachettent": ("décacheter",),
    "décachette": ("décacheter",),
    "décachettera": ("décacheter",),
    "décachetteraient": ("décacheter",),
    "décachetterai": ("décacheter",),
    "décachetterais": ("décacheter",),
    "décachetterait": ("décacheter",),
    "décachetteras": ("décacheter",),
    "décachetterez": ("décacheter",),
    "décachetteriez": ("décacheter",),
    "décachetterions": ("décacheter",),
    "décachetterons": ("décacheter",),
    "décachetteront": ("décacheter",),
    "décachettes": ("décacheter",),
    "décadenassaient": ("décadenasser",),
    "décadenassai": ("décadenasser",),
    "décadenassais": ("décadenasser",),
    "décadenassait": ("décadenasser",),
    "décadenassa": ("décadenasser",),
    "décadenassâmes": ("décadenasser",),
    "décadenassant": ("décadenasser",),
    "décadenassas": ("décadenasser",),
    "décadenassassent": ("décadenasser",),
    "décadenassasses": ("décadenasser",),
    "décadenassasse": ("décadenasser",),
    "décadenassassiez": ("décadenasser",),
    "décadenassassions": ("décadenasser",),
    "décadenassâtes": ("décadenasser",),
    "décadenassât": ("décadenasser",),
    "décadenassée": ("décadenasser",),
    "décadenassées": ("décadenasser",),
    "décadenassé": ("décadenasser",),
    "décadenassent": ("décadenasser",),
    "décadenasse": ("décadenasser",),
    "décadenassera": ("décadenasser",),
    "décadenasseraient": ("décadenasser",),
    "décadenasserai": ("décadenasser",),
    "décadenasserais": ("décadenasser",),
    "décadenasserait": ("décadenasser",),
    "décadenasseras": ("décadenasser",),
    "décadenassèrent": ("décadenasser",),
    "décadenasserez": ("décadenasser",),
    "décadenasseriez": ("décadenasser",),
    "décadenasserions": ("décadenasser",),
    "décadenasserons": ("décadenasser",),
    "décadenasseront": ("décadenasser",),
    "décadenassés": ("décadenasser",),
    "décadenasses": ("décadenasser",),
    "décadenassez": ("décadenasser",),
    "décadenassiez": ("décadenasser",),
    "décadenassions": ("décadenasser",),
    "décadenassons": ("décadenasser",),
    "décageaient": ("décager",),
    "décageai": ("décager",),
    "décageais": ("décager",),
    "décageait": ("décager",),
    "décagea": ("décager",),
    "décageâmes": ("décager",),
    "décageant": ("décager",),
    "décageas": ("décager",),
    "décageassent": ("décager",),
    "décageasses": ("décager",),
    "décageasse": ("décager",),
    "décageassiez": ("décager",),
    "décageassions": ("décager",),
    "décageâtes": ("décager",),
    "décageât": ("décager",),
    "décagée": ("décager",),
    "décagées": ("décager",),
    "décagé": ("décager",),
    "décagent": ("décager",),
    "décageons": ("décager",),
    "décage": ("décager",),
    "décagera": ("décager",),
    "décageraient": ("décager",),
    "décagerai": ("décager",),
    "décagerais": ("décager",),
    "décagerait": ("décager",),
    "décageras": ("décager",),
    "décagèrent": ("décager",),
    "décagerez": ("décager",),
    "décageriez": ("décager",),
    "décagerions": ("décager",),
    "décagerons": ("décager",),
    "décageront": ("décager",),
    "décagés": ("décager",),
    "décages": ("décager",),
    "décagez": ("décager",),
    "décagiez": ("décager",),
    "décagions": ("décager",),
    "décalcifiaient": ("décalcifier",),
    "décalcifiai": ("décalcifier",),
    "décalcifiais": ("décalcifier",),
    "décalcifiait": ("décalcifier",),
    "décalcifia": ("décalcifier",),
    "décalcifiâmes": ("décalcifier",),
    "décalcifiant": ("décalcifier",),
    "décalcifias": ("décalcifier",),
    "décalcifiassent": ("décalcifier",),
    "décalcifiasses": ("décalcifier",),
    "décalcifiasse": ("décalcifier",),
    "décalcifiassiez": ("décalcifier",),
    "décalcifiassions": ("décalcifier",),
    "décalcifiâtes": ("décalcifier",),
    "décalcifiât": ("décalcifier",),
    "décalcifiée": ("décalcifier",),
    "décalcifiées": ("décalcifier",),
    "décalcifié": ("décalcifier",),
    "décalcifient": ("décalcifier",),
    "décalcifie": ("décalcifier",),
    "décalcifiera": ("décalcifier",),
    "décalcifieraient": ("décalcifier",),
    "décalcifierai": ("décalcifier",),
    "décalcifierais": ("décalcifier",),
    "décalcifierait": ("décalcifier",),
    "décalcifieras": ("décalcifier",),
    "décalcifièrent": ("décalcifier",),
    "décalcifierez": ("décalcifier",),
    "décalcifieriez": ("décalcifier",),
    "décalcifierions": ("décalcifier",),
    "décalcifierons": ("décalcifier",),
    "décalcifieront": ("décalcifier",),
    "décalcifiés": ("décalcifier",),
    "décalcifies": ("décalcifier",),
    "décalcifiez": ("décalcifier",),
    "décalcifiiez": ("décalcifier",),
    "décalcifiions": ("décalcifier",),
    "décalcifions": ("décalcifier",),
    "décalorifugeaient": ("décalorifuger",),
    "décalorifugeai": ("décalorifuger",),
    "décalorifugeais": ("décalorifuger",),
    "décalorifugeait": ("décalorifuger",),
    "décalorifugea": ("décalorifuger",),
    "décalorifugeâmes": ("décalorifuger",),
    "décalorifugeant": ("décalorifuger",),
    "décalorifugeas": ("décalorifuger",),
    "décalorifugeassent": ("décalorifuger",),
    "décalorifugeasses": ("décalorifuger",),
    "décalorifugeasse": ("décalorifuger",),
    "décalorifugeassiez": ("décalorifuger",),
    "décalorifugeassions": ("décalorifuger",),
    "décalorifugeâtes": ("décalorifuger",),
    "décalorifugeât": ("décalorifuger",),
    "décalorifugée": ("décalorifuger",),
    "décalorifugées": ("décalorifuger",),
    "décalorifugé": ("décalorifuger",),
    "décalorifugent": ("décalorifuger",),
    "décalorifugeons": ("décalorifuger",),
    "décalorifuge": ("décalorifuger",),
    "décalorifugera": ("décalorifuger",),
    "décalorifugeraient": ("décalorifuger",),
    "décalorifugerai": ("décalorifuger",),
    "décalorifugerais": ("décalorifuger",),
    "décalorifugerait": ("décalorifuger",),
    "décalorifugeras": ("décalorifuger",),
    "décalorifugèrent": ("décalorifuger",),
    "décalorifugerez": ("décalorifuger",),
    "décalorifugeriez": ("décalorifuger",),
    "décalorifugerions": ("décalorifuger",),
    "décalorifugerons": ("décalorifuger",),
    "décalorifugeront": ("décalorifuger",),
    "décalorifugés": ("décalorifuger",),
    "décalorifuges": ("décalorifuger",),
    "décalorifugez": ("décalorifuger",),
    "décalorifugiez": ("décalorifuger",),
    "décalorifugions": ("décalorifuger",),
    "décapelaient": ("décapeler",),
    "décapelai": ("décapeler",),
    "décapelais": ("décapeler",),
    "décapelait": ("décapeler",),
    "décapela": ("décapeler",),
    "décapelâmes": ("décapeler",),
    "décapelant": ("décapeler",),
    "décapelas": ("décapeler",),
    "décapelassent": ("décapeler",),
    "décapelasses": ("décapeler",),
    "décapelasse": ("décapeler",),
    "décapelassiez": ("décapeler",),
    "décapelassions": ("décapeler",),
    "décapelâtes": ("décapeler",),
    "décapelât": ("décapeler",),
    "décapelée": ("décapeler",),
    "décapelées": ("décapeler",),
    "décapelé": ("décapeler",),
    "décapelèrent": ("décapeler",),
    "décapelés": ("décapeler",),
    "décapelez": ("décapeler",),
    "décapeliez": ("décapeler",),
    "décapelions": ("décapeler",),
    "décapellent": ("décapeler",),
    "décapelle": ("décapeler",),
    "décapellera": ("décapeler",),
    "décapelleraient": ("décapeler",),
    "décapellerai": ("décapeler",),
    "décapellerais": ("décapeler",),
    "décapellerait": ("décapeler",),
    "décapelleras": ("décapeler",),
    "décapellerez": ("décapeler",),
    "décapelleriez": ("décapeler",),
    "décapellerions": ("décapeler",),
    "décapellerons": ("décapeler",),
    "décapelleront": ("décapeler",),
    "décapelles": ("décapeler",),
    "décapelons": ("décapeler",),
    "décarcassaient": ("décarcasser",),
    "décarcassai": ("décarcasser",),
    "décarcassais": ("décarcasser",),
    "décarcassait": ("décarcasser",),
    "décarcassa": ("décarcasser",),
    "décarcassâmes": ("décarcasser",),
    "décarcassant": ("décarcasser",),
    "décarcassas": ("décarcasser",),
    "décarcassassent": ("décarcasser",),
    "décarcassasses": ("décarcasser",),
    "décarcassasse": ("décarcasser",),
    "décarcassassiez": ("décarcasser",),
    "décarcassassions": ("décarcasser",),
    "décarcassâtes": ("décarcasser",),
    "décarcassât": ("décarcasser",),
    "décarcassée": ("décarcasser",),
    "décarcassées": ("décarcasser",),
    "décarcassé": ("décarcasser",),
    "décarcassent": ("décarcasser",),
    "décarcasse": ("décarcasser",),
    "décarcassera": ("décarcasser",),
    "décarcasseraient": ("décarcasser",),
    "décarcasserai": ("décarcasser",),
    "décarcasserais": ("décarcasser",),
    "décarcasserait": ("décarcasser",),
    "décarcasseras": ("décarcasser",),
    "décarcassèrent": ("décarcasser",),
    "décarcasserez": ("décarcasser",),
    "décarcasseriez": ("décarcasser",),
    "décarcasserions": ("décarcasser",),
    "décarcasserons": ("décarcasser",),
    "décarcasseront": ("décarcasser",),
    "décarcassés": ("décarcasser",),
    "décarcasses": ("décarcasser",),
    "décarcassez": ("décarcasser",),
    "décarcassiez": ("décarcasser",),
    "décarcassions": ("décarcasser",),
    "décarcassons": ("décarcasser",),
    "décarcéraient": ("décarcérer",),
    "décarcérai": ("décarcérer",),
    "décarcérais": ("décarcérer",),
    "décarcérait": ("décarcérer",),
    "décarcéra": ("décarcérer",),
    "décarcérâmes": ("décarcérer",),
    "décarcérant": ("décarcérer",),
    "décarcéras": ("décarcérer",),
    "décarcérassent": ("décarcérer",),
    "décarcérasses": ("décarcérer",),
    "décarcérasse": ("décarcérer",),
    "décarcérassiez": ("décarcérer",),
    "décarcérassions": ("décarcérer",),
    "décarcérâtes": ("décarcérer",),
    "décarcérât": ("décarcérer",),
    "décarcérée": ("décarcérer",),
    "décarcérées": ("décarcérer",),
    "décarcéré": ("décarcérer",),
    "décarcèrent": ("décarcérer",),
    "décarcère": ("décarcérer",),
    "décarcérera": ("décarcérer",),
    "décarcéreraient": ("décarcérer",),
    "décarcérerai": ("décarcérer",),
    "décarcérerais": ("décarcérer",),
    "décarcérerait": ("décarcérer",),
    "décarcéreras": ("décarcérer",),
    "décarcérèrent": ("décarcérer",),
    "décarcérerez": ("décarcérer",),
    "décarcéreriez": ("décarcérer",),
    "décarcérerions": ("décarcérer",),
    "décarcérerons": ("décarcérer",),
    "décarcéreront": ("décarcérer",),
    "décarcérés": ("décarcérer",),
    "décarcères": ("décarcérer",),
    "décarcérez": ("décarcérer",),
    "décarcériez": ("décarcérer",),
    "décarcérions": ("décarcérer",),
    "décarcérons": ("décarcérer",),
    "décarrelaient": ("décarreler",),
    "décarrelai": ("décarreler",),
    "décarrelais": ("décarreler",),
    "décarrelait": ("décarreler",),
    "décarrela": ("décarreler",),
    "décarrelâmes": ("décarreler",),
    "décarrelant": ("décarreler",),
    "décarrelas": ("décarreler",),
    "décarrelassent": ("décarreler",),
    "décarrelasses": ("décarreler",),
    "décarrelasse": ("décarreler",),
    "décarrelassiez": ("décarreler",),
    "décarrelassions": ("décarreler",),
    "décarrelâtes": ("décarreler",),
    "décarrelât": ("décarreler",),
    "décarrelée": ("décarreler",),
    "décarrelées": ("décarreler",),
    "décarrelé": ("décarreler",),
    "décarrelèrent": ("décarreler",),
    "décarrelés": ("décarreler",),
    "décarrelez": ("décarreler",),
    "décarreliez": ("décarreler",),
    "décarrelions": ("décarreler",),
    "décarrellent": ("décarreler",),
    "décarrelle": ("décarreler",),
    "décarrellera": ("décarreler",),
    "décarrelleraient": ("décarreler",),
    "décarrellerai": ("décarreler",),
    "décarrellerais": ("décarreler",),
    "décarrellerait": ("décarreler",),
    "décarrelleras": ("décarreler",),
    "décarrellerez": ("décarreler",),
    "décarrelleriez": ("décarreler",),
    "décarrellerions": ("décarreler",),
    "décarrellerons": ("décarreler",),
    "décarrelleront": ("décarreler",),
    "décarrelles": ("décarreler",),
    "décarrelons": ("décarreler",),
    "décatie": ("décatir",),
    "décaties": ("décatir",),
    "décati": ("décatir",),
    "décatîmes": ("décatir",),
    "décatira": ("décatir",),
    "décatiraient": ("décatir",),
    "décatirai": ("décatir",),
    "décatirais": ("décatir",),
    "décatirait": ("décatir",),
    "décatiras": ("décatir",),
    "décatirent": ("décatir",),
    "décatirez": ("décatir",),
    "décatiriez": ("décatir",),
    "décatirions": ("décatir",),
    "décatirons": ("décatir",),
    "décatiront": ("décatir",),
    "décatis": ("décatir",),
    "décatissaient": ("décatir",),
    "décatissais": ("décatir",),
    "décatissait": ("décatir",),
    "décatissant": ("décatir",),
    "décatissent": ("décatir",),
    "décatisse": ("décatir",),
    "décatisses": ("décatir",),
    "décatissez": ("décatir",),
    "décatissiez": ("décatir",),
    "décatissions": ("décatir",),
    "décatissons": ("décatir",),
    "décatîtes": ("décatir",),
    "décatit": ("décatir",),
    "décatît": ("décatir",),
    "décédaient": ("décéder",),
    "décédai": ("décéder",),
    "décédais": ("décéder",),
    "décédait": ("décéder",),
    "décéda": ("décéder",),
    "décédâmes": ("décéder",),
    "décédant": ("décéder",),
    "décédas": ("décéder",),
    "décédassent": ("décéder",),
    "décédasses": ("décéder",),
    "décédasse": ("décéder",),
    "décédassiez": ("décéder",),
    "décédassions": ("décéder",),
    "décédâtes": ("décéder",),
    "décédât": ("décéder",),
    "décédée": ("décéder",),
    "décédées": ("décéder",),
    "décédé": ("décéder",),
    "décèdent": ("décéder",),
    "décède": ("décéder",),
    "décédera": ("décéder",),
    "décéderaient": ("décéder",),
    "décéderai": ("décéder",),
    "décéderais": ("décéder",),
    "décéderait": ("décéder",),
    "décéderas": ("décéder",),
    "décédèrent": ("décéder",),
    "décéderez": ("décéder",),
    "décéderiez": ("décéder",),
    "décéderions": ("décéder",),
    "décéderons": ("décéder",),
    "décéderont": ("décéder",),
    "décédés": ("décéder",),
    "décèdes": ("décéder",),
    "décédez": ("décéder",),
    "décédiez": ("décéder",),
    "décédions": ("décéder",),
    "décédons": ("décéder",),
    "déceignaient": ("déceindre",),
    "déceignais": ("déceindre",),
    "déceignait": ("déceindre",),
    "déceignant": ("déceindre",),
    "déceignent": ("déceindre",),
    "déceigne": ("déceindre",),
    "déceignes": ("déceindre",),
    "déceignez": ("déceindre",),
    "déceigniez": ("déceindre",),
    "déceignîmes": ("déceindre",),
    "déceignions": ("déceindre",),
    "déceignirent": ("déceindre",),
    "déceignis": ("déceindre",),
    "déceignissent": ("déceindre",),
    "déceignisses": ("déceindre",),
    "déceignisse": ("déceindre",),
    "déceignissiez": ("déceindre",),
    "déceignissions": ("déceindre",),
    "déceignîtes": ("déceindre",),
    "déceignit": ("déceindre",),
    "déceignît": ("déceindre",),
    "déceignons": ("déceindre",),
    "déceindra": ("déceindre",),
    "déceindraient": ("déceindre",),
    "déceindrai": ("déceindre",),
    "déceindrais": ("déceindre",),
    "déceindrait": ("déceindre",),
    "déceindras": ("déceindre",),
    "déceindrez": ("déceindre",),
    "déceindriez": ("déceindre",),
    "déceindrions": ("déceindre",),
    "déceindrons": ("déceindre",),
    "déceindront": ("déceindre",),
    "déceins": ("déceindre",),
    "déceinte": ("déceindre",),
    "déceintes": ("déceindre",),
    "déceint": ("déceindre",),
    "déceints": ("déceindre",),
    "décéléraient": ("décélérer",),
    "décélérai": ("décélérer",),
    "décélérais": ("décélérer",),
    "décélérait": ("décélérer",),
    "décéléra": ("décélérer",),
    "décélérâmes": ("décélérer",),
    "décélérant": ("décélérer",),
    "décéléras": ("décélérer",),
    "décélérassent": ("décélérer",),
    "décélérasses": ("décélérer",),
    "décélérasse": ("décélérer",),
    "décélérassiez": ("décélérer",),
    "décélérassions": ("décélérer",),
    "décélérâtes": ("décélérer",),
    "décélérât": ("décélérer",),
    "décéléré": ("décélérer",),
    "décélèrent": ("décélérer",),
    "décélère": ("décélérer",),
    "décélérera": ("décélérer",),
    "décéléreraient": ("décélérer",),
    "décélérerai": ("décélérer",),
    "décélérerais": ("décélérer",),
    "décélérerait": ("décélérer",),
    "décéléreras": ("décélérer",),
    "décélérèrent": ("décélérer",),
    "décélérerez": ("décélérer",),
    "décéléreriez": ("décélérer",),
    "décélérerions": ("décélérer",),
    "décélérerons": ("décélérer",),
    "décéléreront": ("décélérer",),
    "décélères": ("décélérer",),
    "décélérez": ("décélérer",),
    "décélériez": ("décélérer",),
    "décélérions": ("décélérer",),
    "décélérons": ("décélérer",),
    "décelaient": ("déceler",),
    "décelai": ("déceler",),
    "décelais": ("déceler",),
    "décelait": ("déceler",),
    "décela": ("déceler",),
    "décelâmes": ("déceler",),
    "décelant": ("déceler",),
    "décelas": ("déceler",),
    "décelassent": ("déceler",),
    "décelasses": ("déceler",),
    "décelasse": ("déceler",),
    "décelassiez": ("déceler",),
    "décelassions": ("déceler",),
    "décelâtes": ("déceler",),
    "décelât": ("déceler",),
    "décelée": ("déceler",),
    "décelées": ("déceler",),
    "décelé": ("déceler",),
    "décèlent": ("déceler",),
    "décèle": ("déceler",),
    "décèlera": ("déceler",),
    "décèleraient": ("déceler",),
    "décèlerai": ("déceler",),
    "décèlerais": ("déceler",),
    "décèlerait": ("déceler",),
    "décèleras": ("déceler",),
    "décelèrent": ("déceler",),
    "décèlerez": ("déceler",),
    "décèleriez": ("déceler",),
    "décèlerions": ("déceler",),
    "décèlerons": ("déceler",),
    "décèleront": ("déceler",),
    "décelés": ("déceler",),
    "décèles": ("déceler",),
    "décelez": ("déceler",),
    "déceliez": ("déceler",),
    "décelions": ("déceler",),
    "décelons": ("déceler",),
    "décérébraient": ("décérébrer",),
    "décérébrai": ("décérébrer",),
    "décérébrais": ("décérébrer",),
    "décérébrait": ("décérébrer",),
    "décérébra": ("décérébrer",),
    "décérébrâmes": ("décérébrer",),
    "décérébrant": ("décérébrer",),
    "décérébras": ("décérébrer",),
    "décérébrassent": ("décérébrer",),
    "décérébrasses": ("décérébrer",),
    "décérébrasse": ("décérébrer",),
    "décérébrassiez": ("décérébrer",),
    "décérébrassions": ("décérébrer",),
    "décérébrâtes": ("décérébrer",),
    "décérébrât": ("décérébrer",),
    "décérébrée": ("décérébrer",),
    "décérébrées": ("décérébrer",),
    "décérébré": ("décérébrer",),
    "décérèbrent": ("décérébrer",),
    "décérèbre": ("décérébrer",),
    "décérébrera": ("décérébrer",),
    "décérébreraient": ("décérébrer",),
    "décérébrerai": ("décérébrer",),
    "décérébrerais": ("décérébrer",),
    "décérébrerait": ("décérébrer",),
    "décérébreras": ("décérébrer",),
    "décérébrèrent": ("décérébrer",),
    "décérébrerez": ("décérébrer",),
    "décérébreriez": ("décérébrer",),
    "décérébrerions": ("décérébrer",),
    "décérébrerons": ("décérébrer",),
    "décérébreront": ("décérébrer",),
    "décérébrés": ("décérébrer",),
    "décérèbres": ("décérébrer",),
    "décérébrez": ("décérébrer",),
    "décérébriez": ("décérébrer",),
    "décérébrions": ("décérébrer",),
    "décérébrons": ("décérébrer",),
    "décervelaient": ("décerveler",),
    "décervelai": ("décerveler",),
    "décervelais": ("décerveler",),
    "décervelait": ("décerveler",),
    "décervela": ("décerveler",),
    "décervelâmes": ("décerveler",),
    "décervelant": ("décerveler",),
    "décervelas": ("décerveler",),
    "décervelassent": ("décerveler",),
    "décervelasses": ("décerveler",),
    "décervelasse": ("décerveler",),
    "décervelassiez": ("décerveler",),
    "décervelassions": ("décerveler",),
    "décervelâtes": ("décerveler",),
    "décervelât": ("décerveler",),
    "décervelée": ("décerveler",),
    "décervelées": ("décerveler",),
    "décervelé": ("décerveler",),
    "décervelèrent": ("décerveler",),
    "décervelés": ("décerveler",),
    "décervelez": ("décerveler",),
    "décerveliez": ("décerveler",),
    "décervelions": ("décerveler",),
    "décervellent": ("décerveler",),
    "décervelle": ("décerveler",),
    "décervellera": ("décerveler",),
    "décervelleraient": ("décerveler",),
    "décervellerai": ("décerveler",),
    "décervellerais": ("décerveler",),
    "décervellerait": ("décerveler",),
    "décervelleras": ("décerveler",),
    "décervellerez": ("décerveler",),
    "décervelleriez": ("décerveler",),
    "décervellerions": ("décerveler",),
    "décervellerons": ("décerveler",),
    "décervelleront": ("décerveler",),
    "décervelles": ("décerveler",),
    "décervelons": ("décerveler",),
    "décevaient": ("décevoir",),
    "décevais": ("décevoir",),
    "décevait": ("décevoir",),
    "décevant": ("décevoir",),
    "décevez": ("décevoir",),
    "déceviez": ("décevoir",),
    "décevions": ("décevoir",),
    "décevons": ("décevoir",),
    "décevra": ("décevoir",),
    "décevraient": ("décevoir",),
    "décevrai": ("décevoir",),
    "décevrais": ("décevoir",),
    "décevrait": ("décevoir",),
    "décevras": ("décevoir",),
    "décevrez": ("décevoir",),
    "décevriez": ("décevoir",),
    "décevrions": ("décevoir",),
    "décevrons": ("décevoir",),
    "décevront": ("décevoir",),
    "déçois": ("décevoir",),
    "déçoit": ("décevoir",),
    "déçoivent": ("décevoir",),
    "déçoive": ("décevoir",),
    "déçoives": ("décevoir",),
    "déçue": ("décevoir",),
    "déçues": ("décevoir",),
    "déçu": ("décevoir",),
    "déçûmes": ("décevoir",),
    "déçurent": ("décevoir",),
    "déçus": ("décevoir",),
    "déçussent": ("décevoir",),
    "déçusses": ("décevoir",),
    "déçusse": ("décevoir",),
    "déçussiez": ("décevoir",),
    "déçussions": ("décevoir",),
    "déçûtes": ("décevoir",),
    "déçut": ("décevoir",),
    "déçût": ("décevoir",),
    "déchalassaient": ("déchalasser",),
    "déchalassai": ("déchalasser",),
    "déchalassais": ("déchalasser",),
    "déchalassait": ("déchalasser",),
    "déchalassa": ("déchalasser",),
    "déchalassâmes": ("déchalasser",),
    "déchalassant": ("déchalasser",),
    "déchalassas": ("déchalasser",),
    "déchalassassent": ("déchalasser",),
    "déchalassasses": ("déchalasser",),
    "déchalassasse": ("déchalasser",),
    "déchalassassiez": ("déchalasser",),
    "déchalassassions": ("déchalasser",),
    "déchalassâtes": ("déchalasser",),
    "déchalassât": ("déchalasser",),
    "déchalassée": ("déchalasser",),
    "déchalassées": ("déchalasser",),
    "déchalassé": ("déchalasser",),
    "déchalassent": ("déchalasser",),
    "déchalasse": ("déchalasser",),
    "déchalassera": ("déchalasser",),
    "déchalasseraient": ("déchalasser",),
    "déchalasserai": ("déchalasser",),
    "déchalasserais": ("déchalasser",),
    "déchalasserait": ("déchalasser",),
    "déchalasseras": ("déchalasser",),
    "déchalassèrent": ("déchalasser",),
    "déchalasserez": ("déchalasser",),
    "déchalasseriez": ("déchalasser",),
    "déchalasserions": ("déchalasser",),
    "déchalasserons": ("déchalasser",),
    "déchalasseront": ("déchalasser",),
    "déchalassés": ("déchalasser",),
    "déchalasses": ("déchalasser",),
    "déchalassez": ("déchalasser",),
    "déchalassiez": ("déchalasser",),
    "déchalassions": ("déchalasser",),
    "déchalassons": ("déchalasser",),
    "déchargeaient": ("décharger",),
    "déchargeai": ("décharger",),
    "déchargeais": ("décharger",),
    "déchargeait": ("décharger",),
    "déchargea": ("décharger",),
    "déchargeâmes": ("décharger",),
    "déchargeant": ("décharger",),
    "déchargeas": ("décharger",),
    "déchargeassent": ("décharger",),
    "déchargeasses": ("décharger",),
    "déchargeasse": ("décharger",),
    "déchargeassiez": ("décharger",),
    "déchargeassions": ("décharger",),
    "déchargeâtes": ("décharger",),
    "déchargeât": ("décharger",),
    "déchargée": ("décharger",),
    "déchargées": ("décharger",),
    "déchargé": ("décharger",),
    "déchargent": ("décharger",),
    "déchargeons": ("décharger",),
    "décharge": ("décharger",),
    "déchargera": ("décharger",),
    "déchargeraient": ("décharger",),
    "déchargerai": ("décharger",),
    "déchargerais": ("décharger",),
    "déchargerait": ("décharger",),
    "déchargeras": ("décharger",),
    "déchargèrent": ("décharger",),
    "déchargerez": ("décharger",),
    "déchargeriez": ("décharger",),
    "déchargerions": ("décharger",),
    "déchargerons": ("décharger",),
    "déchargeront": ("décharger",),
    "déchargés": ("décharger",),
    "décharges": ("décharger",),
    "déchargez": ("décharger",),
    "déchargiez": ("décharger",),
    "déchargions": ("décharger",),
    "déchassaient": ("déchasser",),
    "déchassai": ("déchasser",),
    "déchassais": ("déchasser",),
    "déchassait": ("déchasser",),
    "déchassa": ("déchasser",),
    "déchassâmes": ("déchasser",),
    "déchassant": ("déchasser",),
    "déchassas": ("déchasser",),
    "déchassassent": ("déchasser",),
    "déchassasses": ("déchasser",),
    "déchassasse": ("déchasser",),
    "déchassassiez": ("déchasser",),
    "déchassassions": ("déchasser",),
    "déchassâtes": ("déchasser",),
    "déchassât": ("déchasser",),
    "déchassée": ("déchasser",),
    "déchassées": ("déchasser",),
    "déchassé": ("déchasser",),
    "déchassent": ("décher",),
    "déchasse": ("décher",),
    "déchassera": ("déchasser",),
    "déchasseraient": ("déchasser",),
    "déchasserai": ("déchasser",),
    "déchasserais": ("déchasser",),
    "déchasserait": ("déchasser",),
    "déchasseras": ("déchasser",),
    "déchassèrent": ("déchasser",),
    "déchasserez": ("déchasser",),
    "déchasseriez": ("déchasser",),
    "déchasserions": ("déchasser",),
    "déchasserons": ("déchasser",),
    "déchasseront": ("déchasser",),
    "déchassés": ("déchasser",),
    "déchasses": ("décher",),
    "déchassez": ("déchasser",),
    "déchassiez": ("décher",),
    "déchassions": ("décher",),
    "déchassons": ("déchasser",),
    "déchaient": ("décher",),
    "déchai": ("décher",),
    "déchais": ("décher",),
    "déchait": ("décher",),
    "décha": ("décher",),
    "déchâmes": ("décher",),
    "déchant": ("décher",),
    "déchas": ("décher",),
    "déchâtes": ("décher",),
    "déchât": ("décher",),
    "déchée": ("décher",),
    "déchées": ("décher",),
    "déché": ("décher",),
    "dèchent": ("décher",),
    "dèche": ("décher",),
    "déchera": ("décher",),
    "décheraient": ("décher",),
    "décherai": ("décher",),
    "décherais": ("décher",),
    "décherait": ("décher",),
    "décheras": ("décher",),
    "déchèrent": ("décher",),
    "décherez": ("décher",),
    "décheriez": ("décher",),
    "décherions": ("décher",),
    "décherons": ("décher",),
    "décheront": ("décher",),
    "déchés": ("décher",),
    "dèches": ("décher",),
    "déchez": ("décher",),
    "déchiez": ("décher",),
    "déchions": ("décher",),
    "déchons": ("décher",),
    "déchevelaient": ("décheveler",),
    "déchevelai": ("décheveler",),
    "déchevelais": ("décheveler",),
    "déchevelait": ("décheveler",),
    "déchevela": ("décheveler",),
    "déchevelâmes": ("décheveler",),
    "déchevelant": ("décheveler",),
    "déchevelas": ("décheveler",),
    "déchevelassent": ("décheveler",),
    "déchevelasses": ("décheveler",),
    "déchevelasse": ("décheveler",),
    "déchevelassiez": ("décheveler",),
    "déchevelassions": ("décheveler",),
    "déchevelâtes": ("décheveler",),
    "déchevelât": ("décheveler",),
    "déchevelée": ("décheveler",),
    "déchevelées": ("décheveler",),
    "déchevelé": ("décheveler",),
    "déchevelèrent": ("décheveler",),
    "déchevelés": ("décheveler",),
    "déchevelez": ("décheveler",),
    "décheveliez": ("décheveler",),
    "déchevelions": ("décheveler",),
    "déchevellent": ("décheveler",),
    "déchevelle": ("décheveler",),
    "déchevellera": ("décheveler",),
    "déchevelleraient": ("décheveler",),
    "déchevellerai": ("décheveler",),
    "déchevellerais": ("décheveler",),
    "déchevellerait": ("décheveler",),
    "déchevelleras": ("décheveler",),
    "déchevellerez": ("décheveler",),
    "déchevelleriez": ("décheveler",),
    "déchevellerions": ("décheveler",),
    "déchevellerons": ("décheveler",),
    "déchevelleront": ("décheveler",),
    "déchevelles": ("décheveler",),
    "déchevelons": ("décheveler",),
    "déchiquetaient": ("déchiqueter",),
    "déchiquetai": ("déchiqueter",),
    "déchiquetais": ("déchiqueter",),
    "déchiquetait": ("déchiqueter",),
    "déchiqueta": ("déchiqueter",),
    "déchiquetâmes": ("déchiqueter",),
    "déchiquetant": ("déchiqueter",),
    "déchiquetas": ("déchiqueter",),
    "déchiquetassent": ("déchiqueter",),
    "déchiquetasses": ("déchiqueter",),
    "déchiquetasse": ("déchiqueter",),
    "déchiquetassiez": ("déchiqueter",),
    "déchiquetassions": ("déchiqueter",),
    "déchiquetâtes": ("déchiqueter",),
    "déchiquetât": ("déchiqueter",),
    "déchiquetée": ("déchiqueter",),
    "déchiquetées": ("déchiqueter",),
    "déchiqueté": ("déchiqueter",),
    "déchiquetèrent": ("déchiqueter",),
    "déchiquetés": ("déchiqueter",),
    "déchiquetez": ("déchiqueter",),
    "déchiquetiez": ("déchiqueter",),
    "déchiquetions": ("déchiqueter",),
    "déchiquetons": ("déchiqueter",),
    "déchiquettent": ("déchiqueter",),
    "déchiquette": ("déchiqueter",),
    "déchiquettera": ("déchiqueter",),
    "déchiquetteraient": ("déchiqueter",),
    "déchiquetterai": ("déchiqueter",),
    "déchiquetterais": ("déchiqueter",),
    "déchiquetterait": ("déchiqueter",),
    "déchiquetteras": ("déchiqueter",),
    "déchiquetterez": ("déchiqueter",),
    "déchiquetteriez": ("déchiqueter",),
    "déchiquetterions": ("déchiqueter",),
    "déchiquetterons": ("déchiqueter",),
    "déchiquetteront": ("déchiqueter",),
    "déchiquettes": ("déchiqueter",),
    "déchoient": ("déchoir",),
    "déchoie": ("déchoir",),
    "déchoies": ("déchoir",),
    "déchoira": ("déchoir",),
    "déchoiraient": ("déchoir",),
    "déchoirai": ("déchoir",),
    "déchoirais": ("déchoir",),
    "déchoirait": ("déchoir",),
    "déchoiras": ("déchoir",),
    "déchoirez": ("déchoir",),
    "déchoiriez": ("déchoir",),
    "déchoirions": ("déchoir",),
    "déchoirons": ("déchoir",),
    "déchoiront": ("déchoir",),
    "déchois": ("déchoir",),
    "déchoit": ("déchoir",),
    "déchoyez": ("déchoir",),
    "déchoyiez": ("déchoir",),
    "déchoyions": ("déchoir",),
    "déchoyons": ("déchoir",),
    "déchue": ("déchoir",),
    "déchues": ("déchoir",),
    "déchu": ("déchoir",),
    "déchûmes": ("déchoir",),
    "déchurent": ("déchoir",),
    "déchus": ("déchoir",),
    "déchussent": ("déchoir",),
    "déchusses": ("déchoir",),
    "déchusse": ("déchoir",),
    "déchussiez": ("déchoir",),
    "déchussions": ("déchoir",),
    "déchûtes": ("déchoir",),
    "déchut": ("déchoir",),
    "déchût": ("déchoir",),
    "déclassaient": ("déclasser",),
    "déclassai": ("déclasser",),
    "déclassais": ("déclasser",),
    "déclassait": ("déclasser",),
    "déclassa": ("déclasser",),
    "déclassâmes": ("déclasser",),
    "déclassant": ("déclasser",),
    "déclassas": ("déclasser",),
    "déclassassent": ("déclasser",),
    "déclassasses": ("déclasser",),
    "déclassasse": ("déclasser",),
    "déclassassiez": ("déclasser",),
    "déclassassions": ("déclasser",),
    "déclassâtes": ("déclasser",),
    "déclassât": ("déclasser",),
    "déclassée": ("déclasser",),
    "déclassées": ("déclasser",),
    "déclassé": ("déclasser",),
    "déclassent": ("déclasser",),
    "déclasse": ("déclasser",),
    "déclassera": ("déclasser",),
    "déclasseraient": ("déclasser",),
    "déclasserai": ("déclasser",),
    "déclasserais": ("déclasser",),
    "déclasserait": ("déclasser",),
    "déclasseras": ("déclasser",),
    "déclassèrent": ("déclasser",),
    "déclasserez": ("déclasser",),
    "déclasseriez": ("déclasser",),
    "déclasserions": ("déclasser",),
    "déclasserons": ("déclasser",),
    "déclasseront": ("déclasser",),
    "déclassés": ("déclasser",),
    "déclasses": ("déclasser",),
    "déclassez": ("déclasser",),
    "déclassiez": ("déclasser",),
    "déclassions": ("déclasser",),
    "déclassons": ("déclasser",),
    "déclassifiaient": ("déclassifier",),
    "déclassifiai": ("déclassifier",),
    "déclassifiais": ("déclassifier",),
    "déclassifiait": ("déclassifier",),
    "déclassifia": ("déclassifier",),
    "déclassifiâmes": ("déclassifier",),
    "déclassifiant": ("déclassifier",),
    "déclassifias": ("déclassifier",),
    "déclassifiassent": ("déclassifier",),
    "déclassifiasses": ("déclassifier",),
    "déclassifiasse": ("déclassifier",),
    "déclassifiassiez": ("déclassifier",),
    "déclassifiassions": ("déclassifier",),
    "déclassifiâtes": ("déclassifier",),
    "déclassifiât": ("déclassifier",),
    "déclassifiée": ("déclassifier",),
    "déclassifiées": ("déclassifier",),
    "déclassifié": ("déclassifier",),
    "déclassifient": ("déclassifier",),
    "déclassifie": ("déclassifier",),
    "déclassifiera": ("déclassifier",),
    "déclassifieraient": ("déclassifier",),
    "déclassifierai": ("déclassifier",),
    "déclassifierais": ("déclassifier",),
    "déclassifierait": ("déclassifier",),
    "déclassifieras": ("déclassifier",),
    "déclassifièrent": ("déclassifier",),
    "déclassifierez": ("déclassifier",),
    "déclassifieriez": ("déclassifier",),
    "déclassifierions": ("déclassifier",),
    "déclassifierons": ("déclassifier",),
    "déclassifieront": ("déclassifier",),
    "déclassifiés": ("déclassifier",),
    "déclassifies": ("déclassifier",),
    "déclassifiez": ("déclassifier",),
    "déclassifiiez": ("déclassifier",),
    "déclassifiions": ("déclassifier",),
    "déclassifions": ("déclassifier",),
    "déclavetaient": ("déclaveter",),
    "déclavetai": ("déclaveter",),
    "déclavetais": ("déclaveter",),
    "déclavetait": ("déclaveter",),
    "déclaveta": ("déclaveter",),
    "déclavetâmes": ("déclaveter",),
    "déclavetant": ("déclaveter",),
    "déclavetas": ("déclaveter",),
    "déclavetassent": ("déclaveter",),
    "déclavetasses": ("déclaveter",),
    "déclavetasse": ("déclaveter",),
    "déclavetassiez": ("déclaveter",),
    "déclavetassions": ("déclaveter",),
    "déclavetâtes": ("déclaveter",),
    "déclavetât": ("déclaveter",),
    "déclavetée": ("déclaveter",),
    "déclavetées": ("déclaveter",),
    "déclaveté": ("déclaveter",),
    "déclavetèrent": ("déclaveter",),
    "déclavetés": ("déclaveter",),
    "déclavetez": ("déclaveter",),
    "déclavetiez": ("déclaveter",),
    "déclavetions": ("déclaveter",),
    "déclavetons": ("déclaveter",),
    "déclavettent": ("déclaveter",),
    "déclavette": ("déclaveter",),
    "déclavettera": ("déclaveter",),
    "déclavetteraient": ("déclaveter",),
    "déclavetterai": ("déclaveter",),
    "déclavetterais": ("déclaveter",),
    "déclavetterait": ("déclaveter",),
    "déclavetteras": ("déclaveter",),
    "déclavetterez": ("déclaveter",),
    "déclavetteriez": ("déclaveter",),
    "déclavetterions": ("déclaveter",),
    "déclavetterons": ("déclaveter",),
    "déclavetteront": ("déclaveter",),
    "déclavettes": ("déclaveter",),
    "déclergifiaient": ("déclergifier",),
    "déclergifiai": ("déclergifier",),
    "déclergifiais": ("déclergifier",),
    "déclergifiait": ("déclergifier",),
    "déclergifia": ("déclergifier",),
    "déclergifiâmes": ("déclergifier",),
    "déclergifiant": ("déclergifier",),
    "déclergifias": ("déclergifier",),
    "déclergifiassent": ("déclergifier",),
    "déclergifiasses": ("déclergifier",),
    "déclergifiasse": ("déclergifier",),
    "déclergifiassiez": ("déclergifier",),
    "déclergifiassions": ("déclergifier",),
    "déclergifiâtes": ("déclergifier",),
    "déclergifiât": ("déclergifier",),
    "déclergifiée": ("déclergifier",),
    "déclergifiées": ("déclergifier",),
    "déclergifié": ("déclergifier",),
    "déclergifient": ("déclergifier",),
    "déclergifie": ("déclergifier",),
    "déclergifiera": ("déclergifier",),
    "déclergifieraient": ("déclergifier",),
    "déclergifierai": ("déclergifier",),
    "déclergifierais": ("déclergifier",),
    "déclergifierait": ("déclergifier",),
    "déclergifieras": ("déclergifier",),
    "déclergifièrent": ("déclergifier",),
    "déclergifierez": ("déclergifier",),
    "déclergifieriez": ("déclergifier",),
    "déclergifierions": ("déclergifier",),
    "déclergifierons": ("déclergifier",),
    "déclergifieront": ("déclergifier",),
    "déclergifiés": ("déclergifier",),
    "déclergifies": ("déclergifier",),
    "déclergifiez": ("déclergifier",),
    "déclergifiiez": ("déclergifier",),
    "déclergifiions": ("déclergifier",),
    "déclergifions": ("déclergifier",),
    "décliquetaient": ("décliqueter",),
    "décliquetai": ("décliqueter",),
    "décliquetais": ("décliqueter",),
    "décliquetait": ("décliqueter",),
    "décliqueta": ("décliqueter",),
    "décliquetâmes": ("décliqueter",),
    "décliquetant": ("décliqueter",),
    "décliquetas": ("décliqueter",),
    "décliquetassent": ("décliqueter",),
    "décliquetasses": ("décliqueter",),
    "décliquetasse": ("décliqueter",),
    "décliquetassiez": ("décliqueter",),
    "décliquetassions": ("décliqueter",),
    "décliquetâtes": ("décliqueter",),
    "décliquetât": ("décliqueter",),
    "décliquetée": ("décliqueter",),
    "décliquetées": ("décliqueter",),
    "décliqueté": ("décliqueter",),
    "décliquetèrent": ("décliqueter",),
    "décliquetés": ("décliqueter",),
    "décliquetez": ("décliqueter",),
    "décliquetiez": ("décliqueter",),
    "décliquetions": ("décliqueter",),
    "décliquetons": ("décliqueter",),
    "décliquettent": ("décliqueter",),
    "décliquette": ("décliqueter",),
    "décliquettera": ("décliqueter",),
    "décliquetteraient": ("décliqueter",),
    "décliquetterai": ("décliqueter",),
    "décliquetterais": ("décliqueter",),
    "décliquetterait": ("décliqueter",),
    "décliquetteras": ("décliqueter",),
    "décliquetterez": ("décliqueter",),
    "décliquetteriez": ("décliqueter",),
    "décliquetterions": ("décliqueter",),
    "décliquetterons": ("décliqueter",),
    "décliquetteront": ("décliqueter",),
    "décliquettes": ("décliqueter",),
    "déclora": ("déclore",),
    "décloraient": ("déclore",),
    "déclorai": ("déclore",),
    "déclorais": ("déclore",),
    "déclorait": ("déclore",),
    "décloras": ("déclore",),
    "déclorez": ("déclore",),
    "décloriez": ("déclore",),
    "déclorions": ("déclore",),
    "déclorons": ("déclore",),
    "décloront": ("déclore",),
    "déclosant": ("déclore",),
    "déclose": ("déclore",),
    "déclosent": ("déclore",),
    "décloses": ("déclore",),
    "déclosez": ("déclore",),
    "déclosiez": ("déclore",),
    "déclosions": ("déclore",),
    "déclos": ("déclore",),
    "déclosons": ("déclore",),
    "déclot": ("déclore",),
    "déclôt": ("déclore",),
    "décodifiaient": ("décodifier",),
    "décodifiai": ("décodifier",),
    "décodifiais": ("décodifier",),
    "décodifiait": ("décodifier",),
    "décodifia": ("décodifier",),
    "décodifiâmes": ("décodifier",),
    "décodifiant": ("décodifier",),
    "décodifias": ("décodifier",),
    "décodifiassent": ("décodifier",),
    "décodifiasses": ("décodifier",),
    "décodifiasse": ("décodifier",),
    "décodifiassiez": ("décodifier",),
    "décodifiassions": ("décodifier",),
    "décodifiâtes": ("décodifier",),
    "décodifiât": ("décodifier",),
    "décodifiée": ("décodifier",),
    "décodifiées": ("décodifier",),
    "décodifié": ("décodifier",),
    "décodifient": ("décodifier",),
    "décodifie": ("décodifier",),
    "décodifiera": ("décodifier",),
    "décodifieraient": ("décodifier",),
    "décodifierai": ("décodifier",),
    "décodifierais": ("décodifier",),
    "décodifierait": ("décodifier",),
    "décodifieras": ("décodifier",),
    "décodifièrent": ("décodifier",),
    "décodifierez": ("décodifier",),
    "décodifieriez": ("décodifier",),
    "décodifierions": ("décodifier",),
    "décodifierons": ("décodifier",),
    "décodifieront": ("décodifier",),
    "décodifiés": ("décodifier",),
    "décodifies": ("décodifier",),
    "décodifiez": ("décodifier",),
    "décodifiiez": ("décodifier",),
    "décodifiions": ("décodifier",),
    "décodifions": ("décodifier",),
    "décohéraient": ("décohérer",),
    "décohérai": ("décohérer",),
    "décohérais": ("décohérer",),
    "décohérait": ("décohérer",),
    "décohéra": ("décohérer",),
    "décohérâmes": ("décohérer",),
    "décohérant": ("décohérer",),
    "décohéras": ("décohérer",),
    "décohérassent": ("décohérer",),
    "décohérasses": ("décohérer",),
    "décohérasse": ("décohérer",),
    "décohérassiez": ("décohérer",),
    "décohérassions": ("décohérer",),
    "décohérâtes": ("décohérer",),
    "décohérât": ("décohérer",),
    "décohérée": ("décohérer",),
    "décohérées": ("décohérer",),
    "décohéré": ("décohérer",),
    "décohèrent": ("décohérer",),
    "décohère": ("décohérer",),
    "décohérera": ("décohérer",),
    "décohéreraient": ("décohérer",),
    "décohérerai": ("décohérer",),
    "décohérerais": ("décohérer",),
    "décohérerait": ("décohérer",),
    "décohéreras": ("décohérer",),
    "décohérèrent": ("décohérer",),
    "décohérerez": ("décohérer",),
    "décohéreriez": ("décohérer",),
    "décohérerions": ("décohérer",),
    "décohérerons": ("décohérer",),
    "décohéreront": ("décohérer",),
    "décohérés": ("décohérer",),
    "décohères": ("décohérer",),
    "décohérez": ("décohérer",),
    "décohériez": ("décohérer",),
    "décohérions": ("décohérer",),
    "décohérons": ("décohérer",),
    "décoinçaient": ("décoincer",),
    "décoinçai": ("décoincer",),
    "décoinçais": ("décoincer",),
    "décoinçait": ("décoincer",),
    "décoinça": ("décoincer",),
    "décoinçâmes": ("décoincer",),
    "décoinçant": ("décoincer",),
    "décoinças": ("décoincer",),
    "décoinçassent": ("décoincer",),
    "décoinçasses": ("décoincer",),
    "décoinçasse": ("décoincer",),
    "décoinçassiez": ("décoincer",),
    "décoinçassions": ("décoincer",),
    "décoinçâtes": ("décoincer",),
    "décoinçât": ("décoincer",),
    "décoincée": ("décoincer",),
    "décoincées": ("décoincer",),
    "décoincé": ("décoincer",),
    "décoincent": ("décoincer",),
    "décoince": ("décoincer",),
    "décoincera": ("décoincer",),
    "décoinceraient": ("décoincer",),
    "décoincerai": ("décoincer",),
    "décoincerais": ("décoincer",),
    "décoincerait": ("décoincer",),
    "décoinceras": ("décoincer",),
    "décoincèrent": ("décoincer",),
    "décoincerez": ("décoincer",),
    "décoinceriez": ("décoincer",),
    "décoincerions": ("décoincer",),
    "décoincerons": ("décoincer",),
    "décoinceront": ("décoincer",),
    "décoincés": ("décoincer",),
    "décoinces": ("décoincer",),
    "décoincez": ("décoincer",),
    "décoinciez": ("décoincer",),
    "décoincions": ("décoincer",),
    "décoinçons": ("décoincer",),
    "décoléraient": ("décolérer",),
    "décolérai": ("décolérer",),
    "décolérais": ("décolérer",),
    "décolérait": ("décolérer",),
    "décoléra": ("décolérer",),
    "décolérâmes": ("décolérer",),
    "décolérant": ("décolérer",),
    "décoléras": ("décolérer",),
    "décolérassent": ("décolérer",),
    "décolérasses": ("décolérer",),
    "décolérasse": ("décolérer",),
    "décolérassiez": ("décolérer",),
    "décolérassions": ("décolérer",),
    "décolérâtes": ("décolérer",),
    "décolérât": ("décolérer",),
    "décoléré": ("décolérer",),
    "décolèrent": ("décolérer",),
    "décolère": ("décolérer",),
    "décolérera": ("décolérer",),
    "décoléreraient": ("décolérer",),
    "décolérerai": ("décolérer",),
    "décolérerais": ("décolérer",),
    "décolérerait": ("décolérer",),
    "décoléreras": ("décolérer",),
    "décolérèrent": ("décolérer",),
    "décolérerez": ("décolérer",),
    "décoléreriez": ("décolérer",),
    "décolérerions": ("décolérer",),
    "décolérerons": ("décolérer",),
    "décoléreront": ("décolérer",),
    "décolères": ("décolérer",),
    "décolérez": ("décolérer",),
    "décolériez": ("décolérer",),
    "décolérions": ("décolérer",),
    "décolérons": ("décolérer",),
    "décolletaient": ("décolleter",),
    "décolletai": ("décolleter",),
    "décolletais": ("décolleter",),
    "décolletait": ("décolleter",),
    "décolleta": ("décolleter",),
    "décolletâmes": ("décolleter",),
    "décolletant": ("décolleter",),
    "décolletas": ("décolleter",),
    "décolletassent": ("décolleter",),
    "décolletasses": ("décolleter",),
    "décolletasse": ("décolleter",),
    "décolletassiez": ("décolleter",),
    "décolletassions": ("décolleter",),
    "décolletâtes": ("décolleter",),
    "décolletât": ("décolleter",),
    "décolletée": ("décolleter",),
    "décolletées": ("décolleter",),
    "décolleté": ("décolleter",),
    "décolletèrent": ("décolleter",),
    "décolletés": ("décolleter",),
    "décolletez": ("décolleter",),
    "décolletiez": ("décolleter",),
    "décolletions": ("décolleter",),
    "décolletons": ("décolleter",),
    "décollettent": ("décolleter",),
    "décollette": ("décolleter",),
    "décollettera": ("décolleter",),
    "décolletteraient": ("décolleter",),
    "décolletterai": ("décolleter",),
    "décolletterais": ("décolleter",),
    "décolletterait": ("décolleter",),
    "décolletteras": ("décolleter",),
    "décolletterez": ("décolleter",),
    "décolletteriez": ("décolleter",),
    "décolletterions": ("décolleter",),
    "décolletterons": ("décolleter",),
    "décolletteront": ("décolleter",),
    "décollettes": ("décolleter",),
    "décommet": ("décommettre",),
    "décommets": ("décommettre",),
    "décommettaient": ("décommettre",),
    "décommettais": ("décommettre",),
    "décommettait": ("décommettre",),
    "décommettant": ("décommettre",),
    "décommettent": ("décommettre",),
    "décommette": ("décommettre",),
    "décommettes": ("décommettre",),
    "décommettez": ("décommettre",),
    "décommettiez": ("décommettre",),
    "décommettions": ("décommettre",),
    "décommettons": ("décommettre",),
    "décommettra": ("décommettre",),
    "décommettraient": ("décommettre",),
    "décommettrai": ("décommettre",),
    "décommettrais": ("décommettre",),
    "décommettrait": ("décommettre",),
    "décommettras": ("décommettre",),
    "décommettrez": ("décommettre",),
    "décommettriez": ("décommettre",),
    "décommettrions": ("décommettre",),
    "décommettrons": ("décommettre",),
    "décommettront": ("décommettre",),
    "décommîmes": ("décommettre",),
    "décommirent": ("décommettre",),
    "décommise": ("décommettre",),
    "décommises": ("décommettre",),
    "décommis": ("décommettre",),
    "décommissent": ("décommettre",),
    "décommisses": ("décommettre",),
    "décommisse": ("décommettre",),
    "décommissiez": ("décommettre",),
    "décommissions": ("décommettre",),
    "décommîtes": ("décommettre",),
    "décommit": ("décommettre",),
    "décommît": ("décommettre",),
    "décomplétaient": ("décompléter",),
    "décomplétai": ("décompléter",),
    "décomplétais": ("décompléter",),
    "décomplétait": ("décompléter",),
    "décompléta": ("décompléter",),
    "décomplétâmes": ("décompléter",),
    "décomplétant": ("décompléter",),
    "décomplétas": ("décompléter",),
    "décomplétassent": ("décompléter",),
    "décomplétasses": ("décompléter",),
    "décomplétasse": ("décompléter",),
    "décomplétassiez": ("décompléter",),
    "décomplétassions": ("décompléter",),
    "décomplétâtes": ("décompléter",),
    "décomplétât": ("décompléter",),
    "décomplétée": ("décompléter",),
    "décomplétées": ("décompléter",),
    "décomplété": ("décompléter",),
    "décomplètent": ("décompléter",),
    "décomplète": ("décompléter",),
    "décomplétera": ("décompléter",),
    "décompléteraient": ("décompléter",),
    "décompléterai": ("décompléter",),
    "décompléterais": ("décompléter",),
    "décompléterait": ("décompléter",),
    "décompléteras": ("décompléter",),
    "décomplétèrent": ("décompléter",),
    "décompléterez": ("décompléter",),
    "décompléteriez": ("décompléter",),
    "décompléterions": ("décompléter",),
    "décompléterons": ("décompléter",),
    "décompléteront": ("décompléter",),
    "décomplétés": ("décompléter",),
    "décomplètes": ("décompléter",),
    "décomplétez": ("décompléter",),
    "décomplétiez": ("décompléter",),
    "décomplétions": ("décompléter",),
    "décomplétons": ("décompléter",),
    "déconfîmes": ("déconfire",),
    "déconfira": ("déconfire",),
    "déconfiraient": ("déconfire",),
    "déconfirai": ("déconfire",),
    "déconfirais": ("déconfire",),
    "déconfirait": ("déconfire",),
    "déconfiras": ("déconfire",),
    "déconfirent": ("déconfire",),
    "déconfirez": ("déconfire",),
    "déconfiriez": ("déconfire",),
    "déconfirions": ("déconfire",),
    "déconfirons": ("déconfire",),
    "déconfiront": ("déconfire",),
    "déconfisaient": ("déconfire",),
    "déconfisais": ("déconfire",),
    "déconfisait": ("déconfire",),
    "déconfisant": ("déconfire",),
    "déconfisent": ("déconfire",),
    "déconfise": ("déconfire",),
    "déconfises": ("déconfire",),
    "déconfisez": ("déconfire",),
    "déconfisiez": ("déconfire",),
    "déconfisions": ("déconfire",),
    "déconfisons": ("déconfire",),
    "déconfis": ("déconfire",),
    "déconfissent": ("déconfire",),
    "déconfisses": ("déconfire",),
    "déconfisse": ("déconfire",),
    "déconfissiez": ("déconfire",),
    "déconfissions": ("déconfire",),
    "déconfite": ("déconfire",),
    "déconfîtes": ("déconfire",),
    "déconfites": ("déconfire",),
    "déconfit": ("déconfire",),
    "déconfits": ("déconfire",),
    "déconfît": ("déconfire",),
    "décongelaient": ("décongeler",),
    "décongelai": ("décongeler",),
    "décongelais": ("décongeler",),
    "décongelait": ("décongeler",),
    "décongela": ("décongeler",),
    "décongelâmes": ("décongeler",),
    "décongelant": ("décongeler",),
    "décongelas": ("décongeler",),
    "décongelassent": ("décongeler",),
    "décongelasses": ("décongeler",),
    "décongelasse": ("décongeler",),
    "décongelassiez": ("décongeler",),
    "décongelassions": ("décongeler",),
    "décongelâtes": ("décongeler",),
    "décongelât": ("décongeler",),
    "décongelée": ("décongeler",),
    "décongelées": ("décongeler",),
    "décongelé": ("décongeler",),
    "décongèlent": ("décongeler",),
    "décongèle": ("décongeler",),
    "décongèlera": ("décongeler",),
    "décongèleraient": ("décongeler",),
    "décongèlerai": ("décongeler",),
    "décongèlerais": ("décongeler",),
    "décongèlerait": ("décongeler",),
    "décongèleras": ("décongeler",),
    "décongelèrent": ("décongeler",),
    "décongèlerez": ("décongeler",),
    "décongèleriez": ("décongeler",),
    "décongèlerions": ("décongeler",),
    "décongèlerons": ("décongeler",),
    "décongèleront": ("décongeler",),
    "décongelés": ("décongeler",),
    "décongèles": ("décongeler",),
    "décongelez": ("décongeler",),
    "décongeliez": ("décongeler",),
    "décongelions": ("décongeler",),
    "décongelons": ("décongeler",),
    "déconsidéraient": ("déconsidérer",),
    "déconsidérai": ("déconsidérer",),
    "déconsidérais": ("déconsidérer",),
    "déconsidérait": ("déconsidérer",),
    "déconsidéra": ("déconsidérer",),
    "déconsidérâmes": ("déconsidérer",),
    "déconsidérant": ("déconsidérer",),
    "déconsidéras": ("déconsidérer",),
    "déconsidérassent": ("déconsidérer",),
    "déconsidérasses": ("déconsidérer",),
    "déconsidérasse": ("déconsidérer",),
    "déconsidérassiez": ("déconsidérer",),
    "déconsidérassions": ("déconsidérer",),
    "déconsidérâtes": ("déconsidérer",),
    "déconsidérât": ("déconsidérer",),
    "déconsidérée": ("déconsidérer",),
    "déconsidérées": ("déconsidérer",),
    "déconsidéré": ("déconsidérer",),
    "déconsidèrent": ("déconsidérer",),
    "déconsidère": ("déconsidérer",),
    "déconsidérera": ("déconsidérer",),
    "déconsidéreraient": ("déconsidérer",),
    "déconsidérerai": ("déconsidérer",),
    "déconsidérerais": ("déconsidérer",),
    "déconsidérerait": ("déconsidérer",),
    "déconsidéreras": ("déconsidérer",),
    "déconsidérèrent": ("déconsidérer",),
    "déconsidérerez": ("déconsidérer",),
    "déconsidéreriez": ("déconsidérer",),
    "déconsidérerions": ("déconsidérer",),
    "déconsidérerons": ("déconsidérer",),
    "déconsidéreront": ("déconsidérer",),
    "déconsidérés": ("déconsidérer",),
    "déconsidères": ("déconsidérer",),
    "déconsidérez": ("déconsidérer",),
    "déconsidériez": ("déconsidérer",),
    "déconsidérions": ("déconsidérer",),
    "déconsidérons": ("déconsidérer",),
    "déconstruira": ("déconstruire",),
    "déconstruiraient": ("déconstruire",),
    "déconstruirai": ("déconstruire",),
    "déconstruirais": ("déconstruire",),
    "déconstruirait": ("déconstruire",),
    "déconstruiras": ("déconstruire",),
    "déconstruirez": ("déconstruire",),
    "déconstruiriez": ("déconstruire",),
    "déconstruirions": ("déconstruire",),
    "déconstruirons": ("déconstruire",),
    "déconstruiront": ("déconstruire",),
    "déconstruisaient": ("déconstruire",),
    "déconstruisais": ("déconstruire",),
    "déconstruisait": ("déconstruire",),
    "déconstruisant": ("déconstruire",),
    "déconstruisent": ("déconstruire",),
    "déconstruise": ("déconstruire",),
    "déconstruises": ("déconstruire",),
    "déconstruisez": ("déconstruire",),
    "déconstruisiez": ("déconstruire",),
    "déconstruisîmes": ("déconstruire",),
    "déconstruisions": ("déconstruire",),
    "déconstruisirent": ("déconstruire",),
    "déconstruisis": ("déconstruire",),
    "déconstruisissent": ("déconstruire",),
    "déconstruisisses": ("déconstruire",),
    "déconstruisisse": ("déconstruire",),
    "déconstruisissiez": ("déconstruire",),
    "déconstruisissions": ("déconstruire",),
    "déconstruisîtes": ("déconstruire",),
    "déconstruisit": ("déconstruire",),
    "déconstruisît": ("déconstruire",),
    "déconstruisons": ("déconstruire",),
    "déconstruis": ("déconstruire",),
    "déconstruite": ("déconstruire",),
    "déconstruites": ("déconstruire",),
    "déconstruit": ("déconstruire",),
    "déconstruits": ("déconstruire",),
    "décontenançaient": ("décontenancer",),
    "décontenançai": ("décontenancer",),
    "décontenançais": ("décontenancer",),
    "décontenançait": ("décontenancer",),
    "décontenança": ("décontenancer",),
    "décontenançâmes": ("décontenancer",),
    "décontenançant": ("décontenancer",),
    "décontenanças": ("décontenancer",),
    "décontenançassent": ("décontenancer",),
    "décontenançasses": ("décontenancer",),
    "décontenançasse": ("décontenancer",),
    "décontenançassiez": ("décontenancer",),
    "décontenançassions": ("décontenancer",),
    "décontenançâtes": ("décontenancer",),
    "décontenançât": ("décontenancer",),
    "décontenancée": ("décontenancer",),
    "décontenancées": ("décontenancer",),
    "décontenancé": ("décontenancer",),
    "décontenancent": ("décontenancer",),
    "décontenance": ("décontenancer",),
    "décontenancera": ("décontenancer",),
    "décontenanceraient": ("décontenancer",),
    "décontenancerai": ("décontenancer",),
    "décontenancerais": ("décontenancer",),
    "décontenancerait": ("décontenancer",),
    "décontenanceras": ("décontenancer",),
    "décontenancèrent": ("décontenancer",),
    "décontenancerez": ("décontenancer",),
    "décontenanceriez": ("décontenancer",),
    "décontenancerions": ("décontenancer",),
    "décontenancerons": ("décontenancer",),
    "décontenanceront": ("décontenancer",),
    "décontenancés": ("décontenancer",),
    "décontenances": ("décontenancer",),
    "décontenancez": ("décontenancer",),
    "décontenanciez": ("décontenancer",),
    "décontenancions": ("décontenancer",),
    "décontenançons": ("décontenancer",),
    "découd": ("découdre",),
    "découdra": ("découdre",),
    "découdraient": ("découdre",),
    "découdrai": ("découdre",),
    "découdrais": ("découdre",),
    "découdrait": ("découdre",),
    "découdras": ("découdre",),
    "découdrez": ("découdre",),
    "découdriez": ("découdre",),
    "découdrions": ("découdre",),
    "découdrons": ("découdre",),
    "découdront": ("découdre",),
    "découds": ("découdre",),
    "décousaient": ("découdre",),
    "décousais": ("découdre",),
    "décousait": ("découdre",),
    "décousant": ("découdre",),
    "décousent": ("découdre",),
    "découse": ("découdre",),
    "découses": ("découdre",),
    "décousez": ("découdre",),
    "décousiez": ("découdre",),
    "décousîmes": ("découdre",),
    "décousions": ("découdre",),
    "décousirent": ("découdre",),
    "décousis": ("découdre",),
    "décousissent": ("découdre",),
    "décousisses": ("découdre",),
    "décousisse": ("découdre",),
    "décousissiez": ("découdre",),
    "décousissions": ("découdre",),
    "décousîtes": ("découdre",),
    "décousit": ("découdre",),
    "décousît": ("découdre",),
    "décousons": ("découdre",),
    "décousue": ("découdre",),
    "décousues": ("découdre",),
    "décousu": ("découdre",),
    "décousus": ("découdre",),
    "décourageaient": ("décourager",),
    "décourageai": ("décourager",),
    "décourageais": ("décourager",),
    "décourageait": ("décourager",),
    "découragea": ("décourager",),
    "décourageâmes": ("décourager",),
    "décourageant": ("décourager",),
    "décourageas": ("décourager",),
    "décourageassent": ("décourager",),
    "décourageasses": ("décourager",),
    "décourageasse": ("décourager",),
    "décourageassiez": ("décourager",),
    "décourageassions": ("décourager",),
    "décourageâtes": ("décourager",),
    "décourageât": ("décourager",),
    "découragée": ("décourager",),
    "découragées": ("décourager",),
    "découragé": ("décourager",),
    "découragent": ("décourager",),
    "décourageons": ("décourager",),
    "décourage": ("décourager",),
    "découragera": ("décourager",),
    "décourageraient": ("décourager",),
    "découragerai": ("décourager",),
    "découragerais": ("décourager",),
    "découragerait": ("décourager",),
    "décourageras": ("décourager",),
    "découragèrent": ("décourager",),
    "découragerez": ("décourager",),
    "décourageriez": ("décourager",),
    "découragerions": ("décourager",),
    "découragerons": ("décourager",),
    "décourageront": ("décourager",),
    "découragés": ("décourager",),
    "décourages": ("décourager",),
    "découragez": ("décourager",),
    "découragiez": ("décourager",),
    "découragions": ("décourager",),
    "découverte": ("découvrir",),
    "découvertes": ("découvrir",),
    "découvert": ("découvrir",),
    "découverts": ("découvrir",),
    "découvraient": ("découvrir",),
    "découvrais": ("découvrir",),
    "découvrait": ("découvrir",),
    "découvrant": ("découvrir",),
    "découvrent": ("découvrir",),
    "découvre": ("découvrir",),
    "découvres": ("découvrir",),
    "découvrez": ("découvrir",),
    "découvriez": ("découvrir",),
    "découvrîmes": ("découvrir",),
    "découvrions": ("découvrir",),
    "découvrira": ("découvrir",),
    "découvriraient": ("découvrir",),
    "découvrirai": ("découvrir",),
    "découvrirais": ("découvrir",),
    "découvrirait": ("découvrir",),
    "découvriras": ("découvrir",),
    "découvrirent": ("découvrir",),
    "découvrirez": ("découvrir",),
    "découvririez": ("découvrir",),
    "découvririons": ("découvrir",),
    "découvrirons": ("découvrir",),
    "découvriront": ("découvrir",),
    "découvris": ("découvrir",),
    "découvrissent": ("découvrir",),
    "découvrisses": ("découvrir",),
    "découvrisse": ("découvrir",),
    "découvrissiez": ("découvrir",),
    "découvrissions": ("découvrir",),
    "découvrîtes": ("découvrir",),
    "découvrit": ("découvrir",),
    "découvrît": ("découvrir",),
    "découvrons": ("découvrir",),
    "décrassaient": ("décrasser",),
    "décrassai": ("décrasser",),
    "décrassais": ("décrasser",),
    "décrassait": ("décrasser",),
    "décrassa": ("décrasser",),
    "décrassâmes": ("décrasser",),
    "décrassant": ("décrasser",),
    "décrassas": ("décrasser",),
    "décrassassent": ("décrasser",),
    "décrassasses": ("décrasser",),
    "décrassasse": ("décrasser",),
    "décrassassiez": ("décrasser",),
    "décrassassions": ("décrasser",),
    "décrassâtes": ("décrasser",),
    "décrassât": ("décrasser",),
    "décrassée": ("décrasser",),
    "décrassées": ("décrasser",),
    "décrassé": ("décrasser",),
    "décrassent": ("décrasser",),
    "décrasse": ("décrasser",),
    "décrassera": ("décrasser",),
    "décrasseraient": ("décrasser",),
    "décrasserai": ("décrasser",),
    "décrasserais": ("décrasser",),
    "décrasserait": ("décrasser",),
    "décrasseras": ("décrasser",),
    "décrassèrent": ("décrasser",),
    "décrasserez": ("décrasser",),
    "décrasseriez": ("décrasser",),
    "décrasserions": ("décrasser",),
    "décrasserons": ("décrasser",),
    "décrasseront": ("décrasser",),
    "décrassés": ("décrasser",),
    "décrasses": ("décrasser",),
    "décrassez": ("décrasser",),
    "décrassiez": ("décrasser",),
    "décrassions": ("décrasser",),
    "décrassons": ("décrasser",),
    "décrêpelaient": ("décrêpeler",),
    "décrêpelai": ("décrêpeler",),
    "décrêpelais": ("décrêpeler",),
    "décrêpelait": ("décrêpeler",),
    "décrêpela": ("décrêpeler",),
    "décrêpelâmes": ("décrêpeler",),
    "décrêpelant": ("décrêpeler",),
    "décrêpelas": ("décrêpeler",),
    "décrêpelassent": ("décrêpeler",),
    "décrêpelasses": ("décrêpeler",),
    "décrêpelasse": ("décrêpeler",),
    "décrêpelassiez": ("décrêpeler",),
    "décrêpelassions": ("décrêpeler",),
    "décrêpelâtes": ("décrêpeler",),
    "décrêpelât": ("décrêpeler",),
    "décrêpelée": ("décrêpeler",),
    "décrêpelées": ("décrêpeler",),
    "décrêpelé": ("décrêpeler",),
    "décrêpelèrent": ("décrêpeler",),
    "décrêpelés": ("décrêpeler",),
    "décrêpelez": ("décrêpeler",),
    "décrêpeliez": ("décrêpeler",),
    "décrêpelions": ("décrêpeler",),
    "décrêpellent": ("décrêpeler",),
    "décrêpelle": ("décrêpeler",),
    "décrêpellera": ("décrêpeler",),
    "décrêpelleraient": ("décrêpeler",),
    "décrêpellerai": ("décrêpeler",),
    "décrêpellerais": ("décrêpeler",),
    "décrêpellerait": ("décrêpeler",),
    "décrêpelleras": ("décrêpeler",),
    "décrêpellerez": ("décrêpeler",),
    "décrêpelleriez": ("décrêpeler",),
    "décrêpellerions": ("décrêpeler",),
    "décrêpellerons": ("décrêpeler",),
    "décrêpelleront": ("décrêpeler",),
    "décrêpelles": ("décrêpeler",),
    "décrêpelons": ("décrêpeler",),
    "décrépie": ("décrépir",),
    "décrépies": ("décrépir",),
    "décrépi": ("décrépir",),
    "décrépîmes": ("décrépir",),
    "décrépira": ("décrépir",),
    "décrépiraient": ("décrépir",),
    "décrépirai": ("décrépir",),
    "décrépirais": ("décrépir",),
    "décrépirait": ("décrépir",),
    "décrépiras": ("décrépir",),
    "décrépirent": ("décrépir",),
    "décrépirez": ("décrépir",),
    "décrépiriez": ("décrépir",),
    "décrépirions": ("décrépir",),
    "décrépirons": ("décrépir",),
    "décrépiront": ("décrépir",),
    "décrépis": ("décrépir",),
    "décrépissaient": ("décrépir",),
    "décrépissais": ("décrépir",),
    "décrépissait": ("décrépir",),
    "décrépissant": ("décrépir",),
    "décrépissent": ("décrépir",),
    "décrépisse": ("décrépir",),
    "décrépisses": ("décrépir",),
    "décrépissez": ("décrépir",),
    "décrépissiez": ("décrépir",),
    "décrépissions": ("décrépir",),
    "décrépissons": ("décrépir",),
    "décrépîtes": ("décrépir",),
    "décrépit": ("décrépir",),
    "décrépît": ("décrépir",),
    "décrétaient": ("décréter",),
    "décrétai": ("décréter",),
    "décrétais": ("décréter",),
    "décrétait": ("décréter",),
    "décréta": ("décréter",),
    "décrétâmes": ("décréter",),
    "décrétant": ("décréter",),
    "décrétas": ("décréter",),
    "décrétassent": ("décréter",),
    "décrétasses": ("décréter",),
    "décrétasse": ("décréter",),
    "décrétassiez": ("décréter",),
    "décrétassions": ("décréter",),
    "décrétâtes": ("décréter",),
    "décrétât": ("décréter",),
    "décrétée": ("décréter",),
    "décrétées": ("décréter",),
    "décrété": ("décréter",),
    "décrètent": ("décréter",),
    "décrète": ("décréter",),
    "décrétera": ("décréter",),
    "décréteraient": ("décréter",),
    "décréterai": ("décréter",),
    "décréterais": ("décréter",),
    "décréterait": ("décréter",),
    "décréteras": ("décréter",),
    "décrétèrent": ("décréter",),
    "décréterez": ("décréter",),
    "décréteriez": ("décréter",),
    "décréterions": ("décréter",),
    "décréterons": ("décréter",),
    "décréteront": ("décréter",),
    "décrétés": ("décréter",),
    "décrètes": ("décréter",),
    "décrétez": ("décréter",),
    "décrétiez": ("décréter",),
    "décrétions": ("décréter",),
    "décrétons": ("décréter",),
    "décriaient": ("décrier",),
    "décriai": ("décrier",),
    "décriais": ("décrier",),
    "décriait": ("décrier",),
    "décria": ("décrier",),
    "décriâmes": ("décrier",),
    "décriant": ("décrier",),
    "décrias": ("décrier",),
    "décriassent": ("décrier",),
    "décriasses": ("décrier",),
    "décriasse": ("décrier",),
    "décriassiez": ("décrier",),
    "décriassions": ("décrier",),
    "décriâtes": ("décrier",),
    "décriât": ("décrier",),
    "décriée": ("décrier",),
    "décriées": ("décrier",),
    "décrié": ("décrier",),
    "décrient": ("décrier",),
    "décrie": ("décrier",),
    "décriera": ("décrier",),
    "décrieraient": ("décrier",),
    "décrierai": ("décrier",),
    "décrierais": ("décrier",),
    "décrierait": ("décrier",),
    "décrieras": ("décrier",),
    "décrièrent": ("décrier",),
    "décrierez": ("décrier",),
    "décrieriez": ("décrier",),
    "décrierions": ("décrier",),
    "décrierons": ("décrier",),
    "décrieront": ("décrier",),
    "décriés": ("décrier",),
    "décries": ("décrier",),
    "décriez": ("décrier",),
    "décriiez": ("décrier",),
    "décriions": ("décrier",),
    "décrions": ("décrier",),
    "décrira": ("décrire",),
    "décriraient": ("décrire",),
    "décrirai": ("décrire",),
    "décrirais": ("décrire",),
    "décrirait": ("décrire",),
    "décriras": ("décrire",),
    "décrirez": ("décrire",),
    "décririez": ("décrire",),
    "décririons": ("décrire",),
    "décrirons": ("décrire",),
    "décriront": ("décrire",),
    "décris": ("décrire",),
    "décrite": ("décrire",),
    "décrites": ("décrire",),
    "décrit": ("décrire",),
    "décrits": ("décrire",),
    "décrivaient": ("décrire",),
    "décrivais": ("décrire",),
    "décrivait": ("décrire",),
    "décrivant": ("décrire",),
    "décrivent": ("décrire",),
    "décrive": ("décrire",),
    "décrives": ("décrire",),
    "décrivez": ("décrire",),
    "décriviez": ("décrire",),
    "décrivîmes": ("décrire",),
    "décrivions": ("décrire",),
    "décrivirent": ("décrire",),
    "décrivis": ("décrire",),
    "décrivissent": ("décrire",),
    "décrivisses": ("décrire",),
    "décrivisse": ("décrire",),
    "décrivissiez": ("décrire",),
    "décrivissions": ("décrire",),
    "décrivîtes": ("décrire",),
    "décrivit": ("décrire",),
    "décrivît": ("décrire",),
    "décrivons": ("décrire",),
    "décrochie": ("décrochir",),
    "décrochies": ("décrochir",),
    "décrochi": ("décrochir",),
    "décrochîmes": ("décrochir",),
    "décrochira": ("décrochir",),
    "décrochiraient": ("décrochir",),
    "décrochirai": ("décrochir",),
    "décrochirais": ("décrochir",),
    "décrochirait": ("décrochir",),
    "décrochiras": ("décrochir",),
    "décrochirent": ("décrochir",),
    "décrochirez": ("décrochir",),
    "décrochiriez": ("décrochir",),
    "décrochirions": ("décrochir",),
    "décrochirons": ("décrochir",),
    "décrochiront": ("décrochir",),
    "décrochis": ("décrochir",),
    "décrochissaient": ("décrochir",),
    "décrochissais": ("décrochir",),
    "décrochissait": ("décrochir",),
    "décrochissant": ("décrochir",),
    "décrochissent": ("décrochir",),
    "décrochisse": ("décrochir",),
    "décrochisses": ("décrochir",),
    "décrochissez": ("décrochir",),
    "décrochissiez": ("décrochir",),
    "décrochissions": ("décrochir",),
    "décrochissons": ("décrochir",),
    "décrochîtes": ("décrochir",),
    "décrochit": ("décrochir",),
    "décrochît": ("décrochir",),
    "décroient": ("décroire",),
    "décroie": ("décroire",),
    "décroies": ("décroire",),
    "décroira": ("décroire",),
    "décroiraient": ("décroire",),
    "décroirai": ("décroire",),
    "décroirais": ("décroire",),
    "décroirait": ("décroire",),
    "décroiras": ("décroire",),
    "décroirez": ("décroire",),
    "décroiriez": ("décroire",),
    "décroirions": ("décroire",),
    "décroirons": ("décroire",),
    "décroiront": ("décroire",),
    "décrois": ("décroître",),
    "décroit": ("décroire",),
    "décroyaient": ("décroire",),
    "décroyais": ("décroire",),
    "décroyait": ("décroire",),
    "décroyant": ("décroire",),
    "décroyez": ("décroire",),
    "décroyiez": ("décroire",),
    "décroyions": ("décroire",),
    "décroyons": ("décroire",),
    "décrue": ("décroître",),
    "décrues": ("décroître",),
    "décru": ("décroître",),
    "décrûmes": ("décroître",),
    "décrurent": ("décroître",),
    "décrus": ("décroître",),
    "décrussent": ("décroître",),
    "décrusses": ("décroître",),
    "décrusse": ("décroître",),
    "décrussiez": ("décroître",),
    "décrussions": ("décroître",),
    "décrûtes": ("décroître",),
    "décrut": ("décroître",),
    "décrût": ("décroître",),
    "décroissaient": ("décroître",),
    "décroissais": ("décroître",),
    "décroissait": ("décroître",),
    "décroissant": ("décroître",),
    "décroissent": ("décroître",),
    "décroisse": ("décroître",),
    "décroisses": ("décroître",),
    "décroissez": ("décroître",),
    "décroissiez": ("décroître",),
    "décroissions": ("décroître",),
    "décroissons": ("décroître",),
    "décroît": ("décroître",),
    "décroîtra": ("décroître",),
    "décroîtraient": ("décroître",),
    "décroîtrai": ("décroître",),
    "décroîtrais": ("décroître",),
    "décroîtrait": ("décroître",),
    "décroîtras": ("décroître",),
    "décroîtrez": ("décroître",),
    "décroîtriez": ("décroître",),
    "décroîtrions": ("décroître",),
    "décroîtrons": ("décroître",),
    "décroîtront": ("décroître",),
    "décrucifiaient": ("décrucifier",),
    "décrucifiai": ("décrucifier",),
    "décrucifiais": ("décrucifier",),
    "décrucifiait": ("décrucifier",),
    "décrucifia": ("décrucifier",),
    "décrucifiâmes": ("décrucifier",),
    "décrucifiant": ("décrucifier",),
    "décrucifias": ("décrucifier",),
    "décrucifiassent": ("décrucifier",),
    "décrucifiasses": ("décrucifier",),
    "décrucifiasse": ("décrucifier",),
    "décrucifiassiez": ("décrucifier",),
    "décrucifiassions": ("décrucifier",),
    "décrucifiâtes": ("décrucifier",),
    "décrucifiât": ("décrucifier",),
    "décrucifiée": ("décrucifier",),
    "décrucifiées": ("décrucifier",),
    "décrucifié": ("décrucifier",),
    "décrucifient": ("décrucifier",),
    "décrucifie": ("décrucifier",),
    "décrucifiera": ("décrucifier",),
    "décrucifieraient": ("décrucifier",),
    "décrucifierai": ("décrucifier",),
    "décrucifierais": ("décrucifier",),
    "décrucifierait": ("décrucifier",),
    "décrucifieras": ("décrucifier",),
    "décrucifièrent": ("décrucifier",),
    "décrucifierez": ("décrucifier",),
    "décrucifieriez": ("décrucifier",),
    "décrucifierions": ("décrucifier",),
    "décrucifierons": ("décrucifier",),
    "décrucifieront": ("décrucifier",),
    "décrucifiés": ("décrucifier",),
    "décrucifies": ("décrucifier",),
    "décrucifiez": ("décrucifier",),
    "décrucifiiez": ("décrucifier",),
    "décrucifiions": ("décrucifier",),
    "décrucifions": ("décrucifier",),
    "décuirassaient": ("décuirasser",),
    "décuirassai": ("décuirasser",),
    "décuirassais": ("décuirasser",),
    "décuirassait": ("décuirasser",),
    "décuirassa": ("décuirasser",),
    "décuirassâmes": ("décuirasser",),
    "décuirassant": ("décuirasser",),
    "décuirassas": ("décuirasser",),
    "décuirassassent": ("décuirasser",),
    "décuirassasses": ("décuirasser",),
    "décuirassasse": ("décuirasser",),
    "décuirassassiez": ("décuirasser",),
    "décuirassassions": ("décuirasser",),
    "décuirassâtes": ("décuirasser",),
    "décuirassât": ("décuirasser",),
    "décuirassée": ("décuirasser",),
    "décuirassées": ("décuirasser",),
    "décuirassé": ("décuirasser",),
    "décuirassent": ("décuirasser",),
    "décuirasse": ("décuirasser",),
    "décuirassera": ("décuirasser",),
    "décuirasseraient": ("décuirasser",),
    "décuirasserai": ("décuirasser",),
    "décuirasserais": ("décuirasser",),
    "décuirasserait": ("décuirasser",),
    "décuirasseras": ("décuirasser",),
    "décuirassèrent": ("décuirasser",),
    "décuirasserez": ("décuirasser",),
    "décuirasseriez": ("décuirasser",),
    "décuirasserions": ("décuirasser",),
    "décuirasserons": ("décuirasser",),
    "décuirasseront": ("décuirasser",),
    "décuirassés": ("décuirasser",),
    "décuirasses": ("décuirasser",),
    "décuirassez": ("décuirasser",),
    "décuirassiez": ("décuirasser",),
    "décuirassions": ("décuirasser",),
    "décuirassons": ("décuirasser",),
    "décuira": ("décuire",),
    "décuiraient": ("décuire",),
    "décuirai": ("décuire",),
    "décuirais": ("décuire",),
    "décuirait": ("décuire",),
    "décuiras": ("décuire",),
    "décuirez": ("décuire",),
    "décuiriez": ("décuire",),
    "décuirions": ("décuire",),
    "décuirons": ("décuire",),
    "décuiront": ("décuire",),
    "décuisaient": ("décuire",),
    "décuisais": ("décuire",),
    "décuisait": ("décuire",),
    "décuisant": ("décuire",),
    "décuisent": ("décuire",),
    "décuise": ("décuire",),
    "décuises": ("décuire",),
    "décuisez": ("décuire",),
    "décuisiez": ("décuire",),
    "décuisîmes": ("décuire",),
    "décuisions": ("décuire",),
    "décuisirent": ("décuire",),
    "décuisis": ("décuire",),
    "décuisissent": ("décuire",),
    "décuisisses": ("décuire",),
    "décuisisse": ("décuire",),
    "décuisissiez": ("décuire",),
    "décuisissions": ("décuire",),
    "décuisîtes": ("décuire",),
    "décuisit": ("décuire",),
    "décuisît": ("décuire",),
    "décuisons": ("décuire",),
    "décuis": ("décuire",),
    "décuite": ("décuire",),
    "décuites": ("décuire",),
    "décuit": ("décuire",),
    "décuits": ("décuire",),
    "déculassaient": ("déculasser",),
    "déculassai": ("déculasser",),
    "déculassais": ("déculasser",),
    "déculassait": ("déculasser",),
    "déculassa": ("déculasser",),
    "déculassâmes": ("déculasser",),
    "déculassant": ("déculasser",),
    "déculassas": ("déculasser",),
    "déculassassent": ("déculasser",),
    "déculassasses": ("déculasser",),
    "déculassasse": ("déculasser",),
    "déculassassiez": ("déculasser",),
    "déculassassions": ("déculasser",),
    "déculassâtes": ("déculasser",),
    "déculassât": ("déculasser",),
    "déculassée": ("déculasser",),
    "déculassées": ("déculasser",),
    "déculassé": ("déculasser",),
    "déculassent": ("déculasser",),
    "déculasse": ("déculasser",),
    "déculassera": ("déculasser",),
    "déculasseraient": ("déculasser",),
    "déculasserai": ("déculasser",),
    "déculasserais": ("déculasser",),
    "déculasserait": ("déculasser",),
    "déculasseras": ("déculasser",),
    "déculassèrent": ("déculasser",),
    "déculasserez": ("déculasser",),
    "déculasseriez": ("déculasser",),
    "déculasserions": ("déculasser",),
    "déculasserons": ("déculasser",),
    "déculasseront": ("déculasser",),
    "déculassés": ("déculasser",),
    "déculasses": ("déculasser",),
    "déculassez": ("déculasser",),
    "déculassiez": ("déculasser",),
    "déculassions": ("déculasser",),
    "déculassons": ("déculasser",),
    "dédensifiaient": ("dédensifier",),
    "dédensifiai": ("dédensifier",),
    "dédensifiais": ("dédensifier",),
    "dédensifiait": ("dédensifier",),
    "dédensifia": ("dédensifier",),
    "dédensifiâmes": ("dédensifier",),
    "dédensifiant": ("dédensifier",),
    "dédensifias": ("dédensifier",),
    "dédensifiassent": ("dédensifier",),
    "dédensifiasses": ("dédensifier",),
    "dédensifiasse": ("dédensifier",),
    "dédensifiassiez": ("dédensifier",),
    "dédensifiassions": ("dédensifier",),
    "dédensifiâtes": ("dédensifier",),
    "dédensifiât": ("dédensifier",),
    "dédensifiée": ("dédensifier",),
    "dédensifiées": ("dédensifier",),
    "dédensifié": ("dédensifier",),
    "dédensifient": ("dédensifier",),
    "dédensifie": ("dédensifier",),
    "dédensifiera": ("dédensifier",),
    "dédensifieraient": ("dédensifier",),
    "dédensifierai": ("dédensifier",),
    "dédensifierais": ("dédensifier",),
    "dédensifierait": ("dédensifier",),
    "dédensifieras": ("dédensifier",),
    "dédensifièrent": ("dédensifier",),
    "dédensifierez": ("dédensifier",),
    "dédensifieriez": ("dédensifier",),
    "dédensifierions": ("dédensifier",),
    "dédensifierons": ("dédensifier",),
    "dédensifieront": ("dédensifier",),
    "dédensifiés": ("dédensifier",),
    "dédensifies": ("dédensifier",),
    "dédensifiez": ("dédensifier",),
    "dédensifiiez": ("dédensifier",),
    "dédensifiions": ("dédensifier",),
    "dédensifions": ("dédensifier",),
    "dédicaçaient": ("dédicacer",),
    "dédicaçai": ("dédicacer",),
    "dédicaçais": ("dédicacer",),
    "dédicaçait": ("dédicacer",),
    "dédicaça": ("dédicacer",),
    "dédicaçâmes": ("dédicacer",),
    "dédicaçant": ("dédicacer",),
    "dédicaças": ("dédicacer",),
    "dédicaçassent": ("dédicacer",),
    "dédicaçasses": ("dédicacer",),
    "dédicaçasse": ("dédicacer",),
    "dédicaçassiez": ("dédicacer",),
    "dédicaçassions": ("dédicacer",),
    "dédicaçâtes": ("dédicacer",),
    "dédicaçât": ("dédicacer",),
    "dédicacée": ("dédicacer",),
    "dédicacées": ("dédicacer",),
    "dédicacé": ("dédicacer",),
    "dédicacent": ("dédicacer",),
    "dédicace": ("dédicacer",),
    "dédicacera": ("dédicacer",),
    "dédicaceraient": ("dédicacer",),
    "dédicacerai": ("dédicacer",),
    "dédicacerais": ("dédicacer",),
    "dédicacerait": ("dédicacer",),
    "dédicaceras": ("dédicacer",),
    "dédicacèrent": ("dédicacer",),
    "dédicacerez": ("dédicacer",),
    "dédicaceriez": ("dédicacer",),
    "dédicacerions": ("dédicacer",),
    "dédicacerons": ("dédicacer",),
    "dédicaceront": ("dédicacer",),
    "dédicacés": ("dédicacer",),
    "dédicaces": ("dédicacer",),
    "dédicacez": ("dédicacer",),
    "dédicaciez": ("dédicacer",),
    "dédicacions": ("dédicacer",),
    "dédicaçons": ("dédicacer",),
    "dédiaient": ("dédier",),
    "dédiai": ("dédier",),
    "dédiais": ("dédier",),
    "dédiait": ("dédier",),
    "dédia": ("dédier",),
    "dédiâmes": ("dédier",),
    "dédiant": ("dédier",),
    "dédias": ("dédier",),
    "dédiassent": ("dédier",),
    "dédiasses": ("dédier",),
    "dédiasse": ("dédier",),
    "dédiassiez": ("dédier",),
    "dédiassions": ("dédier",),
    "dédiâtes": ("dédier",),
    "dédiât": ("dédier",),
    "dédiée": ("dédier",),
    "dédiées": ("dédier",),
    "dédié": ("dédier",),
    "dédient": ("dédier",),
    "dédie": ("dédier",),
    "dédiera": ("dédier",),
    "dédieraient": ("dédier",),
    "dédierai": ("dédier",),
    "dédierais": ("dédier",),
    "dédierait": ("dédier",),
    "dédieras": ("dédier",),
    "dédièrent": ("dédier",),
    "dédierez": ("dédier",),
    "dédieriez": ("dédier",),
    "dédierions": ("dédier",),
    "dédierons": ("dédier",),
    "dédieront": ("dédier",),
    "dédiés": ("dédier",),
    "dédies": ("dédier",),
    "dédiez": ("dédier",),
    "dédiiez": ("dédier",),
    "dédiions": ("dédier",),
    "dédions": ("dédier",),
    "dédifférenciaient": ("dédifférencier",),
    "dédifférenciai": ("dédifférencier",),
    "dédifférenciais": ("dédifférencier",),
    "dédifférenciait": ("dédifférencier",),
    "dédifférencia": ("dédifférencier",),
    "dédifférenciâmes": ("dédifférencier",),
    "dédifférenciant": ("dédifférencier",),
    "dédifférencias": ("dédifférencier",),
    "dédifférenciassent": ("dédifférencier",),
    "dédifférenciasses": ("dédifférencier",),
    "dédifférenciasse": ("dédifférencier",),
    "dédifférenciassiez": ("dédifférencier",),
    "dédifférenciassions": ("dédifférencier",),
    "dédifférenciâtes": ("dédifférencier",),
    "dédifférenciât": ("dédifférencier",),
    "dédifférenciée": ("dédifférencier",),
    "dédifférenciées": ("dédifférencier",),
    "dédifférencié": ("dédifférencier",),
    "dédifférencient": ("dédifférencier",),
    "dédifférencie": ("dédifférencier",),
    "dédifférenciera": ("dédifférencier",),
    "dédifférencieraient": ("dédifférencier",),
    "dédifférencierai": ("dédifférencier",),
    "dédifférencierais": ("dédifférencier",),
    "dédifférencierait": ("dédifférencier",),
    "dédifférencieras": ("dédifférencier",),
    "dédifférencièrent": ("dédifférencier",),
    "dédifférencierez": ("dédifférencier",),
    "dédifférencieriez": ("dédifférencier",),
    "dédifférencierions": ("dédifférencier",),
    "dédifférencierons": ("dédifférencier",),
    "dédifférencieront": ("dédifférencier",),
    "dédifférenciés": ("dédifférencier",),
    "dédifférencies": ("dédifférencier",),
    "dédifférenciez": ("dédifférencier",),
    "dédifférenciiez": ("dédifférencier",),
    "dédifférenciions": ("dédifférencier",),
    "dédifférencions": ("dédifférencier",),
    "dédîmes": ("dédire",),
    "dédira": ("dédire",),
    "dédiraient": ("dédire",),
    "dédirai": ("dédire",),
    "dédirais": ("dédire",),
    "dédirait": ("dédire",),
    "dédiras": ("dédire",),
    "dédirent": ("dédire",),
    "dédirez": ("dédire",),
    "dédiriez": ("dédire",),
    "dédirions": ("dédire",),
    "dédirons": ("dédire",),
    "dédiront": ("dédire",),
    "dédisaient": ("dédire",),
    "dédisais": ("dédire",),
    "dédisait": ("dédire",),
    "dédisant": ("dédire",),
    "dédisent": ("dédire",),
    "dédise": ("dédire",),
    "dédises": ("dédire",),
    "dédisez": ("dédire",),
    "dédisiez": ("dédire",),
    "dédisions": ("dédire",),
    "dédisons": ("dédire",),
    "dédis": ("dédire",),
    "dédissent": ("dédire",),
    "dédisses": ("dédire",),
    "dédisse": ("dédire",),
    "dédissiez": ("dédire",),
    "dédissions": ("dédire",),
    "dédite": ("dédire",),
    "dédîtes": ("dédire",),
    "dédites": ("dédire",),
    "dédit": ("dédire",),
    "dédits": ("dédire",),
    "dédît": ("dédire",),
    "dédommageaient": ("dédommager",),
    "dédommageai": ("dédommager",),
    "dédommageais": ("dédommager",),
    "dédommageait": ("dédommager",),
    "dédommagea": ("dédommager",),
    "dédommageâmes": ("dédommager",),
    "dédommageant": ("dédommager",),
    "dédommageas": ("dédommager",),
    "dédommageassent": ("dédommager",),
    "dédommageasses": ("dédommager",),
    "dédommageasse": ("dédommager",),
    "dédommageassiez": ("dédommager",),
    "dédommageassions": ("dédommager",),
    "dédommageâtes": ("dédommager",),
    "dédommageât": ("dédommager",),
    "dédommagée": ("dédommager",),
    "dédommagées": ("dédommager",),
    "dédommagé": ("dédommager",),
    "dédommagent": ("dédommager",),
    "dédommageons": ("dédommager",),
    "dédommage": ("dédommager",),
    "dédommagera": ("dédommager",),
    "dédommageraient": ("dédommager",),
    "dédommagerai": ("dédommager",),
    "dédommagerais": ("dédommager",),
    "dédommagerait": ("dédommager",),
    "dédommageras": ("dédommager",),
    "dédommagèrent": ("dédommager",),
    "dédommagerez": ("dédommager",),
    "dédommageriez": ("dédommager",),
    "dédommagerions": ("dédommager",),
    "dédommagerons": ("dédommager",),
    "dédommageront": ("dédommager",),
    "dédommagés": ("dédommager",),
    "dédommages": ("dédommager",),
    "dédommagez": ("dédommager",),
    "dédommagiez": ("dédommager",),
    "dédommagions": ("dédommager",),
    "déduira": ("déduire",),
    "déduiraient": ("déduire",),
    "déduirai": ("déduire",),
    "déduirais": ("déduire",),
    "déduirait": ("déduire",),
    "déduiras": ("déduire",),
    "déduirez": ("déduire",),
    "déduiriez": ("déduire",),
    "déduirions": ("déduire",),
    "déduirons": ("déduire",),
    "déduiront": ("déduire",),
    "déduisaient": ("déduire",),
    "déduisais": ("déduire",),
    "déduisait": ("déduire",),
    "déduisant": ("déduire",),
    "déduisent": ("déduire",),
    "déduise": ("déduire",),
    "déduises": ("déduire",),
    "déduisez": ("déduire",),
    "déduisiez": ("déduire",),
    "déduisîmes": ("déduire",),
    "déduisions": ("déduire",),
    "déduisirent": ("déduire",),
    "déduisis": ("déduire",),
    "déduisissent": ("déduire",),
    "déduisisses": ("déduire",),
    "déduisisse": ("déduire",),
    "déduisissiez": ("déduire",),
    "déduisissions": ("déduire",),
    "déduisîtes": ("déduire",),
    "déduisit": ("déduire",),
    "déduisît": ("déduire",),
    "déduisons": ("déduire",),
    "déduis": ("déduire",),
    "déduite": ("déduire",),
    "déduites": ("déduire",),
    "déduit": ("déduire",),
    "déduits": ("déduire",),
    "défaillaient": ("défaillir",),
    "défaillais": ("défaillir",),
    "défaillait": ("défaillir",),
    "défaillant": ("défaillir",),
    "défaillent": ("défaillir",),
    "défaille": ("défaillir",),
    "défaillera": ("défaillir",),
    "défailleraient": ("défaillir",),
    "défaillerai": ("défaillir",),
    "défaillerais": ("défaillir",),
    "défaillerait": ("défaillir",),
    "défailleras": ("défaillir",),
    "défaillerez": ("défaillir",),
    "défailleriez": ("défaillir",),
    "défaillerions": ("défaillir",),
    "défaillerons": ("défaillir",),
    "défailleront": ("défaillir",),
    "défailles": ("défaillir",),
    "défaillez": ("défaillir",),
    "défailliez": ("défaillir",),
    "défailli": ("défaillir",),
    "défaillîmes": ("défaillir",),
    "défaillions": ("défaillir",),
    "défaillira": ("défaillir",),
    "défailliraient": ("défaillir",),
    "défaillirai": ("défaillir",),
    "défaillirais": ("défaillir",),
    "défaillirait": ("défaillir",),
    "défailliras": ("défaillir",),
    "défaillirent": ("défaillir",),
    "défaillirez": ("défaillir",),
    "défailliriez": ("défaillir",),
    "défaillirions": ("défaillir",),
    "défaillirons": ("défaillir",),
    "défailliront": ("défaillir",),
    "défaillis": ("défaillir",),
    "défaillissent": ("défaillir",),
    "défaillisses": ("défaillir",),
    "défaillisse": ("défaillir",),
    "défaillissiez": ("défaillir",),
    "défaillissions": ("défaillir",),
    "défaillîtes": ("défaillir",),
    "défaillit": ("défaillir",),
    "défaillît": ("défaillir",),
    "défaillons": ("défaillir",),
    "défaisaient": ("défaire",),
    "défaisais": ("défaire",),
    "défaisait": ("défaire",),
    "défaisant": ("défaire",),
    "défaisiez": ("défaire",),
    "défaisions": ("défaire",),
    "défaisons": ("défaire",),
    "défais": ("défaire",),
    "défaite": ("défaire",),
    "défaites": ("défaire",),
    "défait": ("défaire",),
    "défaits": ("défaire",),
    "défassent": ("défaire",),
    "défasse": ("défaire",),
    "défasses": ("défaire",),
    "défassiez": ("défaire",),
    "défassions": ("défaire",),
    "défera": ("défaire",),
    "déferaient": ("défaire",),
    "déferai": ("défaire",),
    "déferais": ("défaire",),
    "déferait": ("défaire",),
    "déferas": ("défaire",),
    "déferez": ("défaire",),
    "déferiez": ("défaire",),
    "déferions": ("défaire",),
    "déferons": ("défaire",),
    "déferont": ("défaire",),
    "défîmes": ("défaire",),
    "défirent": ("défaire",),
    "défis": ("défaire",),
    "défissent": ("défaire",),
    "défisses": ("défaire",),
    "défisse": ("défaire",),
    "défissiez": ("défaire",),
    "défissions": ("défaire",),
    "défîtes": ("défaire",),
    "défit": ("défaire",),
    "défît": ("défaire",),
    "défont": ("défaire",),
    "défardelaient": ("défardeler",),
    "défardelai": ("défardeler",),
    "défardelais": ("défardeler",),
    "défardelait": ("défardeler",),
    "défardela": ("défardeler",),
    "défardelâmes": ("défardeler",),
    "défardelant": ("défardeler",),
    "défardelas": ("défardeler",),
    "défardelassent": ("défardeler",),
    "défardelasses": ("défardeler",),
    "défardelasse": ("défardeler",),
    "défardelassiez": ("défardeler",),
    "défardelassions": ("défardeler",),
    "défardelâtes": ("défardeler",),
    "défardelât": ("défardeler",),
    "défardelée": ("défardeler",),
    "défardelées": ("défardeler",),
    "défardelé": ("défardeler",),
    "défardèlent": ("défardeler",),
    "défardèle": ("défardeler",),
    "défardèlera": ("défardeler",),
    "défardèleraient": ("défardeler",),
    "défardèlerai": ("défardeler",),
    "défardèlerais": ("défardeler",),
    "défardèlerait": ("défardeler",),
    "défardèleras": ("défardeler",),
    "défardelèrent": ("défardeler",),
    "défardèlerez": ("défardeler",),
    "défardèleriez": ("défardeler",),
    "défardèlerions": ("défardeler",),
    "défardèlerons": ("défardeler",),
    "défardèleront": ("défardeler",),
    "défardelés": ("défardeler",),
    "défardèles": ("défardeler",),
    "défardelez": ("défardeler",),
    "défardeliez": ("défardeler",),
    "défardelions": ("défardeler",),
    "défardelons": ("défardeler",),
    "défendaient": ("défendre",),
    "défendais": ("défendre",),
    "défendait": ("défendre",),
    "défendant": ("défendre",),
    "défendent": ("défendre",),
    "défende": ("défendre",),
    "défendes": ("défendre",),
    "défendez": ("défendre",),
    "défendiez": ("défendre",),
    "défendîmes": ("défendre",),
    "défendions": ("défendre",),
    "défendirent": ("défendre",),
    "défendis": ("défendre",),
    "défendissent": ("défendre",),
    "défendisses": ("défendre",),
    "défendisse": ("défendre",),
    "défendissiez": ("défendre",),
    "défendissions": ("défendre",),
    "défendîtes": ("défendre",),
    "défendit": ("défendre",),
    "défendît": ("défendre",),
    "défendons": ("défendre",),
    "défend": ("défendre",),
    "défendra": ("défendre",),
    "défendraient": ("défendre",),
    "défendrai": ("défendre",),
    "défendrais": ("défendre",),
    "défendrait": ("défendre",),
    "défendras": ("défendre",),
    "défendrez": ("défendre",),
    "défendriez": ("défendre",),
    "défendrions": ("défendre",),
    "défendrons": ("défendre",),
    "défendront": ("défendre",),
    "défends": ("défendre",),
    "défendue": ("défendre",),
    "défendues": ("défendre",),
    "défendu": ("défendre",),
    "défendus": ("défendre",),
    "déféquaient": ("déféquer",),
    "déféquai": ("déféquer",),
    "déféquais": ("déféquer",),
    "déféquait": ("déféquer",),
    "déféqua": ("déféquer",),
    "déféquâmes": ("déféquer",),
    "déféquant": ("déféquer",),
    "déféquas": ("déféquer",),
    "déféquassent": ("déféquer",),
    "déféquasses": ("déféquer",),
    "déféquasse": ("déféquer",),
    "déféquassiez": ("déféquer",),
    "déféquassions": ("déféquer",),
    "déféquâtes": ("déféquer",),
    "déféquât": ("déféquer",),
    "déféquée": ("déféquer",),
    "déféquées": ("déféquer",),
    "déféqué": ("déféquer",),
    "défèquent": ("déféquer",),
    "défèque": ("déféquer",),
    "déféquera": ("déféquer",),
    "déféqueraient": ("déféquer",),
    "déféquerai": ("déféquer",),
    "déféquerais": ("déféquer",),
    "déféquerait": ("déféquer",),
    "déféqueras": ("déféquer",),
    "déféquèrent": ("déféquer",),
    "déféquerez": ("déféquer",),
    "déféqueriez": ("déféquer",),
    "déféquerions": ("déféquer",),
    "déféquerons": ("déféquer",),
    "déféqueront": ("déféquer",),
    "déféqués": ("déféquer",),
    "défèques": ("déféquer",),
    "déféquez": ("déféquer",),
    "déféquiez": ("déféquer",),
    "déféquions": ("déféquer",),
    "déféquons": ("déféquer",),
    "déféraient": ("déférer",),
    "déférai": ("déférer",),
    "déférais": ("déférer",),
    "déférait": ("déférer",),
    "déféra": ("déférer",),
    "déférâmes": ("déférer",),
    "déférant": ("déférer",),
    "déféras": ("déférer",),
    "déférassent": ("déférer",),
    "déférasses": ("déférer",),
    "déférasse": ("déférer",),
    "déférassiez": ("déférer",),
    "déférassions": ("déférer",),
    "déférâtes": ("déférer",),
    "déférât": ("déférer",),
    "déférée": ("déférer",),
    "déférées": ("déférer",),
    "déféré": ("déférer",),
    "défèrent": ("déférer",),
    "défère": ("déférer",),
    "déférera": ("déférer",),
    "déféreraient": ("déférer",),
    "déférerai": ("déférer",),
    "déférerais": ("déférer",),
    "déférerait": ("déférer",),
    "déféreras": ("déférer",),
    "déférèrent": ("déférer",),
    "déférerez": ("déférer",),
    "déféreriez": ("déférer",),
    "déférerions": ("déférer",),
    "déférerons": ("déférer",),
    "déféreront": ("déférer",),
    "déférés": ("déférer",),
    "défères": ("déférer",),
    "déférez": ("déférer",),
    "défériez": ("déférer",),
    "déférions": ("déférer",),
    "déférons": ("déférer",),
    "défiançaient": ("défiancer",),
    "défiançai": ("défiancer",),
    "défiançais": ("défiancer",),
    "défiançait": ("défiancer",),
    "défiança": ("défiancer",),
    "défiançâmes": ("défiancer",),
    "défiançant": ("défiancer",),
    "défianças": ("défiancer",),
    "défiançassent": ("défiancer",),
    "défiançasses": ("défiancer",),
    "défiançasse": ("défiancer",),
    "défiançassiez": ("défiancer",),
    "défiançassions": ("défiancer",),
    "défiançâtes": ("défiancer",),
    "défiançât": ("défiancer",),
    "défiancée": ("défiancer",),
    "défiancées": ("défiancer",),
    "défiancé": ("défiancer",),
    "défiancent": ("défiancer",),
    "défiance": ("défiancer",),
    "défiancera": ("défiancer",),
    "défianceraient": ("défiancer",),
    "défiancerai": ("défiancer",),
    "défiancerais": ("défiancer",),
    "défiancerait": ("défiancer",),
    "défianceras": ("défiancer",),
    "défiancèrent": ("défiancer",),
    "défiancerez": ("défiancer",),
    "défianceriez": ("défiancer",),
    "défiancerions": ("défiancer",),
    "défiancerons": ("défiancer",),
    "défianceront": ("défiancer",),
    "défiancés": ("défiancer",),
    "défiances": ("défiancer",),
    "défiancez": ("défiancer",),
    "défianciez": ("défiancer",),
    "défiancions": ("défiancer",),
    "défiançons": ("défiancer",),
    "déficelaient": ("déficeler",),
    "déficelai": ("déficeler",),
    "déficelais": ("déficeler",),
    "déficelait": ("déficeler",),
    "déficela": ("déficeler",),
    "déficelâmes": ("déficeler",),
    "déficelant": ("déficeler",),
    "déficelas": ("déficeler",),
    "déficelassent": ("déficeler",),
    "déficelasses": ("déficeler",),
    "déficelasse": ("déficeler",),
    "déficelassiez": ("déficeler",),
    "déficelassions": ("déficeler",),
    "déficelâtes": ("déficeler",),
    "déficelât": ("déficeler",),
    "déficelée": ("déficeler",),
    "déficelées": ("déficeler",),
    "déficelé": ("déficeler",),
    "déficelèrent": ("déficeler",),
    "déficelés": ("déficeler",),
    "déficelez": ("déficeler",),
    "déficeliez": ("déficeler",),
    "déficelions": ("déficeler",),
    "déficellent": ("déficeler",),
    "déficelle": ("déficeler",),
    "déficellera": ("déficeler",),
    "déficelleraient": ("déficeler",),
    "déficellerai": ("déficeler",),
    "déficellerais": ("déficeler",),
    "déficellerait": ("déficeler",),
    "déficelleras": ("déficeler",),
    "déficellerez": ("déficeler",),
    "déficelleriez": ("déficeler",),
    "déficellerions": ("déficeler",),
    "déficellerons": ("déficeler",),
    "déficelleront": ("déficeler",),
    "déficelles": ("déficeler",),
    "déficelons": ("déficeler",),
    "défiaient": ("défier",),
    "défiai": ("défier",),
    "défiais": ("défier",),
    "défiait": ("défier",),
    "défia": ("défier",),
    "défiâmes": ("défier",),
    "défiant": ("défier",),
    "défias": ("défier",),
    "défiassent": ("défier",),
    "défiasses": ("défier",),
    "défiasse": ("défier",),
    "défiassiez": ("défier",),
    "défiassions": ("défier",),
    "défiâtes": ("défier",),
    "défiât": ("défier",),
    "défiée": ("défier",),
    "défiées": ("défier",),
    "défié": ("défier",),
    "défient": ("défier",),
    "défie": ("défier",),
    "défiera": ("défier",),
    "défieraient": ("défier",),
    "défierai": ("défier",),
    "défierais": ("défier",),
    "défierait": ("défier",),
    "défieras": ("défier",),
    "défièrent": ("défier",),
    "défierez": ("défier",),
    "défieriez": ("défier",),
    "défierions": ("défier",),
    "défierons": ("défier",),
    "défieront": ("défier",),
    "défiés": ("défier",),
    "défies": ("défier",),
    "défiez": ("défier",),
    "défiiez": ("défier",),
    "défiions": ("défier",),
    "défions": ("défier",),
    "défigeaient": ("défiger",),
    "défigeai": ("défiger",),
    "défigeais": ("défiger",),
    "défigeait": ("défiger",),
    "défigea": ("défiger",),
    "défigeâmes": ("défiger",),
    "défigeant": ("défiger",),
    "défigeas": ("défiger",),
    "défigeassent": ("défiger",),
    "défigeasses": ("défiger",),
    "défigeasse": ("défiger",),
    "défigeassiez": ("défiger",),
    "défigeassions": ("défiger",),
    "défigeâtes": ("défiger",),
    "défigeât": ("défiger",),
    "défigée": ("défiger",),
    "défigées": ("défiger",),
    "défigé": ("défiger",),
    "défigent": ("défiger",),
    "défigeons": ("défiger",),
    "défige": ("défiger",),
    "défigera": ("défiger",),
    "défigeraient": ("défiger",),
    "défigerai": ("défiger",),
    "défigerais": ("défiger",),
    "défigerait": ("défiger",),
    "défigeras": ("défiger",),
    "défigèrent": ("défiger",),
    "défigerez": ("défiger",),
    "défigeriez": ("défiger",),
    "défigerions": ("défiger",),
    "défigerons": ("défiger",),
    "défigeront": ("défiger",),
    "défigés": ("défiger",),
    "défiges": ("défiger",),
    "défigez": ("défiger",),
    "défigiez": ("défiger",),
    "défigions": ("défiger",),
    "définie": ("définir",),
    "définies": ("définir",),
    "défini": ("définir",),
    "définîmes": ("définir",),
    "définira": ("définir",),
    "définiraient": ("définir",),
    "définirai": ("définir",),
    "définirais": ("définir",),
    "définirait": ("définir",),
    "définiras": ("définir",),
    "définirent": ("définir",),
    "définirez": ("définir",),
    "définiriez": ("définir",),
    "définirions": ("définir",),
    "définirons": ("définir",),
    "définiront": ("définir",),
    "définis": ("définir",),
    "définissaient": ("définir",),
    "définissais": ("définir",),
    "définissait": ("définir",),
    "définissant": ("définir",),
    "définissent": ("définir",),
    "définisse": ("définir",),
    "définisses": ("définir",),
    "définissez": ("définir",),
    "définissiez": ("définir",),
    "définissions": ("définir",),
    "définissons": ("définir",),
    "définîtes": ("définir",),
    "définit": ("définir",),
    "définît": ("définir",),
    "défléchie": ("défléchir",),
    "défléchies": ("défléchir",),
    "défléchi": ("défléchir",),
    "défléchîmes": ("défléchir",),
    "défléchira": ("défléchir",),
    "défléchiraient": ("défléchir",),
    "défléchirai": ("défléchir",),
    "défléchirais": ("défléchir",),
    "défléchirait": ("défléchir",),
    "défléchiras": ("défléchir",),
    "défléchirent": ("défléchir",),
    "défléchirez": ("défléchir",),
    "défléchiriez": ("défléchir",),
    "défléchirions": ("défléchir",),
    "défléchirons": ("défléchir",),
    "défléchiront": ("défléchir",),
    "défléchis": ("défléchir",),
    "défléchissaient": ("défléchir",),
    "défléchissais": ("défléchir",),
    "défléchissait": ("défléchir",),
    "défléchissant": ("défléchir",),
    "défléchissent": ("défléchir",),
    "défléchisse": ("défléchir",),
    "défléchisses": ("défléchir",),
    "défléchissez": ("défléchir",),
    "défléchissiez": ("défléchir",),
    "défléchissions": ("défléchir",),
    "défléchissons": ("défléchir",),
    "défléchîtes": ("défléchir",),
    "défléchit": ("défléchir",),
    "défléchît": ("défléchir",),
    "défleurie": ("défleurir",),
    "défleuries": ("défleurir",),
    "défleuri": ("défleurir",),
    "défleurîmes": ("défleurir",),
    "défleurira": ("défleurir",),
    "défleuriraient": ("défleurir",),
    "défleurirai": ("défleurir",),
    "défleurirais": ("défleurir",),
    "défleurirait": ("défleurir",),
    "défleuriras": ("défleurir",),
    "défleurirent": ("défleurir",),
    "défleurirez": ("défleurir",),
    "défleuririez": ("défleurir",),
    "défleuririons": ("défleurir",),
    "défleurirons": ("défleurir",),
    "défleuriront": ("défleurir",),
    "défleuris": ("défleurir",),
    "défleurissaient": ("défleurir",),
    "défleurissais": ("défleurir",),
    "défleurissait": ("défleurir",),
    "défleurissant": ("défleurir",),
    "défleurissent": ("défleurir",),
    "défleurisse": ("défleurir",),
    "défleurisses": ("défleurir",),
    "défleurissez": ("défleurir",),
    "défleurissiez": ("défleurir",),
    "défleurissions": ("défleurir",),
    "défleurissons": ("défleurir",),
    "défleurîtes": ("défleurir",),
    "défleurit": ("défleurir",),
    "défleurît": ("défleurir",),
    "défoliaient": ("défolier",),
    "défoliai": ("défolier",),
    "défoliais": ("défolier",),
    "défoliait": ("défolier",),
    "défolia": ("défolier",),
    "défoliâmes": ("défolier",),
    "défoliant": ("défolier",),
    "défolias": ("défolier",),
    "défoliassent": ("défolier",),
    "défoliasses": ("défolier",),
    "défoliasse": ("défolier",),
    "défoliassiez": ("défolier",),
    "défoliassions": ("défolier",),
    "défoliâtes": ("défolier",),
    "défoliât": ("défolier",),
    "défoliée": ("défolier",),
    "défoliées": ("défolier",),
    "défolié": ("défolier",),
    "défolient": ("défolier",),
    "défolie": ("défolier",),
    "défoliera": ("défolier",),
    "défolieraient": ("défolier",),
    "défolierai": ("défolier",),
    "défolierais": ("défolier",),
    "défolierait": ("défolier",),
    "défolieras": ("défolier",),
    "défolièrent": ("défolier",),
    "défolierez": ("défolier",),
    "défolieriez": ("défolier",),
    "défolierions": ("défolier",),
    "défolierons": ("défolier",),
    "défolieront": ("défolier",),
    "défoliés": ("défolier",),
    "défolies": ("défolier",),
    "défoliez": ("défolier",),
    "défoliiez": ("défolier",),
    "défoliions": ("défolier",),
    "défolions": ("défolier",),
    "défonçaient": ("défoncer",),
    "défonçai": ("défoncer",),
    "défonçais": ("défoncer",),
    "défonçait": ("défoncer",),
    "défonça": ("défoncer",),
    "défonçâmes": ("défoncer",),
    "défonçant": ("défoncer",),
    "défonças": ("défoncer",),
    "défonçassent": ("défoncer",),
    "défonçasses": ("défoncer",),
    "défonçasse": ("défoncer",),
    "défonçassiez": ("défoncer",),
    "défonçassions": ("défoncer",),
    "défonçâtes": ("défoncer",),
    "défonçât": ("défoncer",),
    "défoncée": ("défoncer",),
    "défoncées": ("défoncer",),
    "défoncé": ("défoncer",),
    "défoncent": ("défoncer",),
    "défonce": ("défoncer",),
    "défoncera": ("défoncer",),
    "défonceraient": ("défoncer",),
    "défoncerai": ("défoncer",),
    "défoncerais": ("défoncer",),
    "défoncerait": ("défoncer",),
    "défonceras": ("défoncer",),
    "défoncèrent": ("défoncer",),
    "défoncerez": ("défoncer",),
    "défonceriez": ("défoncer",),
    "défoncerions": ("défoncer",),
    "défoncerons": ("défoncer",),
    "défonceront": ("défoncer",),
    "défoncés": ("défoncer",),
    "défonces": ("défoncer",),
    "défoncez": ("défoncer",),
    "défonciez": ("défoncer",),
    "défoncions": ("défoncer",),
    "défonçons": ("défoncer",),
    "déforçaient": ("déforcer",),
    "déforçai": ("déforcer",),
    "déforçais": ("déforcer",),
    "déforçait": ("déforcer",),
    "déforça": ("déforcer",),
    "déforçâmes": ("déforcer",),
    "déforçant": ("déforcer",),
    "déforças": ("déforcer",),
    "déforçassent": ("déforcer",),
    "déforçasses": ("déforcer",),
    "déforçasse": ("déforcer",),
    "déforçassiez": ("déforcer",),
    "déforçassions": ("déforcer",),
    "déforçâtes": ("déforcer",),
    "déforçât": ("déforcer",),
    "déforcée": ("déforcer",),
    "déforcées": ("déforcer",),
    "déforcé": ("déforcer",),
    "déforcent": ("déforcer",),
    "déforce": ("déforcer",),
    "déforcera": ("déforcer",),
    "déforceraient": ("déforcer",),
    "déforcerai": ("déforcer",),
    "déforcerais": ("déforcer",),
    "déforcerait": ("déforcer",),
    "déforceras": ("déforcer",),
    "déforcèrent": ("déforcer",),
    "déforcerez": ("déforcer",),
    "déforceriez": ("déforcer",),
    "déforcerions": ("déforcer",),
    "déforcerons": ("déforcer",),
    "déforceront": ("déforcer",),
    "déforcés": ("déforcer",),
    "déforces": ("déforcer",),
    "déforcez": ("déforcer",),
    "déforciez": ("déforcer",),
    "déforcions": ("déforcer",),
    "déforçons": ("déforcer",),
    "défortifiaient": ("défortifier",),
    "défortifiai": ("défortifier",),
    "défortifiais": ("défortifier",),
    "défortifiait": ("défortifier",),
    "défortifia": ("défortifier",),
    "défortifiâmes": ("défortifier",),
    "défortifiant": ("défortifier",),
    "défortifias": ("défortifier",),
    "défortifiassent": ("défortifier",),
    "défortifiasses": ("défortifier",),
    "défortifiasse": ("défortifier",),
    "défortifiassiez": ("défortifier",),
    "défortifiassions": ("défortifier",),
    "défortifiâtes": ("défortifier",),
    "défortifiât": ("défortifier",),
    "défortifiée": ("défortifier",),
    "défortifiées": ("défortifier",),
    "défortifié": ("défortifier",),
    "défortifient": ("défortifier",),
    "défortifie": ("défortifier",),
    "défortifiera": ("défortifier",),
    "défortifieraient": ("défortifier",),
    "défortifierai": ("défortifier",),
    "défortifierais": ("défortifier",),
    "défortifierait": ("défortifier",),
    "défortifieras": ("défortifier",),
    "défortifièrent": ("défortifier",),
    "défortifierez": ("défortifier",),
    "défortifieriez": ("défortifier",),
    "défortifierions": ("défortifier",),
    "défortifierons": ("défortifier",),
    "défortifieront": ("défortifier",),
    "défortifiés": ("défortifier",),
    "défortifies": ("défortifier",),
    "défortifiez": ("défortifier",),
    "défortifiiez": ("défortifier",),
    "défortifiions": ("défortifier",),
    "défortifions": ("défortifier",),
    "défraîchie": ("défraîchir",),
    "défraîchies": ("défraîchir",),
    "défraîchi": ("défraîchir",),
    "défraîchîmes": ("défraîchir",),
    "défraîchira": ("défraîchir",),
    "défraîchiraient": ("défraîchir",),
    "défraîchirai": ("défraîchir",),
    "défraîchirais": ("défraîchir",),
    "défraîchirait": ("défraîchir",),
    "défraîchiras": ("défraîchir",),
    "défraîchirent": ("défraîchir",),
    "défraîchirez": ("défraîchir",),
    "défraîchiriez": ("défraîchir",),
    "défraîchirions": ("défraîchir",),
    "défraîchirons": ("défraîchir",),
    "défraîchiront": ("défraîchir",),
    "défraîchis": ("défraîchir",),
    "défraîchissaient": ("défraîchir",),
    "défraîchissais": ("défraîchir",),
    "défraîchissait": ("défraîchir",),
    "défraîchissant": ("défraîchir",),
    "défraîchissent": ("défraîchir",),
    "défraîchisse": ("défraîchir",),
    "défraîchisses": ("défraîchir",),
    "défraîchissez": ("défraîchir",),
    "défraîchissiez": ("défraîchir",),
    "défraîchissions": ("défraîchir",),
    "défraîchissons": ("défraîchir",),
    "défraîchîtes": ("défraîchir",),
    "défraîchit": ("défraîchir",),
    "défraîchît": ("défraîchir",),
    "défraient": ("défrayer",),
    "défraie": ("défrayer",),
    "défraiera": ("défrayer",),
    "défraieraient": ("défrayer",),
    "défraierai": ("défrayer",),
    "défraierais": ("défrayer",),
    "défraierait": ("défrayer",),
    "défraieras": ("défrayer",),
    "défraierez": ("défrayer",),
    "défraieriez": ("défrayer",),
    "défraierions": ("défrayer",),
    "défraierons": ("défrayer",),
    "défraieront": ("défrayer",),
    "défraies": ("défrayer",),
    "défrayaient": ("défrayer",),
    "défrayai": ("défrayer",),
    "défrayais": ("défrayer",),
    "défrayait": ("défrayer",),
    "défraya": ("défrayer",),
    "défrayâmes": ("défrayer",),
    "défrayant": ("défrayer",),
    "défrayas": ("défrayer",),
    "défrayassent": ("défrayer",),
    "défrayasses": ("défrayer",),
    "défrayasse": ("défrayer",),
    "défrayassiez": ("défrayer",),
    "défrayassions": ("défrayer",),
    "défrayâtes": ("défrayer",),
    "défrayât": ("défrayer",),
    "défrayée": ("défrayer",),
    "défrayées": ("défrayer",),
    "défrayé": ("défrayer",),
    "défrayent": ("défrayer",),
    "défraye": ("défrayer",),
    "défrayera": ("défrayer",),
    "défrayeraient": ("défrayer",),
    "défrayerai": ("défrayer",),
    "défrayerais": ("défrayer",),
    "défrayerait": ("défrayer",),
    "défrayeras": ("défrayer",),
    "défrayèrent": ("défrayer",),
    "défrayerez": ("défrayer",),
    "défrayeriez": ("défrayer",),
    "défrayerions": ("défrayer",),
    "défrayerons": ("défrayer",),
    "défrayeront": ("défrayer",),
    "défrayés": ("défrayer",),
    "défrayes": ("défrayer",),
    "défrayez": ("défrayer",),
    "défrayiez": ("défrayer",),
    "défrayions": ("défrayer",),
    "défrayons": ("défrayer",),
    "défrénaient": ("défréner",),
    "défrénai": ("défréner",),
    "défrénais": ("défréner",),
    "défrénait": ("défréner",),
    "défréna": ("défréner",),
    "défrénâmes": ("défréner",),
    "défrénant": ("défréner",),
    "défrénas": ("défréner",),
    "défrénassent": ("défréner",),
    "défrénasses": ("défréner",),
    "défrénasse": ("défréner",),
    "défrénassiez": ("défréner",),
    "défrénassions": ("défréner",),
    "défrénâtes": ("défréner",),
    "défrénât": ("défréner",),
    "défrénée": ("défréner",),
    "défrénées": ("défréner",),
    "défréné": ("défréner",),
    "défrènent": ("défréner",),
    "défrène": ("défréner",),
    "défrénera": ("défréner",),
    "défréneraient": ("défréner",),
    "défrénerai": ("défréner",),
    "défrénerais": ("défréner",),
    "défrénerait": ("défréner",),
    "défréneras": ("défréner",),
    "défrénèrent": ("défréner",),
    "défrénerez": ("défréner",),
    "défréneriez": ("défréner",),
    "défrénerions": ("défréner",),
    "défrénerons": ("défréner",),
    "défréneront": ("défréner",),
    "défrénés": ("défréner",),
    "défrènes": ("défréner",),
    "défrénez": ("défréner",),
    "défréniez": ("défréner",),
    "défrénions": ("défréner",),
    "défrénons": ("défréner",),
    "défronçaient": ("défroncer",),
    "défronçai": ("défroncer",),
    "défronçais": ("défroncer",),
    "défronçait": ("défroncer",),
    "défronça": ("défroncer",),
    "défronçâmes": ("défroncer",),
    "défronçant": ("défroncer",),
    "défronças": ("défroncer",),
    "défronçassent": ("défroncer",),
    "défronçasses": ("défroncer",),
    "défronçasse": ("défroncer",),
    "défronçassiez": ("défroncer",),
    "défronçassions": ("défroncer",),
    "défronçâtes": ("défroncer",),
    "défronçât": ("défroncer",),
    "défroncée": ("défroncer",),
    "défroncées": ("défroncer",),
    "défroncé": ("défroncer",),
    "défroncent": ("défroncer",),
    "défronce": ("défroncer",),
    "défroncera": ("défroncer",),
    "défronceraient": ("défroncer",),
    "défroncerai": ("défroncer",),
    "défroncerais": ("défroncer",),
    "défroncerait": ("défroncer",),
    "défronceras": ("défroncer",),
    "défroncèrent": ("défroncer",),
    "défroncerez": ("défroncer",),
    "défronceriez": ("défroncer",),
    "défroncerions": ("défroncer",),
    "défroncerons": ("défroncer",),
    "défronceront": ("défroncer",),
    "défroncés": ("défroncer",),
    "défronces": ("défroncer",),
    "défroncez": ("défroncer",),
    "défronciez": ("défroncer",),
    "défroncions": ("défroncer",),
    "défronçons": ("défroncer",),
    "dégageaient": ("dégager",),
    "dégageai": ("dégager",),
    "dégageais": ("dégager",),
    "dégageait": ("dégager",),
    "dégagea": ("dégager",),
    "dégageâmes": ("dégager",),
    "dégageant": ("dégager",),
    "dégageas": ("dégager",),
    "dégageassent": ("dégager",),
    "dégageasses": ("dégager",),
    "dégageasse": ("dégager",),
    "dégageassiez": ("dégager",),
    "dégageassions": ("dégager",),
    "dégageâtes": ("dégager",),
    "dégageât": ("dégager",),
    "dégagée": ("dégager",),
    "dégagées": ("dégager",),
    "dégagé": ("dégager",),
    "dégagent": ("dégager",),
    "dégageons": ("dégager",),
    "dégage": ("dégager",),
    "dégagera": ("dégager",),
    "dégageraient": ("dégager",),
    "dégagerai": ("dégager",),
    "dégagerais": ("dégager",),
    "dégagerait": ("dégager",),
    "dégageras": ("dégager",),
    "dégagèrent": ("dégager",),
    "dégagerez": ("dégager",),
    "dégageriez": ("dégager",),
    "dégagerions": ("dégager",),
    "dégagerons": ("dégager",),
    "dégageront": ("dégager",),
    "dégagés": ("dégager",),
    "dégages": ("dégager",),
    "dégagez": ("dégager",),
    "dégagiez": ("dégager",),
    "dégagions": ("dégager",),
    "dégarnie": ("dégarnir",),
    "dégarnies": ("dégarnir",),
    "dégarni": ("dégarnir",),
    "dégarnîmes": ("dégarnir",),
    "dégarnira": ("dégarnir",),
    "dégarniraient": ("dégarnir",),
    "dégarnirai": ("dégarnir",),
    "dégarnirais": ("dégarnir",),
    "dégarnirait": ("dégarnir",),
    "dégarniras": ("dégarnir",),
    "dégarnirent": ("dégarnir",),
    "dégarnirez": ("dégarnir",),
    "dégarniriez": ("dégarnir",),
    "dégarnirions": ("dégarnir",),
    "dégarnirons": ("dégarnir",),
    "dégarniront": ("dégarnir",),
    "dégarnis": ("dégarnir",),
    "dégarnissaient": ("dégarnir",),
    "dégarnissais": ("dégarnir",),
    "dégarnissait": ("dégarnir",),
    "dégarnissant": ("dégarnir",),
    "dégarnissent": ("dégarnir",),
    "dégarnisse": ("dégarnir",),
    "dégarnisses": ("dégarnir",),
    "dégarnissez": ("dégarnir",),
    "dégarnissiez": ("dégarnir",),
    "dégarnissions": ("dégarnir",),
    "dégarnissons": ("dégarnir",),
    "dégarnîtes": ("dégarnir",),
    "dégarnit": ("dégarnir",),
    "dégarnît": ("dégarnir",),
    "dégauchie": ("dégauchir",),
    "dégauchies": ("dégauchir",),
    "dégauchi": ("dégauchir",),
    "dégauchîmes": ("dégauchir",),
    "dégauchira": ("dégauchir",),
    "dégauchiraient": ("dégauchir",),
    "dégauchirai": ("dégauchir",),
    "dégauchirais": ("dégauchir",),
    "dégauchirait": ("dégauchir",),
    "dégauchiras": ("dégauchir",),
    "dégauchirent": ("dégauchir",),
    "dégauchirez": ("dégauchir",),
    "dégauchiriez": ("dégauchir",),
    "dégauchirions": ("dégauchir",),
    "dégauchirons": ("dégauchir",),
    "dégauchiront": ("dégauchir",),
    "dégauchis": ("dégauchir",),
    "dégauchissaient": ("dégauchir",),
    "dégauchissais": ("dégauchir",),
    "dégauchissait": ("dégauchir",),
    "dégauchissant": ("dégauchir",),
    "dégauchissent": ("dégauchir",),
    "dégauchisse": ("dégauchir",),
    "dégauchisses": ("dégauchir",),
    "dégauchissez": ("dégauchir",),
    "dégauchissiez": ("dégauchir",),
    "dégauchissions": ("dégauchir",),
    "dégauchissons": ("dégauchir",),
    "dégauchîtes": ("dégauchir",),
    "dégauchit": ("dégauchir",),
    "dégauchît": ("dégauchir",),
    "dégelaient": ("dégeler",),
    "dégelai": ("dégeler",),
    "dégelais": ("dégeler",),
    "dégelait": ("dégeler",),
    "dégela": ("dégeler",),
    "dégelâmes": ("dégeler",),
    "dégelant": ("dégeler",),
    "dégelas": ("dégeler",),
    "dégelassent": ("dégeler",),
    "dégelasses": ("dégeler",),
    "dégelasse": ("dégeler",),
    "dégelassiez": ("dégeler",),
    "dégelassions": ("dégeler",),
    "dégelâtes": ("dégeler",),
    "dégelât": ("dégeler",),
    "dégelée": ("dégeler",),
    "dégelées": ("dégeler",),
    "dégelé": ("dégeler",),
    "dégèlent": ("dégeler",),
    "dégèle": ("dégeler",),
    "dégèlera": ("dégeler",),
    "dégèleraient": ("dégeler",),
    "dégèlerai": ("dégeler",),
    "dégèlerais": ("dégeler",),
    "dégèlerait": ("dégeler",),
    "dégèleras": ("dégeler",),
    "dégelèrent": ("dégeler",),
    "dégèlerez": ("dégeler",),
    "dégèleriez": ("dégeler",),
    "dégèlerions": ("dégeler",),
    "dégèlerons": ("dégeler",),
    "dégèleront": ("dégeler",),
    "dégelés": ("dégeler",),
    "dégèles": ("dégeler",),
    "dégelez": ("dégeler",),
    "dégeliez": ("dégeler",),
    "dégelions": ("dégeler",),
    "dégelons": ("dégeler",),
    "dégénéraient": ("dégénérer",),
    "dégénérai": ("dégénérer",),
    "dégénérais": ("dégénérer",),
    "dégénérait": ("dégénérer",),
    "dégénéra": ("dégénérer",),
    "dégénérâmes": ("dégénérer",),
    "dégénérant": ("dégénérer",),
    "dégénéras": ("dégénérer",),
    "dégénérassent": ("dégénérer",),
    "dégénérasses": ("dégénérer",),
    "dégénérasse": ("dégénérer",),
    "dégénérassiez": ("dégénérer",),
    "dégénérassions": ("dégénérer",),
    "dégénérâtes": ("dégénérer",),
    "dégénérât": ("dégénérer",),
    "dégénéré": ("dégénérer",),
    "dégénèrent": ("dégénérer",),
    "dégénère": ("dégénérer",),
    "dégénérera": ("dégénérer",),
    "dégénéreraient": ("dégénérer",),
    "dégénérerai": ("dégénérer",),
    "dégénérerais": ("dégénérer",),
    "dégénérerait": ("dégénérer",),
    "dégénéreras": ("dégénérer",),
    "dégénérèrent": ("dégénérer",),
    "dégénérerez": ("dégénérer",),
    "dégénéreriez": ("dégénérer",),
    "dégénérerions": ("dégénérer",),
    "dégénérerons": ("dégénérer",),
    "dégénéreront": ("dégénérer",),
    "dégénères": ("dégénérer",),
    "dégénérez": ("dégénérer",),
    "dégénériez": ("dégénérer",),
    "dégénérions": ("dégénérer",),
    "dégénérons": ("dégénérer",),
    "déglaçaient": ("déglacer",),
    "déglaçai": ("déglacer",),
    "déglaçais": ("déglacer",),
    "déglaçait": ("déglacer",),
    "déglaça": ("déglacer",),
    "déglaçâmes": ("déglacer",),
    "déglaçant": ("déglacer",),
    "déglaças": ("déglacer",),
    "déglaçassent": ("déglacer",),
    "déglaçasses": ("déglacer",),
    "déglaçasse": ("déglacer",),
    "déglaçassiez": ("déglacer",),
    "déglaçassions": ("déglacer",),
    "déglaçâtes": ("déglacer",),
    "déglaçât": ("déglacer",),
    "déglacée": ("déglacer",),
    "déglacées": ("déglacer",),
    "déglacé": ("déglacer",),
    "déglacent": ("déglacer",),
    "déglace": ("déglacer",),
    "déglacera": ("déglacer",),
    "déglaceraient": ("déglacer",),
    "déglacerai": ("déglacer",),
    "déglacerais": ("déglacer",),
    "déglacerait": ("déglacer",),
    "déglaceras": ("déglacer",),
    "déglacèrent": ("déglacer",),
    "déglacerez": ("déglacer",),
    "déglaceriez": ("déglacer",),
    "déglacerions": ("déglacer",),
    "déglacerons": ("déglacer",),
    "déglaceront": ("déglacer",),
    "déglacés": ("déglacer",),
    "déglaces": ("déglacer",),
    "déglacez": ("déglacer",),
    "déglaciez": ("déglacer",),
    "déglacions": ("déglacer",),
    "déglaçons": ("déglacer",),
    "dégloméraient": ("déglomérer",),
    "déglomérai": ("déglomérer",),
    "déglomérais": ("déglomérer",),
    "déglomérait": ("déglomérer",),
    "dégloméra": ("déglomérer",),
    "déglomérâmes": ("déglomérer",),
    "déglomérant": ("déglomérer",),
    "dégloméras": ("déglomérer",),
    "déglomérassent": ("déglomérer",),
    "déglomérasses": ("déglomérer",),
    "déglomérasse": ("déglomérer",),
    "déglomérassiez": ("déglomérer",),
    "déglomérassions": ("déglomérer",),
    "déglomérâtes": ("déglomérer",),
    "déglomérât": ("déglomérer",),
    "déglomérée": ("déglomérer",),
    "déglomérées": ("déglomérer",),
    "dégloméré": ("déglomérer",),
    "déglomèrent": ("déglomérer",),
    "déglomère": ("déglomérer",),
    "déglomérera": ("déglomérer",),
    "dégloméreraient": ("déglomérer",),
    "déglomérerai": ("déglomérer",),
    "déglomérerais": ("déglomérer",),
    "déglomérerait": ("déglomérer",),
    "dégloméreras": ("déglomérer",),
    "déglomérèrent": ("déglomérer",),
    "déglomérerez": ("déglomérer",),
    "dégloméreriez": ("déglomérer",),
    "déglomérerions": ("déglomérer",),
    "déglomérerons": ("déglomérer",),
    "dégloméreront": ("déglomérer",),
    "déglomérés": ("déglomérer",),
    "déglomères": ("déglomérer",),
    "déglomérez": ("déglomérer",),
    "déglomériez": ("déglomérer",),
    "déglomérions": ("déglomérer",),
    "déglomérons": ("déglomérer",),
    "déglutie": ("déglutir",),
    "dégluties": ("déglutir",),
    "dégluti": ("déglutir",),
    "déglutîmes": ("déglutir",),
    "déglutira": ("déglutir",),
    "déglutiraient": ("déglutir",),
    "déglutirai": ("déglutir",),
    "déglutirais": ("déglutir",),
    "déglutirait": ("déglutir",),
    "déglutiras": ("déglutir",),
    "déglutirent": ("déglutir",),
    "déglutirez": ("déglutir",),
    "déglutiriez": ("déglutir",),
    "déglutirions": ("déglutir",),
    "déglutirons": ("déglutir",),
    "déglutiront": ("déglutir",),
    "déglutis": ("déglutir",),
    "déglutissaient": ("déglutir",),
    "déglutissais": ("déglutir",),
    "déglutissait": ("déglutir",),
    "déglutissant": ("déglutir",),
    "déglutissent": ("déglutir",),
    "déglutisse": ("déglutir",),
    "déglutisses": ("déglutir",),
    "déglutissez": ("déglutir",),
    "déglutissiez": ("déglutir",),
    "déglutissions": ("déglutir",),
    "déglutissons": ("déglutir",),
    "déglutîtes": ("déglutir",),
    "déglutit": ("déglutir",),
    "déglutît": ("déglutir",),
    "dégorgeaient": ("dégorger",),
    "dégorgeai": ("dégorger",),
    "dégorgeais": ("dégorger",),
    "dégorgeait": ("dégorger",),
    "dégorgea": ("dégorger",),
    "dégorgeâmes": ("dégorger",),
    "dégorgeant": ("dégorger",),
    "dégorgeas": ("dégorger",),
    "dégorgeassent": ("dégorger",),
    "dégorgeasses": ("dégorger",),
    "dégorgeasse": ("dégorger",),
    "dégorgeassiez": ("dégorger",),
    "dégorgeassions": ("dégorger",),
    "dégorgeâtes": ("dégorger",),
    "dégorgeât": ("dégorger",),
    "dégorgée": ("dégorger",),
    "dégorgées": ("dégorger",),
    "dégorgé": ("dégorger",),
    "dégorgent": ("dégorger",),
    "dégorgeons": ("dégorger",),
    "dégorge": ("dégorger",),
    "dégorgera": ("dégorger",),
    "dégorgeraient": ("dégorger",),
    "dégorgerai": ("dégorger",),
    "dégorgerais": ("dégorger",),
    "dégorgerait": ("dégorger",),
    "dégorgeras": ("dégorger",),
    "dégorgèrent": ("dégorger",),
    "dégorgerez": ("dégorger",),
    "dégorgeriez": ("dégorger",),
    "dégorgerions": ("dégorger",),
    "dégorgerons": ("dégorger",),
    "dégorgeront": ("dégorger",),
    "dégorgés": ("dégorger",),
    "dégorges": ("dégorger",),
    "dégorgez": ("dégorger",),
    "dégorgiez": ("dégorger",),
    "dégorgions": ("dégorger",),
    "dégourdie": ("dégourdir",),
    "dégourdies": ("dégourdir",),
    "dégourdi": ("dégourdir",),
    "dégourdîmes": ("dégourdir",),
    "dégourdira": ("dégourdir",),
    "dégourdiraient": ("dégourdir",),
    "dégourdirai": ("dégourdir",),
    "dégourdirais": ("dégourdir",),
    "dégourdirait": ("dégourdir",),
    "dégourdiras": ("dégourdir",),
    "dégourdirent": ("dégourdir",),
    "dégourdirez": ("dégourdir",),
    "dégourdiriez": ("dégourdir",),
    "dégourdirions": ("dégourdir",),
    "dégourdirons": ("dégourdir",),
    "dégourdiront": ("dégourdir",),
    "dégourdis": ("dégourdir",),
    "dégourdissaient": ("dégourdir",),
    "dégourdissais": ("dégourdir",),
    "dégourdissait": ("dégourdir",),
    "dégourdissant": ("dégourdir",),
    "dégourdissent": ("dégourdir",),
    "dégourdisse": ("dégourdir",),
    "dégourdisses": ("dégourdir",),
    "dégourdissez": ("dégourdir",),
    "dégourdissiez": ("dégourdir",),
    "dégourdissions": ("dégourdir",),
    "dégourdissons": ("dégourdir",),
    "dégourdîtes": ("dégourdir",),
    "dégourdit": ("dégourdir",),
    "dégourdît": ("dégourdir",),
    "dégouttelaient": ("dégoutteler",),
    "dégouttelai": ("dégoutteler",),
    "dégouttelais": ("dégoutteler",),
    "dégouttelait": ("dégoutteler",),
    "dégouttela": ("dégoutteler",),
    "dégouttelâmes": ("dégoutteler",),
    "dégouttelant": ("dégoutteler",),
    "dégouttelas": ("dégoutteler",),
    "dégouttelassent": ("dégoutteler",),
    "dégouttelasses": ("dégoutteler",),
    "dégouttelasse": ("dégoutteler",),
    "dégouttelassiez": ("dégoutteler",),
    "dégouttelassions": ("dégoutteler",),
    "dégouttelâtes": ("dégoutteler",),
    "dégouttelât": ("dégoutteler",),
    "dégouttelée": ("dégoutteler",),
    "dégouttelées": ("dégoutteler",),
    "dégouttelé": ("dégoutteler",),
    "dégouttelèrent": ("dégoutteler",),
    "dégouttelés": ("dégoutteler",),
    "dégouttelez": ("dégoutteler",),
    "dégoutteliez": ("dégoutteler",),
    "dégouttelions": ("dégoutteler",),
    "dégouttellent": ("dégoutteler",),
    "dégouttelle": ("dégoutteler",),
    "dégouttellera": ("dégoutteler",),
    "dégouttelleraient": ("dégoutteler",),
    "dégouttellerai": ("dégoutteler",),
    "dégouttellerais": ("dégoutteler",),
    "dégouttellerait": ("dégoutteler",),
    "dégouttelleras": ("dégoutteler",),
    "dégouttellerez": ("dégoutteler",),
    "dégouttelleriez": ("dégoutteler",),
    "dégouttellerions": ("dégoutteler",),
    "dégouttellerons": ("dégoutteler",),
    "dégouttelleront": ("dégoutteler",),
    "dégouttelles": ("dégoutteler",),
    "dégouttelons": ("dégoutteler",),
    "dégravelaient": ("dégraveler",),
    "dégravelai": ("dégraveler",),
    "dégravelais": ("dégraveler",),
    "dégravelait": ("dégraveler",),
    "dégravela": ("dégraveler",),
    "dégravelâmes": ("dégraveler",),
    "dégravelant": ("dégraveler",),
    "dégravelas": ("dégraveler",),
    "dégravelassent": ("dégraveler",),
    "dégravelasses": ("dégraveler",),
    "dégravelasse": ("dégraveler",),
    "dégravelassiez": ("dégraveler",),
    "dégravelassions": ("dégraveler",),
    "dégravelâtes": ("dégraveler",),
    "dégravelât": ("dégraveler",),
    "dégravelée": ("dégraveler",),
    "dégravelées": ("dégraveler",),
    "dégravelé": ("dégraveler",),
    "dégravelèrent": ("dégraveler",),
    "dégravelés": ("dégraveler",),
    "dégravelez": ("dégraveler",),
    "dégraveliez": ("dégraveler",),
    "dégravelions": ("dégraveler",),
    "dégravellent": ("dégraveler",),
    "dégravelle": ("dégraveler",),
    "dégravellera": ("dégraveler",),
    "dégravelleraient": ("dégraveler",),
    "dégravellerai": ("dégraveler",),
    "dégravellerais": ("dégraveler",),
    "dégravellerait": ("dégraveler",),
    "dégravelleras": ("dégraveler",),
    "dégravellerez": ("dégraveler",),
    "dégravelleriez": ("dégraveler",),
    "dégravellerions": ("dégraveler",),
    "dégravellerons": ("dégraveler",),
    "dégravelleront": ("dégraveler",),
    "dégravelles": ("dégraveler",),
    "dégravelons": ("dégraveler",),
    "dégravoient": ("dégravoyer",),
    "dégravoie": ("dégravoyer",),
    "dégravoiera": ("dégravoyer",),
    "dégravoieraient": ("dégravoyer",),
    "dégravoierai": ("dégravoyer",),
    "dégravoierais": ("dégravoyer",),
    "dégravoierait": ("dégravoyer",),
    "dégravoieras": ("dégravoyer",),
    "dégravoierez": ("dégravoyer",),
    "dégravoieriez": ("dégravoyer",),
    "dégravoierions": ("dégravoyer",),
    "dégravoierons": ("dégravoyer",),
    "dégravoieront": ("dégravoyer",),
    "dégravoies": ("dégravoyer",),
    "dégravoyaient": ("dégravoyer",),
    "dégravoyai": ("dégravoyer",),
    "dégravoyais": ("dégravoyer",),
    "dégravoyait": ("dégravoyer",),
    "dégravoya": ("dégravoyer",),
    "dégravoyâmes": ("dégravoyer",),
    "dégravoyant": ("dégravoyer",),
    "dégravoyas": ("dégravoyer",),
    "dégravoyassent": ("dégravoyer",),
    "dégravoyasses": ("dégravoyer",),
    "dégravoyasse": ("dégravoyer",),
    "dégravoyassiez": ("dégravoyer",),
    "dégravoyassions": ("dégravoyer",),
    "dégravoyâtes": ("dégravoyer",),
    "dégravoyât": ("dégravoyer",),
    "dégravoyée": ("dégravoyer",),
    "dégravoyées": ("dégravoyer",),
    "dégravoyé": ("dégravoyer",),
    "dégravoyèrent": ("dégravoyer",),
    "dégravoyés": ("dégravoyer",),
    "dégravoyez": ("dégravoyer",),
    "dégravoyiez": ("dégravoyer",),
    "dégravoyions": ("dégravoyer",),
    "dégravoyons": ("dégravoyer",),
    "dégréaient": ("dégréer",),
    "dégréai": ("dégréer",),
    "dégréais": ("dégréer",),
    "dégréait": ("dégréer",),
    "dégréa": ("dégréer",),
    "dégréâmes": ("dégréer",),
    "dégréant": ("dégréer",),
    "dégréas": ("dégréer",),
    "dégréassent": ("dégréer",),
    "dégréasses": ("dégréer",),
    "dégréasse": ("dégréer",),
    "dégréassiez": ("dégréer",),
    "dégréassions": ("dégréer",),
    "dégréâtes": ("dégréer",),
    "dégréât": ("dégréer",),
    "dégréée": ("dégréer",),
    "dégréées": ("dégréer",),
    "dégréé": ("dégréer",),
    "dégréent": ("dégréer",),
    "dégrée": ("dégréer",),
    "dégréera": ("dégréer",),
    "dégréeraient": ("dégréer",),
    "dégréerai": ("dégréer",),
    "dégréerais": ("dégréer",),
    "dégréerait": ("dégréer",),
    "dégréeras": ("dégréer",),
    "dégréèrent": ("dégréer",),
    "dégréerez": ("dégréer",),
    "dégréeriez": ("dégréer",),
    "dégréerions": ("dégréer",),
    "dégréerons": ("dégréer",),
    "dégréeront": ("dégréer",),
    "dégréés": ("dégréer",),
    "dégrées": ("dégréer",),
    "dégréez": ("dégréer",),
    "dégréiez": ("dégréer",),
    "dégréions": ("dégréer",),
    "dégréons": ("dégréer",),
    "dégrevaient": ("dégrever",),
    "dégrevai": ("dégrever",),
    "dégrevais": ("dégrever",),
    "dégrevait": ("dégrever",),
    "dégreva": ("dégrever",),
    "dégrevâmes": ("dégrever",),
    "dégrevant": ("dégrever",),
    "dégrevas": ("dégrever",),
    "dégrevassent": ("dégrever",),
    "dégrevasses": ("dégrever",),
    "dégrevasse": ("dégrever",),
    "dégrevassiez": ("dégrever",),
    "dégrevassions": ("dégrever",),
    "dégrevâtes": ("dégrever",),
    "dégrevât": ("dégrever",),
    "dégrevée": ("dégrever",),
    "dégrevées": ("dégrever",),
    "dégrevé": ("dégrever",),
    "dégrèvent": ("dégrever",),
    "dégrève": ("dégrever",),
    "dégrèvera": ("dégrever",),
    "dégrèveraient": ("dégrever",),
    "dégrèverai": ("dégrever",),
    "dégrèverais": ("dégrever",),
    "dégrèverait": ("dégrever",),
    "dégrèveras": ("dégrever",),
    "dégrevèrent": ("dégrever",),
    "dégrèverez": ("dégrever",),
    "dégrèveriez": ("dégrever",),
    "dégrèverions": ("dégrever",),
    "dégrèverons": ("dégrever",),
    "dégrèveront": ("dégrever",),
    "dégrevés": ("dégrever",),
    "dégrèves": ("dégrever",),
    "dégrevez": ("dégrever",),
    "dégreviez": ("dégrever",),
    "dégrevions": ("dégrever",),
    "dégrevons": ("dégrever",),
    "dégrossie": ("dégrossir",),
    "dégrossies": ("dégrossir",),
    "dégrossi": ("dégrossir",),
    "dégrossîmes": ("dégrossir",),
    "dégrossira": ("dégrossir",),
    "dégrossiraient": ("dégrossir",),
    "dégrossirai": ("dégrossir",),
    "dégrossirais": ("dégrossir",),
    "dégrossirait": ("dégrossir",),
    "dégrossiras": ("dégrossir",),
    "dégrossirent": ("dégrossir",),
    "dégrossirez": ("dégrossir",),
    "dégrossiriez": ("dégrossir",),
    "dégrossirions": ("dégrossir",),
    "dégrossirons": ("dégrossir",),
    "dégrossiront": ("dégrossir",),
    "dégrossis": ("dégrossir",),
    "dégrossissaient": ("dégrossir",),
    "dégrossissais": ("dégrossir",),
    "dégrossissait": ("dégrossir",),
    "dégrossissant": ("dégrossir",),
    "dégrossissent": ("dégrossir",),
    "dégrossisse": ("dégrossir",),
    "dégrossisses": ("dégrossir",),
    "dégrossissez": ("dégrossir",),
    "dégrossissiez": ("dégrossir",),
    "dégrossissions": ("dégrossir",),
    "dégrossissons": ("dégrossir",),
    "dégrossîtes": ("dégrossir",),
    "dégrossit": ("dégrossir",),
    "dégrossît": ("dégrossir",),
    "déguerpi": ("déguerpir",),
    "déguerpîmes": ("déguerpir",),
    "déguerpira": ("déguerpir",),
    "déguerpiraient": ("déguerpir",),
    "déguerpirai": ("déguerpir",),
    "déguerpirais": ("déguerpir",),
    "déguerpirait": ("déguerpir",),
    "déguerpiras": ("déguerpir",),
    "déguerpirent": ("déguerpir",),
    "déguerpirez": ("déguerpir",),
    "déguerpiriez": ("déguerpir",),
    "déguerpirions": ("déguerpir",),
    "déguerpirons": ("déguerpir",),
    "déguerpiront": ("déguerpir",),
    "déguerpis": ("déguerpir",),
    "déguerpissaient": ("déguerpir",),
    "déguerpissais": ("déguerpir",),
    "déguerpissait": ("déguerpir",),
    "déguerpissant": ("déguerpir",),
    "déguerpissent": ("déguerpir",),
    "déguerpisse": ("déguerpir",),
    "déguerpisses": ("déguerpir",),
    "déguerpissez": ("déguerpir",),
    "déguerpissiez": ("déguerpir",),
    "déguerpissions": ("déguerpir",),
    "déguerpissons": ("déguerpir",),
    "déguerpîtes": ("déguerpir",),
    "déguerpit": ("déguerpir",),
    "déguerpît": ("déguerpir",),
    "dégueulassaient": ("dégueulasser",),
    "dégueulassai": ("dégueulasser",),
    "dégueulassais": ("dégueulasser",),
    "dégueulassait": ("dégueulasser",),
    "dégueulassa": ("dégueulasser",),
    "dégueulassâmes": ("dégueulasser",),
    "dégueulassant": ("dégueulasser",),
    "dégueulassas": ("dégueulasser",),
    "dégueulassassent": ("dégueulasser",),
    "dégueulassasses": ("dégueulasser",),
    "dégueulassasse": ("dégueulasser",),
    "dégueulassassiez": ("dégueulasser",),
    "dégueulassassions": ("dégueulasser",),
    "dégueulassâtes": ("dégueulasser",),
    "dégueulassât": ("dégueulasser",),
    "dégueulassée": ("dégueulasser",),
    "dégueulassées": ("dégueulasser",),
    "dégueulassé": ("dégueulasser",),
    "dégueulassent": ("dégueulasser",),
    "dégueulasse": ("dégueulasser",),
    "dégueulassera": ("dégueulasser",),
    "dégueulasseraient": ("dégueulasser",),
    "dégueulasserai": ("dégueulasser",),
    "dégueulasserais": ("dégueulasser",),
    "dégueulasserait": ("dégueulasser",),
    "dégueulasseras": ("dégueulasser",),
    "dégueulassèrent": ("dégueulasser",),
    "dégueulasserez": ("dégueulasser",),
    "dégueulasseriez": ("dégueulasser",),
    "dégueulasserions": ("dégueulasser",),
    "dégueulasserons": ("dégueulasser",),
    "dégueulasseront": ("dégueulasser",),
    "dégueulassés": ("dégueulasser",),
    "dégueulasses": ("dégueulasser",),
    "dégueulassez": ("dégueulasser",),
    "dégueulassiez": ("dégueulasser",),
    "dégueulassions": ("dégueulasser",),
    "dégueulassons": ("dégueulasser",),
    "déguillemetaient": ("déguillemeter",),
    "déguillemetai": ("déguillemeter",),
    "déguillemetais": ("déguillemeter",),
    "déguillemetait": ("déguillemeter",),
    "déguillemeta": ("déguillemeter",),
    "déguillemetâmes": ("déguillemeter",),
    "déguillemetant": ("déguillemeter",),
    "déguillemetas": ("déguillemeter",),
    "déguillemetassent": ("déguillemeter",),
    "déguillemetasses": ("déguillemeter",),
    "déguillemetasse": ("déguillemeter",),
    "déguillemetassiez": ("déguillemeter",),
    "déguillemetassions": ("déguillemeter",),
    "déguillemetâtes": ("déguillemeter",),
    "déguillemetât": ("déguillemeter",),
    "déguillemetée": ("déguillemeter",),
    "déguillemetées": ("déguillemeter",),
    "déguillemeté": ("déguillemeter",),
    "déguillemetèrent": ("déguillemeter",),
    "déguillemetés": ("déguillemeter",),
    "déguillemetez": ("déguillemeter",),
    "déguillemetiez": ("déguillemeter",),
    "déguillemetions": ("déguillemeter",),
    "déguillemetons": ("déguillemeter",),
    "déguillemettent": ("déguillemeter",),
    "déguillemette": ("déguillemeter",),
    "déguillemettera": ("déguillemeter",),
    "déguillemetteraient": ("déguillemeter",),
    "déguillemetterai": ("déguillemeter",),
    "déguillemetterais": ("déguillemeter",),
    "déguillemetterait": ("déguillemeter",),
    "déguillemetteras": ("déguillemeter",),
    "déguillemetterez": ("déguillemeter",),
    "déguillemetteriez": ("déguillemeter",),
    "déguillemetterions": ("déguillemeter",),
    "déguillemetterons": ("déguillemeter",),
    "déguillemetteront": ("déguillemeter",),
    "déguillemettes": ("déguillemeter",),
    "déifiaient": ("déifier",),
    "déifiai": ("déifier",),
    "déifiais": ("déifier",),
    "déifiait": ("déifier",),
    "déifia": ("déifier",),
    "déifiâmes": ("déifier",),
    "déifiant": ("déifier",),
    "déifias": ("déifier",),
    "déifiassent": ("déifier",),
    "déifiasses": ("déifier",),
    "déifiasse": ("déifier",),
    "déifiassiez": ("déifier",),
    "déifiassions": ("déifier",),
    "déifiâtes": ("déifier",),
    "déifiât": ("déifier",),
    "déifiée": ("déifier",),
    "déifiées": ("déifier",),
    "déifié": ("déifier",),
    "déifient": ("déifier",),
    "déifie": ("déifier",),
    "déifiera": ("déifier",),
    "déifieraient": ("déifier",),
    "déifierai": ("déifier",),
    "déifierais": ("déifier",),
    "déifierait": ("déifier",),
    "déifieras": ("déifier",),
    "déifièrent": ("déifier",),
    "déifierez": ("déifier",),
    "déifieriez": ("déifier",),
    "déifierions": ("déifier",),
    "déifierons": ("déifier",),
    "déifieront": ("déifier",),
    "déifiés": ("déifier",),
    "déifies": ("déifier",),
    "déifiez": ("déifier",),
    "déifiiez": ("déifier",),
    "déifiions": ("déifier",),
    "déifions": ("déifier",),
    "déjaugeaient": ("déjauger",),
    "déjaugeai": ("déjauger",),
    "déjaugeais": ("déjauger",),
    "déjaugeait": ("déjauger",),
    "déjaugea": ("déjauger",),
    "déjaugeâmes": ("déjauger",),
    "déjaugeant": ("déjauger",),
    "déjaugeas": ("déjauger",),
    "déjaugeassent": ("déjauger",),
    "déjaugeasses": ("déjauger",),
    "déjaugeasse": ("déjauger",),
    "déjaugeassiez": ("déjauger",),
    "déjaugeassions": ("déjauger",),
    "déjaugeâtes": ("déjauger",),
    "déjaugeât": ("déjauger",),
    "déjaugée": ("déjauger",),
    "déjaugées": ("déjauger",),
    "déjaugé": ("déjauger",),
    "déjaugent": ("déjauger",),
    "déjaugeons": ("déjauger",),
    "déjauge": ("déjauger",),
    "déjaugera": ("déjauger",),
    "déjaugeraient": ("déjauger",),
    "déjaugerai": ("déjauger",),
    "déjaugerais": ("déjauger",),
    "déjaugerait": ("déjauger",),
    "déjaugeras": ("déjauger",),
    "déjaugèrent": ("déjauger",),
    "déjaugerez": ("déjauger",),
    "déjaugeriez": ("déjauger",),
    "déjaugerions": ("déjauger",),
    "déjaugerons": ("déjauger",),
    "déjaugeront": ("déjauger",),
    "déjaugés": ("déjauger",),
    "déjauges": ("déjauger",),
    "déjaugez": ("déjauger",),
    "déjaugiez": ("déjauger",),
    "déjaugions": ("déjauger",),
    "déjaunie": ("déjaunir",),
    "déjaunies": ("déjaunir",),
    "déjauni": ("déjaunir",),
    "déjaunîmes": ("déjaunir",),
    "déjaunira": ("déjaunir",),
    "déjauniraient": ("déjaunir",),
    "déjaunirai": ("déjaunir",),
    "déjaunirais": ("déjaunir",),
    "déjaunirait": ("déjaunir",),
    "déjauniras": ("déjaunir",),
    "déjaunirent": ("déjaunir",),
    "déjaunirez": ("déjaunir",),
    "déjauniriez": ("déjaunir",),
    "déjaunirions": ("déjaunir",),
    "déjaunirons": ("déjaunir",),
    "déjauniront": ("déjaunir",),
    "déjaunis": ("déjaunir",),
    "déjaunissaient": ("déjaunir",),
    "déjaunissais": ("déjaunir",),
    "déjaunissait": ("déjaunir",),
    "déjaunissant": ("déjaunir",),
    "déjaunissent": ("déjaunir",),
    "déjaunisse": ("déjaunir",),
    "déjaunisses": ("déjaunir",),
    "déjaunissez": ("déjaunir",),
    "déjaunissiez": ("déjaunir",),
    "déjaunissions": ("déjaunir",),
    "déjaunissons": ("déjaunir",),
    "déjaunîtes": ("déjaunir",),
    "déjaunit": ("déjaunir",),
    "déjaunît": ("déjaunir",),
    "déjetaient": ("déjeter",),
    "déjetai": ("déjeter",),
    "déjetais": ("déjeter",),
    "déjetait": ("déjeter",),
    "déjeta": ("déjeter",),
    "déjetâmes": ("déjeter",),
    "déjetant": ("déjeter",),
    "déjetas": ("déjeter",),
    "déjetassent": ("déjeter",),
    "déjetasses": ("déjeter",),
    "déjetasse": ("déjeter",),
    "déjetassiez": ("déjeter",),
    "déjetassions": ("déjeter",),
    "déjetâtes": ("déjeter",),
    "déjetât": ("déjeter",),
    "déjetée": ("déjeter",),
    "déjetées": ("déjeter",),
    "déjeté": ("déjeter",),
    "déjetèrent": ("déjeter",),
    "déjetés": ("déjeter",),
    "déjetez": ("déjeter",),
    "déjetiez": ("déjeter",),
    "déjetions": ("déjeter",),
    "déjetons": ("déjeter",),
    "déjettent": ("déjeter",),
    "déjette": ("déjeter",),
    "déjettera": ("déjeter",),
    "déjetteraient": ("déjeter",),
    "déjetterai": ("déjeter",),
    "déjetterais": ("déjeter",),
    "déjetterait": ("déjeter",),
    "déjetteras": ("déjeter",),
    "déjetterez": ("déjeter",),
    "déjetteriez": ("déjeter",),
    "déjetterions": ("déjeter",),
    "déjetterons": ("déjeter",),
    "déjetteront": ("déjeter",),
    "déjettes": ("déjeter",),
    "déjoignaient": ("déjoindre",),
    "déjoignais": ("déjoindre",),
    "déjoignait": ("déjoindre",),
    "déjoignant": ("déjoindre",),
    "déjoignent": ("déjoindre",),
    "déjoigne": ("déjoindre",),
    "déjoignes": ("déjoindre",),
    "déjoignez": ("déjoindre",),
    "déjoigniez": ("déjoindre",),
    "déjoignîmes": ("déjoindre",),
    "déjoignions": ("déjoindre",),
    "déjoignirent": ("déjoindre",),
    "déjoignis": ("déjoindre",),
    "déjoignissent": ("déjoindre",),
    "déjoignisses": ("déjoindre",),
    "déjoignisse": ("déjoindre",),
    "déjoignissiez": ("déjoindre",),
    "déjoignissions": ("déjoindre",),
    "déjoignîtes": ("déjoindre",),
    "déjoignit": ("déjoindre",),
    "déjoignît": ("déjoindre",),
    "déjoignons": ("déjoindre",),
    "déjoindra": ("déjoindre",),
    "déjoindraient": ("déjoindre",),
    "déjoindrai": ("déjoindre",),
    "déjoindrais": ("déjoindre",),
    "déjoindrait": ("déjoindre",),
    "déjoindras": ("déjoindre",),
    "déjoindrez": ("déjoindre",),
    "déjoindriez": ("déjoindre",),
    "déjoindrions": ("déjoindre",),
    "déjoindrons": ("déjoindre",),
    "déjoindront": ("déjoindre",),
    "déjoins": ("déjoindre",),
    "déjointe": ("déjoindre",),
    "déjointes": ("déjoindre",),
    "déjoint": ("déjoindre",),
    "déjoints": ("déjoindre",),
    "déjugeaient": ("déjuger",),
    "déjugeai": ("déjuger",),
    "déjugeais": ("déjuger",),
    "déjugeait": ("déjuger",),
    "déjugea": ("déjuger",),
    "déjugeâmes": ("déjuger",),
    "déjugeant": ("déjuger",),
    "déjugeas": ("déjuger",),
    "déjugeassent": ("déjuger",),
    "déjugeasses": ("déjuger",),
    "déjugeasse": ("déjuger",),
    "déjugeassiez": ("déjuger",),
    "déjugeassions": ("déjuger",),
    "déjugeâtes": ("déjuger",),
    "déjugeât": ("déjuger",),
    "déjugée": ("déjuger",),
    "déjugées": ("déjuger",),
    "déjugé": ("déjuger",),
    "déjugent": ("déjuger",),
    "déjugeons": ("déjuger",),
    "déjuge": ("déjuger",),
    "déjugera": ("déjuger",),
    "déjugeraient": ("déjuger",),
    "déjugerai": ("déjuger",),
    "déjugerais": ("déjuger",),
    "déjugerait": ("déjuger",),
    "déjugeras": ("déjuger",),
    "déjugèrent": ("déjuger",),
    "déjugerez": ("déjuger",),
    "déjugeriez": ("déjuger",),
    "déjugerions": ("déjuger",),
    "déjugerons": ("déjuger",),
    "déjugeront": ("déjuger",),
    "déjugés": ("déjuger",),
    "déjuges": ("déjuger",),
    "déjugez": ("déjuger",),
    "déjugiez": ("déjuger",),
    "déjugions": ("déjuger",),
    "délaçaient": ("délacer",),
    "délaçai": ("délacer",),
    "délaçais": ("délacer",),
    "délaçait": ("délacer",),
    "délaça": ("délacer",),
    "délaçâmes": ("délacer",),
    "délaçant": ("délacer",),
    "délaças": ("délacer",),
    "délaçassent": ("délacer",),
    "délaçasses": ("délacer",),
    "délaçasse": ("délacer",),
    "délaçassiez": ("délacer",),
    "délaçassions": ("délacer",),
    "délaçâtes": ("délacer",),
    "délaçât": ("délacer",),
    "délacée": ("délacer",),
    "délacées": ("délacer",),
    "délacé": ("délacer",),
    "délacent": ("délacer",),
    "délace": ("délacer",),
    "délacera": ("délacer",),
    "délaceraient": ("délacer",),
    "délacerai": ("délacer",),
    "délacerais": ("délacer",),
    "délacerait": ("délacer",),
    "délaceras": ("délacer",),
    "délacèrent": ("délacer",),
    "délacerez": ("délacer",),
    "délaceriez": ("délacer",),
    "délacerions": ("délacer",),
    "délacerons": ("délacer",),
    "délaceront": ("délacer",),
    "délacés": ("délacer",),
    "délaces": ("délacer",),
    "délacez": ("délacer",),
    "délaciez": ("délacer",),
    "délacions": ("délacer",),
    "délaçons": ("délacer",),
    "délangeaient": ("délanger",),
    "délangeai": ("délanger",),
    "délangeais": ("délanger",),
    "délangeait": ("délanger",),
    "délangea": ("délanger",),
    "délangeâmes": ("délanger",),
    "délangeant": ("délanger",),
    "délangeas": ("délanger",),
    "délangeassent": ("délanger",),
    "délangeasses": ("délanger",),
    "délangeasse": ("délanger",),
    "délangeassiez": ("délanger",),
    "délangeassions": ("délanger",),
    "délangeâtes": ("délanger",),
    "délangeât": ("délanger",),
    "délangée": ("délanger",),
    "délangées": ("délanger",),
    "délangé": ("délanger",),
    "délangent": ("délanger",),
    "délangeons": ("délanger",),
    "délange": ("délanger",),
    "délangera": ("délanger",),
    "délangeraient": ("délanger",),
    "délangerai": ("délanger",),
    "délangerais": ("délanger",),
    "délangerait": ("délanger",),
    "délangeras": ("délanger",),
    "délangèrent": ("délanger",),
    "délangerez": ("délanger",),
    "délangeriez": ("délanger",),
    "délangerions": ("délanger",),
    "délangerons": ("délanger",),
    "délangeront": ("délanger",),
    "délangés": ("délanger",),
    "délanges": ("délanger",),
    "délangez": ("délanger",),
    "délangiez": ("délanger",),
    "délangions": ("délanger",),
    "délaniéraient": ("délaniérer",),
    "délaniérai": ("délaniérer",),
    "délaniérais": ("délaniérer",),
    "délaniérait": ("délaniérer",),
    "délaniéra": ("délaniérer",),
    "délaniérâmes": ("délaniérer",),
    "délaniérant": ("délaniérer",),
    "délaniéras": ("délaniérer",),
    "délaniérassent": ("délaniérer",),
    "délaniérasses": ("délaniérer",),
    "délaniérasse": ("délaniérer",),
    "délaniérassiez": ("délaniérer",),
    "délaniérassions": ("délaniérer",),
    "délaniérâtes": ("délaniérer",),
    "délaniérât": ("délaniérer",),
    "délaniérée": ("délaniérer",),
    "délaniérées": ("délaniérer",),
    "délaniéré": ("délaniérer",),
    "délanièrent": ("délaniérer",),
    "délanière": ("délaniérer",),
    "délaniérera": ("délaniérer",),
    "délaniéreraient": ("délaniérer",),
    "délaniérerai": ("délaniérer",),
    "délaniérerais": ("délaniérer",),
    "délaniérerait": ("délaniérer",),
    "délaniéreras": ("délaniérer",),
    "délaniérèrent": ("délaniérer",),
    "délaniérerez": ("délaniérer",),
    "délaniéreriez": ("délaniérer",),
    "délaniérerions": ("délaniérer",),
    "délaniérerons": ("délaniérer",),
    "délaniéreront": ("délaniérer",),
    "délaniérés": ("délaniérer",),
    "délanières": ("délaniérer",),
    "délaniérez": ("délaniérer",),
    "délaniériez": ("délaniérer",),
    "délaniérions": ("délaniérer",),
    "délaniérons": ("délaniérer",),
    "délassaient": ("délasser",),
    "délassai": ("délasser",),
    "délassais": ("délasser",),
    "délassait": ("délasser",),
    "délassa": ("délasser",),
    "délassâmes": ("délasser",),
    "délassant": ("délasser",),
    "délassas": ("délasser",),
    "délassassent": ("délasser",),
    "délassasses": ("délasser",),
    "délassasse": ("délasser",),
    "délassassiez": ("délasser",),
    "délassassions": ("délasser",),
    "délassâtes": ("délasser",),
    "délassât": ("délasser",),
    "délassée": ("délasser",),
    "délassées": ("délasser",),
    "délassé": ("délasser",),
    "délassent": ("délasser",),
    "délasse": ("délasser",),
    "délassera": ("délasser",),
    "délasseraient": ("délasser",),
    "délasserai": ("délasser",),
    "délasserais": ("délasser",),
    "délasserait": ("délasser",),
    "délasseras": ("délasser",),
    "délassèrent": ("délasser",),
    "délasserez": ("délasser",),
    "délasseriez": ("délasser",),
    "délasserions": ("délasser",),
    "délasserons": ("délasser",),
    "délasseront": ("délasser",),
    "délassés": ("délasser",),
    "délasses": ("délasser",),
    "délassez": ("délasser",),
    "délassiez": ("délasser",),
    "délassions": ("délasser",),
    "délassons": ("délasser",),
    "délaient": ("délayer",),
    "délaie": ("délayer",),
    "délaiera": ("délayer",),
    "délaieraient": ("délayer",),
    "délaierai": ("délayer",),
    "délaierais": ("délayer",),
    "délaierait": ("délayer",),
    "délaieras": ("délayer",),
    "délaierez": ("délayer",),
    "délaieriez": ("délayer",),
    "délaierions": ("délayer",),
    "délaierons": ("délayer",),
    "délaieront": ("délayer",),
    "délaies": ("délayer",),
    "délayaient": ("délayer",),
    "délayai": ("délayer",),
    "délayais": ("délayer",),
    "délayait": ("délayer",),
    "délaya": ("délayer",),
    "délayâmes": ("délayer",),
    "délayant": ("délayer",),
    "délayas": ("délayer",),
    "délayassent": ("délayer",),
    "délayasses": ("délayer",),
    "délayasse": ("délayer",),
    "délayassiez": ("délayer",),
    "délayassions": ("délayer",),
    "délayâtes": ("délayer",),
    "délayât": ("délayer",),
    "délayée": ("délayer",),
    "délayées": ("délayer",),
    "délayé": ("délayer",),
    "délayent": ("délayer",),
    "délaye": ("délayer",),
    "délayera": ("délayer",),
    "délayeraient": ("délayer",),
    "délayerai": ("délayer",),
    "délayerais": ("délayer",),
    "délayerait": ("délayer",),
    "délayeras": ("délayer",),
    "délayèrent": ("délayer",),
    "délayerez": ("délayer",),
    "délayeriez": ("délayer",),
    "délayerions": ("délayer",),
    "délayerons": ("délayer",),
    "délayeront": ("délayer",),
    "délayés": ("délayer",),
    "délayes": ("délayer",),
    "délayez": ("délayer",),
    "délayiez": ("délayer",),
    "délayions": ("délayer",),
    "délayons": ("délayer",),
    "déléguaient": ("déléguer",),
    "déléguai": ("déléguer",),
    "déléguais": ("déléguer",),
    "déléguait": ("déléguer",),
    "délégua": ("déléguer",),
    "déléguâmes": ("déléguer",),
    "déléguant": ("déléguer",),
    "déléguas": ("déléguer",),
    "déléguassent": ("déléguer",),
    "déléguasses": ("déléguer",),
    "déléguasse": ("déléguer",),
    "déléguassiez": ("déléguer",),
    "déléguassions": ("déléguer",),
    "déléguâtes": ("déléguer",),
    "déléguât": ("déléguer",),
    "déléguée": ("déléguer",),
    "déléguées": ("déléguer",),
    "délégué": ("déléguer",),
    "délèguent": ("déléguer",),
    "délègue": ("déléguer",),
    "déléguera": ("déléguer",),
    "délégueraient": ("déléguer",),
    "déléguerai": ("déléguer",),
    "déléguerais": ("déléguer",),
    "déléguerait": ("déléguer",),
    "délégueras": ("déléguer",),
    "déléguèrent": ("déléguer",),
    "déléguerez": ("déléguer",),
    "délégueriez": ("déléguer",),
    "déléguerions": ("déléguer",),
    "déléguerons": ("déléguer",),
    "délégueront": ("déléguer",),
    "délégués": ("déléguer",),
    "délègues": ("déléguer",),
    "déléguez": ("déléguer",),
    "déléguiez": ("déléguer",),
    "déléguions": ("déléguer",),
    "déléguons": ("déléguer",),
    "délétaient": ("déléter",),
    "délétai": ("déléter",),
    "délétais": ("déléter",),
    "délétait": ("déléter",),
    "déléta": ("déléter",),
    "délétâmes": ("déléter",),
    "délétant": ("déléter",),
    "délétas": ("déléter",),
    "délétassent": ("déléter",),
    "délétasses": ("déléter",),
    "délétasse": ("déléter",),
    "délétassiez": ("déléter",),
    "délétassions": ("déléter",),
    "délétâtes": ("déléter",),
    "délétât": ("déléter",),
    "délétée": ("déléter",),
    "délétées": ("déléter",),
    "délété": ("déléter",),
    "délètent": ("déléter",),
    "délète": ("déléter",),
    "délétera": ("déléter",),
    "déléteraient": ("déléter",),
    "déléterai": ("déléter",),
    "déléterais": ("déléter",),
    "déléterait": ("déléter",),
    "déléteras": ("déléter",),
    "délétèrent": ("déléter",),
    "déléterez": ("déléter",),
    "déléteriez": ("déléter",),
    "déléterions": ("déléter",),
    "déléterons": ("déléter",),
    "déléteront": ("déléter",),
    "délétés": ("déléter",),
    "délètes": ("déléter",),
    "délétez": ("déléter",),
    "délétiez": ("déléter",),
    "délétions": ("déléter",),
    "délétons": ("déléter",),
    "délibéraient": ("délibérer",),
    "délibérai": ("délibérer",),
    "délibérais": ("délibérer",),
    "délibérait": ("délibérer",),
    "délibéra": ("délibérer",),
    "délibérâmes": ("délibérer",),
    "délibérant": ("délibérer",),
    "délibéras": ("délibérer",),
    "délibérassent": ("délibérer",),
    "délibérasses": ("délibérer",),
    "délibérasse": ("délibérer",),
    "délibérassiez": ("délibérer",),
    "délibérassions": ("délibérer",),
    "délibérâtes": ("délibérer",),
    "délibérât": ("délibérer",),
    "délibéré": ("délibérer",),
    "délibèrent": ("délibérer",),
    "délibère": ("délibérer",),
    "délibérera": ("délibérer",),
    "délibéreraient": ("délibérer",),
    "délibérerai": ("délibérer",),
    "délibérerais": ("délibérer",),
    "délibérerait": ("délibérer",),
    "délibéreras": ("délibérer",),
    "délibérèrent": ("délibérer",),
    "délibérerez": ("délibérer",),
    "délibéreriez": ("délibérer",),
    "délibérerions": ("délibérer",),
    "délibérerons": ("délibérer",),
    "délibéreront": ("délibérer",),
    "délibères": ("délibérer",),
    "délibérez": ("délibérer",),
    "délibériez": ("délibérer",),
    "délibérions": ("délibérer",),
    "délibérons": ("délibérer",),
    "déliaient": ("délier",),
    "déliai": ("délier",),
    "déliais": ("délier",),
    "déliait": ("délier",),
    "délia": ("délier",),
    "déliâmes": ("délier",),
    "déliant": ("délier",),
    "délias": ("délier",),
    "déliassent": ("délier",),
    "déliasses": ("délier",),
    "déliasse": ("délier",),
    "déliassiez": ("délier",),
    "déliassions": ("délier",),
    "déliâtes": ("délier",),
    "déliât": ("délier",),
    "déliée": ("délier",),
    "déliées": ("délier",),
    "délié": ("délier",),
    "délient": ("délier",),
    "délie": ("délier",),
    "déliera": ("délier",),
    "délieraient": ("délier",),
    "délierai": ("délier",),
    "délierais": ("délier",),
    "délierait": ("délier",),
    "délieras": ("délier",),
    "délièrent": ("délier",),
    "délierez": ("délier",),
    "délieriez": ("délier",),
    "délierions": ("délier",),
    "délierons": ("délier",),
    "délieront": ("délier",),
    "déliés": ("délier",),
    "délies": ("délier",),
    "déliez": ("délier",),
    "déliiez": ("délier",),
    "déliions": ("délier",),
    "délions": ("délier",),
    "délignifiaient": ("délignifier",),
    "délignifiai": ("délignifier",),
    "délignifiais": ("délignifier",),
    "délignifiait": ("délignifier",),
    "délignifia": ("délignifier",),
    "délignifiâmes": ("délignifier",),
    "délignifiant": ("délignifier",),
    "délignifias": ("délignifier",),
    "délignifiassent": ("délignifier",),
    "délignifiasses": ("délignifier",),
    "délignifiasse": ("délignifier",),
    "délignifiassiez": ("délignifier",),
    "délignifiassions": ("délignifier",),
    "délignifiâtes": ("délignifier",),
    "délignifiât": ("délignifier",),
    "délignifiée": ("délignifier",),
    "délignifiées": ("délignifier",),
    "délignifié": ("délignifier",),
    "délignifient": ("délignifier",),
    "délignifie": ("délignifier",),
    "délignifiera": ("délignifier",),
    "délignifieraient": ("délignifier",),
    "délignifierai": ("délignifier",),
    "délignifierais": ("délignifier",),
    "délignifierait": ("délignifier",),
    "délignifieras": ("délignifier",),
    "délignifièrent": ("délignifier",),
    "délignifierez": ("délignifier",),
    "délignifieriez": ("délignifier",),
    "délignifierions": ("délignifier",),
    "délignifierons": ("délignifier",),
    "délignifieront": ("délignifier",),
    "délignifiés": ("délignifier",),
    "délignifies": ("délignifier",),
    "délignifiez": ("délignifier",),
    "délignifiiez": ("délignifier",),
    "délignifiions": ("délignifier",),
    "délignifions": ("délignifier",),
    "délinéaient": ("délinéer",),
    "délinéai": ("délinéer",),
    "délinéais": ("délinéer",),
    "délinéait": ("délinéer",),
    "délinéa": ("délinéer",),
    "délinéâmes": ("délinéer",),
    "délinéant": ("délinéer",),
    "délinéas": ("délinéer",),
    "délinéassent": ("délinéer",),
    "délinéasses": ("délinéer",),
    "délinéasse": ("délinéer",),
    "délinéassiez": ("délinéer",),
    "délinéassions": ("délinéer",),
    "délinéâtes": ("délinéer",),
    "délinéât": ("délinéer",),
    "délinéée": ("délinéer",),
    "délinéées": ("délinéer",),
    "délinéé": ("délinéer",),
    "délinéent": ("délinéer",),
    "délinée": ("délinéer",),
    "délinéera": ("délinéer",),
    "délinéeraient": ("délinéer",),
    "délinéerai": ("délinéer",),
    "délinéerais": ("délinéer",),
    "délinéerait": ("délinéer",),
    "délinéeras": ("délinéer",),
    "délinéèrent": ("délinéer",),
    "délinéerez": ("délinéer",),
    "délinéeriez": ("délinéer",),
    "délinéerions": ("délinéer",),
    "délinéerons": ("délinéer",),
    "délinéeront": ("délinéer",),
    "délinéés": ("délinéer",),
    "délinées": ("délinéer",),
    "délinéez": ("délinéer",),
    "délinéiez": ("délinéer",),
    "délinéions": ("délinéer",),
    "délinéons": ("délinéer",),
    "délogeaient": ("déloger",),
    "délogeai": ("déloger",),
    "délogeais": ("déloger",),
    "délogeait": ("déloger",),
    "délogea": ("déloger",),
    "délogeâmes": ("déloger",),
    "délogeant": ("déloger",),
    "délogeas": ("déloger",),
    "délogeassent": ("déloger",),
    "délogeasses": ("déloger",),
    "délogeasse": ("déloger",),
    "délogeassiez": ("déloger",),
    "délogeassions": ("déloger",),
    "délogeâtes": ("déloger",),
    "délogeât": ("déloger",),
    "délogée": ("déloger",),
    "délogées": ("déloger",),
    "délogé": ("déloger",),
    "délogent": ("déloger",),
    "délogeons": ("déloger",),
    "déloge": ("déloger",),
    "délogera": ("déloger",),
    "délogeraient": ("déloger",),
    "délogerai": ("déloger",),
    "délogerais": ("déloger",),
    "délogerait": ("déloger",),
    "délogeras": ("déloger",),
    "délogèrent": ("déloger",),
    "délogerez": ("déloger",),
    "délogeriez": ("déloger",),
    "délogerions": ("déloger",),
    "délogerons": ("déloger",),
    "délogeront": ("déloger",),
    "délogés": ("déloger",),
    "déloges": ("déloger",),
    "délogez": ("déloger",),
    "délogiez": ("déloger",),
    "délogions": ("déloger",),
    "délongeaient": ("délonger",),
    "délongeai": ("délonger",),
    "délongeais": ("délonger",),
    "délongeait": ("délonger",),
    "délongea": ("délonger",),
    "délongeâmes": ("délonger",),
    "délongeant": ("délonger",),
    "délongeas": ("délonger",),
    "délongeassent": ("délonger",),
    "délongeasses": ("délonger",),
    "délongeasse": ("délonger",),
    "délongeassiez": ("délonger",),
    "délongeassions": ("délonger",),
    "délongeâtes": ("délonger",),
    "délongeât": ("délonger",),
    "délongée": ("délonger",),
    "délongées": ("délonger",),
    "délongé": ("délonger",),
    "délongent": ("délonger",),
    "délongeons": ("délonger",),
    "délonge": ("délonger",),
    "délongera": ("délonger",),
    "délongeraient": ("délonger",),
    "délongerai": ("délonger",),
    "délongerais": ("délonger",),
    "délongerait": ("délonger",),
    "délongeras": ("délonger",),
    "délongèrent": ("délonger",),
    "délongerez": ("délonger",),
    "délongeriez": ("délonger",),
    "délongerions": ("délonger",),
    "délongerons": ("délonger",),
    "délongeront": ("délonger",),
    "délongés": ("délonger",),
    "délonges": ("délonger",),
    "délongez": ("délonger",),
    "délongiez": ("délonger",),
    "délongions": ("délonger",),
    "délongie": ("délongir",),
    "délongies": ("délongir",),
    "délongi": ("délongir",),
    "délongîmes": ("délongir",),
    "délongira": ("délongir",),
    "délongiraient": ("délongir",),
    "délongirai": ("délongir",),
    "délongirais": ("délongir",),
    "délongirait": ("délongir",),
    "délongiras": ("délongir",),
    "délongirent": ("délongir",),
    "délongirez": ("délongir",),
    "délongiriez": ("délongir",),
    "délongirions": ("délongir",),
    "délongirons": ("délongir",),
    "délongiront": ("délongir",),
    "délongis": ("délongir",),
    "délongissaient": ("délongir",),
    "délongissais": ("délongir",),
    "délongissait": ("délongir",),
    "délongissant": ("délongir",),
    "délongissent": ("délongir",),
    "délongisse": ("délongir",),
    "délongisses": ("délongir",),
    "délongissez": ("délongir",),
    "délongissiez": ("délongir",),
    "délongissions": ("délongir",),
    "délongissons": ("délongir",),
    "délongîtes": ("délongir",),
    "délongit": ("délongir",),
    "délongît": ("délongir",),
    "délugeaient": ("déluger",),
    "délugeait": ("déluger",),
    "délugea": ("déluger",),
    "délugeant": ("déluger",),
    "délugeassent": ("déluger",),
    "délugeât": ("déluger",),
    "délugée": ("déluger",),
    "délugées": ("déluger",),
    "délugé": ("déluger",),
    "délugent": ("déluger",),
    "déluge": ("déluger",),
    "délugera": ("déluger",),
    "délugeraient": ("déluger",),
    "délugerait": ("déluger",),
    "délugèrent": ("déluger",),
    "délugeront": ("déluger",),
    "délugés": ("déluger",),
    "démaigrie": ("démaigrir",),
    "démaigries": ("démaigrir",),
    "démaigri": ("démaigrir",),
    "démaigrîmes": ("démaigrir",),
    "démaigrira": ("démaigrir",),
    "démaigriraient": ("démaigrir",),
    "démaigrirai": ("démaigrir",),
    "démaigrirais": ("démaigrir",),
    "démaigrirait": ("démaigrir",),
    "démaigriras": ("démaigrir",),
    "démaigrirent": ("démaigrir",),
    "démaigrirez": ("démaigrir",),
    "démaigririez": ("démaigrir",),
    "démaigririons": ("démaigrir",),
    "démaigrirons": ("démaigrir",),
    "démaigriront": ("démaigrir",),
    "démaigris": ("démaigrir",),
    "démaigrissaient": ("démaigrir",),
    "démaigrissais": ("démaigrir",),
    "démaigrissait": ("démaigrir",),
    "démaigrissant": ("démaigrir",),
    "démaigrissent": ("démaigrir",),
    "démaigrisse": ("démaigrir",),
    "démaigrisses": ("démaigrir",),
    "démaigrissez": ("démaigrir",),
    "démaigrissiez": ("démaigrir",),
    "démaigrissions": ("démaigrir",),
    "démaigrissons": ("démaigrir",),
    "démaigrîtes": ("démaigrir",),
    "démaigrit": ("démaigrir",),
    "démaigrît": ("démaigrir",),
    "démangeaient": ("démanger",),
    "démangeai": ("démanger",),
    "démangeais": ("démanger",),
    "démangeait": ("démanger",),
    "démangea": ("démanger",),
    "démangeâmes": ("démanger",),
    "démangeant": ("démanger",),
    "démangeas": ("démanger",),
    "démangeassent": ("démanger",),
    "démangeasses": ("démanger",),
    "démangeasse": ("démanger",),
    "démangeassiez": ("démanger",),
    "démangeassions": ("démanger",),
    "démangeâtes": ("démanger",),
    "démangeât": ("démanger",),
    "démangée": ("démanger",),
    "démangées": ("démanger",),
    "démangé": ("démanger",),
    "démangent": ("démanger",),
    "démangeons": ("démanger",),
    "démange": ("démanger",),
    "démangera": ("démanger",),
    "démangeraient": ("démanger",),
    "démangerai": ("démanger",),
    "démangerais": ("démanger",),
    "démangerait": ("démanger",),
    "démangeras": ("démanger",),
    "démangèrent": ("démanger",),
    "démangerez": ("démanger",),
    "démangeriez": ("démanger",),
    "démangerions": ("démanger",),
    "démangerons": ("démanger",),
    "démangeront": ("démanger",),
    "démangés": ("démanger",),
    "démanges": ("démanger",),
    "démangez": ("démanger",),
    "démangiez": ("démanger",),
    "démangions": ("démanger",),
    "démantelaient": ("démanteler",),
    "démantelai": ("démanteler",),
    "démantelais": ("démanteler",),
    "démantelait": ("démanteler",),
    "démantela": ("démanteler",),
    "démantelâmes": ("démanteler",),
    "démantelant": ("démanteler",),
    "démantelas": ("démanteler",),
    "démantelassent": ("démanteler",),
    "démantelasses": ("démanteler",),
    "démantelasse": ("démanteler",),
    "démantelassiez": ("démanteler",),
    "démantelassions": ("démanteler",),
    "démantelâtes": ("démanteler",),
    "démantelât": ("démanteler",),
    "démantelée": ("démanteler",),
    "démantelées": ("démanteler",),
    "démantelé": ("démanteler",),
    "démantèlent": ("démanteler",),
    "démantèle": ("démanteler",),
    "démantèlera": ("démanteler",),
    "démantèleraient": ("démanteler",),
    "démantèlerai": ("démanteler",),
    "démantèlerais": ("démanteler",),
    "démantèlerait": ("démanteler",),
    "démantèleras": ("démanteler",),
    "démantelèrent": ("démanteler",),
    "démantèlerez": ("démanteler",),
    "démantèleriez": ("démanteler",),
    "démantèlerions": ("démanteler",),
    "démantèlerons": ("démanteler",),
    "démantèleront": ("démanteler",),
    "démantelés": ("démanteler",),
    "démantèles": ("démanteler",),
    "démantelez": ("démanteler",),
    "démanteliez": ("démanteler",),
    "démantelions": ("démanteler",),
    "démantelons": ("démanteler",),
    "démargeaient": ("démarger",),
    "démargeai": ("démarger",),
    "démargeais": ("démarger",),
    "démargeait": ("démarger",),
    "démargea": ("démarger",),
    "démargeâmes": ("démarger",),
    "démargeant": ("démarger",),
    "démargeas": ("démarger",),
    "démargeassent": ("démarger",),
    "démargeasses": ("démarger",),
    "démargeasse": ("démarger",),
    "démargeassiez": ("démarger",),
    "démargeassions": ("démarger",),
    "démargeâtes": ("démarger",),
    "démargeât": ("démarger",),
    "démargée": ("démarger",),
    "démargées": ("démarger",),
    "démargé": ("démarger",),
    "démargent": ("démarger",),
    "démargeons": ("démarger",),
    "démarge": ("démarger",),
    "démargera": ("démarger",),
    "démargeraient": ("démarger",),
    "démargerai": ("démarger",),
    "démargerais": ("démarger",),
    "démargerait": ("démarger",),
    "démargeras": ("démarger",),
    "démargèrent": ("démarger",),
    "démargerez": ("démarger",),
    "démargeriez": ("démarger",),
    "démargerions": ("démarger",),
    "démargerons": ("démarger",),
    "démargeront": ("démarger",),
    "démargés": ("démarger",),
    "démarges": ("démarger",),
    "démargez": ("démarger",),
    "démargiez": ("démarger",),
    "démargions": ("démarger",),
    "démariaient": ("démarier",),
    "démariai": ("démarier",),
    "démariais": ("démarier",),
    "démariait": ("démarier",),
    "démaria": ("démarier",),
    "démariâmes": ("démarier",),
    "démariant": ("démarier",),
    "démarias": ("démarier",),
    "démariassent": ("démarier",),
    "démariasses": ("démarier",),
    "démariasse": ("démarier",),
    "démariassiez": ("démarier",),
    "démariassions": ("démarier",),
    "démariâtes": ("démarier",),
    "démariât": ("démarier",),
    "démariée": ("démarier",),
    "démariées": ("démarier",),
    "démarié": ("démarier",),
    "démarient": ("démarier",),
    "démarie": ("démarier",),
    "démariera": ("démarier",),
    "démarieraient": ("démarier",),
    "démarierai": ("démarier",),
    "démarierais": ("démarier",),
    "démarierait": ("démarier",),
    "démarieras": ("démarier",),
    "démarièrent": ("démarier",),
    "démarierez": ("démarier",),
    "démarieriez": ("démarier",),
    "démarierions": ("démarier",),
    "démarierons": ("démarier",),
    "démarieront": ("démarier",),
    "démariés": ("démarier",),
    "démaries": ("démarier",),
    "démariez": ("démarier",),
    "démariiez": ("démarier",),
    "démariions": ("démarier",),
    "démarions": ("démarier",),
    "démassifiaient": ("démassifier",),
    "démassifiai": ("démassifier",),
    "démassifiais": ("démassifier",),
    "démassifiait": ("démassifier",),
    "démassifia": ("démassifier",),
    "démassifiâmes": ("démassifier",),
    "démassifiant": ("démassifier",),
    "démassifias": ("démassifier",),
    "démassifiassent": ("démassifier",),
    "démassifiasses": ("démassifier",),
    "démassifiasse": ("démassifier",),
    "démassifiassiez": ("démassifier",),
    "démassifiassions": ("démassifier",),
    "démassifiâtes": ("démassifier",),
    "démassifiât": ("démassifier",),
    "démassifiée": ("démassifier",),
    "démassifiées": ("démassifier",),
    "démassifié": ("démassifier",),
    "démassifient": ("démassifier",),
    "démassifie": ("démassifier",),
    "démassifiera": ("démassifier",),
    "démassifieraient": ("démassifier",),
    "démassifierai": ("démassifier",),
    "démassifierais": ("démassifier",),
    "démassifierait": ("démassifier",),
    "démassifieras": ("démassifier",),
    "démassifièrent": ("démassifier",),
    "démassifierez": ("démassifier",),
    "démassifieriez": ("démassifier",),
    "démassifierions": ("démassifier",),
    "démassifierons": ("démassifier",),
    "démassifieront": ("démassifier",),
    "démassifiés": ("démassifier",),
    "démassifies": ("démassifier",),
    "démassifiez": ("démassifier",),
    "démassifiiez": ("démassifier",),
    "démassifiions": ("démassifier",),
    "démassifions": ("démassifier",),
    "démâtaient": ("démâter",),
    "démâtai": ("démâter",),
    "démâtais": ("démâter",),
    "démâtait": ("démâter",),
    "démâta": ("démâter",),
    "démâtâmes": ("démâter",),
    "démâtant": ("démâter",),
    "démâtas": ("démâter",),
    "démâtassent": ("démâter",),
    "démâtasses": ("démâter",),
    "démâtasse": ("démâter",),
    "démâtassiez": ("démâter",),
    "démâtassions": ("démâter",),
    "démâtâtes": ("démâter",),
    "démâtât": ("démâter",),
    "démâtée": ("démâter",),
    "démâtées": ("démâter",),
    "démâté": ("démâter",),
    "démâtent": ("démâter",),
    "démâte": ("démâter",),
    "démâtera": ("démâter",),
    "démâteraient": ("démâter",),
    "démâterai": ("démâter",),
    "démâterais": ("démâter",),
    "démâterait": ("démâter",),
    "démâteras": ("démâter",),
    "démâtèrent": ("démâter",),
    "démâterez": ("démâter",),
    "démâteriez": ("démâter",),
    "démâterions": ("démâter",),
    "démâterons": ("démâter",),
    "démâteront": ("démâter",),
    "démâtés": ("démâter",),
    "démâtes": ("démâter",),
    "démâtez": ("démâter",),
    "démâtiez": ("démâter",),
    "démâtions": ("démâter",),
    "démâtons": ("démâter",),
    "déméchaient": ("démécher",),
    "déméchai": ("démécher",),
    "déméchais": ("démécher",),
    "déméchait": ("démécher",),
    "démécha": ("démécher",),
    "déméchâmes": ("démécher",),
    "déméchant": ("démécher",),
    "déméchas": ("démécher",),
    "déméchassent": ("démécher",),
    "déméchasses": ("démécher",),
    "déméchasse": ("démécher",),
    "déméchassiez": ("démécher",),
    "déméchassions": ("démécher",),
    "déméchâtes": ("démécher",),
    "déméchât": ("démécher",),
    "déméchée": ("démécher",),
    "déméchées": ("démécher",),
    "déméché": ("démécher",),
    "démèchent": ("démécher",),
    "démèche": ("démécher",),
    "déméchera": ("démécher",),
    "démécheraient": ("démécher",),
    "démécherai": ("démécher",),
    "démécherais": ("démécher",),
    "démécherait": ("démécher",),
    "démécheras": ("démécher",),
    "déméchèrent": ("démécher",),
    "démécherez": ("démécher",),
    "démécheriez": ("démécher",),
    "démécherions": ("démécher",),
    "démécherons": ("démécher",),
    "démécheront": ("démécher",),
    "déméchés": ("démécher",),
    "démèches": ("démécher",),
    "déméchez": ("démécher",),
    "déméchiez": ("démécher",),
    "déméchions": ("démécher",),
    "déméchons": ("démécher",),
    "déménageaient": ("déménager",),
    "déménageai": ("déménager",),
    "déménageais": ("déménager",),
    "déménageait": ("déménager",),
    "déménagea": ("déménager",),
    "déménageâmes": ("déménager",),
    "déménageant": ("déménager",),
    "déménageas": ("déménager",),
    "déménageassent": ("déménager",),
    "déménageasses": ("déménager",),
    "déménageasse": ("déménager",),
    "déménageassiez": ("déménager",),
    "déménageassions": ("déménager",),
    "déménageâtes": ("déménager",),
    "déménageât": ("déménager",),
    "déménagée": ("déménager",),
    "déménagées": ("déménager",),
    "déménagé": ("déménager",),
    "déménagent": ("déménager",),
    "déménageons": ("déménager",),
    "déménage": ("déménager",),
    "déménagera": ("déménager",),
    "déménageraient": ("déménager",),
    "déménagerai": ("déménager",),
    "déménagerais": ("déménager",),
    "déménagerait": ("déménager",),
    "déménageras": ("déménager",),
    "déménagèrent": ("déménager",),
    "déménagerez": ("déménager",),
    "déménageriez": ("déménager",),
    "déménagerions": ("déménager",),
    "déménagerons": ("déménager",),
    "déménageront": ("déménager",),
    "déménagés": ("déménager",),
    "déménages": ("déménager",),
    "déménagez": ("déménager",),
    "déménagiez": ("déménager",),
    "déménagions": ("déménager",),
    "démenaient": ("démener",),
    "démenai": ("démener",),
    "démenais": ("démener",),
    "démenait": ("démener",),
    "démena": ("démener",),
    "démenâmes": ("démener",),
    "démenant": ("démener",),
    "démenas": ("démener",),
    "démenassent": ("démener",),
    "démenasses": ("démener",),
    "démenasse": ("démener",),
    "démenassiez": ("démener",),
    "démenassions": ("démener",),
    "démenâtes": ("démener",),
    "démenât": ("démener",),
    "démenée": ("démener",),
    "démenées": ("démener",),
    "démené": ("démener",),
    "démènent": ("démener",),
    "démène": ("démener",),
    "démènera": ("démener",),
    "démèneraient": ("démener",),
    "démènerai": ("démener",),
    "démènerais": ("démener",),
    "démènerait": ("démener",),
    "démèneras": ("démener",),
    "démenèrent": ("démener",),
    "démènerez": ("démener",),
    "démèneriez": ("démener",),
    "démènerions": ("démener",),
    "démènerons": ("démener",),
    "démèneront": ("démener",),
    "démenés": ("démener",),
    "démènes": ("démener",),
    "démenez": ("démener",),
    "démeniez": ("démener",),
    "démenions": ("démener",),
    "démenons": ("démener",),
    "démens": ("démentir",),
    "démentaient": ("démentir",),
    "démentais": ("démentir",),
    "démentait": ("démentir",),
    "démentant": ("démentir",),
    "démentent": ("démentir",),
    "démente": ("démentir",),
    "démentes": ("démentir",),
    "démentez": ("démentir",),
    "démentie": ("démentir",),
    "démenties": ("démentir",),
    "démentiez": ("démentir",),
    "démenti": ("démentir",),
    "démentîmes": ("démentir",),
    "démentions": ("démentir",),
    "démentira": ("démentir",),
    "démentiraient": ("démentir",),
    "démentirai": ("démentir",),
    "démentirais": ("démentir",),
    "démentirait": ("démentir",),
    "démentiras": ("démentir",),
    "démentirent": ("démentir",),
    "démentirez": ("démentir",),
    "démentiriez": ("démentir",),
    "démentirions": ("démentir",),
    "démentirons": ("démentir",),
    "démentiront": ("démentir",),
    "démentis": ("démentir",),
    "démentissent": ("démentir",),
    "démentisses": ("démentir",),
    "démentisse": ("démentir",),
    "démentissiez": ("démentir",),
    "démentissions": ("démentir",),
    "démentîtes": ("démentir",),
    "démentit": ("démentir",),
    "démentît": ("démentir",),
    "démentons": ("démentir",),
    "dément": ("démentir",),
    "démet": ("démettre",),
    "démets": ("démettre",),
    "démettaient": ("démettre",),
    "démettais": ("démettre",),
    "démettait": ("démettre",),
    "démettant": ("démettre",),
    "démettent": ("démettre",),
    "démette": ("démettre",),
    "démettes": ("démettre",),
    "démettez": ("démettre",),
    "démettiez": ("démettre",),
    "démettions": ("démettre",),
    "démettons": ("démettre",),
    "démettra": ("démettre",),
    "démettraient": ("démettre",),
    "démettrai": ("démettre",),
    "démettrais": ("démettre",),
    "démettrait": ("démettre",),
    "démettras": ("démettre",),
    "démettrez": ("démettre",),
    "démettriez": ("démettre",),
    "démettrions": ("démettre",),
    "démettrons": ("démettre",),
    "démettront": ("démettre",),
    "démîmes": ("démettre",),
    "démirent": ("démettre",),
    "démise": ("démettre",),
    "démises": ("démettre",),
    "démis": ("démettre",),
    "démissent": ("démettre",),
    "démisses": ("démettre",),
    "démisse": ("démettre",),
    "démissiez": ("démettre",),
    "démissions": ("démettre",),
    "démîtes": ("démettre",),
    "démit": ("démettre",),
    "démît": ("démettre",),
    "démolie": ("démolir",),
    "démolies": ("démolir",),
    "démoli": ("démolir",),
    "démolîmes": ("démolir",),
    "démolira": ("démolir",),
    "démoliraient": ("démolir",),
    "démolirai": ("démolir",),
    "démolirais": ("démolir",),
    "démolirait": ("démolir",),
    "démoliras": ("démolir",),
    "démolirent": ("démolir",),
    "démolirez": ("démolir",),
    "démoliriez": ("démolir",),
    "démolirions": ("démolir",),
    "démolirons": ("démolir",),
    "démoliront": ("démolir",),
    "démolis": ("démolir",),
    "démolissaient": ("démolir",),
    "démolissais": ("démolir",),
    "démolissait": ("démolir",),
    "démolissant": ("démolir",),
    "démolissent": ("démolir",),
    "démolisse": ("démolir",),
    "démolisses": ("démolir",),
    "démolissez": ("démolir",),
    "démolissiez": ("démolir",),
    "démolissions": ("démolir",),
    "démolissons": ("démolir",),
    "démolîtes": ("démolir",),
    "démolit": ("démolir",),
    "démolît": ("démolir",),
    "démordaient": ("démordre",),
    "démordais": ("démordre",),
    "démordait": ("démordre",),
    "démordant": ("démordre",),
    "démordent": ("démordre",),
    "démorde": ("démordre",),
    "démordes": ("démordre",),
    "démordez": ("démordre",),
    "démordiez": ("démordre",),
    "démordîmes": ("démordre",),
    "démordions": ("démordre",),
    "démordirent": ("démordre",),
    "démordis": ("démordre",),
    "démordissent": ("démordre",),
    "démordisses": ("démordre",),
    "démordisse": ("démordre",),
    "démordissiez": ("démordre",),
    "démordissions": ("démordre",),
    "démordîtes": ("démordre",),
    "démordit": ("démordre",),
    "démordît": ("démordre",),
    "démordons": ("démordre",),
    "démord": ("démordre",),
    "démordra": ("démordre",),
    "démordraient": ("démordre",),
    "démordrai": ("démordre",),
    "démordrais": ("démordre",),
    "démordrait": ("démordre",),
    "démordras": ("démordre",),
    "démordrez": ("démordre",),
    "démordriez": ("démordre",),
    "démordrions": ("démordre",),
    "démordrons": ("démordre",),
    "démordront": ("démordre",),
    "démords": ("démordre",),
    "démordu": ("démordre",),
    "démouchetaient": ("démoucheter",),
    "démouchetai": ("démoucheter",),
    "démouchetais": ("démoucheter",),
    "démouchetait": ("démoucheter",),
    "démoucheta": ("démoucheter",),
    "démouchetâmes": ("démoucheter",),
    "démouchetant": ("démoucheter",),
    "démouchetas": ("démoucheter",),
    "démouchetassent": ("démoucheter",),
    "démouchetasses": ("démoucheter",),
    "démouchetasse": ("démoucheter",),
    "démouchetassiez": ("démoucheter",),
    "démouchetassions": ("démoucheter",),
    "démouchetâtes": ("démoucheter",),
    "démouchetât": ("démoucheter",),
    "démouchetée": ("démoucheter",),
    "démouchetées": ("démoucheter",),
    "démoucheté": ("démoucheter",),
    "démouchetèrent": ("démoucheter",),
    "démouchetés": ("démoucheter",),
    "démouchetez": ("démoucheter",),
    "démouchetiez": ("démoucheter",),
    "démouchetions": ("démoucheter",),
    "démouchetons": ("démoucheter",),
    "démouchettent": ("démoucheter",),
    "démouchette": ("démoucheter",),
    "démouchettera": ("démoucheter",),
    "démouchetteraient": ("démoucheter",),
    "démouchetterai": ("démoucheter",),
    "démouchetterais": ("démoucheter",),
    "démouchetterait": ("démoucheter",),
    "démouchetteras": ("démoucheter",),
    "démouchetterez": ("démoucheter",),
    "démouchetteriez": ("démoucheter",),
    "démouchetterions": ("démoucheter",),
    "démouchetterons": ("démoucheter",),
    "démouchetteront": ("démoucheter",),
    "démouchettes": ("démoucheter",),
    "démultipliaient": ("démultiplier",),
    "démultipliai": ("démultiplier",),
    "démultipliais": ("démultiplier",),
    "démultipliait": ("démultiplier",),
    "démultiplia": ("démultiplier",),
    "démultipliâmes": ("démultiplier",),
    "démultipliant": ("démultiplier",),
    "démultiplias": ("démultiplier",),
    "démultipliassent": ("démultiplier",),
    "démultipliasses": ("démultiplier",),
    "démultipliasse": ("démultiplier",),
    "démultipliassiez": ("démultiplier",),
    "démultipliassions": ("démultiplier",),
    "démultipliâtes": ("démultiplier",),
    "démultipliât": ("démultiplier",),
    "démultipliée": ("démultiplier",),
    "démultipliées": ("démultiplier",),
    "démultiplié": ("démultiplier",),
    "démultiplient": ("démultiplier",),
    "démultiplie": ("démultiplier",),
    "démultipliera": ("démultiplier",),
    "démultiplieraient": ("démultiplier",),
    "démultiplierai": ("démultiplier",),
    "démultiplierais": ("démultiplier",),
    "démultiplierait": ("démultiplier",),
    "démultiplieras": ("démultiplier",),
    "démultiplièrent": ("démultiplier",),
    "démultiplierez": ("démultiplier",),
    "démultiplieriez": ("démultiplier",),
    "démultiplierions": ("démultiplier",),
    "démultiplierons": ("démultiplier",),
    "démultiplieront": ("démultiplier",),
    "démultipliés": ("démultiplier",),
    "démultiplies": ("démultiplier",),
    "démultipliez": ("démultiplier",),
    "démultipliiez": ("démultiplier",),
    "démultipliions": ("démultiplier",),
    "démultiplions": ("démultiplier",),
    "démunie": ("démunir",),
    "démunies": ("démunir",),
    "démuni": ("démunir",),
    "démunîmes": ("démunir",),
    "démunira": ("démunir",),
    "démuniraient": ("démunir",),
    "démunirai": ("démunir",),
    "démunirais": ("démunir",),
    "démunirait": ("démunir",),
    "démuniras": ("démunir",),
    "démunirent": ("démunir",),
    "démunirez": ("démunir",),
    "démuniriez": ("démunir",),
    "démunirions": ("démunir",),
    "démunirons": ("démunir",),
    "démuniront": ("démunir",),
    "démunis": ("démunir",),
    "démunissaient": ("démunir",),
    "démunissais": ("démunir",),
    "démunissait": ("démunir",),
    "démunissant": ("démunir",),
    "démunissent": ("démunir",),
    "démunisse": ("démunir",),
    "démunisses": ("démunir",),
    "démunissez": ("démunir",),
    "démunissiez": ("démunir",),
    "démunissions": ("démunir",),
    "démunissons": ("démunir",),
    "démunîtes": ("démunir",),
    "démunit": ("démunir",),
    "démunît": ("démunir",),
    "démuselaient": ("démuseler",),
    "démuselai": ("démuseler",),
    "démuselais": ("démuseler",),
    "démuselait": ("démuseler",),
    "démusela": ("démuseler",),
    "démuselâmes": ("démuseler",),
    "démuselant": ("démuseler",),
    "démuselas": ("démuseler",),
    "démuselassent": ("démuseler",),
    "démuselasses": ("démuseler",),
    "démuselasse": ("démuseler",),
    "démuselassiez": ("démuseler",),
    "démuselassions": ("démuseler",),
    "démuselâtes": ("démuseler",),
    "démuselât": ("démuseler",),
    "démuselée": ("démuseler",),
    "démuselées": ("démuseler",),
    "démuselé": ("démuseler",),
    "démuselèrent": ("démuseler",),
    "démuselés": ("démuseler",),
    "démuselez": ("démuseler",),
    "démuseliez": ("démuseler",),
    "démuselions": ("démuseler",),
    "démusellent": ("démuseler",),
    "démuselle": ("démuseler",),
    "démusellera": ("démuseler",),
    "démuselleraient": ("démuseler",),
    "démusellerai": ("démuseler",),
    "démusellerais": ("démuseler",),
    "démusellerait": ("démuseler",),
    "démuselleras": ("démuseler",),
    "démusellerez": ("démuseler",),
    "démuselleriez": ("démuseler",),
    "démusellerions": ("démuseler",),
    "démusellerons": ("démuseler",),
    "démuselleront": ("démuseler",),
    "démuselles": ("démuseler",),
    "démuselons": ("démuseler",),
    "démystifiaient": ("démystifier",),
    "démystifiai": ("démystifier",),
    "démystifiais": ("démystifier",),
    "démystifiait": ("démystifier",),
    "démystifia": ("démystifier",),
    "démystifiâmes": ("démystifier",),
    "démystifiant": ("démystifier",),
    "démystifias": ("démystifier",),
    "démystifiassent": ("démystifier",),
    "démystifiasses": ("démystifier",),
    "démystifiasse": ("démystifier",),
    "démystifiassiez": ("démystifier",),
    "démystifiassions": ("démystifier",),
    "démystifiâtes": ("démystifier",),
    "démystifiât": ("démystifier",),
    "démystifiée": ("démystifier",),
    "démystifiées": ("démystifier",),
    "démystifié": ("démystifier",),
    "démystifient": ("démystifier",),
    "démystifie": ("démystifier",),
    "démystifiera": ("démystifier",),
    "démystifieraient": ("démystifier",),
    "démystifierai": ("démystifier",),
    "démystifierais": ("démystifier",),
    "démystifierait": ("démystifier",),
    "démystifieras": ("démystifier",),
    "démystifièrent": ("démystifier",),
    "démystifierez": ("démystifier",),
    "démystifieriez": ("démystifier",),
    "démystifierions": ("démystifier",),
    "démystifierons": ("démystifier",),
    "démystifieront": ("démystifier",),
    "démystifiés": ("démystifier",),
    "démystifies": ("démystifier",),
    "démystifiez": ("démystifier",),
    "démystifiiez": ("démystifier",),
    "démystifiions": ("démystifier",),
    "démystifions": ("démystifier",),
    "démythifiaient": ("démythifier",),
    "démythifiai": ("démythifier",),
    "démythifiais": ("démythifier",),
    "démythifiait": ("démythifier",),
    "démythifia": ("démythifier",),
    "démythifiâmes": ("démythifier",),
    "démythifiant": ("démythifier",),
    "démythifias": ("démythifier",),
    "démythifiassent": ("démythifier",),
    "démythifiasses": ("démythifier",),
    "démythifiasse": ("démythifier",),
    "démythifiassiez": ("démythifier",),
    "démythifiassions": ("démythifier",),
    "démythifiâtes": ("démythifier",),
    "démythifiât": ("démythifier",),
    "démythifiée": ("démythifier",),
    "démythifiées": ("démythifier",),
    "démythifié": ("démythifier",),
    "démythifient": ("démythifier",),
    "démythifie": ("démythifier",),
    "démythifiera": ("démythifier",),
    "démythifieraient": ("démythifier",),
    "démythifierai": ("démythifier",),
    "démythifierais": ("démythifier",),
    "démythifierait": ("démythifier",),
    "démythifieras": ("démythifier",),
    "démythifièrent": ("démythifier",),
    "démythifierez": ("démythifier",),
    "démythifieriez": ("démythifier",),
    "démythifierions": ("démythifier",),
    "démythifierons": ("démythifier",),
    "démythifieront": ("démythifier",),
    "démythifiés": ("démythifier",),
    "démythifies": ("démythifier",),
    "démythifiez": ("démythifier",),
    "démythifiiez": ("démythifier",),
    "démythifiions": ("démythifier",),
    "démythifions": ("démythifier",),
    "dénageaient": ("dénager",),
    "dénageai": ("dénager",),
    "dénageais": ("dénager",),
    "dénageait": ("dénager",),
    "dénagea": ("dénager",),
    "dénageâmes": ("dénager",),
    "dénageant": ("dénager",),
    "dénageas": ("dénager",),
    "dénageassent": ("dénager",),
    "dénageasses": ("dénager",),
    "dénageasse": ("dénager",),
    "dénageassiez": ("dénager",),
    "dénageassions": ("dénager",),
    "dénageâtes": ("dénager",),
    "dénageât": ("dénager",),
    "dénagé": ("dénager",),
    "dénagent": ("dénager",),
    "dénageons": ("dénager",),
    "dénage": ("dénager",),
    "dénagera": ("dénager",),
    "dénageraient": ("dénager",),
    "dénagerai": ("dénager",),
    "dénagerais": ("dénager",),
    "dénagerait": ("dénager",),
    "dénageras": ("dénager",),
    "dénagèrent": ("dénager",),
    "dénagerez": ("dénager",),
    "dénageriez": ("dénager",),
    "dénagerions": ("dénager",),
    "dénagerons": ("dénager",),
    "dénageront": ("dénager",),
    "dénages": ("dénager",),
    "dénagez": ("dénager",),
    "dénagiez": ("dénager",),
    "dénagions": ("dénager",),
    "dénantie": ("dénantir",),
    "dénanties": ("dénantir",),
    "dénanti": ("dénantir",),
    "dénantîmes": ("dénantir",),
    "dénantira": ("dénantir",),
    "dénantiraient": ("dénantir",),
    "dénantirai": ("dénantir",),
    "dénantirais": ("dénantir",),
    "dénantirait": ("dénantir",),
    "dénantiras": ("dénantir",),
    "dénantirent": ("dénantir",),
    "dénantirez": ("dénantir",),
    "dénantiriez": ("dénantir",),
    "dénantirions": ("dénantir",),
    "dénantirons": ("dénantir",),
    "dénantiront": ("dénantir",),
    "dénantis": ("dénantir",),
    "dénantissaient": ("dénantir",),
    "dénantissais": ("dénantir",),
    "dénantissait": ("dénantir",),
    "dénantissant": ("dénantir",),
    "dénantissent": ("dénantir",),
    "dénantisse": ("dénantir",),
    "dénantisses": ("dénantir",),
    "dénantissez": ("dénantir",),
    "dénantissiez": ("dénantir",),
    "dénantissions": ("dénantir",),
    "dénantissons": ("dénantir",),
    "dénantîtes": ("dénantir",),
    "dénantit": ("dénantir",),
    "dénantît": ("dénantir",),
    "dénazifiaient": ("dénazifier",),
    "dénazifiai": ("dénazifier",),
    "dénazifiais": ("dénazifier",),
    "dénazifiait": ("dénazifier",),
    "dénazifia": ("dénazifier",),
    "dénazifiâmes": ("dénazifier",),
    "dénazifiant": ("dénazifier",),
    "dénazifias": ("dénazifier",),
    "dénazifiassent": ("dénazifier",),
    "dénazifiasses": ("dénazifier",),
    "dénazifiasse": ("dénazifier",),
    "dénazifiassiez": ("dénazifier",),
    "dénazifiassions": ("dénazifier",),
    "dénazifiâtes": ("dénazifier",),
    "dénazifiât": ("dénazifier",),
    "dénazifiée": ("dénazifier",),
    "dénazifiées": ("dénazifier",),
    "dénazifié": ("dénazifier",),
    "dénazifient": ("dénazifier",),
    "dénazifie": ("dénazifier",),
    "dénazifiera": ("dénazifier",),
    "dénazifieraient": ("dénazifier",),
    "dénazifierai": ("dénazifier",),
    "dénazifierais": ("dénazifier",),
    "dénazifierait": ("dénazifier",),
    "dénazifieras": ("dénazifier",),
    "dénazifièrent": ("dénazifier",),
    "dénazifierez": ("dénazifier",),
    "dénazifieriez": ("dénazifier",),
    "dénazifierions": ("dénazifier",),
    "dénazifierons": ("dénazifier",),
    "dénazifieront": ("dénazifier",),
    "dénazifiés": ("dénazifier",),
    "dénazifies": ("dénazifier",),
    "dénazifiez": ("dénazifier",),
    "dénazifiiez": ("dénazifier",),
    "dénazifiions": ("dénazifier",),
    "dénazifions": ("dénazifier",),
    "déneigeaient": ("déneiger",),
    "déneigeai": ("déneiger",),
    "déneigeais": ("déneiger",),
    "déneigeait": ("déneiger",),
    "déneigea": ("déneiger",),
    "déneigeâmes": ("déneiger",),
    "déneigeant": ("déneiger",),
    "déneigeas": ("déneiger",),
    "déneigeassent": ("déneiger",),
    "déneigeasses": ("déneiger",),
    "déneigeasse": ("déneiger",),
    "déneigeassiez": ("déneiger",),
    "déneigeassions": ("déneiger",),
    "déneigeâtes": ("déneiger",),
    "déneigeât": ("déneiger",),
    "déneigée": ("déneiger",),
    "déneigées": ("déneiger",),
    "déneigé": ("déneiger",),
    "déneigent": ("déneiger",),
    "déneigeons": ("déneiger",),
    "déneige": ("déneiger",),
    "déneigera": ("déneiger",),
    "déneigeraient": ("déneiger",),
    "déneigerai": ("déneiger",),
    "déneigerais": ("déneiger",),
    "déneigerait": ("déneiger",),
    "déneigeras": ("déneiger",),
    "déneigèrent": ("déneiger",),
    "déneigerez": ("déneiger",),
    "déneigeriez": ("déneiger",),
    "déneigerions": ("déneiger",),
    "déneigerons": ("déneiger",),
    "déneigeront": ("déneiger",),
    "déneigés": ("déneiger",),
    "déneiges": ("déneiger",),
    "déneigez": ("déneiger",),
    "déneigiez": ("déneiger",),
    "déneigions": ("déneiger",),
    "dénickelaient": ("dénickeler",),
    "dénickelai": ("dénickeler",),
    "dénickelais": ("dénickeler",),
    "dénickelait": ("dénickeler",),
    "dénickela": ("dénickeler",),
    "dénickelâmes": ("dénickeler",),
    "dénickelant": ("dénickeler",),
    "dénickelas": ("dénickeler",),
    "dénickelassent": ("dénickeler",),
    "dénickelasses": ("dénickeler",),
    "dénickelasse": ("dénickeler",),
    "dénickelassiez": ("dénickeler",),
    "dénickelassions": ("dénickeler",),
    "dénickelâtes": ("dénickeler",),
    "dénickelât": ("dénickeler",),
    "dénickelée": ("dénickeler",),
    "dénickelées": ("dénickeler",),
    "dénickelé": ("dénickeler",),
    "dénickelèrent": ("dénickeler",),
    "dénickelés": ("dénickeler",),
    "dénickelez": ("dénickeler",),
    "dénickeliez": ("dénickeler",),
    "dénickelions": ("dénickeler",),
    "dénickellent": ("dénickeler",),
    "dénickelle": ("dénickeler",),
    "dénickellera": ("dénickeler",),
    "dénickelleraient": ("dénickeler",),
    "dénickellerai": ("dénickeler",),
    "dénickellerais": ("dénickeler",),
    "dénickellerait": ("dénickeler",),
    "dénickelleras": ("dénickeler",),
    "dénickellerez": ("dénickeler",),
    "dénickelleriez": ("dénickeler",),
    "dénickellerions": ("dénickeler",),
    "dénickellerons": ("dénickeler",),
    "dénickelleront": ("dénickeler",),
    "dénickelles": ("dénickeler",),
    "dénickelons": ("dénickeler",),
    "déniaient": ("dénier",),
    "déniai": ("dénier",),
    "déniais": ("dénier",),
    "déniait": ("dénier",),
    "dénia": ("dénier",),
    "déniâmes": ("dénier",),
    "déniant": ("dénier",),
    "dénias": ("dénier",),
    "déniassent": ("dénier",),
    "déniasses": ("dénier",),
    "déniasse": ("dénier",),
    "déniassiez": ("dénier",),
    "déniassions": ("dénier",),
    "déniâtes": ("dénier",),
    "déniât": ("dénier",),
    "déniée": ("dénier",),
    "déniées": ("dénier",),
    "dénié": ("dénier",),
    "dénient": ("dénier",),
    "dénie": ("dénier",),
    "déniera": ("dénier",),
    "dénieraient": ("dénier",),
    "dénierai": ("dénier",),
    "dénierais": ("dénier",),
    "dénierait": ("dénier",),
    "dénieras": ("dénier",),
    "dénièrent": ("dénier",),
    "dénierez": ("dénier",),
    "dénieriez": ("dénier",),
    "dénierions": ("dénier",),
    "dénierons": ("dénier",),
    "dénieront": ("dénier",),
    "déniés": ("dénier",),
    "dénies": ("dénier",),
    "déniez": ("dénier",),
    "déniiez": ("dénier",),
    "déniions": ("dénier",),
    "dénions": ("dénier",),
    "dénitrifiaient": ("dénitrifier",),
    "dénitrifiai": ("dénitrifier",),
    "dénitrifiais": ("dénitrifier",),
    "dénitrifiait": ("dénitrifier",),
    "dénitrifia": ("dénitrifier",),
    "dénitrifiâmes": ("dénitrifier",),
    "dénitrifiant": ("dénitrifier",),
    "dénitrifias": ("dénitrifier",),
    "dénitrifiassent": ("dénitrifier",),
    "dénitrifiasses": ("dénitrifier",),
    "dénitrifiasse": ("dénitrifier",),
    "dénitrifiassiez": ("dénitrifier",),
    "dénitrifiassions": ("dénitrifier",),
    "dénitrifiâtes": ("dénitrifier",),
    "dénitrifiât": ("dénitrifier",),
    "dénitrifiée": ("dénitrifier",),
    "dénitrifiées": ("dénitrifier",),
    "dénitrifié": ("dénitrifier",),
    "dénitrifient": ("dénitrifier",),
    "dénitrifie": ("dénitrifier",),
    "dénitrifiera": ("dénitrifier",),
    "dénitrifieraient": ("dénitrifier",),
    "dénitrifierai": ("dénitrifier",),
    "dénitrifierais": ("dénitrifier",),
    "dénitrifierait": ("dénitrifier",),
    "dénitrifieras": ("dénitrifier",),
    "dénitrifièrent": ("dénitrifier",),
    "dénitrifierez": ("dénitrifier",),
    "dénitrifieriez": ("dénitrifier",),
    "dénitrifierions": ("dénitrifier",),
    "dénitrifierons": ("dénitrifier",),
    "dénitrifieront": ("dénitrifier",),
    "dénitrifiés": ("dénitrifier",),
    "dénitrifies": ("dénitrifier",),
    "dénitrifiez": ("dénitrifier",),
    "dénitrifiiez": ("dénitrifier",),
    "dénitrifiions": ("dénitrifier",),
    "dénitrifions": ("dénitrifier",),
    "dénitrogénaient": ("dénitrogéner",),
    "dénitrogénai": ("dénitrogéner",),
    "dénitrogénais": ("dénitrogéner",),
    "dénitrogénait": ("dénitrogéner",),
    "dénitrogéna": ("dénitrogéner",),
    "dénitrogénâmes": ("dénitrogéner",),
    "dénitrogénant": ("dénitrogéner",),
    "dénitrogénas": ("dénitrogéner",),
    "dénitrogénassent": ("dénitrogéner",),
    "dénitrogénasses": ("dénitrogéner",),
    "dénitrogénasse": ("dénitrogéner",),
    "dénitrogénassiez": ("dénitrogéner",),
    "dénitrogénassions": ("dénitrogéner",),
    "dénitrogénâtes": ("dénitrogéner",),
    "dénitrogénât": ("dénitrogéner",),
    "dénitrogénée": ("dénitrogéner",),
    "dénitrogénées": ("dénitrogéner",),
    "dénitrogéné": ("dénitrogéner",),
    "dénitrogènent": ("dénitrogéner",),
    "dénitrogène": ("dénitrogéner",),
    "dénitrogénera": ("dénitrogéner",),
    "dénitrogéneraient": ("dénitrogéner",),
    "dénitrogénerai": ("dénitrogéner",),
    "dénitrogénerais": ("dénitrogéner",),
    "dénitrogénerait": ("dénitrogéner",),
    "dénitrogéneras": ("dénitrogéner",),
    "dénitrogénèrent": ("dénitrogéner",),
    "dénitrogénerez": ("dénitrogéner",),
    "dénitrogéneriez": ("dénitrogéner",),
    "dénitrogénerions": ("dénitrogéner",),
    "dénitrogénerons": ("dénitrogéner",),
    "dénitrogéneront": ("dénitrogéner",),
    "dénitrogénés": ("dénitrogéner",),
    "dénitrogènes": ("dénitrogéner",),
    "dénitrogénez": ("dénitrogéner",),
    "dénitrogéniez": ("dénitrogéner",),
    "dénitrogénions": ("dénitrogéner",),
    "dénitrogénons": ("dénitrogéner",),
    "dénivelaient": ("déniveler",),
    "dénivelai": ("déniveler",),
    "dénivelais": ("déniveler",),
    "dénivelait": ("déniveler",),
    "dénivela": ("déniveler",),
    "dénivelâmes": ("déniveler",),
    "dénivelant": ("déniveler",),
    "dénivelas": ("déniveler",),
    "dénivelassent": ("déniveler",),
    "dénivelasses": ("déniveler",),
    "dénivelasse": ("déniveler",),
    "dénivelassiez": ("déniveler",),
    "dénivelassions": ("déniveler",),
    "dénivelâtes": ("déniveler",),
    "dénivelât": ("déniveler",),
    "dénivelée": ("déniveler",),
    "dénivelées": ("déniveler",),
    "dénivelé": ("déniveler",),
    "dénivelèrent": ("déniveler",),
    "dénivelés": ("déniveler",),
    "dénivelez": ("déniveler",),
    "déniveliez": ("déniveler",),
    "dénivelions": ("déniveler",),
    "dénivellent": ("déniveler",),
    "dénivelle": ("déniveler",),
    "dénivellera": ("déniveler",),
    "dénivelleraient": ("déniveler",),
    "dénivellerai": ("déniveler",),
    "dénivellerais": ("déniveler",),
    "dénivellerait": ("déniveler",),
    "dénivelleras": ("déniveler",),
    "dénivellerez": ("déniveler",),
    "dénivelleriez": ("déniveler",),
    "dénivellerions": ("déniveler",),
    "dénivellerons": ("déniveler",),
    "dénivelleront": ("déniveler",),
    "dénivelles": ("déniveler",),
    "dénivelons": ("déniveler",),
    "dénoircie": ("dénoircir",),
    "dénoircies": ("dénoircir",),
    "dénoirci": ("dénoircir",),
    "dénoircîmes": ("dénoircir",),
    "dénoircira": ("dénoircir",),
    "dénoirciraient": ("dénoircir",),
    "dénoircirai": ("dénoircir",),
    "dénoircirais": ("dénoircir",),
    "dénoircirait": ("dénoircir",),
    "dénoirciras": ("dénoircir",),
    "dénoircirent": ("dénoircir",),
    "dénoircirez": ("dénoircir",),
    "dénoirciriez": ("dénoircir",),
    "dénoircirions": ("dénoircir",),
    "dénoircirons": ("dénoircir",),
    "dénoirciront": ("dénoircir",),
    "dénoircis": ("dénoircir",),
    "dénoircissaient": ("dénoircir",),
    "dénoircissais": ("dénoircir",),
    "dénoircissait": ("dénoircir",),
    "dénoircissant": ("dénoircir",),
    "dénoircissent": ("dénoircir",),
    "dénoircisse": ("dénoircir",),
    "dénoircisses": ("dénoircir",),
    "dénoircissez": ("dénoircir",),
    "dénoircissiez": ("dénoircir",),
    "dénoircissions": ("dénoircir",),
    "dénoircissons": ("dénoircir",),
    "dénoircîtes": ("dénoircir",),
    "dénoircit": ("dénoircir",),
    "dénoircît": ("dénoircir",),
    "dénonçaient": ("dénoncer",),
    "dénonçai": ("dénoncer",),
    "dénonçais": ("dénoncer",),
    "dénonçait": ("dénoncer",),
    "dénonça": ("dénoncer",),
    "dénonçâmes": ("dénoncer",),
    "dénonçant": ("dénoncer",),
    "dénonças": ("dénoncer",),
    "dénonçassent": ("dénoncer",),
    "dénonçasses": ("dénoncer",),
    "dénonçasse": ("dénoncer",),
    "dénonçassiez": ("dénoncer",),
    "dénonçassions": ("dénoncer",),
    "dénonçâtes": ("dénoncer",),
    "dénonçât": ("dénoncer",),
    "dénoncée": ("dénoncer",),
    "dénoncées": ("dénoncer",),
    "dénoncé": ("dénoncer",),
    "dénoncent": ("dénoncer",),
    "dénonce": ("dénoncer",),
    "dénoncera": ("dénoncer",),
    "dénonceraient": ("dénoncer",),
    "dénoncerai": ("dénoncer",),
    "dénoncerais": ("dénoncer",),
    "dénoncerait": ("dénoncer",),
    "dénonceras": ("dénoncer",),
    "dénoncèrent": ("dénoncer",),
    "dénoncerez": ("dénoncer",),
    "dénonceriez": ("dénoncer",),
    "dénoncerions": ("dénoncer",),
    "dénoncerons": ("dénoncer",),
    "dénonceront": ("dénoncer",),
    "dénoncés": ("dénoncer",),
    "dénonces": ("dénoncer",),
    "dénoncez": ("dénoncer",),
    "dénonciez": ("dénoncer",),
    "dénoncions": ("dénoncer",),
    "dénonçons": ("dénoncer",),
    "dénoient": ("dénoyer",),
    "dénoie": ("dénoyer",),
    "dénoiera": ("dénoyer",),
    "dénoieraient": ("dénoyer",),
    "dénoierai": ("dénoyer",),
    "dénoierais": ("dénoyer",),
    "dénoierait": ("dénoyer",),
    "dénoieras": ("dénoyer",),
    "dénoierez": ("dénoyer",),
    "dénoieriez": ("dénoyer",),
    "dénoierions": ("dénoyer",),
    "dénoierons": ("dénoyer",),
    "dénoieront": ("dénoyer",),
    "dénoies": ("dénoyer",),
    "dénoyaient": ("dénoyer",),
    "dénoyai": ("dénoyer",),
    "dénoyais": ("dénoyer",),
    "dénoyait": ("dénoyer",),
    "dénoya": ("dénoyer",),
    "dénoyâmes": ("dénoyer",),
    "dénoyant": ("dénoyer",),
    "dénoyas": ("dénoyer",),
    "dénoyassent": ("dénoyer",),
    "dénoyasses": ("dénoyer",),
    "dénoyasse": ("dénoyer",),
    "dénoyassiez": ("dénoyer",),
    "dénoyassions": ("dénoyer",),
    "dénoyâtes": ("dénoyer",),
    "dénoyât": ("dénoyer",),
    "dénoyée": ("dénoyer",),
    "dénoyées": ("dénoyer",),
    "dénoyé": ("dénoyer",),
    "dénoyèrent": ("dénoyer",),
    "dénoyés": ("dénoyer",),
    "dénoyez": ("dénoyer",),
    "dénoyiez": ("dénoyer",),
    "dénoyions": ("dénoyer",),
    "dénoyons": ("dénoyer",),
    "densifiaient": ("densifier",),
    "densifiai": ("densifier",),
    "densifiais": ("densifier",),
    "densifiait": ("densifier",),
    "densifia": ("densifier",),
    "densifiâmes": ("densifier",),
    "densifiant": ("densifier",),
    "densifias": ("densifier",),
    "densifiassent": ("densifier",),
    "densifiasses": ("densifier",),
    "densifiasse": ("densifier",),
    "densifiassiez": ("densifier",),
    "densifiassions": ("densifier",),
    "densifiâtes": ("densifier",),
    "densifiât": ("densifier",),
    "densifiée": ("densifier",),
    "densifiées": ("densifier",),
    "densifié": ("densifier",),
    "densifient": ("densifier",),
    "densifie": ("densifier",),
    "densifiera": ("densifier",),
    "densifieraient": ("densifier",),
    "densifierai": ("densifier",),
    "densifierais": ("densifier",),
    "densifierait": ("densifier",),
    "densifieras": ("densifier",),
    "densifièrent": ("densifier",),
    "densifierez": ("densifier",),
    "densifieriez": ("densifier",),
    "densifierions": ("densifier",),
    "densifierons": ("densifier",),
    "densifieront": ("densifier",),
    "densifiés": ("densifier",),
    "densifies": ("densifier",),
    "densifiez": ("densifier",),
    "densifiiez": ("densifier",),
    "densifiions": ("densifier",),
    "densifions": ("densifier",),
    "dentelaient": ("denteler",),
    "dentelai": ("denteler",),
    "dentelais": ("denteler",),
    "dentelait": ("denteler",),
    "dentela": ("denteler",),
    "dentelâmes": ("denteler",),
    "dentelant": ("denteler",),
    "dentelas": ("denteler",),
    "dentelassent": ("denteler",),
    "dentelasses": ("denteler",),
    "dentelasse": ("denteler",),
    "dentelassiez": ("denteler",),
    "dentelassions": ("denteler",),
    "dentelâtes": ("denteler",),
    "dentelât": ("denteler",),
    "dentelée": ("denteler",),
    "dentelées": ("denteler",),
    "dentelé": ("denteler",),
    "dentelèrent": ("denteler",),
    "dentelés": ("denteler",),
    "dentelez": ("denteler",),
    "denteliez": ("denteler",),
    "dentelions": ("denteler",),
    "dentellent": ("denteler",),
    "dentelle": ("denteler",),
    "dentellera": ("denteler",),
    "dentelleraient": ("denteler",),
    "dentellerai": ("denteler",),
    "dentellerais": ("denteler",),
    "dentellerait": ("denteler",),
    "dentelleras": ("denteler",),
    "dentellerez": ("denteler",),
    "dentelleriez": ("denteler",),
    "dentellerions": ("denteler",),
    "dentellerons": ("denteler",),
    "dentelleront": ("denteler",),
    "dentelles": ("denteler",),
    "dentelons": ("denteler",),
    "dépailletaient": ("dépailleter",),
    "dépailletai": ("dépailleter",),
    "dépailletais": ("dépailleter",),
    "dépailletait": ("dépailleter",),
    "dépailleta": ("dépailleter",),
    "dépailletâmes": ("dépailleter",),
    "dépailletant": ("dépailleter",),
    "dépailletas": ("dépailleter",),
    "dépailletassent": ("dépailleter",),
    "dépailletasses": ("dépailleter",),
    "dépailletasse": ("dépailleter",),
    "dépailletassiez": ("dépailleter",),
    "dépailletassions": ("dépailleter",),
    "dépailletâtes": ("dépailleter",),
    "dépailletât": ("dépailleter",),
    "dépailletée": ("dépailleter",),
    "dépailletées": ("dépailleter",),
    "dépailleté": ("dépailleter",),
    "dépailletèrent": ("dépailleter",),
    "dépailletés": ("dépailleter",),
    "dépailletez": ("dépailleter",),
    "dépailletiez": ("dépailleter",),
    "dépailletions": ("dépailleter",),
    "dépailletons": ("dépailleter",),
    "dépaillettent": ("dépailleter",),
    "dépaillette": ("dépailleter",),
    "dépaillettera": ("dépailleter",),
    "dépailletteraient": ("dépailleter",),
    "dépailletterai": ("dépailleter",),
    "dépailletterais": ("dépailleter",),
    "dépailletterait": ("dépailleter",),
    "dépailletteras": ("dépailleter",),
    "dépailletterez": ("dépailleter",),
    "dépailletteriez": ("dépailleter",),
    "dépailletterions": ("dépailleter",),
    "dépailletterons": ("dépailleter",),
    "dépailletteront": ("dépailleter",),
    "dépaillettes": ("dépailleter",),
    "dépaisselaient": ("dépaisseler",),
    "dépaisselai": ("dépaisseler",),
    "dépaisselais": ("dépaisseler",),
    "dépaisselait": ("dépaisseler",),
    "dépaissela": ("dépaisseler",),
    "dépaisselâmes": ("dépaisseler",),
    "dépaisselant": ("dépaisseler",),
    "dépaisselas": ("dépaisseler",),
    "dépaisselassent": ("dépaisseler",),
    "dépaisselasses": ("dépaisseler",),
    "dépaisselasse": ("dépaisseler",),
    "dépaisselassiez": ("dépaisseler",),
    "dépaisselassions": ("dépaisseler",),
    "dépaisselâtes": ("dépaisseler",),
    "dépaisselât": ("dépaisseler",),
    "dépaisselée": ("dépaisseler",),
    "dépaisselées": ("dépaisseler",),
    "dépaisselé": ("dépaisseler",),
    "dépaisselèrent": ("dépaisseler",),
    "dépaisselés": ("dépaisseler",),
    "dépaisselez": ("dépaisseler",),
    "dépaisseliez": ("dépaisseler",),
    "dépaisselions": ("dépaisseler",),
    "dépaissellent": ("dépaisseler",),
    "dépaisselle": ("dépaisseler",),
    "dépaissellera": ("dépaisseler",),
    "dépaisselleraient": ("dépaisseler",),
    "dépaissellerai": ("dépaisseler",),
    "dépaissellerais": ("dépaisseler",),
    "dépaissellerait": ("dépaisseler",),
    "dépaisselleras": ("dépaisseler",),
    "dépaissellerez": ("dépaisseler",),
    "dépaisselleriez": ("dépaisseler",),
    "dépaissellerions": ("dépaisseler",),
    "dépaissellerons": ("dépaisseler",),
    "dépaisselleront": ("dépaisseler",),
    "dépaisselles": ("dépaisseler",),
    "dépaisselons": ("dépaisseler",),
    "dépâmaient": ("dépâmer",),
    "dépâmai": ("dépâmer",),
    "dépâmais": ("dépâmer",),
    "dépâmait": ("dépâmer",),
    "dépâma": ("dépâmer",),
    "dépâmâmes": ("dépâmer",),
    "dépâmant": ("dépâmer",),
    "dépâmas": ("dépâmer",),
    "dépâmassent": ("dépâmer",),
    "dépâmasses": ("dépâmer",),
    "dépâmasse": ("dépâmer",),
    "dépâmassiez": ("dépâmer",),
    "dépâmassions": ("dépâmer",),
    "dépâmâtes": ("dépâmer",),
    "dépâmât": ("dépâmer",),
    "dépâmée": ("dépâmer",),
    "dépâmées": ("dépâmer",),
    "dépâmé": ("dépâmer",),
    "dépâment": ("dépâmer",),
    "dépâme": ("dépâmer",),
    "dépâmera": ("dépâmer",),
    "dépâmeraient": ("dépâmer",),
    "dépâmerai": ("dépâmer",),
    "dépâmerais": ("dépâmer",),
    "dépâmerait": ("dépâmer",),
    "dépâmeras": ("dépâmer",),
    "dépâmèrent": ("dépâmer",),
    "dépâmerez": ("dépâmer",),
    "dépâmeriez": ("dépâmer",),
    "dépâmerions": ("dépâmer",),
    "dépâmerons": ("dépâmer",),
    "dépâmeront": ("dépâmer",),
    "dépâmés": ("dépâmer",),
    "dépâmes": ("dépâmer",),
    "dépâmez": ("dépâmer",),
    "dépâmiez": ("dépâmer",),
    "dépâmions": ("dépâmer",),
    "dépâmons": ("dépâmer",),
    "dépaquetaient": ("dépaqueter",),
    "dépaquetai": ("dépaqueter",),
    "dépaquetais": ("dépaqueter",),
    "dépaquetait": ("dépaqueter",),
    "dépaqueta": ("dépaqueter",),
    "dépaquetâmes": ("dépaqueter",),
    "dépaquetant": ("dépaqueter",),
    "dépaquetas": ("dépaqueter",),
    "dépaquetassent": ("dépaqueter",),
    "dépaquetasses": ("dépaqueter",),
    "dépaquetasse": ("dépaqueter",),
    "dépaquetassiez": ("dépaqueter",),
    "dépaquetassions": ("dépaqueter",),
    "dépaquetâtes": ("dépaqueter",),
    "dépaquetât": ("dépaqueter",),
    "dépaquetée": ("dépaqueter",),
    "dépaquetées": ("dépaqueter",),
    "dépaqueté": ("dépaqueter",),
    "dépaquetèrent": ("dépaqueter",),
    "dépaquetés": ("dépaqueter",),
    "dépaquetez": ("dépaqueter",),
    "dépaquetiez": ("dépaqueter",),
    "dépaquetions": ("dépaqueter",),
    "dépaquetons": ("dépaqueter",),
    "dépaquettent": ("dépaqueter",),
    "dépaquette": ("dépaqueter",),
    "dépaquettera": ("dépaqueter",),
    "dépaquetteraient": ("dépaqueter",),
    "dépaquetterai": ("dépaqueter",),
    "dépaquetterais": ("dépaqueter",),
    "dépaquetterait": ("dépaqueter",),
    "dépaquetteras": ("dépaqueter",),
    "dépaquetterez": ("dépaqueter",),
    "dépaquetteriez": ("dépaqueter",),
    "dépaquetterions": ("dépaqueter",),
    "dépaquetterons": ("dépaqueter",),
    "dépaquetteront": ("dépaqueter",),
    "dépaquettes": ("dépaqueter",),
    "déparageaient": ("déparager",),
    "déparageai": ("déparager",),
    "déparageais": ("déparager",),
    "déparageait": ("déparager",),
    "déparagea": ("déparager",),
    "déparageâmes": ("déparager",),
    "déparageant": ("déparager",),
    "déparageas": ("déparager",),
    "déparageassent": ("déparager",),
    "déparageasses": ("déparager",),
    "déparageasse": ("déparager",),
    "déparageassiez": ("déparager",),
    "déparageassions": ("déparager",),
    "déparageâtes": ("déparager",),
    "déparageât": ("déparager",),
    "déparagée": ("déparager",),
    "déparagées": ("déparager",),
    "déparagé": ("déparager",),
    "déparagent": ("déparager",),
    "déparageons": ("déparager",),
    "déparage": ("déparager",),
    "déparagera": ("déparager",),
    "déparageraient": ("déparager",),
    "déparagerai": ("déparager",),
    "déparagerais": ("déparager",),
    "déparagerait": ("déparager",),
    "déparageras": ("déparager",),
    "déparagèrent": ("déparager",),
    "déparagerez": ("déparager",),
    "déparageriez": ("déparager",),
    "déparagerions": ("déparager",),
    "déparagerons": ("déparager",),
    "déparageront": ("déparager",),
    "déparagés": ("déparager",),
    "déparages": ("déparager",),
    "déparagez": ("déparager",),
    "déparagiez": ("déparager",),
    "déparagions": ("déparager",),
    "dépariaient": ("déparier",),
    "dépariai": ("déparier",),
    "dépariais": ("déparier",),
    "dépariait": ("déparier",),
    "déparia": ("déparier",),
    "dépariâmes": ("déparier",),
    "dépariant": ("déparier",),
    "déparias": ("déparier",),
    "dépariassent": ("déparier",),
    "dépariasses": ("déparier",),
    "dépariasse": ("déparier",),
    "dépariassiez": ("déparier",),
    "dépariassions": ("déparier",),
    "dépariâtes": ("déparier",),
    "dépariât": ("déparier",),
    "dépariée": ("déparier",),
    "dépariées": ("déparier",),
    "déparié": ("déparier",),
    "déparient": ("déparier",),
    "déparie": ("déparier",),
    "dépariera": ("déparier",),
    "déparieraient": ("déparier",),
    "déparierai": ("déparier",),
    "déparierais": ("déparier",),
    "déparierait": ("déparier",),
    "déparieras": ("déparier",),
    "déparièrent": ("déparier",),
    "déparierez": ("déparier",),
    "déparieriez": ("déparier",),
    "déparierions": ("déparier",),
    "déparierons": ("déparier",),
    "déparieront": ("déparier",),
    "dépariés": ("déparier",),
    "déparies": ("déparier",),
    "dépariez": ("déparier",),
    "dépariiez": ("déparier",),
    "dépariions": ("déparier",),
    "déparions": ("déparier",),
    "déparquetaient": ("déparqueter",),
    "déparquetai": ("déparqueter",),
    "déparquetais": ("déparqueter",),
    "déparquetait": ("déparqueter",),
    "déparqueta": ("déparqueter",),
    "déparquetâmes": ("déparqueter",),
    "déparquetant": ("déparqueter",),
    "déparquetas": ("déparqueter",),
    "déparquetassent": ("déparqueter",),
    "déparquetasses": ("déparqueter",),
    "déparquetasse": ("déparqueter",),
    "déparquetassiez": ("déparqueter",),
    "déparquetassions": ("déparqueter",),
    "déparquetâtes": ("déparqueter",),
    "déparquetât": ("déparqueter",),
    "déparquetée": ("déparqueter",),
    "déparquetées": ("déparqueter",),
    "déparqueté": ("déparqueter",),
    "déparquetèrent": ("déparqueter",),
    "déparquetés": ("déparqueter",),
    "déparquetez": ("déparqueter",),
    "déparquetiez": ("déparqueter",),
    "déparquetions": ("déparqueter",),
    "déparquetons": ("déparqueter",),
    "déparquettent": ("déparqueter",),
    "déparquette": ("déparqueter",),
    "déparquettera": ("déparqueter",),
    "déparquetteraient": ("déparqueter",),
    "déparquetterai": ("déparqueter",),
    "déparquetterais": ("déparqueter",),
    "déparquetterait": ("déparqueter",),
    "déparquetteras": ("déparqueter",),
    "déparquetterez": ("déparqueter",),
    "déparquetteriez": ("déparqueter",),
    "déparquetterions": ("déparqueter",),
    "déparquetterons": ("déparqueter",),
    "déparquetteront": ("déparqueter",),
    "déparquettes": ("déparqueter",),
    "départageaient": ("départager",),
    "départageai": ("départager",),
    "départageais": ("départager",),
    "départageait": ("départager",),
    "départagea": ("départager",),
    "départageâmes": ("départager",),
    "départageant": ("départager",),
    "départageas": ("départager",),
    "départageassent": ("départager",),
    "départageasses": ("départager",),
    "départageasse": ("départager",),
    "départageassiez": ("départager",),
    "départageassions": ("départager",),
    "départageâtes": ("départager",),
    "départageât": ("départager",),
    "départagée": ("départager",),
    "départagées": ("départager",),
    "départagé": ("départager",),
    "départagent": ("départager",),
    "départageons": ("départager",),
    "départage": ("départager",),
    "départagera": ("départager",),
    "départageraient": ("départager",),
    "départagerai": ("départager",),
    "départagerais": ("départager",),
    "départagerait": ("départager",),
    "départageras": ("départager",),
    "départagèrent": ("départager",),
    "départagerez": ("départager",),
    "départageriez": ("départager",),
    "départagerions": ("départager",),
    "départagerons": ("départager",),
    "départageront": ("départager",),
    "départagés": ("départager",),
    "départages": ("départager",),
    "départagez": ("départager",),
    "départagiez": ("départager",),
    "départagions": ("départager",),
    "dépars": ("départir",),
    "départaient": ("départir",),
    "départais": ("départir",),
    "départait": ("départir",),
    "départant": ("départir",),
    "départent": ("départir",),
    "départe": ("départir",),
    "départes": ("départir",),
    "départez": ("départir",),
    "départie": ("départir",),
    "départies": ("départir",),
    "départiez": ("départir",),
    "départi": ("départir",),
    "départîmes": ("départir",),
    "départions": ("départir",),
    "départira": ("départir",),
    "départiraient": ("départir",),
    "départirai": ("départir",),
    "départirais": ("départir",),
    "départirait": ("départir",),
    "départiras": ("départir",),
    "départirent": ("départir",),
    "départirez": ("départir",),
    "départiriez": ("départir",),
    "départirions": ("départir",),
    "départirons": ("départir",),
    "départiront": ("départir",),
    "départis": ("départir",),
    "départissent": ("départir",),
    "départisses": ("départir",),
    "départisse": ("départir",),
    "départissiez": ("départir",),
    "départissions": ("départir",),
    "départîtes": ("départir",),
    "départit": ("départir",),
    "départît": ("départir",),
    "départons": ("départir",),
    "départ": ("départir",),
    "dépassaient": ("dépasser",),
    "dépassai": ("dépasser",),
    "dépassais": ("dépasser",),
    "dépassait": ("dépasser",),
    "dépassa": ("dépasser",),
    "dépassâmes": ("dépasser",),
    "dépassant": ("dépasser",),
    "dépassas": ("dépasser",),
    "dépassassent": ("dépasser",),
    "dépassasses": ("dépasser",),
    "dépassasse": ("dépasser",),
    "dépassassiez": ("dépasser",),
    "dépassassions": ("dépasser",),
    "dépassâtes": ("dépasser",),
    "dépassât": ("dépasser",),
    "dépassée": ("dépasser",),
    "dépassées": ("dépasser",),
    "dépassé": ("dépasser",),
    "dépassent": ("dépasser",),
    "dépasse": ("dépasser",),
    "dépassera": ("dépasser",),
    "dépasseraient": ("dépasser",),
    "dépasserai": ("dépasser",),
    "dépasserais": ("dépasser",),
    "dépasserait": ("dépasser",),
    "dépasseras": ("dépasser",),
    "dépassèrent": ("dépasser",),
    "dépasserez": ("dépasser",),
    "dépasseriez": ("dépasser",),
    "dépasserions": ("dépasser",),
    "dépasserons": ("dépasser",),
    "dépasseront": ("dépasser",),
    "dépassés": ("dépasser",),
    "dépasses": ("dépasser",),
    "dépassez": ("dépasser",),
    "dépassiez": ("dépasser",),
    "dépassions": ("dépasser",),
    "dépassons": ("dépasser",),
    "dépatriaient": ("dépatrier",),
    "dépatriai": ("dépatrier",),
    "dépatriais": ("dépatrier",),
    "dépatriait": ("dépatrier",),
    "dépatria": ("dépatrier",),
    "dépatriâmes": ("dépatrier",),
    "dépatriant": ("dépatrier",),
    "dépatrias": ("dépatrier",),
    "dépatriassent": ("dépatrier",),
    "dépatriasses": ("dépatrier",),
    "dépatriasse": ("dépatrier",),
    "dépatriassiez": ("dépatrier",),
    "dépatriassions": ("dépatrier",),
    "dépatriâtes": ("dépatrier",),
    "dépatriât": ("dépatrier",),
    "dépatriée": ("dépatrier",),
    "dépatriées": ("dépatrier",),
    "dépatrié": ("dépatrier",),
    "dépatrient": ("dépatrier",),
    "dépatrie": ("dépatrier",),
    "dépatriera": ("dépatrier",),
    "dépatrieraient": ("dépatrier",),
    "dépatrierai": ("dépatrier",),
    "dépatrierais": ("dépatrier",),
    "dépatrierait": ("dépatrier",),
    "dépatrieras": ("dépatrier",),
    "dépatrièrent": ("dépatrier",),
    "dépatrierez": ("dépatrier",),
    "dépatrieriez": ("dépatrier",),
    "dépatrierions": ("dépatrier",),
    "dépatrierons": ("dépatrier",),
    "dépatrieront": ("dépatrier",),
    "dépatriés": ("dépatrier",),
    "dépatries": ("dépatrier",),
    "dépatriez": ("dépatrier",),
    "dépatriiez": ("dépatrier",),
    "dépatriions": ("dépatrier",),
    "dépatrions": ("dépatrier",),
    "dépeçaient": ("dépecer",),
    "dépeçai": ("dépecer",),
    "dépeçais": ("dépecer",),
    "dépeçait": ("dépecer",),
    "dépeça": ("dépecer",),
    "dépeçâmes": ("dépecer",),
    "dépeçant": ("dépecer",),
    "dépeças": ("dépecer",),
    "dépeçassent": ("dépecer",),
    "dépeçasses": ("dépecer",),
    "dépeçasse": ("dépecer",),
    "dépeçassiez": ("dépecer",),
    "dépeçassions": ("dépecer",),
    "dépeçâtes": ("dépecer",),
    "dépeçât": ("dépecer",),
    "dépecée": ("dépecer",),
    "dépecées": ("dépecer",),
    "dépecé": ("dépecer",),
    "dépècent": ("dépecer",),
    "dépèce": ("dépecer",),
    "dépècera": ("dépecer",),
    "dépèceraient": ("dépecer",),
    "dépècerai": ("dépecer",),
    "dépècerais": ("dépecer",),
    "dépècerait": ("dépecer",),
    "dépèceras": ("dépecer",),
    "dépecèrent": ("dépecer",),
    "dépècerez": ("dépecer",),
    "dépèceriez": ("dépecer",),
    "dépècerions": ("dépecer",),
    "dépècerons": ("dépecer",),
    "dépèceront": ("dépecer",),
    "dépecés": ("dépecer",),
    "dépèces": ("dépecer",),
    "dépecez": ("dépecer",),
    "dépeciez": ("dépecer",),
    "dépecions": ("dépecer",),
    "dépeçons": ("dépecer",),
    "dépeignaient": ("dépeindre",),
    "dépeignais": ("dépeindre",),
    "dépeignait": ("dépeindre",),
    "dépeignant": ("dépeindre",),
    "dépeignent": ("dépeindre",),
    "dépeigne": ("dépeindre",),
    "dépeignes": ("dépeindre",),
    "dépeignez": ("dépeindre",),
    "dépeigniez": ("dépeindre",),
    "dépeignîmes": ("dépeindre",),
    "dépeignions": ("dépeindre",),
    "dépeignirent": ("dépeindre",),
    "dépeignis": ("dépeindre",),
    "dépeignissent": ("dépeindre",),
    "dépeignisses": ("dépeindre",),
    "dépeignisse": ("dépeindre",),
    "dépeignissiez": ("dépeindre",),
    "dépeignissions": ("dépeindre",),
    "dépeignîtes": ("dépeindre",),
    "dépeignit": ("dépeindre",),
    "dépeignît": ("dépeindre",),
    "dépeignons": ("dépeindre",),
    "dépeindra": ("dépeindre",),
    "dépeindraient": ("dépeindre",),
    "dépeindrai": ("dépeindre",),
    "dépeindrais": ("dépeindre",),
    "dépeindrait": ("dépeindre",),
    "dépeindras": ("dépeindre",),
    "dépeindrez": ("dépeindre",),
    "dépeindriez": ("dépeindre",),
    "dépeindrions": ("dépeindre",),
    "dépeindrons": ("dépeindre",),
    "dépeindront": ("dépeindre",),
    "dépeins": ("dépeindre",),
    "dépeinte": ("dépeindre",),
    "dépeintes": ("dépeindre",),
    "dépeint": ("dépeindre",),
    "dépeints": ("dépeindre",),
    "dépendaient": ("dépendre",),
    "dépendais": ("dépendre",),
    "dépendait": ("dépendre",),
    "dépendant": ("dépendre",),
    "dépendent": ("dépendre",),
    "dépende": ("dépendre",),
    "dépendes": ("dépendre",),
    "dépendez": ("dépendre",),
    "dépendiez": ("dépendre",),
    "dépendîmes": ("dépendre",),
    "dépendions": ("dépendre",),
    "dépendirent": ("dépendre",),
    "dépendis": ("dépendre",),
    "dépendissent": ("dépendre",),
    "dépendisses": ("dépendre",),
    "dépendisse": ("dépendre",),
    "dépendissiez": ("dépendre",),
    "dépendissions": ("dépendre",),
    "dépendîtes": ("dépendre",),
    "dépendit": ("dépendre",),
    "dépendît": ("dépendre",),
    "dépendons": ("dépendre",),
    "dépend": ("dépendre",),
    "dépendra": ("dépendre",),
    "dépendraient": ("dépendre",),
    "dépendrai": ("dépendre",),
    "dépendrais": ("dépendre",),
    "dépendrait": ("dépendre",),
    "dépendras": ("dépendre",),
    "dépendrez": ("dépendre",),
    "dépendriez": ("dépendre",),
    "dépendrions": ("dépendre",),
    "dépendrons": ("dépendre",),
    "dépendront": ("dépendre",),
    "dépends": ("dépendre",),
    "dépendue": ("dépendre",),
    "dépendues": ("dépendre",),
    "dépendu": ("dépendre",),
    "dépendus": ("dépendre",),
    "déperdaient": ("déperdre",),
    "déperdais": ("déperdre",),
    "déperdait": ("déperdre",),
    "déperdant": ("déperdre",),
    "déperdent": ("déperdre",),
    "déperde": ("déperdre",),
    "déperdes": ("déperdre",),
    "déperdez": ("déperdre",),
    "déperdiez": ("déperdre",),
    "déperdîmes": ("déperdre",),
    "déperdions": ("déperdre",),
    "déperdirent": ("déperdre",),
    "déperdis": ("déperdre",),
    "déperdissent": ("déperdre",),
    "déperdisses": ("déperdre",),
    "déperdisse": ("déperdre",),
    "déperdissiez": ("déperdre",),
    "déperdissions": ("déperdre",),
    "déperdîtes": ("déperdre",),
    "déperdit": ("déperdre",),
    "déperdît": ("déperdre",),
    "déperdons": ("déperdre",),
    "déperd": ("déperdre",),
    "déperdra": ("déperdre",),
    "déperdraient": ("déperdre",),
    "déperdrai": ("déperdre",),
    "déperdrais": ("déperdre",),
    "déperdrait": ("déperdre",),
    "déperdras": ("déperdre",),
    "déperdrez": ("déperdre",),
    "déperdriez": ("déperdre",),
    "déperdrions": ("déperdre",),
    "déperdrons": ("déperdre",),
    "déperdront": ("déperdre",),
    "déperds": ("déperdre",),
    "déperdue": ("déperdre",),
    "déperdues": ("déperdre",),
    "déperdu": ("déperdre",),
    "déperdus": ("déperdre",),
    "dépéri": ("dépérir",),
    "dépérîmes": ("dépérir",),
    "dépérira": ("dépérir",),
    "dépériraient": ("dépérir",),
    "dépérirai": ("dépérir",),
    "dépérirais": ("dépérir",),
    "dépérirait": ("dépérir",),
    "dépériras": ("dépérir",),
    "dépérirent": ("dépérir",),
    "dépérirez": ("dépérir",),
    "dépéririez": ("dépérir",),
    "dépéririons": ("dépérir",),
    "dépérirons": ("dépérir",),
    "dépériront": ("dépérir",),
    "dépéris": ("dépérir",),
    "dépérissaient": ("dépérir",),
    "dépérissais": ("dépérir",),
    "dépérissait": ("dépérir",),
    "dépérissant": ("dépérir",),
    "dépérissent": ("dépérir",),
    "dépérisse": ("dépérir",),
    "dépérisses": ("dépérir",),
    "dépérissez": ("dépérir",),
    "dépérissiez": ("dépérir",),
    "dépérissions": ("dépérir",),
    "dépérissons": ("dépérir",),
    "dépérîtes": ("dépérir",),
    "dépérit": ("dépérir",),
    "dépérît": ("dépérir",),
    "dépétrifiaient": ("dépétrifier",),
    "dépétrifiai": ("dépétrifier",),
    "dépétrifiais": ("dépétrifier",),
    "dépétrifiait": ("dépétrifier",),
    "dépétrifia": ("dépétrifier",),
    "dépétrifiâmes": ("dépétrifier",),
    "dépétrifiant": ("dépétrifier",),
    "dépétrifias": ("dépétrifier",),
    "dépétrifiassent": ("dépétrifier",),
    "dépétrifiasses": ("dépétrifier",),
    "dépétrifiasse": ("dépétrifier",),
    "dépétrifiassiez": ("dépétrifier",),
    "dépétrifiassions": ("dépétrifier",),
    "dépétrifiâtes": ("dépétrifier",),
    "dépétrifiât": ("dépétrifier",),
    "dépétrifiée": ("dépétrifier",),
    "dépétrifiées": ("dépétrifier",),
    "dépétrifié": ("dépétrifier",),
    "dépétrifient": ("dépétrifier",),
    "dépétrifie": ("dépétrifier",),
    "dépétrifiera": ("dépétrifier",),
    "dépétrifieraient": ("dépétrifier",),
    "dépétrifierai": ("dépétrifier",),
    "dépétrifierais": ("dépétrifier",),
    "dépétrifierait": ("dépétrifier",),
    "dépétrifieras": ("dépétrifier",),
    "dépétrifièrent": ("dépétrifier",),
    "dépétrifierez": ("dépétrifier",),
    "dépétrifieriez": ("dépétrifier",),
    "dépétrifierions": ("dépétrifier",),
    "dépétrifierons": ("dépétrifier",),
    "dépétrifieront": ("dépétrifier",),
    "dépétrifiés": ("dépétrifier",),
    "dépétrifies": ("dépétrifier",),
    "dépétrifiez": ("dépétrifier",),
    "dépétrifiiez": ("dépétrifier",),
    "dépétrifiions": ("dépétrifier",),
    "dépétrifions": ("dépétrifier",),
    "dépiéçaient": ("dépiécer",),
    "dépiéçai": ("dépiécer",),
    "dépiéçais": ("dépiécer",),
    "dépiéçait": ("dépiécer",),
    "dépiéça": ("dépiécer",),
    "dépiéçâmes": ("dépiécer",),
    "dépiéçant": ("dépiécer",),
    "dépiéças": ("dépiécer",),
    "dépiéçassent": ("dépiécer",),
    "dépiéçasses": ("dépiécer",),
    "dépiéçasse": ("dépiécer",),
    "dépiéçassiez": ("dépiécer",),
    "dépiéçassions": ("dépiécer",),
    "dépiéçâtes": ("dépiécer",),
    "dépiéçât": ("dépiécer",),
    "dépiécée": ("dépiécer",),
    "dépiécées": ("dépiécer",),
    "dépiécé": ("dépiécer",),
    "dépiècent": ("dépiécer",),
    "dépièce": ("dépiécer",),
    "dépiécera": ("dépiécer",),
    "dépiéceraient": ("dépiécer",),
    "dépiécerai": ("dépiécer",),
    "dépiécerais": ("dépiécer",),
    "dépiécerait": ("dépiécer",),
    "dépiéceras": ("dépiécer",),
    "dépiécèrent": ("dépiécer",),
    "dépiécerez": ("dépiécer",),
    "dépiéceriez": ("dépiécer",),
    "dépiécerions": ("dépiécer",),
    "dépiécerons": ("dépiécer",),
    "dépiéceront": ("dépiécer",),
    "dépiécés": ("dépiécer",),
    "dépièces": ("dépiécer",),
    "dépiécez": ("dépiécer",),
    "dépiéciez": ("dépiécer",),
    "dépiécions": ("dépiécer",),
    "dépiéçons": ("dépiécer",),
    "dépiégeaient": ("dépiéger",),
    "dépiégeai": ("dépiéger",),
    "dépiégeais": ("dépiéger",),
    "dépiégeait": ("dépiéger",),
    "dépiégea": ("dépiéger",),
    "dépiégeâmes": ("dépiéger",),
    "dépiégeant": ("dépiéger",),
    "dépiégeas": ("dépiéger",),
    "dépiégeassent": ("dépiéger",),
    "dépiégeasses": ("dépiéger",),
    "dépiégeasse": ("dépiéger",),
    "dépiégeassiez": ("dépiéger",),
    "dépiégeassions": ("dépiéger",),
    "dépiégeâtes": ("dépiéger",),
    "dépiégeât": ("dépiéger",),
    "dépiégée": ("dépiéger",),
    "dépiégées": ("dépiéger",),
    "dépiégé": ("dépiéger",),
    "dépiègent": ("dépiéger",),
    "dépiégeons": ("dépiéger",),
    "dépiège": ("dépiéger",),
    "dépiégera": ("dépiéger",),
    "dépiégeraient": ("dépiéger",),
    "dépiégerai": ("dépiéger",),
    "dépiégerais": ("dépiéger",),
    "dépiégerait": ("dépiéger",),
    "dépiégeras": ("dépiéger",),
    "dépiégèrent": ("dépiéger",),
    "dépiégerez": ("dépiéger",),
    "dépiégeriez": ("dépiéger",),
    "dépiégerions": ("dépiéger",),
    "dépiégerons": ("dépiéger",),
    "dépiégeront": ("dépiéger",),
    "dépiégés": ("dépiéger",),
    "dépièges": ("dépiéger",),
    "dépiégez": ("dépiéger",),
    "dépiégiez": ("dépiéger",),
    "dépiégions": ("dépiéger",),
    "déplaçaient": ("déplacer",),
    "déplaçai": ("déplacer",),
    "déplaçais": ("déplacer",),
    "déplaçait": ("déplacer",),
    "déplaça": ("déplacer",),
    "déplaçâmes": ("déplacer",),
    "déplaçant": ("déplacer",),
    "déplaças": ("déplacer",),
    "déplaçassent": ("déplacer",),
    "déplaçasses": ("déplacer",),
    "déplaçasse": ("déplacer",),
    "déplaçassiez": ("déplacer",),
    "déplaçassions": ("déplacer",),
    "déplaçâtes": ("déplacer",),
    "déplaçât": ("déplacer",),
    "déplacée": ("déplacer",),
    "déplacées": ("déplacer",),
    "déplacé": ("déplacer",),
    "déplacent": ("déplacer",),
    "déplace": ("déplacer",),
    "déplacera": ("déplacer",),
    "déplaceraient": ("déplacer",),
    "déplacerai": ("déplacer",),
    "déplacerais": ("déplacer",),
    "déplacerait": ("déplacer",),
    "déplaceras": ("déplacer",),
    "déplacèrent": ("déplacer",),
    "déplacerez": ("déplacer",),
    "déplaceriez": ("déplacer",),
    "déplacerions": ("déplacer",),
    "déplacerons": ("déplacer",),
    "déplaceront": ("déplacer",),
    "déplacés": ("déplacer",),
    "déplaces": ("déplacer",),
    "déplacez": ("déplacer",),
    "déplaciez": ("déplacer",),
    "déplacions": ("déplacer",),
    "déplaçons": ("déplacer",),
    "déplaira": ("déplaire",),
    "déplairaient": ("déplaire",),
    "déplairai": ("déplaire",),
    "déplairais": ("déplaire",),
    "déplairait": ("déplaire",),
    "déplairas": ("déplaire",),
    "déplairez": ("déplaire",),
    "déplairiez": ("déplaire",),
    "déplairions": ("déplaire",),
    "déplairons": ("déplaire",),
    "déplairont": ("déplaire",),
    "déplaisaient": ("déplaire",),
    "déplaisais": ("déplaire",),
    "déplaisait": ("déplaire",),
    "déplaisant": ("déplaire",),
    "déplaisent": ("déplaire",),
    "déplaise": ("déplaire",),
    "déplaises": ("déplaire",),
    "déplaisez": ("déplaire",),
    "déplaisiez": ("déplaire",),
    "déplaisions": ("déplaire",),
    "déplaisons": ("déplaire",),
    "déplais": ("déplaire",),
    "déplaît": ("déplaire",),
    "déplue": ("déplaire",),
    "déplues": ("déplaire",),
    "déplu": ("déplaire",),
    "déplûmes": ("déplaire",),
    "déplurent": ("déplaire",),
    "déplus": ("déplaire",),
    "déplussent": ("déplaire",),
    "déplusses": ("déplaire",),
    "déplusse": ("déplaire",),
    "déplussiez": ("déplaire",),
    "déplussions": ("déplaire",),
    "déplûtes": ("déplaire",),
    "déplut": ("déplaire",),
    "déplût": ("déplaire",),
    "déplanifiaient": ("déplanifier",),
    "déplanifiai": ("déplanifier",),
    "déplanifiais": ("déplanifier",),
    "déplanifiait": ("déplanifier",),
    "déplanifia": ("déplanifier",),
    "déplanifiâmes": ("déplanifier",),
    "déplanifiant": ("déplanifier",),
    "déplanifias": ("déplanifier",),
    "déplanifiassent": ("déplanifier",),
    "déplanifiasses": ("déplanifier",),
    "déplanifiasse": ("déplanifier",),
    "déplanifiassiez": ("déplanifier",),
    "déplanifiassions": ("déplanifier",),
    "déplanifiâtes": ("déplanifier",),
    "déplanifiât": ("déplanifier",),
    "déplanifiée": ("déplanifier",),
    "déplanifiées": ("déplanifier",),
    "déplanifié": ("déplanifier",),
    "déplanifient": ("déplanifier",),
    "déplanifie": ("déplanifier",),
    "déplanifiera": ("déplanifier",),
    "déplanifieraient": ("déplanifier",),
    "déplanifierai": ("déplanifier",),
    "déplanifierais": ("déplanifier",),
    "déplanifierait": ("déplanifier",),
    "déplanifieras": ("déplanifier",),
    "déplanifièrent": ("déplanifier",),
    "déplanifierez": ("déplanifier",),
    "déplanifieriez": ("déplanifier",),
    "déplanifierions": ("déplanifier",),
    "déplanifierons": ("déplanifier",),
    "déplanifieront": ("déplanifier",),
    "déplanifiés": ("déplanifier",),
    "déplanifies": ("déplanifier",),
    "déplanifiez": ("déplanifier",),
    "déplanifiiez": ("déplanifier",),
    "déplanifiions": ("déplanifier",),
    "déplanifions": ("déplanifier",),
    "dépliaient": ("déplier",),
    "dépliai": ("déplier",),
    "dépliais": ("déplier",),
    "dépliait": ("déplier",),
    "déplia": ("déplier",),
    "dépliâmes": ("déplier",),
    "dépliant": ("déplier",),
    "déplias": ("déplier",),
    "dépliassent": ("déplier",),
    "dépliasses": ("déplier",),
    "dépliasse": ("déplier",),
    "dépliassiez": ("déplier",),
    "dépliassions": ("déplier",),
    "dépliâtes": ("déplier",),
    "dépliât": ("déplier",),
    "dépliée": ("déplier",),
    "dépliées": ("déplier",),
    "déplié": ("déplier",),
    "déplient": ("déplier",),
    "déplie": ("déplier",),
    "dépliera": ("déplier",),
    "déplieraient": ("déplier",),
    "déplierai": ("déplier",),
    "déplierais": ("déplier",),
    "déplierait": ("déplier",),
    "déplieras": ("déplier",),
    "déplièrent": ("déplier",),
    "déplierez": ("déplier",),
    "déplieriez": ("déplier",),
    "déplierions": ("déplier",),
    "déplierons": ("déplier",),
    "déplieront": ("déplier",),
    "dépliés": ("déplier",),
    "déplies": ("déplier",),
    "dépliez": ("déplier",),
    "dépliiez": ("déplier",),
    "dépliions": ("déplier",),
    "déplions": ("déplier",),
    "déplongeaient": ("déplonger",),
    "déplongeai": ("déplonger",),
    "déplongeais": ("déplonger",),
    "déplongeait": ("déplonger",),
    "déplongea": ("déplonger",),
    "déplongeâmes": ("déplonger",),
    "déplongeant": ("déplonger",),
    "déplongeas": ("déplonger",),
    "déplongeassent": ("déplonger",),
    "déplongeasses": ("déplonger",),
    "déplongeasse": ("déplonger",),
    "déplongeassiez": ("déplonger",),
    "déplongeassions": ("déplonger",),
    "déplongeâtes": ("déplonger",),
    "déplongeât": ("déplonger",),
    "déplongée": ("déplonger",),
    "déplongées": ("déplonger",),
    "déplongé": ("déplonger",),
    "déplongent": ("déplonger",),
    "déplongeons": ("déplonger",),
    "déplonge": ("déplonger",),
    "déplongera": ("déplonger",),
    "déplongeraient": ("déplonger",),
    "déplongerai": ("déplonger",),
    "déplongerais": ("déplonger",),
    "déplongerait": ("déplonger",),
    "déplongeras": ("déplonger",),
    "déplongèrent": ("déplonger",),
    "déplongerez": ("déplonger",),
    "déplongeriez": ("déplonger",),
    "déplongerions": ("déplonger",),
    "déplongerons": ("déplonger",),
    "déplongeront": ("déplonger",),
    "déplongés": ("déplonger",),
    "déplonges": ("déplonger",),
    "déplongez": ("déplonger",),
    "déplongiez": ("déplonger",),
    "déplongions": ("déplonger",),
    "déploient": ("déployer",),
    "déploie": ("déployer",),
    "déploiera": ("déployer",),
    "déploieraient": ("déployer",),
    "déploierai": ("déployer",),
    "déploierais": ("déployer",),
    "déploierait": ("déployer",),
    "déploieras": ("déployer",),
    "déploierez": ("déployer",),
    "déploieriez": ("déployer",),
    "déploierions": ("déployer",),
    "déploierons": ("déployer",),
    "déploieront": ("déployer",),
    "déploies": ("déployer",),
    "déployaient": ("déployer",),
    "déployai": ("déployer",),
    "déployais": ("déployer",),
    "déployait": ("déployer",),
    "déploya": ("déployer",),
    "déployâmes": ("déployer",),
    "déployant": ("déployer",),
    "déployas": ("déployer",),
    "déployassent": ("déployer",),
    "déployasses": ("déployer",),
    "déployasse": ("déployer",),
    "déployassiez": ("déployer",),
    "déployassions": ("déployer",),
    "déployâtes": ("déployer",),
    "déployât": ("déployer",),
    "déployée": ("déployer",),
    "déployées": ("déployer",),
    "déployé": ("déployer",),
    "déployèrent": ("déployer",),
    "déployés": ("déployer",),
    "déployez": ("déployer",),
    "déployiez": ("déployer",),
    "déployions": ("déployer",),
    "déployons": ("déployer",),
    "dépolie": ("dépolir",),
    "dépolies": ("dépolir",),
    "dépoli": ("dépolir",),
    "dépolîmes": ("dépolir",),
    "dépolira": ("dépolir",),
    "dépoliraient": ("dépolir",),
    "dépolirai": ("dépolir",),
    "dépolirais": ("dépolir",),
    "dépolirait": ("dépolir",),
    "dépoliras": ("dépolir",),
    "dépolirent": ("dépolir",),
    "dépolirez": ("dépolir",),
    "dépoliriez": ("dépolir",),
    "dépolirions": ("dépolir",),
    "dépolirons": ("dépolir",),
    "dépoliront": ("dépolir",),
    "dépolis": ("dépolir",),
    "dépolissaient": ("dépolir",),
    "dépolissais": ("dépolir",),
    "dépolissait": ("dépolir",),
    "dépolissant": ("dépolir",),
    "dépolissent": ("dépolir",),
    "dépolisse": ("dépolir",),
    "dépolisses": ("dépolir",),
    "dépolissez": ("dépolir",),
    "dépolissiez": ("dépolir",),
    "dépolissions": ("dépolir",),
    "dépolissons": ("dépolir",),
    "dépolîtes": ("dépolir",),
    "dépolit": ("dépolir",),
    "dépolît": ("dépolir",),
    "dépossédaient": ("déposséder",),
    "dépossédai": ("déposséder",),
    "dépossédais": ("déposséder",),
    "dépossédait": ("déposséder",),
    "déposséda": ("déposséder",),
    "dépossédâmes": ("déposséder",),
    "dépossédant": ("déposséder",),
    "dépossédas": ("déposséder",),
    "dépossédassent": ("déposséder",),
    "dépossédasses": ("déposséder",),
    "dépossédasse": ("déposséder",),
    "dépossédassiez": ("déposséder",),
    "dépossédassions": ("déposséder",),
    "dépossédâtes": ("déposséder",),
    "dépossédât": ("déposséder",),
    "dépossédée": ("déposséder",),
    "dépossédées": ("déposséder",),
    "dépossédé": ("déposséder",),
    "dépossèdent": ("déposséder",),
    "dépossède": ("déposséder",),
    "dépossédera": ("déposséder",),
    "déposséderaient": ("déposséder",),
    "déposséderai": ("déposséder",),
    "déposséderais": ("déposséder",),
    "déposséderait": ("déposséder",),
    "déposséderas": ("déposséder",),
    "dépossédèrent": ("déposséder",),
    "déposséderez": ("déposséder",),
    "déposséderiez": ("déposséder",),
    "déposséderions": ("déposséder",),
    "déposséderons": ("déposséder",),
    "déposséderont": ("déposséder",),
    "dépossédés": ("déposséder",),
    "dépossèdes": ("déposséder",),
    "dépossédez": ("déposséder",),
    "dépossédiez": ("déposséder",),
    "dépossédions": ("déposséder",),
    "dépossédons": ("déposséder",),
    "dépourvoient": ("dépourvoir",),
    "dépourvoie": ("dépourvoir",),
    "dépourvoies": ("dépourvoir",),
    "dépourvoira": ("dépourvoir",),
    "dépourvoiraient": ("dépourvoir",),
    "dépourvoirai": ("dépourvoir",),
    "dépourvoirais": ("dépourvoir",),
    "dépourvoirait": ("dépourvoir",),
    "dépourvoiras": ("dépourvoir",),
    "dépourvoirez": ("dépourvoir",),
    "dépourvoiriez": ("dépourvoir",),
    "dépourvoirions": ("dépourvoir",),
    "dépourvoirons": ("dépourvoir",),
    "dépourvoiront": ("dépourvoir",),
    "dépourvois": ("dépourvoir",),
    "dépourvoit": ("dépourvoir",),
    "dépourvoyaient": ("dépourvoir",),
    "dépourvoyais": ("dépourvoir",),
    "dépourvoyait": ("dépourvoir",),
    "dépourvoyant": ("dépourvoir",),
    "dépourvoyez": ("dépourvoir",),
    "dépourvoyiez": ("dépourvoir",),
    "dépourvoyions": ("dépourvoir",),
    "dépourvoyons": ("dépourvoir",),
    "dépourvue": ("dépourvoir",),
    "dépourvues": ("dépourvoir",),
    "dépourvu": ("dépourvoir",),
    "dépourvûmes": ("dépourvoir",),
    "dépourvurent": ("dépourvoir",),
    "dépourvus": ("dépourvoir",),
    "dépourvussent": ("dépourvoir",),
    "dépourvusses": ("dépourvoir",),
    "dépourvusse": ("dépourvoir",),
    "dépourvussiez": ("dépourvoir",),
    "dépourvussions": ("dépourvoir",),
    "dépourvûtes": ("dépourvoir",),
    "dépourvut": ("dépourvoir",),
    "dépourvût": ("dépourvoir",),
    "dépoussiéraient": ("dépoussiérer",),
    "dépoussiérai": ("dépoussiérer",),
    "dépoussiérais": ("dépoussiérer",),
    "dépoussiérait": ("dépoussiérer",),
    "dépoussiéra": ("dépoussiérer",),
    "dépoussiérâmes": ("dépoussiérer",),
    "dépoussiérant": ("dépoussiérer",),
    "dépoussiéras": ("dépoussiérer",),
    "dépoussiérassent": ("dépoussiérer",),
    "dépoussiérasses": ("dépoussiérer",),
    "dépoussiérasse": ("dépoussiérer",),
    "dépoussiérassiez": ("dépoussiérer",),
    "dépoussiérassions": ("dépoussiérer",),
    "dépoussiérâtes": ("dépoussiérer",),
    "dépoussiérât": ("dépoussiérer",),
    "dépoussiérée": ("dépoussiérer",),
    "dépoussiérées": ("dépoussiérer",),
    "dépoussiéré": ("dépoussiérer",),
    "dépoussièrent": ("dépoussiérer",),
    "dépoussière": ("dépoussiérer",),
    "dépoussiérera": ("dépoussiérer",),
    "dépoussiéreraient": ("dépoussiérer",),
    "dépoussiérerai": ("dépoussiérer",),
    "dépoussiérerais": ("dépoussiérer",),
    "dépoussiérerait": ("dépoussiérer",),
    "dépoussiéreras": ("dépoussiérer",),
    "dépoussiérèrent": ("dépoussiérer",),
    "dépoussiérerez": ("dépoussiérer",),
    "dépoussiéreriez": ("dépoussiérer",),
    "dépoussiérerions": ("dépoussiérer",),
    "dépoussiérerons": ("dépoussiérer",),
    "dépoussiéreront": ("dépoussiérer",),
    "dépoussiérés": ("dépoussiérer",),
    "dépoussières": ("dépoussiérer",),
    "dépoussiérez": ("dépoussiérer",),
    "dépoussiériez": ("dépoussiérer",),
    "dépoussiérions": ("dépoussiérer",),
    "dépoussiérons": ("dépoussiérer",),
    "dépréciaient": ("déprécier",),
    "dépréciai": ("déprécier",),
    "dépréciais": ("déprécier",),
    "dépréciait": ("déprécier",),
    "déprécia": ("déprécier",),
    "dépréciâmes": ("déprécier",),
    "dépréciant": ("déprécier",),
    "déprécias": ("déprécier",),
    "dépréciassent": ("déprécier",),
    "dépréciasses": ("déprécier",),
    "dépréciasse": ("déprécier",),
    "dépréciassiez": ("déprécier",),
    "dépréciassions": ("déprécier",),
    "dépréciâtes": ("déprécier",),
    "dépréciât": ("déprécier",),
    "dépréciée": ("déprécier",),
    "dépréciées": ("déprécier",),
    "déprécié": ("déprécier",),
    "déprécient": ("déprécier",),
    "déprécie": ("déprécier",),
    "dépréciera": ("déprécier",),
    "déprécieraient": ("déprécier",),
    "déprécierai": ("déprécier",),
    "déprécierais": ("déprécier",),
    "déprécierait": ("déprécier",),
    "déprécieras": ("déprécier",),
    "déprécièrent": ("déprécier",),
    "déprécierez": ("déprécier",),
    "déprécieriez": ("déprécier",),
    "déprécierions": ("déprécier",),
    "déprécierons": ("déprécier",),
    "déprécieront": ("déprécier",),
    "dépréciés": ("déprécier",),
    "déprécies": ("déprécier",),
    "dépréciez": ("déprécier",),
    "dépréciiez": ("déprécier",),
    "dépréciions": ("déprécier",),
    "déprécions": ("déprécier",),
    "déprédaient": ("dépréder",),
    "déprédai": ("dépréder",),
    "déprédais": ("dépréder",),
    "déprédait": ("dépréder",),
    "dépréda": ("dépréder",),
    "déprédâmes": ("dépréder",),
    "déprédant": ("dépréder",),
    "déprédas": ("dépréder",),
    "déprédassent": ("dépréder",),
    "déprédasses": ("dépréder",),
    "déprédasse": ("dépréder",),
    "déprédassiez": ("dépréder",),
    "déprédassions": ("dépréder",),
    "déprédâtes": ("dépréder",),
    "déprédât": ("dépréder",),
    "déprédée": ("dépréder",),
    "déprédées": ("dépréder",),
    "déprédé": ("dépréder",),
    "déprèdent": ("dépréder",),
    "déprède": ("dépréder",),
    "déprédera": ("dépréder",),
    "dépréderaient": ("dépréder",),
    "dépréderai": ("dépréder",),
    "dépréderais": ("dépréder",),
    "dépréderait": ("dépréder",),
    "dépréderas": ("dépréder",),
    "déprédèrent": ("dépréder",),
    "dépréderez": ("dépréder",),
    "dépréderiez": ("dépréder",),
    "dépréderions": ("dépréder",),
    "dépréderons": ("dépréder",),
    "dépréderont": ("dépréder",),
    "déprédés": ("dépréder",),
    "déprèdes": ("dépréder",),
    "déprédez": ("dépréder",),
    "déprédiez": ("dépréder",),
    "déprédions": ("dépréder",),
    "déprédons": ("dépréder",),
    "déprenaient": ("déprendre",),
    "déprenais": ("déprendre",),
    "déprenait": ("déprendre",),
    "déprenant": ("déprendre",),
    "déprend": ("déprendre",),
    "déprendra": ("déprendre",),
    "déprendraient": ("déprendre",),
    "déprendrai": ("déprendre",),
    "déprendrais": ("déprendre",),
    "déprendrait": ("déprendre",),
    "déprendras": ("déprendre",),
    "déprendrez": ("déprendre",),
    "déprendriez": ("déprendre",),
    "déprendrions": ("déprendre",),
    "déprendrons": ("déprendre",),
    "déprendront": ("déprendre",),
    "déprends": ("déprendre",),
    "déprenez": ("déprendre",),
    "dépreniez": ("déprendre",),
    "déprenions": ("déprendre",),
    "déprennent": ("déprendre",),
    "déprenne": ("déprendre",),
    "déprennes": ("déprendre",),
    "déprenons": ("déprendre",),
    "déprîmes": ("déprendre",),
    "déprirent": ("déprendre",),
    "déprise": ("déprendre",),
    "déprises": ("déprendre",),
    "dépris": ("déprendre",),
    "déprissent": ("déprendre",),
    "déprisses": ("déprendre",),
    "déprisse": ("déprendre",),
    "déprissiez": ("déprendre",),
    "déprissions": ("déprendre",),
    "déprîtes": ("déprendre",),
    "déprit": ("déprendre",),
    "déprît": ("déprendre",),
    "dépriaient": ("déprier",),
    "dépriai": ("déprier",),
    "dépriais": ("déprier",),
    "dépriait": ("déprier",),
    "dépria": ("déprier",),
    "dépriâmes": ("déprier",),
    "dépriant": ("déprier",),
    "déprias": ("déprier",),
    "dépriassent": ("déprier",),
    "dépriasses": ("déprier",),
    "dépriasse": ("déprier",),
    "dépriassiez": ("déprier",),
    "dépriassions": ("déprier",),
    "dépriâtes": ("déprier",),
    "dépriât": ("déprier",),
    "dépriée": ("déprier",),
    "dépriées": ("déprier",),
    "déprié": ("déprier",),
    "déprient": ("déprier",),
    "déprie": ("déprier",),
    "dépriera": ("déprier",),
    "déprieraient": ("déprier",),
    "déprierai": ("déprier",),
    "déprierais": ("déprier",),
    "déprierait": ("déprier",),
    "déprieras": ("déprier",),
    "déprièrent": ("déprier",),
    "déprierez": ("déprier",),
    "déprieriez": ("déprier",),
    "déprierions": ("déprier",),
    "déprierons": ("déprier",),
    "déprieront": ("déprier",),
    "dépriés": ("déprier",),
    "dépries": ("déprier",),
    "dépriez": ("déprier",),
    "dépriiez": ("déprier",),
    "dépriions": ("déprier",),
    "déprions": ("déprier",),
    "dépucelaient": ("dépuceler",),
    "dépucelai": ("dépuceler",),
    "dépucelais": ("dépuceler",),
    "dépucelait": ("dépuceler",),
    "dépucela": ("dépuceler",),
    "dépucelâmes": ("dépuceler",),
    "dépucelant": ("dépuceler",),
    "dépucelas": ("dépuceler",),
    "dépucelassent": ("dépuceler",),
    "dépucelasses": ("dépuceler",),
    "dépucelasse": ("dépuceler",),
    "dépucelassiez": ("dépuceler",),
    "dépucelassions": ("dépuceler",),
    "dépucelâtes": ("dépuceler",),
    "dépucelât": ("dépuceler",),
    "dépucelée": ("dépuceler",),
    "dépucelées": ("dépuceler",),
    "dépucelé": ("dépuceler",),
    "dépucelèrent": ("dépuceler",),
    "dépucelés": ("dépuceler",),
    "dépucelez": ("dépuceler",),
    "dépuceliez": ("dépuceler",),
    "dépucelions": ("dépuceler",),
    "dépucellent": ("dépuceler",),
    "dépucelle": ("dépuceler",),
    "dépucellera": ("dépuceler",),
    "dépucelleraient": ("dépuceler",),
    "dépucellerai": ("dépuceler",),
    "dépucellerais": ("dépuceler",),
    "dépucellerait": ("dépuceler",),
    "dépucelleras": ("dépuceler",),
    "dépucellerez": ("dépuceler",),
    "dépucelleriez": ("dépuceler",),
    "dépucellerions": ("dépuceler",),
    "dépucellerons": ("dépuceler",),
    "dépucelleront": ("dépuceler",),
    "dépucelles": ("dépuceler",),
    "dépucelons": ("dépuceler",),
    "déqualifiaient": ("déqualifier",),
    "déqualifiai": ("déqualifier",),
    "déqualifiais": ("déqualifier",),
    "déqualifiait": ("déqualifier",),
    "déqualifia": ("déqualifier",),
    "déqualifiâmes": ("déqualifier",),
    "déqualifiant": ("déqualifier",),
    "déqualifias": ("déqualifier",),
    "déqualifiassent": ("déqualifier",),
    "déqualifiasses": ("déqualifier",),
    "déqualifiasse": ("déqualifier",),
    "déqualifiassiez": ("déqualifier",),
    "déqualifiassions": ("déqualifier",),
    "déqualifiâtes": ("déqualifier",),
    "déqualifiât": ("déqualifier",),
    "déqualifiée": ("déqualifier",),
    "déqualifiées": ("déqualifier",),
    "déqualifié": ("déqualifier",),
    "déqualifient": ("déqualifier",),
    "déqualifie": ("déqualifier",),
    "déqualifiera": ("déqualifier",),
    "déqualifieraient": ("déqualifier",),
    "déqualifierai": ("déqualifier",),
    "déqualifierais": ("déqualifier",),
    "déqualifierait": ("déqualifier",),
    "déqualifieras": ("déqualifier",),
    "déqualifièrent": ("déqualifier",),
    "déqualifierez": ("déqualifier",),
    "déqualifieriez": ("déqualifier",),
    "déqualifierions": ("déqualifier",),
    "déqualifierons": ("déqualifier",),
    "déqualifieront": ("déqualifier",),
    "déqualifiés": ("déqualifier",),
    "déqualifies": ("déqualifier",),
    "déqualifiez": ("déqualifier",),
    "déqualifiiez": ("déqualifier",),
    "déqualifiions": ("déqualifier",),
    "déqualifions": ("déqualifier",),
    "dérageaient": ("dérager",),
    "dérageai": ("dérager",),
    "dérageais": ("dérager",),
    "dérageait": ("dérager",),
    "déragea": ("dérager",),
    "dérageâmes": ("dérager",),
    "dérageant": ("dérager",),
    "dérageas": ("dérager",),
    "dérageassent": ("dérager",),
    "dérageasses": ("dérager",),
    "dérageasse": ("dérager",),
    "dérageassiez": ("dérager",),
    "dérageassions": ("dérager",),
    "dérageâtes": ("dérager",),
    "dérageât": ("dérager",),
    "déragé": ("dérager",),
    "déragent": ("dérager",),
    "dérageons": ("dérager",),
    "dérage": ("dérager",),
    "déragera": ("dérager",),
    "dérageraient": ("dérager",),
    "déragerai": ("dérager",),
    "déragerais": ("dérager",),
    "déragerait": ("dérager",),
    "dérageras": ("dérager",),
    "déragèrent": ("dérager",),
    "déragerez": ("dérager",),
    "dérageriez": ("dérager",),
    "déragerions": ("dérager",),
    "déragerons": ("dérager",),
    "dérageront": ("dérager",),
    "dérages": ("dérager",),
    "déragez": ("dérager",),
    "déragiez": ("dérager",),
    "déragions": ("dérager",),
    "déraidie": ("déraidir",),
    "déraidies": ("déraidir",),
    "déraidi": ("déraidir",),
    "déraidîmes": ("déraidir",),
    "déraidira": ("déraidir",),
    "déraidiraient": ("déraidir",),
    "déraidirai": ("déraidir",),
    "déraidirais": ("déraidir",),
    "déraidirait": ("déraidir",),
    "déraidiras": ("déraidir",),
    "déraidirent": ("déraidir",),
    "déraidirez": ("déraidir",),
    "déraidiriez": ("déraidir",),
    "déraidirions": ("déraidir",),
    "déraidirons": ("déraidir",),
    "déraidiront": ("déraidir",),
    "déraidis": ("déraidir",),
    "déraidissaient": ("déraidir",),
    "déraidissais": ("déraidir",),
    "déraidissait": ("déraidir",),
    "déraidissant": ("déraidir",),
    "déraidissent": ("déraidir",),
    "déraidisse": ("déraidir",),
    "déraidisses": ("déraidir",),
    "déraidissez": ("déraidir",),
    "déraidissiez": ("déraidir",),
    "déraidissions": ("déraidir",),
    "déraidissons": ("déraidir",),
    "déraidîtes": ("déraidir",),
    "déraidit": ("déraidir",),
    "déraidît": ("déraidir",),
    "dérangeaient": ("déranger",),
    "dérangeai": ("déranger",),
    "dérangeais": ("déranger",),
    "dérangeait": ("déranger",),
    "dérangea": ("déranger",),
    "dérangeâmes": ("déranger",),
    "dérangeant": ("déranger",),
    "dérangeas": ("déranger",),
    "dérangeassent": ("déranger",),
    "dérangeasses": ("déranger",),
    "dérangeasse": ("déranger",),
    "dérangeassiez": ("déranger",),
    "dérangeassions": ("déranger",),
    "dérangeâtes": ("déranger",),
    "dérangeât": ("déranger",),
    "dérangée": ("déranger",),
    "dérangées": ("déranger",),
    "dérangé": ("déranger",),
    "dérangent": ("déranger",),
    "dérangeons": ("déranger",),
    "dérange": ("déranger",),
    "dérangera": ("déranger",),
    "dérangeraient": ("déranger",),
    "dérangerai": ("déranger",),
    "dérangerais": ("déranger",),
    "dérangerait": ("déranger",),
    "dérangeras": ("déranger",),
    "dérangèrent": ("déranger",),
    "dérangerez": ("déranger",),
    "dérangeriez": ("déranger",),
    "dérangerions": ("déranger",),
    "dérangerons": ("déranger",),
    "dérangeront": ("déranger",),
    "dérangés": ("déranger",),
    "déranges": ("déranger",),
    "dérangez": ("déranger",),
    "dérangiez": ("déranger",),
    "dérangions": ("déranger",),
    "déraient": ("dérayer",),
    "déraie": ("dérayer",),
    "déraiera": ("dérayer",),
    "déraieraient": ("dérayer",),
    "déraierai": ("dérayer",),
    "déraierais": ("dérayer",),
    "déraierait": ("dérayer",),
    "déraieras": ("dérayer",),
    "déraierez": ("dérayer",),
    "déraieriez": ("dérayer",),
    "déraierions": ("dérayer",),
    "déraierons": ("dérayer",),
    "déraieront": ("dérayer",),
    "déraies": ("dérayer",),
    "dérayaient": ("dérayer",),
    "dérayai": ("dérayer",),
    "dérayais": ("dérayer",),
    "dérayait": ("dérayer",),
    "déraya": ("dérayer",),
    "dérayâmes": ("dérayer",),
    "dérayant": ("dérayer",),
    "dérayas": ("dérayer",),
    "dérayassent": ("dérayer",),
    "dérayasses": ("dérayer",),
    "dérayasse": ("dérayer",),
    "dérayassiez": ("dérayer",),
    "dérayassions": ("dérayer",),
    "dérayâtes": ("dérayer",),
    "dérayât": ("dérayer",),
    "dérayée": ("dérayer",),
    "dérayées": ("dérayer",),
    "dérayé": ("dérayer",),
    "dérayent": ("dérayer",),
    "déraye": ("dérayer",),
    "dérayera": ("dérayer",),
    "dérayeraient": ("dérayer",),
    "dérayerai": ("dérayer",),
    "dérayerais": ("dérayer",),
    "dérayerait": ("dérayer",),
    "dérayeras": ("dérayer",),
    "dérayèrent": ("dérayer",),
    "dérayerez": ("dérayer",),
    "dérayeriez": ("dérayer",),
    "dérayerions": ("dérayer",),
    "dérayerons": ("dérayer",),
    "dérayeront": ("dérayer",),
    "dérayés": ("dérayer",),
    "dérayes": ("dérayer",),
    "dérayez": ("dérayer",),
    "dérayiez": ("dérayer",),
    "dérayions": ("dérayer",),
    "dérayons": ("dérayer",),
    "déréglaient": ("dérégler",),
    "déréglai": ("dérégler",),
    "déréglais": ("dérégler",),
    "déréglait": ("dérégler",),
    "dérégla": ("dérégler",),
    "déréglâmes": ("dérégler",),
    "déréglant": ("dérégler",),
    "déréglas": ("dérégler",),
    "déréglassent": ("dérégler",),
    "déréglasses": ("dérégler",),
    "déréglasse": ("dérégler",),
    "déréglassiez": ("dérégler",),
    "déréglassions": ("dérégler",),
    "déréglâtes": ("dérégler",),
    "déréglât": ("dérégler",),
    "déréglée": ("dérégler",),
    "déréglées": ("dérégler",),
    "déréglé": ("dérégler",),
    "dérèglent": ("dérégler",),
    "dérègle": ("dérégler",),
    "déréglera": ("dérégler",),
    "dérégleraient": ("dérégler",),
    "déréglerai": ("dérégler",),
    "déréglerais": ("dérégler",),
    "déréglerait": ("dérégler",),
    "dérégleras": ("dérégler",),
    "déréglèrent": ("dérégler",),
    "déréglerez": ("dérégler",),
    "dérégleriez": ("dérégler",),
    "déréglerions": ("dérégler",),
    "déréglerons": ("dérégler",),
    "dérégleront": ("dérégler",),
    "déréglés": ("dérégler",),
    "dérègles": ("dérégler",),
    "déréglez": ("dérégler",),
    "dérégliez": ("dérégler",),
    "déréglions": ("dérégler",),
    "déréglons": ("dérégler",),
    "déreliaient": ("dérelier",),
    "déreliai": ("dérelier",),
    "déreliais": ("dérelier",),
    "déreliait": ("dérelier",),
    "dérelia": ("dérelier",),
    "déreliâmes": ("dérelier",),
    "déreliant": ("dérelier",),
    "dérelias": ("dérelier",),
    "déreliassent": ("dérelier",),
    "déreliasses": ("dérelier",),
    "déreliasse": ("dérelier",),
    "déreliassiez": ("dérelier",),
    "déreliassions": ("dérelier",),
    "déreliâtes": ("dérelier",),
    "déreliât": ("dérelier",),
    "déreliée": ("dérelier",),
    "déreliées": ("dérelier",),
    "dérelié": ("dérelier",),
    "dérelient": ("dérelier",),
    "dérelie": ("dérelier",),
    "déreliera": ("dérelier",),
    "dérelieraient": ("dérelier",),
    "dérelierai": ("dérelier",),
    "dérelierais": ("dérelier",),
    "dérelierait": ("dérelier",),
    "dérelieras": ("dérelier",),
    "dérelièrent": ("dérelier",),
    "dérelierez": ("dérelier",),
    "dérelieriez": ("dérelier",),
    "dérelierions": ("dérelier",),
    "dérelierons": ("dérelier",),
    "dérelieront": ("dérelier",),
    "déreliés": ("dérelier",),
    "dérelies": ("dérelier",),
    "déreliez": ("dérelier",),
    "déreliiez": ("dérelier",),
    "déreliions": ("dérelier",),
    "dérelions": ("dérelier",),
    "dérivetaient": ("dériveter",),
    "dérivetai": ("dériveter",),
    "dérivetais": ("dériveter",),
    "dérivetait": ("dériveter",),
    "dériveta": ("dériveter",),
    "dérivetâmes": ("dériveter",),
    "dérivetant": ("dériveter",),
    "dérivetas": ("dériveter",),
    "dérivetassent": ("dériveter",),
    "dérivetasses": ("dériveter",),
    "dérivetasse": ("dériveter",),
    "dérivetassiez": ("dériveter",),
    "dérivetassions": ("dériveter",),
    "dérivetâtes": ("dériveter",),
    "dérivetât": ("dériveter",),
    "dérivetée": ("dériveter",),
    "dérivetées": ("dériveter",),
    "dériveté": ("dériveter",),
    "dérivetèrent": ("dériveter",),
    "dérivetés": ("dériveter",),
    "dérivetez": ("dériveter",),
    "dérivetiez": ("dériveter",),
    "dérivetions": ("dériveter",),
    "dérivetons": ("dériveter",),
    "dérivettent": ("dériveter",),
    "dérivette": ("dériveter",),
    "dérivettera": ("dériveter",),
    "dérivetteraient": ("dériveter",),
    "dérivetterai": ("dériveter",),
    "dérivetterais": ("dériveter",),
    "dérivetterait": ("dériveter",),
    "dérivetteras": ("dériveter",),
    "dérivetterez": ("dériveter",),
    "dérivetteriez": ("dériveter",),
    "dérivetterions": ("dériveter",),
    "dérivetterons": ("dériveter",),
    "dérivetteront": ("dériveter",),
    "dérivettes": ("dériveter",),
    "dérogeaient": ("déroger",),
    "dérogeai": ("déroger",),
    "dérogeais": ("déroger",),
    "dérogeait": ("déroger",),
    "dérogea": ("déroger",),
    "dérogeâmes": ("déroger",),
    "dérogeant": ("déroger",),
    "dérogeas": ("déroger",),
    "dérogeassent": ("déroger",),
    "dérogeasses": ("déroger",),
    "dérogeasse": ("déroger",),
    "dérogeassiez": ("déroger",),
    "dérogeassions": ("déroger",),
    "dérogeâtes": ("déroger",),
    "dérogeât": ("déroger",),
    "dérogé": ("déroger",),
    "dérogent": ("déroger",),
    "dérogeons": ("déroger",),
    "déroge": ("déroger",),
    "dérogera": ("déroger",),
    "dérogeraient": ("déroger",),
    "dérogerai": ("déroger",),
    "dérogerais": ("déroger",),
    "dérogerait": ("déroger",),
    "dérogeras": ("déroger",),
    "dérogèrent": ("déroger",),
    "dérogerez": ("déroger",),
    "dérogeriez": ("déroger",),
    "dérogerions": ("déroger",),
    "dérogerons": ("déroger",),
    "dérogeront": ("déroger",),
    "déroges": ("déroger",),
    "dérogez": ("déroger",),
    "dérogiez": ("déroger",),
    "dérogions": ("déroger",),
    "déroidie": ("déroidir",),
    "déroidies": ("déroidir",),
    "déroidi": ("déroidir",),
    "déroidîmes": ("déroidir",),
    "déroidira": ("déroidir",),
    "déroidiraient": ("déroidir",),
    "déroidirai": ("déroidir",),
    "déroidirais": ("déroidir",),
    "déroidirait": ("déroidir",),
    "déroidiras": ("déroidir",),
    "déroidirent": ("déroidir",),
    "déroidirez": ("déroidir",),
    "déroidiriez": ("déroidir",),
    "déroidirions": ("déroidir",),
    "déroidirons": ("déroidir",),
    "déroidiront": ("déroidir",),
    "déroidis": ("déroidir",),
    "déroidissaient": ("déroidir",),
    "déroidissais": ("déroidir",),
    "déroidissait": ("déroidir",),
    "déroidissant": ("déroidir",),
    "déroidissent": ("déroidir",),
    "déroidisse": ("déroidir",),
    "déroidisses": ("déroidir",),
    "déroidissez": ("déroidir",),
    "déroidissiez": ("déroidir",),
    "déroidissions": ("déroidir",),
    "déroidissons": ("déroidir",),
    "déroidîtes": ("déroidir",),
    "déroidit": ("déroidir",),
    "déroidît": ("déroidir",),
    "dérompaient": ("dérompre",),
    "dérompais": ("dérompre",),
    "dérompait": ("dérompre",),
    "dérompant": ("dérompre",),
    "dérompent": ("dérompre",),
    "dérompe": ("dérompre",),
    "dérompes": ("dérompre",),
    "dérompez": ("dérompre",),
    "dérompiez": ("dérompre",),
    "dérompîmes": ("dérompre",),
    "dérompions": ("dérompre",),
    "dérompirent": ("dérompre",),
    "dérompis": ("dérompre",),
    "dérompissent": ("dérompre",),
    "dérompisses": ("dérompre",),
    "dérompisse": ("dérompre",),
    "dérompissiez": ("dérompre",),
    "dérompissions": ("dérompre",),
    "dérompîtes": ("dérompre",),
    "dérompit": ("dérompre",),
    "dérompît": ("dérompre",),
    "dérompons": ("dérompre",),
    "dérompra": ("dérompre",),
    "dérompraient": ("dérompre",),
    "déromprai": ("dérompre",),
    "déromprais": ("dérompre",),
    "déromprait": ("dérompre",),
    "dérompras": ("dérompre",),
    "déromprez": ("dérompre",),
    "dérompriez": ("dérompre",),
    "déromprions": ("dérompre",),
    "déromprons": ("dérompre",),
    "dérompront": ("dérompre",),
    "déromps": ("dérompre",),
    "dérompt": ("dérompre",),
    "dérompue": ("dérompre",),
    "dérompues": ("dérompre",),
    "dérompu": ("dérompre",),
    "dérompus": ("dérompre",),
    "dérougie": ("dérougir",),
    "dérougies": ("dérougir",),
    "dérougi": ("dérougir",),
    "dérougîmes": ("dérougir",),
    "dérougira": ("dérougir",),
    "dérougiraient": ("dérougir",),
    "dérougirai": ("dérougir",),
    "dérougirais": ("dérougir",),
    "dérougirait": ("dérougir",),
    "dérougiras": ("dérougir",),
    "dérougirent": ("dérougir",),
    "dérougirez": ("dérougir",),
    "dérougiriez": ("dérougir",),
    "dérougirions": ("dérougir",),
    "dérougirons": ("dérougir",),
    "dérougiront": ("dérougir",),
    "dérougis": ("dérougir",),
    "dérougissaient": ("dérougir",),
    "dérougissais": ("dérougir",),
    "dérougissait": ("dérougir",),
    "dérougissant": ("dérougir",),
    "dérougissent": ("dérougir",),
    "dérougisse": ("dérougir",),
    "dérougisses": ("dérougir",),
    "dérougissez": ("dérougir",),
    "dérougissiez": ("dérougir",),
    "dérougissions": ("dérougir",),
    "dérougissons": ("dérougir",),
    "dérougîtes": ("dérougir",),
    "dérougit": ("dérougir",),
    "dérougît": ("dérougir",),
    "dérussifiaient": ("dérussifier",),
    "dérussifiai": ("dérussifier",),
    "dérussifiais": ("dérussifier",),
    "dérussifiait": ("dérussifier",),
    "dérussifia": ("dérussifier",),
    "dérussifiâmes": ("dérussifier",),
    "dérussifiant": ("dérussifier",),
    "dérussifias": ("dérussifier",),
    "dérussifiassent": ("dérussifier",),
    "dérussifiasses": ("dérussifier",),
    "dérussifiasse": ("dérussifier",),
    "dérussifiassiez": ("dérussifier",),
    "dérussifiassions": ("dérussifier",),
    "dérussifiâtes": ("dérussifier",),
    "dérussifiât": ("dérussifier",),
    "dérussifiée": ("dérussifier",),
    "dérussifiées": ("dérussifier",),
    "dérussifié": ("dérussifier",),
    "dérussifient": ("dérussifier",),
    "dérussifie": ("dérussifier",),
    "dérussifiera": ("dérussifier",),
    "dérussifieraient": ("dérussifier",),
    "dérussifierai": ("dérussifier",),
    "dérussifierais": ("dérussifier",),
    "dérussifierait": ("dérussifier",),
    "dérussifieras": ("dérussifier",),
    "dérussifièrent": ("dérussifier",),
    "dérussifierez": ("dérussifier",),
    "dérussifieriez": ("dérussifier",),
    "dérussifierions": ("dérussifier",),
    "dérussifierons": ("dérussifier",),
    "dérussifieront": ("dérussifier",),
    "dérussifiés": ("dérussifier",),
    "dérussifies": ("dérussifier",),
    "dérussifiez": ("dérussifier",),
    "dérussifiiez": ("dérussifier",),
    "dérussifiions": ("dérussifier",),
    "dérussifions": ("dérussifier",),
    "désacidifiaient": ("désacidifier",),
    "désacidifiai": ("désacidifier",),
    "désacidifiais": ("désacidifier",),
    "désacidifiait": ("désacidifier",),
    "désacidifia": ("désacidifier",),
    "désacidifiâmes": ("désacidifier",),
    "désacidifiant": ("désacidifier",),
    "désacidifias": ("désacidifier",),
    "désacidifiassent": ("désacidifier",),
    "désacidifiasses": ("désacidifier",),
    "désacidifiasse": ("désacidifier",),
    "désacidifiassiez": ("désacidifier",),
    "désacidifiassions": ("désacidifier",),
    "désacidifiâtes": ("désacidifier",),
    "désacidifiât": ("désacidifier",),
    "désacidifiée": ("désacidifier",),
    "désacidifiées": ("désacidifier",),
    "désacidifié": ("désacidifier",),
    "désacidifient": ("désacidifier",),
    "désacidifie": ("désacidifier",),
    "désacidifiera": ("désacidifier",),
    "désacidifieraient": ("désacidifier",),
    "désacidifierai": ("désacidifier",),
    "désacidifierais": ("désacidifier",),
    "désacidifierait": ("désacidifier",),
    "désacidifieras": ("désacidifier",),
    "désacidifièrent": ("désacidifier",),
    "désacidifierez": ("désacidifier",),
    "désacidifieriez": ("désacidifier",),
    "désacidifierions": ("désacidifier",),
    "désacidifierons": ("désacidifier",),
    "désacidifieront": ("désacidifier",),
    "désacidifiés": ("désacidifier",),
    "désacidifies": ("désacidifier",),
    "désacidifiez": ("désacidifier",),
    "désacidifiiez": ("désacidifier",),
    "désacidifiions": ("désacidifier",),
    "désacidifions": ("désacidifier",),
    "désaciéraient": ("désaciérer",),
    "désaciérai": ("désaciérer",),
    "désaciérais": ("désaciérer",),
    "désaciérait": ("désaciérer",),
    "désaciéra": ("désaciérer",),
    "désaciérâmes": ("désaciérer",),
    "désaciérant": ("désaciérer",),
    "désaciéras": ("désaciérer",),
    "désaciérassent": ("désaciérer",),
    "désaciérasses": ("désaciérer",),
    "désaciérasse": ("désaciérer",),
    "désaciérassiez": ("désaciérer",),
    "désaciérassions": ("désaciérer",),
    "désaciérâtes": ("désaciérer",),
    "désaciérât": ("désaciérer",),
    "désaciérée": ("désaciérer",),
    "désaciérées": ("désaciérer",),
    "désaciéré": ("désaciérer",),
    "désacièrent": ("désaciérer",),
    "désacière": ("désaciérer",),
    "désaciérera": ("désaciérer",),
    "désaciéreraient": ("désaciérer",),
    "désaciérerai": ("désaciérer",),
    "désaciérerais": ("désaciérer",),
    "désaciérerait": ("désaciérer",),
    "désaciéreras": ("désaciérer",),
    "désaciérèrent": ("désaciérer",),
    "désaciérerez": ("désaciérer",),
    "désaciéreriez": ("désaciérer",),
    "désaciérerions": ("désaciérer",),
    "désaciérerons": ("désaciérer",),
    "désaciéreront": ("désaciérer",),
    "désaciérés": ("désaciérer",),
    "désacières": ("désaciérer",),
    "désaciérez": ("désaciérer",),
    "désaciériez": ("désaciérer",),
    "désaciérions": ("désaciérer",),
    "désaciérons": ("désaciérer",),
    "désaffiliaient": ("désaffilier",),
    "désaffiliai": ("désaffilier",),
    "désaffiliais": ("désaffilier",),
    "désaffiliait": ("désaffilier",),
    "désaffilia": ("désaffilier",),
    "désaffiliâmes": ("désaffilier",),
    "désaffiliant": ("désaffilier",),
    "désaffilias": ("désaffilier",),
    "désaffiliassent": ("désaffilier",),
    "désaffiliasses": ("désaffilier",),
    "désaffiliasse": ("désaffilier",),
    "désaffiliassiez": ("désaffilier",),
    "désaffiliassions": ("désaffilier",),
    "désaffiliâtes": ("désaffilier",),
    "désaffiliât": ("désaffilier",),
    "désaffiliée": ("désaffilier",),
    "désaffiliées": ("désaffilier",),
    "désaffilié": ("désaffilier",),
    "désaffilient": ("désaffilier",),
    "désaffilie": ("désaffilier",),
    "désaffiliera": ("désaffilier",),
    "désaffilieraient": ("désaffilier",),
    "désaffilierai": ("désaffilier",),
    "désaffilierais": ("désaffilier",),
    "désaffilierait": ("désaffilier",),
    "désaffilieras": ("désaffilier",),
    "désaffilièrent": ("désaffilier",),
    "désaffilierez": ("désaffilier",),
    "désaffilieriez": ("désaffilier",),
    "désaffilierions": ("désaffilier",),
    "désaffilierons": ("désaffilier",),
    "désaffilieront": ("désaffilier",),
    "désaffiliés": ("désaffilier",),
    "désaffilies": ("désaffilier",),
    "désaffiliez": ("désaffilier",),
    "désaffiliiez": ("désaffilier",),
    "désaffiliions": ("désaffilier",),
    "désaffilions": ("désaffilier",),
    "désagaçaient": ("désagacer",),
    "désagaçai": ("désagacer",),
    "désagaçais": ("désagacer",),
    "désagaçait": ("désagacer",),
    "désagaça": ("désagacer",),
    "désagaçâmes": ("désagacer",),
    "désagaçant": ("désagacer",),
    "désagaças": ("désagacer",),
    "désagaçassent": ("désagacer",),
    "désagaçasses": ("désagacer",),
    "désagaçasse": ("désagacer",),
    "désagaçassiez": ("désagacer",),
    "désagaçassions": ("désagacer",),
    "désagaçâtes": ("désagacer",),
    "désagaçât": ("désagacer",),
    "désagacée": ("désagacer",),
    "désagacées": ("désagacer",),
    "désagacé": ("désagacer",),
    "désagacent": ("désagacer",),
    "désagace": ("désagacer",),
    "désagacera": ("désagacer",),
    "désagaceraient": ("désagacer",),
    "désagacerai": ("désagacer",),
    "désagacerais": ("désagacer",),
    "désagacerait": ("désagacer",),
    "désagaceras": ("désagacer",),
    "désagacèrent": ("désagacer",),
    "désagacerez": ("désagacer",),
    "désagaceriez": ("désagacer",),
    "désagacerions": ("désagacer",),
    "désagacerons": ("désagacer",),
    "désagaceront": ("désagacer",),
    "désagacés": ("désagacer",),
    "désagaces": ("désagacer",),
    "désagacez": ("désagacer",),
    "désagaciez": ("désagacer",),
    "désagacions": ("désagacer",),
    "désagaçons": ("désagacer",),
    "désagençaient": ("désagencer",),
    "désagençai": ("désagencer",),
    "désagençais": ("désagencer",),
    "désagençait": ("désagencer",),
    "désagença": ("désagencer",),
    "désagençâmes": ("désagencer",),
    "désagençant": ("désagencer",),
    "désagenças": ("désagencer",),
    "désagençassent": ("désagencer",),
    "désagençasses": ("désagencer",),
    "désagençasse": ("désagencer",),
    "désagençassiez": ("désagencer",),
    "désagençassions": ("désagencer",),
    "désagençâtes": ("désagencer",),
    "désagençât": ("désagencer",),
    "désagencée": ("désagencer",),
    "désagencées": ("désagencer",),
    "désagencé": ("désagencer",),
    "désagencent": ("désagencer",),
    "désagence": ("désagencer",),
    "désagencera": ("désagencer",),
    "désagenceraient": ("désagencer",),
    "désagencerai": ("désagencer",),
    "désagencerais": ("désagencer",),
    "désagencerait": ("désagencer",),
    "désagenceras": ("désagencer",),
    "désagencèrent": ("désagencer",),
    "désagencerez": ("désagencer",),
    "désagenceriez": ("désagencer",),
    "désagencerions": ("désagencer",),
    "désagencerons": ("désagencer",),
    "désagenceront": ("désagencer",),
    "désagencés": ("désagencer",),
    "désagences": ("désagencer",),
    "désagencez": ("désagencer",),
    "désagenciez": ("désagencer",),
    "désagencions": ("désagencer",),
    "désagençons": ("désagencer",),
    "désagréaient": ("désagréer",),
    "désagréai": ("désagréer",),
    "désagréais": ("désagréer",),
    "désagréait": ("désagréer",),
    "désagréa": ("désagréer",),
    "désagréâmes": ("désagréer",),
    "désagréant": ("désagréer",),
    "désagréas": ("désagréer",),
    "désagréassent": ("désagréer",),
    "désagréasses": ("désagréer",),
    "désagréasse": ("désagréer",),
    "désagréassiez": ("désagréer",),
    "désagréassions": ("désagréer",),
    "désagréâtes": ("désagréer",),
    "désagréât": ("désagréer",),
    "désagréé": ("désagréer",),
    "désagréent": ("désagréer",),
    "désagrée": ("désagréer",),
    "désagréera": ("désagréer",),
    "désagréeraient": ("désagréer",),
    "désagréerai": ("désagréer",),
    "désagréerais": ("désagréer",),
    "désagréerait": ("désagréer",),
    "désagréeras": ("désagréer",),
    "désagréèrent": ("désagréer",),
    "désagréerez": ("désagréer",),
    "désagréeriez": ("désagréer",),
    "désagréerions": ("désagréer",),
    "désagréerons": ("désagréer",),
    "désagréeront": ("désagréer",),
    "désagrées": ("désagréer",),
    "désagréez": ("désagréer",),
    "désagréiez": ("désagréer",),
    "désagréions": ("désagréer",),
    "désagréons": ("désagréer",),
    "désagrégeaient": ("désagréger",),
    "désagrégeai": ("désagréger",),
    "désagrégeais": ("désagréger",),
    "désagrégeait": ("désagréger",),
    "désagrégea": ("désagréger",),
    "désagrégeâmes": ("désagréger",),
    "désagrégeant": ("désagréger",),
    "désagrégeas": ("désagréger",),
    "désagrégeassent": ("désagréger",),
    "désagrégeasses": ("désagréger",),
    "désagrégeasse": ("désagréger",),
    "désagrégeassiez": ("désagréger",),
    "désagrégeassions": ("désagréger",),
    "désagrégeâtes": ("désagréger",),
    "désagrégeât": ("désagréger",),
    "désagrégée": ("désagréger",),
    "désagrégées": ("désagréger",),
    "désagrégé": ("désagréger",),
    "désagrègent": ("désagréger",),
    "désagrégeons": ("désagréger",),
    "désagrège": ("désagréger",),
    "désagrégera": ("désagréger",),
    "désagrégeraient": ("désagréger",),
    "désagrégerai": ("désagréger",),
    "désagrégerais": ("désagréger",),
    "désagrégerait": ("désagréger",),
    "désagrégeras": ("désagréger",),
    "désagrégèrent": ("désagréger",),
    "désagrégerez": ("désagréger",),
    "désagrégeriez": ("désagréger",),
    "désagrégerions": ("désagréger",),
    "désagrégerons": ("désagréger",),
    "désagrégeront": ("désagréger",),
    "désagrégés": ("désagréger",),
    "désagrèges": ("désagréger",),
    "désagrégez": ("désagréger",),
    "désagrégiez": ("désagréger",),
    "désagrégions": ("désagréger",),
    "désaliénaient": ("désaliéner",),
    "désaliénai": ("désaliéner",),
    "désaliénais": ("désaliéner",),
    "désaliénait": ("désaliéner",),
    "désaliéna": ("désaliéner",),
    "désaliénâmes": ("désaliéner",),
    "désaliénant": ("désaliéner",),
    "désaliénas": ("désaliéner",),
    "désaliénassent": ("désaliéner",),
    "désaliénasses": ("désaliéner",),
    "désaliénasse": ("désaliéner",),
    "désaliénassiez": ("désaliéner",),
    "désaliénassions": ("désaliéner",),
    "désaliénâtes": ("désaliéner",),
    "désaliénât": ("désaliéner",),
    "désaliénée": ("désaliéner",),
    "désaliénées": ("désaliéner",),
    "désaliéné": ("désaliéner",),
    "désaliènent": ("désaliéner",),
    "désaliène": ("désaliéner",),
    "désaliénera": ("désaliéner",),
    "désaliéneraient": ("désaliéner",),
    "désaliénerai": ("désaliéner",),
    "désaliénerais": ("désaliéner",),
    "désaliénerait": ("désaliéner",),
    "désaliéneras": ("désaliéner",),
    "désaliénèrent": ("désaliéner",),
    "désaliénerez": ("désaliéner",),
    "désaliéneriez": ("désaliéner",),
    "désaliénerions": ("désaliéner",),
    "désaliénerons": ("désaliéner",),
    "désaliéneront": ("désaliéner",),
    "désaliénés": ("désaliéner",),
    "désaliènes": ("désaliéner",),
    "désaliénez": ("désaliéner",),
    "désaliéniez": ("désaliéner",),
    "désaliénions": ("désaliéner",),
    "désaliénons": ("désaliéner",),
    "désalliaient": ("désallier",),
    "désalliai": ("désallier",),
    "désalliais": ("désallier",),
    "désalliait": ("désallier",),
    "désallia": ("désallier",),
    "désalliâmes": ("désallier",),
    "désalliant": ("désallier",),
    "désallias": ("désallier",),
    "désalliassent": ("désallier",),
    "désalliasses": ("désallier",),
    "désalliasse": ("désallier",),
    "désalliassiez": ("désallier",),
    "désalliassions": ("désallier",),
    "désalliâtes": ("désallier",),
    "désalliât": ("désallier",),
    "désalliée": ("désallier",),
    "désalliées": ("désallier",),
    "désallié": ("désallier",),
    "désallient": ("désallier",),
    "désallie": ("désallier",),
    "désalliera": ("désallier",),
    "désallieraient": ("désallier",),
    "désallierai": ("désallier",),
    "désallierais": ("désallier",),
    "désallierait": ("désallier",),
    "désallieras": ("désallier",),
    "désallièrent": ("désallier",),
    "désallierez": ("désallier",),
    "désallieriez": ("désallier",),
    "désallierions": ("désallier",),
    "désallierons": ("désallier",),
    "désallieront": ("désallier",),
    "désalliés": ("désallier",),
    "désallies": ("désallier",),
    "désalliez": ("désallier",),
    "désalliiez": ("désallier",),
    "désalliions": ("désallier",),
    "désallions": ("désallier",),
    "désaltéraient": ("désaltérer",),
    "désaltérai": ("désaltérer",),
    "désaltérais": ("désaltérer",),
    "désaltérait": ("désaltérer",),
    "désaltéra": ("désaltérer",),
    "désaltérâmes": ("désaltérer",),
    "désaltérant": ("désaltérer",),
    "désaltéras": ("désaltérer",),
    "désaltérassent": ("désaltérer",),
    "désaltérasses": ("désaltérer",),
    "désaltérasse": ("désaltérer",),
    "désaltérassiez": ("désaltérer",),
    "désaltérassions": ("désaltérer",),
    "désaltérâtes": ("désaltérer",),
    "désaltérât": ("désaltérer",),
    "désaltérée": ("désaltérer",),
    "désaltérées": ("désaltérer",),
    "désaltéré": ("désaltérer",),
    "désaltèrent": ("désaltérer",),
    "désaltère": ("désaltérer",),
    "désaltérera": ("désaltérer",),
    "désaltéreraient": ("désaltérer",),
    "désaltérerai": ("désaltérer",),
    "désaltérerais": ("désaltérer",),
    "désaltérerait": ("désaltérer",),
    "désaltéreras": ("désaltérer",),
    "désaltérèrent": ("désaltérer",),
    "désaltérerez": ("désaltérer",),
    "désaltéreriez": ("désaltérer",),
    "désaltérerions": ("désaltérer",),
    "désaltérerons": ("désaltérer",),
    "désaltéreront": ("désaltérer",),
    "désaltérés": ("désaltérer",),
    "désaltères": ("désaltérer",),
    "désaltérez": ("désaltérer",),
    "désaltériez": ("désaltérer",),
    "désaltérions": ("désaltérer",),
    "désaltérons": ("désaltérer",),
    "désâmaient": ("désâmer",),
    "désâmai": ("désâmer",),
    "désâmais": ("désâmer",),
    "désâmait": ("désâmer",),
    "désâma": ("désâmer",),
    "désâmâmes": ("désâmer",),
    "désâmant": ("désâmer",),
    "désâmas": ("désâmer",),
    "désâmassent": ("désâmer",),
    "désâmasses": ("désâmer",),
    "désâmasse": ("désâmer",),
    "désâmassiez": ("désâmer",),
    "désâmassions": ("désâmer",),
    "désâmâtes": ("désâmer",),
    "désâmât": ("désâmer",),
    "désâmée": ("désâmer",),
    "désâmées": ("désâmer",),
    "désâmé": ("désâmer",),
    "désâment": ("désâmer",),
    "désâme": ("désâmer",),
    "désâmera": ("désâmer",),
    "désâmeraient": ("désâmer",),
    "désâmerai": ("désâmer",),
    "désâmerais": ("désâmer",),
    "désâmerait": ("désâmer",),
    "désâmeras": ("désâmer",),
    "désâmèrent": ("désâmer",),
    "désâmerez": ("désâmer",),
    "désâmeriez": ("désâmer",),
    "désâmerions": ("désâmer",),
    "désâmerons": ("désâmer",),
    "désâmeront": ("désâmer",),
    "désâmés": ("désâmer",),
    "désâmes": ("désâmer",),
    "désâmez": ("désâmer",),
    "désâmiez": ("désâmer",),
    "désâmions": ("désâmer",),
    "désâmons": ("désâmer",),
    "désamoncelaient": ("désamonceler",),
    "désamoncelai": ("désamonceler",),
    "désamoncelais": ("désamonceler",),
    "désamoncelait": ("désamonceler",),
    "désamoncela": ("désamonceler",),
    "désamoncelâmes": ("désamonceler",),
    "désamoncelant": ("désamonceler",),
    "désamoncelas": ("désamonceler",),
    "désamoncelassent": ("désamonceler",),
    "désamoncelasses": ("désamonceler",),
    "désamoncelasse": ("désamonceler",),
    "désamoncelassiez": ("désamonceler",),
    "désamoncelassions": ("désamonceler",),
    "désamoncelâtes": ("désamonceler",),
    "désamoncelât": ("désamonceler",),
    "désamoncelée": ("désamonceler",),
    "désamoncelées": ("désamonceler",),
    "désamoncelé": ("désamonceler",),
    "désamoncelèrent": ("désamonceler",),
    "désamoncelés": ("désamonceler",),
    "désamoncelez": ("désamonceler",),
    "désamonceliez": ("désamonceler",),
    "désamoncelions": ("désamonceler",),
    "désamoncellent": ("désamonceler",),
    "désamoncelle": ("désamonceler",),
    "désamoncellera": ("désamonceler",),
    "désamoncelleraient": ("désamonceler",),
    "désamoncellerai": ("désamonceler",),
    "désamoncellerais": ("désamonceler",),
    "désamoncellerait": ("désamonceler",),
    "désamoncelleras": ("désamonceler",),
    "désamoncellerez": ("désamonceler",),
    "désamoncelleriez": ("désamonceler",),
    "désamoncellerions": ("désamonceler",),
    "désamoncellerons": ("désamonceler",),
    "désamoncelleront": ("désamonceler",),
    "désamoncelles": ("désamonceler",),
    "désamoncelons": ("désamonceler",),
    "désamorçaient": ("désamorcer",),
    "désamorçai": ("désamorcer",),
    "désamorçais": ("désamorcer",),
    "désamorçait": ("désamorcer",),
    "désamorça": ("désamorcer",),
    "désamorçâmes": ("désamorcer",),
    "désamorçant": ("désamorcer",),
    "désamorças": ("désamorcer",),
    "désamorçassent": ("désamorcer",),
    "désamorçasses": ("désamorcer",),
    "désamorçasse": ("désamorcer",),
    "désamorçassiez": ("désamorcer",),
    "désamorçassions": ("désamorcer",),
    "désamorçâtes": ("désamorcer",),
    "désamorçât": ("désamorcer",),
    "désamorcée": ("désamorcer",),
    "désamorcées": ("désamorcer",),
    "désamorcé": ("désamorcer",),
    "désamorcent": ("désamorcer",),
    "désamorce": ("désamorcer",),
    "désamorcera": ("désamorcer",),
    "désamorceraient": ("désamorcer",),
    "désamorcerai": ("désamorcer",),
    "désamorcerais": ("désamorcer",),
    "désamorcerait": ("désamorcer",),
    "désamorceras": ("désamorcer",),
    "désamorcèrent": ("désamorcer",),
    "désamorcerez": ("désamorcer",),
    "désamorceriez": ("désamorcer",),
    "désamorcerions": ("désamorcer",),
    "désamorcerons": ("désamorcer",),
    "désamorceront": ("désamorcer",),
    "désamorcés": ("désamorcer",),
    "désamorces": ("désamorcer",),
    "désamorcez": ("désamorcer",),
    "désamorciez": ("désamorcer",),
    "désamorcions": ("désamorcer",),
    "désamorçons": ("désamorcer",),
    "désamortie": ("désamortir",),
    "désamorties": ("désamortir",),
    "désamorti": ("désamortir",),
    "désamortîmes": ("désamortir",),
    "désamortira": ("désamortir",),
    "désamortiraient": ("désamortir",),
    "désamortirai": ("désamortir",),
    "désamortirais": ("désamortir",),
    "désamortirait": ("désamortir",),
    "désamortiras": ("désamortir",),
    "désamortirent": ("désamortir",),
    "désamortirez": ("désamortir",),
    "désamortiriez": ("désamortir",),
    "désamortirions": ("désamortir",),
    "désamortirons": ("désamortir",),
    "désamortiront": ("désamortir",),
    "désamortis": ("désamortir",),
    "désamortissaient": ("désamortir",),
    "désamortissais": ("désamortir",),
    "désamortissait": ("désamortir",),
    "désamortissant": ("désamortir",),
    "désamortissent": ("désamortir",),
    "désamortisse": ("désamortir",),
    "désamortisses": ("désamortir",),
    "désamortissez": ("désamortir",),
    "désamortissiez": ("désamortir",),
    "désamortissions": ("désamortir",),
    "désamortissons": ("désamortir",),
    "désamortîtes": ("désamortir",),
    "désamortit": ("désamortir",),
    "désamortît": ("désamortir",),
    "désannelaient": ("désanneler",),
    "désannelai": ("désanneler",),
    "désannelais": ("désanneler",),
    "désannelait": ("désanneler",),
    "désannela": ("désanneler",),
    "désannelâmes": ("désanneler",),
    "désannelant": ("désanneler",),
    "désannelas": ("désanneler",),
    "désannelassent": ("désanneler",),
    "désannelasses": ("désanneler",),
    "désannelasse": ("désanneler",),
    "désannelassiez": ("désanneler",),
    "désannelassions": ("désanneler",),
    "désannelâtes": ("désanneler",),
    "désannelât": ("désanneler",),
    "désannelée": ("désanneler",),
    "désannelées": ("désanneler",),
    "désannelé": ("désanneler",),
    "désannelèrent": ("désanneler",),
    "désannelés": ("désanneler",),
    "désannelez": ("désanneler",),
    "désanneliez": ("désanneler",),
    "désannelions": ("désanneler",),
    "désannellent": ("désanneler",),
    "désannelle": ("désanneler",),
    "désannellera": ("désanneler",),
    "désannelleraient": ("désanneler",),
    "désannellerai": ("désanneler",),
    "désannellerais": ("désanneler",),
    "désannellerait": ("désanneler",),
    "désannelleras": ("désanneler",),
    "désannellerez": ("désanneler",),
    "désannelleriez": ("désanneler",),
    "désannellerions": ("désanneler",),
    "désannellerons": ("désanneler",),
    "désannelleront": ("désanneler",),
    "désannelles": ("désanneler",),
    "désannelons": ("désanneler",),
    "désannonçaient": ("désannoncer",),
    "désannonçai": ("désannoncer",),
    "désannonçais": ("désannoncer",),
    "désannonçait": ("désannoncer",),
    "désannonça": ("désannoncer",),
    "désannonçâmes": ("désannoncer",),
    "désannonçant": ("désannoncer",),
    "désannonças": ("désannoncer",),
    "désannonçassent": ("désannoncer",),
    "désannonçasses": ("désannoncer",),
    "désannonçasse": ("désannoncer",),
    "désannonçassiez": ("désannoncer",),
    "désannonçassions": ("désannoncer",),
    "désannonçâtes": ("désannoncer",),
    "désannonçât": ("désannoncer",),
    "désannoncée": ("désannoncer",),
    "désannoncées": ("désannoncer",),
    "désannoncé": ("désannoncer",),
    "désannoncent": ("désannoncer",),
    "désannonce": ("désannoncer",),
    "désannoncera": ("désannoncer",),
    "désannonceraient": ("désannoncer",),
    "désannoncerai": ("désannoncer",),
    "désannoncerais": ("désannoncer",),
    "désannoncerait": ("désannoncer",),
    "désannonceras": ("désannoncer",),
    "désannoncèrent": ("désannoncer",),
    "désannoncerez": ("désannoncer",),
    "désannonceriez": ("désannoncer",),
    "désannoncerions": ("désannoncer",),
    "désannoncerons": ("désannoncer",),
    "désannonceront": ("désannoncer",),
    "désannoncés": ("désannoncer",),
    "désannonces": ("désannoncer",),
    "désannoncez": ("désannoncer",),
    "désannonciez": ("désannoncer",),
    "désannoncions": ("désannoncer",),
    "désannonçons": ("désannoncer",),
    "désappariaient": ("désapparier",),
    "désappariai": ("désapparier",),
    "désappariais": ("désapparier",),
    "désappariait": ("désapparier",),
    "désapparia": ("désapparier",),
    "désappariâmes": ("désapparier",),
    "désappariant": ("désapparier",),
    "désapparias": ("désapparier",),
    "désappariassent": ("désapparier",),
    "désappariasses": ("désapparier",),
    "désappariasse": ("désapparier",),
    "désappariassiez": ("désapparier",),
    "désappariassions": ("désapparier",),
    "désappariâtes": ("désapparier",),
    "désappariât": ("désapparier",),
    "désappariée": ("désapparier",),
    "désappariées": ("désapparier",),
    "désapparié": ("désapparier",),
    "désapparient": ("désapparier",),
    "désapparie": ("désapparier",),
    "désappariera": ("désapparier",),
    "désapparieraient": ("désapparier",),
    "désapparierai": ("désapparier",),
    "désapparierais": ("désapparier",),
    "désapparierait": ("désapparier",),
    "désapparieras": ("désapparier",),
    "désapparièrent": ("désapparier",),
    "désapparierez": ("désapparier",),
    "désapparieriez": ("désapparier",),
    "désapparierions": ("désapparier",),
    "désapparierons": ("désapparier",),
    "désapparieront": ("désapparier",),
    "désappariés": ("désapparier",),
    "désapparies": ("désapparier",),
    "désappariez": ("désapparier",),
    "désappariiez": ("désapparier",),
    "désappariions": ("désapparier",),
    "désapparions": ("désapparier",),
    "désapprenaient": ("désapprendre",),
    "désapprenais": ("désapprendre",),
    "désapprenait": ("désapprendre",),
    "désapprenant": ("désapprendre",),
    "désapprend": ("désapprendre",),
    "désapprendra": ("désapprendre",),
    "désapprendraient": ("désapprendre",),
    "désapprendrai": ("désapprendre",),
    "désapprendrais": ("désapprendre",),
    "désapprendrait": ("désapprendre",),
    "désapprendras": ("désapprendre",),
    "désapprendrez": ("désapprendre",),
    "désapprendriez": ("désapprendre",),
    "désapprendrions": ("désapprendre",),
    "désapprendrons": ("désapprendre",),
    "désapprendront": ("désapprendre",),
    "désapprends": ("désapprendre",),
    "désapprenez": ("désapprendre",),
    "désappreniez": ("désapprendre",),
    "désapprenions": ("désapprendre",),
    "désapprennent": ("désapprendre",),
    "désapprenne": ("désapprendre",),
    "désapprennes": ("désapprendre",),
    "désapprenons": ("désapprendre",),
    "désapprîmes": ("désapprendre",),
    "désapprirent": ("désapprendre",),
    "désapprise": ("désapprendre",),
    "désapprises": ("désapprendre",),
    "désappris": ("désapprendre",),
    "désapprissent": ("désapprendre",),
    "désapprisses": ("désapprendre",),
    "désapprisse": ("désapprendre",),
    "désapprissiez": ("désapprendre",),
    "désapprissions": ("désapprendre",),
    "désapprîtes": ("désapprendre",),
    "désapprit": ("désapprendre",),
    "désapprît": ("désapprendre",),
    "désapprofondie": ("désapprofondir",),
    "désapprofondies": ("désapprofondir",),
    "désapprofondi": ("désapprofondir",),
    "désapprofondîmes": ("désapprofondir",),
    "désapprofondira": ("désapprofondir",),
    "désapprofondiraient": ("désapprofondir",),
    "désapprofondirai": ("désapprofondir",),
    "désapprofondirais": ("désapprofondir",),
    "désapprofondirait": ("désapprofondir",),
    "désapprofondiras": ("désapprofondir",),
    "désapprofondirent": ("désapprofondir",),
    "désapprofondirez": ("désapprofondir",),
    "désapprofondiriez": ("désapprofondir",),
    "désapprofondirions": ("désapprofondir",),
    "désapprofondirons": ("désapprofondir",),
    "désapprofondiront": ("désapprofondir",),
    "désapprofondis": ("désapprofondir",),
    "désapprofondissaient": ("désapprofondir",),
    "désapprofondissais": ("désapprofondir",),
    "désapprofondissait": ("désapprofondir",),
    "désapprofondissant": ("désapprofondir",),
    "désapprofondissent": ("désapprofondir",),
    "désapprofondisse": ("désapprofondir",),
    "désapprofondisses": ("désapprofondir",),
    "désapprofondissez": ("désapprofondir",),
    "désapprofondissiez": ("désapprofondir",),
    "désapprofondissions": ("désapprofondir",),
    "désapprofondissons": ("désapprofondir",),
    "désapprofondîtes": ("désapprofondir",),
    "désapprofondit": ("désapprofondir",),
    "désapprofondît": ("désapprofondir",),
    "désappropriaient": ("désapproprier",),
    "désappropriai": ("désapproprier",),
    "désappropriais": ("désapproprier",),
    "désappropriait": ("désapproprier",),
    "désappropria": ("désapproprier",),
    "désappropriâmes": ("désapproprier",),
    "désappropriant": ("désapproprier",),
    "désapproprias": ("désapproprier",),
    "désappropriassent": ("désapproprier",),
    "désappropriasses": ("désapproprier",),
    "désappropriasse": ("désapproprier",),
    "désappropriassiez": ("désapproprier",),
    "désappropriassions": ("désapproprier",),
    "désappropriâtes": ("désapproprier",),
    "désappropriât": ("désapproprier",),
    "désappropriée": ("désapproprier",),
    "désappropriées": ("désapproprier",),
    "désapproprié": ("désapproprier",),
    "désapproprient": ("désapproprier",),
    "désapproprie": ("désapproprier",),
    "désappropriera": ("désapproprier",),
    "désapproprieraient": ("désapproprier",),
    "désapproprierai": ("désapproprier",),
    "désapproprierais": ("désapproprier",),
    "désapproprierait": ("désapproprier",),
    "désapproprieras": ("désapproprier",),
    "désapproprièrent": ("désapproprier",),
    "désapproprierez": ("désapproprier",),
    "désapproprieriez": ("désapproprier",),
    "désapproprierions": ("désapproprier",),
    "désapproprierons": ("désapproprier",),
    "désapproprieront": ("désapproprier",),
    "désappropriés": ("désapproprier",),
    "désappropries": ("désapproprier",),
    "désappropriez": ("désapproprier",),
    "désappropriiez": ("désapproprier",),
    "désappropriions": ("désapproprier",),
    "désapproprions": ("désapproprier",),
    "désarrondie": ("désarrondir",),
    "désarrondies": ("désarrondir",),
    "désarrondi": ("désarrondir",),
    "désarrondîmes": ("désarrondir",),
    "désarrondira": ("désarrondir",),
    "désarrondiraient": ("désarrondir",),
    "désarrondirai": ("désarrondir",),
    "désarrondirais": ("désarrondir",),
    "désarrondirait": ("désarrondir",),
    "désarrondiras": ("désarrondir",),
    "désarrondirent": ("désarrondir",),
    "désarrondirez": ("désarrondir",),
    "désarrondiriez": ("désarrondir",),
    "désarrondirions": ("désarrondir",),
    "désarrondirons": ("désarrondir",),
    "désarrondiront": ("désarrondir",),
    "désarrondis": ("désarrondir",),
    "désarrondissaient": ("désarrondir",),
    "désarrondissais": ("désarrondir",),
    "désarrondissait": ("désarrondir",),
    "désarrondissant": ("désarrondir",),
    "désarrondissent": ("désarrondir",),
    "désarrondisse": ("désarrondir",),
    "désarrondisses": ("désarrondir",),
    "désarrondissez": ("désarrondir",),
    "désarrondissiez": ("désarrondir",),
    "désarrondissions": ("désarrondir",),
    "désarrondissons": ("désarrondir",),
    "désarrondîtes": ("désarrondir",),
    "désarrondit": ("désarrondir",),
    "désarrondît": ("désarrondir",),
    "désassociaient": ("désassocier",),
    "désassociai": ("désassocier",),
    "désassociais": ("désassocier",),
    "désassociait": ("désassocier",),
    "désassocia": ("désassocier",),
    "désassociâmes": ("désassocier",),
    "désassociant": ("désassocier",),
    "désassocias": ("désassocier",),
    "désassociassent": ("désassocier",),
    "désassociasses": ("désassocier",),
    "désassociasse": ("désassocier",),
    "désassociassiez": ("désassocier",),
    "désassociassions": ("désassocier",),
    "désassociâtes": ("désassocier",),
    "désassociât": ("désassocier",),
    "désassociée": ("désassocier",),
    "désassociées": ("désassocier",),
    "désassocié": ("désassocier",),
    "désassocient": ("désassocier",),
    "désassocie": ("désassocier",),
    "désassociera": ("désassocier",),
    "désassocieraient": ("désassocier",),
    "désassocierai": ("désassocier",),
    "désassocierais": ("désassocier",),
    "désassocierait": ("désassocier",),
    "désassocieras": ("désassocier",),
    "désassocièrent": ("désassocier",),
    "désassocierez": ("désassocier",),
    "désassocieriez": ("désassocier",),
    "désassocierions": ("désassocier",),
    "désassocierons": ("désassocier",),
    "désassocieront": ("désassocier",),
    "désassociés": ("désassocier",),
    "désassocies": ("désassocier",),
    "désassociez": ("désassocier",),
    "désassociiez": ("désassocier",),
    "désassociions": ("désassocier",),
    "désassocions": ("désassocier",),
    "désassombrie": ("désassombrir",),
    "désassombries": ("désassombrir",),
    "désassombri": ("désassombrir",),
    "désassombrîmes": ("désassombrir",),
    "désassombrira": ("désassombrir",),
    "désassombriraient": ("désassombrir",),
    "désassombrirai": ("désassombrir",),
    "désassombrirais": ("désassombrir",),
    "désassombrirait": ("désassombrir",),
    "désassombriras": ("désassombrir",),
    "désassombrirent": ("désassombrir",),
    "désassombrirez": ("désassombrir",),
    "désassombririez": ("désassombrir",),
    "désassombririons": ("désassombrir",),
    "désassombrirons": ("désassombrir",),
    "désassombriront": ("désassombrir",),
    "désassombris": ("désassombrir",),
    "désassombrissaient": ("désassombrir",),
    "désassombrissais": ("désassombrir",),
    "désassombrissait": ("désassombrir",),
    "désassombrissant": ("désassombrir",),
    "désassombrissent": ("désassombrir",),
    "désassombrisse": ("désassombrir",),
    "désassombrisses": ("désassombrir",),
    "désassombrissez": ("désassombrir",),
    "désassombrissiez": ("désassombrir",),
    "désassombrissions": ("désassombrir",),
    "désassombrissons": ("désassombrir",),
    "désassombrîtes": ("désassombrir",),
    "désassombrit": ("désassombrir",),
    "désassombrît": ("désassombrir",),
    "désassortie": ("désassortir",),
    "désassorties": ("désassortir",),
    "désassorti": ("désassortir",),
    "désassortîmes": ("désassortir",),
    "désassortira": ("désassortir",),
    "désassortiraient": ("désassortir",),
    "désassortirai": ("désassortir",),
    "désassortirais": ("désassortir",),
    "désassortirait": ("désassortir",),
    "désassortiras": ("désassortir",),
    "désassortirent": ("désassortir",),
    "désassortirez": ("désassortir",),
    "désassortiriez": ("désassortir",),
    "désassortirions": ("désassortir",),
    "désassortirons": ("désassortir",),
    "désassortiront": ("désassortir",),
    "désassortis": ("désassortir",),
    "désassortissaient": ("désassortir",),
    "désassortissais": ("désassortir",),
    "désassortissait": ("désassortir",),
    "désassortissant": ("désassortir",),
    "désassortissent": ("désassortir",),
    "désassortisse": ("désassortir",),
    "désassortisses": ("désassortir",),
    "désassortissez": ("désassortir",),
    "désassortissiez": ("désassortir",),
    "désassortissions": ("désassortir",),
    "désassortissons": ("désassortir",),
    "désassortîtes": ("désassortir",),
    "désassortit": ("désassortir",),
    "désassortît": ("désassortir",),
    "désassoupie": ("désassoupir",),
    "désassoupies": ("désassoupir",),
    "désassoupi": ("désassoupir",),
    "désassoupîmes": ("désassoupir",),
    "désassoupira": ("désassoupir",),
    "désassoupiraient": ("désassoupir",),
    "désassoupirai": ("désassoupir",),
    "désassoupirais": ("désassoupir",),
    "désassoupirait": ("désassoupir",),
    "désassoupiras": ("désassoupir",),
    "désassoupirent": ("désassoupir",),
    "désassoupirez": ("désassoupir",),
    "désassoupiriez": ("désassoupir",),
    "désassoupirions": ("désassoupir",),
    "désassoupirons": ("désassoupir",),
    "désassoupiront": ("désassoupir",),
    "désassoupis": ("désassoupir",),
    "désassoupissaient": ("désassoupir",),
    "désassoupissais": ("désassoupir",),
    "désassoupissait": ("désassoupir",),
    "désassoupissant": ("désassoupir",),
    "désassoupissent": ("désassoupir",),
    "désassoupisse": ("désassoupir",),
    "désassoupisses": ("désassoupir",),
    "désassoupissez": ("désassoupir",),
    "désassoupissiez": ("désassoupir",),
    "désassoupissions": ("désassoupir",),
    "désassoupissons": ("désassoupir",),
    "désassoupîtes": ("désassoupir",),
    "désassoupit": ("désassoupir",),
    "désassoupît": ("désassoupir",),
    "désassujettie": ("désassujettir",),
    "désassujetties": ("désassujettir",),
    "désassujetti": ("désassujettir",),
    "désassujettîmes": ("désassujettir",),
    "désassujettira": ("désassujettir",),
    "désassujettiraient": ("désassujettir",),
    "désassujettirai": ("désassujettir",),
    "désassujettirais": ("désassujettir",),
    "désassujettirait": ("désassujettir",),
    "désassujettiras": ("désassujettir",),
    "désassujettirent": ("désassujettir",),
    "désassujettirez": ("désassujettir",),
    "désassujettiriez": ("désassujettir",),
    "désassujettirions": ("désassujettir",),
    "désassujettirons": ("désassujettir",),
    "désassujettiront": ("désassujettir",),
    "désassujettis": ("désassujettir",),
    "désassujettissaient": ("désassujettir",),
    "désassujettissais": ("désassujettir",),
    "désassujettissait": ("désassujettir",),
    "désassujettissant": ("désassujettir",),
    "désassujettissent": ("désassujettir",),
    "désassujettisse": ("désassujettir",),
    "désassujettisses": ("désassujettir",),
    "désassujettissez": ("désassujettir",),
    "désassujettissiez": ("désassujettir",),
    "désassujettissions": ("désassujettir",),
    "désassujettissons": ("désassujettir",),
    "désassujettîtes": ("désassujettir",),
    "désassujettit": ("désassujettir",),
    "désassujettît": ("désassujettir",),
    "désaubiéraient": ("désaubiérer",),
    "désaubiérai": ("désaubiérer",),
    "désaubiérais": ("désaubiérer",),
    "désaubiérait": ("désaubiérer",),
    "désaubiéra": ("désaubiérer",),
    "désaubiérâmes": ("désaubiérer",),
    "désaubiérant": ("désaubiérer",),
    "désaubiéras": ("désaubiérer",),
    "désaubiérassent": ("désaubiérer",),
    "désaubiérasses": ("désaubiérer",),
    "désaubiérasse": ("désaubiérer",),
    "désaubiérassiez": ("désaubiérer",),
    "désaubiérassions": ("désaubiérer",),
    "désaubiérâtes": ("désaubiérer",),
    "désaubiérât": ("désaubiérer",),
    "désaubiérée": ("désaubiérer",),
    "désaubiérées": ("désaubiérer",),
    "désaubiéré": ("désaubiérer",),
    "désaubièrent": ("désaubiérer",),
    "désaubière": ("désaubiérer",),
    "désaubiérera": ("désaubiérer",),
    "désaubiéreraient": ("désaubiérer",),
    "désaubiérerai": ("désaubiérer",),
    "désaubiérerais": ("désaubiérer",),
    "désaubiérerait": ("désaubiérer",),
    "désaubiéreras": ("désaubiérer",),
    "désaubiérèrent": ("désaubiérer",),
    "désaubiérerez": ("désaubiérer",),
    "désaubiéreriez": ("désaubiérer",),
    "désaubiérerions": ("désaubiérer",),
    "désaubiérerons": ("désaubiérer",),
    "désaubiéreront": ("désaubiérer",),
    "désaubiérés": ("désaubiérer",),
    "désaubières": ("désaubiérer",),
    "désaubiérez": ("désaubiérer",),
    "désaubiériez": ("désaubiérer",),
    "désaubiérions": ("désaubiérer",),
    "désaubiérons": ("désaubiérer",),
    "désavantageaient": ("désavantager",),
    "désavantageai": ("désavantager",),
    "désavantageais": ("désavantager",),
    "désavantageait": ("désavantager",),
    "désavantagea": ("désavantager",),
    "désavantageâmes": ("désavantager",),
    "désavantageant": ("désavantager",),
    "désavantageas": ("désavantager",),
    "désavantageassent": ("désavantager",),
    "désavantageasses": ("désavantager",),
    "désavantageasse": ("désavantager",),
    "désavantageassiez": ("désavantager",),
    "désavantageassions": ("désavantager",),
    "désavantageâtes": ("désavantager",),
    "désavantageât": ("désavantager",),
    "désavantagée": ("désavantager",),
    "désavantagées": ("désavantager",),
    "désavantagé": ("désavantager",),
    "désavantagent": ("désavantager",),
    "désavantageons": ("désavantager",),
    "désavantage": ("désavantager",),
    "désavantagera": ("désavantager",),
    "désavantageraient": ("désavantager",),
    "désavantagerai": ("désavantager",),
    "désavantagerais": ("désavantager",),
    "désavantagerait": ("désavantager",),
    "désavantageras": ("désavantager",),
    "désavantagèrent": ("désavantager",),
    "désavantagerez": ("désavantager",),
    "désavantageriez": ("désavantager",),
    "désavantagerions": ("désavantager",),
    "désavantagerons": ("désavantager",),
    "désavantageront": ("désavantager",),
    "désavantagés": ("désavantager",),
    "désavantages": ("désavantager",),
    "désavantagez": ("désavantager",),
    "désavantagiez": ("désavantager",),
    "désavantagions": ("désavantager",),
    "descendaient": ("descendre",),
    "descendais": ("descendre",),
    "descendait": ("descendre",),
    "descendant": ("descendre",),
    "descendent": ("descendre",),
    "descende": ("descendre",),
    "descendes": ("descendre",),
    "descendez": ("descendre",),
    "descendiez": ("descendre",),
    "descendîmes": ("descendre",),
    "descendions": ("descendre",),
    "descendirent": ("descendre",),
    "descendis": ("descendre",),
    "descendissent": ("descendre",),
    "descendisses": ("descendre",),
    "descendisse": ("descendre",),
    "descendissiez": ("descendre",),
    "descendissions": ("descendre",),
    "descendîtes": ("descendre",),
    "descendit": ("descendre",),
    "descendît": ("descendre",),
    "descendons": ("descendre",),
    "descend": ("descendre",),
    "descendra": ("descendre",),
    "descendraient": ("descendre",),
    "descendrai": ("descendre",),
    "descendrais": ("descendre",),
    "descendrait": ("descendre",),
    "descendras": ("descendre",),
    "descendrez": ("descendre",),
    "descendriez": ("descendre",),
    "descendrions": ("descendre",),
    "descendrons": ("descendre",),
    "descendront": ("descendre",),
    "descends": ("descendre",),
    "descendue": ("descendre",),
    "descendues": ("descendre",),
    "descendu": ("descendre",),
    "descendus": ("descendre",),
    "déséchalassaient": ("déséchalasser",),
    "déséchalassai": ("déséchalasser",),
    "déséchalassais": ("déséchalasser",),
    "déséchalassait": ("déséchalasser",),
    "déséchalassa": ("déséchalasser",),
    "déséchalassâmes": ("déséchalasser",),
    "déséchalassant": ("déséchalasser",),
    "déséchalassas": ("déséchalasser",),
    "déséchalassassent": ("déséchalasser",),
    "déséchalassasses": ("déséchalasser",),
    "déséchalassasse": ("déséchalasser",),
    "déséchalassassiez": ("déséchalasser",),
    "déséchalassassions": ("déséchalasser",),
    "déséchalassâtes": ("déséchalasser",),
    "déséchalassât": ("déséchalasser",),
    "déséchalassée": ("déséchalasser",),
    "déséchalassées": ("déséchalasser",),
    "déséchalassé": ("déséchalasser",),
    "déséchalassent": ("déséchalasser",),
    "déséchalasse": ("déséchalasser",),
    "déséchalassera": ("déséchalasser",),
    "déséchalasseraient": ("déséchalasser",),
    "déséchalasserai": ("déséchalasser",),
    "déséchalasserais": ("déséchalasser",),
    "déséchalasserait": ("déséchalasser",),
    "déséchalasseras": ("déséchalasser",),
    "déséchalassèrent": ("déséchalasser",),
    "déséchalasserez": ("déséchalasser",),
    "déséchalasseriez": ("déséchalasser",),
    "déséchalasserions": ("déséchalasser",),
    "déséchalasserons": ("déséchalasser",),
    "déséchalasseront": ("déséchalasser",),
    "déséchalassés": ("déséchalasser",),
    "déséchalasses": ("déséchalasser",),
    "déséchalassez": ("déséchalasser",),
    "déséchalassiez": ("déséchalasser",),
    "déséchalassions": ("déséchalasser",),
    "déséchalassons": ("déséchalasser",),
    "déségréguaient": ("déségréguer",),
    "déségréguai": ("déségréguer",),
    "déségréguais": ("déségréguer",),
    "déségréguait": ("déségréguer",),
    "déségrégua": ("déségréguer",),
    "déségréguâmes": ("déségréguer",),
    "déségréguant": ("déségréguer",),
    "déségréguas": ("déségréguer",),
    "déségréguassent": ("déségréguer",),
    "déségréguasses": ("déségréguer",),
    "déségréguasse": ("déségréguer",),
    "déségréguassiez": ("déségréguer",),
    "déségréguassions": ("déségréguer",),
    "déségréguâtes": ("déségréguer",),
    "déségréguât": ("déségréguer",),
    "déségréguée": ("déségréguer",),
    "déségréguées": ("déségréguer",),
    "déségrégué": ("déségréguer",),
    "déségrèguent": ("déségréguer",),
    "déségrègue": ("déségréguer",),
    "déségréguera": ("déségréguer",),
    "déségrégueraient": ("déségréguer",),
    "déségréguerai": ("déségréguer",),
    "déségréguerais": ("déségréguer",),
    "déségréguerait": ("déségréguer",),
    "déségrégueras": ("déségréguer",),
    "déségréguèrent": ("déségréguer",),
    "déségréguerez": ("déségréguer",),
    "déségrégueriez": ("déségréguer",),
    "déségréguerions": ("déségréguer",),
    "déségréguerons": ("déségréguer",),
    "déségrégueront": ("déségréguer",),
    "déségrégués": ("déségréguer",),
    "déségrègues": ("déségréguer",),
    "déségréguez": ("déségréguer",),
    "déségréguiez": ("déségréguer",),
    "déségréguions": ("déségréguer",),
    "déségréguons": ("déségréguer",),
    "désembarrassaient": ("désembarrasser",),
    "désembarrassai": ("désembarrasser",),
    "désembarrassais": ("désembarrasser",),
    "désembarrassait": ("désembarrasser",),
    "désembarrassa": ("désembarrasser",),
    "désembarrassâmes": ("désembarrasser",),
    "désembarrassant": ("désembarrasser",),
    "désembarrassas": ("désembarrasser",),
    "désembarrassassent": ("désembarrasser",),
    "désembarrassasses": ("désembarrasser",),
    "désembarrassasse": ("désembarrasser",),
    "désembarrassassiez": ("désembarrasser",),
    "désembarrassassions": ("désembarrasser",),
    "désembarrassâtes": ("désembarrasser",),
    "désembarrassât": ("désembarrasser",),
    "désembarrassée": ("désembarrasser",),
    "désembarrassées": ("désembarrasser",),
    "désembarrassé": ("désembarrasser",),
    "désembarrassent": ("désembarrasser",),
    "désembarrasse": ("désembarrasser",),
    "désembarrassera": ("désembarrasser",),
    "désembarrasseraient": ("désembarrasser",),
    "désembarrasserai": ("désembarrasser",),
    "désembarrasserais": ("désembarrasser",),
    "désembarrasserait": ("désembarrasser",),
    "désembarrasseras": ("désembarrasser",),
    "désembarrassèrent": ("désembarrasser",),
    "désembarrasserez": ("désembarrasser",),
    "désembarrasseriez": ("désembarrasser",),
    "désembarrasserions": ("désembarrasser",),
    "désembarrasserons": ("désembarrasser",),
    "désembarrasseront": ("désembarrasser",),
    "désembarrassés": ("désembarrasser",),
    "désembarrasses": ("désembarrasser",),
    "désembarrassez": ("désembarrasser",),
    "désembarrassiez": ("désembarrasser",),
    "désembarrassions": ("désembarrasser",),
    "désembarrassons": ("désembarrasser",),
    "désembat": ("désembattre",),
    "désembats": ("désembattre",),
    "désembattaient": ("désembattre",),
    "désembattais": ("désembattre",),
    "désembattait": ("désembattre",),
    "désembattant": ("désembattre",),
    "désembattent": ("désembattre",),
    "désembatte": ("désembattre",),
    "désembattes": ("désembattre",),
    "désembattez": ("désembattre",),
    "désembattiez": ("désembattre",),
    "désembattîmes": ("désembattre",),
    "désembattions": ("désembattre",),
    "désembattirent": ("désembattre",),
    "désembattis": ("désembattre",),
    "désembattissent": ("désembattre",),
    "désembattisses": ("désembattre",),
    "désembattisse": ("désembattre",),
    "désembattissiez": ("désembattre",),
    "désembattissions": ("désembattre",),
    "désembattîtes": ("désembattre",),
    "désembattit": ("désembattre",),
    "désembattît": ("désembattre",),
    "désembattons": ("désembattre",),
    "désembattra": ("désembattre",),
    "désembattraient": ("désembattre",),
    "désembattrai": ("désembattre",),
    "désembattrais": ("désembattre",),
    "désembattrait": ("désembattre",),
    "désembattras": ("désembattre",),
    "désembattrez": ("désembattre",),
    "désembattriez": ("désembattre",),
    "désembattrions": ("désembattre",),
    "désembattrons": ("désembattre",),
    "désembattront": ("désembattre",),
    "désembattue": ("désembattre",),
    "désembattues": ("désembattre",),
    "désembattu": ("désembattre",),
    "désembattus": ("désembattre",),
    "désemboutie": ("désemboutir",),
    "désembouties": ("désemboutir",),
    "désembouti": ("désemboutir",),
    "désemboutîmes": ("désemboutir",),
    "désemboutira": ("désemboutir",),
    "désemboutiraient": ("désemboutir",),
    "désemboutirai": ("désemboutir",),
    "désemboutirais": ("désemboutir",),
    "désemboutirait": ("désemboutir",),
    "désemboutiras": ("désemboutir",),
    "désemboutirent": ("désemboutir",),
    "désemboutirez": ("désemboutir",),
    "désemboutiriez": ("désemboutir",),
    "désemboutirions": ("désemboutir",),
    "désemboutirons": ("désemboutir",),
    "désemboutiront": ("désemboutir",),
    "désemboutis": ("désemboutir",),
    "désemboutissaient": ("désemboutir",),
    "désemboutissais": ("désemboutir",),
    "désemboutissait": ("désemboutir",),
    "désemboutissant": ("désemboutir",),
    "désemboutissent": ("désemboutir",),
    "désemboutisse": ("désemboutir",),
    "désemboutisses": ("désemboutir",),
    "désemboutissez": ("désemboutir",),
    "désemboutissiez": ("désemboutir",),
    "désemboutissions": ("désemboutir",),
    "désemboutissons": ("désemboutir",),
    "désemboutîtes": ("désemboutir",),
    "désemboutit": ("désemboutir",),
    "désemboutît": ("désemboutir",),
    "désembraient": ("désembrayer",),
    "désembraie": ("désembrayer",),
    "désembraiera": ("désembrayer",),
    "désembraieraient": ("désembrayer",),
    "désembraierai": ("désembrayer",),
    "désembraierais": ("désembrayer",),
    "désembraierait": ("désembrayer",),
    "désembraieras": ("désembrayer",),
    "désembraierez": ("désembrayer",),
    "désembraieriez": ("désembrayer",),
    "désembraierions": ("désembrayer",),
    "désembraierons": ("désembrayer",),
    "désembraieront": ("désembrayer",),
    "désembraies": ("désembrayer",),
    "désembrayaient": ("désembrayer",),
    "désembrayai": ("désembrayer",),
    "désembrayais": ("désembrayer",),
    "désembrayait": ("désembrayer",),
    "désembraya": ("désembrayer",),
    "désembrayâmes": ("désembrayer",),
    "désembrayant": ("désembrayer",),
    "désembrayas": ("désembrayer",),
    "désembrayassent": ("désembrayer",),
    "désembrayasses": ("désembrayer",),
    "désembrayasse": ("désembrayer",),
    "désembrayassiez": ("désembrayer",),
    "désembrayassions": ("désembrayer",),
    "désembrayâtes": ("désembrayer",),
    "désembrayât": ("désembrayer",),
    "désembrayée": ("désembrayer",),
    "désembrayées": ("désembrayer",),
    "désembrayé": ("désembrayer",),
    "désembrayent": ("désembrayer",),
    "désembraye": ("désembrayer",),
    "désembrayera": ("désembrayer",),
    "désembrayeraient": ("désembrayer",),
    "désembrayerai": ("désembrayer",),
    "désembrayerais": ("désembrayer",),
    "désembrayerait": ("désembrayer",),
    "désembrayeras": ("désembrayer",),
    "désembrayèrent": ("désembrayer",),
    "désembrayerez": ("désembrayer",),
    "désembrayeriez": ("désembrayer",),
    "désembrayerions": ("désembrayer",),
    "désembrayerons": ("désembrayer",),
    "désembrayeront": ("désembrayer",),
    "désembrayés": ("désembrayer",),
    "désembrayes": ("désembrayer",),
    "désembrayez": ("désembrayer",),
    "désembrayiez": ("désembrayer",),
    "désembrayions": ("désembrayer",),
    "désembrayons": ("désembrayer",),
    "désembrunie": ("désembrunir",),
    "désembrunies": ("désembrunir",),
    "désembruni": ("désembrunir",),
    "désembrunîmes": ("désembrunir",),
    "désembrunira": ("désembrunir",),
    "désembruniraient": ("désembrunir",),
    "désembrunirai": ("désembrunir",),
    "désembrunirais": ("désembrunir",),
    "désembrunirait": ("désembrunir",),
    "désembruniras": ("désembrunir",),
    "désembrunirent": ("désembrunir",),
    "désembrunirez": ("désembrunir",),
    "désembruniriez": ("désembrunir",),
    "désembrunirions": ("désembrunir",),
    "désembrunirons": ("désembrunir",),
    "désembruniront": ("désembrunir",),
    "désembrunis": ("désembrunir",),
    "désembrunissaient": ("désembrunir",),
    "désembrunissais": ("désembrunir",),
    "désembrunissait": ("désembrunir",),
    "désembrunissant": ("désembrunir",),
    "désembrunissent": ("désembrunir",),
    "désembrunisse": ("désembrunir",),
    "désembrunisses": ("désembrunir",),
    "désembrunissez": ("désembrunir",),
    "désembrunissiez": ("désembrunir",),
    "désembrunissions": ("désembrunir",),
    "désembrunissons": ("désembrunir",),
    "désembrunîtes": ("désembrunir",),
    "désembrunit": ("désembrunir",),
    "désembrunît": ("désembrunir",),
    "désempaquetaient": ("désempaqueter",),
    "désempaquetai": ("désempaqueter",),
    "désempaquetais": ("désempaqueter",),
    "désempaquetait": ("désempaqueter",),
    "désempaqueta": ("désempaqueter",),
    "désempaquetâmes": ("désempaqueter",),
    "désempaquetant": ("désempaqueter",),
    "désempaquetas": ("désempaqueter",),
    "désempaquetassent": ("désempaqueter",),
    "désempaquetasses": ("désempaqueter",),
    "désempaquetasse": ("désempaqueter",),
    "désempaquetassiez": ("désempaqueter",),
    "désempaquetassions": ("désempaqueter",),
    "désempaquetâtes": ("désempaqueter",),
    "désempaquetât": ("désempaqueter",),
    "désempaquetée": ("désempaqueter",),
    "désempaquetées": ("désempaqueter",),
    "désempaqueté": ("désempaqueter",),
    "désempaquetèrent": ("désempaqueter",),
    "désempaquetés": ("désempaqueter",),
    "désempaquetez": ("désempaqueter",),
    "désempaquetiez": ("désempaqueter",),
    "désempaquetions": ("désempaqueter",),
    "désempaquetons": ("désempaqueter",),
    "désempaquettent": ("désempaqueter",),
    "désempaquette": ("désempaqueter",),
    "désempaquettera": ("désempaqueter",),
    "désempaquetteraient": ("désempaqueter",),
    "désempaquetterai": ("désempaqueter",),
    "désempaquetterais": ("désempaqueter",),
    "désempaquetterait": ("désempaqueter",),
    "désempaquetteras": ("désempaqueter",),
    "désempaquetterez": ("désempaqueter",),
    "désempaquetteriez": ("désempaqueter",),
    "désempaquetterions": ("désempaqueter",),
    "désempaquetterons": ("désempaqueter",),
    "désempaquetteront": ("désempaqueter",),
    "désempaquettes": ("désempaqueter",),
    "désempesaient": ("désempeser",),
    "désempesai": ("désempeser",),
    "désempesais": ("désempeser",),
    "désempesait": ("désempeser",),
    "désempesa": ("désempeser",),
    "désempesâmes": ("désempeser",),
    "désempesant": ("désempeser",),
    "désempesas": ("désempeser",),
    "désempesassent": ("désempeser",),
    "désempesasses": ("désempeser",),
    "désempesasse": ("désempeser",),
    "désempesassiez": ("désempeser",),
    "désempesassions": ("désempeser",),
    "désempesâtes": ("désempeser",),
    "désempesât": ("désempeser",),
    "désempesée": ("désempeser",),
    "désempesées": ("désempeser",),
    "désempesé": ("désempeser",),
    "désempèsent": ("désempeser",),
    "désempèse": ("désempeser",),
    "désempèsera": ("désempeser",),
    "désempèseraient": ("désempeser",),
    "désempèserai": ("désempeser",),
    "désempèserais": ("désempeser",),
    "désempèserait": ("désempeser",),
    "désempèseras": ("désempeser",),
    "désempesèrent": ("désempeser",),
    "désempèserez": ("désempeser",),
    "désempèseriez": ("désempeser",),
    "désempèserions": ("désempeser",),
    "désempèserons": ("désempeser",),
    "désempèseront": ("désempeser",),
    "désempesés": ("désempeser",),
    "désempèses": ("désempeser",),
    "désempesez": ("désempeser",),
    "désempesiez": ("désempeser",),
    "désempesions": ("désempeser",),
    "désempesons": ("désempeser",),
    "désemplie": ("désemplir",),
    "désemplies": ("désemplir",),
    "désempli": ("désemplir",),
    "désemplîmes": ("désemplir",),
    "désemplira": ("désemplir",),
    "désempliraient": ("désemplir",),
    "désemplirai": ("désemplir",),
    "désemplirais": ("désemplir",),
    "désemplirait": ("désemplir",),
    "désempliras": ("désemplir",),
    "désemplirent": ("désemplir",),
    "désemplirez": ("désemplir",),
    "désempliriez": ("désemplir",),
    "désemplirions": ("désemplir",),
    "désemplirons": ("désemplir",),
    "désempliront": ("désemplir",),
    "désemplis": ("désemplir",),
    "désemplissaient": ("désemplir",),
    "désemplissais": ("désemplir",),
    "désemplissait": ("désemplir",),
    "désemplissant": ("désemplir",),
    "désemplissent": ("désemplir",),
    "désemplisse": ("désemplir",),
    "désemplisses": ("désemplir",),
    "désemplissez": ("désemplir",),
    "désemplissiez": ("désemplir",),
    "désemplissions": ("désemplir",),
    "désemplissons": ("désemplir",),
    "désemplîtes": ("désemplir",),
    "désemplit": ("désemplir",),
    "désemplît": ("désemplir",),
    "désempoussiéraient": ("désempoussiérer",),
    "désempoussiérai": ("désempoussiérer",),
    "désempoussiérais": ("désempoussiérer",),
    "désempoussiérait": ("désempoussiérer",),
    "désempoussiéra": ("désempoussiérer",),
    "désempoussiérâmes": ("désempoussiérer",),
    "désempoussiérant": ("désempoussiérer",),
    "désempoussiéras": ("désempoussiérer",),
    "désempoussiérassent": ("désempoussiérer",),
    "désempoussiérasses": ("désempoussiérer",),
    "désempoussiérasse": ("désempoussiérer",),
    "désempoussiérassiez": ("désempoussiérer",),
    "désempoussiérassions": ("désempoussiérer",),
    "désempoussiérâtes": ("désempoussiérer",),
    "désempoussiérât": ("désempoussiérer",),
    "désempoussiérée": ("désempoussiérer",),
    "désempoussiérées": ("désempoussiérer",),
    "désempoussiéré": ("désempoussiérer",),
    "désempoussièrent": ("désempoussiérer",),
    "désempoussière": ("désempoussiérer",),
    "désempoussiérera": ("désempoussiérer",),
    "désempoussiéreraient": ("désempoussiérer",),
    "désempoussiérerai": ("désempoussiérer",),
    "désempoussiérerais": ("désempoussiérer",),
    "désempoussiérerait": ("désempoussiérer",),
    "désempoussiéreras": ("désempoussiérer",),
    "désempoussiérèrent": ("désempoussiérer",),
    "désempoussiérerez": ("désempoussiérer",),
    "désempoussiéreriez": ("désempoussiérer",),
    "désempoussiérerions": ("désempoussiérer",),
    "désempoussiérerons": ("désempoussiérer",),
    "désempoussiéreront": ("désempoussiérer",),
    "désempoussiérés": ("désempoussiérer",),
    "désempoussières": ("désempoussiérer",),
    "désempoussiérez": ("désempoussiérer",),
    "désempoussiériez": ("désempoussiérer",),
    "désempoussiérions": ("désempoussiérer",),
    "désempoussiérons": ("désempoussiérer",),
    "désémulsifiaient": ("désémulsifier",),
    "désémulsifiai": ("désémulsifier",),
    "désémulsifiais": ("désémulsifier",),
    "désémulsifiait": ("désémulsifier",),
    "désémulsifia": ("désémulsifier",),
    "désémulsifiâmes": ("désémulsifier",),
    "désémulsifiant": ("désémulsifier",),
    "désémulsifias": ("désémulsifier",),
    "désémulsifiassent": ("désémulsifier",),
    "désémulsifiasses": ("désémulsifier",),
    "désémulsifiasse": ("désémulsifier",),
    "désémulsifiassiez": ("désémulsifier",),
    "désémulsifiassions": ("désémulsifier",),
    "désémulsifiâtes": ("désémulsifier",),
    "désémulsifiât": ("désémulsifier",),
    "désémulsifiée": ("désémulsifier",),
    "désémulsifiées": ("désémulsifier",),
    "désémulsifié": ("désémulsifier",),
    "désémulsifient": ("désémulsifier",),
    "désémulsifie": ("désémulsifier",),
    "désémulsifiera": ("désémulsifier",),
    "désémulsifieraient": ("désémulsifier",),
    "désémulsifierai": ("désémulsifier",),
    "désémulsifierais": ("désémulsifier",),
    "désémulsifierait": ("désémulsifier",),
    "désémulsifieras": ("désémulsifier",),
    "désémulsifièrent": ("désémulsifier",),
    "désémulsifierez": ("désémulsifier",),
    "désémulsifieriez": ("désémulsifier",),
    "désémulsifierions": ("désémulsifier",),
    "désémulsifierons": ("désémulsifier",),
    "désémulsifieront": ("désémulsifier",),
    "désémulsifiés": ("désémulsifier",),
    "désémulsifies": ("désémulsifier",),
    "désémulsifiez": ("désémulsifier",),
    "désémulsifiiez": ("désémulsifier",),
    "désémulsifiions": ("désémulsifier",),
    "désémulsifions": ("désémulsifier",),
    "désencageaient": ("désencager",),
    "désencageai": ("désencager",),
    "désencageais": ("désencager",),
    "désencageait": ("désencager",),
    "désencagea": ("désencager",),
    "désencageâmes": ("désencager",),
    "désencageant": ("désencager",),
    "désencageas": ("désencager",),
    "désencageassent": ("désencager",),
    "désencageasses": ("désencager",),
    "désencageasse": ("désencager",),
    "désencageassiez": ("désencager",),
    "désencageassions": ("désencager",),
    "désencageâtes": ("désencager",),
    "désencageât": ("désencager",),
    "désencagée": ("désencager",),
    "désencagées": ("désencager",),
    "désencagé": ("désencager",),
    "désencagent": ("désencager",),
    "désencageons": ("désencager",),
    "désencage": ("désencager",),
    "désencagera": ("désencager",),
    "désencageraient": ("désencager",),
    "désencagerai": ("désencager",),
    "désencagerais": ("désencager",),
    "désencagerait": ("désencager",),
    "désencageras": ("désencager",),
    "désencagèrent": ("désencager",),
    "désencagerez": ("désencager",),
    "désencageriez": ("désencager",),
    "désencagerions": ("désencager",),
    "désencagerons": ("désencager",),
    "désencageront": ("désencager",),
    "désencagés": ("désencager",),
    "désencages": ("désencager",),
    "désencagez": ("désencager",),
    "désencagiez": ("désencager",),
    "désencagions": ("désencager",),
    "désenchifrenaient": ("désenchifrener",),
    "désenchifrenai": ("désenchifrener",),
    "désenchifrenais": ("désenchifrener",),
    "désenchifrenait": ("désenchifrener",),
    "désenchifrena": ("désenchifrener",),
    "désenchifrenâmes": ("désenchifrener",),
    "désenchifrenant": ("désenchifrener",),
    "désenchifrenas": ("désenchifrener",),
    "désenchifrenassent": ("désenchifrener",),
    "désenchifrenasses": ("désenchifrener",),
    "désenchifrenasse": ("désenchifrener",),
    "désenchifrenassiez": ("désenchifrener",),
    "désenchifrenassions": ("désenchifrener",),
    "désenchifrenâtes": ("désenchifrener",),
    "désenchifrenât": ("désenchifrener",),
    "désenchifrenée": ("désenchifrener",),
    "désenchifrenées": ("désenchifrener",),
    "désenchifrené": ("désenchifrener",),
    "désenchifrènent": ("désenchifrener",),
    "désenchifrène": ("désenchifrener",),
    "désenchifrènera": ("désenchifrener",),
    "désenchifrèneraient": ("désenchifrener",),
    "désenchifrènerai": ("désenchifrener",),
    "désenchifrènerais": ("désenchifrener",),
    "désenchifrènerait": ("désenchifrener",),
    "désenchifrèneras": ("désenchifrener",),
    "désenchifrenèrent": ("désenchifrener",),
    "désenchifrènerez": ("désenchifrener",),
    "désenchifrèneriez": ("désenchifrener",),
    "désenchifrènerions": ("désenchifrener",),
    "désenchifrènerons": ("désenchifrener",),
    "désenchifrèneront": ("désenchifrener",),
    "désenchifrenés": ("désenchifrener",),
    "désenchifrènes": ("désenchifrener",),
    "désenchifrenez": ("désenchifrener",),
    "désenchifreniez": ("désenchifrener",),
    "désenchifrenions": ("désenchifrener",),
    "désenchifrenons": ("désenchifrener",),
    "désencliquetaient": ("désencliqueter",),
    "désencliquetai": ("désencliqueter",),
    "désencliquetais": ("désencliqueter",),
    "désencliquetait": ("désencliqueter",),
    "désencliqueta": ("désencliqueter",),
    "désencliquetâmes": ("désencliqueter",),
    "désencliquetant": ("désencliqueter",),
    "désencliquetas": ("désencliqueter",),
    "désencliquetassent": ("désencliqueter",),
    "désencliquetasses": ("désencliqueter",),
    "désencliquetasse": ("désencliqueter",),
    "désencliquetassiez": ("désencliqueter",),
    "désencliquetassions": ("désencliqueter",),
    "désencliquetâtes": ("désencliqueter",),
    "désencliquetât": ("désencliqueter",),
    "désencliquetée": ("désencliqueter",),
    "désencliquetées": ("désencliqueter",),
    "désencliqueté": ("désencliqueter",),
    "désencliquetèrent": ("désencliqueter",),
    "désencliquetés": ("désencliqueter",),
    "désencliquetez": ("désencliqueter",),
    "désencliquetiez": ("désencliqueter",),
    "désencliquetions": ("désencliqueter",),
    "désencliquetons": ("désencliqueter",),
    "désencliquettent": ("désencliqueter",),
    "désencliquette": ("désencliqueter",),
    "désencliquettera": ("désencliqueter",),
    "désencliquetteraient": ("désencliqueter",),
    "désencliquetterai": ("désencliqueter",),
    "désencliquetterais": ("désencliqueter",),
    "désencliquetterait": ("désencliqueter",),
    "désencliquetteras": ("désencliqueter",),
    "désencliquetterez": ("désencliqueter",),
    "désencliquetteriez": ("désencliqueter",),
    "désencliquetterions": ("désencliqueter",),
    "désencliquetterons": ("désencliqueter",),
    "désencliquetteront": ("désencliqueter",),
    "désencliquettes": ("désencliqueter",),
    "désencrassaient": ("désencrasser",),
    "désencrassai": ("désencrasser",),
    "désencrassais": ("désencrasser",),
    "désencrassait": ("désencrasser",),
    "désencrassa": ("désencrasser",),
    "désencrassâmes": ("désencrasser",),
    "désencrassant": ("désencrasser",),
    "désencrassas": ("désencrasser",),
    "désencrassassent": ("désencrasser",),
    "désencrassasses": ("désencrasser",),
    "désencrassasse": ("désencrasser",),
    "désencrassassiez": ("désencrasser",),
    "désencrassassions": ("désencrasser",),
    "désencrassâtes": ("désencrasser",),
    "désencrassât": ("désencrasser",),
    "désencrassée": ("désencrasser",),
    "désencrassées": ("désencrasser",),
    "désencrassé": ("désencrasser",),
    "désencrassent": ("désencrasser",),
    "désencrasse": ("désencrasser",),
    "désencrassera": ("désencrasser",),
    "désencrasseraient": ("désencrasser",),
    "désencrasserai": ("désencrasser",),
    "désencrasserais": ("désencrasser",),
    "désencrasserait": ("désencrasser",),
    "désencrasseras": ("désencrasser",),
    "désencrassèrent": ("désencrasser",),
    "désencrasserez": ("désencrasser",),
    "désencrasseriez": ("désencrasser",),
    "désencrasserions": ("désencrasser",),
    "désencrasserons": ("désencrasser",),
    "désencrasseront": ("désencrasser",),
    "désencrassés": ("désencrasser",),
    "désencrasses": ("désencrasser",),
    "désencrassez": ("désencrasser",),
    "désencrassiez": ("désencrasser",),
    "désencrassions": ("désencrasser",),
    "désencrassons": ("désencrasser",),
    "désendormaient": ("désendormir",),
    "désendormais": ("désendormir",),
    "désendormait": ("désendormir",),
    "désendormant": ("désendormir",),
    "désendorment": ("désendormir",),
    "désendorme": ("désendormir",),
    "désendormes": ("désendormir",),
    "désendormez": ("désendormir",),
    "désendormie": ("désendormir",),
    "désendormies": ("désendormir",),
    "désendormiez": ("désendormir",),
    "désendormi": ("désendormir",),
    "désendormîmes": ("désendormir",),
    "désendormions": ("désendormir",),
    "désendormira": ("désendormir",),
    "désendormiraient": ("désendormir",),
    "désendormirai": ("désendormir",),
    "désendormirais": ("désendormir",),
    "désendormirait": ("désendormir",),
    "désendormiras": ("désendormir",),
    "désendormirent": ("désendormir",),
    "désendormirez": ("désendormir",),
    "désendormiriez": ("désendormir",),
    "désendormirions": ("désendormir",),
    "désendormirons": ("désendormir",),
    "désendormiront": ("désendormir",),
    "désendormis": ("désendormir",),
    "désendormissent": ("désendormir",),
    "désendormisses": ("désendormir",),
    "désendormisse": ("désendormir",),
    "désendormissiez": ("désendormir",),
    "désendormissions": ("désendormir",),
    "désendormîtes": ("désendormir",),
    "désendormit": ("désendormir",),
    "désendormît": ("désendormir",),
    "désendormons": ("désendormir",),
    "désendors": ("désendormir",),
    "désendort": ("désendormir",),
    "désenfiévraient": ("désenfiévrer",),
    "désenfiévrai": ("désenfiévrer",),
    "désenfiévrais": ("désenfiévrer",),
    "désenfiévrait": ("désenfiévrer",),
    "désenfiévra": ("désenfiévrer",),
    "désenfiévrâmes": ("désenfiévrer",),
    "désenfiévrant": ("désenfiévrer",),
    "désenfiévras": ("désenfiévrer",),
    "désenfiévrassent": ("désenfiévrer",),
    "désenfiévrasses": ("désenfiévrer",),
    "désenfiévrasse": ("désenfiévrer",),
    "désenfiévrassiez": ("désenfiévrer",),
    "désenfiévrassions": ("désenfiévrer",),
    "désenfiévrâtes": ("désenfiévrer",),
    "désenfiévrât": ("désenfiévrer",),
    "désenfiévrée": ("désenfiévrer",),
    "désenfiévrées": ("désenfiévrer",),
    "désenfiévré": ("désenfiévrer",),
    "désenfièvrent": ("désenfiévrer",),
    "désenfièvre": ("désenfiévrer",),
    "désenfiévrera": ("désenfiévrer",),
    "désenfiévreraient": ("désenfiévrer",),
    "désenfiévrerai": ("désenfiévrer",),
    "désenfiévrerais": ("désenfiévrer",),
    "désenfiévrerait": ("désenfiévrer",),
    "désenfiévreras": ("désenfiévrer",),
    "désenfiévrèrent": ("désenfiévrer",),
    "désenfiévrerez": ("désenfiévrer",),
    "désenfiévreriez": ("désenfiévrer",),
    "désenfiévrerions": ("désenfiévrer",),
    "désenfiévrerons": ("désenfiévrer",),
    "désenfiévreront": ("désenfiévrer",),
    "désenfiévrés": ("désenfiévrer",),
    "désenfièvres": ("désenfiévrer",),
    "désenfiévrez": ("désenfiévrer",),
    "désenfiévriez": ("désenfiévrer",),
    "désenfiévrions": ("désenfiévrer",),
    "désenfiévrons": ("désenfiévrer",),
    "désengageaient": ("désengager",),
    "désengageai": ("désengager",),
    "désengageais": ("désengager",),
    "désengageait": ("désengager",),
    "désengagea": ("désengager",),
    "désengageâmes": ("désengager",),
    "désengageant": ("désengager",),
    "désengageas": ("désengager",),
    "désengageassent": ("désengager",),
    "désengageasses": ("désengager",),
    "désengageasse": ("désengager",),
    "désengageassiez": ("désengager",),
    "désengageassions": ("désengager",),
    "désengageâtes": ("désengager",),
    "désengageât": ("désengager",),
    "désengagée": ("désengager",),
    "désengagées": ("désengager",),
    "désengagé": ("désengager",),
    "désengagent": ("désengager",),
    "désengageons": ("désengager",),
    "désengage": ("désengager",),
    "désengagera": ("désengager",),
    "désengageraient": ("désengager",),
    "désengagerai": ("désengager",),
    "désengagerais": ("désengager",),
    "désengagerait": ("désengager",),
    "désengageras": ("désengager",),
    "désengagèrent": ("désengager",),
    "désengagerez": ("désengager",),
    "désengageriez": ("désengager",),
    "désengagerions": ("désengager",),
    "désengagerons": ("désengager",),
    "désengageront": ("désengager",),
    "désengagés": ("désengager",),
    "désengages": ("désengager",),
    "désengagez": ("désengager",),
    "désengagiez": ("désengager",),
    "désengagions": ("désengager",),
    "désengonçaient": ("désengoncer",),
    "désengonçai": ("désengoncer",),
    "désengonçais": ("désengoncer",),
    "désengonçait": ("désengoncer",),
    "désengonça": ("désengoncer",),
    "désengonçâmes": ("désengoncer",),
    "désengonçant": ("désengoncer",),
    "désengonças": ("désengoncer",),
    "désengonçassent": ("désengoncer",),
    "désengonçasses": ("désengoncer",),
    "désengonçasse": ("désengoncer",),
    "désengonçassiez": ("désengoncer",),
    "désengonçassions": ("désengoncer",),
    "désengonçâtes": ("désengoncer",),
    "désengonçât": ("désengoncer",),
    "désengoncée": ("désengoncer",),
    "désengoncées": ("désengoncer",),
    "désengoncé": ("désengoncer",),
    "désengoncent": ("désengoncer",),
    "désengonce": ("désengoncer",),
    "désengoncera": ("désengoncer",),
    "désengonceraient": ("désengoncer",),
    "désengoncerai": ("désengoncer",),
    "désengoncerais": ("désengoncer",),
    "désengoncerait": ("désengoncer",),
    "désengonceras": ("désengoncer",),
    "désengoncèrent": ("désengoncer",),
    "désengoncerez": ("désengoncer",),
    "désengonceriez": ("désengoncer",),
    "désengoncerions": ("désengoncer",),
    "désengoncerons": ("désengoncer",),
    "désengonceront": ("désengoncer",),
    "désengoncés": ("désengoncer",),
    "désengonces": ("désengoncer",),
    "désengoncez": ("désengoncer",),
    "désengonciez": ("désengoncer",),
    "désengoncions": ("désengoncer",),
    "désengonçons": ("désengoncer",),
    "désengorgeaient": ("désengorger",),
    "désengorgeai": ("désengorger",),
    "désengorgeais": ("désengorger",),
    "désengorgeait": ("désengorger",),
    "désengorgea": ("désengorger",),
    "désengorgeâmes": ("désengorger",),
    "désengorgeant": ("désengorger",),
    "désengorgeas": ("désengorger",),
    "désengorgeassent": ("désengorger",),
    "désengorgeasses": ("désengorger",),
    "désengorgeasse": ("désengorger",),
    "désengorgeassiez": ("désengorger",),
    "désengorgeassions": ("désengorger",),
    "désengorgeâtes": ("désengorger",),
    "désengorgeât": ("désengorger",),
    "désengorgée": ("désengorger",),
    "désengorgées": ("désengorger",),
    "désengorgé": ("désengorger",),
    "désengorgent": ("désengorger",),
    "désengorgeons": ("désengorger",),
    "désengorge": ("désengorger",),
    "désengorgera": ("désengorger",),
    "désengorgeraient": ("désengorger",),
    "désengorgerai": ("désengorger",),
    "désengorgerais": ("désengorger",),
    "désengorgerait": ("désengorger",),
    "désengorgeras": ("désengorger",),
    "désengorgèrent": ("désengorger",),
    "désengorgerez": ("désengorger",),
    "désengorgeriez": ("désengorger",),
    "désengorgerions": ("désengorger",),
    "désengorgerons": ("désengorger",),
    "désengorgeront": ("désengorger",),
    "désengorgés": ("désengorger",),
    "désengorges": ("désengorger",),
    "désengorgez": ("désengorger",),
    "désengorgiez": ("désengorger",),
    "désengorgions": ("désengorger",),
    "désengourdie": ("désengourdir",),
    "désengourdies": ("désengourdir",),
    "désengourdi": ("désengourdir",),
    "désengourdîmes": ("désengourdir",),
    "désengourdira": ("désengourdir",),
    "désengourdiraient": ("désengourdir",),
    "désengourdirai": ("désengourdir",),
    "désengourdirais": ("désengourdir",),
    "désengourdirait": ("désengourdir",),
    "désengourdiras": ("désengourdir",),
    "désengourdirent": ("désengourdir",),
    "désengourdirez": ("désengourdir",),
    "désengourdiriez": ("désengourdir",),
    "désengourdirions": ("désengourdir",),
    "désengourdirons": ("désengourdir",),
    "désengourdiront": ("désengourdir",),
    "désengourdis": ("désengourdir",),
    "désengourdissaient": ("désengourdir",),
    "désengourdissais": ("désengourdir",),
    "désengourdissait": ("désengourdir",),
    "désengourdissant": ("désengourdir",),
    "désengourdissent": ("désengourdir",),
    "désengourdisse": ("désengourdir",),
    "désengourdisses": ("désengourdir",),
    "désengourdissez": ("désengourdir",),
    "désengourdissiez": ("désengourdir",),
    "désengourdissions": ("désengourdir",),
    "désengourdissons": ("désengourdir",),
    "désengourdîtes": ("désengourdir",),
    "désengourdit": ("désengourdir",),
    "désengourdît": ("désengourdir",),
    "désengrenaient": ("désengrener",),
    "désengrenai": ("désengrener",),
    "désengrenais": ("désengrener",),
    "désengrenait": ("désengrener",),
    "désengrena": ("désengrener",),
    "désengrenâmes": ("désengrener",),
    "désengrenant": ("désengrener",),
    "désengrenas": ("désengrener",),
    "désengrenassent": ("désengrener",),
    "désengrenasses": ("désengrener",),
    "désengrenasse": ("désengrener",),
    "désengrenassiez": ("désengrener",),
    "désengrenassions": ("désengrener",),
    "désengrenâtes": ("désengrener",),
    "désengrenât": ("désengrener",),
    "désengrenée": ("désengrener",),
    "désengrenées": ("désengrener",),
    "désengrené": ("désengrener",),
    "désengrènent": ("désengrener",),
    "désengrène": ("désengrener",),
    "désengrènera": ("désengrener",),
    "désengrèneraient": ("désengrener",),
    "désengrènerai": ("désengrener",),
    "désengrènerais": ("désengrener",),
    "désengrènerait": ("désengrener",),
    "désengrèneras": ("désengrener",),
    "désengrenèrent": ("désengrener",),
    "désengrènerez": ("désengrener",),
    "désengrèneriez": ("désengrener",),
    "désengrènerions": ("désengrener",),
    "désengrènerons": ("désengrener",),
    "désengrèneront": ("désengrener",),
    "désengrenés": ("désengrener",),
    "désengrènes": ("désengrener",),
    "désengrenez": ("désengrener",),
    "désengreniez": ("désengrener",),
    "désengrenions": ("désengrener",),
    "désengrenons": ("désengrener",),
    "désenlaçaient": ("désenlacer",),
    "désenlaçai": ("désenlacer",),
    "désenlaçais": ("désenlacer",),
    "désenlaçait": ("désenlacer",),
    "désenlaça": ("désenlacer",),
    "désenlaçâmes": ("désenlacer",),
    "désenlaçant": ("désenlacer",),
    "désenlaças": ("désenlacer",),
    "désenlaçassent": ("désenlacer",),
    "désenlaçasses": ("désenlacer",),
    "désenlaçasse": ("désenlacer",),
    "désenlaçassiez": ("désenlacer",),
    "désenlaçassions": ("désenlacer",),
    "désenlaçâtes": ("désenlacer",),
    "désenlaçât": ("désenlacer",),
    "désenlacée": ("désenlacer",),
    "désenlacées": ("désenlacer",),
    "désenlacé": ("désenlacer",),
    "désenlacent": ("désenlacer",),
    "désenlace": ("désenlacer",),
    "désenlacera": ("désenlacer",),
    "désenlaceraient": ("désenlacer",),
    "désenlacerai": ("désenlacer",),
    "désenlacerais": ("désenlacer",),
    "désenlacerait": ("désenlacer",),
    "désenlaceras": ("désenlacer",),
    "désenlacèrent": ("désenlacer",),
    "désenlacerez": ("désenlacer",),
    "désenlaceriez": ("désenlacer",),
    "désenlacerions": ("désenlacer",),
    "désenlacerons": ("désenlacer",),
    "désenlaceront": ("désenlacer",),
    "désenlacés": ("désenlacer",),
    "désenlaces": ("désenlacer",),
    "désenlacez": ("désenlacer",),
    "désenlaciez": ("désenlacer",),
    "désenlacions": ("désenlacer",),
    "désenlaçons": ("désenlacer",),
    "désenlaidie": ("désenlaidir",),
    "désenlaidies": ("désenlaidir",),
    "désenlaidi": ("désenlaidir",),
    "désenlaidîmes": ("désenlaidir",),
    "désenlaidira": ("désenlaidir",),
    "désenlaidiraient": ("désenlaidir",),
    "désenlaidirai": ("désenlaidir",),
    "désenlaidirais": ("désenlaidir",),
    "désenlaidirait": ("désenlaidir",),
    "désenlaidiras": ("désenlaidir",),
    "désenlaidirent": ("désenlaidir",),
    "désenlaidirez": ("désenlaidir",),
    "désenlaidiriez": ("désenlaidir",),
    "désenlaidirions": ("désenlaidir",),
    "désenlaidirons": ("désenlaidir",),
    "désenlaidiront": ("désenlaidir",),
    "désenlaidis": ("désenlaidir",),
    "désenlaidissaient": ("désenlaidir",),
    "désenlaidissais": ("désenlaidir",),
    "désenlaidissait": ("désenlaidir",),
    "désenlaidissant": ("désenlaidir",),
    "désenlaidissent": ("désenlaidir",),
    "désenlaidisse": ("désenlaidir",),
    "désenlaidisses": ("désenlaidir",),
    "désenlaidissez": ("désenlaidir",),
    "désenlaidissiez": ("désenlaidir",),
    "désenlaidissions": ("désenlaidir",),
    "désenlaidissons": ("désenlaidir",),
    "désenlaidîtes": ("désenlaidir",),
    "désenlaidit": ("désenlaidir",),
    "désenlaidît": ("désenlaidir",),
    "désenliassaient": ("désenliasser",),
    "désenliassai": ("désenliasser",),
    "désenliassais": ("désenliasser",),
    "désenliassait": ("désenliasser",),
    "désenliassa": ("désenliasser",),
    "désenliassâmes": ("désenliasser",),
    "désenliassant": ("désenliasser",),
    "désenliassas": ("désenliasser",),
    "désenliassassent": ("désenliasser",),
    "désenliassasses": ("désenliasser",),
    "désenliassasse": ("désenliasser",),
    "désenliassassiez": ("désenliasser",),
    "désenliassassions": ("désenliasser",),
    "désenliassâtes": ("désenliasser",),
    "désenliassât": ("désenliasser",),
    "désenliassée": ("désenliasser",),
    "désenliassées": ("désenliasser",),
    "désenliassé": ("désenliasser",),
    "désenliassent": ("désenliasser",),
    "désenliasse": ("désenliasser",),
    "désenliassera": ("désenliasser",),
    "désenliasseraient": ("désenliasser",),
    "désenliasserai": ("désenliasser",),
    "désenliasserais": ("désenliasser",),
    "désenliasserait": ("désenliasser",),
    "désenliasseras": ("désenliasser",),
    "désenliassèrent": ("désenliasser",),
    "désenliasserez": ("désenliasser",),
    "désenliasseriez": ("désenliasser",),
    "désenliasserions": ("désenliasser",),
    "désenliasserons": ("désenliasser",),
    "désenliasseront": ("désenliasser",),
    "désenliassés": ("désenliasser",),
    "désenliasses": ("désenliasser",),
    "désenliassez": ("désenliasser",),
    "désenliassiez": ("désenliasser",),
    "désenliassions": ("désenliasser",),
    "désenliassons": ("désenliasser",),
    "désenneigeaient": ("désenneiger",),
    "désenneigeai": ("désenneiger",),
    "désenneigeais": ("désenneiger",),
    "désenneigeait": ("désenneiger",),
    "désenneigea": ("désenneiger",),
    "désenneigeâmes": ("désenneiger",),
    "désenneigeant": ("désenneiger",),
    "désenneigeas": ("désenneiger",),
    "désenneigeassent": ("désenneiger",),
    "désenneigeasses": ("désenneiger",),
    "désenneigeasse": ("désenneiger",),
    "désenneigeassiez": ("désenneiger",),
    "désenneigeassions": ("désenneiger",),
    "désenneigeâtes": ("désenneiger",),
    "désenneigeât": ("désenneiger",),
    "désenneigée": ("désenneiger",),
    "désenneigées": ("désenneiger",),
    "désenneigé": ("désenneiger",),
    "désenneigent": ("désenneiger",),
    "désenneigeons": ("désenneiger",),
    "désenneige": ("désenneiger",),
    "désenneigera": ("désenneiger",),
    "désenneigeraient": ("désenneiger",),
    "désenneigerai": ("désenneiger",),
    "désenneigerais": ("désenneiger",),
    "désenneigerait": ("désenneiger",),
    "désenneigeras": ("désenneiger",),
    "désenneigèrent": ("désenneiger",),
    "désenneigerez": ("désenneiger",),
    "désenneigeriez": ("désenneiger",),
    "désenneigerions": ("désenneiger",),
    "désenneigerons": ("désenneiger",),
    "désenneigeront": ("désenneiger",),
    "désenneigés": ("désenneiger",),
    "désenneiges": ("désenneiger",),
    "désenneigez": ("désenneiger",),
    "désenneigiez": ("désenneiger",),
    "désenneigions": ("désenneiger",),
    "désennuient": ("désennuyer",),
    "désennuie": ("désennuyer",),
    "désennuiera": ("désennuyer",),
    "désennuieraient": ("désennuyer",),
    "désennuierai": ("désennuyer",),
    "désennuierais": ("désennuyer",),
    "désennuierait": ("désennuyer",),
    "désennuieras": ("désennuyer",),
    "désennuierez": ("désennuyer",),
    "désennuieriez": ("désennuyer",),
    "désennuierions": ("désennuyer",),
    "désennuierons": ("désennuyer",),
    "désennuieront": ("désennuyer",),
    "désennuies": ("désennuyer",),
    "désennuyaient": ("désennuyer",),
    "désennuyai": ("désennuyer",),
    "désennuyais": ("désennuyer",),
    "désennuyait": ("désennuyer",),
    "désennuya": ("désennuyer",),
    "désennuyâmes": ("désennuyer",),
    "désennuyant": ("désennuyer",),
    "désennuyas": ("désennuyer",),
    "désennuyassent": ("désennuyer",),
    "désennuyasses": ("désennuyer",),
    "désennuyasse": ("désennuyer",),
    "désennuyassiez": ("désennuyer",),
    "désennuyassions": ("désennuyer",),
    "désennuyâtes": ("désennuyer",),
    "désennuyât": ("désennuyer",),
    "désennuyée": ("désennuyer",),
    "désennuyées": ("désennuyer",),
    "désennuyé": ("désennuyer",),
    "désennuyèrent": ("désennuyer",),
    "désennuyés": ("désennuyer",),
    "désennuyez": ("désennuyer",),
    "désennuyiez": ("désennuyer",),
    "désennuyions": ("désennuyer",),
    "désennuyons": ("désennuyer",),
    "désenorgueillie": ("désenorgueillir",),
    "désenorgueillies": ("désenorgueillir",),
    "désenorgueilli": ("désenorgueillir",),
    "désenorgueillîmes": ("désenorgueillir",),
    "désenorgueillira": ("désenorgueillir",),
    "désenorgueilliraient": ("désenorgueillir",),
    "désenorgueillirai": ("désenorgueillir",),
    "désenorgueillirais": ("désenorgueillir",),
    "désenorgueillirait": ("désenorgueillir",),
    "désenorgueilliras": ("désenorgueillir",),
    "désenorgueillirent": ("désenorgueillir",),
    "désenorgueillirez": ("désenorgueillir",),
    "désenorgueilliriez": ("désenorgueillir",),
    "désenorgueillirions": ("désenorgueillir",),
    "désenorgueillirons": ("désenorgueillir",),
    "désenorgueilliront": ("désenorgueillir",),
    "désenorgueillis": ("désenorgueillir",),
    "désenorgueillissaient": ("désenorgueillir",),
    "désenorgueillissais": ("désenorgueillir",),
    "désenorgueillissait": ("désenorgueillir",),
    "désenorgueillissant": ("désenorgueillir",),
    "désenorgueillissent": ("désenorgueillir",),
    "désenorgueillisse": ("désenorgueillir",),
    "désenorgueillisses": ("désenorgueillir",),
    "désenorgueillissez": ("désenorgueillir",),
    "désenorgueillissiez": ("désenorgueillir",),
    "désenorgueillissions": ("désenorgueillir",),
    "désenorgueillissons": ("désenorgueillir",),
    "désenorgueillîtes": ("désenorgueillir",),
    "désenorgueillit": ("désenorgueillir",),
    "désenorgueillît": ("désenorgueillir",),
    "désenraient": ("désenrayer",),
    "désenraie": ("désenrayer",),
    "désenraiera": ("désenrayer",),
    "désenraieraient": ("désenrayer",),
    "désenraierai": ("désenrayer",),
    "désenraierais": ("désenrayer",),
    "désenraierait": ("désenrayer",),
    "désenraieras": ("désenrayer",),
    "désenraierez": ("désenrayer",),
    "désenraieriez": ("désenrayer",),
    "désenraierions": ("désenrayer",),
    "désenraierons": ("désenrayer",),
    "désenraieront": ("désenrayer",),
    "désenraies": ("désenrayer",),
    "désenrayaient": ("désenrayer",),
    "désenrayai": ("désenrayer",),
    "désenrayais": ("désenrayer",),
    "désenrayait": ("désenrayer",),
    "désenraya": ("désenrayer",),
    "désenrayâmes": ("désenrayer",),
    "désenrayant": ("désenrayer",),
    "désenrayas": ("désenrayer",),
    "désenrayassent": ("désenrayer",),
    "désenrayasses": ("désenrayer",),
    "désenrayasse": ("désenrayer",),
    "désenrayassiez": ("désenrayer",),
    "désenrayassions": ("désenrayer",),
    "désenrayâtes": ("désenrayer",),
    "désenrayât": ("désenrayer",),
    "désenrayée": ("désenrayer",),
    "désenrayées": ("désenrayer",),
    "désenrayé": ("désenrayer",),
    "désenrayent": ("désenrayer",),
    "désenraye": ("désenrayer",),
    "désenrayera": ("désenrayer",),
    "désenrayeraient": ("désenrayer",),
    "désenrayerai": ("désenrayer",),
    "désenrayerais": ("désenrayer",),
    "désenrayerait": ("désenrayer",),
    "désenrayeras": ("désenrayer",),
    "désenrayèrent": ("désenrayer",),
    "désenrayerez": ("désenrayer",),
    "désenrayeriez": ("désenrayer",),
    "désenrayerions": ("désenrayer",),
    "désenrayerons": ("désenrayer",),
    "désenrayeront": ("désenrayer",),
    "désenrayés": ("désenrayer",),
    "désenrayes": ("désenrayer",),
    "désenrayez": ("désenrayer",),
    "désenrayiez": ("désenrayer",),
    "désenrayions": ("désenrayer",),
    "désenrayons": ("désenrayer",),
    "désensevelie": ("désensevelir",),
    "désensevelies": ("désensevelir",),
    "désenseveli": ("désensevelir",),
    "désensevelîmes": ("désensevelir",),
    "désensevelira": ("désensevelir",),
    "désenseveliraient": ("désensevelir",),
    "désensevelirai": ("désensevelir",),
    "désensevelirais": ("désensevelir",),
    "désensevelirait": ("désensevelir",),
    "désenseveliras": ("désensevelir",),
    "désensevelirent": ("désensevelir",),
    "désensevelirez": ("désensevelir",),
    "désenseveliriez": ("désensevelir",),
    "désensevelirions": ("désensevelir",),
    "désensevelirons": ("désensevelir",),
    "désenseveliront": ("désensevelir",),
    "désensevelis": ("désensevelir",),
    "désensevelissaient": ("désensevelir",),
    "désensevelissais": ("désensevelir",),
    "désensevelissait": ("désensevelir",),
    "désensevelissant": ("désensevelir",),
    "désensevelissent": ("désensevelir",),
    "désensevelisse": ("désensevelir",),
    "désensevelisses": ("désensevelir",),
    "désensevelissez": ("désensevelir",),
    "désensevelissiez": ("désensevelir",),
    "désensevelissions": ("désensevelir",),
    "désensevelissons": ("désensevelir",),
    "désensevelîtes": ("désensevelir",),
    "désensevelit": ("désensevelir",),
    "désensevelît": ("désensevelir",),
    "désensorcelaient": ("désensorceler",),
    "désensorcelai": ("désensorceler",),
    "désensorcelais": ("désensorceler",),
    "désensorcelait": ("désensorceler",),
    "désensorcela": ("désensorceler",),
    "désensorcelâmes": ("désensorceler",),
    "désensorcelant": ("désensorceler",),
    "désensorcelas": ("désensorceler",),
    "désensorcelassent": ("désensorceler",),
    "désensorcelasses": ("désensorceler",),
    "désensorcelasse": ("désensorceler",),
    "désensorcelassiez": ("désensorceler",),
    "désensorcelassions": ("désensorceler",),
    "désensorcelâtes": ("désensorceler",),
    "désensorcelât": ("désensorceler",),
    "désensorcelée": ("désensorceler",),
    "désensorcelées": ("désensorceler",),
    "désensorcelé": ("désensorceler",),
    "désensorcelèrent": ("désensorceler",),
    "désensorcelés": ("désensorceler",),
    "désensorcelez": ("désensorceler",),
    "désensorceliez": ("désensorceler",),
    "désensorcelions": ("désensorceler",),
    "désensorcellent": ("désensorceler",),
    "désensorcelle": ("désensorceler",),
    "désensorcellera": ("désensorceler",),
    "désensorcelleraient": ("désensorceler",),
    "désensorcellerai": ("désensorceler",),
    "désensorcellerais": ("désensorceler",),
    "désensorcellerait": ("désensorceler",),
    "désensorcelleras": ("désensorceler",),
    "désensorcellerez": ("désensorceler",),
    "désensorcelleriez": ("désensorceler",),
    "désensorcellerions": ("désensorceler",),
    "désensorcellerons": ("désensorceler",),
    "désensorcelleront": ("désensorceler",),
    "désensorcelles": ("désensorceler",),
    "désensorcelons": ("désensorceler",),
    "désentassaient": ("désentasser",),
    "désentassai": ("désentasser",),
    "désentassais": ("désentasser",),
    "désentassait": ("désentasser",),
    "désentassa": ("désentasser",),
    "désentassâmes": ("désentasser",),
    "désentassant": ("désentasser",),
    "désentassas": ("désentasser",),
    "désentassassent": ("désentasser",),
    "désentassasses": ("désentasser",),
    "désentassasse": ("désentasser",),
    "désentassassiez": ("désentasser",),
    "désentassassions": ("désentasser",),
    "désentassâtes": ("désentasser",),
    "désentassât": ("désentasser",),
    "désentassée": ("désentasser",),
    "désentassées": ("désentasser",),
    "désentassé": ("désentasser",),
    "désentassent": ("désentasser",),
    "désentasse": ("désentasser",),
    "désentassera": ("désentasser",),
    "désentasseraient": ("désentasser",),
    "désentasserai": ("désentasser",),
    "désentasserais": ("désentasser",),
    "désentasserait": ("désentasser",),
    "désentasseras": ("désentasser",),
    "désentassèrent": ("désentasser",),
    "désentasserez": ("désentasser",),
    "désentasseriez": ("désentasser",),
    "désentasserions": ("désentasser",),
    "désentasserons": ("désentasser",),
    "désentasseront": ("désentasser",),
    "désentassés": ("désentasser",),
    "désentasses": ("désentasser",),
    "désentassez": ("désentasser",),
    "désentassiez": ("désentasser",),
    "désentassions": ("désentasser",),
    "désentassons": ("désentasser",),
    "désentrelaçaient": ("désentrelacer",),
    "désentrelaçai": ("désentrelacer",),
    "désentrelaçais": ("désentrelacer",),
    "désentrelaçait": ("désentrelacer",),
    "désentrelaça": ("désentrelacer",),
    "désentrelaçâmes": ("désentrelacer",),
    "désentrelaçant": ("désentrelacer",),
    "désentrelaças": ("désentrelacer",),
    "désentrelaçassent": ("désentrelacer",),
    "désentrelaçasses": ("désentrelacer",),
    "désentrelaçasse": ("désentrelacer",),
    "désentrelaçassiez": ("désentrelacer",),
    "désentrelaçassions": ("désentrelacer",),
    "désentrelaçâtes": ("désentrelacer",),
    "désentrelaçât": ("désentrelacer",),
    "désentrelacée": ("désentrelacer",),
    "désentrelacées": ("désentrelacer",),
    "désentrelacé": ("désentrelacer",),
    "désentrelacent": ("désentrelacer",),
    "désentrelace": ("désentrelacer",),
    "désentrelacera": ("désentrelacer",),
    "désentrelaceraient": ("désentrelacer",),
    "désentrelacerai": ("désentrelacer",),
    "désentrelacerais": ("désentrelacer",),
    "désentrelacerait": ("désentrelacer",),
    "désentrelaceras": ("désentrelacer",),
    "désentrelacèrent": ("désentrelacer",),
    "désentrelacerez": ("désentrelacer",),
    "désentrelaceriez": ("désentrelacer",),
    "désentrelacerions": ("désentrelacer",),
    "désentrelacerons": ("désentrelacer",),
    "désentrelaceront": ("désentrelacer",),
    "désentrelacés": ("désentrelacer",),
    "désentrelaces": ("désentrelacer",),
    "désentrelacez": ("désentrelacer",),
    "désentrelaciez": ("désentrelacer",),
    "désentrelacions": ("désentrelacer",),
    "désentrelaçons": ("désentrelacer",),
    "désépaissie": ("désépaissir",),
    "désépaissies": ("désépaissir",),
    "désépaissi": ("désépaissir",),
    "désépaissîmes": ("désépaissir",),
    "désépaissira": ("désépaissir",),
    "désépaissiraient": ("désépaissir",),
    "désépaissirai": ("désépaissir",),
    "désépaissirais": ("désépaissir",),
    "désépaissirait": ("désépaissir",),
    "désépaissiras": ("désépaissir",),
    "désépaissirent": ("désépaissir",),
    "désépaissirez": ("désépaissir",),
    "désépaissiriez": ("désépaissir",),
    "désépaissirions": ("désépaissir",),
    "désépaissirons": ("désépaissir",),
    "désépaissiront": ("désépaissir",),
    "désépaissis": ("désépaissir",),
    "désépaississaient": ("désépaissir",),
    "désépaississais": ("désépaissir",),
    "désépaississait": ("désépaissir",),
    "désépaississant": ("désépaissir",),
    "désépaississent": ("désépaissir",),
    "désépaississe": ("désépaissir",),
    "désépaississes": ("désépaissir",),
    "désépaississez": ("désépaissir",),
    "désépaississiez": ("désépaissir",),
    "désépaississions": ("désépaissir",),
    "désépaississons": ("désépaissir",),
    "désépaissîtes": ("désépaissir",),
    "désépaissit": ("désépaissir",),
    "désépaissît": ("désépaissir",),
    "désépiçaient": ("désépicer",),
    "désépiçai": ("désépicer",),
    "désépiçais": ("désépicer",),
    "désépiçait": ("désépicer",),
    "désépiça": ("désépicer",),
    "désépiçâmes": ("désépicer",),
    "désépiçant": ("désépicer",),
    "désépiças": ("désépicer",),
    "désépiçassent": ("désépicer",),
    "désépiçasses": ("désépicer",),
    "désépiçasse": ("désépicer",),
    "désépiçassiez": ("désépicer",),
    "désépiçassions": ("désépicer",),
    "désépiçâtes": ("désépicer",),
    "désépiçât": ("désépicer",),
    "désépicée": ("désépicer",),
    "désépicées": ("désépicer",),
    "désépicé": ("désépicer",),
    "désépicent": ("désépicer",),
    "désépice": ("désépicer",),
    "désépicera": ("désépicer",),
    "désépiceraient": ("désépicer",),
    "désépicerai": ("désépicer",),
    "désépicerais": ("désépicer",),
    "désépicerait": ("désépicer",),
    "désépiceras": ("désépicer",),
    "désépicèrent": ("désépicer",),
    "désépicerez": ("désépicer",),
    "désépiceriez": ("désépicer",),
    "désépicerions": ("désépicer",),
    "désépicerons": ("désépicer",),
    "désépiceront": ("désépicer",),
    "désépicés": ("désépicer",),
    "désépices": ("désépicer",),
    "désépicez": ("désépicer",),
    "désépiciez": ("désépicer",),
    "désépicions": ("désépicer",),
    "désépiçons": ("désépicer",),
    "désertifiaient": ("désertifier",),
    "désertifiai": ("désertifier",),
    "désertifiais": ("désertifier",),
    "désertifiait": ("désertifier",),
    "désertifia": ("désertifier",),
    "désertifiâmes": ("désertifier",),
    "désertifiant": ("désertifier",),
    "désertifias": ("désertifier",),
    "désertifiassent": ("désertifier",),
    "désertifiasses": ("désertifier",),
    "désertifiasse": ("désertifier",),
    "désertifiassiez": ("désertifier",),
    "désertifiassions": ("désertifier",),
    "désertifiâtes": ("désertifier",),
    "désertifiât": ("désertifier",),
    "désertifiée": ("désertifier",),
    "désertifiées": ("désertifier",),
    "désertifié": ("désertifier",),
    "désertifient": ("désertifier",),
    "désertifie": ("désertifier",),
    "désertifiera": ("désertifier",),
    "désertifieraient": ("désertifier",),
    "désertifierai": ("désertifier",),
    "désertifierais": ("désertifier",),
    "désertifierait": ("désertifier",),
    "désertifieras": ("désertifier",),
    "désertifièrent": ("désertifier",),
    "désertifierez": ("désertifier",),
    "désertifieriez": ("désertifier",),
    "désertifierions": ("désertifier",),
    "désertifierons": ("désertifier",),
    "désertifieront": ("désertifier",),
    "désertifiés": ("désertifier",),
    "désertifies": ("désertifier",),
    "désertifiez": ("désertifier",),
    "désertifiiez": ("désertifier",),
    "désertifiions": ("désertifier",),
    "désertifions": ("désertifier",),
    "désespéraient": ("désespérer",),
    "désespérai": ("désespérer",),
    "désespérais": ("désespérer",),
    "désespérait": ("désespérer",),
    "désespéra": ("désespérer",),
    "désespérâmes": ("désespérer",),
    "désespérant": ("désespérer",),
    "désespéras": ("désespérer",),
    "désespérassent": ("désespérer",),
    "désespérasses": ("désespérer",),
    "désespérasse": ("désespérer",),
    "désespérassiez": ("désespérer",),
    "désespérassions": ("désespérer",),
    "désespérâtes": ("désespérer",),
    "désespérât": ("désespérer",),
    "désespérée": ("désespérer",),
    "désespérées": ("désespérer",),
    "désespéré": ("désespérer",),
    "désespèrent": ("désespérer",),
    "désespère": ("désespérer",),
    "désespérera": ("désespérer",),
    "désespéreraient": ("désespérer",),
    "désespérerai": ("désespérer",),
    "désespérerais": ("désespérer",),
    "désespérerait": ("désespérer",),
    "désespéreras": ("désespérer",),
    "désespérèrent": ("désespérer",),
    "désespérerez": ("désespérer",),
    "désespéreriez": ("désespérer",),
    "désespérerions": ("désespérer",),
    "désespérerons": ("désespérer",),
    "désespéreront": ("désespérer",),
    "désespérés": ("désespérer",),
    "désespères": ("désespérer",),
    "désespérez": ("désespérer",),
    "désespériez": ("désespérer",),
    "désespérions": ("désespérer",),
    "désespérons": ("désespérer",),
    "désessenciaient": ("désessencier",),
    "désessenciai": ("désessencier",),
    "désessenciais": ("désessencier",),
    "désessenciait": ("désessencier",),
    "désessencia": ("désessencier",),
    "désessenciâmes": ("désessencier",),
    "désessenciant": ("désessencier",),
    "désessencias": ("désessencier",),
    "désessenciassent": ("désessencier",),
    "désessenciasses": ("désessencier",),
    "désessenciasse": ("désessencier",),
    "désessenciassiez": ("désessencier",),
    "désessenciassions": ("désessencier",),
    "désessenciâtes": ("désessencier",),
    "désessenciât": ("désessencier",),
    "désessenciée": ("désessencier",),
    "désessenciées": ("désessencier",),
    "désessencié": ("désessencier",),
    "désessencient": ("désessencier",),
    "désessencie": ("désessencier",),
    "désessenciera": ("désessencier",),
    "désessencieraient": ("désessencier",),
    "désessencierai": ("désessencier",),
    "désessencierais": ("désessencier",),
    "désessencierait": ("désessencier",),
    "désessencieras": ("désessencier",),
    "désessencièrent": ("désessencier",),
    "désessencierez": ("désessencier",),
    "désessencieriez": ("désessencier",),
    "désessencierions": ("désessencier",),
    "désessencierons": ("désessencier",),
    "désessencieront": ("désessencier",),
    "désessenciés": ("désessencier",),
    "désessencies": ("désessencier",),
    "désessenciez": ("désessencier",),
    "désessenciiez": ("désessencier",),
    "désessenciions": ("désessencier",),
    "désessencions": ("désessencier",),
    "désétablie": ("désétablir",),
    "désétablies": ("désétablir",),
    "désétabli": ("désétablir",),
    "désétablîmes": ("désétablir",),
    "désétablira": ("désétablir",),
    "désétabliraient": ("désétablir",),
    "désétablirai": ("désétablir",),
    "désétablirais": ("désétablir",),
    "désétablirait": ("désétablir",),
    "désétabliras": ("désétablir",),
    "désétablirent": ("désétablir",),
    "désétablirez": ("désétablir",),
    "désétabliriez": ("désétablir",),
    "désétablirions": ("désétablir",),
    "désétablirons": ("désétablir",),
    "désétabliront": ("désétablir",),
    "désétablis": ("désétablir",),
    "désétablissaient": ("désétablir",),
    "désétablissais": ("désétablir",),
    "désétablissait": ("désétablir",),
    "désétablissant": ("désétablir",),
    "désétablissent": ("désétablir",),
    "désétablisse": ("désétablir",),
    "désétablisses": ("désétablir",),
    "désétablissez": ("désétablir",),
    "désétablissiez": ("désétablir",),
    "désétablissions": ("désétablir",),
    "désétablissons": ("désétablir",),
    "désétablîtes": ("désétablir",),
    "désétablit": ("désétablir",),
    "désétablît": ("désétablir",),
    "désétageaient": ("désétager",),
    "désétageai": ("désétager",),
    "désétageais": ("désétager",),
    "désétageait": ("désétager",),
    "désétagea": ("désétager",),
    "désétageâmes": ("désétager",),
    "désétageant": ("désétager",),
    "désétageas": ("désétager",),
    "désétageassent": ("désétager",),
    "désétageasses": ("désétager",),
    "désétageasse": ("désétager",),
    "désétageassiez": ("désétager",),
    "désétageassions": ("désétager",),
    "désétageâtes": ("désétager",),
    "désétageât": ("désétager",),
    "désétagée": ("désétager",),
    "désétagées": ("désétager",),
    "désétagé": ("désétager",),
    "désétagent": ("désétager",),
    "désétageons": ("désétager",),
    "désétage": ("désétager",),
    "désétagera": ("désétager",),
    "désétageraient": ("désétager",),
    "désétagerai": ("désétager",),
    "désétagerais": ("désétager",),
    "désétagerait": ("désétager",),
    "désétageras": ("désétager",),
    "désétagèrent": ("désétager",),
    "désétagerez": ("désétager",),
    "désétageriez": ("désétager",),
    "désétagerions": ("désétager",),
    "désétagerons": ("désétager",),
    "désétageront": ("désétager",),
    "désétagés": ("désétager",),
    "désétages": ("désétager",),
    "désétagez": ("désétager",),
    "désétagiez": ("désétager",),
    "désétagions": ("désétager",),
    "désétaient": ("désétayer",),
    "désétaie": ("désétayer",),
    "désétaiera": ("désétayer",),
    "désétaieraient": ("désétayer",),
    "désétaierai": ("désétayer",),
    "désétaierais": ("désétayer",),
    "désétaierait": ("désétayer",),
    "désétaieras": ("désétayer",),
    "désétaierez": ("désétayer",),
    "désétaieriez": ("désétayer",),
    "désétaierions": ("désétayer",),
    "désétaierons": ("désétayer",),
    "désétaieront": ("désétayer",),
    "désétaies": ("désétayer",),
    "désétayaient": ("désétayer",),
    "désétayai": ("désétayer",),
    "désétayais": ("désétayer",),
    "désétayait": ("désétayer",),
    "désétaya": ("désétayer",),
    "désétayâmes": ("désétayer",),
    "désétayant": ("désétayer",),
    "désétayas": ("désétayer",),
    "désétayassent": ("désétayer",),
    "désétayasses": ("désétayer",),
    "désétayasse": ("désétayer",),
    "désétayassiez": ("désétayer",),
    "désétayassions": ("désétayer",),
    "désétayâtes": ("désétayer",),
    "désétayât": ("désétayer",),
    "désétayée": ("désétayer",),
    "désétayées": ("désétayer",),
    "désétayé": ("désétayer",),
    "désétayent": ("désétayer",),
    "désétaye": ("désétayer",),
    "désétayera": ("désétayer",),
    "désétayeraient": ("désétayer",),
    "désétayerai": ("désétayer",),
    "désétayerais": ("désétayer",),
    "désétayerait": ("désétayer",),
    "désétayeras": ("désétayer",),
    "désétayèrent": ("désétayer",),
    "désétayerez": ("désétayer",),
    "désétayeriez": ("désétayer",),
    "désétayerions": ("désétayer",),
    "désétayerons": ("désétayer",),
    "désétayeront": ("désétayer",),
    "désétayés": ("désétayer",),
    "désétayes": ("désétayer",),
    "désétayez": ("désétayer",),
    "désétayiez": ("désétayer",),
    "désétayions": ("désétayer",),
    "désétayons": ("désétayer",),
    "désétiquetaient": ("désétiqueter",),
    "désétiquetai": ("désétiqueter",),
    "désétiquetais": ("désétiqueter",),
    "désétiquetait": ("désétiqueter",),
    "désétiqueta": ("désétiqueter",),
    "désétiquetâmes": ("désétiqueter",),
    "désétiquetant": ("désétiqueter",),
    "désétiquetas": ("désétiqueter",),
    "désétiquetassent": ("désétiqueter",),
    "désétiquetasses": ("désétiqueter",),
    "désétiquetasse": ("désétiqueter",),
    "désétiquetassiez": ("désétiqueter",),
    "désétiquetassions": ("désétiqueter",),
    "désétiquetâtes": ("désétiqueter",),
    "désétiquetât": ("désétiqueter",),
    "désétiquetée": ("désétiqueter",),
    "désétiquetées": ("désétiqueter",),
    "désétiqueté": ("désétiqueter",),
    "désétiquetèrent": ("désétiqueter",),
    "désétiquetés": ("désétiqueter",),
    "désétiquetez": ("désétiqueter",),
    "désétiquetiez": ("désétiqueter",),
    "désétiquetions": ("désétiqueter",),
    "désétiquetons": ("désétiqueter",),
    "désétiquettent": ("désétiqueter",),
    "désétiquette": ("désétiqueter",),
    "désétiquettera": ("désétiqueter",),
    "désétiquetteraient": ("désétiqueter",),
    "désétiquetterai": ("désétiqueter",),
    "désétiquetterais": ("désétiqueter",),
    "désétiquetterait": ("désétiqueter",),
    "désétiquetteras": ("désétiqueter",),
    "désétiquetterez": ("désétiqueter",),
    "désétiquetteriez": ("désétiqueter",),
    "désétiquetterions": ("désétiqueter",),
    "désétiquetterons": ("désétiqueter",),
    "désétiquetteront": ("désétiqueter",),
    "désétiquettes": ("désétiqueter",),
    "déshalogénaient": ("déshalogéner",),
    "déshalogénai": ("déshalogéner",),
    "déshalogénais": ("déshalogéner",),
    "déshalogénait": ("déshalogéner",),
    "déshalogéna": ("déshalogéner",),
    "déshalogénâmes": ("déshalogéner",),
    "déshalogénant": ("déshalogéner",),
    "déshalogénas": ("déshalogéner",),
    "déshalogénassent": ("déshalogéner",),
    "déshalogénasses": ("déshalogéner",),
    "déshalogénasse": ("déshalogéner",),
    "déshalogénassiez": ("déshalogéner",),
    "déshalogénassions": ("déshalogéner",),
    "déshalogénâtes": ("déshalogéner",),
    "déshalogénât": ("déshalogéner",),
    "déshalogénée": ("déshalogéner",),
    "déshalogénées": ("déshalogéner",),
    "déshalogéné": ("déshalogéner",),
    "déshalogènent": ("déshalogéner",),
    "déshalogène": ("déshalogéner",),
    "déshalogénera": ("déshalogéner",),
    "déshalogéneraient": ("déshalogéner",),
    "déshalogénerai": ("déshalogéner",),
    "déshalogénerais": ("déshalogéner",),
    "déshalogénerait": ("déshalogéner",),
    "déshalogéneras": ("déshalogéner",),
    "déshalogénèrent": ("déshalogéner",),
    "déshalogénerez": ("déshalogéner",),
    "déshalogéneriez": ("déshalogéner",),
    "déshalogénerions": ("déshalogéner",),
    "déshalogénerons": ("déshalogéner",),
    "déshalogéneront": ("déshalogéner",),
    "déshalogénés": ("déshalogéner",),
    "déshalogènes": ("déshalogéner",),
    "déshalogénez": ("déshalogéner",),
    "déshalogéniez": ("déshalogéner",),
    "déshalogénions": ("déshalogéner",),
    "déshalogénons": ("déshalogéner",),
    "déshumidifiaient": ("déshumidifier",),
    "déshumidifiai": ("déshumidifier",),
    "déshumidifiais": ("déshumidifier",),
    "déshumidifiait": ("déshumidifier",),
    "déshumidifia": ("déshumidifier",),
    "déshumidifiâmes": ("déshumidifier",),
    "déshumidifiant": ("déshumidifier",),
    "déshumidifias": ("déshumidifier",),
    "déshumidifiassent": ("déshumidifier",),
    "déshumidifiasses": ("déshumidifier",),
    "déshumidifiasse": ("déshumidifier",),
    "déshumidifiassiez": ("déshumidifier",),
    "déshumidifiassions": ("déshumidifier",),
    "déshumidifiâtes": ("déshumidifier",),
    "déshumidifiât": ("déshumidifier",),
    "déshumidifiée": ("déshumidifier",),
    "déshumidifiées": ("déshumidifier",),
    "déshumidifié": ("déshumidifier",),
    "déshumidifient": ("déshumidifier",),
    "déshumidifie": ("déshumidifier",),
    "déshumidifiera": ("déshumidifier",),
    "déshumidifieraient": ("déshumidifier",),
    "déshumidifierai": ("déshumidifier",),
    "déshumidifierais": ("déshumidifier",),
    "déshumidifierait": ("déshumidifier",),
    "déshumidifieras": ("déshumidifier",),
    "déshumidifièrent": ("déshumidifier",),
    "déshumidifierez": ("déshumidifier",),
    "déshumidifieriez": ("déshumidifier",),
    "déshumidifierions": ("déshumidifier",),
    "déshumidifierons": ("déshumidifier",),
    "déshumidifieront": ("déshumidifier",),
    "déshumidifiés": ("déshumidifier",),
    "déshumidifies": ("déshumidifier",),
    "déshumidifiez": ("déshumidifier",),
    "déshumidifiiez": ("déshumidifier",),
    "déshumidifiions": ("déshumidifier",),
    "déshumidifions": ("déshumidifier",),
    "déshydrogénaient": ("déshydrogéner",),
    "déshydrogénai": ("déshydrogéner",),
    "déshydrogénais": ("déshydrogéner",),
    "déshydrogénait": ("déshydrogéner",),
    "déshydrogéna": ("déshydrogéner",),
    "déshydrogénâmes": ("déshydrogéner",),
    "déshydrogénant": ("déshydrogéner",),
    "déshydrogénas": ("déshydrogéner",),
    "déshydrogénassent": ("déshydrogéner",),
    "déshydrogénasses": ("déshydrogéner",),
    "déshydrogénasse": ("déshydrogéner",),
    "déshydrogénassiez": ("déshydrogéner",),
    "déshydrogénassions": ("déshydrogéner",),
    "déshydrogénâtes": ("déshydrogéner",),
    "déshydrogénât": ("déshydrogéner",),
    "déshydrogénée": ("déshydrogéner",),
    "déshydrogénées": ("déshydrogéner",),
    "déshydrogéné": ("déshydrogéner",),
    "déshydrogènent": ("déshydrogéner",),
    "déshydrogène": ("déshydrogéner",),
    "déshydrogénera": ("déshydrogéner",),
    "déshydrogéneraient": ("déshydrogéner",),
    "déshydrogénerai": ("déshydrogéner",),
    "déshydrogénerais": ("déshydrogéner",),
    "déshydrogénerait": ("déshydrogéner",),
    "déshydrogéneras": ("déshydrogéner",),
    "déshydrogénèrent": ("déshydrogéner",),
    "déshydrogénerez": ("déshydrogéner",),
    "déshydrogéneriez": ("déshydrogéner",),
    "déshydrogénerions": ("déshydrogéner",),
    "déshydrogénerons": ("déshydrogéner",),
    "déshydrogéneront": ("déshydrogéner",),
    "déshydrogénés": ("déshydrogéner",),
    "déshydrogènes": ("déshydrogéner",),
    "déshydrogénez": ("déshydrogéner",),
    "déshydrogéniez": ("déshydrogéner",),
    "déshydrogénions": ("déshydrogéner",),
    "déshydrogénons": ("déshydrogéner",),
    "déshydrohalogénaient": ("déshydrohalogéner",),
    "déshydrohalogénai": ("déshydrohalogéner",),
    "déshydrohalogénais": ("déshydrohalogéner",),
    "déshydrohalogénait": ("déshydrohalogéner",),
    "déshydrohalogéna": ("déshydrohalogéner",),
    "déshydrohalogénâmes": ("déshydrohalogéner",),
    "déshydrohalogénant": ("déshydrohalogéner",),
    "déshydrohalogénas": ("déshydrohalogéner",),
    "déshydrohalogénassent": ("déshydrohalogéner",),
    "déshydrohalogénasses": ("déshydrohalogéner",),
    "déshydrohalogénasse": ("déshydrohalogéner",),
    "déshydrohalogénassiez": ("déshydrohalogéner",),
    "déshydrohalogénassions": ("déshydrohalogéner",),
    "déshydrohalogénâtes": ("déshydrohalogéner",),
    "déshydrohalogénât": ("déshydrohalogéner",),
    "déshydrohalogénée": ("déshydrohalogéner",),
    "déshydrohalogénées": ("déshydrohalogéner",),
    "déshydrohalogéné": ("déshydrohalogéner",),
    "déshydrohalogènent": ("déshydrohalogéner",),
    "déshydrohalogène": ("déshydrohalogéner",),
    "déshydrohalogénera": ("déshydrohalogéner",),
    "déshydrohalogéneraient": ("déshydrohalogéner",),
    "déshydrohalogénerai": ("déshydrohalogéner",),
    "déshydrohalogénerais": ("déshydrohalogéner",),
    "déshydrohalogénerait": ("déshydrohalogéner",),
    "déshydrohalogéneras": ("déshydrohalogéner",),
    "déshydrohalogénèrent": ("déshydrohalogéner",),
    "déshydrohalogénerez": ("déshydrohalogéner",),
    "déshydrohalogéneriez": ("déshydrohalogéner",),
    "déshydrohalogénerions": ("déshydrohalogéner",),
    "déshydrohalogénerons": ("déshydrohalogéner",),
    "déshydrohalogéneront": ("déshydrohalogéner",),
    "déshydrohalogénés": ("déshydrohalogéner",),
    "déshydrohalogènes": ("déshydrohalogéner",),
    "déshydrohalogénez": ("déshydrohalogéner",),
    "déshydrohalogéniez": ("déshydrohalogéner",),
    "déshydrohalogénions": ("déshydrohalogéner",),
    "déshydrohalogénons": ("déshydrohalogéner",),
    "déshypothéquaient": ("déshypothéquer",),
    "déshypothéquai": ("déshypothéquer",),
    "déshypothéquais": ("déshypothéquer",),
    "déshypothéquait": ("déshypothéquer",),
    "déshypothéqua": ("déshypothéquer",),
    "déshypothéquâmes": ("déshypothéquer",),
    "déshypothéquant": ("déshypothéquer",),
    "déshypothéquas": ("déshypothéquer",),
    "déshypothéquassent": ("déshypothéquer",),
    "déshypothéquasses": ("déshypothéquer",),
    "déshypothéquasse": ("déshypothéquer",),
    "déshypothéquassiez": ("déshypothéquer",),
    "déshypothéquassions": ("déshypothéquer",),
    "déshypothéquâtes": ("déshypothéquer",),
    "déshypothéquât": ("déshypothéquer",),
    "déshypothéquée": ("déshypothéquer",),
    "déshypothéquées": ("déshypothéquer",),
    "déshypothéqué": ("déshypothéquer",),
    "déshypothèquent": ("déshypothéquer",),
    "déshypothèque": ("déshypothéquer",),
    "déshypothéquera": ("déshypothéquer",),
    "déshypothéqueraient": ("déshypothéquer",),
    "déshypothéquerai": ("déshypothéquer",),
    "déshypothéquerais": ("déshypothéquer",),
    "déshypothéquerait": ("déshypothéquer",),
    "déshypothéqueras": ("déshypothéquer",),
    "déshypothéquèrent": ("déshypothéquer",),
    "déshypothéquerez": ("déshypothéquer",),
    "déshypothéqueriez": ("déshypothéquer",),
    "déshypothéquerions": ("déshypothéquer",),
    "déshypothéquerons": ("déshypothéquer",),
    "déshypothéqueront": ("déshypothéquer",),
    "déshypothéqués": ("déshypothéquer",),
    "déshypothèques": ("déshypothéquer",),
    "déshypothéquez": ("déshypothéquer",),
    "déshypothéquiez": ("déshypothéquer",),
    "déshypothéquions": ("déshypothéquer",),
    "déshypothéquons": ("déshypothéquer",),
    "désignifiaient": ("désignifier",),
    "désignifiai": ("désignifier",),
    "désignifiais": ("désignifier",),
    "désignifiait": ("désignifier",),
    "désignifia": ("désignifier",),
    "désignifiâmes": ("désignifier",),
    "désignifiant": ("désignifier",),
    "désignifias": ("désignifier",),
    "désignifiassent": ("désignifier",),
    "désignifiasses": ("désignifier",),
    "désignifiasse": ("désignifier",),
    "désignifiassiez": ("désignifier",),
    "désignifiassions": ("désignifier",),
    "désignifiâtes": ("désignifier",),
    "désignifiât": ("désignifier",),
    "désignifiée": ("désignifier",),
    "désignifiées": ("désignifier",),
    "désignifié": ("désignifier",),
    "désignifient": ("désignifier",),
    "désignifie": ("désignifier",),
    "désignifiera": ("désignifier",),
    "désignifieraient": ("désignifier",),
    "désignifierai": ("désignifier",),
    "désignifierais": ("désignifier",),
    "désignifierait": ("désignifier",),
    "désignifieras": ("désignifier",),
    "désignifièrent": ("désignifier",),
    "désignifierez": ("désignifier",),
    "désignifieriez": ("désignifier",),
    "désignifierions": ("désignifier",),
    "désignifierons": ("désignifier",),
    "désignifieront": ("désignifier",),
    "désignifiés": ("désignifier",),
    "désignifies": ("désignifier",),
    "désignifiez": ("désignifier",),
    "désignifiiez": ("désignifier",),
    "désignifiions": ("désignifier",),
    "désignifions": ("désignifier",),
    "désiliciaient": ("désilicier",),
    "désiliciai": ("désilicier",),
    "désiliciais": ("désilicier",),
    "désiliciait": ("désilicier",),
    "désilicia": ("désilicier",),
    "désiliciâmes": ("désilicier",),
    "désiliciant": ("désilicier",),
    "désilicias": ("désilicier",),
    "désiliciassent": ("désilicier",),
    "désiliciasses": ("désilicier",),
    "désiliciasse": ("désilicier",),
    "désiliciassiez": ("désilicier",),
    "désiliciassions": ("désilicier",),
    "désiliciâtes": ("désilicier",),
    "désiliciât": ("désilicier",),
    "désiliciée": ("désilicier",),
    "désiliciées": ("désilicier",),
    "désilicié": ("désilicier",),
    "désilicient": ("désilicier",),
    "désilicie": ("désilicier",),
    "désiliciera": ("désilicier",),
    "désilicieraient": ("désilicier",),
    "désilicierai": ("désilicier",),
    "désilicierais": ("désilicier",),
    "désilicierait": ("désilicier",),
    "désilicieras": ("désilicier",),
    "désilicièrent": ("désilicier",),
    "désilicierez": ("désilicier",),
    "désilicieriez": ("désilicier",),
    "désilicierions": ("désilicier",),
    "désilicierons": ("désilicier",),
    "désilicieront": ("désilicier",),
    "désiliciés": ("désilicier",),
    "désilicies": ("désilicier",),
    "désiliciez": ("désilicier",),
    "désiliciiez": ("désilicier",),
    "désiliciions": ("désilicier",),
    "désilicions": ("désilicier",),
    "désilicifiaient": ("désilicifier",),
    "désilicifiai": ("désilicifier",),
    "désilicifiais": ("désilicifier",),
    "désilicifiait": ("désilicifier",),
    "désilicifia": ("désilicifier",),
    "désilicifiâmes": ("désilicifier",),
    "désilicifiant": ("désilicifier",),
    "désilicifias": ("désilicifier",),
    "désilicifiassent": ("désilicifier",),
    "désilicifiasses": ("désilicifier",),
    "désilicifiasse": ("désilicifier",),
    "désilicifiassiez": ("désilicifier",),
    "désilicifiassions": ("désilicifier",),
    "désilicifiâtes": ("désilicifier",),
    "désilicifiât": ("désilicifier",),
    "désilicifiée": ("désilicifier",),
    "désilicifiées": ("désilicifier",),
    "désilicifié": ("désilicifier",),
    "désilicifient": ("désilicifier",),
    "désilicifie": ("désilicifier",),
    "désilicifiera": ("désilicifier",),
    "désilicifieraient": ("désilicifier",),
    "désilicifierai": ("désilicifier",),
    "désilicifierais": ("désilicifier",),
    "désilicifierait": ("désilicifier",),
    "désilicifieras": ("désilicifier",),
    "désilicifièrent": ("désilicifier",),
    "désilicifierez": ("désilicifier",),
    "désilicifieriez": ("désilicifier",),
    "désilicifierions": ("désilicifier",),
    "désilicifierons": ("désilicifier",),
    "désilicifieront": ("désilicifier",),
    "désilicifiés": ("désilicifier",),
    "désilicifies": ("désilicifier",),
    "désilicifiez": ("désilicifier",),
    "désilicifiiez": ("désilicifier",),
    "désilicifiions": ("désilicifier",),
    "désilicifions": ("désilicifier",),
    "désimprégnaient": ("désimprégner",),
    "désimprégnai": ("désimprégner",),
    "désimprégnais": ("désimprégner",),
    "désimprégnait": ("désimprégner",),
    "désimprégna": ("désimprégner",),
    "désimprégnâmes": ("désimprégner",),
    "désimprégnant": ("désimprégner",),
    "désimprégnas": ("désimprégner",),
    "désimprégnassent": ("désimprégner",),
    "désimprégnasses": ("désimprégner",),
    "désimprégnasse": ("désimprégner",),
    "désimprégnassiez": ("désimprégner",),
    "désimprégnassions": ("désimprégner",),
    "désimprégnâtes": ("désimprégner",),
    "désimprégnât": ("désimprégner",),
    "désimprégnée": ("désimprégner",),
    "désimprégnées": ("désimprégner",),
    "désimprégné": ("désimprégner",),
    "désimprègnent": ("désimprégner",),
    "désimprègne": ("désimprégner",),
    "désimprégnera": ("désimprégner",),
    "désimprégneraient": ("désimprégner",),
    "désimprégnerai": ("désimprégner",),
    "désimprégnerais": ("désimprégner",),
    "désimprégnerait": ("désimprégner",),
    "désimprégneras": ("désimprégner",),
    "désimprégnèrent": ("désimprégner",),
    "désimprégnerez": ("désimprégner",),
    "désimprégneriez": ("désimprégner",),
    "désimprégnerions": ("désimprégner",),
    "désimprégnerons": ("désimprégner",),
    "désimprégneront": ("désimprégner",),
    "désimprégnés": ("désimprégner",),
    "désimprègnes": ("désimprégner",),
    "désimprégnez": ("désimprégner",),
    "désimprégniez": ("désimprégner",),
    "désimprégnions": ("désimprégner",),
    "désimprégnons": ("désimprégner",),
    "désincarcéraient": ("désincarcérer",),
    "désincarcérai": ("désincarcérer",),
    "désincarcérais": ("désincarcérer",),
    "désincarcérait": ("désincarcérer",),
    "désincarcéra": ("désincarcérer",),
    "désincarcérâmes": ("désincarcérer",),
    "désincarcérant": ("désincarcérer",),
    "désincarcéras": ("désincarcérer",),
    "désincarcérassent": ("désincarcérer",),
    "désincarcérasses": ("désincarcérer",),
    "désincarcérasse": ("désincarcérer",),
    "désincarcérassiez": ("désincarcérer",),
    "désincarcérassions": ("désincarcérer",),
    "désincarcérâtes": ("désincarcérer",),
    "désincarcérât": ("désincarcérer",),
    "désincarcérée": ("désincarcérer",),
    "désincarcérées": ("désincarcérer",),
    "désincarcéré": ("désincarcérer",),
    "désincarcèrent": ("désincarcérer",),
    "désincarcère": ("désincarcérer",),
    "désincarcérera": ("désincarcérer",),
    "désincarcéreraient": ("désincarcérer",),
    "désincarcérerai": ("désincarcérer",),
    "désincarcérerais": ("désincarcérer",),
    "désincarcérerait": ("désincarcérer",),
    "désincarcéreras": ("désincarcérer",),
    "désincarcérèrent": ("désincarcérer",),
    "désincarcérerez": ("désincarcérer",),
    "désincarcéreriez": ("désincarcérer",),
    "désincarcérerions": ("désincarcérer",),
    "désincarcérerons": ("désincarcérer",),
    "désincarcéreront": ("désincarcérer",),
    "désincarcérés": ("désincarcérer",),
    "désincarcères": ("désincarcérer",),
    "désincarcérez": ("désincarcérer",),
    "désincarcériez": ("désincarcérer",),
    "désincarcérions": ("désincarcérer",),
    "désincarcérons": ("désincarcérer",),
    "désindiçaient": ("désindicer",),
    "désindiçai": ("désindicer",),
    "désindiçais": ("désindicer",),
    "désindiçait": ("désindicer",),
    "désindiça": ("désindicer",),
    "désindiçâmes": ("désindicer",),
    "désindiçant": ("désindicer",),
    "désindiças": ("désindicer",),
    "désindiçassent": ("désindicer",),
    "désindiçasses": ("désindicer",),
    "désindiçasse": ("désindicer",),
    "désindiçassiez": ("désindicer",),
    "désindiçassions": ("désindicer",),
    "désindiçâtes": ("désindicer",),
    "désindiçât": ("désindicer",),
    "désindicée": ("désindicer",),
    "désindicées": ("désindicer",),
    "désindicé": ("désindicer",),
    "désindicent": ("désindicer",),
    "désindice": ("désindicer",),
    "désindicera": ("désindicer",),
    "désindiceraient": ("désindicer",),
    "désindicerai": ("désindicer",),
    "désindicerais": ("désindicer",),
    "désindicerait": ("désindicer",),
    "désindiceras": ("désindicer",),
    "désindicèrent": ("désindicer",),
    "désindicerez": ("désindicer",),
    "désindiceriez": ("désindicer",),
    "désindicerions": ("désindicer",),
    "désindicerons": ("désindicer",),
    "désindiceront": ("désindicer",),
    "désindicés": ("désindicer",),
    "désindices": ("désindicer",),
    "désindicez": ("désindicer",),
    "désindiciez": ("désindicer",),
    "désindicions": ("désindicer",),
    "désindiçons": ("désindicer",),
    "désinscrira": ("désinscrire",),
    "désinscriraient": ("désinscrire",),
    "désinscrirai": ("désinscrire",),
    "désinscrirais": ("désinscrire",),
    "désinscrirait": ("désinscrire",),
    "désinscriras": ("désinscrire",),
    "désinscrirez": ("désinscrire",),
    "désinscririez": ("désinscrire",),
    "désinscririons": ("désinscrire",),
    "désinscrirons": ("désinscrire",),
    "désinscriront": ("désinscrire",),
    "désinscris": ("désinscrire",),
    "désinscrite": ("désinscrire",),
    "désinscrites": ("désinscrire",),
    "désinscrit": ("désinscrire",),
    "désinscrits": ("désinscrire",),
    "désinscrivaient": ("désinscrire",),
    "désinscrivais": ("désinscrire",),
    "désinscrivait": ("désinscrire",),
    "désinscrivant": ("désinscrire",),
    "désinscrivent": ("désinscrire",),
    "désinscrive": ("désinscrire",),
    "désinscrives": ("désinscrire",),
    "désinscrivez": ("désinscrire",),
    "désinscriviez": ("désinscrire",),
    "désinscrivîmes": ("désinscrire",),
    "désinscrivions": ("désinscrire",),
    "désinscrivirent": ("désinscrire",),
    "désinscrivis": ("désinscrire",),
    "désinscrivissent": ("désinscrire",),
    "désinscrivisses": ("désinscrire",),
    "désinscrivisse": ("désinscrire",),
    "désinscrivissiez": ("désinscrire",),
    "désinscrivissions": ("désinscrire",),
    "désinscrivîtes": ("désinscrire",),
    "désinscrivit": ("désinscrire",),
    "désinscrivît": ("désinscrire",),
    "désinscrivons": ("désinscrire",),
    "désinséraient": ("désinsérer",),
    "désinsérai": ("désinsérer",),
    "désinsérais": ("désinsérer",),
    "désinsérait": ("désinsérer",),
    "désinséra": ("désinsérer",),
    "désinsérâmes": ("désinsérer",),
    "désinsérant": ("désinsérer",),
    "désinséras": ("désinsérer",),
    "désinsérassent": ("désinsérer",),
    "désinsérasses": ("désinsérer",),
    "désinsérasse": ("désinsérer",),
    "désinsérassiez": ("désinsérer",),
    "désinsérassions": ("désinsérer",),
    "désinsérâtes": ("désinsérer",),
    "désinsérât": ("désinsérer",),
    "désinsérée": ("désinsérer",),
    "désinsérées": ("désinsérer",),
    "désinséré": ("désinsérer",),
    "désinsèrent": ("désinsérer",),
    "désinsère": ("désinsérer",),
    "désinsérera": ("désinsérer",),
    "désinséreraient": ("désinsérer",),
    "désinsérerai": ("désinsérer",),
    "désinsérerais": ("désinsérer",),
    "désinsérerait": ("désinsérer",),
    "désinséreras": ("désinsérer",),
    "désinsérèrent": ("désinsérer",),
    "désinsérerez": ("désinsérer",),
    "désinséreriez": ("désinsérer",),
    "désinsérerions": ("désinsérer",),
    "désinsérerons": ("désinsérer",),
    "désinséreront": ("désinsérer",),
    "désinsérés": ("désinsérer",),
    "désinsères": ("désinsérer",),
    "désinsérez": ("désinsérer",),
    "désinsériez": ("désinsérer",),
    "désinsérions": ("désinsérer",),
    "désinsérons": ("désinsérer",),
    "désintégraient": ("désintégrer",),
    "désintégrai": ("désintégrer",),
    "désintégrais": ("désintégrer",),
    "désintégrait": ("désintégrer",),
    "désintégra": ("désintégrer",),
    "désintégrâmes": ("désintégrer",),
    "désintégrant": ("désintégrer",),
    "désintégras": ("désintégrer",),
    "désintégrassent": ("désintégrer",),
    "désintégrasses": ("désintégrer",),
    "désintégrasse": ("désintégrer",),
    "désintégrassiez": ("désintégrer",),
    "désintégrassions": ("désintégrer",),
    "désintégrâtes": ("désintégrer",),
    "désintégrât": ("désintégrer",),
    "désintégrée": ("désintégrer",),
    "désintégrées": ("désintégrer",),
    "désintégré": ("désintégrer",),
    "désintègrent": ("désintégrer",),
    "désintègre": ("désintégrer",),
    "désintégrera": ("désintégrer",),
    "désintégreraient": ("désintégrer",),
    "désintégrerai": ("désintégrer",),
    "désintégrerais": ("désintégrer",),
    "désintégrerait": ("désintégrer",),
    "désintégreras": ("désintégrer",),
    "désintégrèrent": ("désintégrer",),
    "désintégrerez": ("désintégrer",),
    "désintégreriez": ("désintégrer",),
    "désintégrerions": ("désintégrer",),
    "désintégrerons": ("désintégrer",),
    "désintégreront": ("désintégrer",),
    "désintégrés": ("désintégrer",),
    "désintègres": ("désintégrer",),
    "désintégrez": ("désintégrer",),
    "désintégriez": ("désintégrer",),
    "désintégrions": ("désintégrer",),
    "désintégrons": ("désintégrer",),
    "désinvestie": ("désinvestir",),
    "désinvesties": ("désinvestir",),
    "désinvesti": ("désinvestir",),
    "désinvestîmes": ("désinvestir",),
    "désinvestira": ("désinvestir",),
    "désinvestiraient": ("désinvestir",),
    "désinvestirai": ("désinvestir",),
    "désinvestirais": ("désinvestir",),
    "désinvestirait": ("désinvestir",),
    "désinvestiras": ("désinvestir",),
    "désinvestirent": ("désinvestir",),
    "désinvestirez": ("désinvestir",),
    "désinvestiriez": ("désinvestir",),
    "désinvestirions": ("désinvestir",),
    "désinvestirons": ("désinvestir",),
    "désinvestiront": ("désinvestir",),
    "désinvestis": ("désinvestir",),
    "désinvestissaient": ("désinvestir",),
    "désinvestissais": ("désinvestir",),
    "désinvestissait": ("désinvestir",),
    "désinvestissant": ("désinvestir",),
    "désinvestissent": ("désinvestir",),
    "désinvestisse": ("désinvestir",),
    "désinvestisses": ("désinvestir",),
    "désinvestissez": ("désinvestir",),
    "désinvestissiez": ("désinvestir",),
    "désinvestissions": ("désinvestir",),
    "désinvestissons": ("désinvestir",),
    "désinvestîtes": ("désinvestir",),
    "désinvestit": ("désinvestir",),
    "désinvestît": ("désinvestir",),
    "désirradiaient": ("désirradier",),
    "désirradiai": ("désirradier",),
    "désirradiais": ("désirradier",),
    "désirradiait": ("désirradier",),
    "désirradia": ("désirradier",),
    "désirradiâmes": ("désirradier",),
    "désirradiant": ("désirradier",),
    "désirradias": ("désirradier",),
    "désirradiassent": ("désirradier",),
    "désirradiasses": ("désirradier",),
    "désirradiasse": ("désirradier",),
    "désirradiassiez": ("désirradier",),
    "désirradiassions": ("désirradier",),
    "désirradiâtes": ("désirradier",),
    "désirradiât": ("désirradier",),
    "désirradiée": ("désirradier",),
    "désirradiées": ("désirradier",),
    "désirradié": ("désirradier",),
    "désirradient": ("désirradier",),
    "désirradie": ("désirradier",),
    "désirradiera": ("désirradier",),
    "désirradieraient": ("désirradier",),
    "désirradierai": ("désirradier",),
    "désirradierais": ("désirradier",),
    "désirradierait": ("désirradier",),
    "désirradieras": ("désirradier",),
    "désirradièrent": ("désirradier",),
    "désirradierez": ("désirradier",),
    "désirradieriez": ("désirradier",),
    "désirradierions": ("désirradier",),
    "désirradierons": ("désirradier",),
    "désirradieront": ("désirradier",),
    "désirradiés": ("désirradier",),
    "désirradies": ("désirradier",),
    "désirradiez": ("désirradier",),
    "désirradiiez": ("désirradier",),
    "désirradiions": ("désirradier",),
    "désirradions": ("désirradier",),
    "désobéi": ("désobéir",),
    "désobéîmes": ("désobéir",),
    "désobéira": ("désobéir",),
    "désobéiraient": ("désobéir",),
    "désobéirai": ("désobéir",),
    "désobéirais": ("désobéir",),
    "désobéirait": ("désobéir",),
    "désobéiras": ("désobéir",),
    "désobéirent": ("désobéir",),
    "désobéirez": ("désobéir",),
    "désobéiriez": ("désobéir",),
    "désobéirions": ("désobéir",),
    "désobéirons": ("désobéir",),
    "désobéiront": ("désobéir",),
    "désobéis": ("désobéir",),
    "désobéissaient": ("désobéir",),
    "désobéissais": ("désobéir",),
    "désobéissait": ("désobéir",),
    "désobéissant": ("désobéir",),
    "désobéissent": ("désobéir",),
    "désobéisse": ("désobéir",),
    "désobéisses": ("désobéir",),
    "désobéissez": ("désobéir",),
    "désobéissiez": ("désobéir",),
    "désobéissions": ("désobéir",),
    "désobéissons": ("désobéir",),
    "désobéîtes": ("désobéir",),
    "désobéit": ("désobéir",),
    "désobéît": ("désobéir",),
    "désobligeaient": ("désobliger",),
    "désobligeai": ("désobliger",),
    "désobligeais": ("désobliger",),
    "désobligeait": ("désobliger",),
    "désobligea": ("désobliger",),
    "désobligeâmes": ("désobliger",),
    "désobligeant": ("désobliger",),
    "désobligeas": ("désobliger",),
    "désobligeassent": ("désobliger",),
    "désobligeasses": ("désobliger",),
    "désobligeasse": ("désobliger",),
    "désobligeassiez": ("désobliger",),
    "désobligeassions": ("désobliger",),
    "désobligeâtes": ("désobliger",),
    "désobligeât": ("désobliger",),
    "désobligée": ("désobliger",),
    "désobligées": ("désobliger",),
    "désobligé": ("désobliger",),
    "désobligent": ("désobliger",),
    "désobligeons": ("désobliger",),
    "désoblige": ("désobliger",),
    "désobligera": ("désobliger",),
    "désobligeraient": ("désobliger",),
    "désobligerai": ("désobliger",),
    "désobligerais": ("désobliger",),
    "désobligerait": ("désobliger",),
    "désobligeras": ("désobliger",),
    "désobligèrent": ("désobliger",),
    "désobligerez": ("désobliger",),
    "désobligeriez": ("désobliger",),
    "désobligerions": ("désobliger",),
    "désobligerons": ("désobliger",),
    "désobligeront": ("désobliger",),
    "désobligés": ("désobliger",),
    "désobliges": ("désobliger",),
    "désobligez": ("désobliger",),
    "désobligiez": ("désobliger",),
    "désobligions": ("désobliger",),
    "désobscurcie": ("désobscurcir",),
    "désobscurcies": ("désobscurcir",),
    "désobscurci": ("désobscurcir",),
    "désobscurcîmes": ("désobscurcir",),
    "désobscurcira": ("désobscurcir",),
    "désobscurciraient": ("désobscurcir",),
    "désobscurcirai": ("désobscurcir",),
    "désobscurcirais": ("désobscurcir",),
    "désobscurcirait": ("désobscurcir",),
    "désobscurciras": ("désobscurcir",),
    "désobscurcirent": ("désobscurcir",),
    "désobscurcirez": ("désobscurcir",),
    "désobscurciriez": ("désobscurcir",),
    "désobscurcirions": ("désobscurcir",),
    "désobscurcirons": ("désobscurcir",),
    "désobscurciront": ("désobscurcir",),
    "désobscurcis": ("désobscurcir",),
    "désobscurcissaient": ("désobscurcir",),
    "désobscurcissais": ("désobscurcir",),
    "désobscurcissait": ("désobscurcir",),
    "désobscurcissant": ("désobscurcir",),
    "désobscurcissent": ("désobscurcir",),
    "désobscurcisse": ("désobscurcir",),
    "désobscurcisses": ("désobscurcir",),
    "désobscurcissez": ("désobscurcir",),
    "désobscurcissiez": ("désobscurcir",),
    "désobscurcissions": ("désobscurcir",),
    "désobscurcissons": ("désobscurcir",),
    "désobscurcîtes": ("désobscurcir",),
    "désobscurcit": ("désobscurcir",),
    "désobscurcît": ("désobscurcir",),
    "désobsédaient": ("désobséder",),
    "désobsédai": ("désobséder",),
    "désobsédais": ("désobséder",),
    "désobsédait": ("désobséder",),
    "désobséda": ("désobséder",),
    "désobsédâmes": ("désobséder",),
    "désobsédant": ("désobséder",),
    "désobsédas": ("désobséder",),
    "désobsédassent": ("désobséder",),
    "désobsédasses": ("désobséder",),
    "désobsédasse": ("désobséder",),
    "désobsédassiez": ("désobséder",),
    "désobsédassions": ("désobséder",),
    "désobsédâtes": ("désobséder",),
    "désobsédât": ("désobséder",),
    "désobsédée": ("désobséder",),
    "désobsédées": ("désobséder",),
    "désobsédé": ("désobséder",),
    "désobsèdent": ("désobséder",),
    "désobsède": ("désobséder",),
    "désobsédera": ("désobséder",),
    "désobséderaient": ("désobséder",),
    "désobséderai": ("désobséder",),
    "désobséderais": ("désobséder",),
    "désobséderait": ("désobséder",),
    "désobséderas": ("désobséder",),
    "désobsédèrent": ("désobséder",),
    "désobséderez": ("désobséder",),
    "désobséderiez": ("désobséder",),
    "désobséderions": ("désobséder",),
    "désobséderons": ("désobséder",),
    "désobséderont": ("désobséder",),
    "désobsédés": ("désobséder",),
    "désobsèdes": ("désobséder",),
    "désobsédez": ("désobséder",),
    "désobsédiez": ("désobséder",),
    "désobsédions": ("désobséder",),
    "désobsédons": ("désobséder",),
    "désorthographiaient": ("désorthographier",),
    "désorthographiai": ("désorthographier",),
    "désorthographiais": ("désorthographier",),
    "désorthographiait": ("désorthographier",),
    "désorthographia": ("désorthographier",),
    "désorthographiâmes": ("désorthographier",),
    "désorthographiant": ("désorthographier",),
    "désorthographias": ("désorthographier",),
    "désorthographiassent": ("désorthographier",),
    "désorthographiasses": ("désorthographier",),
    "désorthographiasse": ("désorthographier",),
    "désorthographiassiez": ("désorthographier",),
    "désorthographiassions": ("désorthographier",),
    "désorthographiâtes": ("désorthographier",),
    "désorthographiât": ("désorthographier",),
    "désorthographiée": ("désorthographier",),
    "désorthographiées": ("désorthographier",),
    "désorthographié": ("désorthographier",),
    "désorthographient": ("désorthographier",),
    "désorthographie": ("désorthographier",),
    "désorthographiera": ("désorthographier",),
    "désorthographieraient": ("désorthographier",),
    "désorthographierai": ("désorthographier",),
    "désorthographierais": ("désorthographier",),
    "désorthographierait": ("désorthographier",),
    "désorthographieras": ("désorthographier",),
    "désorthographièrent": ("désorthographier",),
    "désorthographierez": ("désorthographier",),
    "désorthographieriez": ("désorthographier",),
    "désorthographierions": ("désorthographier",),
    "désorthographierons": ("désorthographier",),
    "désorthographieront": ("désorthographier",),
    "désorthographiés": ("désorthographier",),
    "désorthographies": ("désorthographier",),
    "désorthographiez": ("désorthographier",),
    "désorthographiiez": ("désorthographier",),
    "désorthographiions": ("désorthographier",),
    "désorthographions": ("désorthographier",),
    "désoxygénaient": ("désoxygéner",),
    "désoxygénai": ("désoxygéner",),
    "désoxygénais": ("désoxygéner",),
    "désoxygénait": ("désoxygéner",),
    "désoxygéna": ("désoxygéner",),
    "désoxygénâmes": ("désoxygéner",),
    "désoxygénant": ("désoxygéner",),
    "désoxygénas": ("désoxygéner",),
    "désoxygénassent": ("désoxygéner",),
    "désoxygénasses": ("désoxygéner",),
    "désoxygénasse": ("désoxygéner",),
    "désoxygénassiez": ("désoxygéner",),
    "désoxygénassions": ("désoxygéner",),
    "désoxygénâtes": ("désoxygéner",),
    "désoxygénât": ("désoxygéner",),
    "désoxygénée": ("désoxygéner",),
    "désoxygénées": ("désoxygéner",),
    "désoxygéné": ("désoxygéner",),
    "désoxygènent": ("désoxygéner",),
    "désoxygène": ("désoxygéner",),
    "désoxygénera": ("désoxygéner",),
    "désoxygéneraient": ("désoxygéner",),
    "désoxygénerai": ("désoxygéner",),
    "désoxygénerais": ("désoxygéner",),
    "désoxygénerait": ("désoxygéner",),
    "désoxygéneras": ("désoxygéner",),
    "désoxygénèrent": ("désoxygéner",),
    "désoxygénerez": ("désoxygéner",),
    "désoxygéneriez": ("désoxygéner",),
    "désoxygénerions": ("désoxygéner",),
    "désoxygénerons": ("désoxygéner",),
    "désoxygéneront": ("désoxygéner",),
    "désoxygénés": ("désoxygéner",),
    "désoxygènes": ("désoxygéner",),
    "désoxygénez": ("désoxygéner",),
    "désoxygéniez": ("désoxygéner",),
    "désoxygénions": ("désoxygéner",),
    "désoxygénons": ("désoxygéner",),
    "desparageaient": ("desparager",),
    "desparageai": ("desparager",),
    "desparageais": ("desparager",),
    "desparageait": ("desparager",),
    "desparagea": ("desparager",),
    "desparageâmes": ("desparager",),
    "desparageant": ("desparager",),
    "desparageas": ("desparager",),
    "desparageassent": ("desparager",),
    "desparageasses": ("desparager",),
    "desparageasse": ("desparager",),
    "desparageassiez": ("desparager",),
    "desparageassions": ("desparager",),
    "desparageâtes": ("desparager",),
    "desparageât": ("desparager",),
    "desparagée": ("desparager",),
    "desparagées": ("desparager",),
    "desparagé": ("desparager",),
    "desparagent": ("desparager",),
    "desparageons": ("desparager",),
    "desparage": ("desparager",),
    "desparagera": ("desparager",),
    "desparageraient": ("desparager",),
    "desparagerai": ("desparager",),
    "desparagerais": ("desparager",),
    "desparagerait": ("desparager",),
    "desparageras": ("desparager",),
    "desparagèrent": ("desparager",),
    "desparagerez": ("desparager",),
    "desparageriez": ("desparager",),
    "desparagerions": ("desparager",),
    "desparagerons": ("desparager",),
    "desparageront": ("desparager",),
    "desparagés": ("desparager",),
    "desparages": ("desparager",),
    "desparagez": ("desparager",),
    "desparagiez": ("desparager",),
    "desparagions": ("desparager",),
    "dessaisie": ("dessaisir",),
    "dessaisies": ("dessaisir",),
    "dessaisi": ("dessaisir",),
    "dessaisîmes": ("dessaisir",),
    "dessaisira": ("dessaisir",),
    "dessaisiraient": ("dessaisir",),
    "dessaisirai": ("dessaisir",),
    "dessaisirais": ("dessaisir",),
    "dessaisirait": ("dessaisir",),
    "dessaisiras": ("dessaisir",),
    "dessaisirent": ("dessaisir",),
    "dessaisirez": ("dessaisir",),
    "dessaisiriez": ("dessaisir",),
    "dessaisirions": ("dessaisir",),
    "dessaisirons": ("dessaisir",),
    "dessaisiront": ("dessaisir",),
    "dessaisis": ("dessaisir",),
    "dessaisissaient": ("dessaisir",),
    "dessaisissais": ("dessaisir",),
    "dessaisissait": ("dessaisir",),
    "dessaisissant": ("dessaisir",),
    "dessaisissent": ("dessaisir",),
    "dessaisisse": ("dessaisir",),
    "dessaisisses": ("dessaisir",),
    "dessaisissez": ("dessaisir",),
    "dessaisissiez": ("dessaisir",),
    "dessaisissions": ("dessaisir",),
    "dessaisissons": ("dessaisir",),
    "dessaisîtes": ("dessaisir",),
    "dessaisit": ("dessaisir",),
    "dessaisît": ("dessaisir",),
    "desséchaient": ("dessécher",),
    "desséchai": ("dessécher",),
    "desséchais": ("dessécher",),
    "desséchait": ("dessécher",),
    "dessécha": ("dessécher",),
    "desséchâmes": ("dessécher",),
    "desséchant": ("dessécher",),
    "desséchas": ("dessécher",),
    "desséchassent": ("dessécher",),
    "desséchasses": ("dessécher",),
    "desséchasse": ("dessécher",),
    "desséchassiez": ("dessécher",),
    "desséchassions": ("dessécher",),
    "desséchâtes": ("dessécher",),
    "desséchât": ("dessécher",),
    "desséchée": ("dessécher",),
    "desséchées": ("dessécher",),
    "desséché": ("dessécher",),
    "dessèchent": ("dessécher",),
    "dessèche": ("dessécher",),
    "desséchera": ("dessécher",),
    "dessécheraient": ("dessécher",),
    "dessécherai": ("dessécher",),
    "dessécherais": ("dessécher",),
    "dessécherait": ("dessécher",),
    "dessécheras": ("dessécher",),
    "desséchèrent": ("dessécher",),
    "dessécherez": ("dessécher",),
    "dessécheriez": ("dessécher",),
    "dessécherions": ("dessécher",),
    "dessécherons": ("dessécher",),
    "dessécheront": ("dessécher",),
    "desséchés": ("dessécher",),
    "dessèches": ("dessécher",),
    "desséchez": ("dessécher",),
    "desséchiez": ("dessécher",),
    "desséchions": ("dessécher",),
    "desséchons": ("dessécher",),
    "dessemelaient": ("dessemeler",),
    "dessemelai": ("dessemeler",),
    "dessemelais": ("dessemeler",),
    "dessemelait": ("dessemeler",),
    "dessemela": ("dessemeler",),
    "dessemelâmes": ("dessemeler",),
    "dessemelant": ("dessemeler",),
    "dessemelas": ("dessemeler",),
    "dessemelassent": ("dessemeler",),
    "dessemelasses": ("dessemeler",),
    "dessemelasse": ("dessemeler",),
    "dessemelassiez": ("dessemeler",),
    "dessemelassions": ("dessemeler",),
    "dessemelâtes": ("dessemeler",),
    "dessemelât": ("dessemeler",),
    "dessemelée": ("dessemeler",),
    "dessemelées": ("dessemeler",),
    "dessemelé": ("dessemeler",),
    "dessemelèrent": ("dessemeler",),
    "dessemelés": ("dessemeler",),
    "dessemelez": ("dessemeler",),
    "dessemeliez": ("dessemeler",),
    "dessemelions": ("dessemeler",),
    "dessemellent": ("dessemeler",),
    "dessemelle": ("dessemeler",),
    "dessemellera": ("dessemeler",),
    "dessemelleraient": ("dessemeler",),
    "dessemellerai": ("dessemeler",),
    "dessemellerais": ("dessemeler",),
    "dessemellerait": ("dessemeler",),
    "dessemelleras": ("dessemeler",),
    "dessemellerez": ("dessemeler",),
    "dessemelleriez": ("dessemeler",),
    "dessemellerions": ("dessemeler",),
    "dessemellerons": ("dessemeler",),
    "dessemelleront": ("dessemeler",),
    "dessemelles": ("dessemeler",),
    "dessemelons": ("dessemeler",),
    "dessertie": ("dessertir",),
    "desserties": ("dessertir",),
    "desserti": ("dessertir",),
    "dessertîmes": ("dessertir",),
    "dessertira": ("dessertir",),
    "dessertiraient": ("dessertir",),
    "dessertirai": ("dessertir",),
    "dessertirais": ("dessertir",),
    "dessertirait": ("dessertir",),
    "dessertiras": ("dessertir",),
    "dessertirent": ("dessertir",),
    "dessertirez": ("dessertir",),
    "dessertiriez": ("dessertir",),
    "dessertirions": ("dessertir",),
    "dessertirons": ("dessertir",),
    "dessertiront": ("dessertir",),
    "dessertis": ("dessertir",),
    "dessertissaient": ("dessertir",),
    "dessertissais": ("dessertir",),
    "dessertissait": ("dessertir",),
    "dessertissant": ("dessertir",),
    "dessertissent": ("dessertir",),
    "dessertisse": ("dessertir",),
    "dessertisses": ("dessertir",),
    "dessertissez": ("dessertir",),
    "dessertissiez": ("dessertir",),
    "dessertissions": ("dessertir",),
    "dessertissons": ("dessertir",),
    "dessertîtes": ("dessertir",),
    "dessertit": ("dessertir",),
    "dessertît": ("dessertir",),
    "dessers": ("desservir",),
    "dessert": ("desservir",),
    "desservaient": ("desservir",),
    "desservais": ("desservir",),
    "desservait": ("desservir",),
    "desservant": ("desservir",),
    "desservent": ("desservir",),
    "desserve": ("desservir",),
    "desserves": ("desservir",),
    "desservez": ("desservir",),
    "desservie": ("desservir",),
    "desservies": ("desservir",),
    "desserviez": ("desservir",),
    "desservi": ("desservir",),
    "desservîmes": ("desservir",),
    "desservions": ("desservir",),
    "desservira": ("desservir",),
    "desserviraient": ("desservir",),
    "desservirai": ("desservir",),
    "desservirais": ("desservir",),
    "desservirait": ("desservir",),
    "desserviras": ("desservir",),
    "desservirent": ("desservir",),
    "desservirez": ("desservir",),
    "desserviriez": ("desservir",),
    "desservirions": ("desservir",),
    "desservirons": ("desservir",),
    "desserviront": ("desservir",),
    "desservis": ("desservir",),
    "desservissent": ("desservir",),
    "desservisses": ("desservir",),
    "desservisse": ("desservir",),
    "desservissiez": ("desservir",),
    "desservissions": ("desservir",),
    "desservîtes": ("desservir",),
    "desservit": ("desservir",),
    "desservît": ("desservir",),
    "desservons": ("desservir",),
    "dessévaient": ("desséver",),
    "dessévai": ("desséver",),
    "dessévais": ("desséver",),
    "dessévait": ("desséver",),
    "desséva": ("desséver",),
    "dessévâmes": ("desséver",),
    "dessévant": ("desséver",),
    "dessévas": ("desséver",),
    "dessévassent": ("desséver",),
    "dessévasses": ("desséver",),
    "dessévasse": ("desséver",),
    "dessévassiez": ("desséver",),
    "dessévassions": ("desséver",),
    "dessévâtes": ("desséver",),
    "dessévât": ("desséver",),
    "dessévée": ("desséver",),
    "dessévées": ("desséver",),
    "dessévé": ("desséver",),
    "dessèvent": ("desséver",),
    "dessève": ("desséver",),
    "dessévera": ("desséver",),
    "desséveraient": ("desséver",),
    "desséverai": ("desséver",),
    "desséverais": ("desséver",),
    "desséverait": ("desséver",),
    "desséveras": ("desséver",),
    "dessévèrent": ("desséver",),
    "desséverez": ("desséver",),
    "desséveriez": ("desséver",),
    "desséverions": ("desséver",),
    "desséverons": ("desséver",),
    "desséveront": ("desséver",),
    "dessévés": ("desséver",),
    "dessèves": ("desséver",),
    "dessévez": ("desséver",),
    "desséviez": ("desséver",),
    "dessévions": ("desséver",),
    "dessévons": ("desséver",),
    "désunifiaient": ("désunifier",),
    "désunifiai": ("désunifier",),
    "désunifiais": ("désunifier",),
    "désunifiait": ("désunifier",),
    "désunifia": ("désunifier",),
    "désunifiâmes": ("désunifier",),
    "désunifiant": ("désunifier",),
    "désunifias": ("désunifier",),
    "désunifiassent": ("désunifier",),
    "désunifiasses": ("désunifier",),
    "désunifiasse": ("désunifier",),
    "désunifiassiez": ("désunifier",),
    "désunifiassions": ("désunifier",),
    "désunifiâtes": ("désunifier",),
    "désunifiât": ("désunifier",),
    "désunifiée": ("désunifier",),
    "désunifiées": ("désunifier",),
    "désunifié": ("désunifier",),
    "désunifient": ("désunifier",),
    "désunifie": ("désunifier",),
    "désunifiera": ("désunifier",),
    "désunifieraient": ("désunifier",),
    "désunifierai": ("désunifier",),
    "désunifierais": ("désunifier",),
    "désunifierait": ("désunifier",),
    "désunifieras": ("désunifier",),
    "désunifièrent": ("désunifier",),
    "désunifierez": ("désunifier",),
    "désunifieriez": ("désunifier",),
    "désunifierions": ("désunifier",),
    "désunifierons": ("désunifier",),
    "désunifieront": ("désunifier",),
    "désunifiés": ("désunifier",),
    "désunifies": ("désunifier",),
    "désunifiez": ("désunifier",),
    "désunifiiez": ("désunifier",),
    "désunifiions": ("désunifier",),
    "désunifions": ("désunifier",),
    "désunie": ("désunir",),
    "désunies": ("désunir",),
    "désuni": ("désunir",),
    "désunîmes": ("désunir",),
    "désunira": ("désunir",),
    "désuniraient": ("désunir",),
    "désunirai": ("désunir",),
    "désunirais": ("désunir",),
    "désunirait": ("désunir",),
    "désuniras": ("désunir",),
    "désunirent": ("désunir",),
    "désunirez": ("désunir",),
    "désuniriez": ("désunir",),
    "désunirions": ("désunir",),
    "désunirons": ("désunir",),
    "désuniront": ("désunir",),
    "désunis": ("désunir",),
    "désunissaient": ("désunir",),
    "désunissais": ("désunir",),
    "désunissait": ("désunir",),
    "désunissant": ("désunir",),
    "désunissent": ("désunir",),
    "désunisse": ("désunir",),
    "désunisses": ("désunir",),
    "désunissez": ("désunir",),
    "désunissiez": ("désunir",),
    "désunissions": ("désunir",),
    "désunissons": ("désunir",),
    "désunîtes": ("désunir",),
    "désunit": ("désunir",),
    "désunît": ("désunir",),
    "détassaient": ("détasser",),
    "détassai": ("détasser",),
    "détassais": ("détasser",),
    "détassait": ("détasser",),
    "détassa": ("détasser",),
    "détassâmes": ("détasser",),
    "détassant": ("détasser",),
    "détassas": ("détasser",),
    "détassassent": ("détasser",),
    "détassasses": ("détasser",),
    "détassasse": ("détasser",),
    "détassassiez": ("détasser",),
    "détassassions": ("détasser",),
    "détassâtes": ("détasser",),
    "détassât": ("détasser",),
    "détassée": ("détasser",),
    "détassées": ("détasser",),
    "détassé": ("détasser",),
    "détassent": ("détasser",),
    "détasse": ("détasser",),
    "détassera": ("détasser",),
    "détasseraient": ("détasser",),
    "détasserai": ("détasser",),
    "détasserais": ("détasser",),
    "détasserait": ("détasser",),
    "détasseras": ("détasser",),
    "détassèrent": ("détasser",),
    "détasserez": ("détasser",),
    "détasseriez": ("détasser",),
    "détasserions": ("détasser",),
    "détasserons": ("détasser",),
    "détasseront": ("détasser",),
    "détassés": ("détasser",),
    "détasses": ("détasser",),
    "détassez": ("détasser",),
    "détassiez": ("détasser",),
    "détassions": ("détasser",),
    "détassons": ("détasser",),
    "déteignaient": ("déteindre",),
    "déteignais": ("déteindre",),
    "déteignait": ("déteindre",),
    "déteignant": ("déteindre",),
    "déteignent": ("déteindre",),
    "déteigne": ("déteindre",),
    "déteignes": ("déteindre",),
    "déteignez": ("déteindre",),
    "déteigniez": ("déteindre",),
    "déteignîmes": ("déteindre",),
    "déteignions": ("déteindre",),
    "déteignirent": ("déteindre",),
    "déteignis": ("déteindre",),
    "déteignissent": ("déteindre",),
    "déteignisses": ("déteindre",),
    "déteignisse": ("déteindre",),
    "déteignissiez": ("déteindre",),
    "déteignissions": ("déteindre",),
    "déteignîtes": ("déteindre",),
    "déteignit": ("déteindre",),
    "déteignît": ("déteindre",),
    "déteignons": ("déteindre",),
    "déteindra": ("déteindre",),
    "déteindraient": ("déteindre",),
    "déteindrai": ("déteindre",),
    "déteindrais": ("déteindre",),
    "déteindrait": ("déteindre",),
    "déteindras": ("déteindre",),
    "déteindrez": ("déteindre",),
    "déteindriez": ("déteindre",),
    "déteindrions": ("déteindre",),
    "déteindrons": ("déteindre",),
    "déteindront": ("déteindre",),
    "déteins": ("déteindre",),
    "déteinte": ("déteindre",),
    "déteintes": ("déteindre",),
    "déteint": ("déteindre",),
    "déteints": ("déteindre",),
    "dételaient": ("dételer",),
    "dételai": ("dételer",),
    "dételais": ("dételer",),
    "dételait": ("dételer",),
    "détela": ("dételer",),
    "dételâmes": ("dételer",),
    "dételant": ("dételer",),
    "dételas": ("dételer",),
    "dételassent": ("dételer",),
    "dételasses": ("dételer",),
    "dételasse": ("dételer",),
    "dételassiez": ("dételer",),
    "dételassions": ("dételer",),
    "dételâtes": ("dételer",),
    "dételât": ("dételer",),
    "dételée": ("dételer",),
    "dételées": ("dételer",),
    "dételé": ("dételer",),
    "dételèrent": ("dételer",),
    "dételés": ("dételer",),
    "dételez": ("dételer",),
    "dételiez": ("dételer",),
    "dételions": ("dételer",),
    "détellent": ("dételer",),
    "dételle": ("dételer",),
    "détellera": ("dételer",),
    "dételleraient": ("dételer",),
    "détellerai": ("dételer",),
    "détellerais": ("dételer",),
    "détellerait": ("dételer",),
    "dételleras": ("dételer",),
    "détellerez": ("dételer",),
    "dételleriez": ("dételer",),
    "détellerions": ("dételer",),
    "détellerons": ("dételer",),
    "dételleront": ("dételer",),
    "dételles": ("dételer",),
    "dételons": ("dételer",),
    "détendaient": ("détendre",),
    "détendais": ("détendre",),
    "détendait": ("détendre",),
    "détendant": ("détendre",),
    "détendent": ("détendre",),
    "détende": ("détendre",),
    "détendes": ("détendre",),
    "détendez": ("détendre",),
    "détendiez": ("détendre",),
    "détendîmes": ("détendre",),
    "détendions": ("détendre",),
    "détendirent": ("détendre",),
    "détendis": ("détendre",),
    "détendissent": ("détendre",),
    "détendisses": ("détendre",),
    "détendisse": ("détendre",),
    "détendissiez": ("détendre",),
    "détendissions": ("détendre",),
    "détendîtes": ("détendre",),
    "détendit": ("détendre",),
    "détendît": ("détendre",),
    "détendons": ("détendre",),
    "détend": ("détendre",),
    "détendra": ("détendre",),
    "détendraient": ("détendre",),
    "détendrai": ("détendre",),
    "détendrais": ("détendre",),
    "détendrait": ("détendre",),
    "détendras": ("détendre",),
    "détendrez": ("détendre",),
    "détendriez": ("détendre",),
    "détendrions": ("détendre",),
    "détendrons": ("détendre",),
    "détendront": ("détendre",),
    "détends": ("détendre",),
    "détendue": ("détendre",),
    "détendues": ("détendre",),
    "détendu": ("détendre",),
    "détendus": ("détendre",),
    "détenaient": ("détenir",),
    "détenais": ("détenir",),
    "détenait": ("détenir",),
    "détenant": ("détenir",),
    "détenez": ("détenir",),
    "déteniez": ("détenir",),
    "détenions": ("détenir",),
    "détenons": ("détenir",),
    "détenue": ("détenir",),
    "détenues": ("détenir",),
    "détenu": ("détenir",),
    "détenus": ("détenir",),
    "détiendra": ("détenir",),
    "détiendraient": ("détenir",),
    "détiendrai": ("détenir",),
    "détiendrais": ("détenir",),
    "détiendrait": ("détenir",),
    "détiendras": ("détenir",),
    "détiendrez": ("détenir",),
    "détiendriez": ("détenir",),
    "détiendrions": ("détenir",),
    "détiendrons": ("détenir",),
    "détiendront": ("détenir",),
    "détiennent": ("détenir",),
    "détienne": ("détenir",),
    "détiennes": ("détenir",),
    "détiens": ("détenir",),
    "détient": ("détenir",),
    "détînmes": ("détenir",),
    "détinrent": ("détenir",),
    "détins": ("détenir",),
    "détinssent": ("détenir",),
    "détinsses": ("détenir",),
    "détinsse": ("détenir",),
    "détinssiez": ("détenir",),
    "détinssions": ("détenir",),
    "détîntes": ("détenir",),
    "détint": ("détenir",),
    "détînt": ("détenir",),
    "détergeaient": ("déterger",),
    "détergeai": ("déterger",),
    "détergeais": ("déterger",),
    "détergeait": ("déterger",),
    "détergea": ("déterger",),
    "détergeâmes": ("déterger",),
    "détergeant": ("déterger",),
    "détergeas": ("déterger",),
    "détergeassent": ("déterger",),
    "détergeasses": ("déterger",),
    "détergeasse": ("déterger",),
    "détergeassiez": ("déterger",),
    "détergeassions": ("déterger",),
    "détergeâtes": ("déterger",),
    "détergeât": ("déterger",),
    "détergée": ("déterger",),
    "détergées": ("déterger",),
    "détergé": ("déterger",),
    "détergent": ("déterger",),
    "détergeons": ("déterger",),
    "déterge": ("déterger",),
    "détergera": ("déterger",),
    "détergeraient": ("déterger",),
    "détergerai": ("déterger",),
    "détergerais": ("déterger",),
    "détergerait": ("déterger",),
    "détergeras": ("déterger",),
    "détergèrent": ("déterger",),
    "détergerez": ("déterger",),
    "détergeriez": ("déterger",),
    "détergerions": ("déterger",),
    "détergerons": ("déterger",),
    "détergeront": ("déterger",),
    "détergés": ("déterger",),
    "déterges": ("déterger",),
    "détergez": ("déterger",),
    "détergiez": ("déterger",),
    "détergions": ("déterger",),
    "déterpénaient": ("déterpéner",),
    "déterpénai": ("déterpéner",),
    "déterpénais": ("déterpéner",),
    "déterpénait": ("déterpéner",),
    "déterpéna": ("déterpéner",),
    "déterpénâmes": ("déterpéner",),
    "déterpénant": ("déterpéner",),
    "déterpénas": ("déterpéner",),
    "déterpénassent": ("déterpéner",),
    "déterpénasses": ("déterpéner",),
    "déterpénasse": ("déterpéner",),
    "déterpénassiez": ("déterpéner",),
    "déterpénassions": ("déterpéner",),
    "déterpénâtes": ("déterpéner",),
    "déterpénât": ("déterpéner",),
    "déterpénée": ("déterpéner",),
    "déterpénées": ("déterpéner",),
    "déterpéné": ("déterpéner",),
    "déterpènent": ("déterpéner",),
    "déterpène": ("déterpéner",),
    "déterpénera": ("déterpéner",),
    "déterpéneraient": ("déterpéner",),
    "déterpénerai": ("déterpéner",),
    "déterpénerais": ("déterpéner",),
    "déterpénerait": ("déterpéner",),
    "déterpéneras": ("déterpéner",),
    "déterpénèrent": ("déterpéner",),
    "déterpénerez": ("déterpéner",),
    "déterpéneriez": ("déterpéner",),
    "déterpénerions": ("déterpéner",),
    "déterpénerons": ("déterpéner",),
    "déterpéneront": ("déterpéner",),
    "déterpénés": ("déterpéner",),
    "déterpènes": ("déterpéner",),
    "déterpénez": ("déterpéner",),
    "déterpéniez": ("déterpéner",),
    "déterpénions": ("déterpéner",),
    "déterpénons": ("déterpéner",),
    "détonnelaient": ("détonneler",),
    "détonnelai": ("détonneler",),
    "détonnelais": ("détonneler",),
    "détonnelait": ("détonneler",),
    "détonnela": ("détonneler",),
    "détonnelâmes": ("détonneler",),
    "détonnelant": ("détonneler",),
    "détonnelas": ("détonneler",),
    "détonnelassent": ("détonneler",),
    "détonnelasses": ("détonneler",),
    "détonnelasse": ("détonneler",),
    "détonnelassiez": ("détonneler",),
    "détonnelassions": ("détonneler",),
    "détonnelâtes": ("détonneler",),
    "détonnelât": ("détonneler",),
    "détonnelée": ("détonneler",),
    "détonnelées": ("détonneler",),
    "détonnelé": ("détonneler",),
    "détonnelèrent": ("détonneler",),
    "détonnelés": ("détonneler",),
    "détonnelez": ("détonneler",),
    "détonneliez": ("détonneler",),
    "détonnelions": ("détonneler",),
    "détonnellent": ("détonneler",),
    "détonnelle": ("détonneler",),
    "détonnellera": ("détonneler",),
    "détonnelleraient": ("détonneler",),
    "détonnellerai": ("détonneler",),
    "détonnellerais": ("détonneler",),
    "détonnellerait": ("détonneler",),
    "détonnelleras": ("détonneler",),
    "détonnellerez": ("détonneler",),
    "détonnelleriez": ("détonneler",),
    "détonnellerions": ("détonneler",),
    "détonnellerons": ("détonneler",),
    "détonnelleront": ("détonneler",),
    "détonnelles": ("détonneler",),
    "détonnelons": ("détonneler",),
    "détordaient": ("détordre",),
    "détordais": ("détordre",),
    "détordait": ("détordre",),
    "détordant": ("détordre",),
    "détordent": ("détordre",),
    "détorde": ("détordre",),
    "détordes": ("détordre",),
    "détordez": ("détordre",),
    "détordiez": ("détordre",),
    "détordîmes": ("détordre",),
    "détordions": ("détordre",),
    "détordirent": ("détordre",),
    "détordis": ("détordre",),
    "détordissent": ("détordre",),
    "détordisses": ("détordre",),
    "détordisse": ("détordre",),
    "détordissiez": ("détordre",),
    "détordissions": ("détordre",),
    "détordîtes": ("détordre",),
    "détordit": ("détordre",),
    "détordît": ("détordre",),
    "détordons": ("détordre",),
    "détord": ("détordre",),
    "détordra": ("détordre",),
    "détordraient": ("détordre",),
    "détordrai": ("détordre",),
    "détordrais": ("détordre",),
    "détordrait": ("détordre",),
    "détordras": ("détordre",),
    "détordrez": ("détordre",),
    "détordriez": ("détordre",),
    "détordrions": ("détordre",),
    "détordrons": ("détordre",),
    "détordront": ("détordre",),
    "détords": ("détordre",),
    "détordue": ("détordre",),
    "détordues": ("détordre",),
    "détordu": ("détordre",),
    "détordus": ("détordre",),
    "détoxifiaient": ("détoxifier",),
    "détoxifiai": ("détoxifier",),
    "détoxifiais": ("détoxifier",),
    "détoxifiait": ("détoxifier",),
    "détoxifia": ("détoxifier",),
    "détoxifiâmes": ("détoxifier",),
    "détoxifiant": ("détoxifier",),
    "détoxifias": ("détoxifier",),
    "détoxifiassent": ("détoxifier",),
    "détoxifiasses": ("détoxifier",),
    "détoxifiasse": ("détoxifier",),
    "détoxifiassiez": ("détoxifier",),
    "détoxifiassions": ("détoxifier",),
    "détoxifiâtes": ("détoxifier",),
    "détoxifiât": ("détoxifier",),
    "détoxifiée": ("détoxifier",),
    "détoxifiées": ("détoxifier",),
    "détoxifié": ("détoxifier",),
    "détoxifient": ("détoxifier",),
    "détoxifie": ("détoxifier",),
    "détoxifiera": ("détoxifier",),
    "détoxifieraient": ("détoxifier",),
    "détoxifierai": ("détoxifier",),
    "détoxifierais": ("détoxifier",),
    "détoxifierait": ("détoxifier",),
    "détoxifieras": ("détoxifier",),
    "détoxifièrent": ("détoxifier",),
    "détoxifierez": ("détoxifier",),
    "détoxifieriez": ("détoxifier",),
    "détoxifierions": ("détoxifier",),
    "détoxifierons": ("détoxifier",),
    "détoxifieront": ("détoxifier",),
    "détoxifiés": ("détoxifier",),
    "détoxifies": ("détoxifier",),
    "détoxifiez": ("détoxifier",),
    "détoxifiiez": ("détoxifier",),
    "détoxifiions": ("détoxifier",),
    "détoxifions": ("détoxifier",),
    "détruira": ("détruire",),
    "détruiraient": ("détruire",),
    "détruirai": ("détruire",),
    "détruirais": ("détruire",),
    "détruirait": ("détruire",),
    "détruiras": ("détruire",),
    "détruirez": ("détruire",),
    "détruiriez": ("détruire",),
    "détruirions": ("détruire",),
    "détruirons": ("détruire",),
    "détruiront": ("détruire",),
    "détruisaient": ("détruire",),
    "détruisais": ("détruire",),
    "détruisait": ("détruire",),
    "détruisant": ("détruire",),
    "détruisent": ("détruire",),
    "détruise": ("détruire",),
    "détruises": ("détruire",),
    "détruisez": ("détruire",),
    "détruisiez": ("détruire",),
    "détruisîmes": ("détruire",),
    "détruisions": ("détruire",),
    "détruisirent": ("détruire",),
    "détruisis": ("détruire",),
    "détruisissent": ("détruire",),
    "détruisisses": ("détruire",),
    "détruisisse": ("détruire",),
    "détruisissiez": ("détruire",),
    "détruisissions": ("détruire",),
    "détruisîtes": ("détruire",),
    "détruisit": ("détruire",),
    "détruisît": ("détruire",),
    "détruisons": ("détruire",),
    "détruis": ("détruire",),
    "détruite": ("détruire",),
    "détruites": ("détruire",),
    "détruit": ("détruire",),
    "détruits": ("détruire",),
    "devançaient": ("devancer",),
    "devançai": ("devancer",),
    "devançais": ("devancer",),
    "devançait": ("devancer",),
    "devança": ("devancer",),
    "devançâmes": ("devancer",),
    "devançant": ("devancer",),
    "devanças": ("devancer",),
    "devançassent": ("devancer",),
    "devançasses": ("devancer",),
    "devançasse": ("devancer",),
    "devançassiez": ("devancer",),
    "devançassions": ("devancer",),
    "devançâtes": ("devancer",),
    "devançât": ("devancer",),
    "devancée": ("devancer",),
    "devancées": ("devancer",),
    "devancé": ("devancer",),
    "devancent": ("devancer",),
    "devance": ("devancer",),
    "devancera": ("devancer",),
    "devanceraient": ("devancer",),
    "devancerai": ("devancer",),
    "devancerais": ("devancer",),
    "devancerait": ("devancer",),
    "devanceras": ("devancer",),
    "devancèrent": ("devancer",),
    "devancerez": ("devancer",),
    "devanceriez": ("devancer",),
    "devancerions": ("devancer",),
    "devancerons": ("devancer",),
    "devanceront": ("devancer",),
    "devancés": ("devancer",),
    "devances": ("devancer",),
    "devancez": ("devancer",),
    "devanciez": ("devancer",),
    "devancions": ("devancer",),
    "devançons": ("devancer",),
    "devenaient": ("devenir",),
    "devenais": ("devenir",),
    "devenait": ("devenir",),
    "devenant": ("devenir",),
    "devenez": ("devenir",),
    "deveniez": ("devenir",),
    "devenions": ("devenir",),
    "devenons": ("devenir",),
    "devenue": ("devenir",),
    "devenues": ("devenir",),
    "devenu": ("devenir",),
    "devenus": ("devenir",),
    "deviendra": ("devenir",),
    "deviendraient": ("devenir",),
    "deviendrai": ("devenir",),
    "deviendrais": ("devenir",),
    "deviendrait": ("devenir",),
    "deviendras": ("devenir",),
    "deviendrez": ("devenir",),
    "deviendriez": ("devenir",),
    "deviendrions": ("devenir",),
    "deviendrons": ("devenir",),
    "deviendront": ("devenir",),
    "deviennent": ("devenir",),
    "devienne": ("devenir",),
    "deviennes": ("devenir",),
    "deviens": ("devenir",),
    "devient": ("devenir",),
    "devînmes": ("devenir",),
    "devinrent": ("devenir",),
    "devins": ("devenir",),
    "devinssent": ("devenir",),
    "devinsses": ("devenir",),
    "devinsse": ("devenir",),
    "devinssiez": ("devenir",),
    "devinssions": ("devenir",),
    "devîntes": ("devenir",),
    "devint": ("devenir",),
    "devînt": ("devenir",),
    "déverdie": ("déverdir",),
    "déverdies": ("déverdir",),
    "déverdi": ("déverdir",),
    "déverdîmes": ("déverdir",),
    "déverdira": ("déverdir",),
    "déverdiraient": ("déverdir",),
    "déverdirai": ("déverdir",),
    "déverdirais": ("déverdir",),
    "déverdirait": ("déverdir",),
    "déverdiras": ("déverdir",),
    "déverdirent": ("déverdir",),
    "déverdirez": ("déverdir",),
    "déverdiriez": ("déverdir",),
    "déverdirions": ("déverdir",),
    "déverdirons": ("déverdir",),
    "déverdiront": ("déverdir",),
    "déverdis": ("déverdir",),
    "déverdissaient": ("déverdir",),
    "déverdissais": ("déverdir",),
    "déverdissait": ("déverdir",),
    "déverdissant": ("déverdir",),
    "déverdissent": ("déverdir",),
    "déverdisse": ("déverdir",),
    "déverdisses": ("déverdir",),
    "déverdissez": ("déverdir",),
    "déverdissiez": ("déverdir",),
    "déverdissions": ("déverdir",),
    "déverdissons": ("déverdir",),
    "déverdîtes": ("déverdir",),
    "déverdit": ("déverdir",),
    "déverdît": ("déverdir",),
    "déverglaçaient": ("déverglacer",),
    "déverglaçai": ("déverglacer",),
    "déverglaçais": ("déverglacer",),
    "déverglaçait": ("déverglacer",),
    "déverglaça": ("déverglacer",),
    "déverglaçâmes": ("déverglacer",),
    "déverglaçant": ("déverglacer",),
    "déverglaças": ("déverglacer",),
    "déverglaçassent": ("déverglacer",),
    "déverglaçasses": ("déverglacer",),
    "déverglaçasse": ("déverglacer",),
    "déverglaçassiez": ("déverglacer",),
    "déverglaçassions": ("déverglacer",),
    "déverglaçâtes": ("déverglacer",),
    "déverglaçât": ("déverglacer",),
    "déverglacée": ("déverglacer",),
    "déverglacées": ("déverglacer",),
    "déverglacé": ("déverglacer",),
    "déverglacent": ("déverglacer",),
    "déverglace": ("déverglacer",),
    "déverglacera": ("déverglacer",),
    "déverglaceraient": ("déverglacer",),
    "déverglacerai": ("déverglacer",),
    "déverglacerais": ("déverglacer",),
    "déverglacerait": ("déverglacer",),
    "déverglaceras": ("déverglacer",),
    "déverglacèrent": ("déverglacer",),
    "déverglacerez": ("déverglacer",),
    "déverglaceriez": ("déverglacer",),
    "déverglacerions": ("déverglacer",),
    "déverglacerons": ("déverglacer",),
    "déverglaceront": ("déverglacer",),
    "déverglacés": ("déverglacer",),
    "déverglaces": ("déverglacer",),
    "déverglacez": ("déverglacer",),
    "déverglaciez": ("déverglacer",),
    "déverglacions": ("déverglacer",),
    "déverglaçons": ("déverglacer",),
    "dévernie": ("dévernir",),
    "dévernies": ("dévernir",),
    "déverni": ("dévernir",),
    "dévernîmes": ("dévernir",),
    "dévernira": ("dévernir",),
    "déverniraient": ("dévernir",),
    "dévernirai": ("dévernir",),
    "dévernirais": ("dévernir",),
    "dévernirait": ("dévernir",),
    "déverniras": ("dévernir",),
    "dévernirent": ("dévernir",),
    "dévernirez": ("dévernir",),
    "déverniriez": ("dévernir",),
    "dévernirions": ("dévernir",),
    "dévernirons": ("dévernir",),
    "déverniront": ("dévernir",),
    "dévernis": ("dévernir",),
    "dévernissaient": ("dévernir",),
    "dévernissais": ("dévernir",),
    "dévernissait": ("dévernir",),
    "dévernissant": ("dévernir",),
    "dévernissent": ("dévernir",),
    "dévernisse": ("dévernir",),
    "dévernisses": ("dévernir",),
    "dévernissez": ("dévernir",),
    "dévernissiez": ("dévernir",),
    "dévernissions": ("dévernir",),
    "dévernissons": ("dévernir",),
    "dévernîtes": ("dévernir",),
    "dévernit": ("dévernir",),
    "dévernît": ("dévernir",),
    "dévêtaient": ("dévêtir",),
    "dévêtais": ("dévêtir",),
    "dévêtait": ("dévêtir",),
    "dévêtant": ("dévêtir",),
    "dévêtent": ("dévêtir",),
    "dévête": ("dévêtir",),
    "dévêtes": ("dévêtir",),
    "dévêtez": ("dévêtir",),
    "dévêtiez": ("dévêtir",),
    "dévêtîmes": ("dévêtir",),
    "dévêtions": ("dévêtir",),
    "dévêtira": ("dévêtir",),
    "dévêtiraient": ("dévêtir",),
    "dévêtirai": ("dévêtir",),
    "dévêtirais": ("dévêtir",),
    "dévêtirait": ("dévêtir",),
    "dévêtiras": ("dévêtir",),
    "dévêtirent": ("dévêtir",),
    "dévêtirez": ("dévêtir",),
    "dévêtiriez": ("dévêtir",),
    "dévêtirions": ("dévêtir",),
    "dévêtirons": ("dévêtir",),
    "dévêtiront": ("dévêtir",),
    "dévêtis": ("dévêtir",),
    "dévêtissent": ("dévêtir",),
    "dévêtisses": ("dévêtir",),
    "dévêtisse": ("dévêtir",),
    "dévêtissiez": ("dévêtir",),
    "dévêtissions": ("dévêtir",),
    "dévêtîtes": ("dévêtir",),
    "dévêtit": ("dévêtir",),
    "dévêtît": ("dévêtir",),
    "dévêtons": ("dévêtir",),
    "dévêt": ("dévêtir",),
    "dévêts": ("dévêtir",),
    "dévêtue": ("dévêtir",),
    "dévêtues": ("dévêtir",),
    "dévêtu": ("dévêtir",),
    "dévêtus": ("dévêtir",),
    "déviaient": ("dévier",),
    "déviai": ("dévier",),
    "déviais": ("dévier",),
    "déviait": ("dévier",),
    "dévia": ("dévier",),
    "déviâmes": ("dévier",),
    "déviant": ("dévier",),
    "dévias": ("dévier",),
    "déviassent": ("dévier",),
    "déviasses": ("dévier",),
    "déviasse": ("dévier",),
    "déviassiez": ("dévier",),
    "déviassions": ("dévier",),
    "déviâtes": ("dévier",),
    "déviât": ("dévier",),
    "déviée": ("dévier",),
    "déviées": ("dévier",),
    "dévié": ("dévier",),
    "dévient": ("dévier",),
    "dévie": ("dévier",),
    "déviera": ("dévier",),
    "dévieraient": ("dévier",),
    "dévierai": ("dévier",),
    "dévierais": ("dévier",),
    "dévierait": ("dévier",),
    "dévieras": ("dévier",),
    "dévièrent": ("dévier",),
    "dévierez": ("dévier",),
    "dévieriez": ("dévier",),
    "dévierions": ("dévier",),
    "dévierons": ("dévier",),
    "dévieront": ("dévier",),
    "déviés": ("dévier",),
    "dévies": ("dévier",),
    "déviez": ("dévier",),
    "déviiez": ("dévier",),
    "déviions": ("dévier",),
    "dévions": ("dévier",),
    "dévisageaient": ("dévisager",),
    "dévisageai": ("dévisager",),
    "dévisageais": ("dévisager",),
    "dévisageait": ("dévisager",),
    "dévisagea": ("dévisager",),
    "dévisageâmes": ("dévisager",),
    "dévisageant": ("dévisager",),
    "dévisageas": ("dévisager",),
    "dévisageassent": ("dévisager",),
    "dévisageasses": ("dévisager",),
    "dévisageasse": ("dévisager",),
    "dévisageassiez": ("dévisager",),
    "dévisageassions": ("dévisager",),
    "dévisageâtes": ("dévisager",),
    "dévisageât": ("dévisager",),
    "dévisagée": ("dévisager",),
    "dévisagées": ("dévisager",),
    "dévisagé": ("dévisager",),
    "dévisagent": ("dévisager",),
    "dévisageons": ("dévisager",),
    "dévisage": ("dévisager",),
    "dévisagera": ("dévisager",),
    "dévisageraient": ("dévisager",),
    "dévisagerai": ("dévisager",),
    "dévisagerais": ("dévisager",),
    "dévisagerait": ("dévisager",),
    "dévisageras": ("dévisager",),
    "dévisagèrent": ("dévisager",),
    "dévisagerez": ("dévisager",),
    "dévisageriez": ("dévisager",),
    "dévisagerions": ("dévisager",),
    "dévisagerons": ("dévisager",),
    "dévisageront": ("dévisager",),
    "dévisagés": ("dévisager",),
    "dévisages": ("dévisager",),
    "dévisagez": ("dévisager",),
    "dévisagiez": ("dévisager",),
    "dévisagions": ("dévisager",),
    "dévitrifiaient": ("dévitrifier",),
    "dévitrifiai": ("dévitrifier",),
    "dévitrifiais": ("dévitrifier",),
    "dévitrifiait": ("dévitrifier",),
    "dévitrifia": ("dévitrifier",),
    "dévitrifiâmes": ("dévitrifier",),
    "dévitrifiant": ("dévitrifier",),
    "dévitrifias": ("dévitrifier",),
    "dévitrifiassent": ("dévitrifier",),
    "dévitrifiasses": ("dévitrifier",),
    "dévitrifiasse": ("dévitrifier",),
    "dévitrifiassiez": ("dévitrifier",),
    "dévitrifiassions": ("dévitrifier",),
    "dévitrifiâtes": ("dévitrifier",),
    "dévitrifiât": ("dévitrifier",),
    "dévitrifiée": ("dévitrifier",),
    "dévitrifiées": ("dévitrifier",),
    "dévitrifié": ("dévitrifier",),
    "dévitrifient": ("dévitrifier",),
    "dévitrifie": ("dévitrifier",),
    "dévitrifiera": ("dévitrifier",),
    "dévitrifieraient": ("dévitrifier",),
    "dévitrifierai": ("dévitrifier",),
    "dévitrifierais": ("dévitrifier",),
    "dévitrifierait": ("dévitrifier",),
    "dévitrifieras": ("dévitrifier",),
    "dévitrifièrent": ("dévitrifier",),
    "dévitrifierez": ("dévitrifier",),
    "dévitrifieriez": ("dévitrifier",),
    "dévitrifierions": ("dévitrifier",),
    "dévitrifierons": ("dévitrifier",),
    "dévitrifieront": ("dévitrifier",),
    "dévitrifiés": ("dévitrifier",),
    "dévitrifies": ("dévitrifier",),
    "dévitrifiez": ("dévitrifier",),
    "dévitrifiiez": ("dévitrifier",),
    "dévitrifiions": ("dévitrifier",),
    "dévitrifions": ("dévitrifier",),
    "devaient": ("devoir",),
    "devais": ("devoir",),
    "devait": ("devoir",),
    "devant": ("devoir",),
    "devez": ("devoir",),
    "deviez": ("devoir",),
    "devions": ("devoir",),
    "devons": ("devoir",),
    "devra": ("devoir",),
    "devraient": ("devoir",),
    "devrai": ("devoir",),
    "devrais": ("devoir",),
    "devrait": ("devoir",),
    "devras": ("devoir",),
    "devrez": ("devoir",),
    "devriez": ("devoir",),
    "devrions": ("devoir",),
    "devrons": ("devoir",),
    "devront": ("devoir",),
    "dois": ("devoir",),
    "doit": ("devoir",),
    "doivent": ("devoir",),
    "doive": ("devoir",),
    "doives": ("devoir",),
    "due": ("devoir",),
    "dues": ("devoir",),
    "dû": ("devoir",),
    "dûmes": ("devoir",),
    "durent": ("devoir",),
    "dus": ("devoir",),
    "dussent": ("devoir",),
    "dusses": ("devoir",),
    "dusse": ("devoir",),
    "dussé": ("devoir",),
    "dussiez": ("devoir",),
    "dussions": ("devoir",),
    "dûtes": ("devoir",),
    "dut": ("devoir",),
    "dût": ("devoir",),
    "dévoient": ("dévoyer",),
    "dévoie": ("dévoyer",),
    "dévoiera": ("dévoyer",),
    "dévoieraient": ("dévoyer",),
    "dévoierai": ("dévoyer",),
    "dévoierais": ("dévoyer",),
    "dévoierait": ("dévoyer",),
    "dévoieras": ("dévoyer",),
    "dévoierez": ("dévoyer",),
    "dévoieriez": ("dévoyer",),
    "dévoierions": ("dévoyer",),
    "dévoierons": ("dévoyer",),
    "dévoieront": ("dévoyer",),
    "dévoies": ("dévoyer",),
    "dévoyaient": ("dévoyer",),
    "dévoyai": ("dévoyer",),
    "dévoyais": ("dévoyer",),
    "dévoyait": ("dévoyer",),
    "dévoya": ("dévoyer",),
    "dévoyâmes": ("dévoyer",),
    "dévoyant": ("dévoyer",),
    "dévoyas": ("dévoyer",),
    "dévoyassent": ("dévoyer",),
    "dévoyasses": ("dévoyer",),
    "dévoyasse": ("dévoyer",),
    "dévoyassiez": ("dévoyer",),
    "dévoyassions": ("dévoyer",),
    "dévoyâtes": ("dévoyer",),
    "dévoyât": ("dévoyer",),
    "dévoyée": ("dévoyer",),
    "dévoyées": ("dévoyer",),
    "dévoyé": ("dévoyer",),
    "dévoyèrent": ("dévoyer",),
    "dévoyés": ("dévoyer",),
    "dévoyez": ("dévoyer",),
    "dévoyiez": ("dévoyer",),
    "dévoyions": ("dévoyer",),
    "dévoyons": ("dévoyer",),
    "dézincifiaient": ("dézincifier",),
    "dézincifiai": ("dézincifier",),
    "dézincifiais": ("dézincifier",),
    "dézincifiait": ("dézincifier",),
    "dézincifia": ("dézincifier",),
    "dézincifiâmes": ("dézincifier",),
    "dézincifiant": ("dézincifier",),
    "dézincifias": ("dézincifier",),
    "dézincifiassent": ("dézincifier",),
    "dézincifiasses": ("dézincifier",),
    "dézincifiasse": ("dézincifier",),
    "dézincifiassiez": ("dézincifier",),
    "dézincifiassions": ("dézincifier",),
    "dézincifiâtes": ("dézincifier",),
    "dézincifiât": ("dézincifier",),
    "dézincifiée": ("dézincifier",),
    "dézincifiées": ("dézincifier",),
    "dézincifié": ("dézincifier",),
    "dézincifient": ("dézincifier",),
    "dézincifie": ("dézincifier",),
    "dézincifiera": ("dézincifier",),
    "dézincifieraient": ("dézincifier",),
    "dézincifierai": ("dézincifier",),
    "dézincifierais": ("dézincifier",),
    "dézincifierait": ("dézincifier",),
    "dézincifieras": ("dézincifier",),
    "dézincifièrent": ("dézincifier",),
    "dézincifierez": ("dézincifier",),
    "dézincifieriez": ("dézincifier",),
    "dézincifierions": ("dézincifier",),
    "dézincifierons": ("dézincifier",),
    "dézincifieront": ("dézincifier",),
    "dézincifiés": ("dézincifier",),
    "dézincifies": ("dézincifier",),
    "dézincifiez": ("dézincifier",),
    "dézincifiiez": ("dézincifier",),
    "dézincifiions": ("dézincifier",),
    "dézincifions": ("dézincifier",),
    "diazocopiaient": ("diazocopier",),
    "diazocopiai": ("diazocopier",),
    "diazocopiais": ("diazocopier",),
    "diazocopiait": ("diazocopier",),
    "diazocopia": ("diazocopier",),
    "diazocopiâmes": ("diazocopier",),
    "diazocopiant": ("diazocopier",),
    "diazocopias": ("diazocopier",),
    "diazocopiassent": ("diazocopier",),
    "diazocopiasses": ("diazocopier",),
    "diazocopiasse": ("diazocopier",),
    "diazocopiassiez": ("diazocopier",),
    "diazocopiassions": ("diazocopier",),
    "diazocopiâtes": ("diazocopier",),
    "diazocopiât": ("diazocopier",),
    "diazocopiée": ("diazocopier",),
    "diazocopiées": ("diazocopier",),
    "diazocopié": ("diazocopier",),
    "diazocopient": ("diazocopier",),
    "diazocopie": ("diazocopier",),
    "diazocopiera": ("diazocopier",),
    "diazocopieraient": ("diazocopier",),
    "diazocopierai": ("diazocopier",),
    "diazocopierais": ("diazocopier",),
    "diazocopierait": ("diazocopier",),
    "diazocopieras": ("diazocopier",),
    "diazocopièrent": ("diazocopier",),
    "diazocopierez": ("diazocopier",),
    "diazocopieriez": ("diazocopier",),
    "diazocopierions": ("diazocopier",),
    "diazocopierons": ("diazocopier",),
    "diazocopieront": ("diazocopier",),
    "diazocopiés": ("diazocopier",),
    "diazocopies": ("diazocopier",),
    "diazocopiez": ("diazocopier",),
    "diazocopiiez": ("diazocopier",),
    "diazocopiions": ("diazocopier",),
    "diazocopions": ("diazocopier",),
    "diésaient": ("diéser",),
    "diésai": ("diéser",),
    "diésais": ("diéser",),
    "diésait": ("diéser",),
    "diésa": ("diéser",),
    "diésâmes": ("diéser",),
    "diésant": ("diéser",),
    "diésas": ("diéser",),
    "diésassent": ("diéser",),
    "diésasses": ("diéser",),
    "diésasse": ("diéser",),
    "diésassiez": ("diéser",),
    "diésassions": ("diéser",),
    "diésâtes": ("diéser",),
    "diésât": ("diéser",),
    "diésée": ("diéser",),
    "diésées": ("diéser",),
    "diésé": ("diéser",),
    "dièsent": ("diéser",),
    "dièse": ("diéser",),
    "diésera": ("diéser",),
    "diéseraient": ("diéser",),
    "diéserai": ("diéser",),
    "diéserais": ("diéser",),
    "diéserait": ("diéser",),
    "diéseras": ("diéser",),
    "diésèrent": ("diéser",),
    "diéserez": ("diéser",),
    "diéseriez": ("diéser",),
    "diéserions": ("diéser",),
    "diéserons": ("diéser",),
    "diéseront": ("diéser",),
    "diésés": ("diéser",),
    "dièses": ("diéser",),
    "diésez": ("diéser",),
    "diésiez": ("diéser",),
    "diésions": ("diéser",),
    "diésons": ("diéser",),
    "différenciaient": ("différencier",),
    "différenciai": ("différencier",),
    "différenciais": ("différencier",),
    "différenciait": ("différencier",),
    "différencia": ("différencier",),
    "différenciâmes": ("différencier",),
    "différenciant": ("différencier",),
    "différencias": ("différencier",),
    "différenciassent": ("différencier",),
    "différenciasses": ("différencier",),
    "différenciasse": ("différencier",),
    "différenciassiez": ("différencier",),
    "différenciassions": ("différencier",),
    "différenciâtes": ("différencier",),
    "différenciât": ("différencier",),
    "différenciée": ("différencier",),
    "différenciées": ("différencier",),
    "différencié": ("différencier",),
    "différencient": ("différencier",),
    "différencie": ("différencier",),
    "différenciera": ("différencier",),
    "différencieraient": ("différencier",),
    "différencierai": ("différencier",),
    "différencierais": ("différencier",),
    "différencierait": ("différencier",),
    "différencieras": ("différencier",),
    "différencièrent": ("différencier",),
    "différencierez": ("différencier",),
    "différencieriez": ("différencier",),
    "différencierions": ("différencier",),
    "différencierons": ("différencier",),
    "différencieront": ("différencier",),
    "différenciés": ("différencier",),
    "différencies": ("différencier",),
    "différenciez": ("différencier",),
    "différenciiez": ("différencier",),
    "différenciions": ("différencier",),
    "différencions": ("différencier",),
    "différentiaient": ("différentier",),
    "différentiai": ("différentier",),
    "différentiais": ("différentier",),
    "différentiait": ("différentier",),
    "différentia": ("différentier",),
    "différentiâmes": ("différentier",),
    "différentiant": ("différentier",),
    "différentias": ("différentier",),
    "différentiassent": ("différentier",),
    "différentiasses": ("différentier",),
    "différentiasse": ("différentier",),
    "différentiassiez": ("différentier",),
    "différentiassions": ("différentier",),
    "différentiâtes": ("différentier",),
    "différentiât": ("différentier",),
    "différentiée": ("différentier",),
    "différentiées": ("différentier",),
    "différentié": ("différentier",),
    "différentient": ("différentier",),
    "différentie": ("différentier",),
    "différentiera": ("différentier",),
    "différentieraient": ("différentier",),
    "différentierai": ("différentier",),
    "différentierais": ("différentier",),
    "différentierait": ("différentier",),
    "différentieras": ("différentier",),
    "différentièrent": ("différentier",),
    "différentierez": ("différentier",),
    "différentieriez": ("différentier",),
    "différentierions": ("différentier",),
    "différentierons": ("différentier",),
    "différentieront": ("différentier",),
    "différentiés": ("différentier",),
    "différenties": ("différentier",),
    "différentiez": ("différentier",),
    "différentiiez": ("différentier",),
    "différentiions": ("différentier",),
    "différentions": ("différentier",),
    "différaient": ("différer",),
    "différai": ("différer",),
    "différais": ("différer",),
    "différait": ("différer",),
    "différa": ("différer",),
    "différâmes": ("différer",),
    "différant": ("différer",),
    "différas": ("différer",),
    "différassent": ("différer",),
    "différasses": ("différer",),
    "différasse": ("différer",),
    "différassiez": ("différer",),
    "différassions": ("différer",),
    "différâtes": ("différer",),
    "différât": ("différer",),
    "différée": ("différer",),
    "différées": ("différer",),
    "différé": ("différer",),
    "diffèrent": ("différer",),
    "diffère": ("différer",),
    "différera": ("différer",),
    "différeraient": ("différer",),
    "différerai": ("différer",),
    "différerais": ("différer",),
    "différerait": ("différer",),
    "différeras": ("différer",),
    "différèrent": ("différer",),
    "différerez": ("différer",),
    "différeriez": ("différer",),
    "différerions": ("différer",),
    "différerons": ("différer",),
    "différeront": ("différer",),
    "différés": ("différer",),
    "diffères": ("différer",),
    "différez": ("différer",),
    "différiez": ("différer",),
    "différions": ("différer",),
    "différons": ("différer",),
    "digéraient": ("digérer",),
    "digérai": ("digérer",),
    "digérais": ("digérer",),
    "digérait": ("digérer",),
    "digéra": ("digérer",),
    "digérâmes": ("digérer",),
    "digérant": ("digérer",),
    "digéras": ("digérer",),
    "digérassent": ("digérer",),
    "digérasses": ("digérer",),
    "digérasse": ("digérer",),
    "digérassiez": ("digérer",),
    "digérassions": ("digérer",),
    "digérâtes": ("digérer",),
    "digérât": ("digérer",),
    "digérée": ("digérer",),
    "digérées": ("digérer",),
    "digéré": ("digérer",),
    "digèrent": ("digérer",),
    "digère": ("digérer",),
    "digérera": ("digérer",),
    "digéreraient": ("digérer",),
    "digérerai": ("digérer",),
    "digérerais": ("digérer",),
    "digérerait": ("digérer",),
    "digéreras": ("digérer",),
    "digérèrent": ("digérer",),
    "digérerez": ("digérer",),
    "digéreriez": ("digérer",),
    "digérerions": ("digérer",),
    "digérerons": ("digérer",),
    "digéreront": ("digérer",),
    "digérés": ("digérer",),
    "digères": ("digérer",),
    "digérez": ("digérer",),
    "digériez": ("digérer",),
    "digérions": ("digérer",),
    "digérons": ("digérer",),
    "dignifiaient": ("dignifier",),
    "dignifiai": ("dignifier",),
    "dignifiais": ("dignifier",),
    "dignifiait": ("dignifier",),
    "dignifia": ("dignifier",),
    "dignifiâmes": ("dignifier",),
    "dignifiant": ("dignifier",),
    "dignifias": ("dignifier",),
    "dignifiassent": ("dignifier",),
    "dignifiasses": ("dignifier",),
    "dignifiasse": ("dignifier",),
    "dignifiassiez": ("dignifier",),
    "dignifiassions": ("dignifier",),
    "dignifiâtes": ("dignifier",),
    "dignifiât": ("dignifier",),
    "dignifiée": ("dignifier",),
    "dignifiées": ("dignifier",),
    "dignifié": ("dignifier",),
    "dignifient": ("dignifier",),
    "dignifie": ("dignifier",),
    "dignifiera": ("dignifier",),
    "dignifieraient": ("dignifier",),
    "dignifierai": ("dignifier",),
    "dignifierais": ("dignifier",),
    "dignifierait": ("dignifier",),
    "dignifieras": ("dignifier",),
    "dignifièrent": ("dignifier",),
    "dignifierez": ("dignifier",),
    "dignifieriez": ("dignifier",),
    "dignifierions": ("dignifier",),
    "dignifierons": ("dignifier",),
    "dignifieront": ("dignifier",),
    "dignifiés": ("dignifier",),
    "dignifies": ("dignifier",),
    "dignifiez": ("dignifier",),
    "dignifiiez": ("dignifier",),
    "dignifiions": ("dignifier",),
    "dignifions": ("dignifier",),
    "dihalogénaient": ("dihalogéner",),
    "dihalogénai": ("dihalogéner",),
    "dihalogénais": ("dihalogéner",),
    "dihalogénait": ("dihalogéner",),
    "dihalogéna": ("dihalogéner",),
    "dihalogénâmes": ("dihalogéner",),
    "dihalogénant": ("dihalogéner",),
    "dihalogénas": ("dihalogéner",),
    "dihalogénassent": ("dihalogéner",),
    "dihalogénasses": ("dihalogéner",),
    "dihalogénasse": ("dihalogéner",),
    "dihalogénassiez": ("dihalogéner",),
    "dihalogénassions": ("dihalogéner",),
    "dihalogénâtes": ("dihalogéner",),
    "dihalogénât": ("dihalogéner",),
    "dihalogénée": ("dihalogéner",),
    "dihalogénées": ("dihalogéner",),
    "dihalogéné": ("dihalogéner",),
    "dihalogènent": ("dihalogéner",),
    "dihalogène": ("dihalogéner",),
    "dihalogénera": ("dihalogéner",),
    "dihalogéneraient": ("dihalogéner",),
    "dihalogénerai": ("dihalogéner",),
    "dihalogénerais": ("dihalogéner",),
    "dihalogénerait": ("dihalogéner",),
    "dihalogéneras": ("dihalogéner",),
    "dihalogénèrent": ("dihalogéner",),
    "dihalogénerez": ("dihalogéner",),
    "dihalogéneriez": ("dihalogéner",),
    "dihalogénerions": ("dihalogéner",),
    "dihalogénerons": ("dihalogéner",),
    "dihalogéneront": ("dihalogéner",),
    "dihalogénés": ("dihalogéner",),
    "dihalogènes": ("dihalogéner",),
    "dihalogénez": ("dihalogéner",),
    "dihalogéniez": ("dihalogéner",),
    "dihalogénions": ("dihalogéner",),
    "dihalogénons": ("dihalogéner",),
    "dilacéraient": ("dilacérer",),
    "dilacérai": ("dilacérer",),
    "dilacérais": ("dilacérer",),
    "dilacérait": ("dilacérer",),
    "dilacéra": ("dilacérer",),
    "dilacérâmes": ("dilacérer",),
    "dilacérant": ("dilacérer",),
    "dilacéras": ("dilacérer",),
    "dilacérassent": ("dilacérer",),
    "dilacérasses": ("dilacérer",),
    "dilacérasse": ("dilacérer",),
    "dilacérassiez": ("dilacérer",),
    "dilacérassions": ("dilacérer",),
    "dilacérâtes": ("dilacérer",),
    "dilacérât": ("dilacérer",),
    "dilacérée": ("dilacérer",),
    "dilacérées": ("dilacérer",),
    "dilacéré": ("dilacérer",),
    "dilacèrent": ("dilacérer",),
    "dilacère": ("dilacérer",),
    "dilacérera": ("dilacérer",),
    "dilacéreraient": ("dilacérer",),
    "dilacérerai": ("dilacérer",),
    "dilacérerais": ("dilacérer",),
    "dilacérerait": ("dilacérer",),
    "dilacéreras": ("dilacérer",),
    "dilacérèrent": ("dilacérer",),
    "dilacérerez": ("dilacérer",),
    "dilacéreriez": ("dilacérer",),
    "dilacérerions": ("dilacérer",),
    "dilacérerons": ("dilacérer",),
    "dilacéreront": ("dilacérer",),
    "dilacérés": ("dilacérer",),
    "dilacères": ("dilacérer",),
    "dilacérez": ("dilacérer",),
    "dilacériez": ("dilacérer",),
    "dilacérions": ("dilacérer",),
    "dilacérons": ("dilacérer",),
    "dîmes": ("dire",),
    "dira": ("dire",),
    "diraient": ("dire",),
    "dirai": ("dire",),
    "dirais": ("dire",),
    "dirait": ("dire",),
    "diras": ("dire",),
    "dirent": ("dire",),
    "direz": ("dire",),
    "diriez": ("dire",),
    "dirions": ("dire",),
    "dirons": ("dire",),
    "diront": ("dire",),
    "disaient": ("dire",),
    "disais": ("dire",),
    "disait": ("dire",),
    "disant": ("dire",),
    "disent": ("dire",),
    "dise": ("dire",),
    "dises": ("dire",),
    "disiez": ("dire",),
    "disions": ("dire",),
    "disons": ("dire",),
    "dis": ("dire",),
    "dissent": ("dire",),
    "disses": ("dire",),
    "disse": ("dire",),
    "dissiez": ("dire",),
    "dissions": ("dire",),
    "dite": ("dire",),
    "dîtes": ("dire",),
    "dites": ("dire",),
    "dit": ("dire",),
    "dits": ("dire",),
    "dît": ("dire",),
    "dirigeaient": ("diriger",),
    "dirigeai": ("diriger",),
    "dirigeais": ("diriger",),
    "dirigeait": ("diriger",),
    "dirigea": ("diriger",),
    "dirigeâmes": ("diriger",),
    "dirigeant": ("diriger",),
    "dirigeas": ("diriger",),
    "dirigeassent": ("diriger",),
    "dirigeasses": ("diriger",),
    "dirigeasse": ("diriger",),
    "dirigeassiez": ("diriger",),
    "dirigeassions": ("diriger",),
    "dirigeâtes": ("diriger",),
    "dirigeât": ("diriger",),
    "dirigée": ("diriger",),
    "dirigées": ("diriger",),
    "dirigé": ("diriger",),
    "dirigent": ("diriger",),
    "dirigeons": ("diriger",),
    "dirige": ("diriger",),
    "dirigera": ("diriger",),
    "dirigeraient": ("diriger",),
    "dirigerai": ("diriger",),
    "dirigerais": ("diriger",),
    "dirigerait": ("diriger",),
    "dirigeras": ("diriger",),
    "dirigèrent": ("diriger",),
    "dirigerez": ("diriger",),
    "dirigeriez": ("diriger",),
    "dirigerions": ("diriger",),
    "dirigerons": ("diriger",),
    "dirigeront": ("diriger",),
    "dirigés": ("diriger",),
    "diriges": ("diriger",),
    "dirigez": ("diriger",),
    "dirigiez": ("diriger",),
    "dirigions": ("diriger",),
    "disconvenaient": ("disconvenir",),
    "disconvenais": ("disconvenir",),
    "disconvenait": ("disconvenir",),
    "disconvenant": ("disconvenir",),
    "disconvenez": ("disconvenir",),
    "disconveniez": ("disconvenir",),
    "disconvenions": ("disconvenir",),
    "disconvenons": ("disconvenir",),
    "disconvenu": ("disconvenir",),
    "disconviendra": ("disconvenir",),
    "disconviendraient": ("disconvenir",),
    "disconviendrai": ("disconvenir",),
    "disconviendrais": ("disconvenir",),
    "disconviendrait": ("disconvenir",),
    "disconviendras": ("disconvenir",),
    "disconviendrez": ("disconvenir",),
    "disconviendriez": ("disconvenir",),
    "disconviendrions": ("disconvenir",),
    "disconviendrons": ("disconvenir",),
    "disconviendront": ("disconvenir",),
    "disconviennent": ("disconvenir",),
    "disconvienne": ("disconvenir",),
    "disconviennes": ("disconvenir",),
    "disconviens": ("disconvenir",),
    "disconvient": ("disconvenir",),
    "disconvînmes": ("disconvenir",),
    "disconvinrent": ("disconvenir",),
    "disconvins": ("disconvenir",),
    "disconvinssent": ("disconvenir",),
    "disconvinsses": ("disconvenir",),
    "disconvinsse": ("disconvenir",),
    "disconvinssiez": ("disconvenir",),
    "disconvinssions": ("disconvenir",),
    "disconvîntes": ("disconvenir",),
    "disconvint": ("disconvenir",),
    "disconvînt": ("disconvenir",),
    "discouraient": ("discourir",),
    "discourais": ("discourir",),
    "discourait": ("discourir",),
    "discourant": ("discourir",),
    "discourent": ("discourir",),
    "discoure": ("discourir",),
    "discoures": ("discourir",),
    "discourez": ("discourir",),
    "discouriez": ("discourir",),
    "discourions": ("discourir",),
    "discourons": ("discourir",),
    "discourra": ("discourir",),
    "discourraient": ("discourir",),
    "discourrai": ("discourir",),
    "discourrais": ("discourir",),
    "discourrait": ("discourir",),
    "discourras": ("discourir",),
    "discourrez": ("discourir",),
    "discourriez": ("discourir",),
    "discourrions": ("discourir",),
    "discourrons": ("discourir",),
    "discourront": ("discourir",),
    "discours": ("discourir",),
    "discourt": ("discourir",),
    "discouru": ("discourir",),
    "discourûmes": ("discourir",),
    "discoururent": ("discourir",),
    "discourus": ("discourir",),
    "discourussent": ("discourir",),
    "discourusses": ("discourir",),
    "discourusse": ("discourir",),
    "discourussiez": ("discourir",),
    "discourussions": ("discourir",),
    "discourûtes": ("discourir",),
    "discourut": ("discourir",),
    "discourût": ("discourir",),
    "disgraciaient": ("disgracier",),
    "disgraciai": ("disgracier",),
    "disgraciais": ("disgracier",),
    "disgraciait": ("disgracier",),
    "disgracia": ("disgracier",),
    "disgraciâmes": ("disgracier",),
    "disgraciant": ("disgracier",),
    "disgracias": ("disgracier",),
    "disgraciassent": ("disgracier",),
    "disgraciasses": ("disgracier",),
    "disgraciasse": ("disgracier",),
    "disgraciassiez": ("disgracier",),
    "disgraciassions": ("disgracier",),
    "disgraciâtes": ("disgracier",),
    "disgraciât": ("disgracier",),
    "disgraciée": ("disgracier",),
    "disgraciées": ("disgracier",),
    "disgracié": ("disgracier",),
    "disgracient": ("disgracier",),
    "disgracie": ("disgracier",),
    "disgraciera": ("disgracier",),
    "disgracieraient": ("disgracier",),
    "disgracierai": ("disgracier",),
    "disgracierais": ("disgracier",),
    "disgracierait": ("disgracier",),
    "disgracieras": ("disgracier",),
    "disgracièrent": ("disgracier",),
    "disgracierez": ("disgracier",),
    "disgracieriez": ("disgracier",),
    "disgracierions": ("disgracier",),
    "disgracierons": ("disgracier",),
    "disgracieront": ("disgracier",),
    "disgraciés": ("disgracier",),
    "disgracies": ("disgracier",),
    "disgraciez": ("disgracier",),
    "disgraciiez": ("disgracier",),
    "disgraciions": ("disgracier",),
    "disgracions": ("disgracier",),
    "disjoignaient": ("disjoindre",),
    "disjoignais": ("disjoindre",),
    "disjoignait": ("disjoindre",),
    "disjoignant": ("disjoindre",),
    "disjoignent": ("disjoindre",),
    "disjoigne": ("disjoindre",),
    "disjoignes": ("disjoindre",),
    "disjoignez": ("disjoindre",),
    "disjoigniez": ("disjoindre",),
    "disjoignîmes": ("disjoindre",),
    "disjoignions": ("disjoindre",),
    "disjoignirent": ("disjoindre",),
    "disjoignis": ("disjoindre",),
    "disjoignissent": ("disjoindre",),
    "disjoignisses": ("disjoindre",),
    "disjoignisse": ("disjoindre",),
    "disjoignissiez": ("disjoindre",),
    "disjoignissions": ("disjoindre",),
    "disjoignîtes": ("disjoindre",),
    "disjoignit": ("disjoindre",),
    "disjoignît": ("disjoindre",),
    "disjoignons": ("disjoindre",),
    "disjoindra": ("disjoindre",),
    "disjoindraient": ("disjoindre",),
    "disjoindrai": ("disjoindre",),
    "disjoindrais": ("disjoindre",),
    "disjoindrait": ("disjoindre",),
    "disjoindras": ("disjoindre",),
    "disjoindrez": ("disjoindre",),
    "disjoindriez": ("disjoindre",),
    "disjoindrions": ("disjoindre",),
    "disjoindrons": ("disjoindre",),
    "disjoindront": ("disjoindre",),
    "disjoins": ("disjoindre",),
    "disjointe": ("disjoindre",),
    "disjointes": ("disjoindre",),
    "disjoint": ("disjoindre",),
    "disjoints": ("disjoindre",),
    "disparais": ("disparaître",),
    "disparaissaient": ("disparaître",),
    "disparaissais": ("disparaître",),
    "disparaissait": ("disparaître",),
    "disparaissant": ("disparaître",),
    "disparaissent": ("disparaître",),
    "disparaisse": ("disparaître",),
    "disparaisses": ("disparaître",),
    "disparaissez": ("disparaître",),
    "disparaissiez": ("disparaître",),
    "disparaissions": ("disparaître",),
    "disparaissons": ("disparaître",),
    "disparaît": ("disparaître",),
    "disparaîtra": ("disparaître",),
    "disparaîtraient": ("disparaître",),
    "disparaîtrai": ("disparaître",),
    "disparaîtrais": ("disparaître",),
    "disparaîtrait": ("disparaître",),
    "disparaîtras": ("disparaître",),
    "disparaîtrez": ("disparaître",),
    "disparaîtriez": ("disparaître",),
    "disparaîtrions": ("disparaître",),
    "disparaîtrons": ("disparaître",),
    "disparaîtront": ("disparaître",),
    "disparue": ("disparaître",),
    "disparues": ("disparaître",),
    "disparu": ("disparaître",),
    "disparûmes": ("disparaître",),
    "disparurent": ("disparaître",),
    "disparus": ("disparaître",),
    "disparussent": ("disparaître",),
    "disparusses": ("disparaître",),
    "disparusse": ("disparaître",),
    "disparussiez": ("disparaître",),
    "disparussions": ("disparaître",),
    "disparûtes": ("disparaître",),
    "disparut": ("disparaître",),
    "disparût": ("disparaître",),
    "disqualifiaient": ("disqualifier",),
    "disqualifiai": ("disqualifier",),
    "disqualifiais": ("disqualifier",),
    "disqualifiait": ("disqualifier",),
    "disqualifia": ("disqualifier",),
    "disqualifiâmes": ("disqualifier",),
    "disqualifiant": ("disqualifier",),
    "disqualifias": ("disqualifier",),
    "disqualifiassent": ("disqualifier",),
    "disqualifiasses": ("disqualifier",),
    "disqualifiasse": ("disqualifier",),
    "disqualifiassiez": ("disqualifier",),
    "disqualifiassions": ("disqualifier",),
    "disqualifiâtes": ("disqualifier",),
    "disqualifiât": ("disqualifier",),
    "disqualifiée": ("disqualifier",),
    "disqualifiées": ("disqualifier",),
    "disqualifié": ("disqualifier",),
    "disqualifient": ("disqualifier",),
    "disqualifie": ("disqualifier",),
    "disqualifiera": ("disqualifier",),
    "disqualifieraient": ("disqualifier",),
    "disqualifierai": ("disqualifier",),
    "disqualifierais": ("disqualifier",),
    "disqualifierait": ("disqualifier",),
    "disqualifieras": ("disqualifier",),
    "disqualifièrent": ("disqualifier",),
    "disqualifierez": ("disqualifier",),
    "disqualifieriez": ("disqualifier",),
    "disqualifierions": ("disqualifier",),
    "disqualifierons": ("disqualifier",),
    "disqualifieront": ("disqualifier",),
    "disqualifiés": ("disqualifier",),
    "disqualifies": ("disqualifier",),
    "disqualifiez": ("disqualifier",),
    "disqualifiiez": ("disqualifier",),
    "disqualifiions": ("disqualifier",),
    "disqualifions": ("disqualifier",),
    "disséquaient": ("disséquer",),
    "disséquai": ("disséquer",),
    "disséquais": ("disséquer",),
    "disséquait": ("disséquer",),
    "disséqua": ("disséquer",),
    "disséquâmes": ("disséquer",),
    "disséquant": ("disséquer",),
    "disséquas": ("disséquer",),
    "disséquassent": ("disséquer",),
    "disséquasses": ("disséquer",),
    "disséquasse": ("disséquer",),
    "disséquassiez": ("disséquer",),
    "disséquassions": ("disséquer",),
    "disséquâtes": ("disséquer",),
    "disséquât": ("disséquer",),
    "disséquée": ("disséquer",),
    "disséquées": ("disséquer",),
    "disséqué": ("disséquer",),
    "dissèquent": ("disséquer",),
    "dissèque": ("disséquer",),
    "disséquera": ("disséquer",),
    "disséqueraient": ("disséquer",),
    "disséquerai": ("disséquer",),
    "disséquerais": ("disséquer",),
    "disséquerait": ("disséquer",),
    "disséqueras": ("disséquer",),
    "disséquèrent": ("disséquer",),
    "disséquerez": ("disséquer",),
    "disséqueriez": ("disséquer",),
    "disséquerions": ("disséquer",),
    "disséquerons": ("disséquer",),
    "disséqueront": ("disséquer",),
    "disséqués": ("disséquer",),
    "dissèques": ("disséquer",),
    "disséquez": ("disséquer",),
    "disséquiez": ("disséquer",),
    "disséquions": ("disséquer",),
    "disséquons": ("disséquer",),
    "dissociaient": ("dissocier",),
    "dissociai": ("dissocier",),
    "dissociais": ("dissocier",),
    "dissociait": ("dissocier",),
    "dissocia": ("dissocier",),
    "dissociâmes": ("dissocier",),
    "dissociant": ("dissocier",),
    "dissocias": ("dissocier",),
    "dissociassent": ("dissocier",),
    "dissociasses": ("dissocier",),
    "dissociasse": ("dissocier",),
    "dissociassiez": ("dissocier",),
    "dissociassions": ("dissocier",),
    "dissociâtes": ("dissocier",),
    "dissociât": ("dissocier",),
    "dissociée": ("dissocier",),
    "dissociées": ("dissocier",),
    "dissocié": ("dissocier",),
    "dissocient": ("dissocier",),
    "dissocie": ("dissocier",),
    "dissociera": ("dissocier",),
    "dissocieraient": ("dissocier",),
    "dissocierai": ("dissocier",),
    "dissocierais": ("dissocier",),
    "dissocierait": ("dissocier",),
    "dissocieras": ("dissocier",),
    "dissocièrent": ("dissocier",),
    "dissocierez": ("dissocier",),
    "dissocieriez": ("dissocier",),
    "dissocierions": ("dissocier",),
    "dissocierons": ("dissocier",),
    "dissocieront": ("dissocier",),
    "dissociés": ("dissocier",),
    "dissocies": ("dissocier",),
    "dissociez": ("dissocier",),
    "dissociiez": ("dissocier",),
    "dissociions": ("dissocier",),
    "dissocions": ("dissocier",),
    "dissolûmes": ("dissoudre",),
    "dissolurent": ("dissoudre",),
    "dissolus": ("dissoudre",),
    "dissolussent": ("dissoudre",),
    "dissolusses": ("dissoudre",),
    "dissolusse": ("dissoudre",),
    "dissolussiez": ("dissoudre",),
    "dissolussions": ("dissoudre",),
    "dissolûtes": ("dissoudre",),
    "dissolut": ("dissoudre",),
    "dissolût": ("dissoudre",),
    "dissolvaient": ("dissoudre",),
    "dissolvais": ("dissoudre",),
    "dissolvait": ("dissoudre",),
    "dissolvant": ("dissoudre",),
    "dissolvent": ("dissoudre",),
    "dissolve": ("dissoudre",),
    "dissolves": ("dissoudre",),
    "dissolvez": ("dissoudre",),
    "dissolviez": ("dissoudre",),
    "dissolvions": ("dissoudre",),
    "dissolvons": ("dissoudre",),
    "dissoudra": ("dissoudre",),
    "dissoudraient": ("dissoudre",),
    "dissoudrai": ("dissoudre",),
    "dissoudrais": ("dissoudre",),
    "dissoudrait": ("dissoudre",),
    "dissoudras": ("dissoudre",),
    "dissoudrez": ("dissoudre",),
    "dissoudriez": ("dissoudre",),
    "dissoudrions": ("dissoudre",),
    "dissoudrons": ("dissoudre",),
    "dissoudront": ("dissoudre",),
    "dissous": ("dissoudre",),
    "dissoute": ("dissoudre",),
    "dissoutes": ("dissoudre",),
    "dissout": ("dissoudre",),
    "distançaient": ("distancer",),
    "distançai": ("distancer",),
    "distançais": ("distancer",),
    "distançait": ("distancer",),
    "distança": ("distancer",),
    "distançâmes": ("distancer",),
    "distançant": ("distancer",),
    "distanças": ("distancer",),
    "distançassent": ("distancer",),
    "distançasses": ("distancer",),
    "distançasse": ("distancer",),
    "distançassiez": ("distancer",),
    "distançassions": ("distancer",),
    "distançâtes": ("distancer",),
    "distançât": ("distancer",),
    "distancée": ("distancer",),
    "distancées": ("distancer",),
    "distancé": ("distancer",),
    "distancent": ("distancer",),
    "distance": ("distancer",),
    "distancera": ("distancer",),
    "distanceraient": ("distancer",),
    "distancerai": ("distancer",),
    "distancerais": ("distancer",),
    "distancerait": ("distancer",),
    "distanceras": ("distancer",),
    "distancèrent": ("distancer",),
    "distancerez": ("distancer",),
    "distanceriez": ("distancer",),
    "distancerions": ("distancer",),
    "distancerons": ("distancer",),
    "distanceront": ("distancer",),
    "distancés": ("distancer",),
    "distances": ("distancer",),
    "distancez": ("distancer",),
    "distanciez": ("distancier",),
    "distancions": ("distancier",),
    "distançons": ("distancer",),
    "distanciaient": ("distancier",),
    "distanciai": ("distancier",),
    "distanciais": ("distancier",),
    "distanciait": ("distancier",),
    "distancia": ("distancier",),
    "distanciâmes": ("distancier",),
    "distanciant": ("distancier",),
    "distancias": ("distancier",),
    "distanciassent": ("distancier",),
    "distanciasses": ("distancier",),
    "distanciasse": ("distancier",),
    "distanciassiez": ("distancier",),
    "distanciassions": ("distancier",),
    "distanciâtes": ("distancier",),
    "distanciât": ("distancier",),
    "distanciée": ("distancier",),
    "distanciées": ("distancier",),
    "distancié": ("distancier",),
    "distancient": ("distancier",),
    "distancie": ("distancier",),
    "distanciera": ("distancier",),
    "distancieraient": ("distancier",),
    "distancierai": ("distancier",),
    "distancierais": ("distancier",),
    "distancierait": ("distancier",),
    "distancieras": ("distancier",),
    "distancièrent": ("distancier",),
    "distancierez": ("distancier",),
    "distancieriez": ("distancier",),
    "distancierions": ("distancier",),
    "distancierons": ("distancier",),
    "distancieront": ("distancier",),
    "distanciés": ("distancier",),
    "distancies": ("distancier",),
    "distanciiez": ("distancier",),
    "distanciions": ("distancier",),
    "distendaient": ("distendre",),
    "distendais": ("distendre",),
    "distendait": ("distendre",),
    "distendant": ("distendre",),
    "distendent": ("distendre",),
    "distende": ("distendre",),
    "distendes": ("distendre",),
    "distendez": ("distendre",),
    "distendiez": ("distendre",),
    "distendîmes": ("distendre",),
    "distendions": ("distendre",),
    "distendirent": ("distendre",),
    "distendis": ("distendre",),
    "distendissent": ("distendre",),
    "distendisses": ("distendre",),
    "distendisse": ("distendre",),
    "distendissiez": ("distendre",),
    "distendissions": ("distendre",),
    "distendîtes": ("distendre",),
    "distendit": ("distendre",),
    "distendît": ("distendre",),
    "distendons": ("distendre",),
    "distend": ("distendre",),
    "distendra": ("distendre",),
    "distendraient": ("distendre",),
    "distendrai": ("distendre",),
    "distendrais": ("distendre",),
    "distendrait": ("distendre",),
    "distendras": ("distendre",),
    "distendrez": ("distendre",),
    "distendriez": ("distendre",),
    "distendrions": ("distendre",),
    "distendrons": ("distendre",),
    "distendront": ("distendre",),
    "distends": ("distendre",),
    "distendue": ("distendre",),
    "distendues": ("distendre",),
    "distendu": ("distendre",),
    "distendus": ("distendre",),
    "distordaient": ("distordre",),
    "distordais": ("distordre",),
    "distordait": ("distordre",),
    "distordant": ("distordre",),
    "distordent": ("distordre",),
    "distorde": ("distordre",),
    "distordes": ("distordre",),
    "distordez": ("distordre",),
    "distordiez": ("distordre",),
    "distordîmes": ("distordre",),
    "distordions": ("distordre",),
    "distordirent": ("distordre",),
    "distordis": ("distordre",),
    "distordissent": ("distordre",),
    "distordisses": ("distordre",),
    "distordisse": ("distordre",),
    "distordissiez": ("distordre",),
    "distordissions": ("distordre",),
    "distordîtes": ("distordre",),
    "distordit": ("distordre",),
    "distordît": ("distordre",),
    "distordons": ("distordre",),
    "distord": ("distordre",),
    "distordra": ("distordre",),
    "distordraient": ("distordre",),
    "distordrai": ("distordre",),
    "distordrais": ("distordre",),
    "distordrait": ("distordre",),
    "distordras": ("distordre",),
    "distordrez": ("distordre",),
    "distordriez": ("distordre",),
    "distordrions": ("distordre",),
    "distordrons": ("distordre",),
    "distordront": ("distordre",),
    "distords": ("distordre",),
    "distordue": ("distordre",),
    "distordues": ("distordre",),
    "distordu": ("distordre",),
    "distordus": ("distordre",),
    "distraient": ("distraire",),
    "distraie": ("distraire",),
    "distraies": ("distraire",),
    "distraira": ("distraire",),
    "distrairaient": ("distraire",),
    "distrairai": ("distraire",),
    "distrairais": ("distraire",),
    "distrairait": ("distraire",),
    "distrairas": ("distraire",),
    "distrairez": ("distraire",),
    "distrairiez": ("distraire",),
    "distrairions": ("distraire",),
    "distrairons": ("distraire",),
    "distrairont": ("distraire",),
    "distrais": ("distraire",),
    "distraite": ("distraire",),
    "distraites": ("distraire",),
    "distrait": ("distraire",),
    "distraits": ("distraire",),
    "distrayaient": ("distraire",),
    "distrayais": ("distraire",),
    "distrayait": ("distraire",),
    "distrayant": ("distraire",),
    "distrayez": ("distraire",),
    "distrayiez": ("distraire",),
    "distrayions": ("distraire",),
    "distrayons": ("distraire",),
    "divergeaient": ("diverger",),
    "divergeai": ("diverger",),
    "divergeais": ("diverger",),
    "divergeait": ("diverger",),
    "divergea": ("diverger",),
    "divergeâmes": ("diverger",),
    "divergeant": ("diverger",),
    "divergeas": ("diverger",),
    "divergeassent": ("diverger",),
    "divergeasses": ("diverger",),
    "divergeasse": ("diverger",),
    "divergeassiez": ("diverger",),
    "divergeassions": ("diverger",),
    "divergeâtes": ("diverger",),
    "divergeât": ("diverger",),
    "divergé": ("diverger",),
    "divergent": ("diverger",),
    "divergeons": ("diverger",),
    "diverge": ("diverger",),
    "divergera": ("diverger",),
    "divergeraient": ("diverger",),
    "divergerai": ("diverger",),
    "divergerais": ("diverger",),
    "divergerait": ("diverger",),
    "divergeras": ("diverger",),
    "divergèrent": ("diverger",),
    "divergerez": ("diverger",),
    "divergeriez": ("diverger",),
    "divergerions": ("diverger",),
    "divergerons": ("diverger",),
    "divergeront": ("diverger",),
    "diverges": ("diverger",),
    "divergez": ("diverger",),
    "divergiez": ("diverger",),
    "divergions": ("diverger",),
    "diversifiaient": ("diversifier",),
    "diversifiai": ("diversifier",),
    "diversifiais": ("diversifier",),
    "diversifiait": ("diversifier",),
    "diversifia": ("diversifier",),
    "diversifiâmes": ("diversifier",),
    "diversifiant": ("diversifier",),
    "diversifias": ("diversifier",),
    "diversifiassent": ("diversifier",),
    "diversifiasses": ("diversifier",),
    "diversifiasse": ("diversifier",),
    "diversifiassiez": ("diversifier",),
    "diversifiassions": ("diversifier",),
    "diversifiâtes": ("diversifier",),
    "diversifiât": ("diversifier",),
    "diversifiée": ("diversifier",),
    "diversifiées": ("diversifier",),
    "diversifié": ("diversifier",),
    "diversifient": ("diversifier",),
    "diversifie": ("diversifier",),
    "diversifiera": ("diversifier",),
    "diversifieraient": ("diversifier",),
    "diversifierai": ("diversifier",),
    "diversifierais": ("diversifier",),
    "diversifierait": ("diversifier",),
    "diversifieras": ("diversifier",),
    "diversifièrent": ("diversifier",),
    "diversifierez": ("diversifier",),
    "diversifieriez": ("diversifier",),
    "diversifierions": ("diversifier",),
    "diversifierons": ("diversifier",),
    "diversifieront": ("diversifier",),
    "diversifiés": ("diversifier",),
    "diversifies": ("diversifier",),
    "diversifiez": ("diversifier",),
    "diversifiiez": ("diversifier",),
    "diversifiions": ("diversifier",),
    "diversifions": ("diversifier",),
    "divertie": ("divertir",),
    "diverties": ("divertir",),
    "diverti": ("divertir",),
    "divertîmes": ("divertir",),
    "divertira": ("divertir",),
    "divertiraient": ("divertir",),
    "divertirai": ("divertir",),
    "divertirais": ("divertir",),
    "divertirait": ("divertir",),
    "divertiras": ("divertir",),
    "divertirent": ("divertir",),
    "divertirez": ("divertir",),
    "divertiriez": ("divertir",),
    "divertirions": ("divertir",),
    "divertirons": ("divertir",),
    "divertiront": ("divertir",),
    "divertis": ("divertir",),
    "divertissaient": ("divertir",),
    "divertissais": ("divertir",),
    "divertissait": ("divertir",),
    "divertissant": ("divertir",),
    "divertissent": ("divertir",),
    "divertisse": ("divertir",),
    "divertisses": ("divertir",),
    "divertissez": ("divertir",),
    "divertissiez": ("divertir",),
    "divertissions": ("divertir",),
    "divertissons": ("divertir",),
    "divertîtes": ("divertir",),
    "divertit": ("divertir",),
    "divertît": ("divertir",),
    "divorçaient": ("divorcer",),
    "divorçai": ("divorcer",),
    "divorçais": ("divorcer",),
    "divorçait": ("divorcer",),
    "divorça": ("divorcer",),
    "divorçâmes": ("divorcer",),
    "divorçant": ("divorcer",),
    "divorças": ("divorcer",),
    "divorçassent": ("divorcer",),
    "divorçasses": ("divorcer",),
    "divorçasse": ("divorcer",),
    "divorçassiez": ("divorcer",),
    "divorçassions": ("divorcer",),
    "divorçâtes": ("divorcer",),
    "divorçât": ("divorcer",),
    "divorcée": ("divorcer",),
    "divorcées": ("divorcer",),
    "divorcé": ("divorcer",),
    "divorcent": ("divorcer",),
    "divorce": ("divorcer",),
    "divorcera": ("divorcer",),
    "divorceraient": ("divorcer",),
    "divorcerai": ("divorcer",),
    "divorcerais": ("divorcer",),
    "divorcerait": ("divorcer",),
    "divorceras": ("divorcer",),
    "divorcèrent": ("divorcer",),
    "divorcerez": ("divorcer",),
    "divorceriez": ("divorcer",),
    "divorcerions": ("divorcer",),
    "divorcerons": ("divorcer",),
    "divorceront": ("divorcer",),
    "divorcés": ("divorcer",),
    "divorces": ("divorcer",),
    "divorcez": ("divorcer",),
    "divorciez": ("divorcer",),
    "divorcions": ("divorcer",),
    "divorçons": ("divorcer",),
    "domiciliaient": ("domicilier",),
    "domiciliai": ("domicilier",),
    "domiciliais": ("domicilier",),
    "domiciliait": ("domicilier",),
    "domicilia": ("domicilier",),
    "domiciliâmes": ("domicilier",),
    "domiciliant": ("domicilier",),
    "domicilias": ("domicilier",),
    "domiciliassent": ("domicilier",),
    "domiciliasses": ("domicilier",),
    "domiciliasse": ("domicilier",),
    "domiciliassiez": ("domicilier",),
    "domiciliassions": ("domicilier",),
    "domiciliâtes": ("domicilier",),
    "domiciliât": ("domicilier",),
    "domiciliée": ("domicilier",),
    "domiciliées": ("domicilier",),
    "domicilié": ("domicilier",),
    "domicilient": ("domicilier",),
    "domicilie": ("domicilier",),
    "domiciliera": ("domicilier",),
    "domicilieraient": ("domicilier",),
    "domicilierai": ("domicilier",),
    "domicilierais": ("domicilier",),
    "domicilierait": ("domicilier",),
    "domicilieras": ("domicilier",),
    "domicilièrent": ("domicilier",),
    "domicilierez": ("domicilier",),
    "domicilieriez": ("domicilier",),
    "domicilierions": ("domicilier",),
    "domicilierons": ("domicilier",),
    "domicilieront": ("domicilier",),
    "domiciliés": ("domicilier",),
    "domicilies": ("domicilier",),
    "domiciliez": ("domicilier",),
    "domiciliiez": ("domicilier",),
    "domiciliions": ("domicilier",),
    "domicilions": ("domicilier",),
    "domifiaient": ("domifier",),
    "domifiai": ("domifier",),
    "domifiais": ("domifier",),
    "domifiait": ("domifier",),
    "domifia": ("domifier",),
    "domifiâmes": ("domifier",),
    "domifiant": ("domifier",),
    "domifias": ("domifier",),
    "domifiassent": ("domifier",),
    "domifiasses": ("domifier",),
    "domifiasse": ("domifier",),
    "domifiassiez": ("domifier",),
    "domifiassions": ("domifier",),
    "domifiâtes": ("domifier",),
    "domifiât": ("domifier",),
    "domifiée": ("domifier",),
    "domifiées": ("domifier",),
    "domifié": ("domifier",),
    "domifient": ("domifier",),
    "domifie": ("domifier",),
    "domifiera": ("domifier",),
    "domifieraient": ("domifier",),
    "domifierai": ("domifier",),
    "domifierais": ("domifier",),
    "domifierait": ("domifier",),
    "domifieras": ("domifier",),
    "domifièrent": ("domifier",),
    "domifierez": ("domifier",),
    "domifieriez": ("domifier",),
    "domifierions": ("domifier",),
    "domifierons": ("domifier",),
    "domifieront": ("domifier",),
    "domifiés": ("domifier",),
    "domifies": ("domifier",),
    "domifiez": ("domifier",),
    "domifiiez": ("domifier",),
    "domifiions": ("domifier",),
    "domifions": ("domifier",),
    "dormassaient": ("dormasser",),
    "dormassai": ("dormasser",),
    "dormassais": ("dormasser",),
    "dormassait": ("dormasser",),
    "dormassa": ("dormasser",),
    "dormassâmes": ("dormasser",),
    "dormassant": ("dormasser",),
    "dormassas": ("dormasser",),
    "dormassassent": ("dormasser",),
    "dormassasses": ("dormasser",),
    "dormassasse": ("dormasser",),
    "dormassassiez": ("dormasser",),
    "dormassassions": ("dormasser",),
    "dormassâtes": ("dormasser",),
    "dormassât": ("dormasser",),
    "dormassé": ("dormasser",),
    "dormassent": ("dormasser",),
    "dormasse": ("dormasser",),
    "dormassera": ("dormasser",),
    "dormasseraient": ("dormasser",),
    "dormasserai": ("dormasser",),
    "dormasserais": ("dormasser",),
    "dormasserait": ("dormasser",),
    "dormasseras": ("dormasser",),
    "dormassèrent": ("dormasser",),
    "dormasserez": ("dormasser",),
    "dormasseriez": ("dormasser",),
    "dormasserions": ("dormasser",),
    "dormasserons": ("dormasser",),
    "dormasseront": ("dormasser",),
    "dormasses": ("dormasser",),
    "dormassez": ("dormasser",),
    "dormassiez": ("dormasser",),
    "dormassions": ("dormasser",),
    "dormassons": ("dormasser",),
    "dormaient": ("dormir",),
    "dormais": ("dormir",),
    "dormait": ("dormir",),
    "dormant": ("dormir",),
    "dorment": ("dormir",),
    "dorme": ("dormir",),
    "dormes": ("dormir",),
    "dormez": ("dormir",),
    "dormie": ("dormir",),
    "dormies": ("dormir",),
    "dormiez": ("dormir",),
    "dormi": ("dormir",),
    "dormîmes": ("dormir",),
    "dormions": ("dormir",),
    "dormira": ("dormir",),
    "dormiraient": ("dormir",),
    "dormirai": ("dormir",),
    "dormirais": ("dormir",),
    "dormirait": ("dormir",),
    "dormiras": ("dormir",),
    "dormirent": ("dormir",),
    "dormirez": ("dormir",),
    "dormiriez": ("dormir",),
    "dormirions": ("dormir",),
    "dormirons": ("dormir",),
    "dormiront": ("dormir",),
    "dormis": ("dormir",),
    "dormissent": ("dormir",),
    "dormisses": ("dormir",),
    "dormisse": ("dormir",),
    "dormissiez": ("dormir",),
    "dormissions": ("dormir",),
    "dormîtes": ("dormir",),
    "dormit": ("dormir",),
    "dormît": ("dormir",),
    "dormons": ("dormir",),
    "dors": ("dormir",),
    "dort": ("dormir",),
    "doucie": ("doucir",),
    "doucies": ("doucir",),
    "douci": ("doucir",),
    "doucîmes": ("doucir",),
    "doucira": ("doucir",),
    "douciraient": ("doucir",),
    "doucirai": ("doucir",),
    "doucirais": ("doucir",),
    "doucirait": ("doucir",),
    "douciras": ("doucir",),
    "doucirent": ("doucir",),
    "doucirez": ("doucir",),
    "douciriez": ("doucir",),
    "doucirions": ("doucir",),
    "doucirons": ("doucir",),
    "douciront": ("doucir",),
    "doucis": ("doucir",),
    "doucissaient": ("doucir",),
    "doucissais": ("doucir",),
    "doucissait": ("doucir",),
    "doucissant": ("doucir",),
    "doucissent": ("doucir",),
    "doucisse": ("doucir",),
    "doucisses": ("doucir",),
    "doucissez": ("doucir",),
    "doucissiez": ("doucir",),
    "doucissions": ("doucir",),
    "doucissons": ("doucir",),
    "doucîtes": ("doucir",),
    "doucit": ("doucir",),
    "doucît": ("doucir",),
    "dragéifiaient": ("dragéifier",),
    "dragéifiai": ("dragéifier",),
    "dragéifiais": ("dragéifier",),
    "dragéifiait": ("dragéifier",),
    "dragéifia": ("dragéifier",),
    "dragéifiâmes": ("dragéifier",),
    "dragéifiant": ("dragéifier",),
    "dragéifias": ("dragéifier",),
    "dragéifiassent": ("dragéifier",),
    "dragéifiasses": ("dragéifier",),
    "dragéifiasse": ("dragéifier",),
    "dragéifiassiez": ("dragéifier",),
    "dragéifiassions": ("dragéifier",),
    "dragéifiâtes": ("dragéifier",),
    "dragéifiât": ("dragéifier",),
    "dragéifiée": ("dragéifier",),
    "dragéifiées": ("dragéifier",),
    "dragéifié": ("dragéifier",),
    "dragéifient": ("dragéifier",),
    "dragéifie": ("dragéifier",),
    "dragéifiera": ("dragéifier",),
    "dragéifieraient": ("dragéifier",),
    "dragéifierai": ("dragéifier",),
    "dragéifierais": ("dragéifier",),
    "dragéifierait": ("dragéifier",),
    "dragéifieras": ("dragéifier",),
    "dragéifièrent": ("dragéifier",),
    "dragéifierez": ("dragéifier",),
    "dragéifieriez": ("dragéifier",),
    "dragéifierions": ("dragéifier",),
    "dragéifierons": ("dragéifier",),
    "dragéifieront": ("dragéifier",),
    "dragéifiés": ("dragéifier",),
    "dragéifies": ("dragéifier",),
    "dragéifiez": ("dragéifier",),
    "dragéifiiez": ("dragéifier",),
    "dragéifiions": ("dragéifier",),
    "dragéifions": ("dragéifier",),
    "drapelaient": ("drapeler",),
    "drapelai": ("drapeler",),
    "drapelais": ("drapeler",),
    "drapelait": ("drapeler",),
    "drapela": ("drapeler",),
    "drapelâmes": ("drapeler",),
    "drapelant": ("drapeler",),
    "drapelas": ("drapeler",),
    "drapelassent": ("drapeler",),
    "drapelasses": ("drapeler",),
    "drapelasse": ("drapeler",),
    "drapelassiez": ("drapeler",),
    "drapelassions": ("drapeler",),
    "drapelâtes": ("drapeler",),
    "drapelât": ("drapeler",),
    "drapelée": ("drapeler",),
    "drapelées": ("drapeler",),
    "drapelé": ("drapeler",),
    "drapèlent": ("drapeler",),
    "drapèle": ("drapeler",),
    "drapèlera": ("drapeler",),
    "drapèleraient": ("drapeler",),
    "drapèlerai": ("drapeler",),
    "drapèlerais": ("drapeler",),
    "drapèlerait": ("drapeler",),
    "drapèleras": ("drapeler",),
    "drapelèrent": ("drapeler",),
    "drapèlerez": ("drapeler",),
    "drapèleriez": ("drapeler",),
    "drapèlerions": ("drapeler",),
    "drapèlerons": ("drapeler",),
    "drapèleront": ("drapeler",),
    "drapelés": ("drapeler",),
    "drapèles": ("drapeler",),
    "drapelez": ("drapeler",),
    "drapeliez": ("drapeler",),
    "drapelions": ("drapeler",),
    "drapelons": ("drapeler",),
    "draient": ("drayer",),
    "draie": ("drayer",),
    "draiera": ("drayer",),
    "draieraient": ("drayer",),
    "draierai": ("drayer",),
    "draierais": ("drayer",),
    "draierait": ("drayer",),
    "draieras": ("drayer",),
    "draierez": ("drayer",),
    "draieriez": ("drayer",),
    "draierions": ("drayer",),
    "draierons": ("drayer",),
    "draieront": ("drayer",),
    "draies": ("drayer",),
    "drayaient": ("drayer",),
    "drayai": ("drayer",),
    "drayais": ("drayer",),
    "drayait": ("drayer",),
    "draya": ("drayer",),
    "drayâmes": ("drayer",),
    "drayant": ("drayer",),
    "drayas": ("drayer",),
    "drayassent": ("drayer",),
    "drayasses": ("drayer",),
    "drayasse": ("drayer",),
    "drayassiez": ("drayer",),
    "drayassions": ("drayer",),
    "drayâtes": ("drayer",),
    "drayât": ("drayer",),
    "drayée": ("drayer",),
    "drayées": ("drayer",),
    "drayé": ("drayer",),
    "drayent": ("drayer",),
    "draye": ("drayer",),
    "drayera": ("drayer",),
    "drayeraient": ("drayer",),
    "drayerai": ("drayer",),
    "drayerais": ("drayer",),
    "drayerait": ("drayer",),
    "drayeras": ("drayer",),
    "drayèrent": ("drayer",),
    "drayerez": ("drayer",),
    "drayeriez": ("drayer",),
    "drayerions": ("drayer",),
    "drayerons": ("drayer",),
    "drayeront": ("drayer",),
    "drayés": ("drayer",),
    "drayes": ("drayer",),
    "drayez": ("drayer",),
    "drayiez": ("drayer",),
    "drayions": ("drayer",),
    "drayons": ("drayer",),
    "drégeaient": ("dréger",),
    "drégeai": ("dréger",),
    "drégeais": ("dréger",),
    "drégeait": ("dréger",),
    "drégea": ("dréger",),
    "drégeâmes": ("dréger",),
    "drégeant": ("dréger",),
    "drégeas": ("dréger",),
    "drégeassent": ("dréger",),
    "drégeasses": ("dréger",),
    "drégeasse": ("dréger",),
    "drégeassiez": ("dréger",),
    "drégeassions": ("dréger",),
    "drégeâtes": ("dréger",),
    "drégeât": ("dréger",),
    "drégée": ("dréger",),
    "drégées": ("dréger",),
    "drégé": ("dréger",),
    "drègent": ("dréger",),
    "drégeons": ("dréger",),
    "drège": ("dréger",),
    "drégera": ("dréger",),
    "drégeraient": ("dréger",),
    "drégerai": ("dréger",),
    "drégerais": ("dréger",),
    "drégerait": ("dréger",),
    "drégeras": ("dréger",),
    "drégèrent": ("dréger",),
    "drégerez": ("dréger",),
    "drégeriez": ("dréger",),
    "drégerions": ("dréger",),
    "drégerons": ("dréger",),
    "drégeront": ("dréger",),
    "drégés": ("dréger",),
    "drèges": ("dréger",),
    "drégez": ("dréger",),
    "drégiez": ("dréger",),
    "drégions": ("dréger",),
    "duira": ("duire",),
    "duiraient": ("duire",),
    "duirai": ("duire",),
    "duirais": ("duire",),
    "duirait": ("duire",),
    "duiras": ("duire",),
    "duirez": ("duire",),
    "duiriez": ("duire",),
    "duirions": ("duire",),
    "duirons": ("duire",),
    "duiront": ("duire",),
    "duisaient": ("duire",),
    "duisais": ("duire",),
    "duisait": ("duire",),
    "duisant": ("duire",),
    "duisent": ("duire",),
    "duise": ("duire",),
    "duises": ("duire",),
    "duisez": ("duire",),
    "duisiez": ("duire",),
    "duisîmes": ("duire",),
    "duisions": ("duire",),
    "duisirent": ("duire",),
    "duisis": ("duire",),
    "duisissent": ("duire",),
    "duisisses": ("duire",),
    "duisisse": ("duire",),
    "duisissiez": ("duire",),
    "duisissions": ("duire",),
    "duisîtes": ("duire",),
    "duisit": ("duire",),
    "duisît": ("duire",),
    "duisons": ("duire",),
    "duis": ("duire",),
    "duite": ("duire",),
    "duites": ("duire",),
    "duit": ("duire",),
    "duits": ("duire",),
    "dulcifiaient": ("dulcifier",),
    "dulcifiai": ("dulcifier",),
    "dulcifiais": ("dulcifier",),
    "dulcifiait": ("dulcifier",),
    "dulcifia": ("dulcifier",),
    "dulcifiâmes": ("dulcifier",),
    "dulcifiant": ("dulcifier",),
    "dulcifias": ("dulcifier",),
    "dulcifiassent": ("dulcifier",),
    "dulcifiasses": ("dulcifier",),
    "dulcifiasse": ("dulcifier",),
    "dulcifiassiez": ("dulcifier",),
    "dulcifiassions": ("dulcifier",),
    "dulcifiâtes": ("dulcifier",),
    "dulcifiât": ("dulcifier",),
    "dulcifiée": ("dulcifier",),
    "dulcifiées": ("dulcifier",),
    "dulcifié": ("dulcifier",),
    "dulcifient": ("dulcifier",),
    "dulcifie": ("dulcifier",),
    "dulcifiera": ("dulcifier",),
    "dulcifieraient": ("dulcifier",),
    "dulcifierai": ("dulcifier",),
    "dulcifierais": ("dulcifier",),
    "dulcifierait": ("dulcifier",),
    "dulcifieras": ("dulcifier",),
    "dulcifièrent": ("dulcifier",),
    "dulcifierez": ("dulcifier",),
    "dulcifieriez": ("dulcifier",),
    "dulcifierions": ("dulcifier",),
    "dulcifierons": ("dulcifier",),
    "dulcifieront": ("dulcifier",),
    "dulcifiés": ("dulcifier",),
    "dulcifies": ("dulcifier",),
    "dulcifiez": ("dulcifier",),
    "dulcifiiez": ("dulcifier",),
    "dulcifiions": ("dulcifier",),
    "dulcifions": ("dulcifier",),
    "durcie": ("durcir",),
    "durcies": ("durcir",),
    "durci": ("durcir",),
    "durcîmes": ("durcir",),
    "durcira": ("durcir",),
    "durciraient": ("durcir",),
    "durcirai": ("durcir",),
    "durcirais": ("durcir",),
    "durcirait": ("durcir",),
    "durciras": ("durcir",),
    "durcirent": ("durcir",),
    "durcirez": ("durcir",),
    "durciriez": ("durcir",),
    "durcirions": ("durcir",),
    "durcirons": ("durcir",),
    "durciront": ("durcir",),
    "durcis": ("durcir",),
    "durcissaient": ("durcir",),
    "durcissais": ("durcir",),
    "durcissait": ("durcir",),
    "durcissant": ("durcir",),
    "durcissent": ("durcir",),
    "durcisse": ("durcir",),
    "durcisses": ("durcir",),
    "durcissez": ("durcir",),
    "durcissiez": ("durcir",),
    "durcissions": ("durcir",),
    "durcissons": ("durcir",),
    "durcîtes": ("durcir",),
    "durcit": ("durcir",),
    "durcît": ("durcir",),
    "duvetaient": ("duveter",),
    "duvetai": ("duveter",),
    "duvetais": ("duveter",),
    "duvetait": ("duveter",),
    "duveta": ("duveter",),
    "duvetâmes": ("duveter",),
    "duvetant": ("duveter",),
    "duvetas": ("duveter",),
    "duvetassent": ("duveter",),
    "duvetasses": ("duveter",),
    "duvetasse": ("duveter",),
    "duvetassiez": ("duveter",),
    "duvetassions": ("duveter",),
    "duvetâtes": ("duveter",),
    "duvetât": ("duveter",),
    "duvetée": ("duveter",),
    "duvetées": ("duveter",),
    "duveté": ("duveter",),
    "duvetèrent": ("duveter",),
    "duvetés": ("duveter",),
    "duvetez": ("duveter",),
    "duvetiez": ("duveter",),
    "duvetions": ("duveter",),
    "duvetons": ("duveter",),
    "duvettent": ("duveter",),
    "duvette": ("duveter",),
    "duvettera": ("duveter",),
    "duvetteraient": ("duveter",),
    "duvetterai": ("duveter",),
    "duvetterais": ("duveter",),
    "duvetterait": ("duveter",),
    "duvetteras": ("duveter",),
    "duvetterez": ("duveter",),
    "duvetteriez": ("duveter",),
    "duvetterions": ("duveter",),
    "duvetterons": ("duveter",),
    "duvetteront": ("duveter",),
    "duvettes": ("duveter",),
    "ébahie": ("ébahir",),
    "ébahies": ("ébahir",),
    "ébahi": ("ébahir",),
    "ébahîmes": ("ébahir",),
    "ébahira": ("ébahir",),
    "ébahiraient": ("ébahir",),
    "ébahirai": ("ébahir",),
    "ébahirais": ("ébahir",),
    "ébahirait": ("ébahir",),
    "ébahiras": ("ébahir",),
    "ébahirent": ("ébahir",),
    "ébahirez": ("ébahir",),
    "ébahiriez": ("ébahir",),
    "ébahirions": ("ébahir",),
    "ébahirons": ("ébahir",),
    "ébahiront": ("ébahir",),
    "ébahis": ("ébahir",),
    "ébahissaient": ("ébahir",),
    "ébahissais": ("ébahir",),
    "ébahissait": ("ébahir",),
    "ébahissant": ("ébahir",),
    "ébahissent": ("ébahir",),
    "ébahisse": ("ébahir",),
    "ébahisses": ("ébahir",),
    "ébahissez": ("ébahir",),
    "ébahissiez": ("ébahir",),
    "ébahissions": ("ébahir",),
    "ébahissons": ("ébahir",),
    "ébahîtes": ("ébahir",),
    "ébahit": ("ébahir",),
    "ébahît": ("ébahir",),
    "ébarouie": ("ébarouir",),
    "ébarouies": ("ébarouir",),
    "ébaroui": ("ébarouir",),
    "ébarouîmes": ("ébarouir",),
    "ébarouira": ("ébarouir",),
    "ébarouiraient": ("ébarouir",),
    "ébarouirai": ("ébarouir",),
    "ébarouirais": ("ébarouir",),
    "ébarouirait": ("ébarouir",),
    "ébarouiras": ("ébarouir",),
    "ébarouirent": ("ébarouir",),
    "ébarouirez": ("ébarouir",),
    "ébarouiriez": ("ébarouir",),
    "ébarouirions": ("ébarouir",),
    "ébarouirons": ("ébarouir",),
    "ébarouiront": ("ébarouir",),
    "ébarouis": ("ébarouir",),
    "ébarouissaient": ("ébarouir",),
    "ébarouissais": ("ébarouir",),
    "ébarouissait": ("ébarouir",),
    "ébarouissant": ("ébarouir",),
    "ébarouissent": ("ébarouir",),
    "ébarouisse": ("ébarouir",),
    "ébarouisses": ("ébarouir",),
    "ébarouissez": ("ébarouir",),
    "ébarouissiez": ("ébarouir",),
    "ébarouissions": ("ébarouir",),
    "ébarouissons": ("ébarouir",),
    "ébarouîtes": ("ébarouir",),
    "ébarouit": ("ébarouir",),
    "ébarouît": ("ébarouir",),
    "ébat": ("ébattre",),
    "ébats": ("ébattre",),
    "ébattaient": ("ébattre",),
    "ébattais": ("ébattre",),
    "ébattait": ("ébattre",),
    "ébattant": ("ébattre",),
    "ébattent": ("ébattre",),
    "ébatte": ("ébattre",),
    "ébattes": ("ébattre",),
    "ébattez": ("ébattre",),
    "ébattiez": ("ébattre",),
    "ébattîmes": ("ébattre",),
    "ébattions": ("ébattre",),
    "ébattirent": ("ébattre",),
    "ébattis": ("ébattre",),
    "ébattissent": ("ébattre",),
    "ébattisses": ("ébattre",),
    "ébattisse": ("ébattre",),
    "ébattissiez": ("ébattre",),
    "ébattissions": ("ébattre",),
    "ébattîtes": ("ébattre",),
    "ébattit": ("ébattre",),
    "ébattît": ("ébattre",),
    "ébattons": ("ébattre",),
    "ébattra": ("ébattre",),
    "ébattraient": ("ébattre",),
    "ébattrai": ("ébattre",),
    "ébattrais": ("ébattre",),
    "ébattrait": ("ébattre",),
    "ébattras": ("ébattre",),
    "ébattrez": ("ébattre",),
    "ébattriez": ("ébattre",),
    "ébattrions": ("ébattre",),
    "ébattrons": ("ébattre",),
    "ébattront": ("ébattre",),
    "ébattue": ("ébattre",),
    "ébattues": ("ébattre",),
    "ébattu": ("ébattre",),
    "ébattus": ("ébattre",),
    "ébaubie": ("ébaubir",),
    "ébaubies": ("ébaubir",),
    "ébaubi": ("ébaubir",),
    "ébaubîmes": ("ébaubir",),
    "ébaubira": ("ébaubir",),
    "ébaubiraient": ("ébaubir",),
    "ébaubirai": ("ébaubir",),
    "ébaubirais": ("ébaubir",),
    "ébaubirait": ("ébaubir",),
    "ébaubiras": ("ébaubir",),
    "ébaubirent": ("ébaubir",),
    "ébaubirez": ("ébaubir",),
    "ébaubiriez": ("ébaubir",),
    "ébaubirions": ("ébaubir",),
    "ébaubirons": ("ébaubir",),
    "ébaubiront": ("ébaubir",),
    "ébaubis": ("ébaubir",),
    "ébaubissaient": ("ébaubir",),
    "ébaubissais": ("ébaubir",),
    "ébaubissait": ("ébaubir",),
    "ébaubissant": ("ébaubir",),
    "ébaubissent": ("ébaubir",),
    "ébaubisse": ("ébaubir",),
    "ébaubisses": ("ébaubir",),
    "ébaubissez": ("ébaubir",),
    "ébaubissiez": ("ébaubir",),
    "ébaubissions": ("ébaubir",),
    "ébaubissons": ("ébaubir",),
    "ébaubîtes": ("ébaubir",),
    "ébaubit": ("ébaubir",),
    "ébaubît": ("ébaubir",),
    "ébaudie": ("ébaudir",),
    "ébaudies": ("ébaudir",),
    "ébaudi": ("ébaudir",),
    "ébaudîmes": ("ébaudir",),
    "ébaudira": ("ébaudir",),
    "ébaudiraient": ("ébaudir",),
    "ébaudirai": ("ébaudir",),
    "ébaudirais": ("ébaudir",),
    "ébaudirait": ("ébaudir",),
    "ébaudiras": ("ébaudir",),
    "ébaudirent": ("ébaudir",),
    "ébaudirez": ("ébaudir",),
    "ébaudiriez": ("ébaudir",),
    "ébaudirions": ("ébaudir",),
    "ébaudirons": ("ébaudir",),
    "ébaudiront": ("ébaudir",),
    "ébaudis": ("ébaudir",),
    "ébaudissaient": ("ébaudir",),
    "ébaudissais": ("ébaudir",),
    "ébaudissait": ("ébaudir",),
    "ébaudissant": ("ébaudir",),
    "ébaudissent": ("ébaudir",),
    "ébaudisse": ("ébaudir",),
    "ébaudisses": ("ébaudir",),
    "ébaudissez": ("ébaudir",),
    "ébaudissiez": ("ébaudir",),
    "ébaudissions": ("ébaudir",),
    "ébaudissons": ("ébaudir",),
    "ébaudîtes": ("ébaudir",),
    "ébaudit": ("ébaudir",),
    "ébaudît": ("ébaudir",),
    "ébergeaient": ("éberger",),
    "ébergeai": ("éberger",),
    "ébergeais": ("éberger",),
    "ébergeait": ("éberger",),
    "ébergea": ("éberger",),
    "ébergeâmes": ("éberger",),
    "ébergeant": ("éberger",),
    "ébergeas": ("éberger",),
    "ébergeassent": ("éberger",),
    "ébergeasses": ("éberger",),
    "ébergeasse": ("éberger",),
    "ébergeassiez": ("éberger",),
    "ébergeassions": ("éberger",),
    "ébergeâtes": ("éberger",),
    "ébergeât": ("éberger",),
    "ébergée": ("éberger",),
    "ébergées": ("éberger",),
    "ébergé": ("éberger",),
    "ébergent": ("éberger",),
    "ébergeons": ("éberger",),
    "éberge": ("éberger",),
    "ébergera": ("éberger",),
    "ébergeraient": ("éberger",),
    "ébergerai": ("éberger",),
    "ébergerais": ("éberger",),
    "ébergerait": ("éberger",),
    "ébergeras": ("éberger",),
    "ébergèrent": ("éberger",),
    "ébergerez": ("éberger",),
    "ébergeriez": ("éberger",),
    "ébergerions": ("éberger",),
    "ébergerons": ("éberger",),
    "ébergeront": ("éberger",),
    "ébergés": ("éberger",),
    "éberges": ("éberger",),
    "ébergez": ("éberger",),
    "ébergiez": ("éberger",),
    "ébergions": ("éberger",),
    "ébiselaient": ("ébiseler",),
    "ébiselai": ("ébiseler",),
    "ébiselais": ("ébiseler",),
    "ébiselait": ("ébiseler",),
    "ébisela": ("ébiseler",),
    "ébiselâmes": ("ébiseler",),
    "ébiselant": ("ébiseler",),
    "ébiselas": ("ébiseler",),
    "ébiselassent": ("ébiseler",),
    "ébiselasses": ("ébiseler",),
    "ébiselasse": ("ébiseler",),
    "ébiselassiez": ("ébiseler",),
    "ébiselassions": ("ébiseler",),
    "ébiselâtes": ("ébiseler",),
    "ébiselât": ("ébiseler",),
    "ébiselée": ("ébiseler",),
    "ébiselées": ("ébiseler",),
    "ébiselé": ("ébiseler",),
    "ébiselèrent": ("ébiseler",),
    "ébiselés": ("ébiseler",),
    "ébiselez": ("ébiseler",),
    "ébiseliez": ("ébiseler",),
    "ébiselions": ("ébiseler",),
    "ébisellent": ("ébiseler",),
    "ébiselle": ("ébiseler",),
    "ébisellera": ("ébiseler",),
    "ébiselleraient": ("ébiseler",),
    "ébisellerai": ("ébiseler",),
    "ébisellerais": ("ébiseler",),
    "ébisellerait": ("ébiseler",),
    "ébiselleras": ("ébiseler",),
    "ébisellerez": ("ébiseler",),
    "ébiselleriez": ("ébiseler",),
    "ébisellerions": ("ébiseler",),
    "ébisellerons": ("ébiseler",),
    "ébiselleront": ("ébiseler",),
    "ébiselles": ("ébiseler",),
    "ébiselons": ("ébiseler",),
    "éblouie": ("éblouir",),
    "éblouies": ("éblouir",),
    "ébloui": ("éblouir",),
    "éblouîmes": ("éblouir",),
    "éblouira": ("éblouir",),
    "éblouiraient": ("éblouir",),
    "éblouirai": ("éblouir",),
    "éblouirais": ("éblouir",),
    "éblouirait": ("éblouir",),
    "éblouiras": ("éblouir",),
    "éblouirent": ("éblouir",),
    "éblouirez": ("éblouir",),
    "éblouiriez": ("éblouir",),
    "éblouirions": ("éblouir",),
    "éblouirons": ("éblouir",),
    "éblouiront": ("éblouir",),
    "éblouis": ("éblouir",),
    "éblouissaient": ("éblouir",),
    "éblouissais": ("éblouir",),
    "éblouissait": ("éblouir",),
    "éblouissant": ("éblouir",),
    "éblouissent": ("éblouir",),
    "éblouisse": ("éblouir",),
    "éblouisses": ("éblouir",),
    "éblouissez": ("éblouir",),
    "éblouissiez": ("éblouir",),
    "éblouissions": ("éblouir",),
    "éblouissons": ("éblouir",),
    "éblouîtes": ("éblouir",),
    "éblouit": ("éblouir",),
    "éblouît": ("éblouir",),
    "ébouillaient": ("ébouillir",),
    "ébouillais": ("ébouillir",),
    "ébouillait": ("ébouillir",),
    "ébouillant": ("ébouillir",),
    "ébouillent": ("ébouillir",),
    "ébouille": ("ébouillir",),
    "ébouilles": ("ébouillir",),
    "ébouillez": ("ébouillir",),
    "ébouillie": ("ébouillir",),
    "ébouillies": ("ébouillir",),
    "ébouilliez": ("ébouillir",),
    "ébouilli": ("ébouillir",),
    "ébouillîmes": ("ébouillir",),
    "ébouillions": ("ébouillir",),
    "ébouillira": ("ébouillir",),
    "ébouilliraient": ("ébouillir",),
    "ébouillirai": ("ébouillir",),
    "ébouillirais": ("ébouillir",),
    "ébouillirait": ("ébouillir",),
    "ébouilliras": ("ébouillir",),
    "ébouillirent": ("ébouillir",),
    "ébouillirez": ("ébouillir",),
    "ébouilliriez": ("ébouillir",),
    "ébouillirions": ("ébouillir",),
    "ébouillirons": ("ébouillir",),
    "ébouilliront": ("ébouillir",),
    "ébouillis": ("ébouillir",),
    "ébouillissent": ("ébouillir",),
    "ébouillisses": ("ébouillir",),
    "ébouillisse": ("ébouillir",),
    "ébouillissiez": ("ébouillir",),
    "ébouillissions": ("ébouillir",),
    "ébouillîtes": ("ébouillir",),
    "ébouillit": ("ébouillir",),
    "ébouillît": ("ébouillir",),
    "ébouillons": ("ébouillir",),
    "ébous": ("ébouillir",),
    "ébout": ("ébouillir",),
    "ébouquetaient": ("ébouqueter",),
    "ébouquetai": ("ébouqueter",),
    "ébouquetais": ("ébouqueter",),
    "ébouquetait": ("ébouqueter",),
    "ébouqueta": ("ébouqueter",),
    "ébouquetâmes": ("ébouqueter",),
    "ébouquetant": ("ébouqueter",),
    "ébouquetas": ("ébouqueter",),
    "ébouquetassent": ("ébouqueter",),
    "ébouquetasses": ("ébouqueter",),
    "ébouquetasse": ("ébouqueter",),
    "ébouquetassiez": ("ébouqueter",),
    "ébouquetassions": ("ébouqueter",),
    "ébouquetâtes": ("ébouqueter",),
    "ébouquetât": ("ébouqueter",),
    "ébouquetée": ("ébouqueter",),
    "ébouquetées": ("ébouqueter",),
    "ébouqueté": ("ébouqueter",),
    "ébouquetèrent": ("ébouqueter",),
    "ébouquetés": ("ébouqueter",),
    "ébouquetez": ("ébouqueter",),
    "ébouquetiez": ("ébouqueter",),
    "ébouquetions": ("ébouqueter",),
    "ébouquetons": ("ébouqueter",),
    "ébouquettent": ("ébouqueter",),
    "ébouquette": ("ébouqueter",),
    "ébouquettera": ("ébouqueter",),
    "ébouquetteraient": ("ébouqueter",),
    "ébouquetterai": ("ébouqueter",),
    "ébouquetterais": ("ébouqueter",),
    "ébouquetterait": ("ébouqueter",),
    "ébouquetteras": ("ébouqueter",),
    "ébouquetterez": ("ébouqueter",),
    "ébouquetteriez": ("ébouqueter",),
    "ébouquetterions": ("ébouqueter",),
    "ébouquetterons": ("ébouqueter",),
    "ébouquetteront": ("ébouqueter",),
    "ébouquettes": ("ébouqueter",),
    "ébréchaient": ("ébrécher",),
    "ébréchai": ("ébrécher",),
    "ébréchais": ("ébrécher",),
    "ébréchait": ("ébrécher",),
    "ébrécha": ("ébrécher",),
    "ébréchâmes": ("ébrécher",),
    "ébréchant": ("ébrécher",),
    "ébréchas": ("ébrécher",),
    "ébréchassent": ("ébrécher",),
    "ébréchasses": ("ébrécher",),
    "ébréchasse": ("ébrécher",),
    "ébréchassiez": ("ébrécher",),
    "ébréchassions": ("ébrécher",),
    "ébréchâtes": ("ébrécher",),
    "ébréchât": ("ébrécher",),
    "ébréchée": ("ébrécher",),
    "ébréchées": ("ébrécher",),
    "ébréché": ("ébrécher",),
    "ébrèchent": ("ébrécher",),
    "ébrèche": ("ébrécher",),
    "ébréchera": ("ébrécher",),
    "ébrécheraient": ("ébrécher",),
    "ébrécherai": ("ébrécher",),
    "ébrécherais": ("ébrécher",),
    "ébrécherait": ("ébrécher",),
    "ébrécheras": ("ébrécher",),
    "ébréchèrent": ("ébrécher",),
    "ébrécherez": ("ébrécher",),
    "ébrécheriez": ("ébrécher",),
    "ébrécherions": ("ébrécher",),
    "ébrécherons": ("ébrécher",),
    "ébrécheront": ("ébrécher",),
    "ébréchés": ("ébrécher",),
    "ébrèches": ("ébrécher",),
    "ébréchez": ("ébrécher",),
    "ébréchiez": ("ébrécher",),
    "ébréchions": ("ébrécher",),
    "ébréchons": ("ébrécher",),
    "ébrenaient": ("ébrener",),
    "ébrenai": ("ébrener",),
    "ébrenais": ("ébrener",),
    "ébrenait": ("ébrener",),
    "ébrena": ("ébrener",),
    "ébrenâmes": ("ébrener",),
    "ébrenant": ("ébrener",),
    "ébrenas": ("ébrener",),
    "ébrenassent": ("ébrener",),
    "ébrenasses": ("ébrener",),
    "ébrenasse": ("ébrener",),
    "ébrenassiez": ("ébrener",),
    "ébrenassions": ("ébrener",),
    "ébrenâtes": ("ébrener",),
    "ébrenât": ("ébrener",),
    "ébrenée": ("ébrener",),
    "ébrenées": ("ébrener",),
    "ébrené": ("ébrener",),
    "ébrènent": ("ébrener",),
    "ébrène": ("ébrener",),
    "ébrènera": ("ébrener",),
    "ébrèneraient": ("ébrener",),
    "ébrènerai": ("ébrener",),
    "ébrènerais": ("ébrener",),
    "ébrènerait": ("ébrener",),
    "ébrèneras": ("ébrener",),
    "ébrenèrent": ("ébrener",),
    "ébrènerez": ("ébrener",),
    "ébrèneriez": ("ébrener",),
    "ébrènerions": ("ébrener",),
    "ébrènerons": ("ébrener",),
    "ébrèneront": ("ébrener",),
    "ébrenés": ("ébrener",),
    "ébrènes": ("ébrener",),
    "ébrenez": ("ébrener",),
    "ébreniez": ("ébrener",),
    "ébrenions": ("ébrener",),
    "ébrenons": ("ébrener",),
    "ébroudie": ("ébroudir",),
    "ébroudies": ("ébroudir",),
    "ébroudi": ("ébroudir",),
    "ébroudîmes": ("ébroudir",),
    "ébroudira": ("ébroudir",),
    "ébroudiraient": ("ébroudir",),
    "ébroudirai": ("ébroudir",),
    "ébroudirais": ("ébroudir",),
    "ébroudirait": ("ébroudir",),
    "ébroudiras": ("ébroudir",),
    "ébroudirent": ("ébroudir",),
    "ébroudirez": ("ébroudir",),
    "ébroudiriez": ("ébroudir",),
    "ébroudirions": ("ébroudir",),
    "ébroudirons": ("ébroudir",),
    "ébroudiront": ("ébroudir",),
    "ébroudis": ("ébroudir",),
    "ébroudissaient": ("ébroudir",),
    "ébroudissais": ("ébroudir",),
    "ébroudissait": ("ébroudir",),
    "ébroudissant": ("ébroudir",),
    "ébroudissent": ("ébroudir",),
    "ébroudisse": ("ébroudir",),
    "ébroudisses": ("ébroudir",),
    "ébroudissez": ("ébroudir",),
    "ébroudissiez": ("ébroudir",),
    "ébroudissions": ("ébroudir",),
    "ébroudissons": ("ébroudir",),
    "ébroudîtes": ("ébroudir",),
    "ébroudit": ("ébroudir",),
    "ébroudît": ("ébroudir",),
    "ébûchetaient": ("ébûcheter",),
    "ébûchetai": ("ébûcheter",),
    "ébûchetais": ("ébûcheter",),
    "ébûchetait": ("ébûcheter",),
    "ébûcheta": ("ébûcheter",),
    "ébûchetâmes": ("ébûcheter",),
    "ébûchetant": ("ébûcheter",),
    "ébûchetas": ("ébûcheter",),
    "ébûchetassent": ("ébûcheter",),
    "ébûchetasses": ("ébûcheter",),
    "ébûchetasse": ("ébûcheter",),
    "ébûchetassiez": ("ébûcheter",),
    "ébûchetassions": ("ébûcheter",),
    "ébûchetâtes": ("ébûcheter",),
    "ébûchetât": ("ébûcheter",),
    "ébûchetée": ("ébûcheter",),
    "ébûchetées": ("ébûcheter",),
    "ébûcheté": ("ébûcheter",),
    "ébûchetèrent": ("ébûcheter",),
    "ébûchetés": ("ébûcheter",),
    "ébûchetez": ("ébûcheter",),
    "ébûchetiez": ("ébûcheter",),
    "ébûchetions": ("ébûcheter",),
    "ébûchetons": ("ébûcheter",),
    "ébûchettent": ("ébûcheter",),
    "ébûchette": ("ébûcheter",),
    "ébûchettera": ("ébûcheter",),
    "ébûchetteraient": ("ébûcheter",),
    "ébûchetterai": ("ébûcheter",),
    "ébûchetterais": ("ébûcheter",),
    "ébûchetterait": ("ébûcheter",),
    "ébûchetteras": ("ébûcheter",),
    "ébûchetterez": ("ébûcheter",),
    "ébûchetteriez": ("ébûcheter",),
    "ébûchetterions": ("ébûcheter",),
    "ébûchetterons": ("ébûcheter",),
    "ébûchetteront": ("ébûcheter",),
    "ébûchettes": ("ébûcheter",),
    "écartelaient": ("écarteler",),
    "écartelai": ("écarteler",),
    "écartelais": ("écarteler",),
    "écartelait": ("écarteler",),
    "écartela": ("écarteler",),
    "écartelâmes": ("écarteler",),
    "écartelant": ("écarteler",),
    "écartelas": ("écarteler",),
    "écartelassent": ("écarteler",),
    "écartelasses": ("écarteler",),
    "écartelasse": ("écarteler",),
    "écartelassiez": ("écarteler",),
    "écartelassions": ("écarteler",),
    "écartelâtes": ("écarteler",),
    "écartelât": ("écarteler",),
    "écartelée": ("écarteler",),
    "écartelées": ("écarteler",),
    "écartelé": ("écarteler",),
    "écartèlent": ("écarteler",),
    "écartèle": ("écarteler",),
    "écartèlera": ("écarteler",),
    "écartèleraient": ("écarteler",),
    "écartèlerai": ("écarteler",),
    "écartèlerais": ("écarteler",),
    "écartèlerait": ("écarteler",),
    "écartèleras": ("écarteler",),
    "écartelèrent": ("écarteler",),
    "écartèlerez": ("écarteler",),
    "écartèleriez": ("écarteler",),
    "écartèlerions": ("écarteler",),
    "écartèlerons": ("écarteler",),
    "écartèleront": ("écarteler",),
    "écartelés": ("écarteler",),
    "écartèles": ("écarteler",),
    "écartelez": ("écarteler",),
    "écarteliez": ("écarteler",),
    "écartelions": ("écarteler",),
    "écartelons": ("écarteler",),
    "écatie": ("écatir",),
    "écaties": ("écatir",),
    "écati": ("écatir",),
    "écatîmes": ("écatir",),
    "écatira": ("écatir",),
    "écatiraient": ("écatir",),
    "écatirai": ("écatir",),
    "écatirais": ("écatir",),
    "écatirait": ("écatir",),
    "écatiras": ("écatir",),
    "écatirent": ("écatir",),
    "écatirez": ("écatir",),
    "écatiriez": ("écatir",),
    "écatirions": ("écatir",),
    "écatirons": ("écatir",),
    "écatiront": ("écatir",),
    "écatis": ("écatir",),
    "écatissaient": ("écatir",),
    "écatissais": ("écatir",),
    "écatissait": ("écatir",),
    "écatissant": ("écatir",),
    "écatissent": ("écatir",),
    "écatisse": ("écatir",),
    "écatisses": ("écatir",),
    "écatissez": ("écatir",),
    "écatissiez": ("écatir",),
    "écatissions": ("écatir",),
    "écatissons": ("écatir",),
    "écatîtes": ("écatir",),
    "écatit": ("écatir",),
    "écatît": ("écatir",),
    "écépaient": ("écéper",),
    "écépai": ("écéper",),
    "écépais": ("écéper",),
    "écépait": ("écéper",),
    "écépa": ("écéper",),
    "écépâmes": ("écéper",),
    "écépant": ("écéper",),
    "écépas": ("écéper",),
    "écépassent": ("écéper",),
    "écépasses": ("écéper",),
    "écépasse": ("écéper",),
    "écépassiez": ("écéper",),
    "écépassions": ("écéper",),
    "écépâtes": ("écéper",),
    "écépât": ("écéper",),
    "écépée": ("écéper",),
    "écépées": ("écéper",),
    "écépé": ("écéper",),
    "écèpent": ("écéper",),
    "écèpe": ("écéper",),
    "écépera": ("écéper",),
    "écéperaient": ("écéper",),
    "écéperai": ("écéper",),
    "écéperais": ("écéper",),
    "écéperait": ("écéper",),
    "écéperas": ("écéper",),
    "écépèrent": ("écéper",),
    "écéperez": ("écéper",),
    "écéperiez": ("écéper",),
    "écéperions": ("écéper",),
    "écéperons": ("écéper",),
    "écéperont": ("écéper",),
    "écépés": ("écéper",),
    "écèpes": ("écéper",),
    "écépez": ("écéper",),
    "écépiez": ("écéper",),
    "écépions": ("écéper",),
    "écépons": ("écéper",),
    "écervelaient": ("écerveler",),
    "écervelai": ("écerveler",),
    "écervelais": ("écerveler",),
    "écervelait": ("écerveler",),
    "écervela": ("écerveler",),
    "écervelâmes": ("écerveler",),
    "écervelant": ("écerveler",),
    "écervelas": ("écerveler",),
    "écervelassent": ("écerveler",),
    "écervelasses": ("écerveler",),
    "écervelasse": ("écerveler",),
    "écervelassiez": ("écerveler",),
    "écervelassions": ("écerveler",),
    "écervelâtes": ("écerveler",),
    "écervelât": ("écerveler",),
    "écervelée": ("écerveler",),
    "écervelées": ("écerveler",),
    "écervelé": ("écerveler",),
    "écervelèrent": ("écerveler",),
    "écervelés": ("écerveler",),
    "écervelez": ("écerveler",),
    "écerveliez": ("écerveler",),
    "écervelions": ("écerveler",),
    "écervellent": ("écerveler",),
    "écervelle": ("écerveler",),
    "écervellera": ("écerveler",),
    "écervelleraient": ("écerveler",),
    "écervellerai": ("écerveler",),
    "écervellerais": ("écerveler",),
    "écervellerait": ("écerveler",),
    "écervelleras": ("écerveler",),
    "écervellerez": ("écerveler",),
    "écervelleriez": ("écerveler",),
    "écervellerions": ("écerveler",),
    "écervellerons": ("écerveler",),
    "écervelleront": ("écerveler",),
    "écervelles": ("écerveler",),
    "écervelons": ("écerveler",),
    "échalassaient": ("échalasser",),
    "échalassai": ("échalasser",),
    "échalassais": ("échalasser",),
    "échalassait": ("échalasser",),
    "échalassa": ("échalasser",),
    "échalassâmes": ("échalasser",),
    "échalassant": ("échalasser",),
    "échalassas": ("échalasser",),
    "échalassassent": ("échalasser",),
    "échalassasses": ("échalasser",),
    "échalassasse": ("échalasser",),
    "échalassassiez": ("échalasser",),
    "échalassassions": ("échalasser",),
    "échalassâtes": ("échalasser",),
    "échalassât": ("échalasser",),
    "échalassée": ("échalasser",),
    "échalassées": ("échalasser",),
    "échalassé": ("échalasser",),
    "échalassent": ("échalasser",),
    "échalasse": ("échalasser",),
    "échalassera": ("échalasser",),
    "échalasseraient": ("échalasser",),
    "échalasserai": ("échalasser",),
    "échalasserais": ("échalasser",),
    "échalasserait": ("échalasser",),
    "échalasseras": ("échalasser",),
    "échalassèrent": ("échalasser",),
    "échalasserez": ("échalasser",),
    "échalasseriez": ("échalasser",),
    "échalasserions": ("échalasser",),
    "échalasserons": ("échalasser",),
    "échalasseront": ("échalasser",),
    "échalassés": ("échalasser",),
    "échalasses": ("échalasser",),
    "échalassez": ("échalasser",),
    "échalassiez": ("échalasser",),
    "échalassions": ("échalasser",),
    "échalassons": ("échalasser",),
    "échampie": ("échampir",),
    "échampies": ("échampir",),
    "échampi": ("échampir",),
    "échampîmes": ("échampir",),
    "échampira": ("échampir",),
    "échampiraient": ("échampir",),
    "échampirai": ("échampir",),
    "échampirais": ("échampir",),
    "échampirait": ("échampir",),
    "échampiras": ("échampir",),
    "échampirent": ("échampir",),
    "échampirez": ("échampir",),
    "échampiriez": ("échampir",),
    "échampirions": ("échampir",),
    "échampirons": ("échampir",),
    "échampiront": ("échampir",),
    "échampis": ("échampir",),
    "échampissaient": ("échampir",),
    "échampissais": ("échampir",),
    "échampissait": ("échampir",),
    "échampissant": ("échampir",),
    "échampissent": ("échampir",),
    "échampisse": ("échampir",),
    "échampisses": ("échampir",),
    "échampissez": ("échampir",),
    "échampissiez": ("échampir",),
    "échampissions": ("échampir",),
    "échampissons": ("échampir",),
    "échampîtes": ("échampir",),
    "échampit": ("échampir",),
    "échampît": ("échampir",),
    "échangeaient": ("échanger",),
    "échangeai": ("échanger",),
    "échangeais": ("échanger",),
    "échangeait": ("échanger",),
    "échangea": ("échanger",),
    "échangeâmes": ("échanger",),
    "échangeant": ("échanger",),
    "échangeas": ("échanger",),
    "échangeassent": ("échanger",),
    "échangeasses": ("échanger",),
    "échangeasse": ("échanger",),
    "échangeassiez": ("échanger",),
    "échangeassions": ("échanger",),
    "échangeâtes": ("échanger",),
    "échangeât": ("échanger",),
    "échangée": ("échanger",),
    "échangées": ("échanger",),
    "échangé": ("échanger",),
    "échangent": ("échanger",),
    "échangeons": ("échanger",),
    "échange": ("échanger",),
    "échangera": ("échanger",),
    "échangeraient": ("échanger",),
    "échangerai": ("échanger",),
    "échangerais": ("échanger",),
    "échangerait": ("échanger",),
    "échangeras": ("échanger",),
    "échangèrent": ("échanger",),
    "échangerez": ("échanger",),
    "échangeriez": ("échanger",),
    "échangerions": ("échanger",),
    "échangerons": ("échanger",),
    "échangeront": ("échanger",),
    "échangés": ("échanger",),
    "échanges": ("échanger",),
    "échangez": ("échanger",),
    "échangiez": ("échanger",),
    "échangions": ("échanger",),
    "échelaient": ("écheler",),
    "échelai": ("écheler",),
    "échelais": ("écheler",),
    "échelait": ("écheler",),
    "échela": ("écheler",),
    "échelâmes": ("écheler",),
    "échelant": ("écheler",),
    "échelas": ("écheler",),
    "échelassent": ("écheler",),
    "échelasses": ("écheler",),
    "échelasse": ("écheler",),
    "échelassiez": ("écheler",),
    "échelassions": ("écheler",),
    "échelâtes": ("écheler",),
    "échelât": ("écheler",),
    "échelée": ("écheler",),
    "échelées": ("écheler",),
    "échelé": ("écheler",),
    "échelèrent": ("écheler",),
    "échelés": ("écheler",),
    "échelez": ("écheler",),
    "écheliez": ("écheler",),
    "échelions": ("écheler",),
    "échellent": ("écheler",),
    "échelle": ("écheler",),
    "échellera": ("écheler",),
    "échelleraient": ("écheler",),
    "échellerai": ("écheler",),
    "échellerais": ("écheler",),
    "échellerait": ("écheler",),
    "échelleras": ("écheler",),
    "échellerez": ("écheler",),
    "échelleriez": ("écheler",),
    "échellerions": ("écheler",),
    "échellerons": ("écheler",),
    "échelleront": ("écheler",),
    "échelles": ("écheler",),
    "échelons": ("écheler",),
    "échaient": ("écher",),
    "échai": ("écher",),
    "échais": ("écher",),
    "échait": ("écher",),
    "écha": ("écher",),
    "échâmes": ("écher",),
    "échant": ("écher",),
    "échas": ("écher",),
    "échassent": ("écher",),
    "échasses": ("écher",),
    "échasse": ("écher",),
    "échassiez": ("écher",),
    "échassions": ("écher",),
    "échâtes": ("écher",),
    "échât": ("écher",),
    "échée": ("écher",),
    "échées": ("écher",),
    "éché": ("écher",),
    "èchent": ("écher",),
    "èche": ("écher",),
    "échera": ("écher",),
    "écheraient": ("écher",),
    "écherai": ("écher",),
    "écherais": ("écher",),
    "écherait": ("écher",),
    "écheras": ("écher",),
    "échèrent": ("écher",),
    "écherez": ("écher",),
    "écheriez": ("écher",),
    "écherions": ("écher",),
    "écherons": ("écher",),
    "écheront": ("écher",),
    "échés": ("écher",),
    "èches": ("écher",),
    "échez": ("écher",),
    "échiez": ("écher",),
    "échions": ("écher",),
    "échons": ("écher",),
    "échevelaient": ("écheveler",),
    "échevelai": ("écheveler",),
    "échevelais": ("écheveler",),
    "échevelait": ("écheveler",),
    "échevela": ("écheveler",),
    "échevelâmes": ("écheveler",),
    "échevelant": ("écheveler",),
    "échevelas": ("écheveler",),
    "échevelassent": ("écheveler",),
    "échevelasses": ("écheveler",),
    "échevelasse": ("écheveler",),
    "échevelassiez": ("écheveler",),
    "échevelassions": ("écheveler",),
    "échevelâtes": ("écheveler",),
    "échevelât": ("écheveler",),
    "échevelée": ("écheveler",),
    "échevelées": ("écheveler",),
    "échevelé": ("écheveler",),
    "échevelèrent": ("écheveler",),
    "échevelés": ("écheveler",),
    "échevelez": ("écheveler",),
    "écheveliez": ("écheveler",),
    "échevelions": ("écheveler",),
    "échevellent": ("écheveler",),
    "échevelle": ("écheveler",),
    "échevellera": ("écheveler",),
    "échevelleraient": ("écheveler",),
    "échevellerai": ("écheveler",),
    "échevellerais": ("écheveler",),
    "échevellerait": ("écheveler",),
    "échevelleras": ("écheveler",),
    "échevellerez": ("écheveler",),
    "échevelleriez": ("écheveler",),
    "échevellerions": ("écheveler",),
    "échevellerons": ("écheveler",),
    "échevelleront": ("écheveler",),
    "échevelles": ("écheveler",),
    "échevelons": ("écheveler",),
    "échographiaient": ("échographier",),
    "échographiai": ("échographier",),
    "échographiais": ("échographier",),
    "échographiait": ("échographier",),
    "échographia": ("échographier",),
    "échographiâmes": ("échographier",),
    "échographiant": ("échographier",),
    "échographias": ("échographier",),
    "échographiassent": ("échographier",),
    "échographiasses": ("échographier",),
    "échographiasse": ("échographier",),
    "échographiassiez": ("échographier",),
    "échographiassions": ("échographier",),
    "échographiâtes": ("échographier",),
    "échographiât": ("échographier",),
    "échographiée": ("échographier",),
    "échographiées": ("échographier",),
    "échographié": ("échographier",),
    "échographient": ("échographier",),
    "échographie": ("échographier",),
    "échographiera": ("échographier",),
    "échographieraient": ("échographier",),
    "échographierai": ("échographier",),
    "échographierais": ("échographier",),
    "échographierait": ("échographier",),
    "échographieras": ("échographier",),
    "échographièrent": ("échographier",),
    "échographierez": ("échographier",),
    "échographieriez": ("échographier",),
    "échographierions": ("échographier",),
    "échographierons": ("échographier",),
    "échographieront": ("échographier",),
    "échographiés": ("échographier",),
    "échographies": ("échographier",),
    "échographiez": ("échographier",),
    "échographiiez": ("échographier",),
    "échographiions": ("échographier",),
    "échographions": ("échographier",),
    "échéant": ("échoir",),
    "écherra": ("échoir",),
    "écherraient": ("échoir",),
    "écherrait": ("échoir",),
    "écherront": ("échoir",),
    "échoient": ("échoir",),
    "échoie": ("échoir",),
    "échoira": ("échoir",),
    "échoiraient": ("échoir",),
    "échoirait": ("échoir",),
    "échoiront": ("échoir",),
    "échoit": ("échoir",),
    "échoyaient": ("échoir",),
    "échoyait": ("échoir",),
    "échue": ("échoir",),
    "échues": ("échoir",),
    "échu": ("échoir",),
    "échurent": ("échoir",),
    "échus": ("échoir",),
    "échussent": ("échoir",),
    "échut": ("échoir",),
    "échût": ("échoir",),
    "éclaircie": ("éclaircir",),
    "éclaircies": ("éclaircir",),
    "éclairci": ("éclaircir",),
    "éclaircîmes": ("éclaircir",),
    "éclaircira": ("éclaircir",),
    "éclairciraient": ("éclaircir",),
    "éclaircirai": ("éclaircir",),
    "éclaircirais": ("éclaircir",),
    "éclaircirait": ("éclaircir",),
    "éclairciras": ("éclaircir",),
    "éclaircirent": ("éclaircir",),
    "éclaircirez": ("éclaircir",),
    "éclairciriez": ("éclaircir",),
    "éclaircirions": ("éclaircir",),
    "éclaircirons": ("éclaircir",),
    "éclairciront": ("éclaircir",),
    "éclaircis": ("éclaircir",),
    "éclaircissaient": ("éclaircir",),
    "éclaircissais": ("éclaircir",),
    "éclaircissait": ("éclaircir",),
    "éclaircissant": ("éclaircir",),
    "éclaircissent": ("éclaircir",),
    "éclaircisse": ("éclaircir",),
    "éclaircisses": ("éclaircir",),
    "éclaircissez": ("éclaircir",),
    "éclaircissiez": ("éclaircir",),
    "éclaircissions": ("éclaircir",),
    "éclaircissons": ("éclaircir",),
    "éclaircîtes": ("éclaircir",),
    "éclaircit": ("éclaircir",),
    "éclaircît": ("éclaircir",),
    "éclora": ("éclore",),
    "écloraient": ("éclore",),
    "éclorai": ("éclore",),
    "éclorais": ("éclore",),
    "éclorait": ("éclore",),
    "écloras": ("éclore",),
    "éclorez": ("éclore",),
    "écloriez": ("éclore",),
    "éclorions": ("éclore",),
    "éclorons": ("éclore",),
    "écloront": ("éclore",),
    "éclosaient": ("éclore",),
    "éclosais": ("éclore",),
    "éclosait": ("éclore",),
    "éclosant": ("éclore",),
    "éclose": ("éclore",),
    "éclosent": ("éclore",),
    "écloses": ("éclore",),
    "éclosez": ("éclore",),
    "éclosiez": ("éclore",),
    "éclosions": ("éclore",),
    "éclos": ("éclore",),
    "éclosons": ("éclore",),
    "éclot": ("éclore",),
    "éclôt": ("éclore",),
    "écolletaient": ("écolleter",),
    "écolletai": ("écolleter",),
    "écolletais": ("écolleter",),
    "écolletait": ("écolleter",),
    "écolleta": ("écolleter",),
    "écolletâmes": ("écolleter",),
    "écolletant": ("écolleter",),
    "écolletas": ("écolleter",),
    "écolletassent": ("écolleter",),
    "écolletasses": ("écolleter",),
    "écolletasse": ("écolleter",),
    "écolletassiez": ("écolleter",),
    "écolletassions": ("écolleter",),
    "écolletâtes": ("écolleter",),
    "écolletât": ("écolleter",),
    "écolletée": ("écolleter",),
    "écolletées": ("écolleter",),
    "écolleté": ("écolleter",),
    "écolletèrent": ("écolleter",),
    "écolletés": ("écolleter",),
    "écolletez": ("écolleter",),
    "écolletiez": ("écolleter",),
    "écolletions": ("écolleter",),
    "écolletons": ("écolleter",),
    "écollettent": ("écolleter",),
    "écollette": ("écolleter",),
    "écollettera": ("écolleter",),
    "écolletteraient": ("écolleter",),
    "écolletterai": ("écolleter",),
    "écolletterais": ("écolleter",),
    "écolletterait": ("écolleter",),
    "écolletteras": ("écolleter",),
    "écolletterez": ("écolleter",),
    "écolletteriez": ("écolleter",),
    "écolletterions": ("écolleter",),
    "écolletterons": ("écolleter",),
    "écolletteront": ("écolleter",),
    "écollettes": ("écolleter",),
    "éconduira": ("éconduire",),
    "éconduiraient": ("éconduire",),
    "éconduirai": ("éconduire",),
    "éconduirais": ("éconduire",),
    "éconduirait": ("éconduire",),
    "éconduiras": ("éconduire",),
    "éconduirez": ("éconduire",),
    "éconduiriez": ("éconduire",),
    "éconduirions": ("éconduire",),
    "éconduirons": ("éconduire",),
    "éconduiront": ("éconduire",),
    "éconduisaient": ("éconduire",),
    "éconduisais": ("éconduire",),
    "éconduisait": ("éconduire",),
    "éconduisant": ("éconduire",),
    "éconduisent": ("éconduire",),
    "éconduise": ("éconduire",),
    "éconduises": ("éconduire",),
    "éconduisez": ("éconduire",),
    "éconduisiez": ("éconduire",),
    "éconduisîmes": ("éconduire",),
    "éconduisions": ("éconduire",),
    "éconduisirent": ("éconduire",),
    "éconduisis": ("éconduire",),
    "éconduisissent": ("éconduire",),
    "éconduisisses": ("éconduire",),
    "éconduisisse": ("éconduire",),
    "éconduisissiez": ("éconduire",),
    "éconduisissions": ("éconduire",),
    "éconduisîtes": ("éconduire",),
    "éconduisit": ("éconduire",),
    "éconduisît": ("éconduire",),
    "éconduisons": ("éconduire",),
    "éconduis": ("éconduire",),
    "éconduite": ("éconduire",),
    "éconduites": ("éconduire",),
    "éconduit": ("éconduire",),
    "éconduits": ("éconduire",),
    "écoquetaient": ("écoqueter",),
    "écoquetai": ("écoqueter",),
    "écoquetais": ("écoqueter",),
    "écoquetait": ("écoqueter",),
    "écoqueta": ("écoqueter",),
    "écoquetâmes": ("écoqueter",),
    "écoquetant": ("écoqueter",),
    "écoquetas": ("écoqueter",),
    "écoquetassent": ("écoqueter",),
    "écoquetasses": ("écoqueter",),
    "écoquetasse": ("écoqueter",),
    "écoquetassiez": ("écoqueter",),
    "écoquetassions": ("écoqueter",),
    "écoquetâtes": ("écoqueter",),
    "écoquetât": ("écoqueter",),
    "écoquetée": ("écoqueter",),
    "écoquetées": ("écoqueter",),
    "écoqueté": ("écoqueter",),
    "écoquetèrent": ("écoqueter",),
    "écoquetés": ("écoqueter",),
    "écoquetez": ("écoqueter",),
    "écoquetiez": ("écoqueter",),
    "écoquetions": ("écoqueter",),
    "écoquetons": ("écoqueter",),
    "écoquettent": ("écoqueter",),
    "écoquette": ("écoqueter",),
    "écoquettera": ("écoqueter",),
    "écoquetteraient": ("écoqueter",),
    "écoquetterai": ("écoqueter",),
    "écoquetterais": ("écoqueter",),
    "écoquetterait": ("écoqueter",),
    "écoquetteras": ("écoqueter",),
    "écoquetterez": ("écoqueter",),
    "écoquetteriez": ("écoqueter",),
    "écoquetterions": ("écoqueter",),
    "écoquetterons": ("écoqueter",),
    "écoquetteront": ("écoqueter",),
    "écoquettes": ("écoqueter",),
    "écorçaient": ("écorcer",),
    "écorçai": ("écorcer",),
    "écorçais": ("écorcer",),
    "écorçait": ("écorcer",),
    "écorça": ("écorcer",),
    "écorçâmes": ("écorcer",),
    "écorçant": ("écorcer",),
    "écorças": ("écorcer",),
    "écorçassent": ("écorcer",),
    "écorçasses": ("écorcer",),
    "écorçasse": ("écorcer",),
    "écorçassiez": ("écorcer",),
    "écorçassions": ("écorcer",),
    "écorçâtes": ("écorcer",),
    "écorçât": ("écorcer",),
    "écorcée": ("écorcer",),
    "écorcées": ("écorcer",),
    "écorcé": ("écorcer",),
    "écorcent": ("écorcer",),
    "écorce": ("écorcer",),
    "écorcera": ("écorcer",),
    "écorceraient": ("écorcer",),
    "écorcerai": ("écorcer",),
    "écorcerais": ("écorcer",),
    "écorcerait": ("écorcer",),
    "écorceras": ("écorcer",),
    "écorcèrent": ("écorcer",),
    "écorcerez": ("écorcer",),
    "écorceriez": ("écorcer",),
    "écorcerions": ("écorcer",),
    "écorcerons": ("écorcer",),
    "écorceront": ("écorcer",),
    "écorcés": ("écorcer",),
    "écorces": ("écorcer",),
    "écorcez": ("écorcer",),
    "écorciez": ("écorcer",),
    "écorcions": ("écorcer",),
    "écorçons": ("écorcer",),
    "écrémaient": ("écrémer",),
    "écrémai": ("écrémer",),
    "écrémais": ("écrémer",),
    "écrémait": ("écrémer",),
    "écréma": ("écrémer",),
    "écrémâmes": ("écrémer",),
    "écrémant": ("écrémer",),
    "écrémas": ("écrémer",),
    "écrémassent": ("écrémer",),
    "écrémasses": ("écrémer",),
    "écrémasse": ("écrémer",),
    "écrémassiez": ("écrémer",),
    "écrémassions": ("écrémer",),
    "écrémâtes": ("écrémer",),
    "écrémât": ("écrémer",),
    "écrémée": ("écrémer",),
    "écrémées": ("écrémer",),
    "écrémé": ("écrémer",),
    "écrèment": ("écrémer",),
    "écrème": ("écrémer",),
    "écrémera": ("écrémer",),
    "écrémeraient": ("écrémer",),
    "écrémerai": ("écrémer",),
    "écrémerais": ("écrémer",),
    "écrémerait": ("écrémer",),
    "écrémeras": ("écrémer",),
    "écrémèrent": ("écrémer",),
    "écrémerez": ("écrémer",),
    "écrémeriez": ("écrémer",),
    "écrémerions": ("écrémer",),
    "écrémerons": ("écrémer",),
    "écrémeront": ("écrémer",),
    "écrémés": ("écrémer",),
    "écrèmes": ("écrémer",),
    "écrémez": ("écrémer",),
    "écrémiez": ("écrémer",),
    "écrémions": ("écrémer",),
    "écrémons": ("écrémer",),
    "écriaient": ("écrier",),
    "écriai": ("écrier",),
    "écriais": ("écrier",),
    "écriait": ("écrier",),
    "écria": ("écrier",),
    "écriâmes": ("écrier",),
    "écriant": ("écrier",),
    "écrias": ("écrier",),
    "écriassent": ("écrier",),
    "écriasses": ("écrier",),
    "écriasse": ("écrier",),
    "écriassiez": ("écrier",),
    "écriassions": ("écrier",),
    "écriâtes": ("écrier",),
    "écriât": ("écrier",),
    "écriée": ("écrier",),
    "écriées": ("écrier",),
    "écrié": ("écrier",),
    "écrient": ("écrier",),
    "écrie": ("écrier",),
    "écriera": ("écrier",),
    "écrieraient": ("écrier",),
    "écrierai": ("écrier",),
    "écrierais": ("écrier",),
    "écrierait": ("écrier",),
    "écrieras": ("écrier",),
    "écrièrent": ("écrier",),
    "écrierez": ("écrier",),
    "écrieriez": ("écrier",),
    "écrierions": ("écrier",),
    "écrierons": ("écrier",),
    "écrieront": ("écrier",),
    "écriés": ("écrier",),
    "écries": ("écrier",),
    "écriez": ("écrier",),
    "écriiez": ("écrier",),
    "écriions": ("écrier",),
    "écrions": ("écrier",),
    "écrira": ("écrire",),
    "écriraient": ("écrire",),
    "écrirai": ("écrire",),
    "écrirais": ("écrire",),
    "écrirait": ("écrire",),
    "écriras": ("écrire",),
    "écrirez": ("écrire",),
    "écririez": ("écrire",),
    "écririons": ("écrire",),
    "écrirons": ("écrire",),
    "écriront": ("écrire",),
    "écris": ("écrire",),
    "écrite": ("écrire",),
    "écrites": ("écrire",),
    "écrit": ("écrire",),
    "écrits": ("écrire",),
    "écrivaient": ("écrire",),
    "écrivais": ("écrire",),
    "écrivait": ("écrire",),
    "écrivant": ("écrire",),
    "écrivent": ("écrire",),
    "écrive": ("écrire",),
    "écrives": ("écrire",),
    "écrivez": ("écrire",),
    "écriviez": ("écrire",),
    "écrivîmes": ("écrire",),
    "écrivions": ("écrire",),
    "écrivirent": ("écrire",),
    "écrivis": ("écrire",),
    "écrivissent": ("écrire",),
    "écrivisses": ("écrire",),
    "écrivisse": ("écrire",),
    "écrivissiez": ("écrire",),
    "écrivissions": ("écrire",),
    "écrivîtes": ("écrire",),
    "écrivit": ("écrire",),
    "écrivît": ("écrire",),
    "écrivons": ("écrire",),
    "écrivassaient": ("écrivasser",),
    "écrivassai": ("écrivasser",),
    "écrivassais": ("écrivasser",),
    "écrivassait": ("écrivasser",),
    "écrivassa": ("écrivasser",),
    "écrivassâmes": ("écrivasser",),
    "écrivassant": ("écrivasser",),
    "écrivassas": ("écrivasser",),
    "écrivassassent": ("écrivasser",),
    "écrivassasses": ("écrivasser",),
    "écrivassasse": ("écrivasser",),
    "écrivassassiez": ("écrivasser",),
    "écrivassassions": ("écrivasser",),
    "écrivassâtes": ("écrivasser",),
    "écrivassât": ("écrivasser",),
    "écrivassée": ("écrivasser",),
    "écrivassées": ("écrivasser",),
    "écrivassé": ("écrivasser",),
    "écrivassent": ("écrivasser",),
    "écrivasse": ("écrivasser",),
    "écrivassera": ("écrivasser",),
    "écrivasseraient": ("écrivasser",),
    "écrivasserai": ("écrivasser",),
    "écrivasserais": ("écrivasser",),
    "écrivasserait": ("écrivasser",),
    "écrivasseras": ("écrivasser",),
    "écrivassèrent": ("écrivasser",),
    "écrivasserez": ("écrivasser",),
    "écrivasseriez": ("écrivasser",),
    "écrivasserions": ("écrivasser",),
    "écrivasserons": ("écrivasser",),
    "écrivasseront": ("écrivasser",),
    "écrivassés": ("écrivasser",),
    "écrivasses": ("écrivasser",),
    "écrivassez": ("écrivasser",),
    "écrivassiez": ("écrivasser",),
    "écrivassions": ("écrivasser",),
    "écrivassons": ("écrivasser",),
    "écrouie": ("écrouir",),
    "écrouies": ("écrouir",),
    "écroui": ("écrouir",),
    "écrouîmes": ("écrouir",),
    "écrouira": ("écrouir",),
    "écrouiraient": ("écrouir",),
    "écrouirai": ("écrouir",),
    "écrouirais": ("écrouir",),
    "écrouirait": ("écrouir",),
    "écrouiras": ("écrouir",),
    "écrouirent": ("écrouir",),
    "écrouirez": ("écrouir",),
    "écrouiriez": ("écrouir",),
    "écrouirions": ("écrouir",),
    "écrouirons": ("écrouir",),
    "écrouiront": ("écrouir",),
    "écrouis": ("écrouir",),
    "écrouissaient": ("écrouir",),
    "écrouissais": ("écrouir",),
    "écrouissait": ("écrouir",),
    "écrouissant": ("écrouir",),
    "écrouissent": ("écrouir",),
    "écrouisse": ("écrouir",),
    "écrouisses": ("écrouir",),
    "écrouissez": ("écrouir",),
    "écrouissiez": ("écrouir",),
    "écrouissions": ("écrouir",),
    "écrouissons": ("écrouir",),
    "écrouîtes": ("écrouir",),
    "écrouit": ("écrouir",),
    "écrouît": ("écrouir",),
    "ectasiaient": ("ectasier",),
    "ectasiai": ("ectasier",),
    "ectasiais": ("ectasier",),
    "ectasiait": ("ectasier",),
    "ectasia": ("ectasier",),
    "ectasiâmes": ("ectasier",),
    "ectasiant": ("ectasier",),
    "ectasias": ("ectasier",),
    "ectasiassent": ("ectasier",),
    "ectasiasses": ("ectasier",),
    "ectasiasse": ("ectasier",),
    "ectasiassiez": ("ectasier",),
    "ectasiassions": ("ectasier",),
    "ectasiâtes": ("ectasier",),
    "ectasiât": ("ectasier",),
    "ectasiée": ("ectasier",),
    "ectasiées": ("ectasier",),
    "ectasié": ("ectasier",),
    "ectasient": ("ectasier",),
    "ectasie": ("ectasier",),
    "ectasiera": ("ectasier",),
    "ectasieraient": ("ectasier",),
    "ectasierai": ("ectasier",),
    "ectasierais": ("ectasier",),
    "ectasierait": ("ectasier",),
    "ectasieras": ("ectasier",),
    "ectasièrent": ("ectasier",),
    "ectasierez": ("ectasier",),
    "ectasieriez": ("ectasier",),
    "ectasierions": ("ectasier",),
    "ectasierons": ("ectasier",),
    "ectasieront": ("ectasier",),
    "ectasiés": ("ectasier",),
    "ectasies": ("ectasier",),
    "ectasiez": ("ectasier",),
    "ectasiiez": ("ectasier",),
    "ectasiions": ("ectasier",),
    "ectasions": ("ectasier",),
    "édifiaient": ("édifier",),
    "édifiai": ("édifier",),
    "édifiais": ("édifier",),
    "édifiait": ("édifier",),
    "édifia": ("édifier",),
    "édifiâmes": ("édifier",),
    "édifiant": ("édifier",),
    "édifias": ("édifier",),
    "édifiassent": ("édifier",),
    "édifiasses": ("édifier",),
    "édifiasse": ("édifier",),
    "édifiassiez": ("édifier",),
    "édifiassions": ("édifier",),
    "édifiâtes": ("édifier",),
    "édifiât": ("édifier",),
    "édifiée": ("édifier",),
    "édifiées": ("édifier",),
    "édifié": ("édifier",),
    "édifient": ("édifier",),
    "édifie": ("édifier",),
    "édifiera": ("édifier",),
    "édifieraient": ("édifier",),
    "édifierai": ("édifier",),
    "édifierais": ("édifier",),
    "édifierait": ("édifier",),
    "édifieras": ("édifier",),
    "édifièrent": ("édifier",),
    "édifierez": ("édifier",),
    "édifieriez": ("édifier",),
    "édifierions": ("édifier",),
    "édifierons": ("édifier",),
    "édifieront": ("édifier",),
    "édifiés": ("édifier",),
    "édifies": ("édifier",),
    "édifiez": ("édifier",),
    "édifiiez": ("édifier",),
    "édifiions": ("édifier",),
    "édifions": ("édifier",),
    "effaçaient": ("effacer",),
    "effaçai": ("effacer",),
    "effaçais": ("effacer",),
    "effaçait": ("effacer",),
    "effaça": ("effacer",),
    "effaçâmes": ("effacer",),
    "effaçant": ("effacer",),
    "effaças": ("effacer",),
    "effaçassent": ("effacer",),
    "effaçasses": ("effacer",),
    "effaçasse": ("effacer",),
    "effaçassiez": ("effacer",),
    "effaçassions": ("effacer",),
    "effaçâtes": ("effacer",),
    "effaçât": ("effacer",),
    "effacée": ("effacer",),
    "effacées": ("effacer",),
    "effacé": ("effacer",),
    "effacent": ("effacer",),
    "efface": ("effacer",),
    "effacera": ("effacer",),
    "effaceraient": ("effacer",),
    "effacerai": ("effacer",),
    "effacerais": ("effacer",),
    "effacerait": ("effacer",),
    "effaceras": ("effacer",),
    "effacèrent": ("effacer",),
    "effacerez": ("effacer",),
    "effaceriez": ("effacer",),
    "effacerions": ("effacer",),
    "effacerons": ("effacer",),
    "effaceront": ("effacer",),
    "effacés": ("effacer",),
    "effaces": ("effacer",),
    "effacez": ("effacer",),
    "effaciez": ("effacer",),
    "effacions": ("effacer",),
    "effaçons": ("effacer",),
    "effigiaient": ("effigier",),
    "effigiai": ("effigier",),
    "effigiais": ("effigier",),
    "effigiait": ("effigier",),
    "effigia": ("effigier",),
    "effigiâmes": ("effigier",),
    "effigiant": ("effigier",),
    "effigias": ("effigier",),
    "effigiassent": ("effigier",),
    "effigiasses": ("effigier",),
    "effigiasse": ("effigier",),
    "effigiassiez": ("effigier",),
    "effigiassions": ("effigier",),
    "effigiâtes": ("effigier",),
    "effigiât": ("effigier",),
    "effigiée": ("effigier",),
    "effigiées": ("effigier",),
    "effigié": ("effigier",),
    "effigient": ("effigier",),
    "effigie": ("effigier",),
    "effigiera": ("effigier",),
    "effigieraient": ("effigier",),
    "effigierai": ("effigier",),
    "effigierais": ("effigier",),
    "effigierait": ("effigier",),
    "effigieras": ("effigier",),
    "effigièrent": ("effigier",),
    "effigierez": ("effigier",),
    "effigieriez": ("effigier",),
    "effigierions": ("effigier",),
    "effigierons": ("effigier",),
    "effigieront": ("effigier",),
    "effigiés": ("effigier",),
    "effigies": ("effigier",),
    "effigiez": ("effigier",),
    "effigiiez": ("effigier",),
    "effigiions": ("effigier",),
    "effigions": ("effigier",),
    "effleurie": ("effleurir",),
    "effleuries": ("effleurir",),
    "effleuri": ("effleurir",),
    "effleurîmes": ("effleurir",),
    "effleurira": ("effleurir",),
    "effleuriraient": ("effleurir",),
    "effleurirai": ("effleurir",),
    "effleurirais": ("effleurir",),
    "effleurirait": ("effleurir",),
    "effleuriras": ("effleurir",),
    "effleurirent": ("effleurir",),
    "effleurirez": ("effleurir",),
    "effleuririez": ("effleurir",),
    "effleuririons": ("effleurir",),
    "effleurirons": ("effleurir",),
    "effleuriront": ("effleurir",),
    "effleuris": ("effleurir",),
    "effleurissaient": ("effleurir",),
    "effleurissais": ("effleurir",),
    "effleurissait": ("effleurir",),
    "effleurissant": ("effleurir",),
    "effleurissent": ("effleurir",),
    "effleurisse": ("effleurir",),
    "effleurisses": ("effleurir",),
    "effleurissez": ("effleurir",),
    "effleurissiez": ("effleurir",),
    "effleurissions": ("effleurir",),
    "effleurissons": ("effleurir",),
    "effleurîtes": ("effleurir",),
    "effleurit": ("effleurir",),
    "effleurît": ("effleurir",),
    "efforçaient": ("efforcer",),
    "efforçai": ("efforcer",),
    "efforçais": ("efforcer",),
    "efforçait": ("efforcer",),
    "efforça": ("efforcer",),
    "efforçâmes": ("efforcer",),
    "efforçant": ("efforcer",),
    "efforças": ("efforcer",),
    "efforçassent": ("efforcer",),
    "efforçasses": ("efforcer",),
    "efforçasse": ("efforcer",),
    "efforçassiez": ("efforcer",),
    "efforçassions": ("efforcer",),
    "efforçâtes": ("efforcer",),
    "efforçât": ("efforcer",),
    "efforcée": ("efforcer",),
    "efforcées": ("efforcer",),
    "efforcé": ("efforcer",),
    "efforcent": ("efforcer",),
    "efforce": ("efforcer",),
    "efforcera": ("efforcer",),
    "efforceraient": ("efforcer",),
    "efforcerai": ("efforcer",),
    "efforcerais": ("efforcer",),
    "efforcerait": ("efforcer",),
    "efforceras": ("efforcer",),
    "efforcèrent": ("efforcer",),
    "efforcerez": ("efforcer",),
    "efforceriez": ("efforcer",),
    "efforcerions": ("efforcer",),
    "efforcerons": ("efforcer",),
    "efforceront": ("efforcer",),
    "efforcés": ("efforcer",),
    "efforces": ("efforcer",),
    "efforcez": ("efforcer",),
    "efforciez": ("efforcer",),
    "efforcions": ("efforcer",),
    "efforçons": ("efforcer",),
    "effrangeaient": ("effranger",),
    "effrangeai": ("effranger",),
    "effrangeais": ("effranger",),
    "effrangeait": ("effranger",),
    "effrangea": ("effranger",),
    "effrangeâmes": ("effranger",),
    "effrangeant": ("effranger",),
    "effrangeas": ("effranger",),
    "effrangeassent": ("effranger",),
    "effrangeasses": ("effranger",),
    "effrangeasse": ("effranger",),
    "effrangeassiez": ("effranger",),
    "effrangeassions": ("effranger",),
    "effrangeâtes": ("effranger",),
    "effrangeât": ("effranger",),
    "effrangée": ("effranger",),
    "effrangées": ("effranger",),
    "effrangé": ("effranger",),
    "effrangent": ("effranger",),
    "effrangeons": ("effranger",),
    "effrange": ("effranger",),
    "effrangera": ("effranger",),
    "effrangeraient": ("effranger",),
    "effrangerai": ("effranger",),
    "effrangerais": ("effranger",),
    "effrangerait": ("effranger",),
    "effrangeras": ("effranger",),
    "effrangèrent": ("effranger",),
    "effrangerez": ("effranger",),
    "effrangeriez": ("effranger",),
    "effrangerions": ("effranger",),
    "effrangerons": ("effranger",),
    "effrangeront": ("effranger",),
    "effrangés": ("effranger",),
    "effranges": ("effranger",),
    "effrangez": ("effranger",),
    "effrangiez": ("effranger",),
    "effrangions": ("effranger",),
    "effraient": ("effrayer",),
    "effraie": ("effrayer",),
    "effraiera": ("effrayer",),
    "effraieraient": ("effrayer",),
    "effraierai": ("effrayer",),
    "effraierais": ("effrayer",),
    "effraierait": ("effrayer",),
    "effraieras": ("effrayer",),
    "effraierez": ("effrayer",),
    "effraieriez": ("effrayer",),
    "effraierions": ("effrayer",),
    "effraierons": ("effrayer",),
    "effraieront": ("effrayer",),
    "effraies": ("effrayer",),
    "effrayaient": ("effrayer",),
    "effrayai": ("effrayer",),
    "effrayais": ("effrayer",),
    "effrayait": ("effrayer",),
    "effraya": ("effrayer",),
    "effrayâmes": ("effrayer",),
    "effrayant": ("effrayer",),
    "effrayas": ("effrayer",),
    "effrayassent": ("effrayer",),
    "effrayasses": ("effrayer",),
    "effrayasse": ("effrayer",),
    "effrayassiez": ("effrayer",),
    "effrayassions": ("effrayer",),
    "effrayâtes": ("effrayer",),
    "effrayât": ("effrayer",),
    "effrayée": ("effrayer",),
    "effrayées": ("effrayer",),
    "effrayé": ("effrayer",),
    "effrayent": ("effrayer",),
    "effraye": ("effrayer",),
    "effrayera": ("effrayer",),
    "effrayeraient": ("effrayer",),
    "effrayerai": ("effrayer",),
    "effrayerais": ("effrayer",),
    "effrayerait": ("effrayer",),
    "effrayeras": ("effrayer",),
    "effrayèrent": ("effrayer",),
    "effrayerez": ("effrayer",),
    "effrayeriez": ("effrayer",),
    "effrayerions": ("effrayer",),
    "effrayerons": ("effrayer",),
    "effrayeront": ("effrayer",),
    "effrayés": ("effrayer",),
    "effrayes": ("effrayer",),
    "effrayez": ("effrayer",),
    "effrayiez": ("effrayer",),
    "effrayions": ("effrayer",),
    "effrayons": ("effrayer",),
    "effulgeaient": ("effulger",),
    "effulgeai": ("effulger",),
    "effulgeais": ("effulger",),
    "effulgeait": ("effulger",),
    "effulgea": ("effulger",),
    "effulgeâmes": ("effulger",),
    "effulgeant": ("effulger",),
    "effulgeas": ("effulger",),
    "effulgeassent": ("effulger",),
    "effulgeasses": ("effulger",),
    "effulgeasse": ("effulger",),
    "effulgeassiez": ("effulger",),
    "effulgeassions": ("effulger",),
    "effulgeâtes": ("effulger",),
    "effulgeât": ("effulger",),
    "effulgée": ("effulger",),
    "effulgées": ("effulger",),
    "effulgé": ("effulger",),
    "effulgent": ("effulger",),
    "effulgeons": ("effulger",),
    "effulge": ("effulger",),
    "effulgera": ("effulger",),
    "effulgeraient": ("effulger",),
    "effulgerai": ("effulger",),
    "effulgerais": ("effulger",),
    "effulgerait": ("effulger",),
    "effulgeras": ("effulger",),
    "effulgèrent": ("effulger",),
    "effulgerez": ("effulger",),
    "effulgeriez": ("effulger",),
    "effulgerions": ("effulger",),
    "effulgerons": ("effulger",),
    "effulgeront": ("effulger",),
    "effulgés": ("effulger",),
    "effulges": ("effulger",),
    "effulgez": ("effulger",),
    "effulgiez": ("effulger",),
    "effulgions": ("effulger",),
    "égalie": ("égalir",),
    "égalies": ("égalir",),
    "égali": ("égalir",),
    "égalîmes": ("égalir",),
    "égalira": ("égalir",),
    "égaliraient": ("égalir",),
    "égalirai": ("égalir",),
    "égalirais": ("égalir",),
    "égalirait": ("égalir",),
    "égaliras": ("égalir",),
    "égalirent": ("égalir",),
    "égalirez": ("égalir",),
    "égaliriez": ("égalir",),
    "égalirions": ("égalir",),
    "égalirons": ("égalir",),
    "égaliront": ("égalir",),
    "égalis": ("égalir",),
    "égalissaient": ("égalir",),
    "égalissais": ("égalir",),
    "égalissait": ("égalir",),
    "égalissant": ("égalir",),
    "égalissent": ("égalir",),
    "égalisse": ("égalir",),
    "égalisses": ("égalir",),
    "égalissez": ("égalir",),
    "égalissiez": ("égalir",),
    "égalissions": ("égalir",),
    "égalissons": ("égalir",),
    "égalîtes": ("égalir",),
    "égalit": ("égalir",),
    "égalît": ("égalir",),
    "égaient": ("égayer",),
    "égaie": ("égayer",),
    "égaiera": ("égayer",),
    "égaieraient": ("égayer",),
    "égaierai": ("égayer",),
    "égaierais": ("égayer",),
    "égaierait": ("égayer",),
    "égaieras": ("égayer",),
    "égaierez": ("égayer",),
    "égaieriez": ("égayer",),
    "égaierions": ("égayer",),
    "égaierons": ("égayer",),
    "égaieront": ("égayer",),
    "égaies": ("égayer",),
    "égayaient": ("égayer",),
    "égayai": ("égayer",),
    "égayais": ("égayer",),
    "égayait": ("égayer",),
    "égaya": ("égayer",),
    "égayâmes": ("égayer",),
    "égayant": ("égayer",),
    "égayas": ("égayer",),
    "égayassent": ("égayer",),
    "égayasses": ("égayer",),
    "égayasse": ("égayer",),
    "égayassiez": ("égayer",),
    "égayassions": ("égayer",),
    "égayâtes": ("égayer",),
    "égayât": ("égayer",),
    "égayée": ("égayer",),
    "égayées": ("égayer",),
    "égayé": ("égayer",),
    "égayent": ("égayer",),
    "égaye": ("égayer",),
    "égayera": ("égayer",),
    "égayeraient": ("égayer",),
    "égayerai": ("égayer",),
    "égayerais": ("égayer",),
    "égayerait": ("égayer",),
    "égayeras": ("égayer",),
    "égayèrent": ("égayer",),
    "égayerez": ("égayer",),
    "égayeriez": ("égayer",),
    "égayerions": ("égayer",),
    "égayerons": ("égayer",),
    "égayeront": ("égayer",),
    "égayés": ("égayer",),
    "égayes": ("égayer",),
    "égayez": ("égayer",),
    "égayiez": ("égayer",),
    "égayions": ("égayer",),
    "égayons": ("égayer",),
    "égorgeaient": ("égorger",),
    "égorgeai": ("égorger",),
    "égorgeais": ("égorger",),
    "égorgeait": ("égorger",),
    "égorgea": ("égorger",),
    "égorgeâmes": ("égorger",),
    "égorgeant": ("égorger",),
    "égorgeas": ("égorger",),
    "égorgeassent": ("égorger",),
    "égorgeasses": ("égorger",),
    "égorgeasse": ("égorger",),
    "égorgeassiez": ("égorger",),
    "égorgeassions": ("égorger",),
    "égorgeâtes": ("égorger",),
    "égorgeât": ("égorger",),
    "égorgée": ("égorger",),
    "égorgées": ("égorger",),
    "égorgé": ("égorger",),
    "égorgent": ("égorger",),
    "égorgeons": ("égorger",),
    "égorge": ("égorger",),
    "égorgera": ("égorger",),
    "égorgeraient": ("égorger",),
    "égorgerai": ("égorger",),
    "égorgerais": ("égorger",),
    "égorgerait": ("égorger",),
    "égorgeras": ("égorger",),
    "égorgèrent": ("égorger",),
    "égorgerez": ("égorger",),
    "égorgeriez": ("égorger",),
    "égorgerions": ("égorger",),
    "égorgerons": ("égorger",),
    "égorgeront": ("égorger",),
    "égorgés": ("égorger",),
    "égorges": ("égorger",),
    "égorgez": ("égorger",),
    "égorgiez": ("égorger",),
    "égorgions": ("égorger",),
    "égrenaient": ("égrener",),
    "égrenai": ("égrener",),
    "égrenais": ("égrener",),
    "égrenait": ("égrener",),
    "égrena": ("égrener",),
    "égrenâmes": ("égrener",),
    "égrenant": ("égrener",),
    "égrenas": ("égrener",),
    "égrenassent": ("égrener",),
    "égrenasses": ("égrener",),
    "égrenasse": ("égrener",),
    "égrenassiez": ("égrener",),
    "égrenassions": ("égrener",),
    "égrenâtes": ("égrener",),
    "égrenât": ("égrener",),
    "égrenée": ("égrener",),
    "égrenées": ("égrener",),
    "égrené": ("égrener",),
    "égrènent": ("égrener",),
    "égrène": ("égrener",),
    "égrènera": ("égrener",),
    "égrèneraient": ("égrener",),
    "égrènerai": ("égrener",),
    "égrènerais": ("égrener",),
    "égrènerait": ("égrener",),
    "égrèneras": ("égrener",),
    "égrenèrent": ("égrener",),
    "égrènerez": ("égrener",),
    "égrèneriez": ("égrener",),
    "égrènerions": ("égrener",),
    "égrènerons": ("égrener",),
    "égrèneront": ("égrener",),
    "égrenés": ("égrener",),
    "égrènes": ("égrener",),
    "égrenez": ("égrener",),
    "égreniez": ("égrener",),
    "égrenions": ("égrener",),
    "égrenons": ("égrener",),
    "égrésaient": ("égréser",),
    "égrésai": ("égréser",),
    "égrésais": ("égréser",),
    "égrésait": ("égréser",),
    "égrésa": ("égréser",),
    "égrésâmes": ("égréser",),
    "égrésant": ("égréser",),
    "égrésas": ("égréser",),
    "égrésassent": ("égréser",),
    "égrésasses": ("égréser",),
    "égrésasse": ("égréser",),
    "égrésassiez": ("égréser",),
    "égrésassions": ("égréser",),
    "égrésâtes": ("égréser",),
    "égrésât": ("égréser",),
    "égrésée": ("égréser",),
    "égrésées": ("égréser",),
    "égrésé": ("égréser",),
    "égrèsent": ("égréser",),
    "égrèse": ("égréser",),
    "égrésera": ("égréser",),
    "égréseraient": ("égréser",),
    "égréserai": ("égréser",),
    "égréserais": ("égréser",),
    "égréserait": ("égréser",),
    "égréseras": ("égréser",),
    "égrésèrent": ("égréser",),
    "égréserez": ("égréser",),
    "égréseriez": ("égréser",),
    "égréserions": ("égréser",),
    "égréserons": ("égréser",),
    "égréseront": ("égréser",),
    "égrésés": ("égréser",),
    "égrèses": ("égréser",),
    "égrésez": ("égréser",),
    "égrésiez": ("égréser",),
    "égrésions": ("égréser",),
    "égrésons": ("égréser",),
    "égrugeaient": ("égruger",),
    "égrugeai": ("égruger",),
    "égrugeais": ("égruger",),
    "égrugeait": ("égruger",),
    "égrugea": ("égruger",),
    "égrugeâmes": ("égruger",),
    "égrugeant": ("égruger",),
    "égrugeas": ("égruger",),
    "égrugeassent": ("égruger",),
    "égrugeasses": ("égruger",),
    "égrugeasse": ("égruger",),
    "égrugeassiez": ("égruger",),
    "égrugeassions": ("égruger",),
    "égrugeâtes": ("égruger",),
    "égrugeât": ("égruger",),
    "égrugée": ("égruger",),
    "égrugées": ("égruger",),
    "égrugé": ("égruger",),
    "égrugent": ("égruger",),
    "égrugeons": ("égruger",),
    "égruge": ("égruger",),
    "égrugera": ("égruger",),
    "égrugeraient": ("égruger",),
    "égrugerai": ("égruger",),
    "égrugerais": ("égruger",),
    "égrugerait": ("égruger",),
    "égrugeras": ("égruger",),
    "égrugèrent": ("égruger",),
    "égrugerez": ("égruger",),
    "égrugeriez": ("égruger",),
    "égrugerions": ("égruger",),
    "égrugerons": ("égruger",),
    "égrugeront": ("égruger",),
    "égrugés": ("égruger",),
    "égruges": ("égruger",),
    "égrugez": ("égruger",),
    "égrugiez": ("égruger",),
    "égrugions": ("égruger",),
    "éjouie": ("éjouir",),
    "éjouies": ("éjouir",),
    "éjoui": ("éjouir",),
    "éjouîmes": ("éjouir",),
    "éjouira": ("éjouir",),
    "éjouiraient": ("éjouir",),
    "éjouirai": ("éjouir",),
    "éjouirais": ("éjouir",),
    "éjouirait": ("éjouir",),
    "éjouiras": ("éjouir",),
    "éjouirent": ("éjouir",),
    "éjouirez": ("éjouir",),
    "éjouiriez": ("éjouir",),
    "éjouirions": ("éjouir",),
    "éjouirons": ("éjouir",),
    "éjouiront": ("éjouir",),
    "éjouis": ("éjouir",),
    "éjouissaient": ("éjouir",),
    "éjouissais": ("éjouir",),
    "éjouissait": ("éjouir",),
    "éjouissant": ("éjouir",),
    "éjouissent": ("éjouir",),
    "éjouisse": ("éjouir",),
    "éjouisses": ("éjouir",),
    "éjouissez": ("éjouir",),
    "éjouissiez": ("éjouir",),
    "éjouissions": ("éjouir",),
    "éjouissons": ("éjouir",),
    "éjouîtes": ("éjouir",),
    "éjouit": ("éjouir",),
    "éjouît": ("éjouir",),
    "élançaient": ("élancer",),
    "élançai": ("élancer",),
    "élançais": ("élancer",),
    "élançait": ("élancer",),
    "élança": ("élancer",),
    "élançâmes": ("élancer",),
    "élançant": ("élancer",),
    "élanças": ("élancer",),
    "élançassent": ("élancer",),
    "élançasses": ("élancer",),
    "élançasse": ("élancer",),
    "élançassiez": ("élancer",),
    "élançassions": ("élancer",),
    "élançâtes": ("élancer",),
    "élançât": ("élancer",),
    "élancée": ("élancer",),
    "élancées": ("élancer",),
    "élancé": ("élancer",),
    "élancent": ("élancer",),
    "élance": ("élancer",),
    "élancera": ("élancer",),
    "élanceraient": ("élancer",),
    "élancerai": ("élancer",),
    "élancerais": ("élancer",),
    "élancerait": ("élancer",),
    "élanceras": ("élancer",),
    "élancèrent": ("élancer",),
    "élancerez": ("élancer",),
    "élanceriez": ("élancer",),
    "élancerions": ("élancer",),
    "élancerons": ("élancer",),
    "élanceront": ("élancer",),
    "élancés": ("élancer",),
    "élances": ("élancer",),
    "élancez": ("élancer",),
    "élanciez": ("élancer",),
    "élancions": ("élancer",),
    "élançons": ("élancer",),
    "élargie": ("élargir",),
    "élargies": ("élargir",),
    "élargi": ("élargir",),
    "élargîmes": ("élargir",),
    "élargira": ("élargir",),
    "élargiraient": ("élargir",),
    "élargirai": ("élargir",),
    "élargirais": ("élargir",),
    "élargirait": ("élargir",),
    "élargiras": ("élargir",),
    "élargirent": ("élargir",),
    "élargirez": ("élargir",),
    "élargiriez": ("élargir",),
    "élargirions": ("élargir",),
    "élargirons": ("élargir",),
    "élargiront": ("élargir",),
    "élargis": ("élargir",),
    "élargissaient": ("élargir",),
    "élargissais": ("élargir",),
    "élargissait": ("élargir",),
    "élargissant": ("élargir",),
    "élargissent": ("élargir",),
    "élargisse": ("élargir",),
    "élargisses": ("élargir",),
    "élargissez": ("élargir",),
    "élargissiez": ("élargir",),
    "élargissions": ("élargir",),
    "élargissons": ("élargir",),
    "élargîtes": ("élargir",),
    "élargit": ("élargir",),
    "élargît": ("élargir",),
    "électrifiaient": ("électrifier",),
    "électrifiai": ("électrifier",),
    "électrifiais": ("électrifier",),
    "électrifiait": ("électrifier",),
    "électrifia": ("électrifier",),
    "électrifiâmes": ("électrifier",),
    "électrifiant": ("électrifier",),
    "électrifias": ("électrifier",),
    "électrifiassent": ("électrifier",),
    "électrifiasses": ("électrifier",),
    "électrifiasse": ("électrifier",),
    "électrifiassiez": ("électrifier",),
    "électrifiassions": ("électrifier",),
    "électrifiâtes": ("électrifier",),
    "électrifiât": ("électrifier",),
    "électrifiée": ("électrifier",),
    "électrifiées": ("électrifier",),
    "électrifié": ("électrifier",),
    "électrifient": ("électrifier",),
    "électrifie": ("électrifier",),
    "électrifiera": ("électrifier",),
    "électrifieraient": ("électrifier",),
    "électrifierai": ("électrifier",),
    "électrifierais": ("électrifier",),
    "électrifierait": ("électrifier",),
    "électrifieras": ("électrifier",),
    "électrifièrent": ("électrifier",),
    "électrifierez": ("électrifier",),
    "électrifieriez": ("électrifier",),
    "électrifierions": ("électrifier",),
    "électrifierons": ("électrifier",),
    "électrifieront": ("électrifier",),
    "électrifiés": ("électrifier",),
    "électrifies": ("électrifier",),
    "électrifiez": ("électrifier",),
    "électrifiiez": ("électrifier",),
    "électrifiions": ("électrifier",),
    "électrifions": ("électrifier",),
    "électropolie": ("électropolir",),
    "électropolies": ("électropolir",),
    "électropoli": ("électropolir",),
    "électropolîmes": ("électropolir",),
    "électropolira": ("électropolir",),
    "électropoliraient": ("électropolir",),
    "électropolirai": ("électropolir",),
    "électropolirais": ("électropolir",),
    "électropolirait": ("électropolir",),
    "électropoliras": ("électropolir",),
    "électropolirent": ("électropolir",),
    "électropolirez": ("électropolir",),
    "électropoliriez": ("électropolir",),
    "électropolirions": ("électropolir",),
    "électropolirons": ("électropolir",),
    "électropoliront": ("électropolir",),
    "électropolis": ("électropolir",),
    "électropolissaient": ("électropolir",),
    "électropolissais": ("électropolir",),
    "électropolissait": ("électropolir",),
    "électropolissant": ("électropolir",),
    "électropolissent": ("électropolir",),
    "électropolisse": ("électropolir",),
    "électropolisses": ("électropolir",),
    "électropolissez": ("électropolir",),
    "électropolissiez": ("électropolir",),
    "électropolissions": ("électropolir",),
    "électropolissons": ("électropolir",),
    "électropolîtes": ("électropolir",),
    "électropolit": ("électropolir",),
    "électropolît": ("électropolir",),
    "élégie": ("élégir",),
    "élégies": ("élégir",),
    "élégi": ("élégir",),
    "élégîmes": ("élégir",),
    "élégira": ("élégir",),
    "élégiraient": ("élégir",),
    "élégirai": ("élégir",),
    "élégirais": ("élégir",),
    "élégirait": ("élégir",),
    "élégiras": ("élégir",),
    "élégirent": ("élégir",),
    "élégirez": ("élégir",),
    "élégiriez": ("élégir",),
    "élégirions": ("élégir",),
    "élégirons": ("élégir",),
    "élégiront": ("élégir",),
    "élégis": ("élégir",),
    "élégissaient": ("élégir",),
    "élégissais": ("élégir",),
    "élégissait": ("élégir",),
    "élégissant": ("élégir",),
    "élégissent": ("élégir",),
    "élégisse": ("élégir",),
    "élégisses": ("élégir",),
    "élégissez": ("élégir",),
    "élégissiez": ("élégir",),
    "élégissions": ("élégir",),
    "élégissons": ("élégir",),
    "élégîtes": ("élégir",),
    "élégit": ("élégir",),
    "élégît": ("élégir",),
    "élevaient": ("élever",),
    "élevai": ("élever",),
    "élevais": ("élever",),
    "élevait": ("élever",),
    "éleva": ("élever",),
    "élevâmes": ("élever",),
    "élevant": ("élever",),
    "élevas": ("élever",),
    "élevassent": ("élever",),
    "élevasses": ("élever",),
    "élevasse": ("élever",),
    "élevassiez": ("élever",),
    "élevassions": ("élever",),
    "élevâtes": ("élever",),
    "élevât": ("élever",),
    "élevée": ("élever",),
    "élevées": ("élever",),
    "élevé": ("élever",),
    "élèvent": ("élever",),
    "élève": ("élever",),
    "élèvera": ("élever",),
    "élèveraient": ("élever",),
    "élèverai": ("élever",),
    "élèverais": ("élever",),
    "élèverait": ("élever",),
    "élèveras": ("élever",),
    "élevèrent": ("élever",),
    "élèverez": ("élever",),
    "élèveriez": ("élever",),
    "élèverions": ("élever",),
    "élèverons": ("élever",),
    "élèveront": ("élever",),
    "élevés": ("élever",),
    "élèves": ("élever",),
    "élevez": ("élever",),
    "éleviez": ("élever",),
    "élevions": ("élever",),
    "élevons": ("élever",),
    "éliaient": ("élier",),
    "éliai": ("élier",),
    "éliais": ("élier",),
    "éliait": ("élier",),
    "élia": ("élier",),
    "éliâmes": ("élier",),
    "éliant": ("élier",),
    "élias": ("élier",),
    "éliassent": ("élier",),
    "éliasses": ("élier",),
    "éliasse": ("élier",),
    "éliassiez": ("élier",),
    "éliassions": ("élier",),
    "éliâtes": ("élier",),
    "éliât": ("élier",),
    "éliée": ("élier",),
    "éliées": ("élier",),
    "élié": ("élier",),
    "élient": ("élier",),
    "élie": ("élier",),
    "éliera": ("élier",),
    "élieraient": ("élier",),
    "élierai": ("élier",),
    "élierais": ("élier",),
    "élierait": ("élier",),
    "élieras": ("élier",),
    "élièrent": ("élier",),
    "élierez": ("élier",),
    "élieriez": ("élier",),
    "élierions": ("élier",),
    "élierons": ("élier",),
    "élieront": ("élier",),
    "éliés": ("élier",),
    "élies": ("élier",),
    "éliez": ("élier",),
    "éliiez": ("élier",),
    "éliions": ("élier",),
    "élions": ("élier",),
    "élira": ("élire",),
    "éliraient": ("élire",),
    "élirai": ("élire",),
    "élirais": ("élire",),
    "élirait": ("élire",),
    "éliras": ("élire",),
    "élirez": ("élire",),
    "éliriez": ("élire",),
    "élirions": ("élire",),
    "élirons": ("élire",),
    "éliront": ("élire",),
    "élisaient": ("élire",),
    "élisais": ("élire",),
    "élisait": ("élire",),
    "élisant": ("élire",),
    "élisent": ("élire",),
    "élise": ("élire",),
    "élises": ("élire",),
    "élisez": ("élire",),
    "élisiez": ("élire",),
    "élisions": ("élire",),
    "élisons": ("élire",),
    "élis": ("élire",),
    "élit": ("élire",),
    "élue": ("élire",),
    "élues": ("élire",),
    "élu": ("élire",),
    "élûmes": ("élire",),
    "élurent": ("élire",),
    "élus": ("élire",),
    "élussent": ("élire",),
    "élusses": ("élire",),
    "élusse": ("élire",),
    "élussiez": ("élire",),
    "élussions": ("élire",),
    "élûtes": ("élire",),
    "élut": ("élire",),
    "élût": ("élire",),
    "élongeaient": ("élonger",),
    "élongeai": ("élonger",),
    "élongeais": ("élonger",),
    "élongeait": ("élonger",),
    "élongea": ("élonger",),
    "élongeâmes": ("élonger",),
    "élongeant": ("élonger",),
    "élongeas": ("élonger",),
    "élongeassent": ("élonger",),
    "élongeasses": ("élonger",),
    "élongeasse": ("élonger",),
    "élongeassiez": ("élonger",),
    "élongeassions": ("élonger",),
    "élongeâtes": ("élonger",),
    "élongeât": ("élonger",),
    "élongée": ("élonger",),
    "élongées": ("élonger",),
    "élongé": ("élonger",),
    "élongent": ("élonger",),
    "élongeons": ("élonger",),
    "élonge": ("élonger",),
    "élongera": ("élonger",),
    "élongeraient": ("élonger",),
    "élongerai": ("élonger",),
    "élongerais": ("élonger",),
    "élongerait": ("élonger",),
    "élongeras": ("élonger",),
    "élongèrent": ("élonger",),
    "élongerez": ("élonger",),
    "élongeriez": ("élonger",),
    "élongerions": ("élonger",),
    "élongerons": ("élonger",),
    "élongeront": ("élonger",),
    "élongés": ("élonger",),
    "élonges": ("élonger",),
    "élongez": ("élonger",),
    "élongiez": ("élonger",),
    "élongions": ("élonger",),
    "élutriaient": ("élutrier",),
    "élutriai": ("élutrier",),
    "élutriais": ("élutrier",),
    "élutriait": ("élutrier",),
    "élutria": ("élutrier",),
    "élutriâmes": ("élutrier",),
    "élutriant": ("élutrier",),
    "élutrias": ("élutrier",),
    "élutriassent": ("élutrier",),
    "élutriasses": ("élutrier",),
    "élutriasse": ("élutrier",),
    "élutriassiez": ("élutrier",),
    "élutriassions": ("élutrier",),
    "élutriâtes": ("élutrier",),
    "élutriât": ("élutrier",),
    "élutriée": ("élutrier",),
    "élutriées": ("élutrier",),
    "élutrié": ("élutrier",),
    "élutrient": ("élutrier",),
    "élutrie": ("élutrier",),
    "élutriera": ("élutrier",),
    "élutrieraient": ("élutrier",),
    "élutrierai": ("élutrier",),
    "élutrierais": ("élutrier",),
    "élutrierait": ("élutrier",),
    "élutrieras": ("élutrier",),
    "élutrièrent": ("élutrier",),
    "élutrierez": ("élutrier",),
    "élutrieriez": ("élutrier",),
    "élutrierions": ("élutrier",),
    "élutrierons": ("élutrier",),
    "élutrieront": ("élutrier",),
    "élutriés": ("élutrier",),
    "élutries": ("élutrier",),
    "élutriez": ("élutrier",),
    "élutriiez": ("élutrier",),
    "élutriions": ("élutrier",),
    "élutrions": ("élutrier",),
    "émaciaient": ("émacier",),
    "émaciai": ("émacier",),
    "émaciais": ("émacier",),
    "émaciait": ("émacier",),
    "émacia": ("émacier",),
    "émaciâmes": ("émacier",),
    "émaciant": ("émacier",),
    "émacias": ("émacier",),
    "émaciassent": ("émacier",),
    "émaciasses": ("émacier",),
    "émaciasse": ("émacier",),
    "émaciassiez": ("émacier",),
    "émaciassions": ("émacier",),
    "émaciâtes": ("émacier",),
    "émaciât": ("émacier",),
    "émaciée": ("émacier",),
    "émaciées": ("émacier",),
    "émacié": ("émacier",),
    "émacient": ("émacier",),
    "émacie": ("émacier",),
    "émaciera": ("émacier",),
    "émacieraient": ("émacier",),
    "émacierai": ("émacier",),
    "émacierais": ("émacier",),
    "émacierait": ("émacier",),
    "émacieras": ("émacier",),
    "émacièrent": ("émacier",),
    "émacierez": ("émacier",),
    "émacieriez": ("émacier",),
    "émacierions": ("émacier",),
    "émacierons": ("émacier",),
    "émacieront": ("émacier",),
    "émaciés": ("émacier",),
    "émacies": ("émacier",),
    "émaciez": ("émacier",),
    "émaciiez": ("émacier",),
    "émaciions": ("émacier",),
    "émacions": ("émacier",),
    "émargeaient": ("émarger",),
    "émargeai": ("émarger",),
    "émargeais": ("émarger",),
    "émargeait": ("émarger",),
    "émargea": ("émarger",),
    "émargeâmes": ("émarger",),
    "émargeant": ("émarger",),
    "émargeas": ("émarger",),
    "émargeassent": ("émarger",),
    "émargeasses": ("émarger",),
    "émargeasse": ("émarger",),
    "émargeassiez": ("émarger",),
    "émargeassions": ("émarger",),
    "émargeâtes": ("émarger",),
    "émargeât": ("émarger",),
    "émargée": ("émarger",),
    "émargées": ("émarger",),
    "émargé": ("émarger",),
    "émargent": ("émarger",),
    "émargeons": ("émarger",),
    "émarge": ("émarger",),
    "émargera": ("émarger",),
    "émargeraient": ("émarger",),
    "émargerai": ("émarger",),
    "émargerais": ("émarger",),
    "émargerait": ("émarger",),
    "émargeras": ("émarger",),
    "émargèrent": ("émarger",),
    "émargerez": ("émarger",),
    "émargeriez": ("émarger",),
    "émargerions": ("émarger",),
    "émargerons": ("émarger",),
    "émargeront": ("émarger",),
    "émargés": ("émarger",),
    "émarges": ("émarger",),
    "émargez": ("émarger",),
    "émargiez": ("émarger",),
    "émargions": ("émarger",),
    "embarrassaient": ("embarrasser",),
    "embarrassai": ("embarrasser",),
    "embarrassais": ("embarrasser",),
    "embarrassait": ("embarrasser",),
    "embarrassa": ("embarrasser",),
    "embarrassâmes": ("embarrasser",),
    "embarrassant": ("embarrasser",),
    "embarrassas": ("embarrasser",),
    "embarrassassent": ("embarrasser",),
    "embarrassasses": ("embarrasser",),
    "embarrassasse": ("embarrasser",),
    "embarrassassiez": ("embarrasser",),
    "embarrassassions": ("embarrasser",),
    "embarrassâtes": ("embarrasser",),
    "embarrassât": ("embarrasser",),
    "embarrassée": ("embarrasser",),
    "embarrassées": ("embarrasser",),
    "embarrassé": ("embarrasser",),
    "embarrassent": ("embarrasser",),
    "embarrasse": ("embarrasser",),
    "embarrassera": ("embarrasser",),
    "embarrasseraient": ("embarrasser",),
    "embarrasserai": ("embarrasser",),
    "embarrasserais": ("embarrasser",),
    "embarrasserait": ("embarrasser",),
    "embarrasseras": ("embarrasser",),
    "embarrassèrent": ("embarrasser",),
    "embarrasserez": ("embarrasser",),
    "embarrasseriez": ("embarrasser",),
    "embarrasserions": ("embarrasser",),
    "embarrasserons": ("embarrasser",),
    "embarrasseront": ("embarrasser",),
    "embarrassés": ("embarrasser",),
    "embarrasses": ("embarrasser",),
    "embarrassez": ("embarrasser",),
    "embarrassiez": ("embarrasser",),
    "embarrassions": ("embarrasser",),
    "embarrassons": ("embarrasser",),
    "embâtaient": ("embâter",),
    "embâtai": ("embâter",),
    "embâtais": ("embâter",),
    "embâtait": ("embâter",),
    "embâta": ("embâter",),
    "embâtâmes": ("embâter",),
    "embâtant": ("embâter",),
    "embâtas": ("embâter",),
    "embâtassent": ("embâter",),
    "embâtasses": ("embâter",),
    "embâtasse": ("embâter",),
    "embâtassiez": ("embâter",),
    "embâtassions": ("embâter",),
    "embâtâtes": ("embâter",),
    "embâtât": ("embâter",),
    "embâtée": ("embâter",),
    "embâtées": ("embâter",),
    "embâté": ("embâter",),
    "embâtent": ("embâter",),
    "embâte": ("embâter",),
    "embâtera": ("embâter",),
    "embâteraient": ("embâter",),
    "embâterai": ("embâter",),
    "embâterais": ("embâter",),
    "embâterait": ("embâter",),
    "embâteras": ("embâter",),
    "embâtèrent": ("embâter",),
    "embâterez": ("embâter",),
    "embâteriez": ("embâter",),
    "embâterions": ("embâter",),
    "embâterons": ("embâter",),
    "embâteront": ("embâter",),
    "embâtés": ("embâter",),
    "embâtes": ("embâter",),
    "embâtez": ("embâter",),
    "embâtiez": ("embâter",),
    "embâtions": ("embâter",),
    "embâtons": ("embâter",),
    "embat": ("embattre",),
    "embats": ("embattre",),
    "embattaient": ("embattre",),
    "embattais": ("embattre",),
    "embattait": ("embattre",),
    "embattant": ("embattre",),
    "embattent": ("embattre",),
    "embatte": ("embattre",),
    "embattes": ("embattre",),
    "embattez": ("embattre",),
    "embattiez": ("embattre",),
    "embattîmes": ("embattre",),
    "embattions": ("embattre",),
    "embattirent": ("embattre",),
    "embattis": ("embattre",),
    "embattissent": ("embattre",),
    "embattisses": ("embattre",),
    "embattisse": ("embattre",),
    "embattissiez": ("embattre",),
    "embattissions": ("embattre",),
    "embattîtes": ("embattre",),
    "embattit": ("embattre",),
    "embattît": ("embattre",),
    "embattons": ("embattre",),
    "embattra": ("embattre",),
    "embattraient": ("embattre",),
    "embattrai": ("embattre",),
    "embattrais": ("embattre",),
    "embattrait": ("embattre",),
    "embattras": ("embattre",),
    "embattrez": ("embattre",),
    "embattriez": ("embattre",),
    "embattrions": ("embattre",),
    "embattrons": ("embattre",),
    "embattront": ("embattre",),
    "embattue": ("embattre",),
    "embattues": ("embattre",),
    "embattu": ("embattre",),
    "embattus": ("embattre",),
    "embellie": ("embellir",),
    "embellies": ("embellir",),
    "embelli": ("embellir",),
    "embellîmes": ("embellir",),
    "embellira": ("embellir",),
    "embelliraient": ("embellir",),
    "embellirai": ("embellir",),
    "embellirais": ("embellir",),
    "embellirait": ("embellir",),
    "embelliras": ("embellir",),
    "embellirent": ("embellir",),
    "embellirez": ("embellir",),
    "embelliriez": ("embellir",),
    "embellirions": ("embellir",),
    "embellirons": ("embellir",),
    "embelliront": ("embellir",),
    "embellis": ("embellir",),
    "embellissaient": ("embellir",),
    "embellissais": ("embellir",),
    "embellissait": ("embellir",),
    "embellissant": ("embellir",),
    "embellissent": ("embellir",),
    "embellisse": ("embellir",),
    "embellisses": ("embellir",),
    "embellissez": ("embellir",),
    "embellissiez": ("embellir",),
    "embellissions": ("embellir",),
    "embellissons": ("embellir",),
    "embellîtes": ("embellir",),
    "embellit": ("embellir",),
    "embellît": ("embellir",),
    "emboira": ("emboire",),
    "emboiraient": ("emboire",),
    "emboirai": ("emboire",),
    "emboirais": ("emboire",),
    "emboirait": ("emboire",),
    "emboiras": ("emboire",),
    "emboirez": ("emboire",),
    "emboiriez": ("emboire",),
    "emboirions": ("emboire",),
    "emboirons": ("emboire",),
    "emboiront": ("emboire",),
    "embois": ("emboire",),
    "emboit": ("emboire",),
    "emboivent": ("emboire",),
    "emboive": ("emboire",),
    "emboives": ("emboire",),
    "embue": ("emboire",),
    "embues": ("emboire",),
    "embu": ("emboire",),
    "embûmes": ("emboire",),
    "emburent": ("emboire",),
    "embus": ("emboire",),
    "embussent": ("emboire",),
    "embusses": ("emboire",),
    "embusse": ("emboire",),
    "embussiez": ("emboire",),
    "embussions": ("emboire",),
    "embûtes": ("emboire",),
    "embut": ("emboire",),
    "embût": ("emboire",),
    "embuvaient": ("emboire",),
    "embuvais": ("emboire",),
    "embuvait": ("emboire",),
    "embuvant": ("emboire",),
    "embuvez": ("emboire",),
    "embuviez": ("emboire",),
    "embuvions": ("emboire",),
    "embuvons": ("emboire",),
    "embottelaient": ("embotteler",),
    "embottelai": ("embotteler",),
    "embottelais": ("embotteler",),
    "embottelait": ("embotteler",),
    "embottela": ("embotteler",),
    "embottelâmes": ("embotteler",),
    "embottelant": ("embotteler",),
    "embottelas": ("embotteler",),
    "embottelassent": ("embotteler",),
    "embottelasses": ("embotteler",),
    "embottelasse": ("embotteler",),
    "embottelassiez": ("embotteler",),
    "embottelassions": ("embotteler",),
    "embottelâtes": ("embotteler",),
    "embottelât": ("embotteler",),
    "embottelée": ("embotteler",),
    "embottelées": ("embotteler",),
    "embottelé": ("embotteler",),
    "embottelèrent": ("embotteler",),
    "embottelés": ("embotteler",),
    "embottelez": ("embotteler",),
    "embotteliez": ("embotteler",),
    "embottelions": ("embotteler",),
    "embottellent": ("embotteler",),
    "embottelle": ("embotteler",),
    "embottellera": ("embotteler",),
    "embottelleraient": ("embotteler",),
    "embottellerai": ("embotteler",),
    "embottellerais": ("embotteler",),
    "embottellerait": ("embotteler",),
    "embottelleras": ("embotteler",),
    "embottellerez": ("embotteler",),
    "embottelleriez": ("embotteler",),
    "embottellerions": ("embotteler",),
    "embottellerons": ("embotteler",),
    "embottelleront": ("embotteler",),
    "embottelles": ("embotteler",),
    "embottelons": ("embotteler",),
    "embouffetaient": ("embouffeter",),
    "embouffetai": ("embouffeter",),
    "embouffetais": ("embouffeter",),
    "embouffetait": ("embouffeter",),
    "embouffeta": ("embouffeter",),
    "embouffetâmes": ("embouffeter",),
    "embouffetant": ("embouffeter",),
    "embouffetas": ("embouffeter",),
    "embouffetassent": ("embouffeter",),
    "embouffetasses": ("embouffeter",),
    "embouffetasse": ("embouffeter",),
    "embouffetassiez": ("embouffeter",),
    "embouffetassions": ("embouffeter",),
    "embouffetâtes": ("embouffeter",),
    "embouffetât": ("embouffeter",),
    "embouffetée": ("embouffeter",),
    "embouffetées": ("embouffeter",),
    "embouffeté": ("embouffeter",),
    "embouffetèrent": ("embouffeter",),
    "embouffetés": ("embouffeter",),
    "embouffetez": ("embouffeter",),
    "embouffetiez": ("embouffeter",),
    "embouffetions": ("embouffeter",),
    "embouffetons": ("embouffeter",),
    "embouffettent": ("embouffeter",),
    "embouffette": ("embouffeter",),
    "embouffettera": ("embouffeter",),
    "embouffetteraient": ("embouffeter",),
    "embouffetterai": ("embouffeter",),
    "embouffetterais": ("embouffeter",),
    "embouffetterait": ("embouffeter",),
    "embouffetteras": ("embouffeter",),
    "embouffetterez": ("embouffeter",),
    "embouffetteriez": ("embouffeter",),
    "embouffetterions": ("embouffeter",),
    "embouffetterons": ("embouffeter",),
    "embouffetteront": ("embouffeter",),
    "embouffettes": ("embouffeter",),
    "emboutie": ("emboutir",),
    "embouties": ("emboutir",),
    "embouti": ("emboutir",),
    "emboutîmes": ("emboutir",),
    "emboutira": ("emboutir",),
    "emboutiraient": ("emboutir",),
    "emboutirai": ("emboutir",),
    "emboutirais": ("emboutir",),
    "emboutirait": ("emboutir",),
    "emboutiras": ("emboutir",),
    "emboutirent": ("emboutir",),
    "emboutirez": ("emboutir",),
    "emboutiriez": ("emboutir",),
    "emboutirions": ("emboutir",),
    "emboutirons": ("emboutir",),
    "emboutiront": ("emboutir",),
    "emboutis": ("emboutir",),
    "emboutissaient": ("emboutir",),
    "emboutissais": ("emboutir",),
    "emboutissait": ("emboutir",),
    "emboutissant": ("emboutir",),
    "emboutissent": ("emboutir",),
    "emboutisse": ("emboutir",),
    "emboutisses": ("emboutir",),
    "emboutissez": ("emboutir",),
    "emboutissiez": ("emboutir",),
    "emboutissions": ("emboutir",),
    "emboutissons": ("emboutir",),
    "emboutîtes": ("emboutir",),
    "emboutit": ("emboutir",),
    "emboutît": ("emboutir",),
    "embrassaient": ("embrasser",),
    "embrassai": ("embrasser",),
    "embrassais": ("embrasser",),
    "embrassait": ("embrasser",),
    "embrassa": ("embrasser",),
    "embrassâmes": ("embrasser",),
    "embrassant": ("embrasser",),
    "embrassas": ("embrasser",),
    "embrassassent": ("embrasser",),
    "embrassasses": ("embrasser",),
    "embrassasse": ("embrasser",),
    "embrassassiez": ("embrasser",),
    "embrassassions": ("embrasser",),
    "embrassâtes": ("embrasser",),
    "embrassât": ("embrasser",),
    "embrassée": ("embrasser",),
    "embrassées": ("embrasser",),
    "embrassé": ("embrasser",),
    "embrassent": ("embrasser",),
    "embrasse": ("embrasser",),
    "embrassera": ("embrasser",),
    "embrasseraient": ("embrasser",),
    "embrasserai": ("embrasser",),
    "embrasserais": ("embrasser",),
    "embrasserait": ("embrasser",),
    "embrasseras": ("embrasser",),
    "embrassèrent": ("embrasser",),
    "embrasserez": ("embrasser",),
    "embrasseriez": ("embrasser",),
    "embrasserions": ("embrasser",),
    "embrasserons": ("embrasser",),
    "embrasseront": ("embrasser",),
    "embrassés": ("embrasser",),
    "embrasses": ("embrasser",),
    "embrassez": ("embrasser",),
    "embrassiez": ("embrasser",),
    "embrassions": ("embrasser",),
    "embrassons": ("embrasser",),
    "embraient": ("embrayer",),
    "embraie": ("embrayer",),
    "embraiera": ("embrayer",),
    "embraieraient": ("embrayer",),
    "embraierai": ("embrayer",),
    "embraierais": ("embrayer",),
    "embraierait": ("embrayer",),
    "embraieras": ("embrayer",),
    "embraierez": ("embrayer",),
    "embraieriez": ("embrayer",),
    "embraierions": ("embrayer",),
    "embraierons": ("embrayer",),
    "embraieront": ("embrayer",),
    "embraies": ("embrayer",),
    "embrayaient": ("embrayer",),
    "embrayai": ("embrayer",),
    "embrayais": ("embrayer",),
    "embrayait": ("embrayer",),
    "embraya": ("embrayer",),
    "embrayâmes": ("embrayer",),
    "embrayant": ("embrayer",),
    "embrayas": ("embrayer",),
    "embrayassent": ("embrayer",),
    "embrayasses": ("embrayer",),
    "embrayasse": ("embrayer",),
    "embrayassiez": ("embrayer",),
    "embrayassions": ("embrayer",),
    "embrayâtes": ("embrayer",),
    "embrayât": ("embrayer",),
    "embrayée": ("embrayer",),
    "embrayées": ("embrayer",),
    "embrayé": ("embrayer",),
    "embrayent": ("embrayer",),
    "embraye": ("embrayer",),
    "embrayera": ("embrayer",),
    "embrayeraient": ("embrayer",),
    "embrayerai": ("embrayer",),
    "embrayerais": ("embrayer",),
    "embrayerait": ("embrayer",),
    "embrayeras": ("embrayer",),
    "embrayèrent": ("embrayer",),
    "embrayerez": ("embrayer",),
    "embrayeriez": ("embrayer",),
    "embrayerions": ("embrayer",),
    "embrayerons": ("embrayer",),
    "embrayeront": ("embrayer",),
    "embrayés": ("embrayer",),
    "embrayes": ("embrayer",),
    "embrayez": ("embrayer",),
    "embrayiez": ("embrayer",),
    "embrayions": ("embrayer",),
    "embrayons": ("embrayer",),
    "embrelaient": ("embreler",),
    "embrelai": ("embreler",),
    "embrelais": ("embreler",),
    "embrelait": ("embreler",),
    "embrela": ("embreler",),
    "embrelâmes": ("embreler",),
    "embrelant": ("embreler",),
    "embrelas": ("embreler",),
    "embrelassent": ("embreler",),
    "embrelasses": ("embreler",),
    "embrelasse": ("embreler",),
    "embrelassiez": ("embreler",),
    "embrelassions": ("embreler",),
    "embrelâtes": ("embreler",),
    "embrelât": ("embreler",),
    "embrelée": ("embreler",),
    "embrelées": ("embreler",),
    "embrelé": ("embreler",),
    "embrèlent": ("embreler",),
    "embrèle": ("embreler",),
    "embrèlera": ("embreler",),
    "embrèleraient": ("embreler",),
    "embrèlerai": ("embreler",),
    "embrèlerais": ("embreler",),
    "embrèlerait": ("embreler",),
    "embrèleras": ("embreler",),
    "embrelèrent": ("embreler",),
    "embrèlerez": ("embreler",),
    "embrèleriez": ("embreler",),
    "embrèlerions": ("embreler",),
    "embrèlerons": ("embreler",),
    "embrèleront": ("embreler",),
    "embrelés": ("embreler",),
    "embrèles": ("embreler",),
    "embrelez": ("embreler",),
    "embreliez": ("embreler",),
    "embrelions": ("embreler",),
    "embrelons": ("embreler",),
    "embrenaient": ("embrener",),
    "embrenai": ("embrener",),
    "embrenais": ("embrener",),
    "embrenait": ("embrener",),
    "embrena": ("embrener",),
    "embrenâmes": ("embrener",),
    "embrenant": ("embrener",),
    "embrenas": ("embrener",),
    "embrenassent": ("embrener",),
    "embrenasses": ("embrener",),
    "embrenasse": ("embrener",),
    "embrenassiez": ("embrener",),
    "embrenassions": ("embrener",),
    "embrenâtes": ("embrener",),
    "embrenât": ("embrener",),
    "embrenée": ("embrener",),
    "embrenées": ("embrener",),
    "embrené": ("embrener",),
    "embrènent": ("embrener",),
    "embrène": ("embrener",),
    "embrènera": ("embrener",),
    "embrèneraient": ("embrener",),
    "embrènerai": ("embrener",),
    "embrènerais": ("embrener",),
    "embrènerait": ("embrener",),
    "embrèneras": ("embrener",),
    "embrenèrent": ("embrener",),
    "embrènerez": ("embrener",),
    "embrèneriez": ("embrener",),
    "embrènerions": ("embrener",),
    "embrènerons": ("embrener",),
    "embrèneront": ("embrener",),
    "embrenés": ("embrener",),
    "embrènes": ("embrener",),
    "embrenez": ("embrener",),
    "embreniez": ("embrener",),
    "embrenions": ("embrener",),
    "embrenons": ("embrener",),
    "embrevaient": ("embrever",),
    "embrevai": ("embrever",),
    "embrevais": ("embrever",),
    "embrevait": ("embrever",),
    "embreva": ("embrever",),
    "embrevâmes": ("embrever",),
    "embrevant": ("embrever",),
    "embrevas": ("embrever",),
    "embrevassent": ("embrever",),
    "embrevasses": ("embrever",),
    "embrevasse": ("embrever",),
    "embrevassiez": ("embrever",),
    "embrevassions": ("embrever",),
    "embrevâtes": ("embrever",),
    "embrevât": ("embrever",),
    "embrevée": ("embrever",),
    "embrevées": ("embrever",),
    "embrevé": ("embrever",),
    "embrèvent": ("embrever",),
    "embrève": ("embrever",),
    "embrèvera": ("embrever",),
    "embrèveraient": ("embrever",),
    "embrèverai": ("embrever",),
    "embrèverais": ("embrever",),
    "embrèverait": ("embrever",),
    "embrèveras": ("embrever",),
    "embrevèrent": ("embrever",),
    "embrèverez": ("embrever",),
    "embrèveriez": ("embrever",),
    "embrèverions": ("embrever",),
    "embrèverons": ("embrever",),
    "embrèveront": ("embrever",),
    "embrevés": ("embrever",),
    "embrèves": ("embrever",),
    "embrevez": ("embrever",),
    "embreviez": ("embrever",),
    "embrevions": ("embrever",),
    "embrevons": ("embrever",),
    "embrunie": ("embrunir",),
    "embrunies": ("embrunir",),
    "embruni": ("embrunir",),
    "embrunîmes": ("embrunir",),
    "embrunira": ("embrunir",),
    "embruniraient": ("embrunir",),
    "embrunirai": ("embrunir",),
    "embrunirais": ("embrunir",),
    "embrunirait": ("embrunir",),
    "embruniras": ("embrunir",),
    "embrunirent": ("embrunir",),
    "embrunirez": ("embrunir",),
    "embruniriez": ("embrunir",),
    "embrunirions": ("embrunir",),
    "embrunirons": ("embrunir",),
    "embruniront": ("embrunir",),
    "embrunis": ("embrunir",),
    "embrunissaient": ("embrunir",),
    "embrunissais": ("embrunir",),
    "embrunissait": ("embrunir",),
    "embrunissant": ("embrunir",),
    "embrunissent": ("embrunir",),
    "embrunisse": ("embrunir",),
    "embrunisses": ("embrunir",),
    "embrunissez": ("embrunir",),
    "embrunissiez": ("embrunir",),
    "embrunissions": ("embrunir",),
    "embrunissons": ("embrunir",),
    "embrunîtes": ("embrunir",),
    "embrunit": ("embrunir",),
    "embrunît": ("embrunir",),
    "éméchaient": ("émécher",),
    "éméchai": ("émécher",),
    "éméchais": ("émécher",),
    "éméchait": ("émécher",),
    "émécha": ("émécher",),
    "éméchâmes": ("émécher",),
    "éméchant": ("émécher",),
    "éméchas": ("émécher",),
    "éméchassent": ("émécher",),
    "éméchasses": ("émécher",),
    "éméchasse": ("émécher",),
    "éméchassiez": ("émécher",),
    "éméchassions": ("émécher",),
    "éméchâtes": ("émécher",),
    "éméchât": ("émécher",),
    "éméchée": ("émécher",),
    "éméchées": ("émécher",),
    "éméché": ("émécher",),
    "émèchent": ("émécher",),
    "émèche": ("émécher",),
    "éméchera": ("émécher",),
    "émécheraient": ("émécher",),
    "émécherai": ("émécher",),
    "émécherais": ("émécher",),
    "émécherait": ("émécher",),
    "émécheras": ("émécher",),
    "éméchèrent": ("émécher",),
    "émécherez": ("émécher",),
    "émécheriez": ("émécher",),
    "émécherions": ("émécher",),
    "émécherons": ("émécher",),
    "émécheront": ("émécher",),
    "éméchés": ("émécher",),
    "émèches": ("émécher",),
    "éméchez": ("émécher",),
    "éméchiez": ("émécher",),
    "éméchions": ("émécher",),
    "éméchons": ("émécher",),
    "émergeaient": ("émerger",),
    "émergeai": ("émerger",),
    "émergeais": ("émerger",),
    "émergeait": ("émerger",),
    "émergea": ("émerger",),
    "émergeâmes": ("émerger",),
    "émergeant": ("émerger",),
    "émergeas": ("émerger",),
    "émergeassent": ("émerger",),
    "émergeasses": ("émerger",),
    "émergeasse": ("émerger",),
    "émergeassiez": ("émerger",),
    "émergeassions": ("émerger",),
    "émergeâtes": ("émerger",),
    "émergeât": ("émerger",),
    "émergé": ("émerger",),
    "émergent": ("émerger",),
    "émergeons": ("émerger",),
    "émerge": ("émerger",),
    "émergera": ("émerger",),
    "émergeraient": ("émerger",),
    "émergerai": ("émerger",),
    "émergerais": ("émerger",),
    "émergerait": ("émerger",),
    "émergeras": ("émerger",),
    "émergèrent": ("émerger",),
    "émergerez": ("émerger",),
    "émergeriez": ("émerger",),
    "émergerions": ("émerger",),
    "émergerons": ("émerger",),
    "émergeront": ("émerger",),
    "émerges": ("émerger",),
    "émergez": ("émerger",),
    "émergiez": ("émerger",),
    "émergions": ("émerger",),
    "émet": ("émettre",),
    "émets": ("émettre",),
    "émettaient": ("émettre",),
    "émettais": ("émettre",),
    "émettait": ("émettre",),
    "émettant": ("émettre",),
    "émettent": ("émettre",),
    "émette": ("émettre",),
    "émettes": ("émettre",),
    "émettez": ("émettre",),
    "émettiez": ("émettre",),
    "émettions": ("émettre",),
    "émettons": ("émettre",),
    "émettra": ("émettre",),
    "émettraient": ("émettre",),
    "émettrai": ("émettre",),
    "émettrais": ("émettre",),
    "émettrait": ("émettre",),
    "émettras": ("émettre",),
    "émettrez": ("émettre",),
    "émettriez": ("émettre",),
    "émettrions": ("émettre",),
    "émettrons": ("émettre",),
    "émettront": ("émettre",),
    "émîmes": ("émettre",),
    "émirent": ("émettre",),
    "émise": ("émettre",),
    "émises": ("émettre",),
    "émis": ("émettre",),
    "émissent": ("émettre",),
    "émisses": ("émettre",),
    "émisse": ("émettre",),
    "émissiez": ("émettre",),
    "émissions": ("émettre",),
    "émîtes": ("émettre",),
    "émit": ("émettre",),
    "émît": ("émettre",),
    "émeutie": ("émeutir",),
    "émeuties": ("émeutir",),
    "émeuti": ("émeutir",),
    "émeutîmes": ("émeutir",),
    "émeutira": ("émeutir",),
    "émeutiraient": ("émeutir",),
    "émeutirai": ("émeutir",),
    "émeutirais": ("émeutir",),
    "émeutirait": ("émeutir",),
    "émeutiras": ("émeutir",),
    "émeutirent": ("émeutir",),
    "émeutirez": ("émeutir",),
    "émeutiriez": ("émeutir",),
    "émeutirions": ("émeutir",),
    "émeutirons": ("émeutir",),
    "émeutiront": ("émeutir",),
    "émeutis": ("émeutir",),
    "émeutissaient": ("émeutir",),
    "émeutissais": ("émeutir",),
    "émeutissait": ("émeutir",),
    "émeutissant": ("émeutir",),
    "émeutissent": ("émeutir",),
    "émeutisse": ("émeutir",),
    "émeutisses": ("émeutir",),
    "émeutissez": ("émeutir",),
    "émeutissiez": ("émeutir",),
    "émeutissions": ("émeutir",),
    "émeutissons": ("émeutir",),
    "émeutîtes": ("émeutir",),
    "émeutit": ("émeutir",),
    "émeutît": ("émeutir",),
    "émiaient": ("émier",),
    "émiai": ("émier",),
    "émiais": ("émier",),
    "émiait": ("émier",),
    "émia": ("émier",),
    "émiâmes": ("émier",),
    "émiant": ("émier",),
    "émias": ("émier",),
    "émiassent": ("émier",),
    "émiasses": ("émier",),
    "émiasse": ("émier",),
    "émiassiez": ("émier",),
    "émiassions": ("émier",),
    "émiâtes": ("émier",),
    "émiât": ("émier",),
    "émiée": ("émier",),
    "émiées": ("émier",),
    "émié": ("émier",),
    "émient": ("émier",),
    "émie": ("émier",),
    "émiera": ("émier",),
    "émieraient": ("émier",),
    "émierai": ("émier",),
    "émierais": ("émier",),
    "émierait": ("émier",),
    "émieras": ("émier",),
    "émièrent": ("émier",),
    "émierez": ("émier",),
    "émieriez": ("émier",),
    "émierions": ("émier",),
    "émierons": ("émier",),
    "émieront": ("émier",),
    "émiés": ("émier",),
    "émies": ("émier",),
    "émiez": ("émier",),
    "émiiez": ("émier",),
    "émiions": ("émier",),
    "émions": ("émier",),
    "éminçaient": ("émincer",),
    "éminçai": ("émincer",),
    "éminçais": ("émincer",),
    "éminçait": ("émincer",),
    "éminça": ("émincer",),
    "éminçâmes": ("émincer",),
    "éminçant": ("émincer",),
    "éminças": ("émincer",),
    "éminçassent": ("émincer",),
    "éminçasses": ("émincer",),
    "éminçasse": ("émincer",),
    "éminçassiez": ("émincer",),
    "éminçassions": ("émincer",),
    "éminçâtes": ("émincer",),
    "éminçât": ("émincer",),
    "émincée": ("émincer",),
    "émincées": ("émincer",),
    "émincé": ("émincer",),
    "émincent": ("émincer",),
    "émince": ("émincer",),
    "émincera": ("émincer",),
    "éminceraient": ("émincer",),
    "émincerai": ("émincer",),
    "émincerais": ("émincer",),
    "émincerait": ("émincer",),
    "éminceras": ("émincer",),
    "émincèrent": ("émincer",),
    "émincerez": ("émincer",),
    "éminceriez": ("émincer",),
    "émincerions": ("émincer",),
    "émincerons": ("émincer",),
    "éminceront": ("émincer",),
    "émincés": ("émincer",),
    "éminces": ("émincer",),
    "émincez": ("émincer",),
    "éminciez": ("émincer",),
    "émincions": ("émincer",),
    "éminçons": ("émincer",),
    "emmaigrie": ("emmaigrir",),
    "emmaigries": ("emmaigrir",),
    "emmaigri": ("emmaigrir",),
    "emmaigrîmes": ("emmaigrir",),
    "emmaigrira": ("emmaigrir",),
    "emmaigriraient": ("emmaigrir",),
    "emmaigrirai": ("emmaigrir",),
    "emmaigrirais": ("emmaigrir",),
    "emmaigrirait": ("emmaigrir",),
    "emmaigriras": ("emmaigrir",),
    "emmaigrirent": ("emmaigrir",),
    "emmaigrirez": ("emmaigrir",),
    "emmaigririez": ("emmaigrir",),
    "emmaigririons": ("emmaigrir",),
    "emmaigrirons": ("emmaigrir",),
    "emmaigriront": ("emmaigrir",),
    "emmaigris": ("emmaigrir",),
    "emmaigrissaient": ("emmaigrir",),
    "emmaigrissais": ("emmaigrir",),
    "emmaigrissait": ("emmaigrir",),
    "emmaigrissant": ("emmaigrir",),
    "emmaigrissent": ("emmaigrir",),
    "emmaigrisse": ("emmaigrir",),
    "emmaigrisses": ("emmaigrir",),
    "emmaigrissez": ("emmaigrir",),
    "emmaigrissiez": ("emmaigrir",),
    "emmaigrissions": ("emmaigrir",),
    "emmaigrissons": ("emmaigrir",),
    "emmaigrîtes": ("emmaigrir",),
    "emmaigrit": ("emmaigrir",),
    "emmaigrît": ("emmaigrir",),
    "emmaliçaient": ("emmalicer",),
    "emmaliçai": ("emmalicer",),
    "emmaliçais": ("emmalicer",),
    "emmaliçait": ("emmalicer",),
    "emmaliça": ("emmalicer",),
    "emmaliçâmes": ("emmalicer",),
    "emmaliçant": ("emmalicer",),
    "emmaliças": ("emmalicer",),
    "emmaliçassent": ("emmalicer",),
    "emmaliçasses": ("emmalicer",),
    "emmaliçasse": ("emmalicer",),
    "emmaliçassiez": ("emmalicer",),
    "emmaliçassions": ("emmalicer",),
    "emmaliçâtes": ("emmalicer",),
    "emmaliçât": ("emmalicer",),
    "emmalicée": ("emmalicer",),
    "emmalicées": ("emmalicer",),
    "emmalicé": ("emmalicer",),
    "emmalicent": ("emmalicer",),
    "emmalice": ("emmalicer",),
    "emmalicera": ("emmalicer",),
    "emmaliceraient": ("emmalicer",),
    "emmalicerai": ("emmalicer",),
    "emmalicerais": ("emmalicer",),
    "emmalicerait": ("emmalicer",),
    "emmaliceras": ("emmalicer",),
    "emmalicèrent": ("emmalicer",),
    "emmalicerez": ("emmalicer",),
    "emmaliceriez": ("emmalicer",),
    "emmalicerions": ("emmalicer",),
    "emmalicerons": ("emmalicer",),
    "emmaliceront": ("emmalicer",),
    "emmalicés": ("emmalicer",),
    "emmalices": ("emmalicer",),
    "emmalicez": ("emmalicer",),
    "emmaliciez": ("emmalicer",),
    "emmalicions": ("emmalicer",),
    "emmaliçons": ("emmalicer",),
    "emmantelaient": ("emmanteler",),
    "emmantelai": ("emmanteler",),
    "emmantelais": ("emmanteler",),
    "emmantelait": ("emmanteler",),
    "emmantela": ("emmanteler",),
    "emmantelâmes": ("emmanteler",),
    "emmantelant": ("emmanteler",),
    "emmantelas": ("emmanteler",),
    "emmantelassent": ("emmanteler",),
    "emmantelasses": ("emmanteler",),
    "emmantelasse": ("emmanteler",),
    "emmantelassiez": ("emmanteler",),
    "emmantelassions": ("emmanteler",),
    "emmantelâtes": ("emmanteler",),
    "emmantelât": ("emmanteler",),
    "emmantelée": ("emmanteler",),
    "emmantelées": ("emmanteler",),
    "emmantelé": ("emmanteler",),
    "emmantèlent": ("emmanteler",),
    "emmantèle": ("emmanteler",),
    "emmantèlera": ("emmanteler",),
    "emmantèleraient": ("emmanteler",),
    "emmantèlerai": ("emmanteler",),
    "emmantèlerais": ("emmanteler",),
    "emmantèlerait": ("emmanteler",),
    "emmantèleras": ("emmanteler",),
    "emmantelèrent": ("emmanteler",),
    "emmantèlerez": ("emmanteler",),
    "emmantèleriez": ("emmanteler",),
    "emmantèlerions": ("emmanteler",),
    "emmantèlerons": ("emmanteler",),
    "emmantèleront": ("emmanteler",),
    "emmantelés": ("emmanteler",),
    "emmantèles": ("emmanteler",),
    "emmantelez": ("emmanteler",),
    "emmanteliez": ("emmanteler",),
    "emmantelions": ("emmanteler",),
    "emmantelons": ("emmanteler",),
    "emmargeaient": ("emmarger",),
    "emmargeai": ("emmarger",),
    "emmargeais": ("emmarger",),
    "emmargeait": ("emmarger",),
    "emmargea": ("emmarger",),
    "emmargeâmes": ("emmarger",),
    "emmargeant": ("emmarger",),
    "emmargeas": ("emmarger",),
    "emmargeassent": ("emmarger",),
    "emmargeasses": ("emmarger",),
    "emmargeasse": ("emmarger",),
    "emmargeassiez": ("emmarger",),
    "emmargeassions": ("emmarger",),
    "emmargeâtes": ("emmarger",),
    "emmargeât": ("emmarger",),
    "emmargée": ("emmarger",),
    "emmargées": ("emmarger",),
    "emmargé": ("emmarger",),
    "emmargent": ("emmarger",),
    "emmargeons": ("emmarger",),
    "emmarge": ("emmarger",),
    "emmargera": ("emmarger",),
    "emmargeraient": ("emmarger",),
    "emmargerai": ("emmarger",),
    "emmargerais": ("emmarger",),
    "emmargerait": ("emmarger",),
    "emmargeras": ("emmarger",),
    "emmargèrent": ("emmarger",),
    "emmargerez": ("emmarger",),
    "emmargeriez": ("emmarger",),
    "emmargerions": ("emmarger",),
    "emmargerons": ("emmarger",),
    "emmargeront": ("emmarger",),
    "emmargés": ("emmarger",),
    "emmarges": ("emmarger",),
    "emmargez": ("emmarger",),
    "emmargiez": ("emmarger",),
    "emmargions": ("emmarger",),
    "emménageaient": ("emménager",),
    "emménageai": ("emménager",),
    "emménageais": ("emménager",),
    "emménageait": ("emménager",),
    "emménagea": ("emménager",),
    "emménageâmes": ("emménager",),
    "emménageant": ("emménager",),
    "emménageas": ("emménager",),
    "emménageassent": ("emménager",),
    "emménageasses": ("emménager",),
    "emménageasse": ("emménager",),
    "emménageassiez": ("emménager",),
    "emménageassions": ("emménager",),
    "emménageâtes": ("emménager",),
    "emménageât": ("emménager",),
    "emménagée": ("emménager",),
    "emménagées": ("emménager",),
    "emménagé": ("emménager",),
    "emménagent": ("emménager",),
    "emménageons": ("emménager",),
    "emménage": ("emménager",),
    "emménagera": ("emménager",),
    "emménageraient": ("emménager",),
    "emménagerai": ("emménager",),
    "emménagerais": ("emménager",),
    "emménagerait": ("emménager",),
    "emménageras": ("emménager",),
    "emménagèrent": ("emménager",),
    "emménagerez": ("emménager",),
    "emménageriez": ("emménager",),
    "emménagerions": ("emménager",),
    "emménagerons": ("emménager",),
    "emménageront": ("emménager",),
    "emménagés": ("emménager",),
    "emménages": ("emménager",),
    "emménagez": ("emménager",),
    "emménagiez": ("emménager",),
    "emménagions": ("emménager",),
    "emmenaient": ("emmener",),
    "emmenai": ("emmener",),
    "emmenais": ("emmener",),
    "emmenait": ("emmener",),
    "emmena": ("emmener",),
    "emmenâmes": ("emmener",),
    "emmenant": ("emmener",),
    "emmenas": ("emmener",),
    "emmenassent": ("emmener",),
    "emmenasses": ("emmener",),
    "emmenasse": ("emmener",),
    "emmenassiez": ("emmener",),
    "emmenassions": ("emmener",),
    "emmenâtes": ("emmener",),
    "emmenât": ("emmener",),
    "emmenée": ("emmener",),
    "emmenées": ("emmener",),
    "emmené": ("emmener",),
    "emmènent": ("emmener",),
    "emmène": ("emmener",),
    "emmènera": ("emmener",),
    "emmèneraient": ("emmener",),
    "emmènerai": ("emmener",),
    "emmènerais": ("emmener",),
    "emmènerait": ("emmener",),
    "emmèneras": ("emmener",),
    "emmenèrent": ("emmener",),
    "emmènerez": ("emmener",),
    "emmèneriez": ("emmener",),
    "emmènerions": ("emmener",),
    "emmènerons": ("emmener",),
    "emmèneront": ("emmener",),
    "emmenés": ("emmener",),
    "emmènes": ("emmener",),
    "emmenez": ("emmener",),
    "emmeniez": ("emmener",),
    "emmenions": ("emmener",),
    "emmenons": ("emmener",),
    "emmétraient": ("emmétrer",),
    "emmétrai": ("emmétrer",),
    "emmétrais": ("emmétrer",),
    "emmétrait": ("emmétrer",),
    "emmétra": ("emmétrer",),
    "emmétrâmes": ("emmétrer",),
    "emmétrant": ("emmétrer",),
    "emmétras": ("emmétrer",),
    "emmétrassent": ("emmétrer",),
    "emmétrasses": ("emmétrer",),
    "emmétrasse": ("emmétrer",),
    "emmétrassiez": ("emmétrer",),
    "emmétrassions": ("emmétrer",),
    "emmétrâtes": ("emmétrer",),
    "emmétrât": ("emmétrer",),
    "emmétrée": ("emmétrer",),
    "emmétrées": ("emmétrer",),
    "emmétré": ("emmétrer",),
    "emmètrent": ("emmétrer",),
    "emmètre": ("emmétrer",),
    "emmétrera": ("emmétrer",),
    "emmétreraient": ("emmétrer",),
    "emmétrerai": ("emmétrer",),
    "emmétrerais": ("emmétrer",),
    "emmétrerait": ("emmétrer",),
    "emmétreras": ("emmétrer",),
    "emmétrèrent": ("emmétrer",),
    "emmétrerez": ("emmétrer",),
    "emmétreriez": ("emmétrer",),
    "emmétrerions": ("emmétrer",),
    "emmétrerons": ("emmétrer",),
    "emmétreront": ("emmétrer",),
    "emmétrés": ("emmétrer",),
    "emmètres": ("emmétrer",),
    "emmétrez": ("emmétrer",),
    "emmétriez": ("emmétrer",),
    "emmétrions": ("emmétrer",),
    "emmétrons": ("emmétrer",),
    "emmiélaient": ("emmiéler",),
    "emmiélai": ("emmiéler",),
    "emmiélais": ("emmiéler",),
    "emmiélait": ("emmiéler",),
    "emmiéla": ("emmiéler",),
    "emmiélâmes": ("emmiéler",),
    "emmiélant": ("emmiéler",),
    "emmiélas": ("emmiéler",),
    "emmiélassent": ("emmiéler",),
    "emmiélasses": ("emmiéler",),
    "emmiélasse": ("emmiéler",),
    "emmiélassiez": ("emmiéler",),
    "emmiélassions": ("emmiéler",),
    "emmiélâtes": ("emmiéler",),
    "emmiélât": ("emmiéler",),
    "emmiélée": ("emmiéler",),
    "emmiélées": ("emmiéler",),
    "emmiélé": ("emmiéler",),
    "emmièlent": ("emmiéler",),
    "emmièle": ("emmiéler",),
    "emmiélera": ("emmiéler",),
    "emmiéleraient": ("emmiéler",),
    "emmiélerai": ("emmiéler",),
    "emmiélerais": ("emmiéler",),
    "emmiélerait": ("emmiéler",),
    "emmiéleras": ("emmiéler",),
    "emmiélèrent": ("emmiéler",),
    "emmiélerez": ("emmiéler",),
    "emmiéleriez": ("emmiéler",),
    "emmiélerions": ("emmiéler",),
    "emmiélerons": ("emmiéler",),
    "emmiéleront": ("emmiéler",),
    "emmiélés": ("emmiéler",),
    "emmièles": ("emmiéler",),
    "emmiélez": ("emmiéler",),
    "emmiéliez": ("emmiéler",),
    "emmiélions": ("emmiéler",),
    "emmiélons": ("emmiéler",),
    "emmuselaient": ("emmuseler",),
    "emmuselai": ("emmuseler",),
    "emmuselais": ("emmuseler",),
    "emmuselait": ("emmuseler",),
    "emmusela": ("emmuseler",),
    "emmuselâmes": ("emmuseler",),
    "emmuselant": ("emmuseler",),
    "emmuselas": ("emmuseler",),
    "emmuselassent": ("emmuseler",),
    "emmuselasses": ("emmuseler",),
    "emmuselasse": ("emmuseler",),
    "emmuselassiez": ("emmuseler",),
    "emmuselassions": ("emmuseler",),
    "emmuselâtes": ("emmuseler",),
    "emmuselât": ("emmuseler",),
    "emmuselée": ("emmuseler",),
    "emmuselées": ("emmuseler",),
    "emmuselé": ("emmuseler",),
    "emmuselèrent": ("emmuseler",),
    "emmuselés": ("emmuseler",),
    "emmuselez": ("emmuseler",),
    "emmuseliez": ("emmuseler",),
    "emmuselions": ("emmuseler",),
    "emmusellent": ("emmuseler",),
    "emmuselle": ("emmuseler",),
    "emmusellera": ("emmuseler",),
    "emmuselleraient": ("emmuseler",),
    "emmusellerai": ("emmuseler",),
    "emmusellerais": ("emmuseler",),
    "emmusellerait": ("emmuseler",),
    "emmuselleras": ("emmuseler",),
    "emmusellerez": ("emmuseler",),
    "emmuselleriez": ("emmuseler",),
    "emmusellerions": ("emmuseler",),
    "emmusellerons": ("emmuseler",),
    "emmuselleront": ("emmuseler",),
    "emmuselles": ("emmuseler",),
    "emmuselons": ("emmuseler",),
    "émouchetaient": ("émoucheter",),
    "émouchetai": ("émoucheter",),
    "émouchetais": ("émoucheter",),
    "émouchetait": ("émoucheter",),
    "émoucheta": ("émoucheter",),
    "émouchetâmes": ("émoucheter",),
    "émouchetant": ("émoucheter",),
    "émouchetas": ("émoucheter",),
    "émouchetassent": ("émoucheter",),
    "émouchetasses": ("émoucheter",),
    "émouchetasse": ("émoucheter",),
    "émouchetassiez": ("émoucheter",),
    "émouchetassions": ("émoucheter",),
    "émouchetâtes": ("émoucheter",),
    "émouchetât": ("émoucheter",),
    "émouchetée": ("émoucheter",),
    "émouchetées": ("émoucheter",),
    "émoucheté": ("émoucheter",),
    "émouchetèrent": ("émoucheter",),
    "émouchetés": ("émoucheter",),
    "émouchetez": ("émoucheter",),
    "émouchetiez": ("émoucheter",),
    "émouchetions": ("émoucheter",),
    "émouchetons": ("émoucheter",),
    "émouchettent": ("émoucheter",),
    "émouchette": ("émoucheter",),
    "émouchettera": ("émoucheter",),
    "émouchetteraient": ("émoucheter",),
    "émouchetterai": ("émoucheter",),
    "émouchetterais": ("émoucheter",),
    "émouchetterait": ("émoucheter",),
    "émouchetteras": ("émoucheter",),
    "émouchetterez": ("émoucheter",),
    "émouchetteriez": ("émoucheter",),
    "émouchetterions": ("émoucheter",),
    "émouchetterons": ("émoucheter",),
    "émouchetteront": ("émoucheter",),
    "émouchettes": ("émoucheter",),
    "émoud": ("émoudre",),
    "émoudra": ("émoudre",),
    "émoudraient": ("émoudre",),
    "émoudrai": ("émoudre",),
    "émoudrais": ("émoudre",),
    "émoudrait": ("émoudre",),
    "émoudras": ("émoudre",),
    "émoudrez": ("émoudre",),
    "émoudriez": ("émoudre",),
    "émoudrions": ("émoudre",),
    "émoudrons": ("émoudre",),
    "émoudront": ("émoudre",),
    "émouds": ("émoudre",),
    "émoulaient": ("émoudre",),
    "émoulais": ("émoudre",),
    "émoulait": ("émoudre",),
    "émoulant": ("émoudre",),
    "émoulent": ("émoudre",),
    "émoule": ("émoudre",),
    "émoules": ("émoudre",),
    "émoulez": ("émoudre",),
    "émouliez": ("émoudre",),
    "émoulions": ("émoudre",),
    "émoulons": ("émoudre",),
    "émoulue": ("émoudre",),
    "émoulues": ("émoudre",),
    "émoulu": ("émoudre",),
    "émoulûmes": ("émoudre",),
    "émoulurent": ("émoudre",),
    "émoulus": ("émoudre",),
    "émoulussent": ("émoudre",),
    "émoulusses": ("émoudre",),
    "émoulusse": ("émoudre",),
    "émoulussiez": ("émoudre",),
    "émoulussions": ("émoudre",),
    "émoulûtes": ("émoudre",),
    "émoulut": ("émoudre",),
    "émoulût": ("émoudre",),
    "émeus": ("émouvoir",),
    "émeut": ("émouvoir",),
    "émeuvent": ("émouvoir",),
    "émeuve": ("émouvoir",),
    "émeuves": ("émouvoir",),
    "émouvaient": ("émouvoir",),
    "émouvais": ("émouvoir",),
    "émouvait": ("émouvoir",),
    "émouvant": ("émouvoir",),
    "émouvez": ("émouvoir",),
    "émouviez": ("émouvoir",),
    "émouvions": ("émouvoir",),
    "émouvons": ("émouvoir",),
    "émouvra": ("émouvoir",),
    "émouvraient": ("émouvoir",),
    "émouvrai": ("émouvoir",),
    "émouvrais": ("émouvoir",),
    "émouvrait": ("émouvoir",),
    "émouvras": ("émouvoir",),
    "émouvrez": ("émouvoir",),
    "émouvriez": ("émouvoir",),
    "émouvrions": ("émouvoir",),
    "émouvrons": ("émouvoir",),
    "émouvront": ("émouvoir",),
    "émue": ("émouvoir",),
    "émues": ("émouvoir",),
    "ému": ("émouvoir",),
    "émûmes": ("émouvoir",),
    "émurent": ("émouvoir",),
    "émus": ("émouvoir",),
    "émussent": ("émouvoir",),
    "émusses": ("émouvoir",),
    "émusse": ("émouvoir",),
    "émussiez": ("émouvoir",),
    "émussions": ("émouvoir",),
    "émûtes": ("émouvoir",),
    "émut": ("émouvoir",),
    "émût": ("émouvoir",),
    "empaquetaient": ("empaqueter",),
    "empaquetai": ("empaqueter",),
    "empaquetais": ("empaqueter",),
    "empaquetait": ("empaqueter",),
    "empaqueta": ("empaqueter",),
    "empaquetâmes": ("empaqueter",),
    "empaquetant": ("empaqueter",),
    "empaquetas": ("empaqueter",),
    "empaquetassent": ("empaqueter",),
    "empaquetasses": ("empaqueter",),
    "empaquetasse": ("empaqueter",),
    "empaquetassiez": ("empaqueter",),
    "empaquetassions": ("empaqueter",),
    "empaquetâtes": ("empaqueter",),
    "empaquetât": ("empaqueter",),
    "empaquetée": ("empaqueter",),
    "empaquetées": ("empaqueter",),
    "empaqueté": ("empaqueter",),
    "empaquetèrent": ("empaqueter",),
    "empaquetés": ("empaqueter",),
    "empaquetez": ("empaqueter",),
    "empaquetiez": ("empaqueter",),
    "empaquetions": ("empaqueter",),
    "empaquetons": ("empaqueter",),
    "empaquettent": ("empaqueter",),
    "empaquette": ("empaqueter",),
    "empaquettera": ("empaqueter",),
    "empaquetteraient": ("empaqueter",),
    "empaquetterai": ("empaqueter",),
    "empaquetterais": ("empaqueter",),
    "empaquetterait": ("empaqueter",),
    "empaquetteras": ("empaqueter",),
    "empaquetterez": ("empaqueter",),
    "empaquetteriez": ("empaqueter",),
    "empaquetterions": ("empaqueter",),
    "empaquetterons": ("empaqueter",),
    "empaquetteront": ("empaqueter",),
    "empaquettes": ("empaqueter",),
    "empâtaient": ("empâter",),
    "empâtai": ("empâter",),
    "empâtais": ("empâter",),
    "empâtait": ("empâter",),
    "empâta": ("empâter",),
    "empâtâmes": ("empâter",),
    "empâtant": ("empâter",),
    "empâtas": ("empâter",),
    "empâtassent": ("empâter",),
    "empâtasses": ("empâter",),
    "empâtasse": ("empâter",),
    "empâtassiez": ("empâter",),
    "empâtassions": ("empâter",),
    "empâtâtes": ("empâter",),
    "empâtât": ("empâter",),
    "empâtée": ("empâter",),
    "empâtées": ("empâter",),
    "empâté": ("empâter",),
    "empâtent": ("empâter",),
    "empâte": ("empâter",),
    "empâtera": ("empâter",),
    "empâteraient": ("empâter",),
    "empâterai": ("empâter",),
    "empâterais": ("empâter",),
    "empâterait": ("empâter",),
    "empâteras": ("empâter",),
    "empâtèrent": ("empâter",),
    "empâterez": ("empâter",),
    "empâteriez": ("empâter",),
    "empâterions": ("empâter",),
    "empâterons": ("empâter",),
    "empâteront": ("empâter",),
    "empâtés": ("empâter",),
    "empâtes": ("empâter",),
    "empâtez": ("empâter",),
    "empâtiez": ("empâter",),
    "empâtions": ("empâter",),
    "empâtons": ("empâter",),
    "empennelaient": ("empenneler",),
    "empennelai": ("empenneler",),
    "empennelais": ("empenneler",),
    "empennelait": ("empenneler",),
    "empennela": ("empenneler",),
    "empennelâmes": ("empenneler",),
    "empennelant": ("empenneler",),
    "empennelas": ("empenneler",),
    "empennelassent": ("empenneler",),
    "empennelasses": ("empenneler",),
    "empennelasse": ("empenneler",),
    "empennelassiez": ("empenneler",),
    "empennelassions": ("empenneler",),
    "empennelâtes": ("empenneler",),
    "empennelât": ("empenneler",),
    "empennelée": ("empenneler",),
    "empennelées": ("empenneler",),
    "empennelé": ("empenneler",),
    "empennelèrent": ("empenneler",),
    "empennelés": ("empenneler",),
    "empennelez": ("empenneler",),
    "empenneliez": ("empenneler",),
    "empennelions": ("empenneler",),
    "empennellent": ("empenneler",),
    "empennelle": ("empenneler",),
    "empennellera": ("empenneler",),
    "empennelleraient": ("empenneler",),
    "empennellerai": ("empenneler",),
    "empennellerais": ("empenneler",),
    "empennellerait": ("empenneler",),
    "empennelleras": ("empenneler",),
    "empennellerez": ("empenneler",),
    "empennelleriez": ("empenneler",),
    "empennellerions": ("empenneler",),
    "empennellerons": ("empenneler",),
    "empennelleront": ("empenneler",),
    "empennelles": ("empenneler",),
    "empennelons": ("empenneler",),
    "empesaient": ("empeser",),
    "empesai": ("empeser",),
    "empesais": ("empeser",),
    "empesait": ("empeser",),
    "empesa": ("empeser",),
    "empesâmes": ("empeser",),
    "empesant": ("empeser",),
    "empesas": ("empeser",),
    "empesassent": ("empeser",),
    "empesasses": ("empeser",),
    "empesasse": ("empeser",),
    "empesassiez": ("empeser",),
    "empesassions": ("empeser",),
    "empesâtes": ("empeser",),
    "empesât": ("empeser",),
    "empesée": ("empeser",),
    "empesées": ("empeser",),
    "empesé": ("empeser",),
    "empèsent": ("empeser",),
    "empèse": ("empeser",),
    "empèsera": ("empeser",),
    "empèseraient": ("empeser",),
    "empèserai": ("empeser",),
    "empèserais": ("empeser",),
    "empèserait": ("empeser",),
    "empèseras": ("empeser",),
    "empesèrent": ("empeser",),
    "empèserez": ("empeser",),
    "empèseriez": ("empeser",),
    "empèserions": ("empeser",),
    "empèserons": ("empeser",),
    "empèseront": ("empeser",),
    "empesés": ("empeser",),
    "empèses": ("empeser",),
    "empesez": ("empeser",),
    "empesiez": ("empeser",),
    "empesions": ("empeser",),
    "empesons": ("empeser",),
    "empiégeaient": ("empiéger",),
    "empiégeai": ("empiéger",),
    "empiégeais": ("empiéger",),
    "empiégeait": ("empiéger",),
    "empiégea": ("empiéger",),
    "empiégeâmes": ("empiéger",),
    "empiégeant": ("empiéger",),
    "empiégeas": ("empiéger",),
    "empiégeassent": ("empiéger",),
    "empiégeasses": ("empiéger",),
    "empiégeasse": ("empiéger",),
    "empiégeassiez": ("empiéger",),
    "empiégeassions": ("empiéger",),
    "empiégeâtes": ("empiéger",),
    "empiégeât": ("empiéger",),
    "empiégée": ("empiéger",),
    "empiégées": ("empiéger",),
    "empiégé": ("empiéger",),
    "empiègent": ("empiéger",),
    "empiégeons": ("empiéger",),
    "empiège": ("empiéger",),
    "empiégera": ("empiéger",),
    "empiégeraient": ("empiéger",),
    "empiégerai": ("empiéger",),
    "empiégerais": ("empiéger",),
    "empiégerait": ("empiéger",),
    "empiégeras": ("empiéger",),
    "empiégèrent": ("empiéger",),
    "empiégerez": ("empiéger",),
    "empiégeriez": ("empiéger",),
    "empiégerions": ("empiéger",),
    "empiégerons": ("empiéger",),
    "empiégeront": ("empiéger",),
    "empiégés": ("empiéger",),
    "empièges": ("empiéger",),
    "empiégez": ("empiéger",),
    "empiégiez": ("empiéger",),
    "empiégions": ("empiéger",),
    "empiétaient": ("empiéter",),
    "empiétai": ("empiéter",),
    "empiétais": ("empiéter",),
    "empiétait": ("empiéter",),
    "empiéta": ("empiéter",),
    "empiétâmes": ("empiéter",),
    "empiétant": ("empiéter",),
    "empiétas": ("empiéter",),
    "empiétassent": ("empiéter",),
    "empiétasses": ("empiéter",),
    "empiétasse": ("empiéter",),
    "empiétassiez": ("empiéter",),
    "empiétassions": ("empiéter",),
    "empiétâtes": ("empiéter",),
    "empiétât": ("empiéter",),
    "empiété": ("empiéter",),
    "empiètent": ("empiéter",),
    "empiète": ("empiéter",),
    "empiétera": ("empiéter",),
    "empiéteraient": ("empiéter",),
    "empiéterai": ("empiéter",),
    "empiéterais": ("empiéter",),
    "empiéterait": ("empiéter",),
    "empiéteras": ("empiéter",),
    "empiétèrent": ("empiéter",),
    "empiéterez": ("empiéter",),
    "empiéteriez": ("empiéter",),
    "empiéterions": ("empiéter",),
    "empiéterons": ("empiéter",),
    "empiéteront": ("empiéter",),
    "empiètes": ("empiéter",),
    "empiétez": ("empiéter",),
    "empiétiez": ("empiéter",),
    "empiétions": ("empiéter",),
    "empiétons": ("empiéter",),
    "emplie": ("emplir",),
    "emplies": ("emplir",),
    "empli": ("emplir",),
    "emplîmes": ("emplir",),
    "emplira": ("emplir",),
    "empliraient": ("emplir",),
    "emplirai": ("emplir",),
    "emplirais": ("emplir",),
    "emplirait": ("emplir",),
    "empliras": ("emplir",),
    "emplirent": ("emplir",),
    "emplirez": ("emplir",),
    "empliriez": ("emplir",),
    "emplirions": ("emplir",),
    "emplirons": ("emplir",),
    "empliront": ("emplir",),
    "emplis": ("emplir",),
    "emplissaient": ("emplir",),
    "emplissais": ("emplir",),
    "emplissait": ("emplir",),
    "emplissant": ("emplir",),
    "emplissent": ("emplir",),
    "emplisse": ("emplir",),
    "emplisses": ("emplir",),
    "emplissez": ("emplir",),
    "emplissiez": ("emplir",),
    "emplissions": ("emplir",),
    "emplissons": ("emplir",),
    "emplîtes": ("emplir",),
    "emplit": ("emplir",),
    "emplît": ("emplir",),
    "emploient": ("employer",),
    "emploie": ("employer",),
    "emploiera": ("employer",),
    "emploieraient": ("employer",),
    "emploierai": ("employer",),
    "emploierais": ("employer",),
    "emploierait": ("employer",),
    "emploieras": ("employer",),
    "emploierez": ("employer",),
    "emploieriez": ("employer",),
    "emploierions": ("employer",),
    "emploierons": ("employer",),
    "emploieront": ("employer",),
    "emploies": ("employer",),
    "employaient": ("employer",),
    "employai": ("employer",),
    "employais": ("employer",),
    "employait": ("employer",),
    "employa": ("employer",),
    "employâmes": ("employer",),
    "employant": ("employer",),
    "employas": ("employer",),
    "employassent": ("employer",),
    "employasses": ("employer",),
    "employasse": ("employer",),
    "employassiez": ("employer",),
    "employassions": ("employer",),
    "employâtes": ("employer",),
    "employât": ("employer",),
    "employée": ("employer",),
    "employées": ("employer",),
    "employé": ("employer",),
    "employèrent": ("employer",),
    "employés": ("employer",),
    "employez": ("employer",),
    "employiez": ("employer",),
    "employions": ("employer",),
    "employons": ("employer",),
    "empoussiéraient": ("empoussiérer",),
    "empoussiérai": ("empoussiérer",),
    "empoussiérais": ("empoussiérer",),
    "empoussiérait": ("empoussiérer",),
    "empoussiéra": ("empoussiérer",),
    "empoussiérâmes": ("empoussiérer",),
    "empoussiérant": ("empoussiérer",),
    "empoussiéras": ("empoussiérer",),
    "empoussiérassent": ("empoussiérer",),
    "empoussiérasses": ("empoussiérer",),
    "empoussiérasse": ("empoussiérer",),
    "empoussiérassiez": ("empoussiérer",),
    "empoussiérassions": ("empoussiérer",),
    "empoussiérâtes": ("empoussiérer",),
    "empoussiérât": ("empoussiérer",),
    "empoussiérée": ("empoussiérer",),
    "empoussiérées": ("empoussiérer",),
    "empoussiéré": ("empoussiérer",),
    "empoussièrent": ("empoussiérer",),
    "empoussière": ("empoussiérer",),
    "empoussiérera": ("empoussiérer",),
    "empoussiéreraient": ("empoussiérer",),
    "empoussiérerai": ("empoussiérer",),
    "empoussiérerais": ("empoussiérer",),
    "empoussiérerait": ("empoussiérer",),
    "empoussiéreras": ("empoussiérer",),
    "empoussiérèrent": ("empoussiérer",),
    "empoussiérerez": ("empoussiérer",),
    "empoussiéreriez": ("empoussiérer",),
    "empoussiérerions": ("empoussiérer",),
    "empoussiérerons": ("empoussiérer",),
    "empoussiéreront": ("empoussiérer",),
    "empoussiérés": ("empoussiérer",),
    "empoussières": ("empoussiérer",),
    "empoussiérez": ("empoussiérer",),
    "empoussiériez": ("empoussiérer",),
    "empoussiérions": ("empoussiérer",),
    "empoussiérons": ("empoussiérer",),
    "empreignaient": ("empreindre",),
    "empreignais": ("empreindre",),
    "empreignait": ("empreindre",),
    "empreignant": ("empreindre",),
    "empreignent": ("empreindre",),
    "empreigne": ("empreindre",),
    "empreignes": ("empreindre",),
    "empreignez": ("empreindre",),
    "empreigniez": ("empreindre",),
    "empreignîmes": ("empreindre",),
    "empreignions": ("empreindre",),
    "empreignirent": ("empreindre",),
    "empreignis": ("empreindre",),
    "empreignissent": ("empreindre",),
    "empreignisses": ("empreindre",),
    "empreignisse": ("empreindre",),
    "empreignissiez": ("empreindre",),
    "empreignissions": ("empreindre",),
    "empreignîtes": ("empreindre",),
    "empreignit": ("empreindre",),
    "empreignît": ("empreindre",),
    "empreignons": ("empreindre",),
    "empreindra": ("empreindre",),
    "empreindraient": ("empreindre",),
    "empreindrai": ("empreindre",),
    "empreindrais": ("empreindre",),
    "empreindrait": ("empreindre",),
    "empreindras": ("empreindre",),
    "empreindrez": ("empreindre",),
    "empreindriez": ("empreindre",),
    "empreindrions": ("empreindre",),
    "empreindrons": ("empreindre",),
    "empreindront": ("empreindre",),
    "empreins": ("empreindre",),
    "empreinte": ("empreindre",),
    "empreintes": ("empreindre",),
    "empreint": ("empreindre",),
    "empreints": ("empreindre",),
    "empuantie": ("empuantir",),
    "empuanties": ("empuantir",),
    "empuanti": ("empuantir",),
    "empuantîmes": ("empuantir",),
    "empuantira": ("empuantir",),
    "empuantiraient": ("empuantir",),
    "empuantirai": ("empuantir",),
    "empuantirais": ("empuantir",),
    "empuantirait": ("empuantir",),
    "empuantiras": ("empuantir",),
    "empuantirent": ("empuantir",),
    "empuantirez": ("empuantir",),
    "empuantiriez": ("empuantir",),
    "empuantirions": ("empuantir",),
    "empuantirons": ("empuantir",),
    "empuantiront": ("empuantir",),
    "empuantis": ("empuantir",),
    "empuantissaient": ("empuantir",),
    "empuantissais": ("empuantir",),
    "empuantissait": ("empuantir",),
    "empuantissant": ("empuantir",),
    "empuantissent": ("empuantir",),
    "empuantisse": ("empuantir",),
    "empuantisses": ("empuantir",),
    "empuantissez": ("empuantir",),
    "empuantissiez": ("empuantir",),
    "empuantissions": ("empuantir",),
    "empuantissons": ("empuantir",),
    "empuantîtes": ("empuantir",),
    "empuantit": ("empuantir",),
    "empuantît": ("empuantir",),
    "émulsifiaient": ("émulsifier",),
    "émulsifiai": ("émulsifier",),
    "émulsifiais": ("émulsifier",),
    "émulsifiait": ("émulsifier",),
    "émulsifia": ("émulsifier",),
    "émulsifiâmes": ("émulsifier",),
    "émulsifiant": ("émulsifier",),
    "émulsifias": ("émulsifier",),
    "émulsifiassent": ("émulsifier",),
    "émulsifiasses": ("émulsifier",),
    "émulsifiasse": ("émulsifier",),
    "émulsifiassiez": ("émulsifier",),
    "émulsifiassions": ("émulsifier",),
    "émulsifiâtes": ("émulsifier",),
    "émulsifiât": ("émulsifier",),
    "émulsifiée": ("émulsifier",),
    "émulsifiées": ("émulsifier",),
    "émulsifié": ("émulsifier",),
    "émulsifient": ("émulsifier",),
    "émulsifie": ("émulsifier",),
    "émulsifiera": ("émulsifier",),
    "émulsifieraient": ("émulsifier",),
    "émulsifierai": ("émulsifier",),
    "émulsifierais": ("émulsifier",),
    "émulsifierait": ("émulsifier",),
    "émulsifieras": ("émulsifier",),
    "émulsifièrent": ("émulsifier",),
    "émulsifierez": ("émulsifier",),
    "émulsifieriez": ("émulsifier",),
    "émulsifierions": ("émulsifier",),
    "émulsifierons": ("émulsifier",),
    "émulsifieront": ("émulsifier",),
    "émulsifiés": ("émulsifier",),
    "émulsifies": ("émulsifier",),
    "émulsifiez": ("émulsifier",),
    "émulsifiiez": ("émulsifier",),
    "émulsifiions": ("émulsifier",),
    "émulsifions": ("émulsifier",),
    "encageaient": ("encager",),
    "encageai": ("encager",),
    "encageais": ("encager",),
    "encageait": ("encager",),
    "encagea": ("encager",),
    "encageâmes": ("encager",),
    "encageant": ("encager",),
    "encageas": ("encager",),
    "encageassent": ("encager",),
    "encageasses": ("encager",),
    "encageasse": ("encager",),
    "encageassiez": ("encager",),
    "encageassions": ("encager",),
    "encageâtes": ("encager",),
    "encageât": ("encager",),
    "encagée": ("encager",),
    "encagées": ("encager",),
    "encagé": ("encager",),
    "encagent": ("encager",),
    "encageons": ("encager",),
    "encage": ("encager",),
    "encagera": ("encager",),
    "encageraient": ("encager",),
    "encagerai": ("encager",),
    "encagerais": ("encager",),
    "encagerait": ("encager",),
    "encageras": ("encager",),
    "encagèrent": ("encager",),
    "encagerez": ("encager",),
    "encageriez": ("encager",),
    "encagerions": ("encager",),
    "encagerons": ("encager",),
    "encageront": ("encager",),
    "encagés": ("encager",),
    "encages": ("encager",),
    "encagez": ("encager",),
    "encagiez": ("encager",),
    "encagions": ("encager",),
    "encapriçaient": ("encapricer",),
    "encapriçai": ("encapricer",),
    "encapriçais": ("encapricer",),
    "encapriçait": ("encapricer",),
    "encapriça": ("encapricer",),
    "encapriçâmes": ("encapricer",),
    "encapriçant": ("encapricer",),
    "encapriças": ("encapricer",),
    "encapriçassent": ("encapricer",),
    "encapriçasses": ("encapricer",),
    "encapriçasse": ("encapricer",),
    "encapriçassiez": ("encapricer",),
    "encapriçassions": ("encapricer",),
    "encapriçâtes": ("encapricer",),
    "encapriçât": ("encapricer",),
    "encapricée": ("encapricer",),
    "encapricées": ("encapricer",),
    "encapricé": ("encapricer",),
    "encapricent": ("encapricer",),
    "encaprice": ("encapricer",),
    "encapricera": ("encapricer",),
    "encapriceraient": ("encapricer",),
    "encapricerai": ("encapricer",),
    "encapricerais": ("encapricer",),
    "encapricerait": ("encapricer",),
    "encapriceras": ("encapricer",),
    "encapricèrent": ("encapricer",),
    "encapricerez": ("encapricer",),
    "encapriceriez": ("encapricer",),
    "encapricerions": ("encapricer",),
    "encapricerons": ("encapricer",),
    "encapriceront": ("encapricer",),
    "encapricés": ("encapricer",),
    "encaprices": ("encapricer",),
    "encapricez": ("encapricer",),
    "encapriciez": ("encapricer",),
    "encapricions": ("encapricer",),
    "encapriçons": ("encapricer",),
    "encarassaient": ("encarasser",),
    "encarassai": ("encarasser",),
    "encarassais": ("encarasser",),
    "encarassait": ("encarasser",),
    "encarassa": ("encarasser",),
    "encarassâmes": ("encarasser",),
    "encarassant": ("encarasser",),
    "encarassas": ("encarasser",),
    "encarassassent": ("encarasser",),
    "encarassasses": ("encarasser",),
    "encarassasse": ("encarasser",),
    "encarassassiez": ("encarasser",),
    "encarassassions": ("encarasser",),
    "encarassâtes": ("encarasser",),
    "encarassât": ("encarasser",),
    "encarassée": ("encarasser",),
    "encarassées": ("encarasser",),
    "encarassé": ("encarasser",),
    "encarassent": ("encarasser",),
    "encarasse": ("encarasser",),
    "encarassera": ("encarasser",),
    "encarasseraient": ("encarasser",),
    "encarasserai": ("encarasser",),
    "encarasserais": ("encarasser",),
    "encarasserait": ("encarasser",),
    "encarasseras": ("encarasser",),
    "encarassèrent": ("encarasser",),
    "encarasserez": ("encarasser",),
    "encarasseriez": ("encarasser",),
    "encarasserions": ("encarasser",),
    "encarasserons": ("encarasser",),
    "encarasseront": ("encarasser",),
    "encarassés": ("encarasser",),
    "encarasses": ("encarasser",),
    "encarassez": ("encarasser",),
    "encarassiez": ("encarasser",),
    "encarassions": ("encarasser",),
    "encarassons": ("encarasser",),
    "encarrassaient": ("encarrasser",),
    "encarrassai": ("encarrasser",),
    "encarrassais": ("encarrasser",),
    "encarrassait": ("encarrasser",),
    "encarrassa": ("encarrasser",),
    "encarrassâmes": ("encarrasser",),
    "encarrassant": ("encarrasser",),
    "encarrassas": ("encarrasser",),
    "encarrassassent": ("encarrasser",),
    "encarrassasses": ("encarrasser",),
    "encarrassasse": ("encarrasser",),
    "encarrassassiez": ("encarrasser",),
    "encarrassassions": ("encarrasser",),
    "encarrassâtes": ("encarrasser",),
    "encarrassât": ("encarrasser",),
    "encarrassée": ("encarrasser",),
    "encarrassées": ("encarrasser",),
    "encarrassé": ("encarrasser",),
    "encarrassent": ("encarrasser",),
    "encarrasse": ("encarrasser",),
    "encarrassera": ("encarrasser",),
    "encarrasseraient": ("encarrasser",),
    "encarrasserai": ("encarrasser",),
    "encarrasserais": ("encarrasser",),
    "encarrasserait": ("encarrasser",),
    "encarrasseras": ("encarrasser",),
    "encarrassèrent": ("encarrasser",),
    "encarrasserez": ("encarrasser",),
    "encarrasseriez": ("encarrasser",),
    "encarrasserions": ("encarrasser",),
    "encarrasserons": ("encarrasser",),
    "encarrasseront": ("encarrasser",),
    "encarrassés": ("encarrasser",),
    "encarrasses": ("encarrasser",),
    "encarrassez": ("encarrasser",),
    "encarrassiez": ("encarrasser",),
    "encarrassions": ("encarrasser",),
    "encarrassons": ("encarrasser",),
    "encastelaient": ("encasteler",),
    "encastelai": ("encasteler",),
    "encastelais": ("encasteler",),
    "encastelait": ("encasteler",),
    "encastela": ("encasteler",),
    "encastelâmes": ("encasteler",),
    "encastelant": ("encasteler",),
    "encastelas": ("encasteler",),
    "encastelassent": ("encasteler",),
    "encastelasses": ("encasteler",),
    "encastelasse": ("encasteler",),
    "encastelassiez": ("encasteler",),
    "encastelassions": ("encasteler",),
    "encastelâtes": ("encasteler",),
    "encastelât": ("encasteler",),
    "encastelée": ("encasteler",),
    "encastelées": ("encasteler",),
    "encastelé": ("encasteler",),
    "encastelèrent": ("encasteler",),
    "encastelés": ("encasteler",),
    "encastelez": ("encasteler",),
    "encasteliez": ("encasteler",),
    "encastelions": ("encasteler",),
    "encastellent": ("encasteler",),
    "encastelle": ("encasteler",),
    "encastellera": ("encasteler",),
    "encastelleraient": ("encasteler",),
    "encastellerai": ("encasteler",),
    "encastellerais": ("encasteler",),
    "encastellerait": ("encasteler",),
    "encastelleras": ("encasteler",),
    "encastellerez": ("encasteler",),
    "encastelleriez": ("encasteler",),
    "encastellerions": ("encasteler",),
    "encastellerons": ("encasteler",),
    "encastelleront": ("encasteler",),
    "encastelles": ("encasteler",),
    "encastelons": ("encasteler",),
    "enceignaient": ("enceindre",),
    "enceignais": ("enceindre",),
    "enceignait": ("enceindre",),
    "enceignant": ("enceindre",),
    "enceignent": ("enceindre",),
    "enceigne": ("enceindre",),
    "enceignes": ("enceindre",),
    "enceignez": ("enceindre",),
    "enceigniez": ("enceindre",),
    "enceignîmes": ("enceindre",),
    "enceignions": ("enceindre",),
    "enceignirent": ("enceindre",),
    "enceignis": ("enceindre",),
    "enceignissent": ("enceindre",),
    "enceignisses": ("enceindre",),
    "enceignisse": ("enceindre",),
    "enceignissiez": ("enceindre",),
    "enceignissions": ("enceindre",),
    "enceignîtes": ("enceindre",),
    "enceignit": ("enceindre",),
    "enceignît": ("enceindre",),
    "enceignons": ("enceindre",),
    "enceindra": ("enceindre",),
    "enceindraient": ("enceindre",),
    "enceindrai": ("enceindre",),
    "enceindrais": ("enceindre",),
    "enceindrait": ("enceindre",),
    "enceindras": ("enceindre",),
    "enceindrez": ("enceindre",),
    "enceindriez": ("enceindre",),
    "enceindrions": ("enceindre",),
    "enceindrons": ("enceindre",),
    "enceindront": ("enceindre",),
    "enceins": ("enceindre",),
    "enceinte": ("enceindre",),
    "enceintes": ("enceindre",),
    "enceint": ("enceindre",),
    "enceints": ("enceindre",),
    "enchargeaient": ("encharger",),
    "enchargeai": ("encharger",),
    "enchargeais": ("encharger",),
    "enchargeait": ("encharger",),
    "enchargea": ("encharger",),
    "enchargeâmes": ("encharger",),
    "enchargeant": ("encharger",),
    "enchargeas": ("encharger",),
    "enchargeassent": ("encharger",),
    "enchargeasses": ("encharger",),
    "enchargeasse": ("encharger",),
    "enchargeassiez": ("encharger",),
    "enchargeassions": ("encharger",),
    "enchargeâtes": ("encharger",),
    "enchargeât": ("encharger",),
    "enchargée": ("encharger",),
    "enchargées": ("encharger",),
    "enchargé": ("encharger",),
    "enchargent": ("encharger",),
    "enchargeons": ("encharger",),
    "encharge": ("encharger",),
    "enchargera": ("encharger",),
    "enchargeraient": ("encharger",),
    "enchargerai": ("encharger",),
    "enchargerais": ("encharger",),
    "enchargerait": ("encharger",),
    "enchargeras": ("encharger",),
    "enchargèrent": ("encharger",),
    "enchargerez": ("encharger",),
    "enchargeriez": ("encharger",),
    "enchargerions": ("encharger",),
    "enchargerons": ("encharger",),
    "enchargeront": ("encharger",),
    "enchargés": ("encharger",),
    "encharges": ("encharger",),
    "enchargez": ("encharger",),
    "enchargiez": ("encharger",),
    "enchargions": ("encharger",),
    "enchastelaient": ("enchasteler",),
    "enchastelai": ("enchasteler",),
    "enchastelais": ("enchasteler",),
    "enchastelait": ("enchasteler",),
    "enchastela": ("enchasteler",),
    "enchastelâmes": ("enchasteler",),
    "enchastelant": ("enchasteler",),
    "enchastelas": ("enchasteler",),
    "enchastelassent": ("enchasteler",),
    "enchastelasses": ("enchasteler",),
    "enchastelasse": ("enchasteler",),
    "enchastelassiez": ("enchasteler",),
    "enchastelassions": ("enchasteler",),
    "enchastelâtes": ("enchasteler",),
    "enchastelât": ("enchasteler",),
    "enchastelée": ("enchasteler",),
    "enchastelées": ("enchasteler",),
    "enchastelé": ("enchasteler",),
    "enchastelèrent": ("enchasteler",),
    "enchastelés": ("enchasteler",),
    "enchastelez": ("enchasteler",),
    "enchasteliez": ("enchasteler",),
    "enchastelions": ("enchasteler",),
    "enchastellent": ("enchasteler",),
    "enchastelle": ("enchasteler",),
    "enchastellera": ("enchasteler",),
    "enchastelleraient": ("enchasteler",),
    "enchastellerai": ("enchasteler",),
    "enchastellerais": ("enchasteler",),
    "enchastellerait": ("enchasteler",),
    "enchastelleras": ("enchasteler",),
    "enchastellerez": ("enchasteler",),
    "enchastelleriez": ("enchasteler",),
    "enchastellerions": ("enchasteler",),
    "enchastellerons": ("enchasteler",),
    "enchastelleront": ("enchasteler",),
    "enchastelles": ("enchasteler",),
    "enchastelons": ("enchasteler",),
    "enchaucenaient": ("enchaucener",),
    "enchaucenai": ("enchaucener",),
    "enchaucenais": ("enchaucener",),
    "enchaucenait": ("enchaucener",),
    "enchaucena": ("enchaucener",),
    "enchaucenâmes": ("enchaucener",),
    "enchaucenant": ("enchaucener",),
    "enchaucenas": ("enchaucener",),
    "enchaucenassent": ("enchaucener",),
    "enchaucenasses": ("enchaucener",),
    "enchaucenasse": ("enchaucener",),
    "enchaucenassiez": ("enchaucener",),
    "enchaucenassions": ("enchaucener",),
    "enchaucenâtes": ("enchaucener",),
    "enchaucenât": ("enchaucener",),
    "enchaucenée": ("enchaucener",),
    "enchaucenées": ("enchaucener",),
    "enchaucené": ("enchaucener",),
    "enchaucènent": ("enchaucener",),
    "enchaucène": ("enchaucener",),
    "enchaucènera": ("enchaucener",),
    "enchaucèneraient": ("enchaucener",),
    "enchaucènerai": ("enchaucener",),
    "enchaucènerais": ("enchaucener",),
    "enchaucènerait": ("enchaucener",),
    "enchaucèneras": ("enchaucener",),
    "enchaucenèrent": ("enchaucener",),
    "enchaucènerez": ("enchaucener",),
    "enchaucèneriez": ("enchaucener",),
    "enchaucènerions": ("enchaucener",),
    "enchaucènerons": ("enchaucener",),
    "enchaucèneront": ("enchaucener",),
    "enchaucenés": ("enchaucener",),
    "enchaucènes": ("enchaucener",),
    "enchaucenez": ("enchaucener",),
    "enchauceniez": ("enchaucener",),
    "enchaucenions": ("enchaucener",),
    "enchaucenons": ("enchaucener",),
    "enchaussenaient": ("enchaussener",),
    "enchaussenai": ("enchaussener",),
    "enchaussenais": ("enchaussener",),
    "enchaussenait": ("enchaussener",),
    "enchaussena": ("enchaussener",),
    "enchaussenâmes": ("enchaussener",),
    "enchaussenant": ("enchaussener",),
    "enchaussenas": ("enchaussener",),
    "enchaussenassent": ("enchaussener",),
    "enchaussenasses": ("enchaussener",),
    "enchaussenasse": ("enchaussener",),
    "enchaussenassiez": ("enchaussener",),
    "enchaussenassions": ("enchaussener",),
    "enchaussenâtes": ("enchaussener",),
    "enchaussenât": ("enchaussener",),
    "enchaussenée": ("enchaussener",),
    "enchaussenées": ("enchaussener",),
    "enchaussené": ("enchaussener",),
    "enchaussènent": ("enchaussener",),
    "enchaussène": ("enchaussener",),
    "enchaussènera": ("enchaussener",),
    "enchaussèneraient": ("enchaussener",),
    "enchaussènerai": ("enchaussener",),
    "enchaussènerais": ("enchaussener",),
    "enchaussènerait": ("enchaussener",),
    "enchaussèneras": ("enchaussener",),
    "enchaussenèrent": ("enchaussener",),
    "enchaussènerez": ("enchaussener",),
    "enchaussèneriez": ("enchaussener",),
    "enchaussènerions": ("enchaussener",),
    "enchaussènerons": ("enchaussener",),
    "enchaussèneront": ("enchaussener",),
    "enchaussenés": ("enchaussener",),
    "enchaussènes": ("enchaussener",),
    "enchaussenez": ("enchaussener",),
    "enchausseniez": ("enchaussener",),
    "enchaussenions": ("enchaussener",),
    "enchaussenons": ("enchaussener",),
    "enchéri": ("enchérir",),
    "enchérîmes": ("enchérir",),
    "enchérira": ("enchérir",),
    "enchériraient": ("enchérir",),
    "enchérirai": ("enchérir",),
    "enchérirais": ("enchérir",),
    "enchérirait": ("enchérir",),
    "enchériras": ("enchérir",),
    "enchérirent": ("enchérir",),
    "enchérirez": ("enchérir",),
    "enchéririez": ("enchérir",),
    "enchéririons": ("enchérir",),
    "enchérirons": ("enchérir",),
    "enchériront": ("enchérir",),
    "enchéris": ("enchérir",),
    "enchérissaient": ("enchérir",),
    "enchérissais": ("enchérir",),
    "enchérissait": ("enchérir",),
    "enchérissant": ("enchérir",),
    "enchérissent": ("enchérir",),
    "enchérisse": ("enchérir",),
    "enchérisses": ("enchérir",),
    "enchérissez": ("enchérir",),
    "enchérissiez": ("enchérir",),
    "enchérissions": ("enchérir",),
    "enchérissons": ("enchérir",),
    "enchérîtes": ("enchérir",),
    "enchérit": ("enchérir",),
    "enchérît": ("enchérir",),
    "enchifrenaient": ("enchifrener",),
    "enchifrenai": ("enchifrener",),
    "enchifrenais": ("enchifrener",),
    "enchifrenait": ("enchifrener",),
    "enchifrena": ("enchifrener",),
    "enchifrenâmes": ("enchifrener",),
    "enchifrenant": ("enchifrener",),
    "enchifrenas": ("enchifrener",),
    "enchifrenassent": ("enchifrener",),
    "enchifrenasses": ("enchifrener",),
    "enchifrenasse": ("enchifrener",),
    "enchifrenassiez": ("enchifrener",),
    "enchifrenassions": ("enchifrener",),
    "enchifrenâtes": ("enchifrener",),
    "enchifrenât": ("enchifrener",),
    "enchifrenée": ("enchifrener",),
    "enchifrenées": ("enchifrener",),
    "enchifrené": ("enchifrener",),
    "enchifrènent": ("enchifrener",),
    "enchifrène": ("enchifrener",),
    "enchifrènera": ("enchifrener",),
    "enchifrèneraient": ("enchifrener",),
    "enchifrènerai": ("enchifrener",),
    "enchifrènerais": ("enchifrener",),
    "enchifrènerait": ("enchifrener",),
    "enchifrèneras": ("enchifrener",),
    "enchifrenèrent": ("enchifrener",),
    "enchifrènerez": ("enchifrener",),
    "enchifrèneriez": ("enchifrener",),
    "enchifrènerions": ("enchifrener",),
    "enchifrènerons": ("enchifrener",),
    "enchifrèneront": ("enchifrener",),
    "enchifrenés": ("enchifrener",),
    "enchifrènes": ("enchifrener",),
    "enchifrenez": ("enchifrener",),
    "enchifreniez": ("enchifrener",),
    "enchifrenions": ("enchifrener",),
    "enchifrenons": ("enchifrener",),
    "encliquetaient": ("encliqueter",),
    "encliquetai": ("encliqueter",),
    "encliquetais": ("encliqueter",),
    "encliquetait": ("encliqueter",),
    "encliqueta": ("encliqueter",),
    "encliquetâmes": ("encliqueter",),
    "encliquetant": ("encliqueter",),
    "encliquetas": ("encliqueter",),
    "encliquetassent": ("encliqueter",),
    "encliquetasses": ("encliqueter",),
    "encliquetasse": ("encliqueter",),
    "encliquetassiez": ("encliqueter",),
    "encliquetassions": ("encliqueter",),
    "encliquetâtes": ("encliqueter",),
    "encliquetât": ("encliqueter",),
    "encliquetée": ("encliqueter",),
    "encliquetées": ("encliqueter",),
    "encliqueté": ("encliqueter",),
    "encliquetèrent": ("encliqueter",),
    "encliquetés": ("encliqueter",),
    "encliquetez": ("encliqueter",),
    "encliquetiez": ("encliqueter",),
    "encliquetions": ("encliqueter",),
    "encliquetons": ("encliqueter",),
    "encliquettent": ("encliqueter",),
    "encliquette": ("encliqueter",),
    "encliquettera": ("encliqueter",),
    "encliquetteraient": ("encliqueter",),
    "encliquetterai": ("encliqueter",),
    "encliquetterais": ("encliqueter",),
    "encliquetterait": ("encliqueter",),
    "encliquetteras": ("encliqueter",),
    "encliquetterez": ("encliqueter",),
    "encliquetteriez": ("encliqueter",),
    "encliquetterions": ("encliqueter",),
    "encliquetterons": ("encliqueter",),
    "encliquetteront": ("encliqueter",),
    "encliquettes": ("encliqueter",),
    "enclora": ("enclore",),
    "encloraient": ("enclore",),
    "enclorai": ("enclore",),
    "enclorais": ("enclore",),
    "enclorait": ("enclore",),
    "encloras": ("enclore",),
    "enclorez": ("enclore",),
    "encloriez": ("enclore",),
    "enclorions": ("enclore",),
    "enclorons": ("enclore",),
    "encloront": ("enclore",),
    "enclosant": ("enclore",),
    "enclose": ("enclore",),
    "enclosent": ("enclore",),
    "encloses": ("enclore",),
    "enclosez": ("enclore",),
    "enclosiez": ("enclore",),
    "enclosions": ("enclore",),
    "enclos": ("enclore",),
    "enclosons": ("enclore",),
    "enclot": ("enclore",),
    "enclôt": ("enclore",),
    "encoléraient": ("encolérer",),
    "encolérai": ("encolérer",),
    "encolérais": ("encolérer",),
    "encolérait": ("encolérer",),
    "encoléra": ("encolérer",),
    "encolérâmes": ("encolérer",),
    "encolérant": ("encolérer",),
    "encoléras": ("encolérer",),
    "encolérassent": ("encolérer",),
    "encolérasses": ("encolérer",),
    "encolérasse": ("encolérer",),
    "encolérassiez": ("encolérer",),
    "encolérassions": ("encolérer",),
    "encolérâtes": ("encolérer",),
    "encolérât": ("encolérer",),
    "encolérée": ("encolérer",),
    "encolérées": ("encolérer",),
    "encoléré": ("encolérer",),
    "encolèrent": ("encolérer",),
    "encolère": ("encolérer",),
    "encolérera": ("encolérer",),
    "encoléreraient": ("encolérer",),
    "encolérerai": ("encolérer",),
    "encolérerais": ("encolérer",),
    "encolérerait": ("encolérer",),
    "encoléreras": ("encolérer",),
    "encolérèrent": ("encolérer",),
    "encolérerez": ("encolérer",),
    "encoléreriez": ("encolérer",),
    "encolérerions": ("encolérer",),
    "encolérerons": ("encolérer",),
    "encoléreront": ("encolérer",),
    "encolérés": ("encolérer",),
    "encolères": ("encolérer",),
    "encolérez": ("encolérer",),
    "encolériez": ("encolérer",),
    "encolérions": ("encolérer",),
    "encolérons": ("encolérer",),
    "encolletaient": ("encolleter",),
    "encolletai": ("encolleter",),
    "encolletais": ("encolleter",),
    "encolletait": ("encolleter",),
    "encolleta": ("encolleter",),
    "encolletâmes": ("encolleter",),
    "encolletant": ("encolleter",),
    "encolletas": ("encolleter",),
    "encolletassent": ("encolleter",),
    "encolletasses": ("encolleter",),
    "encolletasse": ("encolleter",),
    "encolletassiez": ("encolleter",),
    "encolletassions": ("encolleter",),
    "encolletâtes": ("encolleter",),
    "encolletât": ("encolleter",),
    "encolletée": ("encolleter",),
    "encolletées": ("encolleter",),
    "encolleté": ("encolleter",),
    "encolletèrent": ("encolleter",),
    "encolletés": ("encolleter",),
    "encolletez": ("encolleter",),
    "encolletiez": ("encolleter",),
    "encolletions": ("encolleter",),
    "encolletons": ("encolleter",),
    "encollettent": ("encolleter",),
    "encollette": ("encolleter",),
    "encollettera": ("encolleter",),
    "encolletteraient": ("encolleter",),
    "encolletterai": ("encolleter",),
    "encolletterais": ("encolleter",),
    "encolletterait": ("encolleter",),
    "encolletteras": ("encolleter",),
    "encolletterez": ("encolleter",),
    "encolletteriez": ("encolleter",),
    "encolletterions": ("encolleter",),
    "encolletterons": ("encolleter",),
    "encolletteront": ("encolleter",),
    "encollettes": ("encolleter",),
    "encornetaient": ("encorneter",),
    "encornetai": ("encorneter",),
    "encornetais": ("encorneter",),
    "encornetait": ("encorneter",),
    "encorneta": ("encorneter",),
    "encornetâmes": ("encorneter",),
    "encornetant": ("encorneter",),
    "encornetas": ("encorneter",),
    "encornetassent": ("encorneter",),
    "encornetasses": ("encorneter",),
    "encornetasse": ("encorneter",),
    "encornetassiez": ("encorneter",),
    "encornetassions": ("encorneter",),
    "encornetâtes": ("encorneter",),
    "encornetât": ("encorneter",),
    "encornetée": ("encorneter",),
    "encornetées": ("encorneter",),
    "encorneté": ("encorneter",),
    "encornetèrent": ("encorneter",),
    "encornetés": ("encorneter",),
    "encornetez": ("encorneter",),
    "encornetiez": ("encorneter",),
    "encornetions": ("encorneter",),
    "encornetons": ("encorneter",),
    "encornettent": ("encorneter",),
    "encornette": ("encorneter",),
    "encornettera": ("encorneter",),
    "encornetteraient": ("encorneter",),
    "encornetterai": ("encorneter",),
    "encornetterais": ("encorneter",),
    "encornetterait": ("encorneter",),
    "encornetteras": ("encorneter",),
    "encornetterez": ("encorneter",),
    "encornetteriez": ("encorneter",),
    "encornetterions": ("encorneter",),
    "encornetterons": ("encorneter",),
    "encornetteront": ("encorneter",),
    "encornettes": ("encorneter",),
    "encourageaient": ("encourager",),
    "encourageai": ("encourager",),
    "encourageais": ("encourager",),
    "encourageait": ("encourager",),
    "encouragea": ("encourager",),
    "encourageâmes": ("encourager",),
    "encourageant": ("encourager",),
    "encourageas": ("encourager",),
    "encourageassent": ("encourager",),
    "encourageasses": ("encourager",),
    "encourageasse": ("encourager",),
    "encourageassiez": ("encourager",),
    "encourageassions": ("encourager",),
    "encourageâtes": ("encourager",),
    "encourageât": ("encourager",),
    "encouragée": ("encourager",),
    "encouragées": ("encourager",),
    "encouragé": ("encourager",),
    "encouragent": ("encourager",),
    "encourageons": ("encourager",),
    "encourage": ("encourager",),
    "encouragera": ("encourager",),
    "encourageraient": ("encourager",),
    "encouragerai": ("encourager",),
    "encouragerais": ("encourager",),
    "encouragerait": ("encourager",),
    "encourageras": ("encourager",),
    "encouragèrent": ("encourager",),
    "encouragerez": ("encourager",),
    "encourageriez": ("encourager",),
    "encouragerions": ("encourager",),
    "encouragerons": ("encourager",),
    "encourageront": ("encourager",),
    "encouragés": ("encourager",),
    "encourages": ("encourager",),
    "encouragez": ("encourager",),
    "encouragiez": ("encourager",),
    "encouragions": ("encourager",),
    "encouraient": ("encourir",),
    "encourais": ("encourir",),
    "encourait": ("encourir",),
    "encourant": ("encourir",),
    "encourent": ("encourir",),
    "encoure": ("encourir",),
    "encoures": ("encourir",),
    "encourez": ("encourir",),
    "encouriez": ("encourir",),
    "encourions": ("encourir",),
    "encourons": ("encourir",),
    "encourra": ("encourir",),
    "encourraient": ("encourir",),
    "encourrai": ("encourir",),
    "encourrais": ("encourir",),
    "encourrait": ("encourir",),
    "encourras": ("encourir",),
    "encourrez": ("encourir",),
    "encourriez": ("encourir",),
    "encourrions": ("encourir",),
    "encourrons": ("encourir",),
    "encourront": ("encourir",),
    "encours": ("encourir",),
    "encourt": ("encourir",),
    "encourue": ("encourir",),
    "encourues": ("encourir",),
    "encouru": ("encourir",),
    "encourûmes": ("encourir",),
    "encoururent": ("encourir",),
    "encourus": ("encourir",),
    "encourussent": ("encourir",),
    "encourusses": ("encourir",),
    "encourusse": ("encourir",),
    "encourussiez": ("encourir",),
    "encourussions": ("encourir",),
    "encourûtes": ("encourir",),
    "encourut": ("encourir",),
    "encourût": ("encourir",),
    "encrassaient": ("encrasser",),
    "encrassai": ("encrasser",),
    "encrassais": ("encrasser",),
    "encrassait": ("encrasser",),
    "encrassa": ("encrasser",),
    "encrassâmes": ("encrasser",),
    "encrassant": ("encrasser",),
    "encrassas": ("encrasser",),
    "encrassassent": ("encrasser",),
    "encrassasses": ("encrasser",),
    "encrassasse": ("encrasser",),
    "encrassassiez": ("encrasser",),
    "encrassassions": ("encrasser",),
    "encrassâtes": ("encrasser",),
    "encrassât": ("encrasser",),
    "encrassée": ("encrasser",),
    "encrassées": ("encrasser",),
    "encrassé": ("encrasser",),
    "encrassent": ("encrasser",),
    "encrasse": ("encrasser",),
    "encrassera": ("encrasser",),
    "encrasseraient": ("encrasser",),
    "encrasserai": ("encrasser",),
    "encrasserais": ("encrasser",),
    "encrasserait": ("encrasser",),
    "encrasseras": ("encrasser",),
    "encrassèrent": ("encrasser",),
    "encrasserez": ("encrasser",),
    "encrasseriez": ("encrasser",),
    "encrasserions": ("encrasser",),
    "encrasserons": ("encrasser",),
    "encrasseront": ("encrasser",),
    "encrassés": ("encrasser",),
    "encrasses": ("encrasser",),
    "encrassez": ("encrasser",),
    "encrassiez": ("encrasser",),
    "encrassions": ("encrasser",),
    "encrassons": ("encrasser",),
    "encuirassaient": ("encuirasser",),
    "encuirassai": ("encuirasser",),
    "encuirassais": ("encuirasser",),
    "encuirassait": ("encuirasser",),
    "encuirassa": ("encuirasser",),
    "encuirassâmes": ("encuirasser",),
    "encuirassant": ("encuirasser",),
    "encuirassas": ("encuirasser",),
    "encuirassassent": ("encuirasser",),
    "encuirassasses": ("encuirasser",),
    "encuirassasse": ("encuirasser",),
    "encuirassassiez": ("encuirasser",),
    "encuirassassions": ("encuirasser",),
    "encuirassâtes": ("encuirasser",),
    "encuirassât": ("encuirasser",),
    "encuirassée": ("encuirasser",),
    "encuirassées": ("encuirasser",),
    "encuirassé": ("encuirasser",),
    "encuirassent": ("encuirasser",),
    "encuirasse": ("encuirasser",),
    "encuirassera": ("encuirasser",),
    "encuirasseraient": ("encuirasser",),
    "encuirasserai": ("encuirasser",),
    "encuirasserais": ("encuirasser",),
    "encuirasserait": ("encuirasser",),
    "encuirasseras": ("encuirasser",),
    "encuirassèrent": ("encuirasser",),
    "encuirasserez": ("encuirasser",),
    "encuirasseriez": ("encuirasser",),
    "encuirasserions": ("encuirasser",),
    "encuirasserons": ("encuirasser",),
    "encuirasseront": ("encuirasser",),
    "encuirassés": ("encuirasser",),
    "encuirasses": ("encuirasser",),
    "encuirassez": ("encuirasser",),
    "encuirassiez": ("encuirasser",),
    "encuirassions": ("encuirasser",),
    "encuirassons": ("encuirasser",),
    "endizelaient": ("endizeler",),
    "endizelai": ("endizeler",),
    "endizelais": ("endizeler",),
    "endizelait": ("endizeler",),
    "endizela": ("endizeler",),
    "endizelâmes": ("endizeler",),
    "endizelant": ("endizeler",),
    "endizelas": ("endizeler",),
    "endizelassent": ("endizeler",),
    "endizelasses": ("endizeler",),
    "endizelasse": ("endizeler",),
    "endizelassiez": ("endizeler",),
    "endizelassions": ("endizeler",),
    "endizelâtes": ("endizeler",),
    "endizelât": ("endizeler",),
    "endizelée": ("endizeler",),
    "endizelées": ("endizeler",),
    "endizelé": ("endizeler",),
    "endizèlent": ("endizeler",),
    "endizèle": ("endizeler",),
    "endizèlera": ("endizeler",),
    "endizèleraient": ("endizeler",),
    "endizèlerai": ("endizeler",),
    "endizèlerais": ("endizeler",),
    "endizèlerait": ("endizeler",),
    "endizèleras": ("endizeler",),
    "endizelèrent": ("endizeler",),
    "endizèlerez": ("endizeler",),
    "endizèleriez": ("endizeler",),
    "endizèlerions": ("endizeler",),
    "endizèlerons": ("endizeler",),
    "endizèleront": ("endizeler",),
    "endizelés": ("endizeler",),
    "endizèles": ("endizeler",),
    "endizelez": ("endizeler",),
    "endizeliez": ("endizeler",),
    "endizelions": ("endizeler",),
    "endizelons": ("endizeler",),
    "endolorie": ("endolorir",),
    "endolories": ("endolorir",),
    "endolori": ("endolorir",),
    "endolorîmes": ("endolorir",),
    "endolorira": ("endolorir",),
    "endoloriraient": ("endolorir",),
    "endolorirai": ("endolorir",),
    "endolorirais": ("endolorir",),
    "endolorirait": ("endolorir",),
    "endoloriras": ("endolorir",),
    "endolorirent": ("endolorir",),
    "endolorirez": ("endolorir",),
    "endoloririez": ("endolorir",),
    "endoloririons": ("endolorir",),
    "endolorirons": ("endolorir",),
    "endoloriront": ("endolorir",),
    "endoloris": ("endolorir",),
    "endolorissaient": ("endolorir",),
    "endolorissais": ("endolorir",),
    "endolorissait": ("endolorir",),
    "endolorissant": ("endolorir",),
    "endolorissent": ("endolorir",),
    "endolorisse": ("endolorir",),
    "endolorisses": ("endolorir",),
    "endolorissez": ("endolorir",),
    "endolorissiez": ("endolorir",),
    "endolorissions": ("endolorir",),
    "endolorissons": ("endolorir",),
    "endolorîtes": ("endolorir",),
    "endolorit": ("endolorir",),
    "endolorît": ("endolorir",),
    "endommageaient": ("endommager",),
    "endommageai": ("endommager",),
    "endommageais": ("endommager",),
    "endommageait": ("endommager",),
    "endommagea": ("endommager",),
    "endommageâmes": ("endommager",),
    "endommageant": ("endommager",),
    "endommageas": ("endommager",),
    "endommageassent": ("endommager",),
    "endommageasses": ("endommager",),
    "endommageasse": ("endommager",),
    "endommageassiez": ("endommager",),
    "endommageassions": ("endommager",),
    "endommageâtes": ("endommager",),
    "endommageât": ("endommager",),
    "endommagée": ("endommager",),
    "endommagées": ("endommager",),
    "endommagé": ("endommager",),
    "endommagent": ("endommager",),
    "endommageons": ("endommager",),
    "endommage": ("endommager",),
    "endommagera": ("endommager",),
    "endommageraient": ("endommager",),
    "endommagerai": ("endommager",),
    "endommagerais": ("endommager",),
    "endommagerait": ("endommager",),
    "endommageras": ("endommager",),
    "endommagèrent": ("endommager",),
    "endommagerez": ("endommager",),
    "endommageriez": ("endommager",),
    "endommagerions": ("endommager",),
    "endommagerons": ("endommager",),
    "endommageront": ("endommager",),
    "endommagés": ("endommager",),
    "endommages": ("endommager",),
    "endommagez": ("endommager",),
    "endommagiez": ("endommager",),
    "endommagions": ("endommager",),
    "endormaient": ("endormir",),
    "endormais": ("endormir",),
    "endormait": ("endormir",),
    "endormant": ("endormir",),
    "endorment": ("endormir",),
    "endorme": ("endormir",),
    "endormes": ("endormir",),
    "endormez": ("endormir",),
    "endormie": ("endormir",),
    "endormies": ("endormir",),
    "endormiez": ("endormir",),
    "endormi": ("endormir",),
    "endormîmes": ("endormir",),
    "endormions": ("endormir",),
    "endormira": ("endormir",),
    "endormiraient": ("endormir",),
    "endormirai": ("endormir",),
    "endormirais": ("endormir",),
    "endormirait": ("endormir",),
    "endormiras": ("endormir",),
    "endormirent": ("endormir",),
    "endormirez": ("endormir",),
    "endormiriez": ("endormir",),
    "endormirions": ("endormir",),
    "endormirons": ("endormir",),
    "endormiront": ("endormir",),
    "endormis": ("endormir",),
    "endormissent": ("endormir",),
    "endormisses": ("endormir",),
    "endormisse": ("endormir",),
    "endormissiez": ("endormir",),
    "endormissions": ("endormir",),
    "endormîtes": ("endormir",),
    "endormit": ("endormir",),
    "endormît": ("endormir",),
    "endormons": ("endormir",),
    "endors": ("endormir",),
    "endort": ("endormir",),
    "enduira": ("enduire",),
    "enduiraient": ("enduire",),
    "enduirai": ("enduire",),
    "enduirais": ("enduire",),
    "enduirait": ("enduire",),
    "enduiras": ("enduire",),
    "enduirez": ("enduire",),
    "enduiriez": ("enduire",),
    "enduirions": ("enduire",),
    "enduirons": ("enduire",),
    "enduiront": ("enduire",),
    "enduisaient": ("enduire",),
    "enduisais": ("enduire",),
    "enduisait": ("enduire",),
    "enduisant": ("enduire",),
    "enduisent": ("enduire",),
    "enduise": ("enduire",),
    "enduises": ("enduire",),
    "enduisez": ("enduire",),
    "enduisiez": ("enduire",),
    "enduisîmes": ("enduire",),
    "enduisions": ("enduire",),
    "enduisirent": ("enduire",),
    "enduisis": ("enduire",),
    "enduisissent": ("enduire",),
    "enduisisses": ("enduire",),
    "enduisisse": ("enduire",),
    "enduisissiez": ("enduire",),
    "enduisissions": ("enduire",),
    "enduisîtes": ("enduire",),
    "enduisit": ("enduire",),
    "enduisît": ("enduire",),
    "enduisons": ("enduire",),
    "enduis": ("enduire",),
    "enduite": ("enduire",),
    "enduites": ("enduire",),
    "enduit": ("enduire",),
    "enduits": ("enduire",),
    "endurcie": ("endurcir",),
    "endurcies": ("endurcir",),
    "endurci": ("endurcir",),
    "endurcîmes": ("endurcir",),
    "endurcira": ("endurcir",),
    "endurciraient": ("endurcir",),
    "endurcirai": ("endurcir",),
    "endurcirais": ("endurcir",),
    "endurcirait": ("endurcir",),
    "endurciras": ("endurcir",),
    "endurcirent": ("endurcir",),
    "endurcirez": ("endurcir",),
    "endurciriez": ("endurcir",),
    "endurcirions": ("endurcir",),
    "endurcirons": ("endurcir",),
    "endurciront": ("endurcir",),
    "endurcis": ("endurcir",),
    "endurcissaient": ("endurcir",),
    "endurcissais": ("endurcir",),
    "endurcissait": ("endurcir",),
    "endurcissant": ("endurcir",),
    "endurcissent": ("endurcir",),
    "endurcisse": ("endurcir",),
    "endurcisses": ("endurcir",),
    "endurcissez": ("endurcir",),
    "endurcissiez": ("endurcir",),
    "endurcissions": ("endurcir",),
    "endurcissons": ("endurcir",),
    "endurcîtes": ("endurcir",),
    "endurcit": ("endurcir",),
    "endurcît": ("endurcir",),
    "enficelaient": ("enficeler",),
    "enficelai": ("enficeler",),
    "enficelais": ("enficeler",),
    "enficelait": ("enficeler",),
    "enficela": ("enficeler",),
    "enficelâmes": ("enficeler",),
    "enficelant": ("enficeler",),
    "enficelas": ("enficeler",),
    "enficelassent": ("enficeler",),
    "enficelasses": ("enficeler",),
    "enficelasse": ("enficeler",),
    "enficelassiez": ("enficeler",),
    "enficelassions": ("enficeler",),
    "enficelâtes": ("enficeler",),
    "enficelât": ("enficeler",),
    "enficelée": ("enficeler",),
    "enficelées": ("enficeler",),
    "enficelé": ("enficeler",),
    "enficelèrent": ("enficeler",),
    "enficelés": ("enficeler",),
    "enficelez": ("enficeler",),
    "enficeliez": ("enficeler",),
    "enficelions": ("enficeler",),
    "enficellent": ("enficeler",),
    "enficelle": ("enficeler",),
    "enficellera": ("enficeler",),
    "enficelleraient": ("enficeler",),
    "enficellerai": ("enficeler",),
    "enficellerais": ("enficeler",),
    "enficellerait": ("enficeler",),
    "enficelleras": ("enficeler",),
    "enficellerez": ("enficeler",),
    "enficelleriez": ("enficeler",),
    "enficellerions": ("enficeler",),
    "enficellerons": ("enficeler",),
    "enficelleront": ("enficeler",),
    "enficelles": ("enficeler",),
    "enficelons": ("enficeler",),
    "enfiévraient": ("enfiévrer",),
    "enfiévrai": ("enfiévrer",),
    "enfiévrais": ("enfiévrer",),
    "enfiévrait": ("enfiévrer",),
    "enfiévra": ("enfiévrer",),
    "enfiévrâmes": ("enfiévrer",),
    "enfiévrant": ("enfiévrer",),
    "enfiévras": ("enfiévrer",),
    "enfiévrassent": ("enfiévrer",),
    "enfiévrasses": ("enfiévrer",),
    "enfiévrasse": ("enfiévrer",),
    "enfiévrassiez": ("enfiévrer",),
    "enfiévrassions": ("enfiévrer",),
    "enfiévrâtes": ("enfiévrer",),
    "enfiévrât": ("enfiévrer",),
    "enfiévrée": ("enfiévrer",),
    "enfiévrées": ("enfiévrer",),
    "enfiévré": ("enfiévrer",),
    "enfièvrent": ("enfiévrer",),
    "enfièvre": ("enfiévrer",),
    "enfiévrera": ("enfiévrer",),
    "enfiévreraient": ("enfiévrer",),
    "enfiévrerai": ("enfiévrer",),
    "enfiévrerais": ("enfiévrer",),
    "enfiévrerait": ("enfiévrer",),
    "enfiévreras": ("enfiévrer",),
    "enfiévrèrent": ("enfiévrer",),
    "enfiévrerez": ("enfiévrer",),
    "enfiévreriez": ("enfiévrer",),
    "enfiévrerions": ("enfiévrer",),
    "enfiévrerons": ("enfiévrer",),
    "enfiévreront": ("enfiévrer",),
    "enfiévrés": ("enfiévrer",),
    "enfièvres": ("enfiévrer",),
    "enfiévrez": ("enfiévrer",),
    "enfiévriez": ("enfiévrer",),
    "enfiévrions": ("enfiévrer",),
    "enfiévrons": ("enfiévrer",),
    "enfléchaient": ("enflécher",),
    "enfléchai": ("enflécher",),
    "enfléchais": ("enflécher",),
    "enfléchait": ("enflécher",),
    "enflécha": ("enflécher",),
    "enfléchâmes": ("enflécher",),
    "enfléchant": ("enflécher",),
    "enfléchas": ("enflécher",),
    "enfléchassent": ("enflécher",),
    "enfléchasses": ("enflécher",),
    "enfléchasse": ("enflécher",),
    "enfléchassiez": ("enflécher",),
    "enfléchassions": ("enflécher",),
    "enfléchâtes": ("enflécher",),
    "enfléchât": ("enflécher",),
    "enfléchée": ("enflécher",),
    "enfléchées": ("enflécher",),
    "enfléché": ("enflécher",),
    "enflèchent": ("enflécher",),
    "enflèche": ("enflécher",),
    "enfléchera": ("enflécher",),
    "enflécheraient": ("enflécher",),
    "enflécherai": ("enflécher",),
    "enflécherais": ("enflécher",),
    "enflécherait": ("enflécher",),
    "enflécheras": ("enflécher",),
    "enfléchèrent": ("enflécher",),
    "enflécherez": ("enflécher",),
    "enflécheriez": ("enflécher",),
    "enflécherions": ("enflécher",),
    "enflécherons": ("enflécher",),
    "enflécheront": ("enflécher",),
    "enfléchés": ("enflécher",),
    "enflèches": ("enflécher",),
    "enfléchez": ("enflécher",),
    "enfléchiez": ("enflécher",),
    "enfléchions": ("enflécher",),
    "enfléchons": ("enflécher",),
    "enfonçaient": ("enfoncer",),
    "enfonçai": ("enfoncer",),
    "enfonçais": ("enfoncer",),
    "enfonçait": ("enfoncer",),
    "enfonça": ("enfoncer",),
    "enfonçâmes": ("enfoncer",),
    "enfonçant": ("enfoncer",),
    "enfonças": ("enfoncer",),
    "enfonçassent": ("enfoncer",),
    "enfonçasses": ("enfoncer",),
    "enfonçasse": ("enfoncer",),
    "enfonçassiez": ("enfoncer",),
    "enfonçassions": ("enfoncer",),
    "enfonçâtes": ("enfoncer",),
    "enfonçât": ("enfoncer",),
    "enfoncée": ("enfoncer",),
    "enfoncées": ("enfoncer",),
    "enfoncé": ("enfoncer",),
    "enfoncent": ("enfoncer",),
    "enfonce": ("enfoncer",),
    "enfoncera": ("enfoncer",),
    "enfonceraient": ("enfoncer",),
    "enfoncerai": ("enfoncer",),
    "enfoncerais": ("enfoncer",),
    "enfoncerait": ("enfoncer",),
    "enfonceras": ("enfoncer",),
    "enfoncèrent": ("enfoncer",),
    "enfoncerez": ("enfoncer",),
    "enfonceriez": ("enfoncer",),
    "enfoncerions": ("enfoncer",),
    "enfoncerons": ("enfoncer",),
    "enfonceront": ("enfoncer",),
    "enfoncés": ("enfoncer",),
    "enfonces": ("enfoncer",),
    "enfoncez": ("enfoncer",),
    "enfonciez": ("enfoncer",),
    "enfoncions": ("enfoncer",),
    "enfonçons": ("enfoncer",),
    "enforcie": ("enforcir",),
    "enforcies": ("enforcir",),
    "enforci": ("enforcir",),
    "enforcîmes": ("enforcir",),
    "enforcira": ("enforcir",),
    "enforciraient": ("enforcir",),
    "enforcirai": ("enforcir",),
    "enforcirais": ("enforcir",),
    "enforcirait": ("enforcir",),
    "enforciras": ("enforcir",),
    "enforcirent": ("enforcir",),
    "enforcirez": ("enforcir",),
    "enforciriez": ("enforcir",),
    "enforcirions": ("enforcir",),
    "enforcirons": ("enforcir",),
    "enforciront": ("enforcir",),
    "enforcis": ("enforcir",),
    "enforcissaient": ("enforcir",),
    "enforcissais": ("enforcir",),
    "enforcissait": ("enforcir",),
    "enforcissant": ("enforcir",),
    "enforcissent": ("enforcir",),
    "enforcisse": ("enforcir",),
    "enforcisses": ("enforcir",),
    "enforcissez": ("enforcir",),
    "enforcissiez": ("enforcir",),
    "enforcissions": ("enforcir",),
    "enforcissons": ("enforcir",),
    "enforcîtes": ("enforcir",),
    "enforcit": ("enforcir",),
    "enforcît": ("enforcir",),
    "enfouie": ("enfouir",),
    "enfouies": ("enfouir",),
    "enfoui": ("enfouir",),
    "enfouîmes": ("enfouir",),
    "enfouira": ("enfouir",),
    "enfouiraient": ("enfouir",),
    "enfouirai": ("enfouir",),
    "enfouirais": ("enfouir",),
    "enfouirait": ("enfouir",),
    "enfouiras": ("enfouir",),
    "enfouirent": ("enfouir",),
    "enfouirez": ("enfouir",),
    "enfouiriez": ("enfouir",),
    "enfouirions": ("enfouir",),
    "enfouirons": ("enfouir",),
    "enfouiront": ("enfouir",),
    "enfouis": ("enfouir",),
    "enfouissaient": ("enfouir",),
    "enfouissais": ("enfouir",),
    "enfouissait": ("enfouir",),
    "enfouissant": ("enfouir",),
    "enfouissent": ("enfouir",),
    "enfouisse": ("enfouir",),
    "enfouisses": ("enfouir",),
    "enfouissez": ("enfouir",),
    "enfouissiez": ("enfouir",),
    "enfouissions": ("enfouir",),
    "enfouissons": ("enfouir",),
    "enfouîtes": ("enfouir",),
    "enfouit": ("enfouir",),
    "enfouît": ("enfouir",),
    "enfreignaient": ("enfreindre",),
    "enfreignais": ("enfreindre",),
    "enfreignait": ("enfreindre",),
    "enfreignant": ("enfreindre",),
    "enfreignent": ("enfreindre",),
    "enfreigne": ("enfreindre",),
    "enfreignes": ("enfreindre",),
    "enfreignez": ("enfreindre",),
    "enfreigniez": ("enfreindre",),
    "enfreignîmes": ("enfreindre",),
    "enfreignions": ("enfreindre",),
    "enfreignirent": ("enfreindre",),
    "enfreignis": ("enfreindre",),
    "enfreignissent": ("enfreindre",),
    "enfreignisses": ("enfreindre",),
    "enfreignisse": ("enfreindre",),
    "enfreignissiez": ("enfreindre",),
    "enfreignissions": ("enfreindre",),
    "enfreignîtes": ("enfreindre",),
    "enfreignit": ("enfreindre",),
    "enfreignît": ("enfreindre",),
    "enfreignons": ("enfreindre",),
    "enfreindra": ("enfreindre",),
    "enfreindraient": ("enfreindre",),
    "enfreindrai": ("enfreindre",),
    "enfreindrais": ("enfreindre",),
    "enfreindrait": ("enfreindre",),
    "enfreindras": ("enfreindre",),
    "enfreindrez": ("enfreindre",),
    "enfreindriez": ("enfreindre",),
    "enfreindrions": ("enfreindre",),
    "enfreindrons": ("enfreindre",),
    "enfreindront": ("enfreindre",),
    "enfreins": ("enfreindre",),
    "enfreinte": ("enfreindre",),
    "enfreintes": ("enfreindre",),
    "enfreint": ("enfreindre",),
    "enfreints": ("enfreindre",),
    "enfuie": ("enfuir",),
    "enfuient": ("enfuir",),
    "enfuies": ("enfuir",),
    "enfui": ("enfuir",),
    "enfuîmes": ("enfuir",),
    "enfuira": ("enfuir",),
    "enfuiraient": ("enfuir",),
    "enfuirai": ("enfuir",),
    "enfuirais": ("enfuir",),
    "enfuirait": ("enfuir",),
    "enfuiras": ("enfuir",),
    "enfuirent": ("enfuir",),
    "enfuirez": ("enfuir",),
    "enfuiriez": ("enfuir",),
    "enfuirions": ("enfuir",),
    "enfuirons": ("enfuir",),
    "enfuiront": ("enfuir",),
    "enfuis": ("enfuir",),
    "enfuissent": ("enfuir",),
    "enfuisses": ("enfuir",),
    "enfuisse": ("enfuir",),
    "enfuissiez": ("enfuir",),
    "enfuissions": ("enfuir",),
    "enfuîtes": ("enfuir",),
    "enfuit": ("enfuir",),
    "enfuît": ("enfuir",),
    "enfuyaient": ("enfuir",),
    "enfuyais": ("enfuir",),
    "enfuyait": ("enfuir",),
    "enfuyant": ("enfuir",),
    "enfuyez": ("enfuir",),
    "enfuyiez": ("enfuir",),
    "enfuyions": ("enfuir",),
    "enfuyons": ("enfuir",),
    "engageaient": ("engager",),
    "engageai": ("engager",),
    "engageais": ("engager",),
    "engageait": ("engager",),
    "engagea": ("engager",),
    "engageâmes": ("engager",),
    "engageant": ("engager",),
    "engageas": ("engager",),
    "engageassent": ("engager",),
    "engageasses": ("engager",),
    "engageasse": ("engager",),
    "engageassiez": ("engager",),
    "engageassions": ("engager",),
    "engageâtes": ("engager",),
    "engageât": ("engager",),
    "engagée": ("engager",),
    "engagées": ("engager",),
    "engagé": ("engager",),
    "engagent": ("engager",),
    "engageons": ("engager",),
    "engage": ("engager",),
    "engagera": ("engager",),
    "engageraient": ("engager",),
    "engagerai": ("engager",),
    "engagerais": ("engager",),
    "engagerait": ("engager",),
    "engageras": ("engager",),
    "engagèrent": ("engager",),
    "engagerez": ("engager",),
    "engageriez": ("engager",),
    "engagerions": ("engager",),
    "engagerons": ("engager",),
    "engageront": ("engager",),
    "engagés": ("engager",),
    "engages": ("engager",),
    "engagez": ("engager",),
    "engagiez": ("engager",),
    "engagions": ("engager",),
    "engeançaient": ("engeancer",),
    "engeançai": ("engeancer",),
    "engeançais": ("engeancer",),
    "engeançait": ("engeancer",),
    "engeança": ("engeancer",),
    "engeançâmes": ("engeancer",),
    "engeançant": ("engeancer",),
    "engeanças": ("engeancer",),
    "engeançassent": ("engeancer",),
    "engeançasses": ("engeancer",),
    "engeançasse": ("engeancer",),
    "engeançassiez": ("engeancer",),
    "engeançassions": ("engeancer",),
    "engeançâtes": ("engeancer",),
    "engeançât": ("engeancer",),
    "engeancée": ("engeancer",),
    "engeancées": ("engeancer",),
    "engeancé": ("engeancer",),
    "engeancent": ("engeancer",),
    "engeance": ("engeancer",),
    "engeancera": ("engeancer",),
    "engeanceraient": ("engeancer",),
    "engeancerai": ("engeancer",),
    "engeancerais": ("engeancer",),
    "engeancerait": ("engeancer",),
    "engeanceras": ("engeancer",),
    "engeancèrent": ("engeancer",),
    "engeancerez": ("engeancer",),
    "engeanceriez": ("engeancer",),
    "engeancerions": ("engeancer",),
    "engeancerons": ("engeancer",),
    "engeanceront": ("engeancer",),
    "engeancés": ("engeancer",),
    "engeances": ("engeancer",),
    "engeancez": ("engeancer",),
    "engeanciez": ("engeancer",),
    "engeancions": ("engeancer",),
    "engeançons": ("engeancer",),
    "engeaient": ("enger",),
    "engeai": ("enger",),
    "engeais": ("enger",),
    "engeait": ("enger",),
    "engea": ("enger",),
    "engeâmes": ("enger",),
    "engeant": ("enger",),
    "engeas": ("enger",),
    "engeassent": ("enger",),
    "engeasses": ("enger",),
    "engeasse": ("enger",),
    "engeassiez": ("enger",),
    "engeassions": ("enger",),
    "engeâtes": ("enger",),
    "engeât": ("enger",),
    "engée": ("enger",),
    "engées": ("enger",),
    "engé": ("enger",),
    "engent": ("enger",),
    "engeons": ("enger",),
    "enge": ("enger",),
    "engera": ("enger",),
    "engeraient": ("enger",),
    "engerai": ("enger",),
    "engerais": ("enger",),
    "engerait": ("enger",),
    "engeras": ("enger",),
    "engèrent": ("enger",),
    "engerez": ("enger",),
    "engeriez": ("enger",),
    "engerions": ("enger",),
    "engerons": ("enger",),
    "engeront": ("enger",),
    "engés": ("enger",),
    "enges": ("enger",),
    "engez": ("enger",),
    "engiez": ("enger",),
    "engions": ("enger",),
    "englaçaient": ("englacer",),
    "englaçai": ("englacer",),
    "englaçais": ("englacer",),
    "englaçait": ("englacer",),
    "englaça": ("englacer",),
    "englaçâmes": ("englacer",),
    "englaçant": ("englacer",),
    "englaças": ("englacer",),
    "englaçassent": ("englacer",),
    "englaçasses": ("englacer",),
    "englaçasse": ("englacer",),
    "englaçassiez": ("englacer",),
    "englaçassions": ("englacer",),
    "englaçâtes": ("englacer",),
    "englaçât": ("englacer",),
    "englacée": ("englacer",),
    "englacées": ("englacer",),
    "englacé": ("englacer",),
    "englacent": ("englacer",),
    "englace": ("englacer",),
    "englacera": ("englacer",),
    "englaceraient": ("englacer",),
    "englacerai": ("englacer",),
    "englacerais": ("englacer",),
    "englacerait": ("englacer",),
    "englaceras": ("englacer",),
    "englacèrent": ("englacer",),
    "englacerez": ("englacer",),
    "englaceriez": ("englacer",),
    "englacerions": ("englacer",),
    "englacerons": ("englacer",),
    "englaceront": ("englacer",),
    "englacés": ("englacer",),
    "englaces": ("englacer",),
    "englacez": ("englacer",),
    "englaciez": ("englacer",),
    "englacions": ("englacer",),
    "englaçons": ("englacer",),
    "engloutie": ("engloutir",),
    "englouties": ("engloutir",),
    "englouti": ("engloutir",),
    "engloutîmes": ("engloutir",),
    "engloutira": ("engloutir",),
    "engloutiraient": ("engloutir",),
    "engloutirai": ("engloutir",),
    "engloutirais": ("engloutir",),
    "engloutirait": ("engloutir",),
    "engloutiras": ("engloutir",),
    "engloutirent": ("engloutir",),
    "engloutirez": ("engloutir",),
    "engloutiriez": ("engloutir",),
    "engloutirions": ("engloutir",),
    "engloutirons": ("engloutir",),
    "engloutiront": ("engloutir",),
    "engloutis": ("engloutir",),
    "engloutissaient": ("engloutir",),
    "engloutissais": ("engloutir",),
    "engloutissait": ("engloutir",),
    "engloutissant": ("engloutir",),
    "engloutissent": ("engloutir",),
    "engloutisse": ("engloutir",),
    "engloutisses": ("engloutir",),
    "engloutissez": ("engloutir",),
    "engloutissiez": ("engloutir",),
    "engloutissions": ("engloutir",),
    "engloutissons": ("engloutir",),
    "engloutîtes": ("engloutir",),
    "engloutit": ("engloutir",),
    "engloutît": ("engloutir",),
    "engonçaient": ("engoncer",),
    "engonçai": ("engoncer",),
    "engonçais": ("engoncer",),
    "engonçait": ("engoncer",),
    "engonça": ("engoncer",),
    "engonçâmes": ("engoncer",),
    "engonçant": ("engoncer",),
    "engonças": ("engoncer",),
    "engonçassent": ("engoncer",),
    "engonçasses": ("engoncer",),
    "engonçasse": ("engoncer",),
    "engonçassiez": ("engoncer",),
    "engonçassions": ("engoncer",),
    "engonçâtes": ("engoncer",),
    "engonçât": ("engoncer",),
    "engoncée": ("engoncer",),
    "engoncées": ("engoncer",),
    "engoncé": ("engoncer",),
    "engoncent": ("engoncer",),
    "engonce": ("engoncer",),
    "engoncera": ("engoncer",),
    "engonceraient": ("engoncer",),
    "engoncerai": ("engoncer",),
    "engoncerais": ("engoncer",),
    "engoncerait": ("engoncer",),
    "engonceras": ("engoncer",),
    "engoncèrent": ("engoncer",),
    "engoncerez": ("engoncer",),
    "engonceriez": ("engoncer",),
    "engoncerions": ("engoncer",),
    "engoncerons": ("engoncer",),
    "engonceront": ("engoncer",),
    "engoncés": ("engoncer",),
    "engonces": ("engoncer",),
    "engoncez": ("engoncer",),
    "engonciez": ("engoncer",),
    "engoncions": ("engoncer",),
    "engonçons": ("engoncer",),
    "engorgeaient": ("engorger",),
    "engorgeai": ("engorger",),
    "engorgeais": ("engorger",),
    "engorgeait": ("engorger",),
    "engorgea": ("engorger",),
    "engorgeâmes": ("engorger",),
    "engorgeant": ("engorger",),
    "engorgeas": ("engorger",),
    "engorgeassent": ("engorger",),
    "engorgeasses": ("engorger",),
    "engorgeasse": ("engorger",),
    "engorgeassiez": ("engorger",),
    "engorgeassions": ("engorger",),
    "engorgeâtes": ("engorger",),
    "engorgeât": ("engorger",),
    "engorgée": ("engorger",),
    "engorgées": ("engorger",),
    "engorgé": ("engorger",),
    "engorgent": ("engorger",),
    "engorgeons": ("engorger",),
    "engorge": ("engorger",),
    "engorgera": ("engorger",),
    "engorgeraient": ("engorger",),
    "engorgerai": ("engorger",),
    "engorgerais": ("engorger",),
    "engorgerait": ("engorger",),
    "engorgeras": ("engorger",),
    "engorgèrent": ("engorger",),
    "engorgerez": ("engorger",),
    "engorgeriez": ("engorger",),
    "engorgerions": ("engorger",),
    "engorgerons": ("engorger",),
    "engorgeront": ("engorger",),
    "engorgés": ("engorger",),
    "engorges": ("engorger",),
    "engorgez": ("engorger",),
    "engorgiez": ("engorger",),
    "engorgions": ("engorger",),
    "engourdie": ("engourdir",),
    "engourdies": ("engourdir",),
    "engourdi": ("engourdir",),
    "engourdîmes": ("engourdir",),
    "engourdira": ("engourdir",),
    "engourdiraient": ("engourdir",),
    "engourdirai": ("engourdir",),
    "engourdirais": ("engourdir",),
    "engourdirait": ("engourdir",),
    "engourdiras": ("engourdir",),
    "engourdirent": ("engourdir",),
    "engourdirez": ("engourdir",),
    "engourdiriez": ("engourdir",),
    "engourdirions": ("engourdir",),
    "engourdirons": ("engourdir",),
    "engourdiront": ("engourdir",),
    "engourdis": ("engourdir",),
    "engourdissaient": ("engourdir",),
    "engourdissais": ("engourdir",),
    "engourdissait": ("engourdir",),
    "engourdissant": ("engourdir",),
    "engourdissent": ("engourdir",),
    "engourdisse": ("engourdir",),
    "engourdisses": ("engourdir",),
    "engourdissez": ("engourdir",),
    "engourdissiez": ("engourdir",),
    "engourdissions": ("engourdir",),
    "engourdissons": ("engourdir",),
    "engourdîtes": ("engourdir",),
    "engourdit": ("engourdir",),
    "engourdît": ("engourdir",),
    "engrangeaient": ("engranger",),
    "engrangeai": ("engranger",),
    "engrangeais": ("engranger",),
    "engrangeait": ("engranger",),
    "engrangea": ("engranger",),
    "engrangeâmes": ("engranger",),
    "engrangeant": ("engranger",),
    "engrangeas": ("engranger",),
    "engrangeassent": ("engranger",),
    "engrangeasses": ("engranger",),
    "engrangeasse": ("engranger",),
    "engrangeassiez": ("engranger",),
    "engrangeassions": ("engranger",),
    "engrangeâtes": ("engranger",),
    "engrangeât": ("engranger",),
    "engrangée": ("engranger",),
    "engrangées": ("engranger",),
    "engrangé": ("engranger",),
    "engrangent": ("engranger",),
    "engrangeons": ("engranger",),
    "engrange": ("engranger",),
    "engrangera": ("engranger",),
    "engrangeraient": ("engranger",),
    "engrangerai": ("engranger",),
    "engrangerais": ("engranger",),
    "engrangerait": ("engranger",),
    "engrangeras": ("engranger",),
    "engrangèrent": ("engranger",),
    "engrangerez": ("engranger",),
    "engrangeriez": ("engranger",),
    "engrangerions": ("engranger",),
    "engrangerons": ("engranger",),
    "engrangeront": ("engranger",),
    "engrangés": ("engranger",),
    "engranges": ("engranger",),
    "engrangez": ("engranger",),
    "engrangiez": ("engranger",),
    "engrangions": ("engranger",),
    "engrenaient": ("engrener",),
    "engrenai": ("engrener",),
    "engrenais": ("engrener",),
    "engrenait": ("engrener",),
    "engrena": ("engrener",),
    "engrenâmes": ("engrener",),
    "engrenant": ("engrener",),
    "engrenas": ("engrener",),
    "engrenassent": ("engrener",),
    "engrenasses": ("engrener",),
    "engrenasse": ("engrener",),
    "engrenassiez": ("engrener",),
    "engrenassions": ("engrener",),
    "engrenâtes": ("engrener",),
    "engrenât": ("engrener",),
    "engrenée": ("engrener",),
    "engrenées": ("engrener",),
    "engrené": ("engrener",),
    "engrènent": ("engrener",),
    "engrène": ("engrener",),
    "engrènera": ("engrener",),
    "engrèneraient": ("engrener",),
    "engrènerai": ("engrener",),
    "engrènerais": ("engrener",),
    "engrènerait": ("engrener",),
    "engrèneras": ("engrener",),
    "engrenèrent": ("engrener",),
    "engrènerez": ("engrener",),
    "engrèneriez": ("engrener",),
    "engrènerions": ("engrener",),
    "engrènerons": ("engrener",),
    "engrèneront": ("engrener",),
    "engrenés": ("engrener",),
    "engrènes": ("engrener",),
    "engrenez": ("engrener",),
    "engreniez": ("engrener",),
    "engrenions": ("engrener",),
    "engrenons": ("engrener",),
    "engrumelaient": ("engrumeler",),
    "engrumelai": ("engrumeler",),
    "engrumelais": ("engrumeler",),
    "engrumelait": ("engrumeler",),
    "engrumela": ("engrumeler",),
    "engrumelâmes": ("engrumeler",),
    "engrumelant": ("engrumeler",),
    "engrumelas": ("engrumeler",),
    "engrumelassent": ("engrumeler",),
    "engrumelasses": ("engrumeler",),
    "engrumelasse": ("engrumeler",),
    "engrumelassiez": ("engrumeler",),
    "engrumelassions": ("engrumeler",),
    "engrumelâtes": ("engrumeler",),
    "engrumelât": ("engrumeler",),
    "engrumelée": ("engrumeler",),
    "engrumelées": ("engrumeler",),
    "engrumelé": ("engrumeler",),
    "engrumelèrent": ("engrumeler",),
    "engrumelés": ("engrumeler",),
    "engrumelez": ("engrumeler",),
    "engrumeliez": ("engrumeler",),
    "engrumelions": ("engrumeler",),
    "engrumellent": ("engrumeler",),
    "engrumelle": ("engrumeler",),
    "engrumellera": ("engrumeler",),
    "engrumelleraient": ("engrumeler",),
    "engrumellerai": ("engrumeler",),
    "engrumellerais": ("engrumeler",),
    "engrumellerait": ("engrumeler",),
    "engrumelleras": ("engrumeler",),
    "engrumellerez": ("engrumeler",),
    "engrumelleriez": ("engrumeler",),
    "engrumellerions": ("engrumeler",),
    "engrumellerons": ("engrumeler",),
    "engrumelleront": ("engrumeler",),
    "engrumelles": ("engrumeler",),
    "engrumelons": ("engrumeler",),
    "enhardie": ("enhardir",),
    "enhardies": ("enhardir",),
    "enhardi": ("enhardir",),
    "enhardîmes": ("enhardir",),
    "enhardira": ("enhardir",),
    "enhardiraient": ("enhardir",),
    "enhardirai": ("enhardir",),
    "enhardirais": ("enhardir",),
    "enhardirait": ("enhardir",),
    "enhardiras": ("enhardir",),
    "enhardirent": ("enhardir",),
    "enhardirez": ("enhardir",),
    "enhardiriez": ("enhardir",),
    "enhardirions": ("enhardir",),
    "enhardirons": ("enhardir",),
    "enhardiront": ("enhardir",),
    "enhardis": ("enhardir",),
    "enhardissaient": ("enhardir",),
    "enhardissais": ("enhardir",),
    "enhardissait": ("enhardir",),
    "enhardissant": ("enhardir",),
    "enhardissent": ("enhardir",),
    "enhardisse": ("enhardir",),
    "enhardisses": ("enhardir",),
    "enhardissez": ("enhardir",),
    "enhardissiez": ("enhardir",),
    "enhardissions": ("enhardir",),
    "enhardissons": ("enhardir",),
    "enhardîtes": ("enhardir",),
    "enhardit": ("enhardir",),
    "enhardît": ("enhardir",),
    "enhaient": ("enhayer",),
    "enhaie": ("enhayer",),
    "enhaiera": ("enhayer",),
    "enhaieraient": ("enhayer",),
    "enhaierai": ("enhayer",),
    "enhaierais": ("enhayer",),
    "enhaierait": ("enhayer",),
    "enhaieras": ("enhayer",),
    "enhaierez": ("enhayer",),
    "enhaieriez": ("enhayer",),
    "enhaierions": ("enhayer",),
    "enhaierons": ("enhayer",),
    "enhaieront": ("enhayer",),
    "enhaies": ("enhayer",),
    "enhayaient": ("enhayer",),
    "enhayai": ("enhayer",),
    "enhayais": ("enhayer",),
    "enhayait": ("enhayer",),
    "enhaya": ("enhayer",),
    "enhayâmes": ("enhayer",),
    "enhayant": ("enhayer",),
    "enhayas": ("enhayer",),
    "enhayassent": ("enhayer",),
    "enhayasses": ("enhayer",),
    "enhayasse": ("enhayer",),
    "enhayassiez": ("enhayer",),
    "enhayassions": ("enhayer",),
    "enhayâtes": ("enhayer",),
    "enhayât": ("enhayer",),
    "enhayée": ("enhayer",),
    "enhayées": ("enhayer",),
    "enhayé": ("enhayer",),
    "enhayent": ("enhayer",),
    "enhaye": ("enhayer",),
    "enhayera": ("enhayer",),
    "enhayeraient": ("enhayer",),
    "enhayerai": ("enhayer",),
    "enhayerais": ("enhayer",),
    "enhayerait": ("enhayer",),
    "enhayeras": ("enhayer",),
    "enhayèrent": ("enhayer",),
    "enhayerez": ("enhayer",),
    "enhayeriez": ("enhayer",),
    "enhayerions": ("enhayer",),
    "enhayerons": ("enhayer",),
    "enhayeront": ("enhayer",),
    "enhayés": ("enhayer",),
    "enhayes": ("enhayer",),
    "enhayez": ("enhayer",),
    "enhayiez": ("enhayer",),
    "enhayions": ("enhayer",),
    "enhayons": ("enhayer",),
    "enjavelaient": ("enjaveler",),
    "enjavelai": ("enjaveler",),
    "enjavelais": ("enjaveler",),
    "enjavelait": ("enjaveler",),
    "enjavela": ("enjaveler",),
    "enjavelâmes": ("enjaveler",),
    "enjavelant": ("enjaveler",),
    "enjavelas": ("enjaveler",),
    "enjavelassent": ("enjaveler",),
    "enjavelasses": ("enjaveler",),
    "enjavelasse": ("enjaveler",),
    "enjavelassiez": ("enjaveler",),
    "enjavelassions": ("enjaveler",),
    "enjavelâtes": ("enjaveler",),
    "enjavelât": ("enjaveler",),
    "enjavelée": ("enjaveler",),
    "enjavelées": ("enjaveler",),
    "enjavelé": ("enjaveler",),
    "enjavelèrent": ("enjaveler",),
    "enjavelés": ("enjaveler",),
    "enjavelez": ("enjaveler",),
    "enjaveliez": ("enjaveler",),
    "enjavelions": ("enjaveler",),
    "enjavellent": ("enjaveler",),
    "enjavelle": ("enjaveler",),
    "enjavellera": ("enjaveler",),
    "enjavelleraient": ("enjaveler",),
    "enjavellerai": ("enjaveler",),
    "enjavellerais": ("enjaveler",),
    "enjavellerait": ("enjaveler",),
    "enjavelleras": ("enjaveler",),
    "enjavellerez": ("enjaveler",),
    "enjavelleriez": ("enjaveler",),
    "enjavellerions": ("enjaveler",),
    "enjavellerons": ("enjaveler",),
    "enjavelleront": ("enjaveler",),
    "enjavelles": ("enjaveler",),
    "enjavelons": ("enjaveler",),
    "enjoignaient": ("enjoindre",),
    "enjoignais": ("enjoindre",),
    "enjoignait": ("enjoindre",),
    "enjoignant": ("enjoindre",),
    "enjoignent": ("enjoindre",),
    "enjoigne": ("enjoindre",),
    "enjoignes": ("enjoindre",),
    "enjoignez": ("enjoindre",),
    "enjoigniez": ("enjoindre",),
    "enjoignîmes": ("enjoindre",),
    "enjoignions": ("enjoindre",),
    "enjoignirent": ("enjoindre",),
    "enjoignis": ("enjoindre",),
    "enjoignissent": ("enjoindre",),
    "enjoignisses": ("enjoindre",),
    "enjoignisse": ("enjoindre",),
    "enjoignissiez": ("enjoindre",),
    "enjoignissions": ("enjoindre",),
    "enjoignîtes": ("enjoindre",),
    "enjoignit": ("enjoindre",),
    "enjoignît": ("enjoindre",),
    "enjoignons": ("enjoindre",),
    "enjoindra": ("enjoindre",),
    "enjoindraient": ("enjoindre",),
    "enjoindrai": ("enjoindre",),
    "enjoindrais": ("enjoindre",),
    "enjoindrait": ("enjoindre",),
    "enjoindras": ("enjoindre",),
    "enjoindrez": ("enjoindre",),
    "enjoindriez": ("enjoindre",),
    "enjoindrions": ("enjoindre",),
    "enjoindrons": ("enjoindre",),
    "enjoindront": ("enjoindre",),
    "enjoins": ("enjoindre",),
    "enjointe": ("enjoindre",),
    "enjointes": ("enjoindre",),
    "enjoint": ("enjoindre",),
    "enjoints": ("enjoindre",),
    "enjonçaient": ("enjoncer",),
    "enjonçai": ("enjoncer",),
    "enjonçais": ("enjoncer",),
    "enjonçait": ("enjoncer",),
    "enjonça": ("enjoncer",),
    "enjonçâmes": ("enjoncer",),
    "enjonçant": ("enjoncer",),
    "enjonças": ("enjoncer",),
    "enjonçassent": ("enjoncer",),
    "enjonçasses": ("enjoncer",),
    "enjonçasse": ("enjoncer",),
    "enjonçassiez": ("enjoncer",),
    "enjonçassions": ("enjoncer",),
    "enjonçâtes": ("enjoncer",),
    "enjonçât": ("enjoncer",),
    "enjoncée": ("enjoncer",),
    "enjoncées": ("enjoncer",),
    "enjoncé": ("enjoncer",),
    "enjoncent": ("enjoncer",),
    "enjonce": ("enjoncer",),
    "enjoncera": ("enjoncer",),
    "enjonceraient": ("enjoncer",),
    "enjoncerai": ("enjoncer",),
    "enjoncerais": ("enjoncer",),
    "enjoncerait": ("enjoncer",),
    "enjonceras": ("enjoncer",),
    "enjoncèrent": ("enjoncer",),
    "enjoncerez": ("enjoncer",),
    "enjonceriez": ("enjoncer",),
    "enjoncerions": ("enjoncer",),
    "enjoncerons": ("enjoncer",),
    "enjonceront": ("enjoncer",),
    "enjoncés": ("enjoncer",),
    "enjonces": ("enjoncer",),
    "enjoncez": ("enjoncer",),
    "enjonciez": ("enjoncer",),
    "enjoncions": ("enjoncer",),
    "enjonçons": ("enjoncer",),
    "enlaçaient": ("enlacer",),
    "enlaçai": ("enlacer",),
    "enlaçais": ("enlacer",),
    "enlaçait": ("enlacer",),
    "enlaça": ("enlacer",),
    "enlaçâmes": ("enlacer",),
    "enlaçant": ("enlacer",),
    "enlaças": ("enlacer",),
    "enlaçassent": ("enlacer",),
    "enlaçasses": ("enlacer",),
    "enlaçasse": ("enlacer",),
    "enlaçassiez": ("enlacer",),
    "enlaçassions": ("enlacer",),
    "enlaçâtes": ("enlacer",),
    "enlaçât": ("enlacer",),
    "enlacée": ("enlacer",),
    "enlacées": ("enlacer",),
    "enlacé": ("enlacer",),
    "enlacent": ("enlacer",),
    "enlace": ("enlacer",),
    "enlacera": ("enlacer",),
    "enlaceraient": ("enlacer",),
    "enlacerai": ("enlacer",),
    "enlacerais": ("enlacer",),
    "enlacerait": ("enlacer",),
    "enlaceras": ("enlacer",),
    "enlacèrent": ("enlacer",),
    "enlacerez": ("enlacer",),
    "enlaceriez": ("enlacer",),
    "enlacerions": ("enlacer",),
    "enlacerons": ("enlacer",),
    "enlaceront": ("enlacer",),
    "enlacés": ("enlacer",),
    "enlaces": ("enlacer",),
    "enlacez": ("enlacer",),
    "enlaciez": ("enlacer",),
    "enlacions": ("enlacer",),
    "enlaçons": ("enlacer",),
    "enlaidie": ("enlaidir",),
    "enlaidies": ("enlaidir",),
    "enlaidi": ("enlaidir",),
    "enlaidîmes": ("enlaidir",),
    "enlaidira": ("enlaidir",),
    "enlaidiraient": ("enlaidir",),
    "enlaidirai": ("enlaidir",),
    "enlaidirais": ("enlaidir",),
    "enlaidirait": ("enlaidir",),
    "enlaidiras": ("enlaidir",),
    "enlaidirent": ("enlaidir",),
    "enlaidirez": ("enlaidir",),
    "enlaidiriez": ("enlaidir",),
    "enlaidirions": ("enlaidir",),
    "enlaidirons": ("enlaidir",),
    "enlaidiront": ("enlaidir",),
    "enlaidis": ("enlaidir",),
    "enlaidissaient": ("enlaidir",),
    "enlaidissais": ("enlaidir",),
    "enlaidissait": ("enlaidir",),
    "enlaidissant": ("enlaidir",),
    "enlaidissent": ("enlaidir",),
    "enlaidisse": ("enlaidir",),
    "enlaidisses": ("enlaidir",),
    "enlaidissez": ("enlaidir",),
    "enlaidissiez": ("enlaidir",),
    "enlaidissions": ("enlaidir",),
    "enlaidissons": ("enlaidir",),
    "enlaidîtes": ("enlaidir",),
    "enlaidit": ("enlaidir",),
    "enlaidît": ("enlaidir",),
    "enlevaient": ("enlever",),
    "enlevai": ("enlever",),
    "enlevais": ("enlever",),
    "enlevait": ("enlever",),
    "enleva": ("enlever",),
    "enlevâmes": ("enlever",),
    "enlevant": ("enlever",),
    "enlevas": ("enlever",),
    "enlevassent": ("enlever",),
    "enlevasses": ("enlever",),
    "enlevasse": ("enlever",),
    "enlevassiez": ("enlever",),
    "enlevassions": ("enlever",),
    "enlevâtes": ("enlever",),
    "enlevât": ("enlever",),
    "enlevée": ("enlever",),
    "enlevées": ("enlever",),
    "enlevé": ("enlever",),
    "enlèvent": ("enlever",),
    "enlève": ("enlever",),
    "enlèvera": ("enlever",),
    "enlèveraient": ("enlever",),
    "enlèverai": ("enlever",),
    "enlèverais": ("enlever",),
    "enlèverait": ("enlever",),
    "enlèveras": ("enlever",),
    "enlevèrent": ("enlever",),
    "enlèverez": ("enlever",),
    "enlèveriez": ("enlever",),
    "enlèverions": ("enlever",),
    "enlèverons": ("enlever",),
    "enlèveront": ("enlever",),
    "enlevés": ("enlever",),
    "enlèves": ("enlever",),
    "enlevez": ("enlever",),
    "enleviez": ("enlever",),
    "enlevions": ("enlever",),
    "enlevons": ("enlever",),
    "enliassaient": ("enliasser",),
    "enliassai": ("enliasser",),
    "enliassais": ("enliasser",),
    "enliassait": ("enliasser",),
    "enliassa": ("enliasser",),
    "enliassâmes": ("enliasser",),
    "enliassant": ("enliasser",),
    "enliassas": ("enliasser",),
    "enliassassent": ("enliasser",),
    "enliassasses": ("enliasser",),
    "enliassasse": ("enliasser",),
    "enliassassiez": ("enliasser",),
    "enliassassions": ("enliasser",),
    "enliassâtes": ("enliasser",),
    "enliassât": ("enliasser",),
    "enliassée": ("enliasser",),
    "enliassées": ("enliasser",),
    "enliassé": ("enliasser",),
    "enliassent": ("enlier",),
    "enliasse": ("enlier",),
    "enliassera": ("enliasser",),
    "enliasseraient": ("enliasser",),
    "enliasserai": ("enliasser",),
    "enliasserais": ("enliasser",),
    "enliasserait": ("enliasser",),
    "enliasseras": ("enliasser",),
    "enliassèrent": ("enliasser",),
    "enliasserez": ("enliasser",),
    "enliasseriez": ("enliasser",),
    "enliasserions": ("enliasser",),
    "enliasserons": ("enliasser",),
    "enliasseront": ("enliasser",),
    "enliassés": ("enliasser",),
    "enliasses": ("enlier",),
    "enliassez": ("enliasser",),
    "enliassiez": ("enlier",),
    "enliassions": ("enlier",),
    "enliassons": ("enliasser",),
    "enliaient": ("enlier",),
    "enliai": ("enlier",),
    "enliais": ("enlier",),
    "enliait": ("enlier",),
    "enlia": ("enlier",),
    "enliâmes": ("enlier",),
    "enliant": ("enlier",),
    "enlias": ("enlier",),
    "enliâtes": ("enlier",),
    "enliât": ("enlier",),
    "enliée": ("enlier",),
    "enliées": ("enlier",),
    "enlié": ("enlier",),
    "enlient": ("enlier",),
    "enlie": ("enlier",),
    "enliera": ("enlier",),
    "enlieraient": ("enlier",),
    "enlierai": ("enlier",),
    "enlierais": ("enlier",),
    "enlierait": ("enlier",),
    "enlieras": ("enlier",),
    "enlièrent": ("enlier",),
    "enlierez": ("enlier",),
    "enlieriez": ("enlier",),
    "enlierions": ("enlier",),
    "enlierons": ("enlier",),
    "enlieront": ("enlier",),
    "enliés": ("enlier",),
    "enlies": ("enlier",),
    "enliez": ("enlier",),
    "enliiez": ("enlier",),
    "enliions": ("enlier",),
    "enlions": ("enlier",),
    "enneigeaient": ("enneiger",),
    "enneigeai": ("enneiger",),
    "enneigeais": ("enneiger",),
    "enneigeait": ("enneiger",),
    "enneigea": ("enneiger",),
    "enneigeâmes": ("enneiger",),
    "enneigeant": ("enneiger",),
    "enneigeas": ("enneiger",),
    "enneigeassent": ("enneiger",),
    "enneigeasses": ("enneiger",),
    "enneigeasse": ("enneiger",),
    "enneigeassiez": ("enneiger",),
    "enneigeassions": ("enneiger",),
    "enneigeâtes": ("enneiger",),
    "enneigeât": ("enneiger",),
    "enneigée": ("enneiger",),
    "enneigées": ("enneiger",),
    "enneigé": ("enneiger",),
    "enneigent": ("enneiger",),
    "enneigeons": ("enneiger",),
    "enneige": ("enneiger",),
    "enneigera": ("enneiger",),
    "enneigeraient": ("enneiger",),
    "enneigerai": ("enneiger",),
    "enneigerais": ("enneiger",),
    "enneigerait": ("enneiger",),
    "enneigeras": ("enneiger",),
    "enneigèrent": ("enneiger",),
    "enneigerez": ("enneiger",),
    "enneigeriez": ("enneiger",),
    "enneigerions": ("enneiger",),
    "enneigerons": ("enneiger",),
    "enneigeront": ("enneiger",),
    "enneigés": ("enneiger",),
    "enneiges": ("enneiger",),
    "enneigez": ("enneiger",),
    "enneigiez": ("enneiger",),
    "enneigions": ("enneiger",),
    "ennoblie": ("ennoblir",),
    "ennoblies": ("ennoblir",),
    "ennobli": ("ennoblir",),
    "ennoblîmes": ("ennoblir",),
    "ennoblira": ("ennoblir",),
    "ennobliraient": ("ennoblir",),
    "ennoblirai": ("ennoblir",),
    "ennoblirais": ("ennoblir",),
    "ennoblirait": ("ennoblir",),
    "ennobliras": ("ennoblir",),
    "ennoblirent": ("ennoblir",),
    "ennoblirez": ("ennoblir",),
    "ennobliriez": ("ennoblir",),
    "ennoblirions": ("ennoblir",),
    "ennoblirons": ("ennoblir",),
    "ennobliront": ("ennoblir",),
    "ennoblis": ("ennoblir",),
    "ennoblissaient": ("ennoblir",),
    "ennoblissais": ("ennoblir",),
    "ennoblissait": ("ennoblir",),
    "ennoblissant": ("ennoblir",),
    "ennoblissent": ("ennoblir",),
    "ennoblisse": ("ennoblir",),
    "ennoblisses": ("ennoblir",),
    "ennoblissez": ("ennoblir",),
    "ennoblissiez": ("ennoblir",),
    "ennoblissions": ("ennoblir",),
    "ennoblissons": ("ennoblir",),
    "ennoblîtes": ("ennoblir",),
    "ennoblit": ("ennoblir",),
    "ennoblît": ("ennoblir",),
    "ennoient": ("ennoyer",),
    "ennoie": ("ennoyer",),
    "ennoiera": ("ennoyer",),
    "ennoieraient": ("ennoyer",),
    "ennoierai": ("ennoyer",),
    "ennoierais": ("ennoyer",),
    "ennoierait": ("ennoyer",),
    "ennoieras": ("ennoyer",),
    "ennoierez": ("ennoyer",),
    "ennoieriez": ("ennoyer",),
    "ennoierions": ("ennoyer",),
    "ennoierons": ("ennoyer",),
    "ennoieront": ("ennoyer",),
    "ennoies": ("ennoyer",),
    "ennoyaient": ("ennoyer",),
    "ennoyai": ("ennoyer",),
    "ennoyais": ("ennoyer",),
    "ennoyait": ("ennoyer",),
    "ennoya": ("ennoyer",),
    "ennoyâmes": ("ennoyer",),
    "ennoyant": ("ennoyer",),
    "ennoyas": ("ennoyer",),
    "ennoyassent": ("ennoyer",),
    "ennoyasses": ("ennoyer",),
    "ennoyasse": ("ennoyer",),
    "ennoyassiez": ("ennoyer",),
    "ennoyassions": ("ennoyer",),
    "ennoyâtes": ("ennoyer",),
    "ennoyât": ("ennoyer",),
    "ennoyée": ("ennoyer",),
    "ennoyées": ("ennoyer",),
    "ennoyé": ("ennoyer",),
    "ennoyèrent": ("ennoyer",),
    "ennoyés": ("ennoyer",),
    "ennoyez": ("ennoyer",),
    "ennoyiez": ("ennoyer",),
    "ennoyions": ("ennoyer",),
    "ennoyons": ("ennoyer",),
    "ennuageaient": ("ennuager",),
    "ennuageai": ("ennuager",),
    "ennuageais": ("ennuager",),
    "ennuageait": ("ennuager",),
    "ennuagea": ("ennuager",),
    "ennuageâmes": ("ennuager",),
    "ennuageant": ("ennuager",),
    "ennuageas": ("ennuager",),
    "ennuageassent": ("ennuager",),
    "ennuageasses": ("ennuager",),
    "ennuageasse": ("ennuager",),
    "ennuageassiez": ("ennuager",),
    "ennuageassions": ("ennuager",),
    "ennuageâtes": ("ennuager",),
    "ennuageât": ("ennuager",),
    "ennuagée": ("ennuager",),
    "ennuagées": ("ennuager",),
    "ennuagé": ("ennuager",),
    "ennuagent": ("ennuager",),
    "ennuageons": ("ennuager",),
    "ennuage": ("ennuager",),
    "ennuagera": ("ennuager",),
    "ennuageraient": ("ennuager",),
    "ennuagerai": ("ennuager",),
    "ennuagerais": ("ennuager",),
    "ennuagerait": ("ennuager",),
    "ennuageras": ("ennuager",),
    "ennuagèrent": ("ennuager",),
    "ennuagerez": ("ennuager",),
    "ennuageriez": ("ennuager",),
    "ennuagerions": ("ennuager",),
    "ennuagerons": ("ennuager",),
    "ennuageront": ("ennuager",),
    "ennuagés": ("ennuager",),
    "ennuages": ("ennuager",),
    "ennuagez": ("ennuager",),
    "ennuagiez": ("ennuager",),
    "ennuagions": ("ennuager",),
    "ennuient": ("ennuyer",),
    "ennuie": ("ennuyer",),
    "ennuiera": ("ennuyer",),
    "ennuieraient": ("ennuyer",),
    "ennuierai": ("ennuyer",),
    "ennuierais": ("ennuyer",),
    "ennuierait": ("ennuyer",),
    "ennuieras": ("ennuyer",),
    "ennuierez": ("ennuyer",),
    "ennuieriez": ("ennuyer",),
    "ennuierions": ("ennuyer",),
    "ennuierons": ("ennuyer",),
    "ennuieront": ("ennuyer",),
    "ennuies": ("ennuyer",),
    "ennuyaient": ("ennuyer",),
    "ennuyai": ("ennuyer",),
    "ennuyais": ("ennuyer",),
    "ennuyait": ("ennuyer",),
    "ennuya": ("ennuyer",),
    "ennuyâmes": ("ennuyer",),
    "ennuyant": ("ennuyer",),
    "ennuyas": ("ennuyer",),
    "ennuyassent": ("ennuyer",),
    "ennuyasses": ("ennuyer",),
    "ennuyasse": ("ennuyer",),
    "ennuyassiez": ("ennuyer",),
    "ennuyassions": ("ennuyer",),
    "ennuyâtes": ("ennuyer",),
    "ennuyât": ("ennuyer",),
    "ennuyée": ("ennuyer",),
    "ennuyées": ("ennuyer",),
    "ennuyé": ("ennuyer",),
    "ennuyèrent": ("ennuyer",),
    "ennuyés": ("ennuyer",),
    "ennuyez": ("ennuyer",),
    "ennuyiez": ("ennuyer",),
    "ennuyions": ("ennuyer",),
    "ennuyons": ("ennuyer",),
    "énonçaient": ("énoncer",),
    "énonçai": ("énoncer",),
    "énonçais": ("énoncer",),
    "énonçait": ("énoncer",),
    "énonça": ("énoncer",),
    "énonçâmes": ("énoncer",),
    "énonçant": ("énoncer",),
    "énonças": ("énoncer",),
    "énonçassent": ("énoncer",),
    "énonçasses": ("énoncer",),
    "énonçasse": ("énoncer",),
    "énonçassiez": ("énoncer",),
    "énonçassions": ("énoncer",),
    "énonçâtes": ("énoncer",),
    "énonçât": ("énoncer",),
    "énoncée": ("énoncer",),
    "énoncées": ("énoncer",),
    "énoncé": ("énoncer",),
    "énoncent": ("énoncer",),
    "énonce": ("énoncer",),
    "énoncera": ("énoncer",),
    "énonceraient": ("énoncer",),
    "énoncerai": ("énoncer",),
    "énoncerais": ("énoncer",),
    "énoncerait": ("énoncer",),
    "énonceras": ("énoncer",),
    "énoncèrent": ("énoncer",),
    "énoncerez": ("énoncer",),
    "énonceriez": ("énoncer",),
    "énoncerions": ("énoncer",),
    "énoncerons": ("énoncer",),
    "énonceront": ("énoncer",),
    "énoncés": ("énoncer",),
    "énonces": ("énoncer",),
    "énoncez": ("énoncer",),
    "énonciez": ("énoncer",),
    "énoncions": ("énoncer",),
    "énonçons": ("énoncer",),
    "enorgueillie": ("enorgueillir",),
    "enorgueillies": ("enorgueillir",),
    "enorgueilli": ("enorgueillir",),
    "enorgueillîmes": ("enorgueillir",),
    "enorgueillira": ("enorgueillir",),
    "enorgueilliraient": ("enorgueillir",),
    "enorgueillirai": ("enorgueillir",),
    "enorgueillirais": ("enorgueillir",),
    "enorgueillirait": ("enorgueillir",),
    "enorgueilliras": ("enorgueillir",),
    "enorgueillirent": ("enorgueillir",),
    "enorgueillirez": ("enorgueillir",),
    "enorgueilliriez": ("enorgueillir",),
    "enorgueillirions": ("enorgueillir",),
    "enorgueillirons": ("enorgueillir",),
    "enorgueilliront": ("enorgueillir",),
    "enorgueillis": ("enorgueillir",),
    "enorgueillissaient": ("enorgueillir",),
    "enorgueillissais": ("enorgueillir",),
    "enorgueillissait": ("enorgueillir",),
    "enorgueillissant": ("enorgueillir",),
    "enorgueillissent": ("enorgueillir",),
    "enorgueillisse": ("enorgueillir",),
    "enorgueillisses": ("enorgueillir",),
    "enorgueillissez": ("enorgueillir",),
    "enorgueillissiez": ("enorgueillir",),
    "enorgueillissions": ("enorgueillir",),
    "enorgueillissons": ("enorgueillir",),
    "enorgueillîtes": ("enorgueillir",),
    "enorgueillit": ("enorgueillir",),
    "enorgueillît": ("enorgueillir",),
    "enquéraient": ("enquérir",),
    "enquérais": ("enquérir",),
    "enquérait": ("enquérir",),
    "enquérant": ("enquérir",),
    "enquérez": ("enquérir",),
    "enquériez": ("enquérir",),
    "enquérions": ("enquérir",),
    "enquérons": ("enquérir",),
    "enquerra": ("enquérir",),
    "enquerraient": ("enquérir",),
    "enquerrai": ("enquérir",),
    "enquerrais": ("enquérir",),
    "enquerrait": ("enquérir",),
    "enquerras": ("enquérir",),
    "enquerrez": ("enquérir",),
    "enquerriez": ("enquérir",),
    "enquerrions": ("enquérir",),
    "enquerrons": ("enquérir",),
    "enquerront": ("enquérir",),
    "enquièrent": ("enquérir",),
    "enquière": ("enquérir",),
    "enquières": ("enquérir",),
    "enquiers": ("enquérir",),
    "enquiert": ("enquérir",),
    "enquîmes": ("enquérir",),
    "enquirent": ("enquérir",),
    "enquise": ("enquérir",),
    "enquises": ("enquérir",),
    "enquis": ("enquérir",),
    "enquissent": ("enquérir",),
    "enquisses": ("enquérir",),
    "enquisse": ("enquérir",),
    "enquissiez": ("enquérir",),
    "enquissions": ("enquérir",),
    "enquîtes": ("enquérir",),
    "enquit": ("enquérir",),
    "enquît": ("enquérir",),
    "enrageaient": ("enrager",),
    "enrageai": ("enrager",),
    "enrageais": ("enrager",),
    "enrageait": ("enrager",),
    "enragea": ("enrager",),
    "enrageâmes": ("enrager",),
    "enrageant": ("enrager",),
    "enrageas": ("enrager",),
    "enrageassent": ("enrager",),
    "enrageasses": ("enrager",),
    "enrageasse": ("enrager",),
    "enrageassiez": ("enrager",),
    "enrageassions": ("enrager",),
    "enrageâtes": ("enrager",),
    "enrageât": ("enrager",),
    "enragée": ("enrager",),
    "enragées": ("enrager",),
    "enragé": ("enrager",),
    "enragent": ("enrager",),
    "enrageons": ("enrager",),
    "enrage": ("enrager",),
    "enragera": ("enrager",),
    "enrageraient": ("enrager",),
    "enragerai": ("enrager",),
    "enragerais": ("enrager",),
    "enragerait": ("enrager",),
    "enrageras": ("enrager",),
    "enragèrent": ("enrager",),
    "enragerez": ("enrager",),
    "enrageriez": ("enrager",),
    "enragerions": ("enrager",),
    "enragerons": ("enrager",),
    "enrageront": ("enrager",),
    "enragés": ("enrager",),
    "enrages": ("enrager",),
    "enragez": ("enrager",),
    "enragiez": ("enrager",),
    "enragions": ("enrager",),
    "enraidie": ("enraidir",),
    "enraidies": ("enraidir",),
    "enraidi": ("enraidir",),
    "enraidîmes": ("enraidir",),
    "enraidira": ("enraidir",),
    "enraidiraient": ("enraidir",),
    "enraidirai": ("enraidir",),
    "enraidirais": ("enraidir",),
    "enraidirait": ("enraidir",),
    "enraidiras": ("enraidir",),
    "enraidirent": ("enraidir",),
    "enraidirez": ("enraidir",),
    "enraidiriez": ("enraidir",),
    "enraidirions": ("enraidir",),
    "enraidirons": ("enraidir",),
    "enraidiront": ("enraidir",),
    "enraidis": ("enraidir",),
    "enraidissaient": ("enraidir",),
    "enraidissais": ("enraidir",),
    "enraidissait": ("enraidir",),
    "enraidissant": ("enraidir",),
    "enraidissent": ("enraidir",),
    "enraidisse": ("enraidir",),
    "enraidisses": ("enraidir",),
    "enraidissez": ("enraidir",),
    "enraidissiez": ("enraidir",),
    "enraidissions": ("enraidir",),
    "enraidissons": ("enraidir",),
    "enraidîtes": ("enraidir",),
    "enraidit": ("enraidir",),
    "enraidît": ("enraidir",),
    "enraient": ("enrayer",),
    "enraie": ("enrayer",),
    "enraiera": ("enrayer",),
    "enraieraient": ("enrayer",),
    "enraierai": ("enrayer",),
    "enraierais": ("enrayer",),
    "enraierait": ("enrayer",),
    "enraieras": ("enrayer",),
    "enraierez": ("enrayer",),
    "enraieriez": ("enrayer",),
    "enraierions": ("enrayer",),
    "enraierons": ("enrayer",),
    "enraieront": ("enrayer",),
    "enraies": ("enrayer",),
    "enrayaient": ("enrayer",),
    "enrayai": ("enrayer",),
    "enrayais": ("enrayer",),
    "enrayait": ("enrayer",),
    "enraya": ("enrayer",),
    "enrayâmes": ("enrayer",),
    "enrayant": ("enrayer",),
    "enrayas": ("enrayer",),
    "enrayassent": ("enrayer",),
    "enrayasses": ("enrayer",),
    "enrayasse": ("enrayer",),
    "enrayassiez": ("enrayer",),
    "enrayassions": ("enrayer",),
    "enrayâtes": ("enrayer",),
    "enrayât": ("enrayer",),
    "enrayée": ("enrayer",),
    "enrayées": ("enrayer",),
    "enrayé": ("enrayer",),
    "enrayent": ("enrayer",),
    "enraye": ("enrayer",),
    "enrayera": ("enrayer",),
    "enrayeraient": ("enrayer",),
    "enrayerai": ("enrayer",),
    "enrayerais": ("enrayer",),
    "enrayerait": ("enrayer",),
    "enrayeras": ("enrayer",),
    "enrayèrent": ("enrayer",),
    "enrayerez": ("enrayer",),
    "enrayeriez": ("enrayer",),
    "enrayerions": ("enrayer",),
    "enrayerons": ("enrayer",),
    "enrayeront": ("enrayer",),
    "enrayés": ("enrayer",),
    "enrayes": ("enrayer",),
    "enrayez": ("enrayer",),
    "enrayiez": ("enrayer",),
    "enrayions": ("enrayer",),
    "enrayons": ("enrayer",),
    "enrichie": ("enrichir",),
    "enrichies": ("enrichir",),
    "enrichi": ("enrichir",),
    "enrichîmes": ("enrichir",),
    "enrichira": ("enrichir",),
    "enrichiraient": ("enrichir",),
    "enrichirai": ("enrichir",),
    "enrichirais": ("enrichir",),
    "enrichirait": ("enrichir",),
    "enrichiras": ("enrichir",),
    "enrichirent": ("enrichir",),
    "enrichirez": ("enrichir",),
    "enrichiriez": ("enrichir",),
    "enrichirions": ("enrichir",),
    "enrichirons": ("enrichir",),
    "enrichiront": ("enrichir",),
    "enrichis": ("enrichir",),
    "enrichissaient": ("enrichir",),
    "enrichissais": ("enrichir",),
    "enrichissait": ("enrichir",),
    "enrichissant": ("enrichir",),
    "enrichissent": ("enrichir",),
    "enrichisse": ("enrichir",),
    "enrichisses": ("enrichir",),
    "enrichissez": ("enrichir",),
    "enrichissiez": ("enrichir",),
    "enrichissions": ("enrichir",),
    "enrichissons": ("enrichir",),
    "enrichîtes": ("enrichir",),
    "enrichit": ("enrichir",),
    "enrichît": ("enrichir",),
    "ensauvageaient": ("ensauvager",),
    "ensauvageai": ("ensauvager",),
    "ensauvageais": ("ensauvager",),
    "ensauvageait": ("ensauvager",),
    "ensauvagea": ("ensauvager",),
    "ensauvageâmes": ("ensauvager",),
    "ensauvageant": ("ensauvager",),
    "ensauvageas": ("ensauvager",),
    "ensauvageassent": ("ensauvager",),
    "ensauvageasses": ("ensauvager",),
    "ensauvageasse": ("ensauvager",),
    "ensauvageassiez": ("ensauvager",),
    "ensauvageassions": ("ensauvager",),
    "ensauvageâtes": ("ensauvager",),
    "ensauvageât": ("ensauvager",),
    "ensauvagée": ("ensauvager",),
    "ensauvagées": ("ensauvager",),
    "ensauvagé": ("ensauvager",),
    "ensauvagent": ("ensauvager",),
    "ensauvageons": ("ensauvager",),
    "ensauvage": ("ensauvager",),
    "ensauvagera": ("ensauvager",),
    "ensauvageraient": ("ensauvager",),
    "ensauvagerai": ("ensauvager",),
    "ensauvagerais": ("ensauvager",),
    "ensauvagerait": ("ensauvager",),
    "ensauvageras": ("ensauvager",),
    "ensauvagèrent": ("ensauvager",),
    "ensauvagerez": ("ensauvager",),
    "ensauvageriez": ("ensauvager",),
    "ensauvagerions": ("ensauvager",),
    "ensauvagerons": ("ensauvager",),
    "ensauvageront": ("ensauvager",),
    "ensauvagés": ("ensauvager",),
    "ensauvages": ("ensauvager",),
    "ensauvagez": ("ensauvager",),
    "ensauvagiez": ("ensauvager",),
    "ensauvagions": ("ensauvager",),
    "ensemençaient": ("ensemencer",),
    "ensemençai": ("ensemencer",),
    "ensemençais": ("ensemencer",),
    "ensemençait": ("ensemencer",),
    "ensemença": ("ensemencer",),
    "ensemençâmes": ("ensemencer",),
    "ensemençant": ("ensemencer",),
    "ensemenças": ("ensemencer",),
    "ensemençassent": ("ensemencer",),
    "ensemençasses": ("ensemencer",),
    "ensemençasse": ("ensemencer",),
    "ensemençassiez": ("ensemencer",),
    "ensemençassions": ("ensemencer",),
    "ensemençâtes": ("ensemencer",),
    "ensemençât": ("ensemencer",),
    "ensemencée": ("ensemencer",),
    "ensemencées": ("ensemencer",),
    "ensemencé": ("ensemencer",),
    "ensemencent": ("ensemencer",),
    "ensemence": ("ensemencer",),
    "ensemencera": ("ensemencer",),
    "ensemenceraient": ("ensemencer",),
    "ensemencerai": ("ensemencer",),
    "ensemencerais": ("ensemencer",),
    "ensemencerait": ("ensemencer",),
    "ensemenceras": ("ensemencer",),
    "ensemencèrent": ("ensemencer",),
    "ensemencerez": ("ensemencer",),
    "ensemenceriez": ("ensemencer",),
    "ensemencerions": ("ensemencer",),
    "ensemencerons": ("ensemencer",),
    "ensemenceront": ("ensemencer",),
    "ensemencés": ("ensemencer",),
    "ensemences": ("ensemencer",),
    "ensemencez": ("ensemencer",),
    "ensemenciez": ("ensemencer",),
    "ensemencions": ("ensemencer",),
    "ensemençons": ("ensemencer",),
    "ensevelie": ("ensevelir",),
    "ensevelies": ("ensevelir",),
    "enseveli": ("ensevelir",),
    "ensevelîmes": ("ensevelir",),
    "ensevelira": ("ensevelir",),
    "enseveliraient": ("ensevelir",),
    "ensevelirai": ("ensevelir",),
    "ensevelirais": ("ensevelir",),
    "ensevelirait": ("ensevelir",),
    "enseveliras": ("ensevelir",),
    "ensevelirent": ("ensevelir",),
    "ensevelirez": ("ensevelir",),
    "enseveliriez": ("ensevelir",),
    "ensevelirions": ("ensevelir",),
    "ensevelirons": ("ensevelir",),
    "enseveliront": ("ensevelir",),
    "ensevelis": ("ensevelir",),
    "ensevelissaient": ("ensevelir",),
    "ensevelissais": ("ensevelir",),
    "ensevelissait": ("ensevelir",),
    "ensevelissant": ("ensevelir",),
    "ensevelissent": ("ensevelir",),
    "ensevelisse": ("ensevelir",),
    "ensevelisses": ("ensevelir",),
    "ensevelissez": ("ensevelir",),
    "ensevelissiez": ("ensevelir",),
    "ensevelissions": ("ensevelir",),
    "ensevelissons": ("ensevelir",),
    "ensevelîtes": ("ensevelir",),
    "ensevelit": ("ensevelir",),
    "ensevelît": ("ensevelir",),
    "ensorcelaient": ("ensorceler",),
    "ensorcelai": ("ensorceler",),
    "ensorcelais": ("ensorceler",),
    "ensorcelait": ("ensorceler",),
    "ensorcela": ("ensorceler",),
    "ensorcelâmes": ("ensorceler",),
    "ensorcelant": ("ensorceler",),
    "ensorcelas": ("ensorceler",),
    "ensorcelassent": ("ensorceler",),
    "ensorcelasses": ("ensorceler",),
    "ensorcelasse": ("ensorceler",),
    "ensorcelassiez": ("ensorceler",),
    "ensorcelassions": ("ensorceler",),
    "ensorcelâtes": ("ensorceler",),
    "ensorcelât": ("ensorceler",),
    "ensorcelée": ("ensorceler",),
    "ensorcelées": ("ensorceler",),
    "ensorcelé": ("ensorceler",),
    "ensorcelèrent": ("ensorceler",),
    "ensorcelés": ("ensorceler",),
    "ensorcelez": ("ensorceler",),
    "ensorceliez": ("ensorceler",),
    "ensorcelions": ("ensorceler",),
    "ensorcellent": ("ensorceler",),
    "ensorcelle": ("ensorceler",),
    "ensorcellera": ("ensorceler",),
    "ensorcelleraient": ("ensorceler",),
    "ensorcellerai": ("ensorceler",),
    "ensorcellerais": ("ensorceler",),
    "ensorcellerait": ("ensorceler",),
    "ensorcelleras": ("ensorceler",),
    "ensorcellerez": ("ensorceler",),
    "ensorcelleriez": ("ensorceler",),
    "ensorcellerions": ("ensorceler",),
    "ensorcellerons": ("ensorceler",),
    "ensorcelleront": ("ensorceler",),
    "ensorcelles": ("ensorceler",),
    "ensorcelons": ("ensorceler",),
    "enstéraient": ("enstérer",),
    "enstérai": ("enstérer",),
    "enstérais": ("enstérer",),
    "enstérait": ("enstérer",),
    "enstéra": ("enstérer",),
    "enstérâmes": ("enstérer",),
    "enstérant": ("enstérer",),
    "enstéras": ("enstérer",),
    "enstérassent": ("enstérer",),
    "enstérasses": ("enstérer",),
    "enstérasse": ("enstérer",),
    "enstérassiez": ("enstérer",),
    "enstérassions": ("enstérer",),
    "enstérâtes": ("enstérer",),
    "enstérât": ("enstérer",),
    "enstérée": ("enstérer",),
    "enstérées": ("enstérer",),
    "enstéré": ("enstérer",),
    "enstèrent": ("enstérer",),
    "enstère": ("enstérer",),
    "enstérera": ("enstérer",),
    "enstéreraient": ("enstérer",),
    "enstérerai": ("enstérer",),
    "enstérerais": ("enstérer",),
    "enstérerait": ("enstérer",),
    "enstéreras": ("enstérer",),
    "enstérèrent": ("enstérer",),
    "enstérerez": ("enstérer",),
    "enstéreriez": ("enstérer",),
    "enstérerions": ("enstérer",),
    "enstérerons": ("enstérer",),
    "enstéreront": ("enstérer",),
    "enstérés": ("enstérer",),
    "enstères": ("enstérer",),
    "enstérez": ("enstérer",),
    "enstériez": ("enstérer",),
    "enstérions": ("enstérer",),
    "enstérons": ("enstérer",),
    "ensuis": ("ensuivre",),
    "ensuit": ("ensuivre",),
    "ensuivaient": ("ensuivre",),
    "ensuivais": ("ensuivre",),
    "ensuivait": ("ensuivre",),
    "ensuivant": ("ensuivre",),
    "ensuivent": ("ensuivre",),
    "ensuive": ("ensuivre",),
    "ensuives": ("ensuivre",),
    "ensuivez": ("ensuivre",),
    "ensuivie": ("ensuivre",),
    "ensuivies": ("ensuivre",),
    "ensuiviez": ("ensuivre",),
    "ensuivi": ("ensuivre",),
    "ensuivîmes": ("ensuivre",),
    "ensuivions": ("ensuivre",),
    "ensuivirent": ("ensuivre",),
    "ensuivis": ("ensuivre",),
    "ensuivissent": ("ensuivre",),
    "ensuivisses": ("ensuivre",),
    "ensuivisse": ("ensuivre",),
    "ensuivissiez": ("ensuivre",),
    "ensuivissions": ("ensuivre",),
    "ensuivîtes": ("ensuivre",),
    "ensuivit": ("ensuivre",),
    "ensuivît": ("ensuivre",),
    "ensuivons": ("ensuivre",),
    "ensuivra": ("ensuivre",),
    "ensuivraient": ("ensuivre",),
    "ensuivrai": ("ensuivre",),
    "ensuivrais": ("ensuivre",),
    "ensuivrait": ("ensuivre",),
    "ensuivras": ("ensuivre",),
    "ensuivrez": ("ensuivre",),
    "ensuivriez": ("ensuivre",),
    "ensuivrions": ("ensuivre",),
    "ensuivrons": ("ensuivre",),
    "ensuivront": ("ensuivre",),
    "entassaient": ("entasser",),
    "entassai": ("entasser",),
    "entassais": ("entasser",),
    "entassait": ("entasser",),
    "entassa": ("entasser",),
    "entassâmes": ("entasser",),
    "entassant": ("entasser",),
    "entassas": ("entasser",),
    "entassassent": ("entasser",),
    "entassasses": ("entasser",),
    "entassasse": ("entasser",),
    "entassassiez": ("entasser",),
    "entassassions": ("entasser",),
    "entassâtes": ("entasser",),
    "entassât": ("entasser",),
    "entassée": ("entasser",),
    "entassées": ("entasser",),
    "entassé": ("entasser",),
    "entassent": ("entasser",),
    "entasse": ("entasser",),
    "entassera": ("entasser",),
    "entasseraient": ("entasser",),
    "entasserai": ("entasser",),
    "entasserais": ("entasser",),
    "entasserait": ("entasser",),
    "entasseras": ("entasser",),
    "entassèrent": ("entasser",),
    "entasserez": ("entasser",),
    "entasseriez": ("entasser",),
    "entasserions": ("entasser",),
    "entasserons": ("entasser",),
    "entasseront": ("entasser",),
    "entassés": ("entasser",),
    "entasses": ("entasser",),
    "entassez": ("entasser",),
    "entassiez": ("entasser",),
    "entassions": ("entasser",),
    "entassons": ("entasser",),
    "entendaient": ("entendre",),
    "entendais": ("entendre",),
    "entendait": ("entendre",),
    "entendant": ("entendre",),
    "entendent": ("entendre",),
    "entende": ("entendre",),
    "entendes": ("entendre",),
    "entendez": ("entendre",),
    "entendiez": ("entendre",),
    "entendîmes": ("entendre",),
    "entendions": ("entendre",),
    "entendirent": ("entendre",),
    "entendis": ("entendre",),
    "entendissent": ("entendre",),
    "entendisses": ("entendre",),
    "entendisse": ("entendre",),
    "entendissiez": ("entendre",),
    "entendissions": ("entendre",),
    "entendîtes": ("entendre",),
    "entendit": ("entendre",),
    "entendît": ("entendre",),
    "entendons": ("entendre",),
    "entend": ("entendre",),
    "entendra": ("entendre",),
    "entendraient": ("entendre",),
    "entendrai": ("entendre",),
    "entendrais": ("entendre",),
    "entendrait": ("entendre",),
    "entendras": ("entendre",),
    "entendrez": ("entendre",),
    "entendriez": ("entendre",),
    "entendrions": ("entendre",),
    "entendrons": ("entendre",),
    "entendront": ("entendre",),
    "entends": ("entendre",),
    "entendue": ("entendre",),
    "entendues": ("entendre",),
    "entendu": ("entendre",),
    "entendus": ("entendre",),
    "enténébraient": ("enténébrer",),
    "enténébrai": ("enténébrer",),
    "enténébrais": ("enténébrer",),
    "enténébrait": ("enténébrer",),
    "enténébra": ("enténébrer",),
    "enténébrâmes": ("enténébrer",),
    "enténébrant": ("enténébrer",),
    "enténébras": ("enténébrer",),
    "enténébrassent": ("enténébrer",),
    "enténébrasses": ("enténébrer",),
    "enténébrasse": ("enténébrer",),
    "enténébrassiez": ("enténébrer",),
    "enténébrassions": ("enténébrer",),
    "enténébrâtes": ("enténébrer",),
    "enténébrât": ("enténébrer",),
    "enténébrée": ("enténébrer",),
    "enténébrées": ("enténébrer",),
    "enténébré": ("enténébrer",),
    "enténèbrent": ("enténébrer",),
    "enténèbre": ("enténébrer",),
    "enténébrera": ("enténébrer",),
    "enténébreraient": ("enténébrer",),
    "enténébrerai": ("enténébrer",),
    "enténébrerais": ("enténébrer",),
    "enténébrerait": ("enténébrer",),
    "enténébreras": ("enténébrer",),
    "enténébrèrent": ("enténébrer",),
    "enténébrerez": ("enténébrer",),
    "enténébreriez": ("enténébrer",),
    "enténébrerions": ("enténébrer",),
    "enténébrerons": ("enténébrer",),
    "enténébreront": ("enténébrer",),
    "enténébrés": ("enténébrer",),
    "enténèbres": ("enténébrer",),
    "enténébrez": ("enténébrer",),
    "enténébriez": ("enténébrer",),
    "enténébrions": ("enténébrer",),
    "enténébrons": ("enténébrer",),
    "entierçaient": ("entiercer",),
    "entierçai": ("entiercer",),
    "entierçais": ("entiercer",),
    "entierçait": ("entiercer",),
    "entierça": ("entiercer",),
    "entierçâmes": ("entiercer",),
    "entierçant": ("entiercer",),
    "entierças": ("entiercer",),
    "entierçassent": ("entiercer",),
    "entierçasses": ("entiercer",),
    "entierçasse": ("entiercer",),
    "entierçassiez": ("entiercer",),
    "entierçassions": ("entiercer",),
    "entierçâtes": ("entiercer",),
    "entierçât": ("entiercer",),
    "entiercée": ("entiercer",),
    "entiercées": ("entiercer",),
    "entiercé": ("entiercer",),
    "entiercent": ("entiercer",),
    "entierce": ("entiercer",),
    "entiercera": ("entiercer",),
    "entierceraient": ("entiercer",),
    "entiercerai": ("entiercer",),
    "entiercerais": ("entiercer",),
    "entiercerait": ("entiercer",),
    "entierceras": ("entiercer",),
    "entiercèrent": ("entiercer",),
    "entiercerez": ("entiercer",),
    "entierceriez": ("entiercer",),
    "entiercerions": ("entiercer",),
    "entiercerons": ("entiercer",),
    "entierceront": ("entiercer",),
    "entiercés": ("entiercer",),
    "entierces": ("entiercer",),
    "entiercez": ("entiercer",),
    "entierciez": ("entiercer",),
    "entiercions": ("entiercer",),
    "entierçons": ("entiercer",),
    "entrapercevaient": ("entrapercevoir",),
    "entrapercevais": ("entrapercevoir",),
    "entrapercevait": ("entrapercevoir",),
    "entrapercevant": ("entrapercevoir",),
    "entrapercevez": ("entrapercevoir",),
    "entraperceviez": ("entrapercevoir",),
    "entrapercevions": ("entrapercevoir",),
    "entrapercevons": ("entrapercevoir",),
    "entrapercevra": ("entrapercevoir",),
    "entrapercevraient": ("entrapercevoir",),
    "entrapercevrai": ("entrapercevoir",),
    "entrapercevrais": ("entrapercevoir",),
    "entrapercevrait": ("entrapercevoir",),
    "entrapercevras": ("entrapercevoir",),
    "entrapercevrez": ("entrapercevoir",),
    "entrapercevriez": ("entrapercevoir",),
    "entrapercevrions": ("entrapercevoir",),
    "entrapercevrons": ("entrapercevoir",),
    "entrapercevront": ("entrapercevoir",),
    "entraperçois": ("entrapercevoir",),
    "entraperçoit": ("entrapercevoir",),
    "entraperçoivent": ("entrapercevoir",),
    "entraperçoive": ("entrapercevoir",),
    "entraperçoives": ("entrapercevoir",),
    "entraperçue": ("entrapercevoir",),
    "entraperçues": ("entrapercevoir",),
    "entraperçu": ("entrapercevoir",),
    "entraperçûmes": ("entrapercevoir",),
    "entraperçurent": ("entrapercevoir",),
    "entraperçus": ("entrapercevoir",),
    "entraperçussent": ("entrapercevoir",),
    "entraperçusses": ("entrapercevoir",),
    "entraperçusse": ("entrapercevoir",),
    "entraperçussiez": ("entrapercevoir",),
    "entraperçussions": ("entrapercevoir",),
    "entraperçûtes": ("entrapercevoir",),
    "entraperçut": ("entrapercevoir",),
    "entraperçût": ("entrapercevoir",),
    "entrapparais": ("entrapparaître",),
    "entrapparaissaient": ("entrapparaître",),
    "entrapparaissais": ("entrapparaître",),
    "entrapparaissait": ("entrapparaître",),
    "entrapparaissant": ("entrapparaître",),
    "entrapparaissent": ("entrapparaître",),
    "entrapparaisse": ("entrapparaître",),
    "entrapparaisses": ("entrapparaître",),
    "entrapparaissez": ("entrapparaître",),
    "entrapparaissiez": ("entrapparaître",),
    "entrapparaissions": ("entrapparaître",),
    "entrapparaissons": ("entrapparaître",),
    "entrapparaît": ("entrapparaître",),
    "entrapparaîtra": ("entrapparaître",),
    "entrapparaîtraient": ("entrapparaître",),
    "entrapparaîtrai": ("entrapparaître",),
    "entrapparaîtrais": ("entrapparaître",),
    "entrapparaîtrait": ("entrapparaître",),
    "entrapparaîtras": ("entrapparaître",),
    "entrapparaîtrez": ("entrapparaître",),
    "entrapparaîtriez": ("entrapparaître",),
    "entrapparaîtrions": ("entrapparaître",),
    "entrapparaîtrons": ("entrapparaître",),
    "entrapparaîtront": ("entrapparaître",),
    "entrapparue": ("entrapparaître",),
    "entrapparues": ("entrapparaître",),
    "entrapparu": ("entrapparaître",),
    "entrapparûmes": ("entrapparaître",),
    "entrapparurent": ("entrapparaître",),
    "entrapparus": ("entrapparaître",),
    "entrapparussent": ("entrapparaître",),
    "entrapparusses": ("entrapparaître",),
    "entrapparusse": ("entrapparaître",),
    "entrapparussiez": ("entrapparaître",),
    "entrapparussions": ("entrapparaître",),
    "entrapparûtes": ("entrapparaître",),
    "entrapparut": ("entrapparaître",),
    "entrapparût": ("entrapparaître",),
    "entrebat": ("entrebattre",),
    "entrebats": ("entrebattre",),
    "entrebattaient": ("entrebattre",),
    "entrebattais": ("entrebattre",),
    "entrebattait": ("entrebattre",),
    "entrebattant": ("entrebattre",),
    "entrebattent": ("entrebattre",),
    "entrebatte": ("entrebattre",),
    "entrebattes": ("entrebattre",),
    "entrebattez": ("entrebattre",),
    "entrebattiez": ("entrebattre",),
    "entrebattîmes": ("entrebattre",),
    "entrebattions": ("entrebattre",),
    "entrebattirent": ("entrebattre",),
    "entrebattis": ("entrebattre",),
    "entrebattissent": ("entrebattre",),
    "entrebattisses": ("entrebattre",),
    "entrebattisse": ("entrebattre",),
    "entrebattissiez": ("entrebattre",),
    "entrebattissions": ("entrebattre",),
    "entrebattîtes": ("entrebattre",),
    "entrebattit": ("entrebattre",),
    "entrebattît": ("entrebattre",),
    "entrebattons": ("entrebattre",),
    "entrebattra": ("entrebattre",),
    "entrebattraient": ("entrebattre",),
    "entrebattrai": ("entrebattre",),
    "entrebattrais": ("entrebattre",),
    "entrebattrait": ("entrebattre",),
    "entrebattras": ("entrebattre",),
    "entrebattrez": ("entrebattre",),
    "entrebattriez": ("entrebattre",),
    "entrebattrions": ("entrebattre",),
    "entrebattrons": ("entrebattre",),
    "entrebattront": ("entrebattre",),
    "entrebattue": ("entrebattre",),
    "entrebattues": ("entrebattre",),
    "entrebattu": ("entrebattre",),
    "entrebattus": ("entrebattre",),
    "entrecueillaient": ("entrecueillir",),
    "entrecueillais": ("entrecueillir",),
    "entrecueillait": ("entrecueillir",),
    "entrecueillant": ("entrecueillir",),
    "entrecueillent": ("entrecueillir",),
    "entrecueille": ("entrecueillir",),
    "entrecueillera": ("entrecueillir",),
    "entrecueilleraient": ("entrecueillir",),
    "entrecueillerai": ("entrecueillir",),
    "entrecueillerais": ("entrecueillir",),
    "entrecueillerait": ("entrecueillir",),
    "entrecueilleras": ("entrecueillir",),
    "entrecueillerez": ("entrecueillir",),
    "entrecueilleriez": ("entrecueillir",),
    "entrecueillerions": ("entrecueillir",),
    "entrecueillerons": ("entrecueillir",),
    "entrecueilleront": ("entrecueillir",),
    "entrecueilles": ("entrecueillir",),
    "entrecueillez": ("entrecueillir",),
    "entrecueillie": ("entrecueillir",),
    "entrecueillies": ("entrecueillir",),
    "entrecueilliez": ("entrecueillir",),
    "entrecueilli": ("entrecueillir",),
    "entrecueillîmes": ("entrecueillir",),
    "entrecueillions": ("entrecueillir",),
    "entrecueillirent": ("entrecueillir",),
    "entrecueillis": ("entrecueillir",),
    "entrecueillissent": ("entrecueillir",),
    "entrecueillisses": ("entrecueillir",),
    "entrecueillisse": ("entrecueillir",),
    "entrecueillissiez": ("entrecueillir",),
    "entrecueillissions": ("entrecueillir",),
    "entrecueillîtes": ("entrecueillir",),
    "entrecueillit": ("entrecueillir",),
    "entrecueillît": ("entrecueillir",),
    "entrecueillons": ("entrecueillir",),
    "entrelaçaient": ("entrelacer",),
    "entrelaçai": ("entrelacer",),
    "entrelaçais": ("entrelacer",),
    "entrelaçait": ("entrelacer",),
    "entrelaça": ("entrelacer",),
    "entrelaçâmes": ("entrelacer",),
    "entrelaçant": ("entrelacer",),
    "entrelaças": ("entrelacer",),
    "entrelaçassent": ("entrelacer",),
    "entrelaçasses": ("entrelacer",),
    "entrelaçasse": ("entrelacer",),
    "entrelaçassiez": ("entrelacer",),
    "entrelaçassions": ("entrelacer",),
    "entrelaçâtes": ("entrelacer",),
    "entrelaçât": ("entrelacer",),
    "entrelacée": ("entrelacer",),
    "entrelacées": ("entrelacer",),
    "entrelacé": ("entrelacer",),
    "entrelacent": ("entrelacer",),
    "entrelace": ("entrelacer",),
    "entrelacera": ("entrelacer",),
    "entrelaceraient": ("entrelacer",),
    "entrelacerai": ("entrelacer",),
    "entrelacerais": ("entrelacer",),
    "entrelacerait": ("entrelacer",),
    "entrelaceras": ("entrelacer",),
    "entrelacèrent": ("entrelacer",),
    "entrelacerez": ("entrelacer",),
    "entrelaceriez": ("entrelacer",),
    "entrelacerions": ("entrelacer",),
    "entrelacerons": ("entrelacer",),
    "entrelaceront": ("entrelacer",),
    "entrelacés": ("entrelacer",),
    "entrelaces": ("entrelacer",),
    "entrelacez": ("entrelacer",),
    "entrelaciez": ("entrelacer",),
    "entrelacions": ("entrelacer",),
    "entrelaçons": ("entrelacer",),
    "entrelira": ("entrelire",),
    "entreliraient": ("entrelire",),
    "entrelirai": ("entrelire",),
    "entrelirais": ("entrelire",),
    "entrelirait": ("entrelire",),
    "entreliras": ("entrelire",),
    "entrelirez": ("entrelire",),
    "entreliriez": ("entrelire",),
    "entrelirions": ("entrelire",),
    "entrelirons": ("entrelire",),
    "entreliront": ("entrelire",),
    "entrelisaient": ("entrelire",),
    "entrelisais": ("entrelire",),
    "entrelisait": ("entrelire",),
    "entrelisant": ("entrelire",),
    "entrelisent": ("entrelire",),
    "entrelise": ("entrelire",),
    "entrelises": ("entrelire",),
    "entrelisez": ("entrelire",),
    "entrelisiez": ("entrelire",),
    "entrelisions": ("entrelire",),
    "entrelisons": ("entrelire",),
    "entrelis": ("entrelire",),
    "entrelit": ("entrelire",),
    "entrelue": ("entrelire",),
    "entrelues": ("entrelire",),
    "entrelu": ("entrelire",),
    "entrelûmes": ("entrelire",),
    "entrelurent": ("entrelire",),
    "entrelus": ("entrelire",),
    "entrelussent": ("entrelire",),
    "entrelusses": ("entrelire",),
    "entrelusse": ("entrelire",),
    "entrelussiez": ("entrelire",),
    "entrelussions": ("entrelire",),
    "entrelûtes": ("entrelire",),
    "entrelut": ("entrelire",),
    "entrelût": ("entrelire",),
    "entrelui": ("entreluire",),
    "entreluîmes": ("entreluire",),
    "entreluira": ("entreluire",),
    "entreluiraient": ("entreluire",),
    "entreluirai": ("entreluire",),
    "entreluirais": ("entreluire",),
    "entreluirait": ("entreluire",),
    "entreluiras": ("entreluire",),
    "entreluirent": ("entreluire",),
    "entreluirez": ("entreluire",),
    "entreluiriez": ("entreluire",),
    "entreluirions": ("entreluire",),
    "entreluirons": ("entreluire",),
    "entreluiront": ("entreluire",),
    "entreluisaient": ("entreluire",),
    "entreluisais": ("entreluire",),
    "entreluisait": ("entreluire",),
    "entreluisant": ("entreluire",),
    "entreluisent": ("entreluire",),
    "entreluise": ("entreluire",),
    "entreluises": ("entreluire",),
    "entreluisez": ("entreluire",),
    "entreluisiez": ("entreluire",),
    "entreluisîmes": ("entreluire",),
    "entreluisions": ("entreluire",),
    "entreluisirent": ("entreluire",),
    "entreluisis": ("entreluire",),
    "entreluisissent": ("entreluire",),
    "entreluisisses": ("entreluire",),
    "entreluisisse": ("entreluire",),
    "entreluisissiez": ("entreluire",),
    "entreluisissions": ("entreluire",),
    "entreluisîtes": ("entreluire",),
    "entreluisit": ("entreluire",),
    "entreluisît": ("entreluire",),
    "entreluisons": ("entreluire",),
    "entreluis": ("entreluire",),
    "entreluîtes": ("entreluire",),
    "entreluit": ("entreluire",),
    "entremangeaient": ("entremanger",),
    "entremangeai": ("entremanger",),
    "entremangeais": ("entremanger",),
    "entremangeait": ("entremanger",),
    "entremangea": ("entremanger",),
    "entremangeâmes": ("entremanger",),
    "entremangeant": ("entremanger",),
    "entremangeas": ("entremanger",),
    "entremangeassent": ("entremanger",),
    "entremangeasses": ("entremanger",),
    "entremangeasse": ("entremanger",),
    "entremangeassiez": ("entremanger",),
    "entremangeassions": ("entremanger",),
    "entremangeâtes": ("entremanger",),
    "entremangeât": ("entremanger",),
    "entremangée": ("entremanger",),
    "entremangées": ("entremanger",),
    "entremangé": ("entremanger",),
    "entremangent": ("entremanger",),
    "entremangeons": ("entremanger",),
    "entremange": ("entremanger",),
    "entremangera": ("entremanger",),
    "entremangeraient": ("entremanger",),
    "entremangerai": ("entremanger",),
    "entremangerais": ("entremanger",),
    "entremangerait": ("entremanger",),
    "entremangeras": ("entremanger",),
    "entremangèrent": ("entremanger",),
    "entremangerez": ("entremanger",),
    "entremangeriez": ("entremanger",),
    "entremangerions": ("entremanger",),
    "entremangerons": ("entremanger",),
    "entremangeront": ("entremanger",),
    "entremangés": ("entremanger",),
    "entremanges": ("entremanger",),
    "entremangez": ("entremanger",),
    "entremangiez": ("entremanger",),
    "entremangions": ("entremanger",),
    "entremariaient": ("entremarier",),
    "entremariai": ("entremarier",),
    "entremariais": ("entremarier",),
    "entremariait": ("entremarier",),
    "entremaria": ("entremarier",),
    "entremariâmes": ("entremarier",),
    "entremariant": ("entremarier",),
    "entremarias": ("entremarier",),
    "entremariassent": ("entremarier",),
    "entremariasses": ("entremarier",),
    "entremariasse": ("entremarier",),
    "entremariassiez": ("entremarier",),
    "entremariassions": ("entremarier",),
    "entremariâtes": ("entremarier",),
    "entremariât": ("entremarier",),
    "entremariée": ("entremarier",),
    "entremariées": ("entremarier",),
    "entremarié": ("entremarier",),
    "entremarient": ("entremarier",),
    "entremarie": ("entremarier",),
    "entremariera": ("entremarier",),
    "entremarieraient": ("entremarier",),
    "entremarierai": ("entremarier",),
    "entremarierais": ("entremarier",),
    "entremarierait": ("entremarier",),
    "entremarieras": ("entremarier",),
    "entremarièrent": ("entremarier",),
    "entremarierez": ("entremarier",),
    "entremarieriez": ("entremarier",),
    "entremarierions": ("entremarier",),
    "entremarierons": ("entremarier",),
    "entremarieront": ("entremarier",),
    "entremariés": ("entremarier",),
    "entremaries": ("entremarier",),
    "entremariez": ("entremarier",),
    "entremariiez": ("entremarier",),
    "entremariions": ("entremarier",),
    "entremarions": ("entremarier",),
    "entremet": ("entremettre",),
    "entremets": ("entremettre",),
    "entremettaient": ("entremettre",),
    "entremettais": ("entremettre",),
    "entremettait": ("entremettre",),
    "entremettant": ("entremettre",),
    "entremettent": ("entremettre",),
    "entremette": ("entremettre",),
    "entremettes": ("entremettre",),
    "entremettez": ("entremettre",),
    "entremettiez": ("entremettre",),
    "entremettions": ("entremettre",),
    "entremettons": ("entremettre",),
    "entremettra": ("entremettre",),
    "entremettraient": ("entremettre",),
    "entremettrai": ("entremettre",),
    "entremettrais": ("entremettre",),
    "entremettrait": ("entremettre",),
    "entremettras": ("entremettre",),
    "entremettrez": ("entremettre",),
    "entremettriez": ("entremettre",),
    "entremettrions": ("entremettre",),
    "entremettrons": ("entremettre",),
    "entremettront": ("entremettre",),
    "entremîmes": ("entremettre",),
    "entremirent": ("entremettre",),
    "entremise": ("entremettre",),
    "entremises": ("entremettre",),
    "entremis": ("entremettre",),
    "entremissent": ("entremettre",),
    "entremisses": ("entremettre",),
    "entremisse": ("entremettre",),
    "entremissiez": ("entremettre",),
    "entremissions": ("entremettre",),
    "entremîtes": ("entremettre",),
    "entremit": ("entremettre",),
    "entremît": ("entremettre",),
    "entreparais": ("entreparaître",),
    "entreparaissaient": ("entreparaître",),
    "entreparaissais": ("entreparaître",),
    "entreparaissait": ("entreparaître",),
    "entreparaissant": ("entreparaître",),
    "entreparaissent": ("entreparaître",),
    "entreparaisse": ("entreparaître",),
    "entreparaisses": ("entreparaître",),
    "entreparaissez": ("entreparaître",),
    "entreparaissiez": ("entreparaître",),
    "entreparaissions": ("entreparaître",),
    "entreparaissons": ("entreparaître",),
    "entreparaît": ("entreparaître",),
    "entreparaîtra": ("entreparaître",),
    "entreparaîtraient": ("entreparaître",),
    "entreparaîtrai": ("entreparaître",),
    "entreparaîtrais": ("entreparaître",),
    "entreparaîtrait": ("entreparaître",),
    "entreparaîtras": ("entreparaître",),
    "entreparaîtrez": ("entreparaître",),
    "entreparaîtriez": ("entreparaître",),
    "entreparaîtrions": ("entreparaître",),
    "entreparaîtrons": ("entreparaître",),
    "entreparaîtront": ("entreparaître",),
    "entreparue": ("entreparaître",),
    "entreparues": ("entreparaître",),
    "entreparu": ("entreparaître",),
    "entreparûmes": ("entreparaître",),
    "entreparurent": ("entreparaître",),
    "entreparus": ("entreparaître",),
    "entreparussent": ("entreparaître",),
    "entreparusses": ("entreparaître",),
    "entreparusse": ("entreparaître",),
    "entreparussiez": ("entreparaître",),
    "entreparussions": ("entreparaître",),
    "entreparûtes": ("entreparaître",),
    "entreparut": ("entreparaître",),
    "entreparût": ("entreparaître",),
    "entrepénétraient": ("entrepénétrer",),
    "entrepénétrai": ("entrepénétrer",),
    "entrepénétrais": ("entrepénétrer",),
    "entrepénétrait": ("entrepénétrer",),
    "entrepénétra": ("entrepénétrer",),
    "entrepénétrâmes": ("entrepénétrer",),
    "entrepénétrant": ("entrepénétrer",),
    "entrepénétras": ("entrepénétrer",),
    "entrepénétrassent": ("entrepénétrer",),
    "entrepénétrasses": ("entrepénétrer",),
    "entrepénétrasse": ("entrepénétrer",),
    "entrepénétrassiez": ("entrepénétrer",),
    "entrepénétrassions": ("entrepénétrer",),
    "entrepénétrâtes": ("entrepénétrer",),
    "entrepénétrât": ("entrepénétrer",),
    "entrepénétrée": ("entrepénétrer",),
    "entrepénétrées": ("entrepénétrer",),
    "entrepénétré": ("entrepénétrer",),
    "entrepénètrent": ("entrepénétrer",),
    "entrepénètre": ("entrepénétrer",),
    "entrepénétrera": ("entrepénétrer",),
    "entrepénétreraient": ("entrepénétrer",),
    "entrepénétrerai": ("entrepénétrer",),
    "entrepénétrerais": ("entrepénétrer",),
    "entrepénétrerait": ("entrepénétrer",),
    "entrepénétreras": ("entrepénétrer",),
    "entrepénétrèrent": ("entrepénétrer",),
    "entrepénétrerez": ("entrepénétrer",),
    "entrepénétreriez": ("entrepénétrer",),
    "entrepénétrerions": ("entrepénétrer",),
    "entrepénétrerons": ("entrepénétrer",),
    "entrepénétreront": ("entrepénétrer",),
    "entrepénétrés": ("entrepénétrer",),
    "entrepénètres": ("entrepénétrer",),
    "entrepénétrez": ("entrepénétrer",),
    "entrepénétriez": ("entrepénétrer",),
    "entrepénétrions": ("entrepénétrer",),
    "entrepénétrons": ("entrepénétrer",),
    "entreperçaient": ("entrepercer",),
    "entreperçai": ("entrepercer",),
    "entreperçais": ("entrepercer",),
    "entreperçait": ("entrepercer",),
    "entreperça": ("entrepercer",),
    "entreperçâmes": ("entrepercer",),
    "entreperçant": ("entrepercer",),
    "entreperças": ("entrepercer",),
    "entreperçassent": ("entrepercer",),
    "entreperçasses": ("entrepercer",),
    "entreperçasse": ("entrepercer",),
    "entreperçassiez": ("entrepercer",),
    "entreperçassions": ("entrepercer",),
    "entreperçâtes": ("entrepercer",),
    "entreperçât": ("entrepercer",),
    "entrepercée": ("entrepercer",),
    "entrepercées": ("entrepercer",),
    "entrepercé": ("entrepercer",),
    "entrepercent": ("entrepercer",),
    "entreperce": ("entrepercer",),
    "entrepercera": ("entrepercer",),
    "entreperceraient": ("entrepercer",),
    "entrepercerai": ("entrepercer",),
    "entrepercerais": ("entrepercer",),
    "entrepercerait": ("entrepercer",),
    "entreperceras": ("entrepercer",),
    "entrepercèrent": ("entrepercer",),
    "entrepercerez": ("entrepercer",),
    "entreperceriez": ("entrepercer",),
    "entrepercerions": ("entrepercer",),
    "entrepercerons": ("entrepercer",),
    "entreperceront": ("entrepercer",),
    "entrepercés": ("entrepercer",),
    "entreperces": ("entrepercer",),
    "entrepercez": ("entrepercer",),
    "entreperciez": ("entrepercer",),
    "entrepercions": ("entrepercer",),
    "entreperçons": ("entrepercer",),
    "entreprenaient": ("entreprendre",),
    "entreprenais": ("entreprendre",),
    "entreprenait": ("entreprendre",),
    "entreprenant": ("entreprendre",),
    "entreprend": ("entreprendre",),
    "entreprendra": ("entreprendre",),
    "entreprendraient": ("entreprendre",),
    "entreprendrai": ("entreprendre",),
    "entreprendrais": ("entreprendre",),
    "entreprendrait": ("entreprendre",),
    "entreprendras": ("entreprendre",),
    "entreprendrez": ("entreprendre",),
    "entreprendriez": ("entreprendre",),
    "entreprendrions": ("entreprendre",),
    "entreprendrons": ("entreprendre",),
    "entreprendront": ("entreprendre",),
    "entreprends": ("entreprendre",),
    "entreprenez": ("entreprendre",),
    "entrepreniez": ("entreprendre",),
    "entreprenions": ("entreprendre",),
    "entreprennent": ("entreprendre",),
    "entreprenne": ("entreprendre",),
    "entreprennes": ("entreprendre",),
    "entreprenons": ("entreprendre",),
    "entreprîmes": ("entreprendre",),
    "entreprirent": ("entreprendre",),
    "entreprise": ("entreprendre",),
    "entreprises": ("entreprendre",),
    "entrepris": ("entreprendre",),
    "entreprissent": ("entreprendre",),
    "entreprisses": ("entreprendre",),
    "entreprisse": ("entreprendre",),
    "entreprissiez": ("entreprendre",),
    "entreprissions": ("entreprendre",),
    "entreprîtes": ("entreprendre",),
    "entreprit": ("entreprendre",),
    "entreprît": ("entreprendre",),
    "entresuis": ("entresuivre",),
    "entresuit": ("entresuivre",),
    "entresuivaient": ("entresuivre",),
    "entresuivais": ("entresuivre",),
    "entresuivait": ("entresuivre",),
    "entresuivant": ("entresuivre",),
    "entresuivent": ("entresuivre",),
    "entresuive": ("entresuivre",),
    "entresuives": ("entresuivre",),
    "entresuivez": ("entresuivre",),
    "entresuivie": ("entresuivre",),
    "entresuivies": ("entresuivre",),
    "entresuiviez": ("entresuivre",),
    "entresuivi": ("entresuivre",),
    "entresuivîmes": ("entresuivre",),
    "entresuivions": ("entresuivre",),
    "entresuivirent": ("entresuivre",),
    "entresuivis": ("entresuivre",),
    "entresuivissent": ("entresuivre",),
    "entresuivisses": ("entresuivre",),
    "entresuivisse": ("entresuivre",),
    "entresuivissiez": ("entresuivre",),
    "entresuivissions": ("entresuivre",),
    "entresuivîtes": ("entresuivre",),
    "entresuivit": ("entresuivre",),
    "entresuivît": ("entresuivre",),
    "entresuivons": ("entresuivre",),
    "entresuivra": ("entresuivre",),
    "entresuivraient": ("entresuivre",),
    "entresuivrai": ("entresuivre",),
    "entresuivrais": ("entresuivre",),
    "entresuivrait": ("entresuivre",),
    "entresuivras": ("entresuivre",),
    "entresuivrez": ("entresuivre",),
    "entresuivriez": ("entresuivre",),
    "entresuivrions": ("entresuivre",),
    "entresuivrons": ("entresuivre",),
    "entresuivront": ("entresuivre",),
    "entretenaient": ("entretenir",),
    "entretenais": ("entretenir",),
    "entretenait": ("entretenir",),
    "entretenant": ("entretenir",),
    "entretenez": ("entretenir",),
    "entreteniez": ("entretenir",),
    "entretenions": ("entretenir",),
    "entretenons": ("entretenir",),
    "entretenue": ("entretenir",),
    "entretenues": ("entretenir",),
    "entretenu": ("entretenir",),
    "entretenus": ("entretenir",),
    "entretiendra": ("entretenir",),
    "entretiendraient": ("entretenir",),
    "entretiendrai": ("entretenir",),
    "entretiendrais": ("entretenir",),
    "entretiendrait": ("entretenir",),
    "entretiendras": ("entretenir",),
    "entretiendrez": ("entretenir",),
    "entretiendriez": ("entretenir",),
    "entretiendrions": ("entretenir",),
    "entretiendrons": ("entretenir",),
    "entretiendront": ("entretenir",),
    "entretiennent": ("entretenir",),
    "entretienne": ("entretenir",),
    "entretiennes": ("entretenir",),
    "entretiens": ("entretenir",),
    "entretient": ("entretenir",),
    "entretînmes": ("entretenir",),
    "entretinrent": ("entretenir",),
    "entretins": ("entretenir",),
    "entretinssent": ("entretenir",),
    "entretinsses": ("entretenir",),
    "entretinsse": ("entretenir",),
    "entretinssiez": ("entretenir",),
    "entretinssions": ("entretenir",),
    "entretîntes": ("entretenir",),
    "entretint": ("entretenir",),
    "entretînt": ("entretenir",),
    "entreverra": ("entrevoir",),
    "entreverraient": ("entrevoir",),
    "entreverrai": ("entrevoir",),
    "entreverrais": ("entrevoir",),
    "entreverrait": ("entrevoir",),
    "entreverras": ("entrevoir",),
    "entreverrez": ("entrevoir",),
    "entreverriez": ("entrevoir",),
    "entreverrions": ("entrevoir",),
    "entreverrons": ("entrevoir",),
    "entreverront": ("entrevoir",),
    "entrevîmes": ("entrevoir",),
    "entrevirent": ("entrevoir",),
    "entrevis": ("entrevoir",),
    "entrevissent": ("entrevoir",),
    "entrevisses": ("entrevoir",),
    "entrevisse": ("entrevoir",),
    "entrevissiez": ("entrevoir",),
    "entrevissions": ("entrevoir",),
    "entrevîtes": ("entrevoir",),
    "entrevit": ("entrevoir",),
    "entrevît": ("entrevoir",),
    "entrevoient": ("entrevoir",),
    "entrevoie": ("entrevoir",),
    "entrevoies": ("entrevoir",),
    "entrevois": ("entrevoir",),
    "entrevoit": ("entrevoir",),
    "entrevoyaient": ("entrevoir",),
    "entrevoyais": ("entrevoir",),
    "entrevoyait": ("entrevoir",),
    "entrevoyant": ("entrevoir",),
    "entrevoyez": ("entrevoir",),
    "entrevoyiez": ("entrevoir",),
    "entrevoyions": ("entrevoir",),
    "entrevoyons": ("entrevoir",),
    "entrevue": ("entrevoir",),
    "entrevues": ("entrevoir",),
    "entrevu": ("entrevoir",),
    "entrevus": ("entrevoir",),
    "entrobligeaient": ("entrobliger",),
    "entrobligeai": ("entrobliger",),
    "entrobligeais": ("entrobliger",),
    "entrobligeait": ("entrobliger",),
    "entrobligea": ("entrobliger",),
    "entrobligeâmes": ("entrobliger",),
    "entrobligeant": ("entrobliger",),
    "entrobligeas": ("entrobliger",),
    "entrobligeassent": ("entrobliger",),
    "entrobligeasses": ("entrobliger",),
    "entrobligeasse": ("entrobliger",),
    "entrobligeassiez": ("entrobliger",),
    "entrobligeassions": ("entrobliger",),
    "entrobligeâtes": ("entrobliger",),
    "entrobligeât": ("entrobliger",),
    "entrobligée": ("entrobliger",),
    "entrobligées": ("entrobliger",),
    "entrobligé": ("entrobliger",),
    "entrobligent": ("entrobliger",),
    "entrobligeons": ("entrobliger",),
    "entroblige": ("entrobliger",),
    "entrobligera": ("entrobliger",),
    "entrobligeraient": ("entrobliger",),
    "entrobligerai": ("entrobliger",),
    "entrobligerais": ("entrobliger",),
    "entrobligerait": ("entrobliger",),
    "entrobligeras": ("entrobliger",),
    "entrobligèrent": ("entrobliger",),
    "entrobligerez": ("entrobliger",),
    "entrobligeriez": ("entrobliger",),
    "entrobligerions": ("entrobliger",),
    "entrobligerons": ("entrobliger",),
    "entrobligeront": ("entrobliger",),
    "entrobligés": ("entrobliger",),
    "entrobliges": ("entrobliger",),
    "entrobligez": ("entrobliger",),
    "entrobligiez": ("entrobliger",),
    "entrobligions": ("entrobliger",),
    "entrouverte": ("entrouvrir",),
    "entrouvertes": ("entrouvrir",),
    "entrouvert": ("entrouvrir",),
    "entrouverts": ("entrouvrir",),
    "entrouvraient": ("entrouvrir",),
    "entrouvrais": ("entrouvrir",),
    "entrouvrait": ("entrouvrir",),
    "entrouvrant": ("entrouvrir",),
    "entrouvrent": ("entrouvrir",),
    "entrouvre": ("entrouvrir",),
    "entrouvres": ("entrouvrir",),
    "entrouvrez": ("entrouvrir",),
    "entrouvriez": ("entrouvrir",),
    "entrouvrîmes": ("entrouvrir",),
    "entrouvrions": ("entrouvrir",),
    "entrouvrira": ("entrouvrir",),
    "entrouvriraient": ("entrouvrir",),
    "entrouvrirai": ("entrouvrir",),
    "entrouvrirais": ("entrouvrir",),
    "entrouvrirait": ("entrouvrir",),
    "entrouvriras": ("entrouvrir",),
    "entrouvrirent": ("entrouvrir",),
    "entrouvrirez": ("entrouvrir",),
    "entrouvririez": ("entrouvrir",),
    "entrouvririons": ("entrouvrir",),
    "entrouvrirons": ("entrouvrir",),
    "entrouvriront": ("entrouvrir",),
    "entrouvris": ("entrouvrir",),
    "entrouvrissent": ("entrouvrir",),
    "entrouvrisses": ("entrouvrir",),
    "entrouvrisse": ("entrouvrir",),
    "entrouvrissiez": ("entrouvrir",),
    "entrouvrissions": ("entrouvrir",),
    "entrouvrîtes": ("entrouvrir",),
    "entrouvrit": ("entrouvrir",),
    "entrouvrît": ("entrouvrir",),
    "entrouvrons": ("entrouvrir",),
    "énucléaient": ("énucléer",),
    "énucléai": ("énucléer",),
    "énucléais": ("énucléer",),
    "énucléait": ("énucléer",),
    "énucléa": ("énucléer",),
    "énucléâmes": ("énucléer",),
    "énucléant": ("énucléer",),
    "énucléas": ("énucléer",),
    "énucléassent": ("énucléer",),
    "énucléasses": ("énucléer",),
    "énucléasse": ("énucléer",),
    "énucléassiez": ("énucléer",),
    "énucléassions": ("énucléer",),
    "énucléâtes": ("énucléer",),
    "énucléât": ("énucléer",),
    "énucléée": ("énucléer",),
    "énucléées": ("énucléer",),
    "énucléé": ("énucléer",),
    "énucléent": ("énucléer",),
    "énuclée": ("énucléer",),
    "énucléera": ("énucléer",),
    "énucléeraient": ("énucléer",),
    "énucléerai": ("énucléer",),
    "énucléerais": ("énucléer",),
    "énucléerait": ("énucléer",),
    "énucléeras": ("énucléer",),
    "énucléèrent": ("énucléer",),
    "énucléerez": ("énucléer",),
    "énucléeriez": ("énucléer",),
    "énucléerions": ("énucléer",),
    "énucléerons": ("énucléer",),
    "énucléeront": ("énucléer",),
    "énucléés": ("énucléer",),
    "énuclées": ("énucléer",),
    "énucléez": ("énucléer",),
    "énucléiez": ("énucléer",),
    "énucléions": ("énucléer",),
    "énucléons": ("énucléer",),
    "énuméraient": ("énumérer",),
    "énumérai": ("énumérer",),
    "énumérais": ("énumérer",),
    "énumérait": ("énumérer",),
    "énuméra": ("énumérer",),
    "énumérâmes": ("énumérer",),
    "énumérant": ("énumérer",),
    "énuméras": ("énumérer",),
    "énumérassent": ("énumérer",),
    "énumérasses": ("énumérer",),
    "énumérasse": ("énumérer",),
    "énumérassiez": ("énumérer",),
    "énumérassions": ("énumérer",),
    "énumérâtes": ("énumérer",),
    "énumérât": ("énumérer",),
    "énumérée": ("énumérer",),
    "énumérées": ("énumérer",),
    "énuméré": ("énumérer",),
    "énumèrent": ("énumérer",),
    "énumère": ("énumérer",),
    "énumérera": ("énumérer",),
    "énuméreraient": ("énumérer",),
    "énumérerai": ("énumérer",),
    "énumérerais": ("énumérer",),
    "énumérerait": ("énumérer",),
    "énuméreras": ("énumérer",),
    "énumérèrent": ("énumérer",),
    "énumérerez": ("énumérer",),
    "énuméreriez": ("énumérer",),
    "énumérerions": ("énumérer",),
    "énumérerons": ("énumérer",),
    "énuméreront": ("énumérer",),
    "énumérés": ("énumérer",),
    "énumères": ("énumérer",),
    "énumérez": ("énumérer",),
    "énumériez": ("énumérer",),
    "énumérions": ("énumérer",),
    "énumérons": ("énumérer",),
    "envahie": ("envahir",),
    "envahies": ("envahir",),
    "envahi": ("envahir",),
    "envahîmes": ("envahir",),
    "envahira": ("envahir",),
    "envahiraient": ("envahir",),
    "envahirai": ("envahir",),
    "envahirais": ("envahir",),
    "envahirait": ("envahir",),
    "envahiras": ("envahir",),
    "envahirent": ("envahir",),
    "envahirez": ("envahir",),
    "envahiriez": ("envahir",),
    "envahirions": ("envahir",),
    "envahirons": ("envahir",),
    "envahiront": ("envahir",),
    "envahis": ("envahir",),
    "envahissaient": ("envahir",),
    "envahissais": ("envahir",),
    "envahissait": ("envahir",),
    "envahissant": ("envahir",),
    "envahissent": ("envahir",),
    "envahisse": ("envahir",),
    "envahisses": ("envahir",),
    "envahissez": ("envahir",),
    "envahissiez": ("envahir",),
    "envahissions": ("envahir",),
    "envahissons": ("envahir",),
    "envahîtes": ("envahir",),
    "envahit": ("envahir",),
    "envahît": ("envahir",),
    "envergeaient": ("enverger",),
    "envergeai": ("enverger",),
    "envergeais": ("enverger",),
    "envergeait": ("enverger",),
    "envergea": ("enverger",),
    "envergeâmes": ("enverger",),
    "envergeant": ("enverger",),
    "envergeas": ("enverger",),
    "envergeassent": ("enverger",),
    "envergeasses": ("enverger",),
    "envergeasse": ("enverger",),
    "envergeassiez": ("enverger",),
    "envergeassions": ("enverger",),
    "envergeâtes": ("enverger",),
    "envergeât": ("enverger",),
    "envergée": ("enverger",),
    "envergées": ("enverger",),
    "envergé": ("enverger",),
    "envergent": ("enverger",),
    "envergeons": ("enverger",),
    "enverge": ("enverger",),
    "envergera": ("enverger",),
    "envergeraient": ("enverger",),
    "envergerai": ("enverger",),
    "envergerais": ("enverger",),
    "envergerait": ("enverger",),
    "envergeras": ("enverger",),
    "envergèrent": ("enverger",),
    "envergerez": ("enverger",),
    "envergeriez": ("enverger",),
    "envergerions": ("enverger",),
    "envergerons": ("enverger",),
    "envergeront": ("enverger",),
    "envergés": ("enverger",),
    "enverges": ("enverger",),
    "envergez": ("enverger",),
    "envergiez": ("enverger",),
    "envergions": ("enverger",),
    "envieillie": ("envieillir",),
    "envieillies": ("envieillir",),
    "envieilli": ("envieillir",),
    "envieillîmes": ("envieillir",),
    "envieillira": ("envieillir",),
    "envieilliraient": ("envieillir",),
    "envieillirai": ("envieillir",),
    "envieillirais": ("envieillir",),
    "envieillirait": ("envieillir",),
    "envieilliras": ("envieillir",),
    "envieillirent": ("envieillir",),
    "envieillirez": ("envieillir",),
    "envieilliriez": ("envieillir",),
    "envieillirions": ("envieillir",),
    "envieillirons": ("envieillir",),
    "envieilliront": ("envieillir",),
    "envieillis": ("envieillir",),
    "envieillissaient": ("envieillir",),
    "envieillissais": ("envieillir",),
    "envieillissait": ("envieillir",),
    "envieillissant": ("envieillir",),
    "envieillissent": ("envieillir",),
    "envieillisse": ("envieillir",),
    "envieillisses": ("envieillir",),
    "envieillissez": ("envieillir",),
    "envieillissiez": ("envieillir",),
    "envieillissions": ("envieillir",),
    "envieillissons": ("envieillir",),
    "envieillîtes": ("envieillir",),
    "envieillit": ("envieillir",),
    "envieillît": ("envieillir",),
    "enviaient": ("envier",),
    "enviai": ("envier",),
    "enviais": ("envier",),
    "enviait": ("envier",),
    "envia": ("envier",),
    "enviâmes": ("envier",),
    "enviant": ("envier",),
    "envias": ("envier",),
    "enviassent": ("envier",),
    "enviasses": ("envier",),
    "enviasse": ("envier",),
    "enviassiez": ("envier",),
    "enviassions": ("envier",),
    "enviâtes": ("envier",),
    "enviât": ("envier",),
    "enviée": ("envier",),
    "enviées": ("envier",),
    "envié": ("envier",),
    "envient": ("envier",),
    "envie": ("envier",),
    "enviera": ("envier",),
    "envieraient": ("envier",),
    "envierai": ("envier",),
    "envierais": ("envier",),
    "envierait": ("envier",),
    "envieras": ("envier",),
    "envièrent": ("envier",),
    "envierez": ("envier",),
    "envieriez": ("envier",),
    "envierions": ("envier",),
    "envierons": ("envier",),
    "envieront": ("envier",),
    "enviés": ("envier",),
    "envies": ("envier",),
    "enviez": ("envier",),
    "enviiez": ("envier",),
    "enviions": ("envier",),
    "envions": ("envier",),
    "envisageaient": ("envisager",),
    "envisageai": ("envisager",),
    "envisageais": ("envisager",),
    "envisageait": ("envisager",),
    "envisagea": ("envisager",),
    "envisageâmes": ("envisager",),
    "envisageant": ("envisager",),
    "envisageas": ("envisager",),
    "envisageassent": ("envisager",),
    "envisageasses": ("envisager",),
    "envisageasse": ("envisager",),
    "envisageassiez": ("envisager",),
    "envisageassions": ("envisager",),
    "envisageâtes": ("envisager",),
    "envisageât": ("envisager",),
    "envisagée": ("envisager",),
    "envisagées": ("envisager",),
    "envisagé": ("envisager",),
    "envisagent": ("envisager",),
    "envisageons": ("envisager",),
    "envisage": ("envisager",),
    "envisagera": ("envisager",),
    "envisageraient": ("envisager",),
    "envisagerai": ("envisager",),
    "envisagerais": ("envisager",),
    "envisagerait": ("envisager",),
    "envisageras": ("envisager",),
    "envisagèrent": ("envisager",),
    "envisagerez": ("envisager",),
    "envisageriez": ("envisager",),
    "envisagerions": ("envisager",),
    "envisagerons": ("envisager",),
    "envisageront": ("envisager",),
    "envisagés": ("envisager",),
    "envisages": ("envisager",),
    "envisagez": ("envisager",),
    "envisagiez": ("envisager",),
    "envisagions": ("envisager",),
    "enverra": ("envoyer",),
    "enverraient": ("envoyer",),
    "enverrai": ("envoyer",),
    "enverrais": ("envoyer",),
    "enverrait": ("envoyer",),
    "enverras": ("envoyer",),
    "enverrez": ("envoyer",),
    "enverriez": ("envoyer",),
    "enverrions": ("envoyer",),
    "enverrons": ("envoyer",),
    "enverront": ("envoyer",),
    "envoient": ("envoyer",),
    "envoie": ("envoyer",),
    "envoies": ("envoyer",),
    "envoyaient": ("envoyer",),
    "envoyai": ("envoyer",),
    "envoyais": ("envoyer",),
    "envoyait": ("envoyer",),
    "envoya": ("envoyer",),
    "envoyâmes": ("envoyer",),
    "envoyant": ("envoyer",),
    "envoyas": ("envoyer",),
    "envoyassent": ("envoyer",),
    "envoyasses": ("envoyer",),
    "envoyasse": ("envoyer",),
    "envoyassiez": ("envoyer",),
    "envoyassions": ("envoyer",),
    "envoyâtes": ("envoyer",),
    "envoyât": ("envoyer",),
    "envoyée": ("envoyer",),
    "envoyées": ("envoyer",),
    "envoyé": ("envoyer",),
    "envoyèrent": ("envoyer",),
    "envoyés": ("envoyer",),
    "envoyez": ("envoyer",),
    "envoyiez": ("envoyer",),
    "envoyions": ("envoyer",),
    "envoyons": ("envoyer",),
    "épaissie": ("épaissir",),
    "épaissies": ("épaissir",),
    "épaissi": ("épaissir",),
    "épaissîmes": ("épaissir",),
    "épaissira": ("épaissir",),
    "épaissiraient": ("épaissir",),
    "épaissirai": ("épaissir",),
    "épaissirais": ("épaissir",),
    "épaissirait": ("épaissir",),
    "épaissiras": ("épaissir",),
    "épaissirent": ("épaissir",),
    "épaissirez": ("épaissir",),
    "épaissiriez": ("épaissir",),
    "épaissirions": ("épaissir",),
    "épaissirons": ("épaissir",),
    "épaissiront": ("épaissir",),
    "épaissis": ("épaissir",),
    "épaississaient": ("épaissir",),
    "épaississais": ("épaissir",),
    "épaississait": ("épaissir",),
    "épaississant": ("épaissir",),
    "épaississent": ("épaissir",),
    "épaississe": ("épaissir",),
    "épaississes": ("épaissir",),
    "épaississez": ("épaissir",),
    "épaississiez": ("épaissir",),
    "épaississions": ("épaissir",),
    "épaississons": ("épaissir",),
    "épaissîtes": ("épaissir",),
    "épaissit": ("épaissir",),
    "épaissît": ("épaissir",),
    "épandaient": ("épandre",),
    "épandais": ("épandre",),
    "épandait": ("épandre",),
    "épandant": ("épandre",),
    "épandent": ("épandre",),
    "épande": ("épandre",),
    "épandes": ("épandre",),
    "épandez": ("épandre",),
    "épandiez": ("épandre",),
    "épandîmes": ("épandre",),
    "épandions": ("épandre",),
    "épandirent": ("épandre",),
    "épandis": ("épandre",),
    "épandissent": ("épandre",),
    "épandisses": ("épandre",),
    "épandisse": ("épandre",),
    "épandissiez": ("épandre",),
    "épandissions": ("épandre",),
    "épandîtes": ("épandre",),
    "épandit": ("épandre",),
    "épandît": ("épandre",),
    "épandons": ("épandre",),
    "épand": ("épandre",),
    "épandra": ("épandre",),
    "épandraient": ("épandre",),
    "épandrai": ("épandre",),
    "épandrais": ("épandre",),
    "épandrait": ("épandre",),
    "épandras": ("épandre",),
    "épandrez": ("épandre",),
    "épandriez": ("épandre",),
    "épandrions": ("épandre",),
    "épandrons": ("épandre",),
    "épandront": ("épandre",),
    "épands": ("épandre",),
    "épandue": ("épandre",),
    "épandues": ("épandre",),
    "épandu": ("épandre",),
    "épandus": ("épandre",),
    "épannelaient": ("épanneler",),
    "épannelai": ("épanneler",),
    "épannelais": ("épanneler",),
    "épannelait": ("épanneler",),
    "épannela": ("épanneler",),
    "épannelâmes": ("épanneler",),
    "épannelant": ("épanneler",),
    "épannelas": ("épanneler",),
    "épannelassent": ("épanneler",),
    "épannelasses": ("épanneler",),
    "épannelasse": ("épanneler",),
    "épannelassiez": ("épanneler",),
    "épannelassions": ("épanneler",),
    "épannelâtes": ("épanneler",),
    "épannelât": ("épanneler",),
    "épannelée": ("épanneler",),
    "épannelées": ("épanneler",),
    "épannelé": ("épanneler",),
    "épannelèrent": ("épanneler",),
    "épannelés": ("épanneler",),
    "épannelez": ("épanneler",),
    "épanneliez": ("épanneler",),
    "épannelions": ("épanneler",),
    "épannellent": ("épanneler",),
    "épannelle": ("épanneler",),
    "épannellera": ("épanneler",),
    "épannelleraient": ("épanneler",),
    "épannellerai": ("épanneler",),
    "épannellerais": ("épanneler",),
    "épannellerait": ("épanneler",),
    "épannelleras": ("épanneler",),
    "épannellerez": ("épanneler",),
    "épannelleriez": ("épanneler",),
    "épannellerions": ("épanneler",),
    "épannellerons": ("épanneler",),
    "épannelleront": ("épanneler",),
    "épannelles": ("épanneler",),
    "épannelons": ("épanneler",),
    "épanouie": ("épanouir",),
    "épanouies": ("épanouir",),
    "épanoui": ("épanouir",),
    "épanouîmes": ("épanouir",),
    "épanouira": ("épanouir",),
    "épanouiraient": ("épanouir",),
    "épanouirai": ("épanouir",),
    "épanouirais": ("épanouir",),
    "épanouirait": ("épanouir",),
    "épanouiras": ("épanouir",),
    "épanouirent": ("épanouir",),
    "épanouirez": ("épanouir",),
    "épanouiriez": ("épanouir",),
    "épanouirions": ("épanouir",),
    "épanouirons": ("épanouir",),
    "épanouiront": ("épanouir",),
    "épanouis": ("épanouir",),
    "épanouissaient": ("épanouir",),
    "épanouissais": ("épanouir",),
    "épanouissait": ("épanouir",),
    "épanouissant": ("épanouir",),
    "épanouissent": ("épanouir",),
    "épanouisse": ("épanouir",),
    "épanouisses": ("épanouir",),
    "épanouissez": ("épanouir",),
    "épanouissiez": ("épanouir",),
    "épanouissions": ("épanouir",),
    "épanouissons": ("épanouir",),
    "épanouîtes": ("épanouir",),
    "épanouit": ("épanouir",),
    "épanouît": ("épanouir",),
    "épars": ("épartir",),
    "épartaient": ("épartir",),
    "épartais": ("épartir",),
    "épartait": ("épartir",),
    "épartant": ("épartir",),
    "épartent": ("épartir",),
    "éparte": ("épartir",),
    "épartes": ("épartir",),
    "épartez": ("épartir",),
    "épartie": ("épartir",),
    "éparties": ("épartir",),
    "épartiez": ("épartir",),
    "éparti": ("épartir",),
    "épartîmes": ("épartir",),
    "épartions": ("épartir",),
    "épartira": ("épartir",),
    "épartiraient": ("épartir",),
    "épartirai": ("épartir",),
    "épartirais": ("épartir",),
    "épartirait": ("épartir",),
    "épartiras": ("épartir",),
    "épartirent": ("épartir",),
    "épartirez": ("épartir",),
    "épartiriez": ("épartir",),
    "épartirions": ("épartir",),
    "épartirons": ("épartir",),
    "épartiront": ("épartir",),
    "épartis": ("épartir",),
    "épartissent": ("épartir",),
    "épartisses": ("épartir",),
    "épartisse": ("épartir",),
    "épartissiez": ("épartir",),
    "épartissions": ("épartir",),
    "épartîtes": ("épartir",),
    "épartit": ("épartir",),
    "épartît": ("épartir",),
    "épartons": ("épartir",),
    "épart": ("épartir",),
    "épelaient": ("épeler",),
    "épelai": ("épeler",),
    "épelais": ("épeler",),
    "épelait": ("épeler",),
    "épela": ("épeler",),
    "épelâmes": ("épeler",),
    "épelant": ("épeler",),
    "épelas": ("épeler",),
    "épelassent": ("épeler",),
    "épelasses": ("épeler",),
    "épelasse": ("épeler",),
    "épelassiez": ("épeler",),
    "épelassions": ("épeler",),
    "épelâtes": ("épeler",),
    "épelât": ("épeler",),
    "épelée": ("épeler",),
    "épelées": ("épeler",),
    "épelé": ("épeler",),
    "épelèrent": ("épeler",),
    "épelés": ("épeler",),
    "épelez": ("épeler",),
    "épeliez": ("épeler",),
    "épelions": ("épeler",),
    "épellent": ("épeler",),
    "épelle": ("épeler",),
    "épellera": ("épeler",),
    "épelleraient": ("épeler",),
    "épellerai": ("épeler",),
    "épellerais": ("épeler",),
    "épellerait": ("épeler",),
    "épelleras": ("épeler",),
    "épellerez": ("épeler",),
    "épelleriez": ("épeler",),
    "épellerions": ("épeler",),
    "épellerons": ("épeler",),
    "épelleront": ("épeler",),
    "épelles": ("épeler",),
    "épelons": ("épeler",),
    "épiçaient": ("épicer",),
    "épiçai": ("épicer",),
    "épiçais": ("épicer",),
    "épiçait": ("épicer",),
    "épiça": ("épicer",),
    "épiçâmes": ("épicer",),
    "épiçant": ("épicer",),
    "épiças": ("épicer",),
    "épiçassent": ("épicer",),
    "épiçasses": ("épicer",),
    "épiçasse": ("épicer",),
    "épiçassiez": ("épicer",),
    "épiçassions": ("épicer",),
    "épiçâtes": ("épicer",),
    "épiçât": ("épicer",),
    "épicée": ("épicer",),
    "épicées": ("épicer",),
    "épicé": ("épicer",),
    "épicent": ("épicer",),
    "épice": ("épicer",),
    "épicera": ("épicer",),
    "épiceraient": ("épicer",),
    "épicerai": ("épicer",),
    "épicerais": ("épicer",),
    "épicerait": ("épicer",),
    "épiceras": ("épicer",),
    "épicèrent": ("épicer",),
    "épicerez": ("épicer",),
    "épiceriez": ("épicer",),
    "épicerions": ("épicer",),
    "épicerons": ("épicer",),
    "épiceront": ("épicer",),
    "épicés": ("épicer",),
    "épices": ("épicer",),
    "épicez": ("épicer",),
    "épiciez": ("épicer",),
    "épicions": ("épicer",),
    "épiçons": ("épicer",),
    "épiaient": ("épier",),
    "épiai": ("épier",),
    "épiais": ("épier",),
    "épiait": ("épier",),
    "épia": ("épier",),
    "épiâmes": ("épier",),
    "épiant": ("épier",),
    "épias": ("épier",),
    "épiassent": ("épier",),
    "épiasses": ("épier",),
    "épiasse": ("épier",),
    "épiassiez": ("épier",),
    "épiassions": ("épier",),
    "épiâtes": ("épier",),
    "épiât": ("épier",),
    "épiée": ("épier",),
    "épiées": ("épier",),
    "épié": ("épier",),
    "épient": ("épier",),
    "épie": ("épier",),
    "épiera": ("épier",),
    "épieraient": ("épier",),
    "épierai": ("épier",),
    "épierais": ("épier",),
    "épierait": ("épier",),
    "épieras": ("épier",),
    "épièrent": ("épier",),
    "épierez": ("épier",),
    "épieriez": ("épier",),
    "épierions": ("épier",),
    "épierons": ("épier",),
    "épieront": ("épier",),
    "épiés": ("épier",),
    "épies": ("épier",),
    "épiez": ("épier",),
    "épiiez": ("épier",),
    "épiions": ("épier",),
    "épions": ("épier",),
    "épiétaient": ("épiéter",),
    "épiétai": ("épiéter",),
    "épiétais": ("épiéter",),
    "épiétait": ("épiéter",),
    "épiéta": ("épiéter",),
    "épiétâmes": ("épiéter",),
    "épiétant": ("épiéter",),
    "épiétas": ("épiéter",),
    "épiétassent": ("épiéter",),
    "épiétasses": ("épiéter",),
    "épiétasse": ("épiéter",),
    "épiétassiez": ("épiéter",),
    "épiétassions": ("épiéter",),
    "épiétâtes": ("épiéter",),
    "épiétât": ("épiéter",),
    "épiétée": ("épiéter",),
    "épiétées": ("épiéter",),
    "épiété": ("épiéter",),
    "épiètent": ("épiéter",),
    "épiète": ("épiéter",),
    "épiétera": ("épiéter",),
    "épiéteraient": ("épiéter",),
    "épiéterai": ("épiéter",),
    "épiéterais": ("épiéter",),
    "épiéterait": ("épiéter",),
    "épiéteras": ("épiéter",),
    "épiétèrent": ("épiéter",),
    "épiéterez": ("épiéter",),
    "épiéteriez": ("épiéter",),
    "épiéterions": ("épiéter",),
    "épiéterons": ("épiéter",),
    "épiéteront": ("épiéter",),
    "épiétés": ("épiéter",),
    "épiètes": ("épiéter",),
    "épiétez": ("épiéter",),
    "épiétiez": ("épiéter",),
    "épiétions": ("épiéter",),
    "épiétons": ("épiéter",),
    "épigraphiaient": ("épigraphier",),
    "épigraphiai": ("épigraphier",),
    "épigraphiais": ("épigraphier",),
    "épigraphiait": ("épigraphier",),
    "épigraphia": ("épigraphier",),
    "épigraphiâmes": ("épigraphier",),
    "épigraphiant": ("épigraphier",),
    "épigraphias": ("épigraphier",),
    "épigraphiassent": ("épigraphier",),
    "épigraphiasses": ("épigraphier",),
    "épigraphiasse": ("épigraphier",),
    "épigraphiassiez": ("épigraphier",),
    "épigraphiassions": ("épigraphier",),
    "épigraphiâtes": ("épigraphier",),
    "épigraphiât": ("épigraphier",),
    "épigraphiée": ("épigraphier",),
    "épigraphiées": ("épigraphier",),
    "épigraphié": ("épigraphier",),
    "épigraphient": ("épigraphier",),
    "épigraphie": ("épigraphier",),
    "épigraphiera": ("épigraphier",),
    "épigraphieraient": ("épigraphier",),
    "épigraphierai": ("épigraphier",),
    "épigraphierais": ("épigraphier",),
    "épigraphierait": ("épigraphier",),
    "épigraphieras": ("épigraphier",),
    "épigraphièrent": ("épigraphier",),
    "épigraphierez": ("épigraphier",),
    "épigraphieriez": ("épigraphier",),
    "épigraphierions": ("épigraphier",),
    "épigraphierons": ("épigraphier",),
    "épigraphieront": ("épigraphier",),
    "épigraphiés": ("épigraphier",),
    "épigraphies": ("épigraphier",),
    "épigraphiez": ("épigraphier",),
    "épigraphiiez": ("épigraphier",),
    "épigraphiions": ("épigraphier",),
    "épigraphions": ("épigraphier",),
    "épincelaient": ("épinceler",),
    "épincelai": ("épinceler",),
    "épincelais": ("épinceler",),
    "épincelait": ("épinceler",),
    "épincela": ("épinceler",),
    "épincelâmes": ("épinceler",),
    "épincelant": ("épinceler",),
    "épincelas": ("épinceler",),
    "épincelassent": ("épinceler",),
    "épincelasses": ("épinceler",),
    "épincelasse": ("épinceler",),
    "épincelassiez": ("épinceler",),
    "épincelassions": ("épinceler",),
    "épincelâtes": ("épinceler",),
    "épincelât": ("épinceler",),
    "épincelée": ("épinceler",),
    "épincelées": ("épinceler",),
    "épincelé": ("épinceler",),
    "épincelèrent": ("épinceler",),
    "épincelés": ("épinceler",),
    "épincelez": ("épinceler",),
    "épinceliez": ("épinceler",),
    "épincelions": ("épinceler",),
    "épincellent": ("épinceler",),
    "épincelle": ("épinceler",),
    "épincellera": ("épinceler",),
    "épincelleraient": ("épinceler",),
    "épincellerai": ("épinceler",),
    "épincellerais": ("épinceler",),
    "épincellerait": ("épinceler",),
    "épincelleras": ("épinceler",),
    "épincellerez": ("épinceler",),
    "épincelleriez": ("épinceler",),
    "épincellerions": ("épinceler",),
    "épincellerons": ("épinceler",),
    "épincelleront": ("épinceler",),
    "épincelles": ("épinceler",),
    "épincelons": ("épinceler",),
    "épinçaient": ("épincer",),
    "épinçai": ("épincer",),
    "épinçais": ("épincer",),
    "épinçait": ("épincer",),
    "épinça": ("épincer",),
    "épinçâmes": ("épincer",),
    "épinçant": ("épincer",),
    "épinças": ("épincer",),
    "épinçassent": ("épincer",),
    "épinçasses": ("épincer",),
    "épinçasse": ("épincer",),
    "épinçassiez": ("épincer",),
    "épinçassions": ("épincer",),
    "épinçâtes": ("épincer",),
    "épinçât": ("épincer",),
    "épincée": ("épincer",),
    "épincées": ("épincer",),
    "épincé": ("épincer",),
    "épincent": ("épincer",),
    "épince": ("épincer",),
    "épincera": ("épincer",),
    "épinceraient": ("épincer",),
    "épincerai": ("épincer",),
    "épincerais": ("épincer",),
    "épincerait": ("épincer",),
    "épinceras": ("épincer",),
    "épincèrent": ("épincer",),
    "épincerez": ("épincer",),
    "épinceriez": ("épincer",),
    "épincerions": ("épincer",),
    "épincerons": ("épincer",),
    "épinceront": ("épincer",),
    "épincés": ("épincer",),
    "épinces": ("épincer",),
    "épincez": ("épincer",),
    "épinciez": ("épincer",),
    "épincions": ("épincer",),
    "épinçons": ("épincer",),
    "épincetaient": ("épinceter",),
    "épincetai": ("épinceter",),
    "épincetais": ("épinceter",),
    "épincetait": ("épinceter",),
    "épinceta": ("épinceter",),
    "épincetâmes": ("épinceter",),
    "épincetant": ("épinceter",),
    "épincetas": ("épinceter",),
    "épincetassent": ("épinceter",),
    "épincetasses": ("épinceter",),
    "épincetasse": ("épinceter",),
    "épincetassiez": ("épinceter",),
    "épincetassions": ("épinceter",),
    "épincetâtes": ("épinceter",),
    "épincetât": ("épinceter",),
    "épincetée": ("épinceter",),
    "épincetées": ("épinceter",),
    "épinceté": ("épinceter",),
    "épincetèrent": ("épinceter",),
    "épincetés": ("épinceter",),
    "épincetez": ("épinceter",),
    "épincetiez": ("épinceter",),
    "épincetions": ("épinceter",),
    "épincetons": ("épinceter",),
    "épincettent": ("épinceter",),
    "épincette": ("épinceter",),
    "épincettera": ("épinceter",),
    "épincetteraient": ("épinceter",),
    "épincetterai": ("épinceter",),
    "épincetterais": ("épinceter",),
    "épincetterait": ("épinceter",),
    "épincetteras": ("épinceter",),
    "épincetterez": ("épinceter",),
    "épincetteriez": ("épinceter",),
    "épincetterions": ("épinceter",),
    "épincetterons": ("épinceter",),
    "épincetteront": ("épinceter",),
    "épincettes": ("épinceter",),
    "épitaxiaient": ("épitaxier",),
    "épitaxiai": ("épitaxier",),
    "épitaxiais": ("épitaxier",),
    "épitaxiait": ("épitaxier",),
    "épitaxia": ("épitaxier",),
    "épitaxiâmes": ("épitaxier",),
    "épitaxiant": ("épitaxier",),
    "épitaxias": ("épitaxier",),
    "épitaxiassent": ("épitaxier",),
    "épitaxiasses": ("épitaxier",),
    "épitaxiasse": ("épitaxier",),
    "épitaxiassiez": ("épitaxier",),
    "épitaxiassions": ("épitaxier",),
    "épitaxiâtes": ("épitaxier",),
    "épitaxiât": ("épitaxier",),
    "épitaxiée": ("épitaxier",),
    "épitaxiées": ("épitaxier",),
    "épitaxié": ("épitaxier",),
    "épitaxient": ("épitaxier",),
    "épitaxie": ("épitaxier",),
    "épitaxiera": ("épitaxier",),
    "épitaxieraient": ("épitaxier",),
    "épitaxierai": ("épitaxier",),
    "épitaxierais": ("épitaxier",),
    "épitaxierait": ("épitaxier",),
    "épitaxieras": ("épitaxier",),
    "épitaxièrent": ("épitaxier",),
    "épitaxierez": ("épitaxier",),
    "épitaxieriez": ("épitaxier",),
    "épitaxierions": ("épitaxier",),
    "épitaxierons": ("épitaxier",),
    "épitaxieront": ("épitaxier",),
    "épitaxiés": ("épitaxier",),
    "épitaxies": ("épitaxier",),
    "épitaxiez": ("épitaxier",),
    "épitaxiiez": ("épitaxier",),
    "épitaxiions": ("épitaxier",),
    "épitaxions": ("épitaxier",),
    "éploient": ("éployer",),
    "éploie": ("éployer",),
    "éploiera": ("éployer",),
    "éploieraient": ("éployer",),
    "éploierai": ("éployer",),
    "éploierais": ("éployer",),
    "éploierait": ("éployer",),
    "éploieras": ("éployer",),
    "éploierez": ("éployer",),
    "éploieriez": ("éployer",),
    "éploierions": ("éployer",),
    "éploierons": ("éployer",),
    "éploieront": ("éployer",),
    "éploies": ("éployer",),
    "éployaient": ("éployer",),
    "éployai": ("éployer",),
    "éployais": ("éployer",),
    "éployait": ("éployer",),
    "éploya": ("éployer",),
    "éployâmes": ("éployer",),
    "éployant": ("éployer",),
    "éployas": ("éployer",),
    "éployassent": ("éployer",),
    "éployasses": ("éployer",),
    "éployasse": ("éployer",),
    "éployassiez": ("éployer",),
    "éployassions": ("éployer",),
    "éployâtes": ("éployer",),
    "éployât": ("éployer",),
    "éployée": ("éployer",),
    "éployées": ("éployer",),
    "éployé": ("éployer",),
    "éployèrent": ("éployer",),
    "éployés": ("éployer",),
    "éployez": ("éployer",),
    "éployiez": ("éployer",),
    "éployions": ("éployer",),
    "éployons": ("éployer",),
    "épongeaient": ("éponger",),
    "épongeai": ("éponger",),
    "épongeais": ("éponger",),
    "épongeait": ("éponger",),
    "épongea": ("éponger",),
    "épongeâmes": ("éponger",),
    "épongeant": ("éponger",),
    "épongeas": ("éponger",),
    "épongeassent": ("éponger",),
    "épongeasses": ("éponger",),
    "épongeasse": ("éponger",),
    "épongeassiez": ("éponger",),
    "épongeassions": ("éponger",),
    "épongeâtes": ("éponger",),
    "épongeât": ("éponger",),
    "épongée": ("éponger",),
    "épongées": ("éponger",),
    "épongé": ("éponger",),
    "épongent": ("éponger",),
    "épongeons": ("éponger",),
    "éponge": ("éponger",),
    "épongera": ("éponger",),
    "épongeraient": ("éponger",),
    "épongerai": ("éponger",),
    "épongerais": ("éponger",),
    "épongerait": ("éponger",),
    "épongeras": ("éponger",),
    "épongèrent": ("éponger",),
    "épongerez": ("éponger",),
    "épongeriez": ("éponger",),
    "épongerions": ("éponger",),
    "épongerons": ("éponger",),
    "épongeront": ("éponger",),
    "épongés": ("éponger",),
    "éponges": ("éponger",),
    "épongez": ("éponger",),
    "épongiez": ("éponger",),
    "épongions": ("éponger",),
    "époussetaient": ("épousseter",),
    "époussetai": ("épousseter",),
    "époussetais": ("épousseter",),
    "époussetait": ("épousseter",),
    "épousseta": ("épousseter",),
    "époussetâmes": ("épousseter",),
    "époussetant": ("épousseter",),
    "époussetas": ("épousseter",),
    "époussetassent": ("épousseter",),
    "époussetasses": ("épousseter",),
    "époussetasse": ("épousseter",),
    "époussetassiez": ("épousseter",),
    "époussetassions": ("épousseter",),
    "époussetâtes": ("épousseter",),
    "époussetât": ("épousseter",),
    "époussetée": ("épousseter",),
    "époussetées": ("épousseter",),
    "épousseté": ("épousseter",),
    "époussetèrent": ("épousseter",),
    "époussetés": ("épousseter",),
    "époussetez": ("épousseter",),
    "époussetiez": ("épousseter",),
    "époussetions": ("épousseter",),
    "époussetons": ("épousseter",),
    "époussettent": ("épousseter",),
    "époussette": ("épousseter",),
    "époussettera": ("épousseter",),
    "époussetteraient": ("épousseter",),
    "époussetterai": ("épousseter",),
    "époussetterais": ("épousseter",),
    "époussetterait": ("épousseter",),
    "époussetteras": ("épousseter",),
    "époussetterez": ("épousseter",),
    "époussetteriez": ("épousseter",),
    "époussetterions": ("épousseter",),
    "époussetterons": ("épousseter",),
    "époussetteront": ("épousseter",),
    "époussettes": ("épousseter",),
    "époutiaient": ("époutier",),
    "époutiai": ("époutier",),
    "époutiais": ("époutier",),
    "époutiait": ("époutier",),
    "époutia": ("époutier",),
    "époutiâmes": ("époutier",),
    "époutiant": ("époutier",),
    "époutias": ("époutier",),
    "époutiassent": ("époutier",),
    "époutiasses": ("époutier",),
    "époutiasse": ("époutier",),
    "époutiassiez": ("époutier",),
    "époutiassions": ("époutier",),
    "époutiâtes": ("époutier",),
    "époutiât": ("époutier",),
    "époutiée": ("époutier",),
    "époutiées": ("époutier",),
    "époutié": ("époutier",),
    "époutient": ("époutier",),
    "époutie": ("époutir",),
    "époutiera": ("époutier",),
    "époutieraient": ("époutier",),
    "époutierai": ("époutier",),
    "époutierais": ("époutier",),
    "époutierait": ("époutier",),
    "époutieras": ("époutier",),
    "époutièrent": ("époutier",),
    "époutierez": ("époutier",),
    "époutieriez": ("époutier",),
    "époutierions": ("époutier",),
    "époutierons": ("époutier",),
    "époutieront": ("époutier",),
    "époutiés": ("époutier",),
    "épouties": ("époutir",),
    "époutiez": ("époutier",),
    "époutiiez": ("époutier",),
    "époutiions": ("époutier",),
    "époutions": ("époutier",),
    "épouti": ("époutir",),
    "époutîmes": ("époutir",),
    "époutira": ("époutir",),
    "époutiraient": ("époutir",),
    "époutirai": ("époutir",),
    "époutirais": ("époutir",),
    "époutirait": ("époutir",),
    "époutiras": ("époutir",),
    "époutirent": ("époutir",),
    "époutirez": ("époutir",),
    "époutiriez": ("époutir",),
    "époutirions": ("époutir",),
    "époutirons": ("époutir",),
    "époutiront": ("époutir",),
    "époutis": ("époutir",),
    "époutissaient": ("époutir",),
    "époutissais": ("époutir",),
    "époutissait": ("époutir",),
    "époutissant": ("époutir",),
    "époutissent": ("époutir",),
    "époutisse": ("époutir",),
    "époutisses": ("époutir",),
    "époutissez": ("époutir",),
    "époutissiez": ("époutir",),
    "époutissions": ("époutir",),
    "époutissons": ("époutir",),
    "époutîtes": ("époutir",),
    "époutit": ("époutir",),
    "époutît": ("époutir",),
    "épreignaient": ("épreindre",),
    "épreignais": ("épreindre",),
    "épreignait": ("épreindre",),
    "épreignant": ("épreindre",),
    "épreignent": ("épreindre",),
    "épreigne": ("épreindre",),
    "épreignes": ("épreindre",),
    "épreignez": ("épreindre",),
    "épreigniez": ("épreindre",),
    "épreignîmes": ("épreindre",),
    "épreignions": ("épreindre",),
    "épreignirent": ("épreindre",),
    "épreignis": ("épreindre",),
    "épreignissent": ("épreindre",),
    "épreignisses": ("épreindre",),
    "épreignisse": ("épreindre",),
    "épreignissiez": ("épreindre",),
    "épreignissions": ("épreindre",),
    "épreignîtes": ("épreindre",),
    "épreignit": ("épreindre",),
    "épreignît": ("épreindre",),
    "épreignons": ("épreindre",),
    "épreindra": ("épreindre",),
    "épreindraient": ("épreindre",),
    "épreindrai": ("épreindre",),
    "épreindrais": ("épreindre",),
    "épreindrait": ("épreindre",),
    "épreindras": ("épreindre",),
    "épreindrez": ("épreindre",),
    "épreindriez": ("épreindre",),
    "épreindrions": ("épreindre",),
    "épreindrons": ("épreindre",),
    "épreindront": ("épreindre",),
    "épreins": ("épreindre",),
    "épreinte": ("épreindre",),
    "épreintes": ("épreindre",),
    "épreint": ("épreindre",),
    "épreints": ("épreindre",),
    "éprenaient": ("éprendre",),
    "éprenais": ("éprendre",),
    "éprenait": ("éprendre",),
    "éprenant": ("éprendre",),
    "éprend": ("éprendre",),
    "éprendra": ("éprendre",),
    "éprendraient": ("éprendre",),
    "éprendrai": ("éprendre",),
    "éprendrais": ("éprendre",),
    "éprendrait": ("éprendre",),
    "éprendras": ("éprendre",),
    "éprendrez": ("éprendre",),
    "éprendriez": ("éprendre",),
    "éprendrions": ("éprendre",),
    "éprendrons": ("éprendre",),
    "éprendront": ("éprendre",),
    "éprends": ("éprendre",),
    "éprenez": ("éprendre",),
    "épreniez": ("éprendre",),
    "éprenions": ("éprendre",),
    "éprennent": ("éprendre",),
    "éprenne": ("éprendre",),
    "éprennes": ("éprendre",),
    "éprenons": ("éprendre",),
    "éprîmes": ("éprendre",),
    "éprirent": ("éprendre",),
    "éprise": ("éprendre",),
    "éprises": ("éprendre",),
    "épris": ("éprendre",),
    "éprissent": ("éprendre",),
    "éprisses": ("éprendre",),
    "éprisse": ("éprendre",),
    "éprissiez": ("éprendre",),
    "éprissions": ("éprendre",),
    "éprîtes": ("éprendre",),
    "éprit": ("éprendre",),
    "éprît": ("éprendre",),
    "épuçaient": ("épucer",),
    "épuçai": ("épucer",),
    "épuçais": ("épucer",),
    "épuçait": ("épucer",),
    "épuça": ("épucer",),
    "épuçâmes": ("épucer",),
    "épuçant": ("épucer",),
    "épuças": ("épucer",),
    "épuçassent": ("épucer",),
    "épuçasses": ("épucer",),
    "épuçasse": ("épucer",),
    "épuçassiez": ("épucer",),
    "épuçassions": ("épucer",),
    "épuçâtes": ("épucer",),
    "épuçât": ("épucer",),
    "épucée": ("épucer",),
    "épucées": ("épucer",),
    "épucé": ("épucer",),
    "épucent": ("épucer",),
    "épuce": ("épucer",),
    "épucera": ("épucer",),
    "épuceraient": ("épucer",),
    "épucerai": ("épucer",),
    "épucerais": ("épucer",),
    "épucerait": ("épucer",),
    "épuceras": ("épucer",),
    "épucèrent": ("épucer",),
    "épucerez": ("épucer",),
    "épuceriez": ("épucer",),
    "épucerions": ("épucer",),
    "épucerons": ("épucer",),
    "épuceront": ("épucer",),
    "épucés": ("épucer",),
    "épuces": ("épucer",),
    "épucez": ("épucer",),
    "épuciez": ("épucer",),
    "épucions": ("épucer",),
    "épuçons": ("épucer",),
    "épuisetaient": ("épuiseter",),
    "épuisetai": ("épuiseter",),
    "épuisetais": ("épuiseter",),
    "épuisetait": ("épuiseter",),
    "épuiseta": ("épuiseter",),
    "épuisetâmes": ("épuiseter",),
    "épuisetant": ("épuiseter",),
    "épuisetas": ("épuiseter",),
    "épuisetassent": ("épuiseter",),
    "épuisetasses": ("épuiseter",),
    "épuisetasse": ("épuiseter",),
    "épuisetassiez": ("épuiseter",),
    "épuisetassions": ("épuiseter",),
    "épuisetâtes": ("épuiseter",),
    "épuisetât": ("épuiseter",),
    "épuisetée": ("épuiseter",),
    "épuisetées": ("épuiseter",),
    "épuiseté": ("épuiseter",),
    "épuisetèrent": ("épuiseter",),
    "épuisetés": ("épuiseter",),
    "épuisetez": ("épuiseter",),
    "épuisetiez": ("épuiseter",),
    "épuisetions": ("épuiseter",),
    "épuisetons": ("épuiseter",),
    "épuisettent": ("épuiseter",),
    "épuisette": ("épuiseter",),
    "épuisettera": ("épuiseter",),
    "épuisetteraient": ("épuiseter",),
    "épuisetterai": ("épuiseter",),
    "épuisetterais": ("épuiseter",),
    "épuisetterait": ("épuiseter",),
    "épuisetteras": ("épuiseter",),
    "épuisetterez": ("épuiseter",),
    "épuisetteriez": ("épuiseter",),
    "épuisetterions": ("épuiseter",),
    "épuisetterons": ("épuiseter",),
    "épuisetteront": ("épuiseter",),
    "épuisettes": ("épuiseter",),
    "équarriaient": ("équarrier",),
    "équarriai": ("équarrier",),
    "équarriais": ("équarrier",),
    "équarriait": ("équarrier",),
    "équarria": ("équarrier",),
    "équarriâmes": ("équarrier",),
    "équarriant": ("équarrier",),
    "équarrias": ("équarrier",),
    "équarriassent": ("équarrier",),
    "équarriasses": ("équarrier",),
    "équarriasse": ("équarrier",),
    "équarriassiez": ("équarrier",),
    "équarriassions": ("équarrier",),
    "équarriâtes": ("équarrier",),
    "équarriât": ("équarrier",),
    "équarriée": ("équarrier",),
    "équarriées": ("équarrier",),
    "équarrié": ("équarrier",),
    "équarrient": ("équarrier",),
    "équarrie": ("équarrir",),
    "équarriera": ("équarrier",),
    "équarrieraient": ("équarrier",),
    "équarrierai": ("équarrier",),
    "équarrierais": ("équarrier",),
    "équarrierait": ("équarrier",),
    "équarrieras": ("équarrier",),
    "équarrièrent": ("équarrier",),
    "équarrierez": ("équarrier",),
    "équarrieriez": ("équarrier",),
    "équarrierions": ("équarrier",),
    "équarrierons": ("équarrier",),
    "équarrieront": ("équarrier",),
    "équarriés": ("équarrier",),
    "équarries": ("équarrir",),
    "équarriez": ("équarrier",),
    "équarriiez": ("équarrier",),
    "équarriions": ("équarrier",),
    "équarrions": ("équarrier",),
    "équarri": ("équarrir",),
    "équarrîmes": ("équarrir",),
    "équarrira": ("équarrir",),
    "équarriraient": ("équarrir",),
    "équarrirai": ("équarrir",),
    "équarrirais": ("équarrir",),
    "équarrirait": ("équarrir",),
    "équarriras": ("équarrir",),
    "équarrirent": ("équarrir",),
    "équarrirez": ("équarrir",),
    "équarririez": ("équarrir",),
    "équarririons": ("équarrir",),
    "équarrirons": ("équarrir",),
    "équarriront": ("équarrir",),
    "équarris": ("équarrir",),
    "équarrissaient": ("équarrir",),
    "équarrissais": ("équarrir",),
    "équarrissait": ("équarrir",),
    "équarrissant": ("équarrir",),
    "équarrissent": ("équarrir",),
    "équarrisse": ("équarrir",),
    "équarrisses": ("équarrir",),
    "équarrissez": ("équarrir",),
    "équarrissiez": ("équarrir",),
    "équarrissions": ("équarrir",),
    "équarrissons": ("équarrir",),
    "équarrîtes": ("équarrir",),
    "équarrit": ("équarrir",),
    "équarrît": ("équarrir",),
    "équivaillent": ("équivaloir",),
    "équivaille": ("équivaloir",),
    "équivailles": ("équivaloir",),
    "équivalaient": ("équivaloir",),
    "équivalais": ("équivaloir",),
    "équivalait": ("équivaloir",),
    "équivalant": ("équivaloir",),
    "équivalent": ("équivaloir",),
    "équivalez": ("équivaloir",),
    "équivaliez": ("équivaloir",),
    "équivalions": ("équivaloir",),
    "équivalons": ("équivaloir",),
    "équivalue": ("équivaloir",),
    "équivalues": ("équivaloir",),
    "équivalu": ("équivaloir",),
    "équivalûmes": ("équivaloir",),
    "équivalurent": ("équivaloir",),
    "équivalus": ("équivaloir",),
    "équivalussent": ("équivaloir",),
    "équivalusses": ("équivaloir",),
    "équivalusse": ("équivaloir",),
    "équivalussiez": ("équivaloir",),
    "équivalussions": ("équivaloir",),
    "équivalûtes": ("équivaloir",),
    "équivalut": ("équivaloir",),
    "équivalût": ("équivaloir",),
    "équivaudra": ("équivaloir",),
    "équivaudraient": ("équivaloir",),
    "équivaudrai": ("équivaloir",),
    "équivaudrais": ("équivaloir",),
    "équivaudrait": ("équivaloir",),
    "équivaudras": ("équivaloir",),
    "équivaudrez": ("équivaloir",),
    "équivaudriez": ("équivaloir",),
    "équivaudrions": ("équivaloir",),
    "équivaudrons": ("équivaloir",),
    "équivaudront": ("équivaloir",),
    "équivaut": ("équivaloir",),
    "équivaux": ("équivaloir",),
    "éraient": ("érayer",),
    "éraie": ("érayer",),
    "éraiera": ("érayer",),
    "éraieraient": ("érayer",),
    "éraierai": ("érayer",),
    "éraierais": ("érayer",),
    "éraierait": ("érayer",),
    "éraieras": ("érayer",),
    "éraierez": ("érayer",),
    "éraieriez": ("érayer",),
    "éraierions": ("érayer",),
    "éraierons": ("érayer",),
    "éraieront": ("érayer",),
    "éraies": ("érayer",),
    "érayaient": ("érayer",),
    "érayai": ("érayer",),
    "érayais": ("érayer",),
    "érayait": ("érayer",),
    "éraya": ("érayer",),
    "érayâmes": ("érayer",),
    "érayant": ("érayer",),
    "érayas": ("érayer",),
    "érayassent": ("érayer",),
    "érayasses": ("érayer",),
    "érayasse": ("érayer",),
    "érayassiez": ("érayer",),
    "érayassions": ("érayer",),
    "érayâtes": ("érayer",),
    "érayât": ("érayer",),
    "érayée": ("érayer",),
    "érayées": ("érayer",),
    "érayé": ("érayer",),
    "érayent": ("érayer",),
    "éraye": ("érayer",),
    "érayera": ("érayer",),
    "érayeraient": ("érayer",),
    "érayerai": ("érayer",),
    "érayerais": ("érayer",),
    "érayerait": ("érayer",),
    "érayeras": ("érayer",),
    "érayèrent": ("érayer",),
    "érayerez": ("érayer",),
    "érayeriez": ("érayer",),
    "érayerions": ("érayer",),
    "érayerons": ("érayer",),
    "érayeront": ("érayer",),
    "érayés": ("érayer",),
    "érayes": ("érayer",),
    "érayez": ("érayer",),
    "érayiez": ("érayer",),
    "érayions": ("érayer",),
    "érayons": ("érayer",),
    "érigeaient": ("ériger",),
    "érigeai": ("ériger",),
    "érigeais": ("ériger",),
    "érigeait": ("ériger",),
    "érigea": ("ériger",),
    "érigeâmes": ("ériger",),
    "érigeant": ("ériger",),
    "érigeas": ("ériger",),
    "érigeassent": ("ériger",),
    "érigeasses": ("ériger",),
    "érigeasse": ("ériger",),
    "érigeassiez": ("ériger",),
    "érigeassions": ("ériger",),
    "érigeâtes": ("ériger",),
    "érigeât": ("ériger",),
    "érigée": ("ériger",),
    "érigées": ("ériger",),
    "érigé": ("ériger",),
    "érigent": ("ériger",),
    "érigeons": ("ériger",),
    "érige": ("ériger",),
    "érigera": ("ériger",),
    "érigeraient": ("ériger",),
    "érigerai": ("ériger",),
    "érigerais": ("ériger",),
    "érigerait": ("ériger",),
    "érigeras": ("ériger",),
    "érigèrent": ("ériger",),
    "érigerez": ("ériger",),
    "érigeriez": ("ériger",),
    "érigerions": ("ériger",),
    "érigerons": ("ériger",),
    "érigeront": ("ériger",),
    "érigés": ("ériger",),
    "ériges": ("ériger",),
    "érigez": ("ériger",),
    "érigiez": ("ériger",),
    "érigions": ("ériger",),
    "érucie": ("érucir",),
    "érucies": ("érucir",),
    "éruci": ("érucir",),
    "érucîmes": ("érucir",),
    "érucira": ("érucir",),
    "éruciraient": ("érucir",),
    "érucirai": ("érucir",),
    "érucirais": ("érucir",),
    "érucirait": ("érucir",),
    "éruciras": ("érucir",),
    "érucirent": ("érucir",),
    "érucirez": ("érucir",),
    "éruciriez": ("érucir",),
    "érucirions": ("érucir",),
    "érucirons": ("érucir",),
    "éruciront": ("érucir",),
    "érucis": ("érucir",),
    "érucissaient": ("érucir",),
    "érucissais": ("érucir",),
    "érucissait": ("érucir",),
    "érucissant": ("érucir",),
    "érucissent": ("érucir",),
    "érucisse": ("érucir",),
    "érucisses": ("érucir",),
    "érucissez": ("érucir",),
    "érucissiez": ("érucir",),
    "érucissions": ("érucir",),
    "érucissons": ("érucir",),
    "érucîtes": ("érucir",),
    "érucit": ("érucir",),
    "érucît": ("érucir",),
    "esbaudie": ("esbaudir",),
    "esbaudies": ("esbaudir",),
    "esbaudi": ("esbaudir",),
    "esbaudîmes": ("esbaudir",),
    "esbaudira": ("esbaudir",),
    "esbaudiraient": ("esbaudir",),
    "esbaudirai": ("esbaudir",),
    "esbaudirais": ("esbaudir",),
    "esbaudirait": ("esbaudir",),
    "esbaudiras": ("esbaudir",),
    "esbaudirent": ("esbaudir",),
    "esbaudirez": ("esbaudir",),
    "esbaudiriez": ("esbaudir",),
    "esbaudirions": ("esbaudir",),
    "esbaudirons": ("esbaudir",),
    "esbaudiront": ("esbaudir",),
    "esbaudis": ("esbaudir",),
    "esbaudissaient": ("esbaudir",),
    "esbaudissais": ("esbaudir",),
    "esbaudissait": ("esbaudir",),
    "esbaudissant": ("esbaudir",),
    "esbaudissent": ("esbaudir",),
    "esbaudisse": ("esbaudir",),
    "esbaudisses": ("esbaudir",),
    "esbaudissez": ("esbaudir",),
    "esbaudissiez": ("esbaudir",),
    "esbaudissions": ("esbaudir",),
    "esbaudissons": ("esbaudir",),
    "esbaudîtes": ("esbaudir",),
    "esbaudit": ("esbaudir",),
    "esbaudît": ("esbaudir",),
    "escabéchaient": ("escabécher",),
    "escabéchai": ("escabécher",),
    "escabéchais": ("escabécher",),
    "escabéchait": ("escabécher",),
    "escabécha": ("escabécher",),
    "escabéchâmes": ("escabécher",),
    "escabéchant": ("escabécher",),
    "escabéchas": ("escabécher",),
    "escabéchassent": ("escabécher",),
    "escabéchasses": ("escabécher",),
    "escabéchasse": ("escabécher",),
    "escabéchassiez": ("escabécher",),
    "escabéchassions": ("escabécher",),
    "escabéchâtes": ("escabécher",),
    "escabéchât": ("escabécher",),
    "escabéchée": ("escabécher",),
    "escabéchées": ("escabécher",),
    "escabéché": ("escabécher",),
    "escabèchent": ("escabécher",),
    "escabèche": ("escabécher",),
    "escabéchera": ("escabécher",),
    "escabécheraient": ("escabécher",),
    "escabécherai": ("escabécher",),
    "escabécherais": ("escabécher",),
    "escabécherait": ("escabécher",),
    "escabécheras": ("escabécher",),
    "escabéchèrent": ("escabécher",),
    "escabécherez": ("escabécher",),
    "escabécheriez": ("escabécher",),
    "escabécherions": ("escabécher",),
    "escabécherons": ("escabécher",),
    "escabécheront": ("escabécher",),
    "escabéchés": ("escabécher",),
    "escabèches": ("escabécher",),
    "escabéchez": ("escabécher",),
    "escabéchiez": ("escabécher",),
    "escabéchions": ("escabécher",),
    "escabéchons": ("escabécher",),
    "escagassaient": ("escagasser",),
    "escagassai": ("escagasser",),
    "escagassais": ("escagasser",),
    "escagassait": ("escagasser",),
    "escagassa": ("escagasser",),
    "escagassâmes": ("escagasser",),
    "escagassant": ("escagasser",),
    "escagassas": ("escagasser",),
    "escagassassent": ("escagasser",),
    "escagassasses": ("escagasser",),
    "escagassasse": ("escagasser",),
    "escagassassiez": ("escagasser",),
    "escagassassions": ("escagasser",),
    "escagassâtes": ("escagasser",),
    "escagassât": ("escagasser",),
    "escagassée": ("escagasser",),
    "escagassées": ("escagasser",),
    "escagassé": ("escagasser",),
    "escagassent": ("escagasser",),
    "escagasse": ("escagasser",),
    "escagassera": ("escagasser",),
    "escagasseraient": ("escagasser",),
    "escagasserai": ("escagasser",),
    "escagasserais": ("escagasser",),
    "escagasserait": ("escagasser",),
    "escagasseras": ("escagasser",),
    "escagassèrent": ("escagasser",),
    "escagasserez": ("escagasser",),
    "escagasseriez": ("escagasser",),
    "escagasserions": ("escagasser",),
    "escagasserons": ("escagasser",),
    "escagasseront": ("escagasser",),
    "escagassés": ("escagasser",),
    "escagasses": ("escagasser",),
    "escagassez": ("escagasser",),
    "escagassiez": ("escagasser",),
    "escagassions": ("escagasser",),
    "escagassons": ("escagasser",),
    "escargassaient": ("escargasser",),
    "escargassai": ("escargasser",),
    "escargassais": ("escargasser",),
    "escargassait": ("escargasser",),
    "escargassa": ("escargasser",),
    "escargassâmes": ("escargasser",),
    "escargassant": ("escargasser",),
    "escargassas": ("escargasser",),
    "escargassassent": ("escargasser",),
    "escargassasses": ("escargasser",),
    "escargassasse": ("escargasser",),
    "escargassassiez": ("escargasser",),
    "escargassassions": ("escargasser",),
    "escargassâtes": ("escargasser",),
    "escargassât": ("escargasser",),
    "escargassée": ("escargasser",),
    "escargassées": ("escargasser",),
    "escargassé": ("escargasser",),
    "escargassent": ("escargasser",),
    "escargasse": ("escargasser",),
    "escargassera": ("escargasser",),
    "escargasseraient": ("escargasser",),
    "escargasserai": ("escargasser",),
    "escargasserais": ("escargasser",),
    "escargasserait": ("escargasser",),
    "escargasseras": ("escargasser",),
    "escargassèrent": ("escargasser",),
    "escargasserez": ("escargasser",),
    "escargasseriez": ("escargasser",),
    "escargasserions": ("escargasser",),
    "escargasserons": ("escargasser",),
    "escargasseront": ("escargasser",),
    "escargassés": ("escargasser",),
    "escargasses": ("escargasser",),
    "escargassez": ("escargasser",),
    "escargassiez": ("escargasser",),
    "escargassions": ("escargasser",),
    "escargassons": ("escargasser",),
    "escarifiaient": ("escarifier",),
    "escarifiai": ("escarifier",),
    "escarifiais": ("escarifier",),
    "escarifiait": ("escarifier",),
    "escarifia": ("escarifier",),
    "escarifiâmes": ("escarifier",),
    "escarifiant": ("escarifier",),
    "escarifias": ("escarifier",),
    "escarifiassent": ("escarifier",),
    "escarifiasses": ("escarifier",),
    "escarifiasse": ("escarifier",),
    "escarifiassiez": ("escarifier",),
    "escarifiassions": ("escarifier",),
    "escarifiâtes": ("escarifier",),
    "escarifiât": ("escarifier",),
    "escarifiée": ("escarifier",),
    "escarifiées": ("escarifier",),
    "escarifié": ("escarifier",),
    "escarifient": ("escarifier",),
    "escarifie": ("escarifier",),
    "escarifiera": ("escarifier",),
    "escarifieraient": ("escarifier",),
    "escarifierai": ("escarifier",),
    "escarifierais": ("escarifier",),
    "escarifierait": ("escarifier",),
    "escarifieras": ("escarifier",),
    "escarifièrent": ("escarifier",),
    "escarifierez": ("escarifier",),
    "escarifieriez": ("escarifier",),
    "escarifierions": ("escarifier",),
    "escarifierons": ("escarifier",),
    "escarifieront": ("escarifier",),
    "escarifiés": ("escarifier",),
    "escarifies": ("escarifier",),
    "escarifiez": ("escarifier",),
    "escarifiiez": ("escarifier",),
    "escarifiions": ("escarifier",),
    "escarifions": ("escarifier",),
    "escarrifiaient": ("escarrifier",),
    "escarrifiai": ("escarrifier",),
    "escarrifiais": ("escarrifier",),
    "escarrifiait": ("escarrifier",),
    "escarrifia": ("escarrifier",),
    "escarrifiâmes": ("escarrifier",),
    "escarrifiant": ("escarrifier",),
    "escarrifias": ("escarrifier",),
    "escarrifiassent": ("escarrifier",),
    "escarrifiasses": ("escarrifier",),
    "escarrifiasse": ("escarrifier",),
    "escarrifiassiez": ("escarrifier",),
    "escarrifiassions": ("escarrifier",),
    "escarrifiâtes": ("escarrifier",),
    "escarrifiât": ("escarrifier",),
    "escarrifiée": ("escarrifier",),
    "escarrifiées": ("escarrifier",),
    "escarrifié": ("escarrifier",),
    "escarrifient": ("escarrifier",),
    "escarrifie": ("escarrifier",),
    "escarrifiera": ("escarrifier",),
    "escarrifieraient": ("escarrifier",),
    "escarrifierai": ("escarrifier",),
    "escarrifierais": ("escarrifier",),
    "escarrifierait": ("escarrifier",),
    "escarrifieras": ("escarrifier",),
    "escarrifièrent": ("escarrifier",),
    "escarrifierez": ("escarrifier",),
    "escarrifieriez": ("escarrifier",),
    "escarrifierions": ("escarrifier",),
    "escarrifierons": ("escarrifier",),
    "escarrifieront": ("escarrifier",),
    "escarrifiés": ("escarrifier",),
    "escarrifies": ("escarrifier",),
    "escarrifiez": ("escarrifier",),
    "escarrifiiez": ("escarrifier",),
    "escarrifiions": ("escarrifier",),
    "escarrifions": ("escarrifier",),
    "esclavageaient": ("esclavager",),
    "esclavageai": ("esclavager",),
    "esclavageais": ("esclavager",),
    "esclavageait": ("esclavager",),
    "esclavagea": ("esclavager",),
    "esclavageâmes": ("esclavager",),
    "esclavageant": ("esclavager",),
    "esclavageas": ("esclavager",),
    "esclavageassent": ("esclavager",),
    "esclavageasses": ("esclavager",),
    "esclavageasse": ("esclavager",),
    "esclavageassiez": ("esclavager",),
    "esclavageassions": ("esclavager",),
    "esclavageâtes": ("esclavager",),
    "esclavageât": ("esclavager",),
    "esclavagée": ("esclavager",),
    "esclavagées": ("esclavager",),
    "esclavagé": ("esclavager",),
    "esclavagent": ("esclavager",),
    "esclavageons": ("esclavager",),
    "esclavage": ("esclavager",),
    "esclavagera": ("esclavager",),
    "esclavageraient": ("esclavager",),
    "esclavagerai": ("esclavager",),
    "esclavagerais": ("esclavager",),
    "esclavagerait": ("esclavager",),
    "esclavageras": ("esclavager",),
    "esclavagèrent": ("esclavager",),
    "esclavagerez": ("esclavager",),
    "esclavageriez": ("esclavager",),
    "esclavagerions": ("esclavager",),
    "esclavagerons": ("esclavager",),
    "esclavageront": ("esclavager",),
    "esclavagés": ("esclavager",),
    "esclavages": ("esclavager",),
    "esclavagez": ("esclavager",),
    "esclavagiez": ("esclavager",),
    "esclavagions": ("esclavager",),
    "escoffiaient": ("escoffier",),
    "escoffiai": ("escoffier",),
    "escoffiais": ("escoffier",),
    "escoffiait": ("escoffier",),
    "escoffia": ("escoffier",),
    "escoffiâmes": ("escoffier",),
    "escoffiant": ("escoffier",),
    "escoffias": ("escoffier",),
    "escoffiassent": ("escoffier",),
    "escoffiasses": ("escoffier",),
    "escoffiasse": ("escoffier",),
    "escoffiassiez": ("escoffier",),
    "escoffiassions": ("escoffier",),
    "escoffiâtes": ("escoffier",),
    "escoffiât": ("escoffier",),
    "escoffiée": ("escoffier",),
    "escoffiées": ("escoffier",),
    "escoffié": ("escoffier",),
    "escoffient": ("escoffier",),
    "escoffie": ("escoffier",),
    "escoffiera": ("escoffier",),
    "escoffieraient": ("escoffier",),
    "escoffierai": ("escoffier",),
    "escoffierais": ("escoffier",),
    "escoffierait": ("escoffier",),
    "escoffieras": ("escoffier",),
    "escoffièrent": ("escoffier",),
    "escoffierez": ("escoffier",),
    "escoffieriez": ("escoffier",),
    "escoffierions": ("escoffier",),
    "escoffierons": ("escoffier",),
    "escoffieront": ("escoffier",),
    "escoffiés": ("escoffier",),
    "escoffies": ("escoffier",),
    "escoffiez": ("escoffier",),
    "escoffiiez": ("escoffier",),
    "escoffiions": ("escoffier",),
    "escoffions": ("escoffier",),
    "escofiaient": ("escofier",),
    "escofiai": ("escofier",),
    "escofiais": ("escofier",),
    "escofiait": ("escofier",),
    "escofia": ("escofier",),
    "escofiâmes": ("escofier",),
    "escofiant": ("escofier",),
    "escofias": ("escofier",),
    "escofiassent": ("escofier",),
    "escofiasses": ("escofier",),
    "escofiasse": ("escofier",),
    "escofiassiez": ("escofier",),
    "escofiassions": ("escofier",),
    "escofiâtes": ("escofier",),
    "escofiât": ("escofier",),
    "escofiée": ("escofier",),
    "escofiées": ("escofier",),
    "escofié": ("escofier",),
    "escofient": ("escofier",),
    "escofie": ("escofier",),
    "escofiera": ("escofier",),
    "escofieraient": ("escofier",),
    "escofierai": ("escofier",),
    "escofierais": ("escofier",),
    "escofierait": ("escofier",),
    "escofieras": ("escofier",),
    "escofièrent": ("escofier",),
    "escofierez": ("escofier",),
    "escofieriez": ("escofier",),
    "escofierions": ("escofier",),
    "escofierons": ("escofier",),
    "escofieront": ("escofier",),
    "escofiés": ("escofier",),
    "escofies": ("escofier",),
    "escofiez": ("escofier",),
    "escofiiez": ("escofier",),
    "escofiions": ("escofier",),
    "escofions": ("escofier",),
    "esjouie": ("esjouir",),
    "esjouies": ("esjouir",),
    "esjoui": ("esjouir",),
    "esjouîmes": ("esjouir",),
    "esjouira": ("esjouir",),
    "esjouiraient": ("esjouir",),
    "esjouirai": ("esjouir",),
    "esjouirais": ("esjouir",),
    "esjouirait": ("esjouir",),
    "esjouiras": ("esjouir",),
    "esjouirent": ("esjouir",),
    "esjouirez": ("esjouir",),
    "esjouiriez": ("esjouir",),
    "esjouirions": ("esjouir",),
    "esjouirons": ("esjouir",),
    "esjouiront": ("esjouir",),
    "esjouis": ("esjouir",),
    "esjouissaient": ("esjouir",),
    "esjouissais": ("esjouir",),
    "esjouissait": ("esjouir",),
    "esjouissant": ("esjouir",),
    "esjouissent": ("esjouir",),
    "esjouisse": ("esjouir",),
    "esjouisses": ("esjouir",),
    "esjouissez": ("esjouir",),
    "esjouissiez": ("esjouir",),
    "esjouissions": ("esjouir",),
    "esjouissons": ("esjouir",),
    "esjouîtes": ("esjouir",),
    "esjouit": ("esjouir",),
    "esjouît": ("esjouir",),
    "espaçaient": ("espacer",),
    "espaçai": ("espacer",),
    "espaçais": ("espacer",),
    "espaçait": ("espacer",),
    "espaça": ("espacer",),
    "espaçâmes": ("espacer",),
    "espaçant": ("espacer",),
    "espaças": ("espacer",),
    "espaçassent": ("espacer",),
    "espaçasses": ("espacer",),
    "espaçasse": ("espacer",),
    "espaçassiez": ("espacer",),
    "espaçassions": ("espacer",),
    "espaçâtes": ("espacer",),
    "espaçât": ("espacer",),
    "espacée": ("espacer",),
    "espacées": ("espacer",),
    "espacé": ("espacer",),
    "espacent": ("espacer",),
    "espace": ("espacer",),
    "espacera": ("espacer",),
    "espaceraient": ("espacer",),
    "espacerai": ("espacer",),
    "espacerais": ("espacer",),
    "espacerait": ("espacer",),
    "espaceras": ("espacer",),
    "espacèrent": ("espacer",),
    "espacerez": ("espacer",),
    "espaceriez": ("espacer",),
    "espacerions": ("espacer",),
    "espacerons": ("espacer",),
    "espaceront": ("espacer",),
    "espacés": ("espacer",),
    "espaces": ("espacer",),
    "espacez": ("espacer",),
    "espaciez": ("espacer",),
    "espacions": ("espacer",),
    "espaçons": ("espacer",),
    "espéraient": ("espérer",),
    "espérai": ("espérer",),
    "espérais": ("espérer",),
    "espérait": ("espérer",),
    "espéra": ("espérer",),
    "espérâmes": ("espérer",),
    "espérant": ("espérer",),
    "espéras": ("espérer",),
    "espérassent": ("espérer",),
    "espérasses": ("espérer",),
    "espérasse": ("espérer",),
    "espérassiez": ("espérer",),
    "espérassions": ("espérer",),
    "espérâtes": ("espérer",),
    "espérât": ("espérer",),
    "espérée": ("espérer",),
    "espérées": ("espérer",),
    "espéré": ("espérer",),
    "espèrent": ("espérer",),
    "espère": ("espérer",),
    "espérera": ("espérer",),
    "espéreraient": ("espérer",),
    "espérerai": ("espérer",),
    "espérerais": ("espérer",),
    "espérerait": ("espérer",),
    "espéreras": ("espérer",),
    "espérèrent": ("espérer",),
    "espérerez": ("espérer",),
    "espéreriez": ("espérer",),
    "espérerions": ("espérer",),
    "espérerons": ("espérer",),
    "espéreront": ("espérer",),
    "espérés": ("espérer",),
    "espères": ("espérer",),
    "espérez": ("espérer",),
    "espériez": ("espérer",),
    "espérions": ("espérer",),
    "espérons": ("espérer",),
    "essangeaient": ("essanger",),
    "essangeai": ("essanger",),
    "essangeais": ("essanger",),
    "essangeait": ("essanger",),
    "essangea": ("essanger",),
    "essangeâmes": ("essanger",),
    "essangeant": ("essanger",),
    "essangeas": ("essanger",),
    "essangeassent": ("essanger",),
    "essangeasses": ("essanger",),
    "essangeasse": ("essanger",),
    "essangeassiez": ("essanger",),
    "essangeassions": ("essanger",),
    "essangeâtes": ("essanger",),
    "essangeât": ("essanger",),
    "essangée": ("essanger",),
    "essangées": ("essanger",),
    "essangé": ("essanger",),
    "essangent": ("essanger",),
    "essangeons": ("essanger",),
    "essange": ("essanger",),
    "essangera": ("essanger",),
    "essangeraient": ("essanger",),
    "essangerai": ("essanger",),
    "essangerais": ("essanger",),
    "essangerait": ("essanger",),
    "essangeras": ("essanger",),
    "essangèrent": ("essanger",),
    "essangerez": ("essanger",),
    "essangeriez": ("essanger",),
    "essangerions": ("essanger",),
    "essangerons": ("essanger",),
    "essangeront": ("essanger",),
    "essangés": ("essanger",),
    "essanges": ("essanger",),
    "essangez": ("essanger",),
    "essangiez": ("essanger",),
    "essangions": ("essanger",),
    "essaient": ("essayer",),
    "essaie": ("essayer",),
    "essaiera": ("essayer",),
    "essaieraient": ("essayer",),
    "essaierai": ("essayer",),
    "essaierais": ("essayer",),
    "essaierait": ("essayer",),
    "essaieras": ("essayer",),
    "essaierez": ("essayer",),
    "essaieriez": ("essayer",),
    "essaierions": ("essayer",),
    "essaierons": ("essayer",),
    "essaieront": ("essayer",),
    "essaies": ("essayer",),
    "essayaient": ("essayer",),
    "essayai": ("essayer",),
    "essayais": ("essayer",),
    "essayait": ("essayer",),
    "essaya": ("essayer",),
    "essayâmes": ("essayer",),
    "essayant": ("essayer",),
    "essayas": ("essayer",),
    "essayassent": ("essayer",),
    "essayasses": ("essayer",),
    "essayasse": ("essayer",),
    "essayassiez": ("essayer",),
    "essayassions": ("essayer",),
    "essayâtes": ("essayer",),
    "essayât": ("essayer",),
    "essayée": ("essayer",),
    "essayées": ("essayer",),
    "essayé": ("essayer",),
    "essayent": ("essayer",),
    "essaye": ("essayer",),
    "essayera": ("essayer",),
    "essayeraient": ("essayer",),
    "essayerai": ("essayer",),
    "essayerais": ("essayer",),
    "essayerait": ("essayer",),
    "essayeras": ("essayer",),
    "essayèrent": ("essayer",),
    "essayerez": ("essayer",),
    "essayeriez": ("essayer",),
    "essayerions": ("essayer",),
    "essayerons": ("essayer",),
    "essayeront": ("essayer",),
    "essayés": ("essayer",),
    "essayes": ("essayer",),
    "essayez": ("essayer",),
    "essayiez": ("essayer",),
    "essayions": ("essayer",),
    "essayons": ("essayer",),
    "essuient": ("essuyer",),
    "essuie": ("essuyer",),
    "essuiera": ("essuyer",),
    "essuieraient": ("essuyer",),
    "essuierai": ("essuyer",),
    "essuierais": ("essuyer",),
    "essuierait": ("essuyer",),
    "essuieras": ("essuyer",),
    "essuierez": ("essuyer",),
    "essuieriez": ("essuyer",),
    "essuierions": ("essuyer",),
    "essuierons": ("essuyer",),
    "essuieront": ("essuyer",),
    "essuies": ("essuyer",),
    "essuyaient": ("essuyer",),
    "essuyai": ("essuyer",),
    "essuyais": ("essuyer",),
    "essuyait": ("essuyer",),
    "essuya": ("essuyer",),
    "essuyâmes": ("essuyer",),
    "essuyant": ("essuyer",),
    "essuyas": ("essuyer",),
    "essuyassent": ("essuyer",),
    "essuyasses": ("essuyer",),
    "essuyasse": ("essuyer",),
    "essuyassiez": ("essuyer",),
    "essuyassions": ("essuyer",),
    "essuyâtes": ("essuyer",),
    "essuyât": ("essuyer",),
    "essuyée": ("essuyer",),
    "essuyées": ("essuyer",),
    "essuyé": ("essuyer",),
    "essuyèrent": ("essuyer",),
    "essuyés": ("essuyer",),
    "essuyez": ("essuyer",),
    "essuyiez": ("essuyer",),
    "essuyions": ("essuyer",),
    "essuyons": ("essuyer",),
    "estérifiaient": ("estérifier",),
    "estérifiai": ("estérifier",),
    "estérifiais": ("estérifier",),
    "estérifiait": ("estérifier",),
    "estérifia": ("estérifier",),
    "estérifiâmes": ("estérifier",),
    "estérifiant": ("estérifier",),
    "estérifias": ("estérifier",),
    "estérifiassent": ("estérifier",),
    "estérifiasses": ("estérifier",),
    "estérifiasse": ("estérifier",),
    "estérifiassiez": ("estérifier",),
    "estérifiassions": ("estérifier",),
    "estérifiâtes": ("estérifier",),
    "estérifiât": ("estérifier",),
    "estérifiée": ("estérifier",),
    "estérifiées": ("estérifier",),
    "estérifié": ("estérifier",),
    "estérifient": ("estérifier",),
    "estérifie": ("estérifier",),
    "estérifiera": ("estérifier",),
    "estérifieraient": ("estérifier",),
    "estérifierai": ("estérifier",),
    "estérifierais": ("estérifier",),
    "estérifierait": ("estérifier",),
    "estérifieras": ("estérifier",),
    "estérifièrent": ("estérifier",),
    "estérifierez": ("estérifier",),
    "estérifieriez": ("estérifier",),
    "estérifierions": ("estérifier",),
    "estérifierons": ("estérifier",),
    "estérifieront": ("estérifier",),
    "estérifiés": ("estérifier",),
    "estérifies": ("estérifier",),
    "estérifiez": ("estérifier",),
    "estérifiiez": ("estérifier",),
    "estérifiions": ("estérifier",),
    "estérifions": ("estérifier",),
    "estourbie": ("estourbir",),
    "estourbies": ("estourbir",),
    "estourbi": ("estourbir",),
    "estourbîmes": ("estourbir",),
    "estourbira": ("estourbir",),
    "estourbiraient": ("estourbir",),
    "estourbirai": ("estourbir",),
    "estourbirais": ("estourbir",),
    "estourbirait": ("estourbir",),
    "estourbiras": ("estourbir",),
    "estourbirent": ("estourbir",),
    "estourbirez": ("estourbir",),
    "estourbiriez": ("estourbir",),
    "estourbirions": ("estourbir",),
    "estourbirons": ("estourbir",),
    "estourbiront": ("estourbir",),
    "estourbis": ("estourbir",),
    "estourbissaient": ("estourbir",),
    "estourbissais": ("estourbir",),
    "estourbissait": ("estourbir",),
    "estourbissant": ("estourbir",),
    "estourbissent": ("estourbir",),
    "estourbisse": ("estourbir",),
    "estourbisses": ("estourbir",),
    "estourbissez": ("estourbir",),
    "estourbissiez": ("estourbir",),
    "estourbissions": ("estourbir",),
    "estourbissons": ("estourbir",),
    "estourbîtes": ("estourbir",),
    "estourbit": ("estourbir",),
    "estourbît": ("estourbir",),
    "estrapassaient": ("estrapasser",),
    "estrapassai": ("estrapasser",),
    "estrapassais": ("estrapasser",),
    "estrapassait": ("estrapasser",),
    "estrapassa": ("estrapasser",),
    "estrapassâmes": ("estrapasser",),
    "estrapassant": ("estrapasser",),
    "estrapassas": ("estrapasser",),
    "estrapassassent": ("estrapasser",),
    "estrapassasses": ("estrapasser",),
    "estrapassasse": ("estrapasser",),
    "estrapassassiez": ("estrapasser",),
    "estrapassassions": ("estrapasser",),
    "estrapassâtes": ("estrapasser",),
    "estrapassât": ("estrapasser",),
    "estrapassée": ("estrapasser",),
    "estrapassées": ("estrapasser",),
    "estrapassé": ("estrapasser",),
    "estrapassent": ("estrapasser",),
    "estrapasse": ("estrapasser",),
    "estrapassera": ("estrapasser",),
    "estrapasseraient": ("estrapasser",),
    "estrapasserai": ("estrapasser",),
    "estrapasserais": ("estrapasser",),
    "estrapasserait": ("estrapasser",),
    "estrapasseras": ("estrapasser",),
    "estrapassèrent": ("estrapasser",),
    "estrapasserez": ("estrapasser",),
    "estrapasseriez": ("estrapasser",),
    "estrapasserions": ("estrapasser",),
    "estrapasserons": ("estrapasser",),
    "estrapasseront": ("estrapasser",),
    "estrapassés": ("estrapasser",),
    "estrapasses": ("estrapasser",),
    "estrapassez": ("estrapasser",),
    "estrapassiez": ("estrapasser",),
    "estrapassions": ("estrapasser",),
    "estrapassons": ("estrapasser",),
    "estropiaient": ("estropier",),
    "estropiai": ("estropier",),
    "estropiais": ("estropier",),
    "estropiait": ("estropier",),
    "estropia": ("estropier",),
    "estropiâmes": ("estropier",),
    "estropiant": ("estropier",),
    "estropias": ("estropier",),
    "estropiassent": ("estropier",),
    "estropiasses": ("estropier",),
    "estropiasse": ("estropier",),
    "estropiassiez": ("estropier",),
    "estropiassions": ("estropier",),
    "estropiâtes": ("estropier",),
    "estropiât": ("estropier",),
    "estropiée": ("estropier",),
    "estropiées": ("estropier",),
    "estropié": ("estropier",),
    "estropient": ("estropier",),
    "estropie": ("estropier",),
    "estropiera": ("estropier",),
    "estropieraient": ("estropier",),
    "estropierai": ("estropier",),
    "estropierais": ("estropier",),
    "estropierait": ("estropier",),
    "estropieras": ("estropier",),
    "estropièrent": ("estropier",),
    "estropierez": ("estropier",),
    "estropieriez": ("estropier",),
    "estropierions": ("estropier",),
    "estropierons": ("estropier",),
    "estropieront": ("estropier",),
    "estropiés": ("estropier",),
    "estropies": ("estropier",),
    "estropiez": ("estropier",),
    "estropiiez": ("estropier",),
    "estropiions": ("estropier",),
    "estropions": ("estropier",),
    "établie": ("établir",),
    "établies": ("établir",),
    "établi": ("établir",),
    "établîmes": ("établir",),
    "établira": ("établir",),
    "établiraient": ("établir",),
    "établirai": ("établir",),
    "établirais": ("établir",),
    "établirait": ("établir",),
    "établiras": ("établir",),
    "établirent": ("établir",),
    "établirez": ("établir",),
    "établiriez": ("établir",),
    "établirions": ("établir",),
    "établirons": ("établir",),
    "établiront": ("établir",),
    "établis": ("établir",),
    "établissaient": ("établir",),
    "établissais": ("établir",),
    "établissait": ("établir",),
    "établissant": ("établir",),
    "établissent": ("établir",),
    "établisse": ("établir",),
    "établisses": ("établir",),
    "établissez": ("établir",),
    "établissiez": ("établir",),
    "établissions": ("établir",),
    "établissons": ("établir",),
    "établîtes": ("établir",),
    "établit": ("établir",),
    "établît": ("établir",),
    "étageaient": ("étager",),
    "étageai": ("étager",),
    "étageais": ("étager",),
    "étageait": ("étager",),
    "étagea": ("étager",),
    "étageâmes": ("étager",),
    "étageant": ("étager",),
    "étageas": ("étager",),
    "étageassent": ("étager",),
    "étageasses": ("étager",),
    "étageasse": ("étager",),
    "étageassiez": ("étager",),
    "étageassions": ("étager",),
    "étageâtes": ("étager",),
    "étageât": ("étager",),
    "étagée": ("étager",),
    "étagées": ("étager",),
    "étagé": ("étager",),
    "étagent": ("étager",),
    "étageons": ("étager",),
    "étage": ("étager",),
    "étagera": ("étager",),
    "étageraient": ("étager",),
    "étagerai": ("étager",),
    "étagerais": ("étager",),
    "étagerait": ("étager",),
    "étageras": ("étager",),
    "étagèrent": ("étager",),
    "étagerez": ("étager",),
    "étageriez": ("étager",),
    "étagerions": ("étager",),
    "étagerons": ("étager",),
    "étageront": ("étager",),
    "étagés": ("étager",),
    "étages": ("étager",),
    "étagez": ("étager",),
    "étagiez": ("étager",),
    "étagions": ("étager",),
    "étalageaient": ("étalager",),
    "étalageai": ("étalager",),
    "étalageais": ("étalager",),
    "étalageait": ("étalager",),
    "étalagea": ("étalager",),
    "étalageâmes": ("étalager",),
    "étalageant": ("étalager",),
    "étalageas": ("étalager",),
    "étalageassent": ("étalager",),
    "étalageasses": ("étalager",),
    "étalageasse": ("étalager",),
    "étalageassiez": ("étalager",),
    "étalageassions": ("étalager",),
    "étalageâtes": ("étalager",),
    "étalageât": ("étalager",),
    "étalagée": ("étalager",),
    "étalagées": ("étalager",),
    "étalagé": ("étalager",),
    "étalagent": ("étalager",),
    "étalageons": ("étalager",),
    "étalage": ("étalager",),
    "étalagera": ("étalager",),
    "étalageraient": ("étalager",),
    "étalagerai": ("étalager",),
    "étalagerais": ("étalager",),
    "étalagerait": ("étalager",),
    "étalageras": ("étalager",),
    "étalagèrent": ("étalager",),
    "étalagerez": ("étalager",),
    "étalageriez": ("étalager",),
    "étalagerions": ("étalager",),
    "étalagerons": ("étalager",),
    "étalageront": ("étalager",),
    "étalagés": ("étalager",),
    "étalages": ("étalager",),
    "étalagez": ("étalager",),
    "étalagiez": ("étalager",),
    "étalagions": ("étalager",),
    "étanchéifiaient": ("étanchéifier",),
    "étanchéifiai": ("étanchéifier",),
    "étanchéifiais": ("étanchéifier",),
    "étanchéifiait": ("étanchéifier",),
    "étanchéifia": ("étanchéifier",),
    "étanchéifiâmes": ("étanchéifier",),
    "étanchéifiant": ("étanchéifier",),
    "étanchéifias": ("étanchéifier",),
    "étanchéifiassent": ("étanchéifier",),
    "étanchéifiasses": ("étanchéifier",),
    "étanchéifiasse": ("étanchéifier",),
    "étanchéifiassiez": ("étanchéifier",),
    "étanchéifiassions": ("étanchéifier",),
    "étanchéifiâtes": ("étanchéifier",),
    "étanchéifiât": ("étanchéifier",),
    "étanchéifiée": ("étanchéifier",),
    "étanchéifiées": ("étanchéifier",),
    "étanchéifié": ("étanchéifier",),
    "étanchéifient": ("étanchéifier",),
    "étanchéifie": ("étanchéifier",),
    "étanchéifiera": ("étanchéifier",),
    "étanchéifieraient": ("étanchéifier",),
    "étanchéifierai": ("étanchéifier",),
    "étanchéifierais": ("étanchéifier",),
    "étanchéifierait": ("étanchéifier",),
    "étanchéifieras": ("étanchéifier",),
    "étanchéifièrent": ("étanchéifier",),
    "étanchéifierez": ("étanchéifier",),
    "étanchéifieriez": ("étanchéifier",),
    "étanchéifierions": ("étanchéifier",),
    "étanchéifierons": ("étanchéifier",),
    "étanchéifieront": ("étanchéifier",),
    "étanchéifiés": ("étanchéifier",),
    "étanchéifies": ("étanchéifier",),
    "étanchéifiez": ("étanchéifier",),
    "étanchéifiiez": ("étanchéifier",),
    "étanchéifiions": ("étanchéifier",),
    "étanchéifions": ("étanchéifier",),
    "étatifiaient": ("étatifier",),
    "étatifiai": ("étatifier",),
    "étatifiais": ("étatifier",),
    "étatifiait": ("étatifier",),
    "étatifia": ("étatifier",),
    "étatifiâmes": ("étatifier",),
    "étatifiant": ("étatifier",),
    "étatifias": ("étatifier",),
    "étatifiassent": ("étatifier",),
    "étatifiasses": ("étatifier",),
    "étatifiasse": ("étatifier",),
    "étatifiassiez": ("étatifier",),
    "étatifiassions": ("étatifier",),
    "étatifiâtes": ("étatifier",),
    "étatifiât": ("étatifier",),
    "étatifiée": ("étatifier",),
    "étatifiées": ("étatifier",),
    "étatifié": ("étatifier",),
    "étatifient": ("étatifier",),
    "étatifie": ("étatifier",),
    "étatifiera": ("étatifier",),
    "étatifieraient": ("étatifier",),
    "étatifierai": ("étatifier",),
    "étatifierais": ("étatifier",),
    "étatifierait": ("étatifier",),
    "étatifieras": ("étatifier",),
    "étatifièrent": ("étatifier",),
    "étatifierez": ("étatifier",),
    "étatifieriez": ("étatifier",),
    "étatifierions": ("étatifier",),
    "étatifierons": ("étatifier",),
    "étatifieront": ("étatifier",),
    "étatifiés": ("étatifier",),
    "étatifies": ("étatifier",),
    "étatifiez": ("étatifier",),
    "étatifiiez": ("étatifier",),
    "étatifiions": ("étatifier",),
    "étatifions": ("étatifier",),
    "étaient": ("être",),
    "étaie": ("étayer",),
    "étaiera": ("étayer",),
    "étaieraient": ("étayer",),
    "étaierai": ("étayer",),
    "étaierais": ("étayer",),
    "étaierait": ("étayer",),
    "étaieras": ("étayer",),
    "étaierez": ("étayer",),
    "étaieriez": ("étayer",),
    "étaierions": ("étayer",),
    "étaierons": ("étayer",),
    "étaieront": ("étayer",),
    "étaies": ("étayer",),
    "étayaient": ("étayer",),
    "étayai": ("étayer",),
    "étayais": ("étayer",),
    "étayait": ("étayer",),
    "étaya": ("étayer",),
    "étayâmes": ("étayer",),
    "étayant": ("étayer",),
    "étayas": ("étayer",),
    "étayassent": ("étayer",),
    "étayasses": ("étayer",),
    "étayasse": ("étayer",),
    "étayassiez": ("étayer",),
    "étayassions": ("étayer",),
    "étayâtes": ("étayer",),
    "étayât": ("étayer",),
    "étayée": ("étayer",),
    "étayées": ("étayer",),
    "étayé": ("étayer",),
    "étayent": ("étayer",),
    "étaye": ("étayer",),
    "étayera": ("étayer",),
    "étayeraient": ("étayer",),
    "étayerai": ("étayer",),
    "étayerais": ("étayer",),
    "étayerait": ("étayer",),
    "étayeras": ("étayer",),
    "étayèrent": ("étayer",),
    "étayerez": ("étayer",),
    "étayeriez": ("étayer",),
    "étayerions": ("étayer",),
    "étayerons": ("étayer",),
    "étayeront": ("étayer",),
    "étayés": ("étayer",),
    "étayes": ("étayer",),
    "étayez": ("étayer",),
    "étayiez": ("étayer",),
    "étayions": ("étayer",),
    "étayons": ("étayer",),
    "éteignaient": ("éteindre",),
    "éteignais": ("éteindre",),
    "éteignait": ("éteindre",),
    "éteignant": ("éteindre",),
    "éteignent": ("éteindre",),
    "éteigne": ("éteindre",),
    "éteignes": ("éteindre",),
    "éteignez": ("éteindre",),
    "éteigniez": ("éteindre",),
    "éteignîmes": ("éteindre",),
    "éteignions": ("éteindre",),
    "éteignirent": ("éteindre",),
    "éteignis": ("éteindre",),
    "éteignissent": ("éteindre",),
    "éteignisses": ("éteindre",),
    "éteignisse": ("éteindre",),
    "éteignissiez": ("éteindre",),
    "éteignissions": ("éteindre",),
    "éteignîtes": ("éteindre",),
    "éteignit": ("éteindre",),
    "éteignît": ("éteindre",),
    "éteignons": ("éteindre",),
    "éteindra": ("éteindre",),
    "éteindraient": ("éteindre",),
    "éteindrai": ("éteindre",),
    "éteindrais": ("éteindre",),
    "éteindrait": ("éteindre",),
    "éteindras": ("éteindre",),
    "éteindrez": ("éteindre",),
    "éteindriez": ("éteindre",),
    "éteindrions": ("éteindre",),
    "éteindrons": ("éteindre",),
    "éteindront": ("éteindre",),
    "éteins": ("éteindre",),
    "éteinte": ("éteindre",),
    "éteintes": ("éteindre",),
    "éteint": ("éteindre",),
    "éteints": ("éteindre",),
    "étendaient": ("étendre",),
    "étendais": ("étendre",),
    "étendait": ("étendre",),
    "étendant": ("étendre",),
    "étendent": ("étendre",),
    "étende": ("étendre",),
    "étendes": ("étendre",),
    "étendez": ("étendre",),
    "étendiez": ("étendre",),
    "étendîmes": ("étendre",),
    "étendions": ("étendre",),
    "étendirent": ("étendre",),
    "étendis": ("étendre",),
    "étendissent": ("étendre",),
    "étendisses": ("étendre",),
    "étendisse": ("étendre",),
    "étendissiez": ("étendre",),
    "étendissions": ("étendre",),
    "étendîtes": ("étendre",),
    "étendit": ("étendre",),
    "étendît": ("étendre",),
    "étendons": ("étendre",),
    "étend": ("étendre",),
    "étendra": ("étendre",),
    "étendraient": ("étendre",),
    "étendrai": ("étendre",),
    "étendrais": ("étendre",),
    "étendrait": ("étendre",),
    "étendras": ("étendre",),
    "étendrez": ("étendre",),
    "étendriez": ("étendre",),
    "étendrions": ("étendre",),
    "étendrons": ("étendre",),
    "étendront": ("étendre",),
    "étends": ("étendre",),
    "étendue": ("étendre",),
    "étendues": ("étendre",),
    "étendu": ("étendre",),
    "étendus": ("étendre",),
    "éthérifiaient": ("éthérifier",),
    "éthérifiai": ("éthérifier",),
    "éthérifiais": ("éthérifier",),
    "éthérifiait": ("éthérifier",),
    "éthérifia": ("éthérifier",),
    "éthérifiâmes": ("éthérifier",),
    "éthérifiant": ("éthérifier",),
    "éthérifias": ("éthérifier",),
    "éthérifiassent": ("éthérifier",),
    "éthérifiasses": ("éthérifier",),
    "éthérifiasse": ("éthérifier",),
    "éthérifiassiez": ("éthérifier",),
    "éthérifiassions": ("éthérifier",),
    "éthérifiâtes": ("éthérifier",),
    "éthérifiât": ("éthérifier",),
    "éthérifiée": ("éthérifier",),
    "éthérifiées": ("éthérifier",),
    "éthérifié": ("éthérifier",),
    "éthérifient": ("éthérifier",),
    "éthérifie": ("éthérifier",),
    "éthérifiera": ("éthérifier",),
    "éthérifieraient": ("éthérifier",),
    "éthérifierai": ("éthérifier",),
    "éthérifierais": ("éthérifier",),
    "éthérifierait": ("éthérifier",),
    "éthérifieras": ("éthérifier",),
    "éthérifièrent": ("éthérifier",),
    "éthérifierez": ("éthérifier",),
    "éthérifieriez": ("éthérifier",),
    "éthérifierions": ("éthérifier",),
    "éthérifierons": ("éthérifier",),
    "éthérifieront": ("éthérifier",),
    "éthérifiés": ("éthérifier",),
    "éthérifies": ("éthérifier",),
    "éthérifiez": ("éthérifier",),
    "éthérifiiez": ("éthérifier",),
    "éthérifiions": ("éthérifier",),
    "éthérifions": ("éthérifier",),
    "étigeaient": ("étiger",),
    "étigeai": ("étiger",),
    "étigeais": ("étiger",),
    "étigeait": ("étiger",),
    "étigea": ("étiger",),
    "étigeâmes": ("étiger",),
    "étigeant": ("étiger",),
    "étigeas": ("étiger",),
    "étigeassent": ("étiger",),
    "étigeasses": ("étiger",),
    "étigeasse": ("étiger",),
    "étigeassiez": ("étiger",),
    "étigeassions": ("étiger",),
    "étigeâtes": ("étiger",),
    "étigeât": ("étiger",),
    "étigée": ("étiger",),
    "étigées": ("étiger",),
    "étigé": ("étiger",),
    "étigent": ("étiger",),
    "étigeons": ("étiger",),
    "étige": ("étiger",),
    "étigera": ("étiger",),
    "étigeraient": ("étiger",),
    "étigerai": ("étiger",),
    "étigerais": ("étiger",),
    "étigerait": ("étiger",),
    "étigeras": ("étiger",),
    "étigèrent": ("étiger",),
    "étigerez": ("étiger",),
    "étigeriez": ("étiger",),
    "étigerions": ("étiger",),
    "étigerons": ("étiger",),
    "étigeront": ("étiger",),
    "étigés": ("étiger",),
    "étiges": ("étiger",),
    "étigez": ("étiger",),
    "étigiez": ("étiger",),
    "étigions": ("étiger",),
    "étincelaient": ("étinceler",),
    "étincelai": ("étinceler",),
    "étincelais": ("étinceler",),
    "étincelait": ("étinceler",),
    "étincela": ("étinceler",),
    "étincelâmes": ("étinceler",),
    "étincelant": ("étinceler",),
    "étincelas": ("étinceler",),
    "étincelassent": ("étinceler",),
    "étincelasses": ("étinceler",),
    "étincelasse": ("étinceler",),
    "étincelassiez": ("étinceler",),
    "étincelassions": ("étinceler",),
    "étincelâtes": ("étinceler",),
    "étincelât": ("étinceler",),
    "étincelé": ("étinceler",),
    "étincelèrent": ("étinceler",),
    "étincelez": ("étinceler",),
    "étinceliez": ("étinceler",),
    "étincelions": ("étinceler",),
    "étincellent": ("étinceler",),
    "étincelle": ("étinceler",),
    "étincellera": ("étinceler",),
    "étincelleraient": ("étinceler",),
    "étincellerai": ("étinceler",),
    "étincellerais": ("étinceler",),
    "étincellerait": ("étinceler",),
    "étincelleras": ("étinceler",),
    "étincellerez": ("étinceler",),
    "étincelleriez": ("étinceler",),
    "étincellerions": ("étinceler",),
    "étincellerons": ("étinceler",),
    "étincelleront": ("étinceler",),
    "étincelles": ("étinceler",),
    "étincelons": ("étinceler",),
    "étiquetaient": ("étiqueter",),
    "étiquetai": ("étiqueter",),
    "étiquetais": ("étiqueter",),
    "étiquetait": ("étiqueter",),
    "étiqueta": ("étiqueter",),
    "étiquetâmes": ("étiqueter",),
    "étiquetant": ("étiqueter",),
    "étiquetas": ("étiqueter",),
    "étiquetassent": ("étiqueter",),
    "étiquetasses": ("étiqueter",),
    "étiquetasse": ("étiqueter",),
    "étiquetassiez": ("étiqueter",),
    "étiquetassions": ("étiqueter",),
    "étiquetâtes": ("étiqueter",),
    "étiquetât": ("étiqueter",),
    "étiquetée": ("étiqueter",),
    "étiquetées": ("étiqueter",),
    "étiqueté": ("étiqueter",),
    "étiquetèrent": ("étiqueter",),
    "étiquetés": ("étiqueter",),
    "étiquetez": ("étiqueter",),
    "étiquetiez": ("étiqueter",),
    "étiquetions": ("étiqueter",),
    "étiquetons": ("étiqueter",),
    "étiquettent": ("étiqueter",),
    "étiquette": ("étiqueter",),
    "étiquettera": ("étiqueter",),
    "étiquetteraient": ("étiqueter",),
    "étiquetterai": ("étiqueter",),
    "étiquetterais": ("étiqueter",),
    "étiquetterait": ("étiqueter",),
    "étiquetteras": ("étiqueter",),
    "étiquetterez": ("étiqueter",),
    "étiquetteriez": ("étiqueter",),
    "étiquetterions": ("étiqueter",),
    "étiquetterons": ("étiqueter",),
    "étiquetteront": ("étiqueter",),
    "étiquettes": ("étiqueter",),
    "étourdie": ("étourdir",),
    "étourdies": ("étourdir",),
    "étourdi": ("étourdir",),
    "étourdîmes": ("étourdir",),
    "étourdira": ("étourdir",),
    "étourdiraient": ("étourdir",),
    "étourdirai": ("étourdir",),
    "étourdirais": ("étourdir",),
    "étourdirait": ("étourdir",),
    "étourdiras": ("étourdir",),
    "étourdirent": ("étourdir",),
    "étourdirez": ("étourdir",),
    "étourdiriez": ("étourdir",),
    "étourdirions": ("étourdir",),
    "étourdirons": ("étourdir",),
    "étourdiront": ("étourdir",),
    "étourdis": ("étourdir",),
    "étourdissaient": ("étourdir",),
    "étourdissais": ("étourdir",),
    "étourdissait": ("étourdir",),
    "étourdissant": ("étourdir",),
    "étourdissent": ("étourdir",),
    "étourdisse": ("étourdir",),
    "étourdisses": ("étourdir",),
    "étourdissez": ("étourdir",),
    "étourdissiez": ("étourdir",),
    "étourdissions": ("étourdir",),
    "étourdissons": ("étourdir",),
    "étourdîtes": ("étourdir",),
    "étourdit": ("étourdir",),
    "étourdît": ("étourdir",),
    "étrécie": ("étrécir",),
    "étrécies": ("étrécir",),
    "étréci": ("étrécir",),
    "étrécîmes": ("étrécir",),
    "étrécira": ("étrécir",),
    "étréciraient": ("étrécir",),
    "étrécirai": ("étrécir",),
    "étrécirais": ("étrécir",),
    "étrécirait": ("étrécir",),
    "étréciras": ("étrécir",),
    "étrécirent": ("étrécir",),
    "étrécirez": ("étrécir",),
    "étréciriez": ("étrécir",),
    "étrécirions": ("étrécir",),
    "étrécirons": ("étrécir",),
    "étréciront": ("étrécir",),
    "étrécis": ("étrécir",),
    "étrécissaient": ("étrécir",),
    "étrécissais": ("étrécir",),
    "étrécissait": ("étrécir",),
    "étrécissant": ("étrécir",),
    "étrécissent": ("étrécir",),
    "étrécisse": ("étrécir",),
    "étrécisses": ("étrécir",),
    "étrécissez": ("étrécir",),
    "étrécissiez": ("étrécir",),
    "étrécissions": ("étrécir",),
    "étrécissons": ("étrécir",),
    "étrécîtes": ("étrécir",),
    "étrécit": ("étrécir",),
    "étrécît": ("étrécir",),
    "étreignaient": ("étreindre",),
    "étreignais": ("étreindre",),
    "étreignait": ("étreindre",),
    "étreignant": ("étreindre",),
    "étreignent": ("étreindre",),
    "étreigne": ("étreindre",),
    "étreignes": ("étreindre",),
    "étreignez": ("étreindre",),
    "étreigniez": ("étreindre",),
    "étreignîmes": ("étreindre",),
    "étreignions": ("étreindre",),
    "étreignirent": ("étreindre",),
    "étreignis": ("étreindre",),
    "étreignissent": ("étreindre",),
    "étreignisses": ("étreindre",),
    "étreignisse": ("étreindre",),
    "étreignissiez": ("étreindre",),
    "étreignissions": ("étreindre",),
    "étreignîtes": ("étreindre",),
    "étreignit": ("étreindre",),
    "étreignît": ("étreindre",),
    "étreignons": ("étreindre",),
    "étreindra": ("étreindre",),
    "étreindraient": ("étreindre",),
    "étreindrai": ("étreindre",),
    "étreindrais": ("étreindre",),
    "étreindrait": ("étreindre",),
    "étreindras": ("étreindre",),
    "étreindrez": ("étreindre",),
    "étreindriez": ("étreindre",),
    "étreindrions": ("étreindre",),
    "étreindrons": ("étreindre",),
    "étreindront": ("étreindre",),
    "étreins": ("étreindre",),
    "étreinte": ("étreindre",),
    "étreintes": ("étreindre",),
    "étreint": ("étreindre",),
    "étreints": ("étreindre",),
    "étrépaient": ("étréper",),
    "étrépai": ("étréper",),
    "étrépais": ("étréper",),
    "étrépait": ("étréper",),
    "étrépa": ("étréper",),
    "étrépâmes": ("étréper",),
    "étrépant": ("étréper",),
    "étrépas": ("étréper",),
    "étrépassent": ("étréper",),
    "étrépasses": ("étréper",),
    "étrépasse": ("étréper",),
    "étrépassiez": ("étréper",),
    "étrépassions": ("étréper",),
    "étrépâtes": ("étréper",),
    "étrépât": ("étréper",),
    "étrépée": ("étréper",),
    "étrépées": ("étréper",),
    "étrépé": ("étréper",),
    "étrèpent": ("étréper",),
    "étrèpe": ("étréper",),
    "étrépera": ("étréper",),
    "étréperaient": ("étréper",),
    "étréperai": ("étréper",),
    "étréperais": ("étréper",),
    "étréperait": ("étréper",),
    "étréperas": ("étréper",),
    "étrépèrent": ("étréper",),
    "étréperez": ("étréper",),
    "étréperiez": ("étréper",),
    "étréperions": ("étréper",),
    "étréperons": ("étréper",),
    "étréperont": ("étréper",),
    "étrépés": ("étréper",),
    "étrèpes": ("étréper",),
    "étrépez": ("étréper",),
    "étrépiez": ("étréper",),
    "étrépions": ("étréper",),
    "étrépons": ("étréper",),
    "es": ("être",),
    "est": ("être",),
    "étais": ("être",),
    "était": ("être",),
    "étant": ("être",),
    "été": ("être",),
    "êtes": ("être",),
    "étiez": ("être",),
    "étions": ("être",),
    "fûmes": ("être",),
    "furent": ("être",),
    "fus": ("être",),
    "fussent": ("être",),
    "fusses": ("être",),
    "fusse": ("être",),
    "fussé": ("être",),
    "fussiez": ("être",),
    "fussions": ("être",),
    "fûtes": ("être",),
    "fut": ("être",),
    "fût": ("être",),
    "sera": ("être",),
    "seraient": ("être",),
    "serai": ("être",),
    "serais": ("être",),
    "serait": ("être",),
    "seras": ("être",),
    "serez": ("être",),
    "seriez": ("être",),
    "serions": ("être",),
    "serons": ("être",),
    "seront": ("être",),
    "soient": ("être",),
    "sois": ("être",),
    "soit": ("être",),
    "sommes": ("être",),
    "sont": ("être",),
    "soyez": ("être",),
    "soyons": ("être",),
    "suis": ("suivre",),
    "étudiaient": ("étudier",),
    "étudiai": ("étudier",),
    "étudiais": ("étudier",),
    "étudiait": ("étudier",),
    "étudia": ("étudier",),
    "étudiâmes": ("étudier",),
    "étudiant": ("étudier",),
    "étudias": ("étudier",),
    "étudiassent": ("étudier",),
    "étudiasses": ("étudier",),
    "étudiasse": ("étudier",),
    "étudiassiez": ("étudier",),
    "étudiassions": ("étudier",),
    "étudiâtes": ("étudier",),
    "étudiât": ("étudier",),
    "étudiée": ("étudier",),
    "étudiées": ("étudier",),
    "étudié": ("étudier",),
    "étudient": ("étudier",),
    "étudie": ("étudier",),
    "étudiera": ("étudier",),
    "étudieraient": ("étudier",),
    "étudierai": ("étudier",),
    "étudierais": ("étudier",),
    "étudierait": ("étudier",),
    "étudieras": ("étudier",),
    "étudièrent": ("étudier",),
    "étudierez": ("étudier",),
    "étudieriez": ("étudier",),
    "étudierions": ("étudier",),
    "étudierons": ("étudier",),
    "étudieront": ("étudier",),
    "étudiés": ("étudier",),
    "étudies": ("étudier",),
    "étudiez": ("étudier",),
    "étudiiez": ("étudier",),
    "étudiions": ("étudier",),
    "étudions": ("étudier",),
    "euthanasiaient": ("euthanasier",),
    "euthanasiai": ("euthanasier",),
    "euthanasiais": ("euthanasier",),
    "euthanasiait": ("euthanasier",),
    "euthanasia": ("euthanasier",),
    "euthanasiâmes": ("euthanasier",),
    "euthanasiant": ("euthanasier",),
    "euthanasias": ("euthanasier",),
    "euthanasiassent": ("euthanasier",),
    "euthanasiasses": ("euthanasier",),
    "euthanasiasse": ("euthanasier",),
    "euthanasiassiez": ("euthanasier",),
    "euthanasiassions": ("euthanasier",),
    "euthanasiâtes": ("euthanasier",),
    "euthanasiât": ("euthanasier",),
    "euthanasiée": ("euthanasier",),
    "euthanasiées": ("euthanasier",),
    "euthanasié": ("euthanasier",),
    "euthanasient": ("euthanasier",),
    "euthanasie": ("euthanasier",),
    "euthanasiera": ("euthanasier",),
    "euthanasieraient": ("euthanasier",),
    "euthanasierai": ("euthanasier",),
    "euthanasierais": ("euthanasier",),
    "euthanasierait": ("euthanasier",),
    "euthanasieras": ("euthanasier",),
    "euthanasièrent": ("euthanasier",),
    "euthanasierez": ("euthanasier",),
    "euthanasieriez": ("euthanasier",),
    "euthanasierions": ("euthanasier",),
    "euthanasierons": ("euthanasier",),
    "euthanasieront": ("euthanasier",),
    "euthanasiés": ("euthanasier",),
    "euthanasies": ("euthanasier",),
    "euthanasiez": ("euthanasier",),
    "euthanasiiez": ("euthanasier",),
    "euthanasiions": ("euthanasier",),
    "euthanasions": ("euthanasier",),
    "eutrophiaient": ("eutrophier",),
    "eutrophiai": ("eutrophier",),
    "eutrophiais": ("eutrophier",),
    "eutrophiait": ("eutrophier",),
    "eutrophia": ("eutrophier",),
    "eutrophiâmes": ("eutrophier",),
    "eutrophiant": ("eutrophier",),
    "eutrophias": ("eutrophier",),
    "eutrophiassent": ("eutrophier",),
    "eutrophiasses": ("eutrophier",),
    "eutrophiasse": ("eutrophier",),
    "eutrophiassiez": ("eutrophier",),
    "eutrophiassions": ("eutrophier",),
    "eutrophiâtes": ("eutrophier",),
    "eutrophiât": ("eutrophier",),
    "eutrophiée": ("eutrophier",),
    "eutrophiées": ("eutrophier",),
    "eutrophié": ("eutrophier",),
    "eutrophient": ("eutrophier",),
    "eutrophie": ("eutrophier",),
    "eutrophiera": ("eutrophier",),
    "eutrophieraient": ("eutrophier",),
    "eutrophierai": ("eutrophier",),
    "eutrophierais": ("eutrophier",),
    "eutrophierait": ("eutrophier",),
    "eutrophieras": ("eutrophier",),
    "eutrophièrent": ("eutrophier",),
    "eutrophierez": ("eutrophier",),
    "eutrophieriez": ("eutrophier",),
    "eutrophierions": ("eutrophier",),
    "eutrophierons": ("eutrophier",),
    "eutrophieront": ("eutrophier",),
    "eutrophiés": ("eutrophier",),
    "eutrophies": ("eutrophier",),
    "eutrophiez": ("eutrophier",),
    "eutrophiiez": ("eutrophier",),
    "eutrophiions": ("eutrophier",),
    "eutrophions": ("eutrophier",),
    "évanouie": ("évanouir",),
    "évanouies": ("évanouir",),
    "évanoui": ("évanouir",),
    "évanouîmes": ("évanouir",),
    "évanouira": ("évanouir",),
    "évanouiraient": ("évanouir",),
    "évanouirai": ("évanouir",),
    "évanouirais": ("évanouir",),
    "évanouirait": ("évanouir",),
    "évanouiras": ("évanouir",),
    "évanouirent": ("évanouir",),
    "évanouirez": ("évanouir",),
    "évanouiriez": ("évanouir",),
    "évanouirions": ("évanouir",),
    "évanouirons": ("évanouir",),
    "évanouiront": ("évanouir",),
    "évanouis": ("évanouir",),
    "évanouissaient": ("évanouir",),
    "évanouissais": ("évanouir",),
    "évanouissait": ("évanouir",),
    "évanouissant": ("évanouir",),
    "évanouissent": ("évanouir",),
    "évanouisse": ("évanouir",),
    "évanouisses": ("évanouir",),
    "évanouissez": ("évanouir",),
    "évanouissiez": ("évanouir",),
    "évanouissions": ("évanouir",),
    "évanouissons": ("évanouir",),
    "évanouîtes": ("évanouir",),
    "évanouit": ("évanouir",),
    "évanouît": ("évanouir",),
    "évinçaient": ("évincer",),
    "évinçai": ("évincer",),
    "évinçais": ("évincer",),
    "évinçait": ("évincer",),
    "évinça": ("évincer",),
    "évinçâmes": ("évincer",),
    "évinçant": ("évincer",),
    "évinças": ("évincer",),
    "évinçassent": ("évincer",),
    "évinçasses": ("évincer",),
    "évinçasse": ("évincer",),
    "évinçassiez": ("évincer",),
    "évinçassions": ("évincer",),
    "évinçâtes": ("évincer",),
    "évinçât": ("évincer",),
    "évincée": ("évincer",),
    "évincées": ("évincer",),
    "évincé": ("évincer",),
    "évincent": ("évincer",),
    "évince": ("évincer",),
    "évincera": ("évincer",),
    "évinceraient": ("évincer",),
    "évincerai": ("évincer",),
    "évincerais": ("évincer",),
    "évincerait": ("évincer",),
    "évinceras": ("évincer",),
    "évincèrent": ("évincer",),
    "évincerez": ("évincer",),
    "évinceriez": ("évincer",),
    "évincerions": ("évincer",),
    "évincerons": ("évincer",),
    "évinceront": ("évincer",),
    "évincés": ("évincer",),
    "évinces": ("évincer",),
    "évincez": ("évincer",),
    "évinciez": ("évincer",),
    "évincions": ("évincer",),
    "évinçons": ("évincer",),
    "éviscéraient": ("éviscérer",),
    "éviscérai": ("éviscérer",),
    "éviscérais": ("éviscérer",),
    "éviscérait": ("éviscérer",),
    "éviscéra": ("éviscérer",),
    "éviscérâmes": ("éviscérer",),
    "éviscérant": ("éviscérer",),
    "éviscéras": ("éviscérer",),
    "éviscérassent": ("éviscérer",),
    "éviscérasses": ("éviscérer",),
    "éviscérasse": ("éviscérer",),
    "éviscérassiez": ("éviscérer",),
    "éviscérassions": ("éviscérer",),
    "éviscérâtes": ("éviscérer",),
    "éviscérât": ("éviscérer",),
    "éviscérée": ("éviscérer",),
    "éviscérées": ("éviscérer",),
    "éviscéré": ("éviscérer",),
    "éviscèrent": ("éviscérer",),
    "éviscère": ("éviscérer",),
    "éviscérera": ("éviscérer",),
    "éviscéreraient": ("éviscérer",),
    "éviscérerai": ("éviscérer",),
    "éviscérerais": ("éviscérer",),
    "éviscérerait": ("éviscérer",),
    "éviscéreras": ("éviscérer",),
    "éviscérèrent": ("éviscérer",),
    "éviscérerez": ("éviscérer",),
    "éviscéreriez": ("éviscérer",),
    "éviscérerions": ("éviscérer",),
    "éviscérerons": ("éviscérer",),
    "éviscéreront": ("éviscérer",),
    "éviscérés": ("éviscérer",),
    "éviscères": ("éviscérer",),
    "éviscérez": ("éviscérer",),
    "éviscériez": ("éviscérer",),
    "éviscérions": ("éviscérer",),
    "éviscérons": ("éviscérer",),
    "exagéraient": ("exagérer",),
    "exagérai": ("exagérer",),
    "exagérais": ("exagérer",),
    "exagérait": ("exagérer",),
    "exagéra": ("exagérer",),
    "exagérâmes": ("exagérer",),
    "exagérant": ("exagérer",),
    "exagéras": ("exagérer",),
    "exagérassent": ("exagérer",),
    "exagérasses": ("exagérer",),
    "exagérasse": ("exagérer",),
    "exagérassiez": ("exagérer",),
    "exagérassions": ("exagérer",),
    "exagérâtes": ("exagérer",),
    "exagérât": ("exagérer",),
    "exagérée": ("exagérer",),
    "exagérées": ("exagérer",),
    "exagéré": ("exagérer",),
    "exagèrent": ("exagérer",),
    "exagère": ("exagérer",),
    "exagérera": ("exagérer",),
    "exagéreraient": ("exagérer",),
    "exagérerai": ("exagérer",),
    "exagérerais": ("exagérer",),
    "exagérerait": ("exagérer",),
    "exagéreras": ("exagérer",),
    "exagérèrent": ("exagérer",),
    "exagérerez": ("exagérer",),
    "exagéreriez": ("exagérer",),
    "exagérerions": ("exagérer",),
    "exagérerons": ("exagérer",),
    "exagéreront": ("exagérer",),
    "exagérés": ("exagérer",),
    "exagères": ("exagérer",),
    "exagérez": ("exagérer",),
    "exagériez": ("exagérer",),
    "exagérions": ("exagérer",),
    "exagérons": ("exagérer",),
    "exaspéraient": ("exaspérer",),
    "exaspérai": ("exaspérer",),
    "exaspérais": ("exaspérer",),
    "exaspérait": ("exaspérer",),
    "exaspéra": ("exaspérer",),
    "exaspérâmes": ("exaspérer",),
    "exaspérant": ("exaspérer",),
    "exaspéras": ("exaspérer",),
    "exaspérassent": ("exaspérer",),
    "exaspérasses": ("exaspérer",),
    "exaspérasse": ("exaspérer",),
    "exaspérassiez": ("exaspérer",),
    "exaspérassions": ("exaspérer",),
    "exaspérâtes": ("exaspérer",),
    "exaspérât": ("exaspérer",),
    "exaspérée": ("exaspérer",),
    "exaspérées": ("exaspérer",),
    "exaspéré": ("exaspérer",),
    "exaspèrent": ("exaspérer",),
    "exaspère": ("exaspérer",),
    "exaspérera": ("exaspérer",),
    "exaspéreraient": ("exaspérer",),
    "exaspérerai": ("exaspérer",),
    "exaspérerais": ("exaspérer",),
    "exaspérerait": ("exaspérer",),
    "exaspéreras": ("exaspérer",),
    "exaspérèrent": ("exaspérer",),
    "exaspérerez": ("exaspérer",),
    "exaspéreriez": ("exaspérer",),
    "exaspérerions": ("exaspérer",),
    "exaspérerons": ("exaspérer",),
    "exaspéreront": ("exaspérer",),
    "exaspérés": ("exaspérer",),
    "exaspères": ("exaspérer",),
    "exaspérez": ("exaspérer",),
    "exaspériez": ("exaspérer",),
    "exaspérions": ("exaspérer",),
    "exaspérons": ("exaspérer",),
    "exauçaient": ("exaucer",),
    "exauçai": ("exaucer",),
    "exauçais": ("exaucer",),
    "exauçait": ("exaucer",),
    "exauça": ("exaucer",),
    "exauçâmes": ("exaucer",),
    "exauçant": ("exaucer",),
    "exauças": ("exaucer",),
    "exauçassent": ("exaucer",),
    "exauçasses": ("exaucer",),
    "exauçasse": ("exaucer",),
    "exauçassiez": ("exaucer",),
    "exauçassions": ("exaucer",),
    "exauçâtes": ("exaucer",),
    "exauçât": ("exaucer",),
    "exaucée": ("exaucer",),
    "exaucées": ("exaucer",),
    "exaucé": ("exaucer",),
    "exaucent": ("exaucer",),
    "exauce": ("exaucer",),
    "exaucera": ("exaucer",),
    "exauceraient": ("exaucer",),
    "exaucerai": ("exaucer",),
    "exaucerais": ("exaucer",),
    "exaucerait": ("exaucer",),
    "exauceras": ("exaucer",),
    "exaucèrent": ("exaucer",),
    "exaucerez": ("exaucer",),
    "exauceriez": ("exaucer",),
    "exaucerions": ("exaucer",),
    "exaucerons": ("exaucer",),
    "exauceront": ("exaucer",),
    "exaucés": ("exaucer",),
    "exauces": ("exaucer",),
    "exaucez": ("exaucer",),
    "exauciez": ("exaucer",),
    "exaucions": ("exaucer",),
    "exauçons": ("exaucer",),
    "excédaient": ("excéder",),
    "excédai": ("excéder",),
    "excédais": ("excéder",),
    "excédait": ("excéder",),
    "excéda": ("excéder",),
    "excédâmes": ("excéder",),
    "excédant": ("excéder",),
    "excédas": ("excéder",),
    "excédassent": ("excéder",),
    "excédasses": ("excéder",),
    "excédasse": ("excéder",),
    "excédassiez": ("excéder",),
    "excédassions": ("excéder",),
    "excédâtes": ("excéder",),
    "excédât": ("excéder",),
    "excédée": ("excéder",),
    "excédées": ("excéder",),
    "excédé": ("excéder",),
    "excèdent": ("excéder",),
    "excède": ("excéder",),
    "excédera": ("excéder",),
    "excéderaient": ("excéder",),
    "excéderai": ("excéder",),
    "excéderais": ("excéder",),
    "excéderait": ("excéder",),
    "excéderas": ("excéder",),
    "excédèrent": ("excéder",),
    "excéderez": ("excéder",),
    "excéderiez": ("excéder",),
    "excéderions": ("excéder",),
    "excéderons": ("excéder",),
    "excéderont": ("excéder",),
    "excédés": ("excéder",),
    "excèdes": ("excéder",),
    "excédez": ("excéder",),
    "excédiez": ("excéder",),
    "excédions": ("excéder",),
    "excédons": ("excéder",),
    "excluaient": ("exclure",),
    "excluais": ("exclure",),
    "excluait": ("exclure",),
    "excluant": ("exclure",),
    "exclue": ("exclure",),
    "excluent": ("exclure",),
    "exclues": ("exclure",),
    "excluez": ("exclure",),
    "excluiez": ("exclure",),
    "excluions": ("exclure",),
    "exclu": ("exclure",),
    "exclûmes": ("exclure",),
    "excluons": ("exclure",),
    "exclura": ("exclure",),
    "excluraient": ("exclure",),
    "exclurai": ("exclure",),
    "exclurais": ("exclure",),
    "exclurait": ("exclure",),
    "excluras": ("exclure",),
    "exclurent": ("exclure",),
    "exclurez": ("exclure",),
    "excluriez": ("exclure",),
    "exclurions": ("exclure",),
    "exclurons": ("exclure",),
    "excluront": ("exclure",),
    "exclus": ("exclure",),
    "exclussent": ("exclure",),
    "exclusses": ("exclure",),
    "exclusse": ("exclure",),
    "exclussiez": ("exclure",),
    "exclussions": ("exclure",),
    "exclûtes": ("exclure",),
    "exclut": ("exclure",),
    "exclût": ("exclure",),
    "excommuniaient": ("excommunier",),
    "excommuniai": ("excommunier",),
    "excommuniais": ("excommunier",),
    "excommuniait": ("excommunier",),
    "excommunia": ("excommunier",),
    "excommuniâmes": ("excommunier",),
    "excommuniant": ("excommunier",),
    "excommunias": ("excommunier",),
    "excommuniassent": ("excommunier",),
    "excommuniasses": ("excommunier",),
    "excommuniasse": ("excommunier",),
    "excommuniassiez": ("excommunier",),
    "excommuniassions": ("excommunier",),
    "excommuniâtes": ("excommunier",),
    "excommuniât": ("excommunier",),
    "excommuniée": ("excommunier",),
    "excommuniées": ("excommunier",),
    "excommunié": ("excommunier",),
    "excommunient": ("excommunier",),
    "excommunie": ("excommunier",),
    "excommuniera": ("excommunier",),
    "excommunieraient": ("excommunier",),
    "excommunierai": ("excommunier",),
    "excommunierais": ("excommunier",),
    "excommunierait": ("excommunier",),
    "excommunieras": ("excommunier",),
    "excommunièrent": ("excommunier",),
    "excommunierez": ("excommunier",),
    "excommunieriez": ("excommunier",),
    "excommunierions": ("excommunier",),
    "excommunierons": ("excommunier",),
    "excommunieront": ("excommunier",),
    "excommuniés": ("excommunier",),
    "excommunies": ("excommunier",),
    "excommuniez": ("excommunier",),
    "excommuniiez": ("excommunier",),
    "excommuniions": ("excommunier",),
    "excommunions": ("excommunier",),
    "excoriaient": ("excorier",),
    "excoriai": ("excorier",),
    "excoriais": ("excorier",),
    "excoriait": ("excorier",),
    "excoria": ("excorier",),
    "excoriâmes": ("excorier",),
    "excoriant": ("excorier",),
    "excorias": ("excorier",),
    "excoriassent": ("excorier",),
    "excoriasses": ("excorier",),
    "excoriasse": ("excorier",),
    "excoriassiez": ("excorier",),
    "excoriassions": ("excorier",),
    "excoriâtes": ("excorier",),
    "excoriât": ("excorier",),
    "excoriée": ("excorier",),
    "excoriées": ("excorier",),
    "excorié": ("excorier",),
    "excorient": ("excorier",),
    "excorie": ("excorier",),
    "excoriera": ("excorier",),
    "excorieraient": ("excorier",),
    "excorierai": ("excorier",),
    "excorierais": ("excorier",),
    "excorierait": ("excorier",),
    "excorieras": ("excorier",),
    "excorièrent": ("excorier",),
    "excorierez": ("excorier",),
    "excorieriez": ("excorier",),
    "excorierions": ("excorier",),
    "excorierons": ("excorier",),
    "excorieront": ("excorier",),
    "excoriés": ("excorier",),
    "excories": ("excorier",),
    "excoriez": ("excorier",),
    "excoriiez": ("excorier",),
    "excoriions": ("excorier",),
    "excorions": ("excorier",),
    "excrétaient": ("excréter",),
    "excrétai": ("excréter",),
    "excrétais": ("excréter",),
    "excrétait": ("excréter",),
    "excréta": ("excréter",),
    "excrétâmes": ("excréter",),
    "excrétant": ("excréter",),
    "excrétas": ("excréter",),
    "excrétassent": ("excréter",),
    "excrétasses": ("excréter",),
    "excrétasse": ("excréter",),
    "excrétassiez": ("excréter",),
    "excrétassions": ("excréter",),
    "excrétâtes": ("excréter",),
    "excrétât": ("excréter",),
    "excrétée": ("excréter",),
    "excrétées": ("excréter",),
    "excrété": ("excréter",),
    "excrètent": ("excréter",),
    "excrète": ("excréter",),
    "excrétera": ("excréter",),
    "excréteraient": ("excréter",),
    "excréterai": ("excréter",),
    "excréterais": ("excréter",),
    "excréterait": ("excréter",),
    "excréteras": ("excréter",),
    "excrétèrent": ("excréter",),
    "excréterez": ("excréter",),
    "excréteriez": ("excréter",),
    "excréterions": ("excréter",),
    "excréterons": ("excréter",),
    "excréteront": ("excréter",),
    "excrétés": ("excréter",),
    "excrètes": ("excréter",),
    "excrétez": ("excréter",),
    "excrétiez": ("excréter",),
    "excrétions": ("excréter",),
    "excrétons": ("excréter",),
    "excrois": ("excroître",),
    "excroissaient": ("excroître",),
    "excroissais": ("excroître",),
    "excroissait": ("excroître",),
    "excroissant": ("excroître",),
    "excroissent": ("excroître",),
    "excroisse": ("excroître",),
    "excroisses": ("excroître",),
    "excroissez": ("excroître",),
    "excroissiez": ("excroître",),
    "excroissions": ("excroître",),
    "excroissons": ("excroître",),
    "excroît": ("excroître",),
    "excroîtra": ("excroître",),
    "excroîtraient": ("excroître",),
    "excroîtrai": ("excroître",),
    "excroîtrais": ("excroître",),
    "excroîtrait": ("excroître",),
    "excroîtras": ("excroître",),
    "excroîtrez": ("excroître",),
    "excroîtriez": ("excroître",),
    "excroîtrions": ("excroître",),
    "excroîtrons": ("excroître",),
    "excroîtront": ("excroître",),
    "excrue": ("excroître",),
    "excrues": ("excroître",),
    "excru": ("excroître",),
    "excrûmes": ("excroître",),
    "excrurent": ("excroître",),
    "excrus": ("excroître",),
    "excrussent": ("excroître",),
    "excrusses": ("excroître",),
    "excrusse": ("excroître",),
    "excrussiez": ("excroître",),
    "excrussions": ("excroître",),
    "excrûtes": ("excroître",),
    "excrut": ("excroître",),
    "excrût": ("excroître",),
    "exécraient": ("exécrer",),
    "exécrai": ("exécrer",),
    "exécrais": ("exécrer",),
    "exécrait": ("exécrer",),
    "exécra": ("exécrer",),
    "exécrâmes": ("exécrer",),
    "exécrant": ("exécrer",),
    "exécras": ("exécrer",),
    "exécrassent": ("exécrer",),
    "exécrasses": ("exécrer",),
    "exécrasse": ("exécrer",),
    "exécrassiez": ("exécrer",),
    "exécrassions": ("exécrer",),
    "exécrâtes": ("exécrer",),
    "exécrât": ("exécrer",),
    "exécrée": ("exécrer",),
    "exécrées": ("exécrer",),
    "exécré": ("exécrer",),
    "exècrent": ("exécrer",),
    "exècre": ("exécrer",),
    "exécrera": ("exécrer",),
    "exécreraient": ("exécrer",),
    "exécrerai": ("exécrer",),
    "exécrerais": ("exécrer",),
    "exécrerait": ("exécrer",),
    "exécreras": ("exécrer",),
    "exécrèrent": ("exécrer",),
    "exécrerez": ("exécrer",),
    "exécreriez": ("exécrer",),
    "exécrerions": ("exécrer",),
    "exécrerons": ("exécrer",),
    "exécreront": ("exécrer",),
    "exécrés": ("exécrer",),
    "exècres": ("exécrer",),
    "exécrez": ("exécrer",),
    "exécriez": ("exécrer",),
    "exécrions": ("exécrer",),
    "exécrons": ("exécrer",),
    "exemplifiaient": ("exemplifier",),
    "exemplifiai": ("exemplifier",),
    "exemplifiais": ("exemplifier",),
    "exemplifiait": ("exemplifier",),
    "exemplifia": ("exemplifier",),
    "exemplifiâmes": ("exemplifier",),
    "exemplifiant": ("exemplifier",),
    "exemplifias": ("exemplifier",),
    "exemplifiassent": ("exemplifier",),
    "exemplifiasses": ("exemplifier",),
    "exemplifiasse": ("exemplifier",),
    "exemplifiassiez": ("exemplifier",),
    "exemplifiassions": ("exemplifier",),
    "exemplifiâtes": ("exemplifier",),
    "exemplifiât": ("exemplifier",),
    "exemplifiée": ("exemplifier",),
    "exemplifiées": ("exemplifier",),
    "exemplifié": ("exemplifier",),
    "exemplifient": ("exemplifier",),
    "exemplifie": ("exemplifier",),
    "exemplifiera": ("exemplifier",),
    "exemplifieraient": ("exemplifier",),
    "exemplifierai": ("exemplifier",),
    "exemplifierais": ("exemplifier",),
    "exemplifierait": ("exemplifier",),
    "exemplifieras": ("exemplifier",),
    "exemplifièrent": ("exemplifier",),
    "exemplifierez": ("exemplifier",),
    "exemplifieriez": ("exemplifier",),
    "exemplifierions": ("exemplifier",),
    "exemplifierons": ("exemplifier",),
    "exemplifieront": ("exemplifier",),
    "exemplifiés": ("exemplifier",),
    "exemplifies": ("exemplifier",),
    "exemplifiez": ("exemplifier",),
    "exemplifiiez": ("exemplifier",),
    "exemplifiions": ("exemplifier",),
    "exemplifions": ("exemplifier",),
    "exentéraient": ("exentérer",),
    "exentérai": ("exentérer",),
    "exentérais": ("exentérer",),
    "exentérait": ("exentérer",),
    "exentéra": ("exentérer",),
    "exentérâmes": ("exentérer",),
    "exentérant": ("exentérer",),
    "exentéras": ("exentérer",),
    "exentérassent": ("exentérer",),
    "exentérasses": ("exentérer",),
    "exentérasse": ("exentérer",),
    "exentérassiez": ("exentérer",),
    "exentérassions": ("exentérer",),
    "exentérâtes": ("exentérer",),
    "exentérât": ("exentérer",),
    "exentérée": ("exentérer",),
    "exentérées": ("exentérer",),
    "exentéré": ("exentérer",),
    "exentèrent": ("exentérer",),
    "exentère": ("exentérer",),
    "exentérera": ("exentérer",),
    "exentéreraient": ("exentérer",),
    "exentérerai": ("exentérer",),
    "exentérerais": ("exentérer",),
    "exentérerait": ("exentérer",),
    "exentéreras": ("exentérer",),
    "exentérèrent": ("exentérer",),
    "exentérerez": ("exentérer",),
    "exentéreriez": ("exentérer",),
    "exentérerions": ("exentérer",),
    "exentérerons": ("exentérer",),
    "exentéreront": ("exentérer",),
    "exentérés": ("exentérer",),
    "exentères": ("exentérer",),
    "exentérez": ("exentérer",),
    "exentériez": ("exentérer",),
    "exentérions": ("exentérer",),
    "exentérons": ("exentérer",),
    "exerçaient": ("exercer",),
    "exerçai": ("exercer",),
    "exerçais": ("exercer",),
    "exerçait": ("exercer",),
    "exerça": ("exercer",),
    "exerçâmes": ("exercer",),
    "exerçant": ("exercer",),
    "exerças": ("exercer",),
    "exerçassent": ("exercer",),
    "exerçasses": ("exercer",),
    "exerçasse": ("exercer",),
    "exerçassiez": ("exercer",),
    "exerçassions": ("exercer",),
    "exerçâtes": ("exercer",),
    "exerçât": ("exercer",),
    "exercée": ("exercer",),
    "exercées": ("exercer",),
    "exercé": ("exercer",),
    "exercent": ("exercer",),
    "exerce": ("exercer",),
    "exercera": ("exercer",),
    "exerceraient": ("exercer",),
    "exercerai": ("exercer",),
    "exercerais": ("exercer",),
    "exercerait": ("exercer",),
    "exerceras": ("exercer",),
    "exercèrent": ("exercer",),
    "exercerez": ("exercer",),
    "exerceriez": ("exercer",),
    "exercerions": ("exercer",),
    "exercerons": ("exercer",),
    "exerceront": ("exercer",),
    "exercés": ("exercer",),
    "exerces": ("exercer",),
    "exercez": ("exercer",),
    "exerciez": ("exercer",),
    "exercions": ("exercer",),
    "exerçons": ("exercer",),
    "exfoliaient": ("exfolier",),
    "exfoliai": ("exfolier",),
    "exfoliais": ("exfolier",),
    "exfoliait": ("exfolier",),
    "exfolia": ("exfolier",),
    "exfoliâmes": ("exfolier",),
    "exfoliant": ("exfolier",),
    "exfolias": ("exfolier",),
    "exfoliassent": ("exfolier",),
    "exfoliasses": ("exfolier",),
    "exfoliasse": ("exfolier",),
    "exfoliassiez": ("exfolier",),
    "exfoliassions": ("exfolier",),
    "exfoliâtes": ("exfolier",),
    "exfoliât": ("exfolier",),
    "exfoliée": ("exfolier",),
    "exfoliées": ("exfolier",),
    "exfolié": ("exfolier",),
    "exfolient": ("exfolier",),
    "exfolie": ("exfolier",),
    "exfoliera": ("exfolier",),
    "exfolieraient": ("exfolier",),
    "exfolierai": ("exfolier",),
    "exfolierais": ("exfolier",),
    "exfolierait": ("exfolier",),
    "exfolieras": ("exfolier",),
    "exfolièrent": ("exfolier",),
    "exfolierez": ("exfolier",),
    "exfolieriez": ("exfolier",),
    "exfolierions": ("exfolier",),
    "exfolierons": ("exfolier",),
    "exfolieront": ("exfolier",),
    "exfoliés": ("exfolier",),
    "exfolies": ("exfolier",),
    "exfoliez": ("exfolier",),
    "exfoliiez": ("exfolier",),
    "exfoliions": ("exfolier",),
    "exfolions": ("exfolier",),
    "exhérédaient": ("exhéréder",),
    "exhérédai": ("exhéréder",),
    "exhérédais": ("exhéréder",),
    "exhérédait": ("exhéréder",),
    "exhéréda": ("exhéréder",),
    "exhérédâmes": ("exhéréder",),
    "exhérédant": ("exhéréder",),
    "exhérédas": ("exhéréder",),
    "exhérédassent": ("exhéréder",),
    "exhérédasses": ("exhéréder",),
    "exhérédasse": ("exhéréder",),
    "exhérédassiez": ("exhéréder",),
    "exhérédassions": ("exhéréder",),
    "exhérédâtes": ("exhéréder",),
    "exhérédât": ("exhéréder",),
    "exhérédée": ("exhéréder",),
    "exhérédées": ("exhéréder",),
    "exhérédé": ("exhéréder",),
    "exhérèdent": ("exhéréder",),
    "exhérède": ("exhéréder",),
    "exhérédera": ("exhéréder",),
    "exhéréderaient": ("exhéréder",),
    "exhéréderai": ("exhéréder",),
    "exhéréderais": ("exhéréder",),
    "exhéréderait": ("exhéréder",),
    "exhéréderas": ("exhéréder",),
    "exhérédèrent": ("exhéréder",),
    "exhéréderez": ("exhéréder",),
    "exhéréderiez": ("exhéréder",),
    "exhéréderions": ("exhéréder",),
    "exhéréderons": ("exhéréder",),
    "exhéréderont": ("exhéréder",),
    "exhérédés": ("exhéréder",),
    "exhérèdes": ("exhéréder",),
    "exhérédez": ("exhéréder",),
    "exhérédiez": ("exhéréder",),
    "exhérédions": ("exhéréder",),
    "exhérédons": ("exhéréder",),
    "exigeaient": ("exiger",),
    "exigeai": ("exiger",),
    "exigeais": ("exiger",),
    "exigeait": ("exiger",),
    "exigea": ("exiger",),
    "exigeâmes": ("exiger",),
    "exigeant": ("exiger",),
    "exigeas": ("exiger",),
    "exigeassent": ("exiger",),
    "exigeasses": ("exiger",),
    "exigeasse": ("exiger",),
    "exigeassiez": ("exiger",),
    "exigeassions": ("exiger",),
    "exigeâtes": ("exiger",),
    "exigeât": ("exiger",),
    "exigée": ("exiger",),
    "exigées": ("exiger",),
    "exigé": ("exiger",),
    "exigent": ("exiger",),
    "exigeons": ("exiger",),
    "exige": ("exiger",),
    "exigera": ("exiger",),
    "exigeraient": ("exiger",),
    "exigerai": ("exiger",),
    "exigerais": ("exiger",),
    "exigerait": ("exiger",),
    "exigeras": ("exiger",),
    "exigèrent": ("exiger",),
    "exigerez": ("exiger",),
    "exigeriez": ("exiger",),
    "exigerions": ("exiger",),
    "exigerons": ("exiger",),
    "exigeront": ("exiger",),
    "exigés": ("exiger",),
    "exiges": ("exiger",),
    "exigez": ("exiger",),
    "exigiez": ("exiger",),
    "exigions": ("exiger",),
    "exonéraient": ("exonérer",),
    "exonérai": ("exonérer",),
    "exonérais": ("exonérer",),
    "exonérait": ("exonérer",),
    "exonéra": ("exonérer",),
    "exonérâmes": ("exonérer",),
    "exonérant": ("exonérer",),
    "exonéras": ("exonérer",),
    "exonérassent": ("exonérer",),
    "exonérasses": ("exonérer",),
    "exonérasse": ("exonérer",),
    "exonérassiez": ("exonérer",),
    "exonérassions": ("exonérer",),
    "exonérâtes": ("exonérer",),
    "exonérât": ("exonérer",),
    "exonérée": ("exonérer",),
    "exonérées": ("exonérer",),
    "exonéré": ("exonérer",),
    "exonèrent": ("exonérer",),
    "exonère": ("exonérer",),
    "exonérera": ("exonérer",),
    "exonéreraient": ("exonérer",),
    "exonérerai": ("exonérer",),
    "exonérerais": ("exonérer",),
    "exonérerait": ("exonérer",),
    "exonéreras": ("exonérer",),
    "exonérèrent": ("exonérer",),
    "exonérerez": ("exonérer",),
    "exonéreriez": ("exonérer",),
    "exonérerions": ("exonérer",),
    "exonérerons": ("exonérer",),
    "exonéreront": ("exonérer",),
    "exonérés": ("exonérer",),
    "exonères": ("exonérer",),
    "exonérez": ("exonérer",),
    "exonériez": ("exonérer",),
    "exonérions": ("exonérer",),
    "exonérons": ("exonérer",),
    "expassaient": ("expasser",),
    "expassai": ("expasser",),
    "expassais": ("expasser",),
    "expassait": ("expasser",),
    "expassa": ("expasser",),
    "expassâmes": ("expasser",),
    "expassant": ("expasser",),
    "expassas": ("expasser",),
    "expassassent": ("expasser",),
    "expassasses": ("expasser",),
    "expassasse": ("expasser",),
    "expassassiez": ("expasser",),
    "expassassions": ("expasser",),
    "expassâtes": ("expasser",),
    "expassât": ("expasser",),
    "expassée": ("expasser",),
    "expassées": ("expasser",),
    "expassé": ("expasser",),
    "expassent": ("expasser",),
    "expasse": ("expasser",),
    "expassera": ("expasser",),
    "expasseraient": ("expasser",),
    "expasserai": ("expasser",),
    "expasserais": ("expasser",),
    "expasserait": ("expasser",),
    "expasseras": ("expasser",),
    "expassèrent": ("expasser",),
    "expasserez": ("expasser",),
    "expasseriez": ("expasser",),
    "expasserions": ("expasser",),
    "expasserons": ("expasser",),
    "expasseront": ("expasser",),
    "expassés": ("expasser",),
    "expasses": ("expasser",),
    "expassez": ("expasser",),
    "expassiez": ("expasser",),
    "expassions": ("expasser",),
    "expassons": ("expasser",),
    "expatriaient": ("expatrier",),
    "expatriai": ("expatrier",),
    "expatriais": ("expatrier",),
    "expatriait": ("expatrier",),
    "expatria": ("expatrier",),
    "expatriâmes": ("expatrier",),
    "expatriant": ("expatrier",),
    "expatrias": ("expatrier",),
    "expatriassent": ("expatrier",),
    "expatriasses": ("expatrier",),
    "expatriasse": ("expatrier",),
    "expatriassiez": ("expatrier",),
    "expatriassions": ("expatrier",),
    "expatriâtes": ("expatrier",),
    "expatriât": ("expatrier",),
    "expatriée": ("expatrier",),
    "expatriées": ("expatrier",),
    "expatrié": ("expatrier",),
    "expatrient": ("expatrier",),
    "expatrie": ("expatrier",),
    "expatriera": ("expatrier",),
    "expatrieraient": ("expatrier",),
    "expatrierai": ("expatrier",),
    "expatrierais": ("expatrier",),
    "expatrierait": ("expatrier",),
    "expatrieras": ("expatrier",),
    "expatrièrent": ("expatrier",),
    "expatrierez": ("expatrier",),
    "expatrieriez": ("expatrier",),
    "expatrierions": ("expatrier",),
    "expatrierons": ("expatrier",),
    "expatrieront": ("expatrier",),
    "expatriés": ("expatrier",),
    "expatries": ("expatrier",),
    "expatriez": ("expatrier",),
    "expatriiez": ("expatrier",),
    "expatriions": ("expatrier",),
    "expatrions": ("expatrier",),
    "expédiaient": ("expédier",),
    "expédiai": ("expédier",),
    "expédiais": ("expédier",),
    "expédiait": ("expédier",),
    "expédia": ("expédier",),
    "expédiâmes": ("expédier",),
    "expédiant": ("expédier",),
    "expédias": ("expédier",),
    "expédiassent": ("expédier",),
    "expédiasses": ("expédier",),
    "expédiasse": ("expédier",),
    "expédiassiez": ("expédier",),
    "expédiassions": ("expédier",),
    "expédiâtes": ("expédier",),
    "expédiât": ("expédier",),
    "expédiée": ("expédier",),
    "expédiées": ("expédier",),
    "expédié": ("expédier",),
    "expédient": ("expédier",),
    "expédie": ("expédier",),
    "expédiera": ("expédier",),
    "expédieraient": ("expédier",),
    "expédierai": ("expédier",),
    "expédierais": ("expédier",),
    "expédierait": ("expédier",),
    "expédieras": ("expédier",),
    "expédièrent": ("expédier",),
    "expédierez": ("expédier",),
    "expédieriez": ("expédier",),
    "expédierions": ("expédier",),
    "expédierons": ("expédier",),
    "expédieront": ("expédier",),
    "expédiés": ("expédier",),
    "expédies": ("expédier",),
    "expédiez": ("expédier",),
    "expédiiez": ("expédier",),
    "expédiions": ("expédier",),
    "expédions": ("expédier",),
    "expiaient": ("expier",),
    "expiai": ("expier",),
    "expiais": ("expier",),
    "expiait": ("expier",),
    "expia": ("expier",),
    "expiâmes": ("expier",),
    "expiant": ("expier",),
    "expias": ("expier",),
    "expiassent": ("expier",),
    "expiasses": ("expier",),
    "expiasse": ("expier",),
    "expiassiez": ("expier",),
    "expiassions": ("expier",),
    "expiâtes": ("expier",),
    "expiât": ("expier",),
    "expiée": ("expier",),
    "expiées": ("expier",),
    "expié": ("expier",),
    "expient": ("expier",),
    "expie": ("expier",),
    "expiera": ("expier",),
    "expieraient": ("expier",),
    "expierai": ("expier",),
    "expierais": ("expier",),
    "expierait": ("expier",),
    "expieras": ("expier",),
    "expièrent": ("expier",),
    "expierez": ("expier",),
    "expieriez": ("expier",),
    "expierions": ("expier",),
    "expierons": ("expier",),
    "expieront": ("expier",),
    "expiés": ("expier",),
    "expies": ("expier",),
    "expiez": ("expier",),
    "expiiez": ("expier",),
    "expiions": ("expier",),
    "expions": ("expier",),
    "expropriaient": ("exproprier",),
    "expropriai": ("exproprier",),
    "expropriais": ("exproprier",),
    "expropriait": ("exproprier",),
    "expropria": ("exproprier",),
    "expropriâmes": ("exproprier",),
    "expropriant": ("exproprier",),
    "exproprias": ("exproprier",),
    "expropriassent": ("exproprier",),
    "expropriasses": ("exproprier",),
    "expropriasse": ("exproprier",),
    "expropriassiez": ("exproprier",),
    "expropriassions": ("exproprier",),
    "expropriâtes": ("exproprier",),
    "expropriât": ("exproprier",),
    "expropriée": ("exproprier",),
    "expropriées": ("exproprier",),
    "exproprié": ("exproprier",),
    "exproprient": ("exproprier",),
    "exproprie": ("exproprier",),
    "expropriera": ("exproprier",),
    "exproprieraient": ("exproprier",),
    "exproprierai": ("exproprier",),
    "exproprierais": ("exproprier",),
    "exproprierait": ("exproprier",),
    "exproprieras": ("exproprier",),
    "exproprièrent": ("exproprier",),
    "exproprierez": ("exproprier",),
    "exproprieriez": ("exproprier",),
    "exproprierions": ("exproprier",),
    "exproprierons": ("exproprier",),
    "exproprieront": ("exproprier",),
    "expropriés": ("exproprier",),
    "expropries": ("exproprier",),
    "expropriez": ("exproprier",),
    "expropriiez": ("exproprier",),
    "expropriions": ("exproprier",),
    "exproprions": ("exproprier",),
    "expurgeaient": ("expurger",),
    "expurgeai": ("expurger",),
    "expurgeais": ("expurger",),
    "expurgeait": ("expurger",),
    "expurgea": ("expurger",),
    "expurgeâmes": ("expurger",),
    "expurgeant": ("expurger",),
    "expurgeas": ("expurger",),
    "expurgeassent": ("expurger",),
    "expurgeasses": ("expurger",),
    "expurgeasse": ("expurger",),
    "expurgeassiez": ("expurger",),
    "expurgeassions": ("expurger",),
    "expurgeâtes": ("expurger",),
    "expurgeât": ("expurger",),
    "expurgée": ("expurger",),
    "expurgées": ("expurger",),
    "expurgé": ("expurger",),
    "expurgent": ("expurger",),
    "expurgeons": ("expurger",),
    "expurge": ("expurger",),
    "expurgera": ("expurger",),
    "expurgeraient": ("expurger",),
    "expurgerai": ("expurger",),
    "expurgerais": ("expurger",),
    "expurgerait": ("expurger",),
    "expurgeras": ("expurger",),
    "expurgèrent": ("expurger",),
    "expurgerez": ("expurger",),
    "expurgeriez": ("expurger",),
    "expurgerions": ("expurger",),
    "expurgerons": ("expurger",),
    "expurgeront": ("expurger",),
    "expurgés": ("expurger",),
    "expurges": ("expurger",),
    "expurgez": ("expurger",),
    "expurgiez": ("expurger",),
    "expurgions": ("expurger",),
    "extasiaient": ("extasier",),
    "extasiai": ("extasier",),
    "extasiais": ("extasier",),
    "extasiait": ("extasier",),
    "extasia": ("extasier",),
    "extasiâmes": ("extasier",),
    "extasiant": ("extasier",),
    "extasias": ("extasier",),
    "extasiassent": ("extasier",),
    "extasiasses": ("extasier",),
    "extasiasse": ("extasier",),
    "extasiassiez": ("extasier",),
    "extasiassions": ("extasier",),
    "extasiâtes": ("extasier",),
    "extasiât": ("extasier",),
    "extasiée": ("extasier",),
    "extasiées": ("extasier",),
    "extasié": ("extasier",),
    "extasient": ("extasier",),
    "extasie": ("extasier",),
    "extasiera": ("extasier",),
    "extasieraient": ("extasier",),
    "extasierai": ("extasier",),
    "extasierais": ("extasier",),
    "extasierait": ("extasier",),
    "extasieras": ("extasier",),
    "extasièrent": ("extasier",),
    "extasierez": ("extasier",),
    "extasieriez": ("extasier",),
    "extasierions": ("extasier",),
    "extasierons": ("extasier",),
    "extasieront": ("extasier",),
    "extasiés": ("extasier",),
    "extasies": ("extasier",),
    "extasiez": ("extasier",),
    "extasiiez": ("extasier",),
    "extasiions": ("extasier",),
    "extasions": ("extasier",),
    "extraient": ("extraire",),
    "extraie": ("extraire",),
    "extraies": ("extraire",),
    "extraira": ("extraire",),
    "extrairaient": ("extraire",),
    "extrairai": ("extraire",),
    "extrairais": ("extraire",),
    "extrairait": ("extraire",),
    "extrairas": ("extraire",),
    "extrairez": ("extraire",),
    "extrairiez": ("extraire",),
    "extrairions": ("extraire",),
    "extrairons": ("extraire",),
    "extrairont": ("extraire",),
    "extrais": ("extraire",),
    "extraite": ("extraire",),
    "extraites": ("extraire",),
    "extrait": ("extraire",),
    "extraits": ("extraire",),
    "extrayaient": ("extraire",),
    "extrayais": ("extraire",),
    "extrayait": ("extraire",),
    "extrayant": ("extraire",),
    "extrayez": ("extraire",),
    "extrayiez": ("extraire",),
    "extrayions": ("extraire",),
    "extrayons": ("extraire",),
    "extravertie": ("extravertir",),
    "extraverties": ("extravertir",),
    "extraverti": ("extravertir",),
    "extravertîmes": ("extravertir",),
    "extravertira": ("extravertir",),
    "extravertiraient": ("extravertir",),
    "extravertirai": ("extravertir",),
    "extravertirais": ("extravertir",),
    "extravertirait": ("extravertir",),
    "extravertiras": ("extravertir",),
    "extravertirent": ("extravertir",),
    "extravertirez": ("extravertir",),
    "extravertiriez": ("extravertir",),
    "extravertirions": ("extravertir",),
    "extravertirons": ("extravertir",),
    "extravertiront": ("extravertir",),
    "extravertis": ("extravertir",),
    "extravertissaient": ("extravertir",),
    "extravertissais": ("extravertir",),
    "extravertissait": ("extravertir",),
    "extravertissant": ("extravertir",),
    "extravertissent": ("extravertir",),
    "extravertisse": ("extravertir",),
    "extravertisses": ("extravertir",),
    "extravertissez": ("extravertir",),
    "extravertissiez": ("extravertir",),
    "extravertissions": ("extravertir",),
    "extravertissons": ("extravertir",),
    "extravertîtes": ("extravertir",),
    "extravertit": ("extravertir",),
    "extravertît": ("extravertir",),
    "exubéraient": ("exubérer",),
    "exubérai": ("exubérer",),
    "exubérais": ("exubérer",),
    "exubérait": ("exubérer",),
    "exubéra": ("exubérer",),
    "exubérâmes": ("exubérer",),
    "exubérant": ("exubérer",),
    "exubéras": ("exubérer",),
    "exubérassent": ("exubérer",),
    "exubérasses": ("exubérer",),
    "exubérasse": ("exubérer",),
    "exubérassiez": ("exubérer",),
    "exubérassions": ("exubérer",),
    "exubérâtes": ("exubérer",),
    "exubérât": ("exubérer",),
    "exubéré": ("exubérer",),
    "exubèrent": ("exubérer",),
    "exubère": ("exubérer",),
    "exubérera": ("exubérer",),
    "exubéreraient": ("exubérer",),
    "exubérerai": ("exubérer",),
    "exubérerais": ("exubérer",),
    "exubérerait": ("exubérer",),
    "exubéreras": ("exubérer",),
    "exubérèrent": ("exubérer",),
    "exubérerez": ("exubérer",),
    "exubéreriez": ("exubérer",),
    "exubérerions": ("exubérer",),
    "exubérerons": ("exubérer",),
    "exubéreront": ("exubérer",),
    "exubères": ("exubérer",),
    "exubérez": ("exubérer",),
    "exubériez": ("exubérer",),
    "exubérions": ("exubérer",),
    "exubérons": ("exubérer",),
    "exulcéraient": ("exulcérer",),
    "exulcérai": ("exulcérer",),
    "exulcérais": ("exulcérer",),
    "exulcérait": ("exulcérer",),
    "exulcéra": ("exulcérer",),
    "exulcérâmes": ("exulcérer",),
    "exulcérant": ("exulcérer",),
    "exulcéras": ("exulcérer",),
    "exulcérassent": ("exulcérer",),
    "exulcérasses": ("exulcérer",),
    "exulcérasse": ("exulcérer",),
    "exulcérassiez": ("exulcérer",),
    "exulcérassions": ("exulcérer",),
    "exulcérâtes": ("exulcérer",),
    "exulcérât": ("exulcérer",),
    "exulcérée": ("exulcérer",),
    "exulcérées": ("exulcérer",),
    "exulcéré": ("exulcérer",),
    "exulcèrent": ("exulcérer",),
    "exulcère": ("exulcérer",),
    "exulcérera": ("exulcérer",),
    "exulcéreraient": ("exulcérer",),
    "exulcérerai": ("exulcérer",),
    "exulcérerais": ("exulcérer",),
    "exulcérerait": ("exulcérer",),
    "exulcéreras": ("exulcérer",),
    "exulcérèrent": ("exulcérer",),
    "exulcérerez": ("exulcérer",),
    "exulcéreriez": ("exulcérer",),
    "exulcérerions": ("exulcérer",),
    "exulcérerons": ("exulcérer",),
    "exulcéreront": ("exulcérer",),
    "exulcérés": ("exulcérer",),
    "exulcères": ("exulcérer",),
    "exulcérez": ("exulcérer",),
    "exulcériez": ("exulcérer",),
    "exulcérions": ("exulcérer",),
    "exulcérons": ("exulcérer",),
    "façaient": ("facer",),
    "façai": ("facer",),
    "façais": ("facer",),
    "façait": ("facer",),
    "faça": ("facer",),
    "façâmes": ("facer",),
    "façant": ("facer",),
    "faças": ("facer",),
    "façassent": ("facer",),
    "façasses": ("facer",),
    "façasse": ("facer",),
    "façassiez": ("facer",),
    "façassions": ("facer",),
    "façâtes": ("facer",),
    "façât": ("facer",),
    "facée": ("facer",),
    "facées": ("facer",),
    "facé": ("facer",),
    "facent": ("facer",),
    "face": ("facer",),
    "facera": ("facer",),
    "faceraient": ("facer",),
    "facerai": ("facer",),
    "facerais": ("facer",),
    "facerait": ("facer",),
    "faceras": ("facer",),
    "facèrent": ("facer",),
    "facerez": ("facer",),
    "faceriez": ("facer",),
    "facerions": ("facer",),
    "facerons": ("facer",),
    "faceront": ("facer",),
    "facés": ("facer",),
    "faces": ("facer",),
    "facez": ("facer",),
    "faciez": ("facer",),
    "facions": ("facer",),
    "façons": ("facer",),
    "faibli": ("faiblir",),
    "faiblîmes": ("faiblir",),
    "faiblira": ("faiblir",),
    "faibliraient": ("faiblir",),
    "faiblirai": ("faiblir",),
    "faiblirais": ("faiblir",),
    "faiblirait": ("faiblir",),
    "faibliras": ("faiblir",),
    "faiblirent": ("faiblir",),
    "faiblirez": ("faiblir",),
    "faibliriez": ("faiblir",),
    "faiblirions": ("faiblir",),
    "faiblirons": ("faiblir",),
    "faibliront": ("faiblir",),
    "faiblis": ("faiblir",),
    "faiblissaient": ("faiblir",),
    "faiblissais": ("faiblir",),
    "faiblissait": ("faiblir",),
    "faiblissant": ("faiblir",),
    "faiblissent": ("faiblir",),
    "faiblisse": ("faiblir",),
    "faiblisses": ("faiblir",),
    "faiblissez": ("faiblir",),
    "faiblissiez": ("faiblir",),
    "faiblissions": ("faiblir",),
    "faiblissons": ("faiblir",),
    "faiblîtes": ("faiblir",),
    "faiblit": ("faiblir",),
    "faiblît": ("faiblir",),
    "faïençaient": ("faïencer",),
    "faïençai": ("faïencer",),
    "faïençais": ("faïencer",),
    "faïençait": ("faïencer",),
    "faïença": ("faïencer",),
    "faïençâmes": ("faïencer",),
    "faïençant": ("faïencer",),
    "faïenças": ("faïencer",),
    "faïençassent": ("faïencer",),
    "faïençasses": ("faïencer",),
    "faïençasse": ("faïencer",),
    "faïençassiez": ("faïencer",),
    "faïençassions": ("faïencer",),
    "faïençâtes": ("faïencer",),
    "faïençât": ("faïencer",),
    "faïencée": ("faïencer",),
    "faïencées": ("faïencer",),
    "faïencé": ("faïencer",),
    "faïencent": ("faïencer",),
    "faïence": ("faïencer",),
    "faïencera": ("faïencer",),
    "faïenceraient": ("faïencer",),
    "faïencerai": ("faïencer",),
    "faïencerais": ("faïencer",),
    "faïencerait": ("faïencer",),
    "faïenceras": ("faïencer",),
    "faïencèrent": ("faïencer",),
    "faïencerez": ("faïencer",),
    "faïenceriez": ("faïencer",),
    "faïencerions": ("faïencer",),
    "faïencerons": ("faïencer",),
    "faïenceront": ("faïencer",),
    "faïencés": ("faïencer",),
    "faïences": ("faïencer",),
    "faïencez": ("faïencer",),
    "faïenciez": ("faïencer",),
    "faïencions": ("faïencer",),
    "faïençons": ("faïencer",),
    "faillaient": ("faillir",),
    "faillais": ("faillir",),
    "faillait": ("faillir",),
    "faillant": ("faillir",),
    "faillent": ("faillir",),
    "faille": ("falloir",),
    "failles": ("faillir",),
    "faillez": ("faillir",),
    "failliez": ("faillir",),
    "failli": ("faillir",),
    "faillîmes": ("faillir",),
    "faillions": ("faillir",),
    "faillira": ("faillir",),
    "failliraient": ("faillir",),
    "faillirai": ("faillir",),
    "faillirais": ("faillir",),
    "faillirait": ("faillir",),
    "failliras": ("faillir",),
    "faillirent": ("faillir",),
    "faillirez": ("faillir",),
    "failliriez": ("faillir",),
    "faillirions": ("faillir",),
    "faillirons": ("faillir",),
    "failliront": ("faillir",),
    "faillis": ("faillir",),
    "faillissaient": ("faillir",),
    "faillissais": ("faillir",),
    "faillissait": ("faillir",),
    "faillissant": ("faillir",),
    "faillissent": ("faillir",),
    "faillisse": ("faillir",),
    "faillisses": ("faillir",),
    "faillissez": ("faillir",),
    "faillissiez": ("faillir",),
    "faillissions": ("faillir",),
    "faillissons": ("faillir",),
    "faillîtes": ("faillir",),
    "faillit": ("faillir",),
    "faillît": ("faillir",),
    "faillons": ("faillir",),
    "faudra": ("falloir",),
    "faudraient": ("faillir",),
    "faudrai": ("faillir",),
    "faudrais": ("faillir",),
    "faudrait": ("falloir",),
    "faudras": ("faillir",),
    "faudrez": ("faillir",),
    "faudriez": ("faillir",),
    "faudrions": ("faillir",),
    "faudrons": ("faillir",),
    "faudront": ("faillir",),
    "faut": ("falloir",),
    "faux": ("faillir",),
    "faisaient": ("faire",),
    "faisais": ("faire",),
    "faisait": ("faire",),
    "faisant": ("faire",),
    "faisiez": ("faire",),
    "faisions": ("faire",),
    "faisons": ("faire",),
    "fais": ("faire",),
    "faite": ("faire",),
    "faites": ("faire",),
    "fait": ("faire",),
    "faits": ("faire",),
    "fassent": ("faire",),
    "fasse": ("faire",),
    "fasses": ("faire",),
    "fassiez": ("faire",),
    "fassions": ("faire",),
    "fera": ("faire",),
    "feraient": ("faire",),
    "ferai": ("faire",),
    "ferais": ("faire",),
    "ferait": ("faire",),
    "feras": ("faire",),
    "ferez": ("faire",),
    "feriez": ("faire",),
    "ferions": ("faire",),
    "ferons": ("faire",),
    "feront": ("faire",),
    "fîmes": ("faire",),
    "firent": ("faire",),
    "fis": ("faire",),
    "fissent": ("faire",),
    "fisses": ("faire",),
    "fisse": ("faire",),
    "fissiez": ("faire",),
    "fissions": ("faire",),
    "fîtes": ("faire",),
    "fit": ("faire",),
    "fît": ("faire",),
    "font": ("faire",),
    "falbalassaient": ("falbalasser",),
    "falbalassai": ("falbalasser",),
    "falbalassais": ("falbalasser",),
    "falbalassait": ("falbalasser",),
    "falbalassa": ("falbalasser",),
    "falbalassâmes": ("falbalasser",),
    "falbalassant": ("falbalasser",),
    "falbalassas": ("falbalasser",),
    "falbalassassent": ("falbalasser",),
    "falbalassasses": ("falbalasser",),
    "falbalassasse": ("falbalasser",),
    "falbalassassiez": ("falbalasser",),
    "falbalassassions": ("falbalasser",),
    "falbalassâtes": ("falbalasser",),
    "falbalassât": ("falbalasser",),
    "falbalassée": ("falbalasser",),
    "falbalassées": ("falbalasser",),
    "falbalassé": ("falbalasser",),
    "falbalassent": ("falbalasser",),
    "falbalasse": ("falbalasser",),
    "falbalassera": ("falbalasser",),
    "falbalasseraient": ("falbalasser",),
    "falbalasserai": ("falbalasser",),
    "falbalasserais": ("falbalasser",),
    "falbalasserait": ("falbalasser",),
    "falbalasseras": ("falbalasser",),
    "falbalassèrent": ("falbalasser",),
    "falbalasserez": ("falbalasser",),
    "falbalasseriez": ("falbalasser",),
    "falbalasserions": ("falbalasser",),
    "falbalasserons": ("falbalasser",),
    "falbalasseront": ("falbalasser",),
    "falbalassés": ("falbalasser",),
    "falbalasses": ("falbalasser",),
    "falbalassez": ("falbalasser",),
    "falbalassiez": ("falbalasser",),
    "falbalassions": ("falbalasser",),
    "falbalassons": ("falbalasser",),
    "fallait": ("falloir",),
    "fallu": ("falloir",),
    "fallut": ("falloir",),
    "fallût": ("falloir",),
    "falsifiaient": ("falsifier",),
    "falsifiai": ("falsifier",),
    "falsifiais": ("falsifier",),
    "falsifiait": ("falsifier",),
    "falsifia": ("falsifier",),
    "falsifiâmes": ("falsifier",),
    "falsifiant": ("falsifier",),
    "falsifias": ("falsifier",),
    "falsifiassent": ("falsifier",),
    "falsifiasses": ("falsifier",),
    "falsifiasse": ("falsifier",),
    "falsifiassiez": ("falsifier",),
    "falsifiassions": ("falsifier",),
    "falsifiâtes": ("falsifier",),
    "falsifiât": ("falsifier",),
    "falsifiée": ("falsifier",),
    "falsifiées": ("falsifier",),
    "falsifié": ("falsifier",),
    "falsifient": ("falsifier",),
    "falsifie": ("falsifier",),
    "falsifiera": ("falsifier",),
    "falsifieraient": ("falsifier",),
    "falsifierai": ("falsifier",),
    "falsifierais": ("falsifier",),
    "falsifierait": ("falsifier",),
    "falsifieras": ("falsifier",),
    "falsifièrent": ("falsifier",),
    "falsifierez": ("falsifier",),
    "falsifieriez": ("falsifier",),
    "falsifierions": ("falsifier",),
    "falsifierons": ("falsifier",),
    "falsifieront": ("falsifier",),
    "falsifiés": ("falsifier",),
    "falsifies": ("falsifier",),
    "falsifiez": ("falsifier",),
    "falsifiiez": ("falsifier",),
    "falsifiions": ("falsifier",),
    "falsifions": ("falsifier",),
    "fantasiaient": ("fantasier",),
    "fantasiai": ("fantasier",),
    "fantasiais": ("fantasier",),
    "fantasiait": ("fantasier",),
    "fantasia": ("fantasier",),
    "fantasiâmes": ("fantasier",),
    "fantasiant": ("fantasier",),
    "fantasias": ("fantasier",),
    "fantasiassent": ("fantasier",),
    "fantasiasses": ("fantasier",),
    "fantasiasse": ("fantasier",),
    "fantasiassiez": ("fantasier",),
    "fantasiassions": ("fantasier",),
    "fantasiâtes": ("fantasier",),
    "fantasiât": ("fantasier",),
    "fantasiée": ("fantasier",),
    "fantasiées": ("fantasier",),
    "fantasié": ("fantasier",),
    "fantasient": ("fantasier",),
    "fantasie": ("fantasier",),
    "fantasiera": ("fantasier",),
    "fantasieraient": ("fantasier",),
    "fantasierai": ("fantasier",),
    "fantasierais": ("fantasier",),
    "fantasierait": ("fantasier",),
    "fantasieras": ("fantasier",),
    "fantasièrent": ("fantasier",),
    "fantasierez": ("fantasier",),
    "fantasieriez": ("fantasier",),
    "fantasierions": ("fantasier",),
    "fantasierons": ("fantasier",),
    "fantasieront": ("fantasier",),
    "fantasiés": ("fantasier",),
    "fantasies": ("fantasier",),
    "fantasiez": ("fantasier",),
    "fantasiiez": ("fantasier",),
    "fantasiions": ("fantasier",),
    "fantasions": ("fantasier",),
    "farcie": ("farcir",),
    "farcies": ("farcir",),
    "farci": ("farcir",),
    "farcîmes": ("farcir",),
    "farcira": ("farcir",),
    "farciraient": ("farcir",),
    "farcirai": ("farcir",),
    "farcirais": ("farcir",),
    "farcirait": ("farcir",),
    "farciras": ("farcir",),
    "farcirent": ("farcir",),
    "farcirez": ("farcir",),
    "farciriez": ("farcir",),
    "farcirions": ("farcir",),
    "farcirons": ("farcir",),
    "farciront": ("farcir",),
    "farcis": ("farcir",),
    "farcissaient": ("farcir",),
    "farcissais": ("farcir",),
    "farcissait": ("farcir",),
    "farcissant": ("farcir",),
    "farcissent": ("farcir",),
    "farcisse": ("farcir",),
    "farcisses": ("farcir",),
    "farcissez": ("farcir",),
    "farcissiez": ("farcir",),
    "farcissions": ("farcir",),
    "farcissons": ("farcir",),
    "farcîtes": ("farcir",),
    "farcit": ("farcir",),
    "farcît": ("farcir",),
    "fardelaient": ("fardeler",),
    "fardelai": ("fardeler",),
    "fardelais": ("fardeler",),
    "fardelait": ("fardeler",),
    "fardela": ("fardeler",),
    "fardelâmes": ("fardeler",),
    "fardelant": ("fardeler",),
    "fardelas": ("fardeler",),
    "fardelassent": ("fardeler",),
    "fardelasses": ("fardeler",),
    "fardelasse": ("fardeler",),
    "fardelassiez": ("fardeler",),
    "fardelassions": ("fardeler",),
    "fardelâtes": ("fardeler",),
    "fardelât": ("fardeler",),
    "fardelée": ("fardeler",),
    "fardelées": ("fardeler",),
    "fardelé": ("fardeler",),
    "fardèlent": ("fardeler",),
    "fardèle": ("fardeler",),
    "fardèlera": ("fardeler",),
    "fardèleraient": ("fardeler",),
    "fardèlerai": ("fardeler",),
    "fardèlerais": ("fardeler",),
    "fardèlerait": ("fardeler",),
    "fardèleras": ("fardeler",),
    "fardelèrent": ("fardeler",),
    "fardèlerez": ("fardeler",),
    "fardèleriez": ("fardeler",),
    "fardèlerions": ("fardeler",),
    "fardèlerons": ("fardeler",),
    "fardèleront": ("fardeler",),
    "fardelés": ("fardeler",),
    "fardèles": ("fardeler",),
    "fardelez": ("fardeler",),
    "fardeliez": ("fardeler",),
    "fardelions": ("fardeler",),
    "fardelons": ("fardeler",),
    "faséiaient": ("faséier",),
    "faséiai": ("faséier",),
    "faséiais": ("faséier",),
    "faséiait": ("faséier",),
    "faséia": ("faséier",),
    "faséiâmes": ("faséier",),
    "faséiant": ("faséier",),
    "faséias": ("faséier",),
    "faséiassent": ("faséier",),
    "faséiasses": ("faséier",),
    "faséiasse": ("faséier",),
    "faséiassiez": ("faséier",),
    "faséiassions": ("faséier",),
    "faséiâtes": ("faséier",),
    "faséiât": ("faséier",),
    "faséié": ("faséier",),
    "faséient": ("faséier",),
    "faséie": ("faséier",),
    "faséiera": ("faséier",),
    "faséieraient": ("faséier",),
    "faséierai": ("faséier",),
    "faséierais": ("faséier",),
    "faséierait": ("faséier",),
    "faséieras": ("faséier",),
    "faséièrent": ("faséier",),
    "faséierez": ("faséier",),
    "faséieriez": ("faséier",),
    "faséierions": ("faséier",),
    "faséierons": ("faséier",),
    "faséieront": ("faséier",),
    "faséies": ("faséier",),
    "faséiez": ("faséier",),
    "faséiiez": ("faséier",),
    "faséiions": ("faséier",),
    "faséions": ("faséier",),
    "fatrassaient": ("fatrasser",),
    "fatrassai": ("fatrasser",),
    "fatrassais": ("fatrasser",),
    "fatrassait": ("fatrasser",),
    "fatrassa": ("fatrasser",),
    "fatrassâmes": ("fatrasser",),
    "fatrassant": ("fatrasser",),
    "fatrassas": ("fatrasser",),
    "fatrassassent": ("fatrasser",),
    "fatrassasses": ("fatrasser",),
    "fatrassasse": ("fatrasser",),
    "fatrassassiez": ("fatrasser",),
    "fatrassassions": ("fatrasser",),
    "fatrassâtes": ("fatrasser",),
    "fatrassât": ("fatrasser",),
    "fatrassé": ("fatrasser",),
    "fatrassent": ("fatrasser",),
    "fatrasse": ("fatrasser",),
    "fatrassera": ("fatrasser",),
    "fatrasseraient": ("fatrasser",),
    "fatrasserai": ("fatrasser",),
    "fatrasserais": ("fatrasser",),
    "fatrasserait": ("fatrasser",),
    "fatrasseras": ("fatrasser",),
    "fatrassèrent": ("fatrasser",),
    "fatrasserez": ("fatrasser",),
    "fatrasseriez": ("fatrasser",),
    "fatrasserions": ("fatrasser",),
    "fatrasserons": ("fatrasser",),
    "fatrasseront": ("fatrasser",),
    "fatrasses": ("fatrasser",),
    "fatrassez": ("fatrasser",),
    "fatrassiez": ("fatrasser",),
    "fatrassions": ("fatrasser",),
    "fatrassons": ("fatrasser",),
    "fédéraient": ("fédérer",),
    "fédérai": ("fédérer",),
    "fédérais": ("fédérer",),
    "fédérait": ("fédérer",),
    "fédéra": ("fédérer",),
    "fédérâmes": ("fédérer",),
    "fédérant": ("fédérer",),
    "fédéras": ("fédérer",),
    "fédérassent": ("fédérer",),
    "fédérasses": ("fédérer",),
    "fédérasse": ("fédérer",),
    "fédérassiez": ("fédérer",),
    "fédérassions": ("fédérer",),
    "fédérâtes": ("fédérer",),
    "fédérât": ("fédérer",),
    "fédérée": ("fédérer",),
    "fédérées": ("fédérer",),
    "fédéré": ("fédérer",),
    "fédèrent": ("fédérer",),
    "fédère": ("fédérer",),
    "fédérera": ("fédérer",),
    "fédéreraient": ("fédérer",),
    "fédérerai": ("fédérer",),
    "fédérerais": ("fédérer",),
    "fédérerait": ("fédérer",),
    "fédéreras": ("fédérer",),
    "fédérèrent": ("fédérer",),
    "fédérerez": ("fédérer",),
    "fédéreriez": ("fédérer",),
    "fédérerions": ("fédérer",),
    "fédérerons": ("fédérer",),
    "fédéreront": ("fédérer",),
    "fédérés": ("fédérer",),
    "fédères": ("fédérer",),
    "fédérez": ("fédérer",),
    "fédériez": ("fédérer",),
    "fédérions": ("fédérer",),
    "fédérons": ("fédérer",),
    "feignaient": ("feindre",),
    "feignais": ("feindre",),
    "feignait": ("feindre",),
    "feignant": ("feindre",),
    "feignent": ("feindre",),
    "feigne": ("feindre",),
    "feignes": ("feindre",),
    "feignez": ("feindre",),
    "feigniez": ("feindre",),
    "feignîmes": ("feindre",),
    "feignions": ("feindre",),
    "feignirent": ("feindre",),
    "feignis": ("feindre",),
    "feignissent": ("feindre",),
    "feignisses": ("feindre",),
    "feignisse": ("feindre",),
    "feignissiez": ("feindre",),
    "feignissions": ("feindre",),
    "feignîtes": ("feindre",),
    "feignit": ("feindre",),
    "feignît": ("feindre",),
    "feignons": ("feindre",),
    "feindra": ("feindre",),
    "feindraient": ("feindre",),
    "feindrai": ("feindre",),
    "feindrais": ("feindre",),
    "feindrait": ("feindre",),
    "feindras": ("feindre",),
    "feindrez": ("feindre",),
    "feindriez": ("feindre",),
    "feindrions": ("feindre",),
    "feindrons": ("feindre",),
    "feindront": ("feindre",),
    "feins": ("feindre",),
    "feinte": ("feindre",),
    "feintes": ("feindre",),
    "feint": ("feindre",),
    "feints": ("feindre",),
    "fendaient": ("fendre",),
    "fendais": ("fendre",),
    "fendait": ("fendre",),
    "fendant": ("fendre",),
    "fendent": ("fendre",),
    "fende": ("fendre",),
    "fendes": ("fendre",),
    "fendez": ("fendre",),
    "fendiez": ("fendre",),
    "fendîmes": ("fendre",),
    "fendions": ("fendre",),
    "fendirent": ("fendre",),
    "fendis": ("fendre",),
    "fendissent": ("fendre",),
    "fendisses": ("fendre",),
    "fendisse": ("fendre",),
    "fendissiez": ("fendre",),
    "fendissions": ("fendre",),
    "fendîtes": ("fendre",),
    "fendit": ("fendre",),
    "fendît": ("fendre",),
    "fendons": ("fendre",),
    "fend": ("fendre",),
    "fendra": ("fendre",),
    "fendraient": ("fendre",),
    "fendrai": ("fendre",),
    "fendrais": ("fendre",),
    "fendrait": ("fendre",),
    "fendras": ("fendre",),
    "fendrez": ("fendre",),
    "fendriez": ("fendre",),
    "fendrions": ("fendre",),
    "fendrons": ("fendre",),
    "fendront": ("fendre",),
    "fends": ("fendre",),
    "fendue": ("fendre",),
    "fendues": ("fendre",),
    "fendu": ("fendre",),
    "fendus": ("fendre",),
    "festoient": ("festoyer",),
    "festoie": ("festoyer",),
    "festoiera": ("festoyer",),
    "festoieraient": ("festoyer",),
    "festoierai": ("festoyer",),
    "festoierais": ("festoyer",),
    "festoierait": ("festoyer",),
    "festoieras": ("festoyer",),
    "festoierez": ("festoyer",),
    "festoieriez": ("festoyer",),
    "festoierions": ("festoyer",),
    "festoierons": ("festoyer",),
    "festoieront": ("festoyer",),
    "festoies": ("festoyer",),
    "festoyaient": ("festoyer",),
    "festoyai": ("festoyer",),
    "festoyais": ("festoyer",),
    "festoyait": ("festoyer",),
    "festoya": ("festoyer",),
    "festoyâmes": ("festoyer",),
    "festoyant": ("festoyer",),
    "festoyas": ("festoyer",),
    "festoyassent": ("festoyer",),
    "festoyasses": ("festoyer",),
    "festoyasse": ("festoyer",),
    "festoyassiez": ("festoyer",),
    "festoyassions": ("festoyer",),
    "festoyâtes": ("festoyer",),
    "festoyât": ("festoyer",),
    "festoyé": ("festoyer",),
    "festoyèrent": ("festoyer",),
    "festoyez": ("festoyer",),
    "festoyiez": ("festoyer",),
    "festoyions": ("festoyer",),
    "festoyons": ("festoyer",),
    "feuilletaient": ("feuilleter",),
    "feuilletai": ("feuilleter",),
    "feuilletais": ("feuilleter",),
    "feuilletait": ("feuilleter",),
    "feuilleta": ("feuilleter",),
    "feuilletâmes": ("feuilleter",),
    "feuilletant": ("feuilleter",),
    "feuilletas": ("feuilleter",),
    "feuilletassent": ("feuilleter",),
    "feuilletasses": ("feuilleter",),
    "feuilletasse": ("feuilleter",),
    "feuilletassiez": ("feuilleter",),
    "feuilletassions": ("feuilleter",),
    "feuilletâtes": ("feuilleter",),
    "feuilletât": ("feuilleter",),
    "feuilletée": ("feuilleter",),
    "feuilletées": ("feuilleter",),
    "feuilleté": ("feuilleter",),
    "feuilletèrent": ("feuilleter",),
    "feuilletés": ("feuilleter",),
    "feuilletez": ("feuilleter",),
    "feuilletiez": ("feuilleter",),
    "feuilletions": ("feuilleter",),
    "feuilletons": ("feuilleter",),
    "feuillettent": ("feuilleter",),
    "feuillette": ("feuilleter",),
    "feuillettera": ("feuilleter",),
    "feuilletteraient": ("feuilleter",),
    "feuilletterai": ("feuilleter",),
    "feuilletterais": ("feuilleter",),
    "feuilletterait": ("feuilleter",),
    "feuilletteras": ("feuilleter",),
    "feuilletterez": ("feuilleter",),
    "feuilletteriez": ("feuilleter",),
    "feuilletterions": ("feuilleter",),
    "feuilletterons": ("feuilleter",),
    "feuilletteront": ("feuilleter",),
    "feuillettes": ("feuilleter",),
    "feuillie": ("feuillir",),
    "feuillies": ("feuillir",),
    "feuilli": ("feuillir",),
    "feuillîmes": ("feuillir",),
    "feuillira": ("feuillir",),
    "feuilliraient": ("feuillir",),
    "feuillirai": ("feuillir",),
    "feuillirais": ("feuillir",),
    "feuillirait": ("feuillir",),
    "feuilliras": ("feuillir",),
    "feuillirent": ("feuillir",),
    "feuillirez": ("feuillir",),
    "feuilliriez": ("feuillir",),
    "feuillirions": ("feuillir",),
    "feuillirons": ("feuillir",),
    "feuilliront": ("feuillir",),
    "feuillis": ("feuillir",),
    "feuillissaient": ("feuillir",),
    "feuillissais": ("feuillir",),
    "feuillissait": ("feuillir",),
    "feuillissant": ("feuillir",),
    "feuillissent": ("feuillir",),
    "feuillisse": ("feuillir",),
    "feuillisses": ("feuillir",),
    "feuillissez": ("feuillir",),
    "feuillissiez": ("feuillir",),
    "feuillissions": ("feuillir",),
    "feuillissons": ("feuillir",),
    "feuillîtes": ("feuillir",),
    "feuillit": ("feuillir",),
    "feuillît": ("feuillir",),
    "fiançaient": ("fiancer",),
    "fiançai": ("fiancer",),
    "fiançais": ("fiancer",),
    "fiançait": ("fiancer",),
    "fiança": ("fiancer",),
    "fiançâmes": ("fiancer",),
    "fiançant": ("fiancer",),
    "fianças": ("fiancer",),
    "fiançassent": ("fiancer",),
    "fiançasses": ("fiancer",),
    "fiançasse": ("fiancer",),
    "fiançassiez": ("fiancer",),
    "fiançassions": ("fiancer",),
    "fiançâtes": ("fiancer",),
    "fiançât": ("fiancer",),
    "fiancée": ("fiancer",),
    "fiancées": ("fiancer",),
    "fiancé": ("fiancer",),
    "fiancent": ("fiancer",),
    "fiance": ("fiancer",),
    "fiancera": ("fiancer",),
    "fianceraient": ("fiancer",),
    "fiancerai": ("fiancer",),
    "fiancerais": ("fiancer",),
    "fiancerait": ("fiancer",),
    "fianceras": ("fiancer",),
    "fiancèrent": ("fiancer",),
    "fiancerez": ("fiancer",),
    "fianceriez": ("fiancer",),
    "fiancerions": ("fiancer",),
    "fiancerons": ("fiancer",),
    "fianceront": ("fiancer",),
    "fiancés": ("fiancer",),
    "fiances": ("fiancer",),
    "fiancez": ("fiancer",),
    "fianciez": ("fiancer",),
    "fiancions": ("fiancer",),
    "fiançons": ("fiancer",),
    "ficelaient": ("ficeler",),
    "ficelai": ("ficeler",),
    "ficelais": ("ficeler",),
    "ficelait": ("ficeler",),
    "ficela": ("ficeler",),
    "ficelâmes": ("ficeler",),
    "ficelant": ("ficeler",),
    "ficelas": ("ficeler",),
    "ficelassent": ("ficeler",),
    "ficelasses": ("ficeler",),
    "ficelasse": ("ficeler",),
    "ficelassiez": ("ficeler",),
    "ficelassions": ("ficeler",),
    "ficelâtes": ("ficeler",),
    "ficelât": ("ficeler",),
    "ficelée": ("ficeler",),
    "ficelées": ("ficeler",),
    "ficelé": ("ficeler",),
    "ficelèrent": ("ficeler",),
    "ficelés": ("ficeler",),
    "ficelez": ("ficeler",),
    "ficeliez": ("ficeler",),
    "ficelions": ("ficeler",),
    "ficellent": ("ficeler",),
    "ficelle": ("ficeler",),
    "ficellera": ("ficeler",),
    "ficelleraient": ("ficeler",),
    "ficellerai": ("ficeler",),
    "ficellerais": ("ficeler",),
    "ficellerait": ("ficeler",),
    "ficelleras": ("ficeler",),
    "ficellerez": ("ficeler",),
    "ficelleriez": ("ficeler",),
    "ficellerions": ("ficeler",),
    "ficellerons": ("ficeler",),
    "ficelleront": ("ficeler",),
    "ficelles": ("ficeler",),
    "ficelons": ("ficeler",),
    "fiaient": ("fier",),
    "fiai": ("fier",),
    "fiais": ("fier",),
    "fiait": ("fier",),
    "fia": ("fier",),
    "fiâmes": ("fier",),
    "fiant": ("fier",),
    "fias": ("fier",),
    "fiassent": ("fier",),
    "fiasses": ("fier",),
    "fiasse": ("fier",),
    "fiassiez": ("fier",),
    "fiassions": ("fier",),
    "fiâtes": ("fier",),
    "fiât": ("fier",),
    "fiée": ("fier",),
    "fiées": ("fier",),
    "fié": ("fier",),
    "fient": ("fier",),
    "fie": ("fier",),
    "fiera": ("fier",),
    "fieraient": ("fier",),
    "fierai": ("fier",),
    "fierais": ("fier",),
    "fierait": ("fier",),
    "fieras": ("fier",),
    "fièrent": ("fier",),
    "fierez": ("fier",),
    "fieriez": ("fier",),
    "fierions": ("fier",),
    "fierons": ("fier",),
    "fieront": ("fier",),
    "fiés": ("fier",),
    "fies": ("fier",),
    "fiez": ("fier",),
    "fiiez": ("fier",),
    "fiions": ("fier",),
    "fions": ("fier",),
    "figeaient": ("figer",),
    "figeai": ("figer",),
    "figeais": ("figer",),
    "figeait": ("figer",),
    "figea": ("figer",),
    "figeâmes": ("figer",),
    "figeant": ("figer",),
    "figeas": ("figer",),
    "figeassent": ("figer",),
    "figeasses": ("figer",),
    "figeasse": ("figer",),
    "figeassiez": ("figer",),
    "figeassions": ("figer",),
    "figeâtes": ("figer",),
    "figeât": ("figer",),
    "figée": ("figer",),
    "figées": ("figer",),
    "figé": ("figer",),
    "figent": ("figer",),
    "figeons": ("figer",),
    "fige": ("figer",),
    "figera": ("figer",),
    "figeraient": ("figer",),
    "figerai": ("figer",),
    "figerais": ("figer",),
    "figerait": ("figer",),
    "figeras": ("figer",),
    "figèrent": ("figer",),
    "figerez": ("figer",),
    "figeriez": ("figer",),
    "figerions": ("figer",),
    "figerons": ("figer",),
    "figeront": ("figer",),
    "figés": ("figer",),
    "figes": ("figer",),
    "figez": ("figer",),
    "figiez": ("figer",),
    "figions": ("figer",),
    "filetaient": ("fileter",),
    "filetai": ("fileter",),
    "filetais": ("fileter",),
    "filetait": ("fileter",),
    "fileta": ("fileter",),
    "filetâmes": ("fileter",),
    "filetant": ("fileter",),
    "filetas": ("fileter",),
    "filetassent": ("fileter",),
    "filetasses": ("fileter",),
    "filetasse": ("fileter",),
    "filetassiez": ("fileter",),
    "filetassions": ("fileter",),
    "filetâtes": ("fileter",),
    "filetât": ("fileter",),
    "filetée": ("fileter",),
    "filetées": ("fileter",),
    "fileté": ("fileter",),
    "filetèrent": ("fileter",),
    "filetés": ("fileter",),
    "filetez": ("fileter",),
    "filetiez": ("fileter",),
    "filetions": ("fileter",),
    "filetons": ("fileter",),
    "filettent": ("fileter",),
    "filette": ("fileter",),
    "filettera": ("fileter",),
    "filetteraient": ("fileter",),
    "filetterai": ("fileter",),
    "filetterais": ("fileter",),
    "filetterait": ("fileter",),
    "filetteras": ("fileter",),
    "filetterez": ("fileter",),
    "filetteriez": ("fileter",),
    "filetterions": ("fileter",),
    "filetterons": ("fileter",),
    "filetteront": ("fileter",),
    "filettes": ("fileter",),
    "finançaient": ("financer",),
    "finançai": ("financer",),
    "finançais": ("financer",),
    "finançait": ("financer",),
    "finança": ("financer",),
    "finançâmes": ("financer",),
    "finançant": ("financer",),
    "finanças": ("financer",),
    "finançassent": ("financer",),
    "finançasses": ("financer",),
    "finançasse": ("financer",),
    "finançassiez": ("financer",),
    "finançassions": ("financer",),
    "finançâtes": ("financer",),
    "finançât": ("financer",),
    "financée": ("financer",),
    "financées": ("financer",),
    "financé": ("financer",),
    "financent": ("financer",),
    "finance": ("financer",),
    "financera": ("financer",),
    "financeraient": ("financer",),
    "financerai": ("financer",),
    "financerais": ("financer",),
    "financerait": ("financer",),
    "financeras": ("financer",),
    "financèrent": ("financer",),
    "financerez": ("financer",),
    "financeriez": ("financer",),
    "financerions": ("financer",),
    "financerons": ("financer",),
    "financeront": ("financer",),
    "financés": ("financer",),
    "finances": ("financer",),
    "financez": ("financer",),
    "financiez": ("financer",),
    "financions": ("financer",),
    "finançons": ("financer",),
    "finassaient": ("finasser",),
    "finassai": ("finasser",),
    "finassais": ("finasser",),
    "finassait": ("finasser",),
    "finassa": ("finasser",),
    "finassâmes": ("finasser",),
    "finassant": ("finasser",),
    "finassas": ("finasser",),
    "finassassent": ("finasser",),
    "finassasses": ("finasser",),
    "finassasse": ("finasser",),
    "finassassiez": ("finasser",),
    "finassassions": ("finasser",),
    "finassâtes": ("finasser",),
    "finassât": ("finasser",),
    "finassé": ("finasser",),
    "finassent": ("finasser",),
    "finasse": ("finasser",),
    "finassera": ("finasser",),
    "finasseraient": ("finasser",),
    "finasserai": ("finasser",),
    "finasserais": ("finasser",),
    "finasserait": ("finasser",),
    "finasseras": ("finasser",),
    "finassèrent": ("finasser",),
    "finasserez": ("finasser",),
    "finasseriez": ("finasser",),
    "finasserions": ("finasser",),
    "finasserons": ("finasser",),
    "finasseront": ("finasser",),
    "finasses": ("finasser",),
    "finassez": ("finasser",),
    "finassiez": ("finasser",),
    "finassions": ("finasser",),
    "finassons": ("finasser",),
    "finie": ("finir",),
    "finies": ("finir",),
    "fini": ("finir",),
    "finîmes": ("finir",),
    "finira": ("finir",),
    "finiraient": ("finir",),
    "finirai": ("finir",),
    "finirais": ("finir",),
    "finirait": ("finir",),
    "finiras": ("finir",),
    "finirent": ("finir",),
    "finirez": ("finir",),
    "finiriez": ("finir",),
    "finirions": ("finir",),
    "finirons": ("finir",),
    "finiront": ("finir",),
    "finis": ("finir",),
    "finissaient": ("finir",),
    "finissais": ("finir",),
    "finissait": ("finir",),
    "finissant": ("finir",),
    "finissent": ("finir",),
    "finisse": ("finir",),
    "finisses": ("finir",),
    "finissez": ("finir",),
    "finissiez": ("finir",),
    "finissions": ("finir",),
    "finissons": ("finir",),
    "finîtes": ("finir",),
    "finit": ("finir",),
    "finît": ("finir",),
    "flamboient": ("flamboyer",),
    "flamboie": ("flamboyer",),
    "flamboiera": ("flamboyer",),
    "flamboieraient": ("flamboyer",),
    "flamboierai": ("flamboyer",),
    "flamboierais": ("flamboyer",),
    "flamboierait": ("flamboyer",),
    "flamboieras": ("flamboyer",),
    "flamboierez": ("flamboyer",),
    "flamboieriez": ("flamboyer",),
    "flamboierions": ("flamboyer",),
    "flamboierons": ("flamboyer",),
    "flamboieront": ("flamboyer",),
    "flamboies": ("flamboyer",),
    "flamboyaient": ("flamboyer",),
    "flamboyai": ("flamboyer",),
    "flamboyais": ("flamboyer",),
    "flamboyait": ("flamboyer",),
    "flamboya": ("flamboyer",),
    "flamboyâmes": ("flamboyer",),
    "flamboyant": ("flamboyer",),
    "flamboyas": ("flamboyer",),
    "flamboyassent": ("flamboyer",),
    "flamboyasses": ("flamboyer",),
    "flamboyasse": ("flamboyer",),
    "flamboyassiez": ("flamboyer",),
    "flamboyassions": ("flamboyer",),
    "flamboyâtes": ("flamboyer",),
    "flamboyât": ("flamboyer",),
    "flamboyé": ("flamboyer",),
    "flamboyèrent": ("flamboyer",),
    "flamboyez": ("flamboyer",),
    "flamboyiez": ("flamboyer",),
    "flamboyions": ("flamboyer",),
    "flamboyons": ("flamboyer",),
    "flapie": ("flapir",),
    "flapies": ("flapir",),
    "flapi": ("flapir",),
    "flapîmes": ("flapir",),
    "flapira": ("flapir",),
    "flapiraient": ("flapir",),
    "flapirai": ("flapir",),
    "flapirais": ("flapir",),
    "flapirait": ("flapir",),
    "flapiras": ("flapir",),
    "flapirent": ("flapir",),
    "flapirez": ("flapir",),
    "flapiriez": ("flapir",),
    "flapirions": ("flapir",),
    "flapirons": ("flapir",),
    "flapiront": ("flapir",),
    "flapis": ("flapir",),
    "flapissaient": ("flapir",),
    "flapissais": ("flapir",),
    "flapissait": ("flapir",),
    "flapissant": ("flapir",),
    "flapissent": ("flapir",),
    "flapisse": ("flapir",),
    "flapisses": ("flapir",),
    "flapissez": ("flapir",),
    "flapissiez": ("flapir",),
    "flapissions": ("flapir",),
    "flapissons": ("flapir",),
    "flapîtes": ("flapir",),
    "flapit": ("flapir",),
    "flapît": ("flapir",),
    "fléchaient": ("flécher",),
    "fléchai": ("flécher",),
    "fléchais": ("flécher",),
    "fléchait": ("flécher",),
    "flécha": ("flécher",),
    "fléchâmes": ("flécher",),
    "fléchant": ("flécher",),
    "fléchas": ("flécher",),
    "fléchassent": ("flécher",),
    "fléchasses": ("flécher",),
    "fléchasse": ("flécher",),
    "fléchassiez": ("flécher",),
    "fléchassions": ("flécher",),
    "fléchâtes": ("flécher",),
    "fléchât": ("flécher",),
    "fléchée": ("flécher",),
    "fléchées": ("flécher",),
    "fléché": ("flécher",),
    "flèchent": ("flécher",),
    "flèche": ("flécher",),
    "fléchera": ("flécher",),
    "flécheraient": ("flécher",),
    "flécherai": ("flécher",),
    "flécherais": ("flécher",),
    "flécherait": ("flécher",),
    "flécheras": ("flécher",),
    "fléchèrent": ("flécher",),
    "flécherez": ("flécher",),
    "flécheriez": ("flécher",),
    "flécherions": ("flécher",),
    "flécherons": ("flécher",),
    "flécheront": ("flécher",),
    "fléchés": ("flécher",),
    "flèches": ("flécher",),
    "fléchez": ("flécher",),
    "fléchiez": ("flécher",),
    "fléchions": ("flécher",),
    "fléchons": ("flécher",),
    "fléchie": ("fléchir",),
    "fléchies": ("fléchir",),
    "fléchi": ("fléchir",),
    "fléchîmes": ("fléchir",),
    "fléchira": ("fléchir",),
    "fléchiraient": ("fléchir",),
    "fléchirai": ("fléchir",),
    "fléchirais": ("fléchir",),
    "fléchirait": ("fléchir",),
    "fléchiras": ("fléchir",),
    "fléchirent": ("fléchir",),
    "fléchirez": ("fléchir",),
    "fléchiriez": ("fléchir",),
    "fléchirions": ("fléchir",),
    "fléchirons": ("fléchir",),
    "fléchiront": ("fléchir",),
    "fléchis": ("fléchir",),
    "fléchissaient": ("fléchir",),
    "fléchissais": ("fléchir",),
    "fléchissait": ("fléchir",),
    "fléchissant": ("fléchir",),
    "fléchissent": ("fléchir",),
    "fléchisse": ("fléchir",),
    "fléchisses": ("fléchir",),
    "fléchissez": ("fléchir",),
    "fléchissiez": ("fléchir",),
    "fléchissions": ("fléchir",),
    "fléchissons": ("fléchir",),
    "fléchîtes": ("fléchir",),
    "fléchit": ("fléchir",),
    "fléchît": ("fléchir",),
    "flemmassaient": ("flemmasser",),
    "flemmassai": ("flemmasser",),
    "flemmassais": ("flemmasser",),
    "flemmassait": ("flemmasser",),
    "flemmassa": ("flemmasser",),
    "flemmassâmes": ("flemmasser",),
    "flemmassant": ("flemmasser",),
    "flemmassas": ("flemmasser",),
    "flemmassassent": ("flemmasser",),
    "flemmassasses": ("flemmasser",),
    "flemmassasse": ("flemmasser",),
    "flemmassassiez": ("flemmasser",),
    "flemmassassions": ("flemmasser",),
    "flemmassâtes": ("flemmasser",),
    "flemmassât": ("flemmasser",),
    "flemmassé": ("flemmasser",),
    "flemmassent": ("flemmasser",),
    "flemmasse": ("flemmasser",),
    "flemmassera": ("flemmasser",),
    "flemmasseraient": ("flemmasser",),
    "flemmasserai": ("flemmasser",),
    "flemmasserais": ("flemmasser",),
    "flemmasserait": ("flemmasser",),
    "flemmasseras": ("flemmasser",),
    "flemmassèrent": ("flemmasser",),
    "flemmasserez": ("flemmasser",),
    "flemmasseriez": ("flemmasser",),
    "flemmasserions": ("flemmasser",),
    "flemmasserons": ("flemmasser",),
    "flemmasseront": ("flemmasser",),
    "flemmasses": ("flemmasser",),
    "flemmassez": ("flemmasser",),
    "flemmassiez": ("flemmasser",),
    "flemmassions": ("flemmasser",),
    "flemmassons": ("flemmasser",),
    "flétrie": ("flétrir",),
    "flétries": ("flétrir",),
    "flétri": ("flétrir",),
    "flétrîmes": ("flétrir",),
    "flétrira": ("flétrir",),
    "flétriraient": ("flétrir",),
    "flétrirai": ("flétrir",),
    "flétrirais": ("flétrir",),
    "flétrirait": ("flétrir",),
    "flétriras": ("flétrir",),
    "flétrirent": ("flétrir",),
    "flétrirez": ("flétrir",),
    "flétririez": ("flétrir",),
    "flétririons": ("flétrir",),
    "flétrirons": ("flétrir",),
    "flétriront": ("flétrir",),
    "flétris": ("flétrir",),
    "flétrissaient": ("flétrir",),
    "flétrissais": ("flétrir",),
    "flétrissait": ("flétrir",),
    "flétrissant": ("flétrir",),
    "flétrissent": ("flétrir",),
    "flétrisse": ("flétrir",),
    "flétrisses": ("flétrir",),
    "flétrissez": ("flétrir",),
    "flétrissiez": ("flétrir",),
    "flétrissions": ("flétrir",),
    "flétrissons": ("flétrir",),
    "flétrîtes": ("flétrir",),
    "flétrit": ("flétrir",),
    "flétrît": ("flétrir",),
    "fleuretaient": ("fleureter",),
    "fleuretai": ("fleureter",),
    "fleuretais": ("fleureter",),
    "fleuretait": ("fleureter",),
    "fleureta": ("fleureter",),
    "fleuretâmes": ("fleureter",),
    "fleuretant": ("fleureter",),
    "fleuretas": ("fleureter",),
    "fleuretassent": ("fleureter",),
    "fleuretasses": ("fleureter",),
    "fleuretasse": ("fleureter",),
    "fleuretassiez": ("fleureter",),
    "fleuretassions": ("fleureter",),
    "fleuretâtes": ("fleureter",),
    "fleuretât": ("fleureter",),
    "fleuretée": ("fleureter",),
    "fleuretées": ("fleureter",),
    "fleureté": ("fleureter",),
    "fleuretèrent": ("fleureter",),
    "fleuretés": ("fleureter",),
    "fleuretez": ("fleureter",),
    "fleuretiez": ("fleureter",),
    "fleuretions": ("fleureter",),
    "fleuretons": ("fleureter",),
    "fleurettent": ("fleureter",),
    "fleurette": ("fleureter",),
    "fleurettera": ("fleureter",),
    "fleuretteraient": ("fleureter",),
    "fleuretterai": ("fleureter",),
    "fleuretterais": ("fleureter",),
    "fleuretterait": ("fleureter",),
    "fleuretteras": ("fleureter",),
    "fleuretterez": ("fleureter",),
    "fleuretteriez": ("fleureter",),
    "fleuretterions": ("fleureter",),
    "fleuretterons": ("fleureter",),
    "fleuretteront": ("fleureter",),
    "fleurettes": ("fleureter",),
    "fleurie": ("fleurir",),
    "fleuries": ("fleurir",),
    "fleuri": ("fleurir",),
    "fleurîmes": ("fleurir",),
    "fleurira": ("fleurir",),
    "fleuriraient": ("fleurir",),
    "fleurirai": ("fleurir",),
    "fleurirais": ("fleurir",),
    "fleurirait": ("fleurir",),
    "fleuriras": ("fleurir",),
    "fleurirent": ("fleurir",),
    "fleurirez": ("fleurir",),
    "fleuririez": ("fleurir",),
    "fleuririons": ("fleurir",),
    "fleurirons": ("fleurir",),
    "fleuriront": ("fleurir",),
    "fleuris": ("fleurir",),
    "fleurissaient": ("fleurir",),
    "fleurissais": ("fleurir",),
    "fleurissait": ("fleurir",),
    "fleurissant": ("fleurir",),
    "fleurissent": ("fleurir",),
    "fleurisse": ("fleurir",),
    "fleurisses": ("fleurir",),
    "fleurissez": ("fleurir",),
    "fleurissiez": ("fleurir",),
    "fleurissions": ("fleurir",),
    "fleurissons": ("fleurir",),
    "fleurîtes": ("fleurir",),
    "fleurit": ("fleurir",),
    "fleurît": ("fleurir",),
    "florissaient": ("florir",),
    "florissais": ("fleurir",),
    "florissait": ("florir",),
    "florissant": ("florir",),
    "florissiez": ("fleurir",),
    "florissions": ("fleurir",),
    "flongeaient": ("flonger",),
    "flongeai": ("flonger",),
    "flongeais": ("flonger",),
    "flongeait": ("flonger",),
    "flongea": ("flonger",),
    "flongeâmes": ("flonger",),
    "flongeant": ("flonger",),
    "flongeas": ("flonger",),
    "flongeassent": ("flonger",),
    "flongeasses": ("flonger",),
    "flongeasse": ("flonger",),
    "flongeassiez": ("flonger",),
    "flongeassions": ("flonger",),
    "flongeâtes": ("flonger",),
    "flongeât": ("flonger",),
    "flongée": ("flonger",),
    "flongées": ("flonger",),
    "flongé": ("flonger",),
    "flongent": ("flonger",),
    "flongeons": ("flonger",),
    "flonge": ("flonger",),
    "flongera": ("flonger",),
    "flongeraient": ("flonger",),
    "flongerai": ("flonger",),
    "flongerais": ("flonger",),
    "flongerait": ("flonger",),
    "flongeras": ("flonger",),
    "flongèrent": ("flonger",),
    "flongerez": ("flonger",),
    "flongeriez": ("flonger",),
    "flongerions": ("flonger",),
    "flongerons": ("flonger",),
    "flongeront": ("flonger",),
    "flongés": ("flonger",),
    "flonges": ("flonger",),
    "flongez": ("flonger",),
    "flongiez": ("flonger",),
    "flongions": ("flonger",),
    "flori": ("florir",),
    "florira": ("florir",),
    "floriraient": ("florir",),
    "florirait": ("florir",),
    "florirent": ("florir",),
    "floriront": ("florir",),
    "florissent": ("florir",),
    "florisse": ("florir",),
    "florit": ("florir",),
    "florît": ("florir",),
    "fluidifiaient": ("fluidifier",),
    "fluidifiai": ("fluidifier",),
    "fluidifiais": ("fluidifier",),
    "fluidifiait": ("fluidifier",),
    "fluidifia": ("fluidifier",),
    "fluidifiâmes": ("fluidifier",),
    "fluidifiant": ("fluidifier",),
    "fluidifias": ("fluidifier",),
    "fluidifiassent": ("fluidifier",),
    "fluidifiasses": ("fluidifier",),
    "fluidifiasse": ("fluidifier",),
    "fluidifiassiez": ("fluidifier",),
    "fluidifiassions": ("fluidifier",),
    "fluidifiâtes": ("fluidifier",),
    "fluidifiât": ("fluidifier",),
    "fluidifiée": ("fluidifier",),
    "fluidifiées": ("fluidifier",),
    "fluidifié": ("fluidifier",),
    "fluidifient": ("fluidifier",),
    "fluidifie": ("fluidifier",),
    "fluidifiera": ("fluidifier",),
    "fluidifieraient": ("fluidifier",),
    "fluidifierai": ("fluidifier",),
    "fluidifierais": ("fluidifier",),
    "fluidifierait": ("fluidifier",),
    "fluidifieras": ("fluidifier",),
    "fluidifièrent": ("fluidifier",),
    "fluidifierez": ("fluidifier",),
    "fluidifieriez": ("fluidifier",),
    "fluidifierions": ("fluidifier",),
    "fluidifierons": ("fluidifier",),
    "fluidifieront": ("fluidifier",),
    "fluidifiés": ("fluidifier",),
    "fluidifies": ("fluidifier",),
    "fluidifiez": ("fluidifier",),
    "fluidifiiez": ("fluidifier",),
    "fluidifiions": ("fluidifier",),
    "fluidifions": ("fluidifier",),
    "fluoresçaient": ("fluorescer",),
    "fluoresçai": ("fluorescer",),
    "fluoresçais": ("fluorescer",),
    "fluoresçait": ("fluorescer",),
    "fluoresça": ("fluorescer",),
    "fluoresçâmes": ("fluorescer",),
    "fluoresçant": ("fluorescer",),
    "fluoresças": ("fluorescer",),
    "fluoresçassent": ("fluorescer",),
    "fluoresçasses": ("fluorescer",),
    "fluoresçasse": ("fluorescer",),
    "fluoresçassiez": ("fluorescer",),
    "fluoresçassions": ("fluorescer",),
    "fluoresçâtes": ("fluorescer",),
    "fluoresçât": ("fluorescer",),
    "fluorescée": ("fluorescer",),
    "fluorescées": ("fluorescer",),
    "fluorescé": ("fluorescer",),
    "fluorescent": ("fluorescer",),
    "fluoresce": ("fluorescer",),
    "fluorescera": ("fluorescer",),
    "fluoresceraient": ("fluorescer",),
    "fluorescerai": ("fluorescer",),
    "fluorescerais": ("fluorescer",),
    "fluorescerait": ("fluorescer",),
    "fluoresceras": ("fluorescer",),
    "fluorescèrent": ("fluorescer",),
    "fluorescerez": ("fluorescer",),
    "fluoresceriez": ("fluorescer",),
    "fluorescerions": ("fluorescer",),
    "fluorescerons": ("fluorescer",),
    "fluoresceront": ("fluorescer",),
    "fluorescés": ("fluorescer",),
    "fluoresces": ("fluorescer",),
    "fluorescez": ("fluorescer",),
    "fluoresciez": ("fluorescer",),
    "fluorescions": ("fluorescer",),
    "fluoresçons": ("fluorescer",),
    "folletaient": ("folleter",),
    "folletai": ("folleter",),
    "folletais": ("folleter",),
    "folletait": ("folleter",),
    "folleta": ("folleter",),
    "folletâmes": ("folleter",),
    "folletant": ("folleter",),
    "folletas": ("folleter",),
    "folletassent": ("folleter",),
    "folletasses": ("folleter",),
    "folletasse": ("folleter",),
    "folletassiez": ("folleter",),
    "folletassions": ("folleter",),
    "folletâtes": ("folleter",),
    "folletât": ("folleter",),
    "folletée": ("folleter",),
    "folletées": ("folleter",),
    "folleté": ("folleter",),
    "folletèrent": ("folleter",),
    "folletés": ("folleter",),
    "folletez": ("folleter",),
    "folletiez": ("folleter",),
    "folletions": ("folleter",),
    "folletons": ("folleter",),
    "follettent": ("folleter",),
    "follette": ("folleter",),
    "follettera": ("folleter",),
    "folletteraient": ("folleter",),
    "folletterai": ("folleter",),
    "folletterais": ("folleter",),
    "folletterait": ("folleter",),
    "folletteras": ("folleter",),
    "folletterez": ("folleter",),
    "folletteriez": ("folleter",),
    "folletterions": ("folleter",),
    "folletterons": ("folleter",),
    "folletteront": ("folleter",),
    "follettes": ("folleter",),
    "fonçaient": ("foncer",),
    "fonçai": ("foncer",),
    "fonçais": ("foncer",),
    "fonçait": ("foncer",),
    "fonça": ("foncer",),
    "fonçâmes": ("foncer",),
    "fonçant": ("foncer",),
    "fonças": ("foncer",),
    "fonçassent": ("foncer",),
    "fonçasses": ("foncer",),
    "fonçasse": ("foncer",),
    "fonçassiez": ("foncer",),
    "fonçassions": ("foncer",),
    "fonçâtes": ("foncer",),
    "fonçât": ("foncer",),
    "foncée": ("foncer",),
    "foncées": ("foncer",),
    "foncé": ("foncer",),
    "foncent": ("foncer",),
    "fonce": ("foncer",),
    "foncera": ("foncer",),
    "fonceraient": ("foncer",),
    "foncerai": ("foncer",),
    "foncerais": ("foncer",),
    "foncerait": ("foncer",),
    "fonceras": ("foncer",),
    "foncèrent": ("foncer",),
    "foncerez": ("foncer",),
    "fonceriez": ("foncer",),
    "foncerions": ("foncer",),
    "foncerons": ("foncer",),
    "fonceront": ("foncer",),
    "foncés": ("foncer",),
    "fonces": ("foncer",),
    "foncez": ("foncer",),
    "fonciez": ("foncer",),
    "foncions": ("foncer",),
    "fonçons": ("foncer",),
    "fondaient": ("fondre",),
    "fondais": ("fondre",),
    "fondait": ("fondre",),
    "fondant": ("fondre",),
    "fondent": ("fondre",),
    "fonde": ("fondre",),
    "fondes": ("fondre",),
    "fondez": ("fondre",),
    "fondiez": ("fondre",),
    "fondîmes": ("fondre",),
    "fondions": ("fondre",),
    "fondirent": ("fondre",),
    "fondis": ("fondre",),
    "fondissent": ("fondre",),
    "fondisses": ("fondre",),
    "fondisse": ("fondre",),
    "fondissiez": ("fondre",),
    "fondissions": ("fondre",),
    "fondîtes": ("fondre",),
    "fondit": ("fondre",),
    "fondît": ("fondre",),
    "fondons": ("fondre",),
    "fond": ("fondre",),
    "fondra": ("fondre",),
    "fondraient": ("fondre",),
    "fondrai": ("fondre",),
    "fondrais": ("fondre",),
    "fondrait": ("fondre",),
    "fondras": ("fondre",),
    "fondrez": ("fondre",),
    "fondriez": ("fondre",),
    "fondrions": ("fondre",),
    "fondrons": ("fondre",),
    "fondront": ("fondre",),
    "fonds": ("fondre",),
    "fondue": ("fondre",),
    "fondues": ("fondre",),
    "fondu": ("fondre",),
    "fondus": ("fondre",),
    "forbannie": ("forbannir",),
    "forbannies": ("forbannir",),
    "forbanni": ("forbannir",),
    "forbannîmes": ("forbannir",),
    "forbannira": ("forbannir",),
    "forbanniraient": ("forbannir",),
    "forbannirai": ("forbannir",),
    "forbannirais": ("forbannir",),
    "forbannirait": ("forbannir",),
    "forbanniras": ("forbannir",),
    "forbannirent": ("forbannir",),
    "forbannirez": ("forbannir",),
    "forbanniriez": ("forbannir",),
    "forbannirions": ("forbannir",),
    "forbannirons": ("forbannir",),
    "forbanniront": ("forbannir",),
    "forbannis": ("forbannir",),
    "forbannissaient": ("forbannir",),
    "forbannissais": ("forbannir",),
    "forbannissait": ("forbannir",),
    "forbannissant": ("forbannir",),
    "forbannissent": ("forbannir",),
    "forbannisse": ("forbannir",),
    "forbannisses": ("forbannir",),
    "forbannissez": ("forbannir",),
    "forbannissiez": ("forbannir",),
    "forbannissions": ("forbannir",),
    "forbannissons": ("forbannir",),
    "forbannîtes": ("forbannir",),
    "forbannit": ("forbannir",),
    "forbannît": ("forbannir",),
    "forcenaient": ("forcener",),
    "forcenai": ("forcener",),
    "forcenais": ("forcener",),
    "forcenait": ("forcener",),
    "forcena": ("forcener",),
    "forcenâmes": ("forcener",),
    "forcenant": ("forcener",),
    "forcenas": ("forcener",),
    "forcenassent": ("forcener",),
    "forcenasses": ("forcener",),
    "forcenasse": ("forcener",),
    "forcenassiez": ("forcener",),
    "forcenassions": ("forcener",),
    "forcenâtes": ("forcener",),
    "forcenât": ("forcener",),
    "forcenée": ("forcener",),
    "forcenées": ("forcener",),
    "forcené": ("forcener",),
    "forcènent": ("forcener",),
    "forcène": ("forcener",),
    "forcènera": ("forcener",),
    "forcèneraient": ("forcener",),
    "forcènerai": ("forcener",),
    "forcènerais": ("forcener",),
    "forcènerait": ("forcener",),
    "forcèneras": ("forcener",),
    "forcenèrent": ("forcener",),
    "forcènerez": ("forcener",),
    "forcèneriez": ("forcener",),
    "forcènerions": ("forcener",),
    "forcènerons": ("forcener",),
    "forcèneront": ("forcener",),
    "forcenés": ("forcener",),
    "forcènes": ("forcener",),
    "forcenez": ("forcener",),
    "forceniez": ("forcener",),
    "forcenions": ("forcener",),
    "forcenons": ("forcener",),
    "forçaient": ("forcer",),
    "forçai": ("forcer",),
    "forçais": ("forcer",),
    "forçait": ("forcer",),
    "força": ("forcer",),
    "forçâmes": ("forcer",),
    "forçant": ("forcer",),
    "forças": ("forcer",),
    "forçassent": ("forcer",),
    "forçasses": ("forcer",),
    "forçasse": ("forcer",),
    "forçassiez": ("forcer",),
    "forçassions": ("forcer",),
    "forçâtes": ("forcer",),
    "forçât": ("forcer",),
    "forcée": ("forcer",),
    "forcées": ("forcer",),
    "forcé": ("forcer",),
    "forcent": ("forcer",),
    "force": ("forcer",),
    "forcera": ("forcer",),
    "forceraient": ("forcer",),
    "forcerai": ("forcer",),
    "forcerais": ("forcer",),
    "forcerait": ("forcer",),
    "forceras": ("forcer",),
    "forcèrent": ("forcer",),
    "forcerez": ("forcer",),
    "forceriez": ("forcer",),
    "forcerions": ("forcer",),
    "forcerons": ("forcer",),
    "forceront": ("forcer",),
    "forcés": ("forcer",),
    "forces": ("forcer",),
    "forcez": ("forcer",),
    "forciez": ("forcer",),
    "forcions": ("forcer",),
    "forçons": ("forcer",),
    "forcie": ("forcir",),
    "forcies": ("forcir",),
    "forci": ("forcir",),
    "forcîmes": ("forcir",),
    "forcira": ("forcir",),
    "forciraient": ("forcir",),
    "forcirai": ("forcir",),
    "forcirais": ("forcir",),
    "forcirait": ("forcir",),
    "forciras": ("forcir",),
    "forcirent": ("forcir",),
    "forcirez": ("forcir",),
    "forciriez": ("forcir",),
    "forcirions": ("forcir",),
    "forcirons": ("forcir",),
    "forciront": ("forcir",),
    "forcis": ("forcir",),
    "forcissaient": ("forcir",),
    "forcissais": ("forcir",),
    "forcissait": ("forcir",),
    "forcissant": ("forcir",),
    "forcissent": ("forcir",),
    "forcisse": ("forcir",),
    "forcisses": ("forcir",),
    "forcissez": ("forcir",),
    "forcissiez": ("forcir",),
    "forcissions": ("forcir",),
    "forcissons": ("forcir",),
    "forcîtes": ("forcir",),
    "forcit": ("forcir",),
    "forcît": ("forcir",),
    "forclose": ("forclore",),
    "forcloses": ("forclore",),
    "forclos": ("forclore",),
    "forfais": ("forfaire",),
    "forfaite": ("forfaire",),
    "forfaites": ("forfaire",),
    "forfait": ("forfaire",),
    "forfaits": ("forfaire",),
    "forgeaient": ("forger",),
    "forgeai": ("forger",),
    "forgeais": ("forger",),
    "forgeait": ("forger",),
    "forgea": ("forger",),
    "forgeâmes": ("forger",),
    "forgeant": ("forger",),
    "forgeas": ("forger",),
    "forgeassent": ("forger",),
    "forgeasses": ("forger",),
    "forgeasse": ("forger",),
    "forgeassiez": ("forger",),
    "forgeassions": ("forger",),
    "forgeâtes": ("forger",),
    "forgeât": ("forger",),
    "forgée": ("forger",),
    "forgées": ("forger",),
    "forgé": ("forger",),
    "forgent": ("forger",),
    "forgeons": ("forger",),
    "forge": ("forger",),
    "forgera": ("forger",),
    "forgeraient": ("forger",),
    "forgerai": ("forger",),
    "forgerais": ("forger",),
    "forgerait": ("forger",),
    "forgeras": ("forger",),
    "forgèrent": ("forger",),
    "forgerez": ("forger",),
    "forgeriez": ("forger",),
    "forgerions": ("forger",),
    "forgerons": ("forger",),
    "forgeront": ("forger",),
    "forgés": ("forger",),
    "forges": ("forger",),
    "forgez": ("forger",),
    "forgiez": ("forger",),
    "forgions": ("forger",),
    "forjetaient": ("forjeter",),
    "forjetai": ("forjeter",),
    "forjetais": ("forjeter",),
    "forjetait": ("forjeter",),
    "forjeta": ("forjeter",),
    "forjetâmes": ("forjeter",),
    "forjetant": ("forjeter",),
    "forjetas": ("forjeter",),
    "forjetassent": ("forjeter",),
    "forjetasses": ("forjeter",),
    "forjetasse": ("forjeter",),
    "forjetassiez": ("forjeter",),
    "forjetassions": ("forjeter",),
    "forjetâtes": ("forjeter",),
    "forjetât": ("forjeter",),
    "forjetée": ("forjeter",),
    "forjetées": ("forjeter",),
    "forjeté": ("forjeter",),
    "forjetèrent": ("forjeter",),
    "forjetés": ("forjeter",),
    "forjetez": ("forjeter",),
    "forjetiez": ("forjeter",),
    "forjetions": ("forjeter",),
    "forjetons": ("forjeter",),
    "forjettent": ("forjeter",),
    "forjette": ("forjeter",),
    "forjettera": ("forjeter",),
    "forjetteraient": ("forjeter",),
    "forjetterai": ("forjeter",),
    "forjetterais": ("forjeter",),
    "forjetterait": ("forjeter",),
    "forjetteras": ("forjeter",),
    "forjetterez": ("forjeter",),
    "forjetteriez": ("forjeter",),
    "forjetterions": ("forjeter",),
    "forjetterons": ("forjeter",),
    "forjetteront": ("forjeter",),
    "forjettes": ("forjeter",),
    "forlançaient": ("forlancer",),
    "forlançai": ("forlancer",),
    "forlançais": ("forlancer",),
    "forlançait": ("forlancer",),
    "forlança": ("forlancer",),
    "forlançâmes": ("forlancer",),
    "forlançant": ("forlancer",),
    "forlanças": ("forlancer",),
    "forlançassent": ("forlancer",),
    "forlançasses": ("forlancer",),
    "forlançasse": ("forlancer",),
    "forlançassiez": ("forlancer",),
    "forlançassions": ("forlancer",),
    "forlançâtes": ("forlancer",),
    "forlançât": ("forlancer",),
    "forlancée": ("forlancer",),
    "forlancées": ("forlancer",),
    "forlancé": ("forlancer",),
    "forlancent": ("forlancer",),
    "forlance": ("forlancer",),
    "forlancera": ("forlancer",),
    "forlanceraient": ("forlancer",),
    "forlancerai": ("forlancer",),
    "forlancerais": ("forlancer",),
    "forlancerait": ("forlancer",),
    "forlanceras": ("forlancer",),
    "forlancèrent": ("forlancer",),
    "forlancerez": ("forlancer",),
    "forlanceriez": ("forlancer",),
    "forlancerions": ("forlancer",),
    "forlancerons": ("forlancer",),
    "forlanceront": ("forlancer",),
    "forlancés": ("forlancer",),
    "forlances": ("forlancer",),
    "forlancez": ("forlancer",),
    "forlanciez": ("forlancer",),
    "forlancions": ("forlancer",),
    "forlançons": ("forlancer",),
    "forlongeaient": ("forlonger",),
    "forlongeai": ("forlonger",),
    "forlongeais": ("forlonger",),
    "forlongeait": ("forlonger",),
    "forlongea": ("forlonger",),
    "forlongeâmes": ("forlonger",),
    "forlongeant": ("forlonger",),
    "forlongeas": ("forlonger",),
    "forlongeassent": ("forlonger",),
    "forlongeasses": ("forlonger",),
    "forlongeasse": ("forlonger",),
    "forlongeassiez": ("forlonger",),
    "forlongeassions": ("forlonger",),
    "forlongeâtes": ("forlonger",),
    "forlongeât": ("forlonger",),
    "forlongée": ("forlonger",),
    "forlongées": ("forlonger",),
    "forlongé": ("forlonger",),
    "forlongent": ("forlonger",),
    "forlongeons": ("forlonger",),
    "forlonge": ("forlonger",),
    "forlongera": ("forlonger",),
    "forlongeraient": ("forlonger",),
    "forlongerai": ("forlonger",),
    "forlongerais": ("forlonger",),
    "forlongerait": ("forlonger",),
    "forlongeras": ("forlonger",),
    "forlongèrent": ("forlonger",),
    "forlongerez": ("forlonger",),
    "forlongeriez": ("forlonger",),
    "forlongerions": ("forlonger",),
    "forlongerons": ("forlonger",),
    "forlongeront": ("forlonger",),
    "forlongés": ("forlonger",),
    "forlonges": ("forlonger",),
    "forlongez": ("forlonger",),
    "forlongiez": ("forlonger",),
    "forlongions": ("forlonger",),
    "fortifiaient": ("fortifier",),
    "fortifiai": ("fortifier",),
    "fortifiais": ("fortifier",),
    "fortifiait": ("fortifier",),
    "fortifia": ("fortifier",),
    "fortifiâmes": ("fortifier",),
    "fortifiant": ("fortifier",),
    "fortifias": ("fortifier",),
    "fortifiassent": ("fortifier",),
    "fortifiasses": ("fortifier",),
    "fortifiasse": ("fortifier",),
    "fortifiassiez": ("fortifier",),
    "fortifiassions": ("fortifier",),
    "fortifiâtes": ("fortifier",),
    "fortifiât": ("fortifier",),
    "fortifiée": ("fortifier",),
    "fortifiées": ("fortifier",),
    "fortifié": ("fortifier",),
    "fortifient": ("fortifier",),
    "fortifie": ("fortifier",),
    "fortifiera": ("fortifier",),
    "fortifieraient": ("fortifier",),
    "fortifierai": ("fortifier",),
    "fortifierais": ("fortifier",),
    "fortifierait": ("fortifier",),
    "fortifieras": ("fortifier",),
    "fortifièrent": ("fortifier",),
    "fortifierez": ("fortifier",),
    "fortifieriez": ("fortifier",),
    "fortifierions": ("fortifier",),
    "fortifierons": ("fortifier",),
    "fortifieront": ("fortifier",),
    "fortifiés": ("fortifier",),
    "fortifies": ("fortifier",),
    "fortifiez": ("fortifier",),
    "fortifiiez": ("fortifier",),
    "fortifiions": ("fortifier",),
    "fortifions": ("fortifier",),
    "fosseraient": ("fosserer",),
    "fosserai": ("fosserer",),
    "fosserais": ("fosserer",),
    "fosserait": ("fosserer",),
    "fossera": ("fosserer",),
    "fosserâmes": ("fosserer",),
    "fosserant": ("fosserer",),
    "fosseras": ("fosserer",),
    "fosserassent": ("fosserer",),
    "fosserasses": ("fosserer",),
    "fosserasse": ("fosserer",),
    "fosserassiez": ("fosserer",),
    "fosserassions": ("fosserer",),
    "fosserâtes": ("fosserer",),
    "fosserât": ("fosserer",),
    "fosserée": ("fosserer",),
    "fosserées": ("fosserer",),
    "fosseré": ("fosserer",),
    "fossèrent": ("fosserer",),
    "fossère": ("fosserer",),
    "fossèrera": ("fosserer",),
    "fossèreraient": ("fosserer",),
    "fossèrerai": ("fosserer",),
    "fossèrerais": ("fosserer",),
    "fossèrerait": ("fosserer",),
    "fossèreras": ("fosserer",),
    "fosserèrent": ("fosserer",),
    "fossèrerez": ("fosserer",),
    "fossèreriez": ("fosserer",),
    "fossèrerions": ("fosserer",),
    "fossèrerons": ("fosserer",),
    "fossèreront": ("fosserer",),
    "fosserés": ("fosserer",),
    "fossères": ("fosserer",),
    "fosserez": ("fosserer",),
    "fosseriez": ("fosserer",),
    "fosserions": ("fosserer",),
    "fosserons": ("fosserer",),
    "fossoient": ("fossoyer",),
    "fossoie": ("fossoyer",),
    "fossoiera": ("fossoyer",),
    "fossoieraient": ("fossoyer",),
    "fossoierai": ("fossoyer",),
    "fossoierais": ("fossoyer",),
    "fossoierait": ("fossoyer",),
    "fossoieras": ("fossoyer",),
    "fossoierez": ("fossoyer",),
    "fossoieriez": ("fossoyer",),
    "fossoierions": ("fossoyer",),
    "fossoierons": ("fossoyer",),
    "fossoieront": ("fossoyer",),
    "fossoies": ("fossoyer",),
    "fossoyaient": ("fossoyer",),
    "fossoyai": ("fossoyer",),
    "fossoyais": ("fossoyer",),
    "fossoyait": ("fossoyer",),
    "fossoya": ("fossoyer",),
    "fossoyâmes": ("fossoyer",),
    "fossoyant": ("fossoyer",),
    "fossoyas": ("fossoyer",),
    "fossoyassent": ("fossoyer",),
    "fossoyasses": ("fossoyer",),
    "fossoyasse": ("fossoyer",),
    "fossoyassiez": ("fossoyer",),
    "fossoyassions": ("fossoyer",),
    "fossoyâtes": ("fossoyer",),
    "fossoyât": ("fossoyer",),
    "fossoyée": ("fossoyer",),
    "fossoyées": ("fossoyer",),
    "fossoyé": ("fossoyer",),
    "fossoyèrent": ("fossoyer",),
    "fossoyés": ("fossoyer",),
    "fossoyez": ("fossoyer",),
    "fossoyiez": ("fossoyer",),
    "fossoyions": ("fossoyer",),
    "fossoyons": ("fossoyer",),
    "foudroient": ("foudroyer",),
    "foudroie": ("foudroyer",),
    "foudroiera": ("foudroyer",),
    "foudroieraient": ("foudroyer",),
    "foudroierai": ("foudroyer",),
    "foudroierais": ("foudroyer",),
    "foudroierait": ("foudroyer",),
    "foudroieras": ("foudroyer",),
    "foudroierez": ("foudroyer",),
    "foudroieriez": ("foudroyer",),
    "foudroierions": ("foudroyer",),
    "foudroierons": ("foudroyer",),
    "foudroieront": ("foudroyer",),
    "foudroies": ("foudroyer",),
    "foudroyaient": ("foudroyer",),
    "foudroyai": ("foudroyer",),
    "foudroyais": ("foudroyer",),
    "foudroyait": ("foudroyer",),
    "foudroya": ("foudroyer",),
    "foudroyâmes": ("foudroyer",),
    "foudroyant": ("foudroyer",),
    "foudroyas": ("foudroyer",),
    "foudroyassent": ("foudroyer",),
    "foudroyasses": ("foudroyer",),
    "foudroyasse": ("foudroyer",),
    "foudroyassiez": ("foudroyer",),
    "foudroyassions": ("foudroyer",),
    "foudroyâtes": ("foudroyer",),
    "foudroyât": ("foudroyer",),
    "foudroyée": ("foudroyer",),
    "foudroyées": ("foudroyer",),
    "foudroyé": ("foudroyer",),
    "foudroyèrent": ("foudroyer",),
    "foudroyés": ("foudroyer",),
    "foudroyez": ("foudroyer",),
    "foudroyiez": ("foudroyer",),
    "foudroyions": ("foudroyer",),
    "foudroyons": ("foudroyer",),
    "fougeaient": ("fouger",),
    "fougeai": ("fouger",),
    "fougeais": ("fouger",),
    "fougeait": ("fouger",),
    "fougea": ("fouger",),
    "fougeâmes": ("fouger",),
    "fougeant": ("fouger",),
    "fougeas": ("fouger",),
    "fougeassent": ("fouger",),
    "fougeasses": ("fouger",),
    "fougeasse": ("fouger",),
    "fougeassiez": ("fouger",),
    "fougeassions": ("fouger",),
    "fougeâtes": ("fouger",),
    "fougeât": ("fouger",),
    "fougée": ("fouger",),
    "fougées": ("fouger",),
    "fougé": ("fouger",),
    "fougent": ("fouger",),
    "fougeons": ("fouger",),
    "fouge": ("fouger",),
    "fougera": ("fouger",),
    "fougeraient": ("fouger",),
    "fougerai": ("fouger",),
    "fougerais": ("fouger",),
    "fougerait": ("fouger",),
    "fougeras": ("fouger",),
    "fougèrent": ("fouger",),
    "fougerez": ("fouger",),
    "fougeriez": ("fouger",),
    "fougerions": ("fouger",),
    "fougerons": ("fouger",),
    "fougeront": ("fouger",),
    "fougés": ("fouger",),
    "fouges": ("fouger",),
    "fougez": ("fouger",),
    "fougiez": ("fouger",),
    "fougions": ("fouger",),
    "fouie": ("fouir",),
    "fouies": ("fouir",),
    "foui": ("fouir",),
    "fouîmes": ("fouir",),
    "fouira": ("fouir",),
    "fouiraient": ("fouir",),
    "fouirai": ("fouir",),
    "fouirais": ("fouir",),
    "fouirait": ("fouir",),
    "fouiras": ("fouir",),
    "fouirent": ("fouir",),
    "fouirez": ("fouir",),
    "fouiriez": ("fouir",),
    "fouirions": ("fouir",),
    "fouirons": ("fouir",),
    "fouiront": ("fouir",),
    "fouis": ("fouir",),
    "fouissaient": ("fouir",),
    "fouissais": ("fouir",),
    "fouissait": ("fouir",),
    "fouissant": ("fouir",),
    "fouissent": ("fouir",),
    "fouisse": ("fouir",),
    "fouisses": ("fouir",),
    "fouissez": ("fouir",),
    "fouissiez": ("fouir",),
    "fouissions": ("fouir",),
    "fouissons": ("fouir",),
    "fouîtes": ("fouir",),
    "fouit": ("fouir",),
    "fouît": ("fouir",),
    "fourbie": ("fourbir",),
    "fourbies": ("fourbir",),
    "fourbi": ("fourbir",),
    "fourbîmes": ("fourbir",),
    "fourbira": ("fourbir",),
    "fourbiraient": ("fourbir",),
    "fourbirai": ("fourbir",),
    "fourbirais": ("fourbir",),
    "fourbirait": ("fourbir",),
    "fourbiras": ("fourbir",),
    "fourbirent": ("fourbir",),
    "fourbirez": ("fourbir",),
    "fourbiriez": ("fourbir",),
    "fourbirions": ("fourbir",),
    "fourbirons": ("fourbir",),
    "fourbiront": ("fourbir",),
    "fourbis": ("fourbir",),
    "fourbissaient": ("fourbir",),
    "fourbissais": ("fourbir",),
    "fourbissait": ("fourbir",),
    "fourbissant": ("fourbir",),
    "fourbissent": ("fourbir",),
    "fourbisse": ("fourbir",),
    "fourbisses": ("fourbir",),
    "fourbissez": ("fourbir",),
    "fourbissiez": ("fourbir",),
    "fourbissions": ("fourbir",),
    "fourbissons": ("fourbir",),
    "fourbîtes": ("fourbir",),
    "fourbit": ("fourbir",),
    "fourbît": ("fourbir",),
    "fournelaient": ("fourneler",),
    "fournelai": ("fourneler",),
    "fournelais": ("fourneler",),
    "fournelait": ("fourneler",),
    "fournela": ("fourneler",),
    "fournelâmes": ("fourneler",),
    "fournelant": ("fourneler",),
    "fournelas": ("fourneler",),
    "fournelassent": ("fourneler",),
    "fournelasses": ("fourneler",),
    "fournelasse": ("fourneler",),
    "fournelassiez": ("fourneler",),
    "fournelassions": ("fourneler",),
    "fournelâtes": ("fourneler",),
    "fournelât": ("fourneler",),
    "fournelée": ("fourneler",),
    "fournelées": ("fourneler",),
    "fournelé": ("fourneler",),
    "fournelèrent": ("fourneler",),
    "fournelés": ("fourneler",),
    "fournelez": ("fourneler",),
    "fourneliez": ("fourneler",),
    "fournelions": ("fourneler",),
    "fournellent": ("fourneler",),
    "fournelle": ("fourneler",),
    "fournellera": ("fourneler",),
    "fournelleraient": ("fourneler",),
    "fournellerai": ("fourneler",),
    "fournellerais": ("fourneler",),
    "fournellerait": ("fourneler",),
    "fournelleras": ("fourneler",),
    "fournellerez": ("fourneler",),
    "fournelleriez": ("fourneler",),
    "fournellerions": ("fourneler",),
    "fournellerons": ("fourneler",),
    "fournelleront": ("fourneler",),
    "fournelles": ("fourneler",),
    "fournelons": ("fourneler",),
    "fournie": ("fournir",),
    "fournies": ("fournir",),
    "fourni": ("fournir",),
    "fournîmes": ("fournir",),
    "fournira": ("fournir",),
    "fourniraient": ("fournir",),
    "fournirai": ("fournir",),
    "fournirais": ("fournir",),
    "fournirait": ("fournir",),
    "fourniras": ("fournir",),
    "fournirent": ("fournir",),
    "fournirez": ("fournir",),
    "fourniriez": ("fournir",),
    "fournirions": ("fournir",),
    "fournirons": ("fournir",),
    "fourniront": ("fournir",),
    "fournis": ("fournir",),
    "fournissaient": ("fournir",),
    "fournissais": ("fournir",),
    "fournissait": ("fournir",),
    "fournissant": ("fournir",),
    "fournissent": ("fournir",),
    "fournisse": ("fournir",),
    "fournisses": ("fournir",),
    "fournissez": ("fournir",),
    "fournissiez": ("fournir",),
    "fournissions": ("fournir",),
    "fournissons": ("fournir",),
    "fournîtes": ("fournir",),
    "fournit": ("fournir",),
    "fournît": ("fournir",),
    "fourrageaient": ("fourrager",),
    "fourrageai": ("fourrager",),
    "fourrageais": ("fourrager",),
    "fourrageait": ("fourrager",),
    "fourragea": ("fourrager",),
    "fourrageâmes": ("fourrager",),
    "fourrageant": ("fourrager",),
    "fourrageas": ("fourrager",),
    "fourrageassent": ("fourrager",),
    "fourrageasses": ("fourrager",),
    "fourrageasse": ("fourrager",),
    "fourrageassiez": ("fourrager",),
    "fourrageassions": ("fourrager",),
    "fourrageâtes": ("fourrager",),
    "fourrageât": ("fourrager",),
    "fourragée": ("fourrager",),
    "fourragées": ("fourrager",),
    "fourragé": ("fourrager",),
    "fourragent": ("fourrager",),
    "fourrageons": ("fourrager",),
    "fourrage": ("fourrager",),
    "fourragera": ("fourrager",),
    "fourrageraient": ("fourrager",),
    "fourragerai": ("fourrager",),
    "fourragerais": ("fourrager",),
    "fourragerait": ("fourrager",),
    "fourrageras": ("fourrager",),
    "fourragèrent": ("fourrager",),
    "fourragerez": ("fourrager",),
    "fourrageriez": ("fourrager",),
    "fourragerions": ("fourrager",),
    "fourragerons": ("fourrager",),
    "fourrageront": ("fourrager",),
    "fourragés": ("fourrager",),
    "fourrages": ("fourrager",),
    "fourragez": ("fourrager",),
    "fourragiez": ("fourrager",),
    "fourragions": ("fourrager",),
    "fourvoient": ("fourvoyer",),
    "fourvoie": ("fourvoyer",),
    "fourvoiera": ("fourvoyer",),
    "fourvoieraient": ("fourvoyer",),
    "fourvoierai": ("fourvoyer",),
    "fourvoierais": ("fourvoyer",),
    "fourvoierait": ("fourvoyer",),
    "fourvoieras": ("fourvoyer",),
    "fourvoierez": ("fourvoyer",),
    "fourvoieriez": ("fourvoyer",),
    "fourvoierions": ("fourvoyer",),
    "fourvoierons": ("fourvoyer",),
    "fourvoieront": ("fourvoyer",),
    "fourvoies": ("fourvoyer",),
    "fourvoyaient": ("fourvoyer",),
    "fourvoyai": ("fourvoyer",),
    "fourvoyais": ("fourvoyer",),
    "fourvoyait": ("fourvoyer",),
    "fourvoya": ("fourvoyer",),
    "fourvoyâmes": ("fourvoyer",),
    "fourvoyant": ("fourvoyer",),
    "fourvoyas": ("fourvoyer",),
    "fourvoyassent": ("fourvoyer",),
    "fourvoyasses": ("fourvoyer",),
    "fourvoyasse": ("fourvoyer",),
    "fourvoyassiez": ("fourvoyer",),
    "fourvoyassions": ("fourvoyer",),
    "fourvoyâtes": ("fourvoyer",),
    "fourvoyât": ("fourvoyer",),
    "fourvoyée": ("fourvoyer",),
    "fourvoyées": ("fourvoyer",),
    "fourvoyé": ("fourvoyer",),
    "fourvoyèrent": ("fourvoyer",),
    "fourvoyés": ("fourvoyer",),
    "fourvoyez": ("fourvoyer",),
    "fourvoyiez": ("fourvoyer",),
    "fourvoyions": ("fourvoyer",),
    "fourvoyons": ("fourvoyer",),
    "fous": ("foutre",),
    "foutaient": ("foutre",),
    "foutais": ("foutre",),
    "foutait": ("foutre",),
    "foutant": ("foutre",),
    "foutent": ("foutre",),
    "foute": ("foutre",),
    "foutes": ("foutre",),
    "foutez": ("foutre",),
    "foutiez": ("foutre",),
    "foutions": ("foutre",),
    "foutissent": ("foutre",),
    "foutisses": ("foutre",),
    "foutisse": ("foutre",),
    "foutissiez": ("foutre",),
    "foutissions": ("foutre",),
    "foutît": ("foutre",),
    "foutons": ("foutre",),
    "fout": ("foutre",),
    "foutra": ("foutre",),
    "foutraient": ("foutre",),
    "foutrai": ("foutre",),
    "foutrais": ("foutre",),
    "foutrait": ("foutre",),
    "foutras": ("foutre",),
    "foutrez": ("foutre",),
    "foutriez": ("foutre",),
    "foutrions": ("foutre",),
    "foutrons": ("foutre",),
    "foutront": ("foutre",),
    "foutue": ("foutre",),
    "foutues": ("foutre",),
    "foutu": ("foutre",),
    "foutus": ("foutre",),
    "fracassaient": ("fracasser",),
    "fracassai": ("fracasser",),
    "fracassais": ("fracasser",),
    "fracassait": ("fracasser",),
    "fracassa": ("fracasser",),
    "fracassâmes": ("fracasser",),
    "fracassant": ("fracasser",),
    "fracassas": ("fracasser",),
    "fracassassent": ("fracasser",),
    "fracassasses": ("fracasser",),
    "fracassasse": ("fracasser",),
    "fracassassiez": ("fracasser",),
    "fracassassions": ("fracasser",),
    "fracassâtes": ("fracasser",),
    "fracassât": ("fracasser",),
    "fracassée": ("fracasser",),
    "fracassées": ("fracasser",),
    "fracassé": ("fracasser",),
    "fracassent": ("fracasser",),
    "fracasse": ("fracasser",),
    "fracassera": ("fracasser",),
    "fracasseraient": ("fracasser",),
    "fracasserai": ("fracasser",),
    "fracasserais": ("fracasser",),
    "fracasserait": ("fracasser",),
    "fracasseras": ("fracasser",),
    "fracassèrent": ("fracasser",),
    "fracasserez": ("fracasser",),
    "fracasseriez": ("fracasser",),
    "fracasserions": ("fracasser",),
    "fracasserons": ("fracasser",),
    "fracasseront": ("fracasser",),
    "fracassés": ("fracasser",),
    "fracasses": ("fracasser",),
    "fracassez": ("fracasser",),
    "fracassiez": ("fracasser",),
    "fracassions": ("fracasser",),
    "fracassons": ("fracasser",),
    "fraîchie": ("fraîchir",),
    "fraîchies": ("fraîchir",),
    "fraîchi": ("fraîchir",),
    "fraîchîmes": ("fraîchir",),
    "fraîchira": ("fraîchir",),
    "fraîchiraient": ("fraîchir",),
    "fraîchirai": ("fraîchir",),
    "fraîchirais": ("fraîchir",),
    "fraîchirait": ("fraîchir",),
    "fraîchiras": ("fraîchir",),
    "fraîchirent": ("fraîchir",),
    "fraîchirez": ("fraîchir",),
    "fraîchiriez": ("fraîchir",),
    "fraîchirions": ("fraîchir",),
    "fraîchirons": ("fraîchir",),
    "fraîchiront": ("fraîchir",),
    "fraîchis": ("fraîchir",),
    "fraîchissaient": ("fraîchir",),
    "fraîchissais": ("fraîchir",),
    "fraîchissait": ("fraîchir",),
    "fraîchissant": ("fraîchir",),
    "fraîchissent": ("fraîchir",),
    "fraîchisse": ("fraîchir",),
    "fraîchisses": ("fraîchir",),
    "fraîchissez": ("fraîchir",),
    "fraîchissiez": ("fraîchir",),
    "fraîchissions": ("fraîchir",),
    "fraîchissons": ("fraîchir",),
    "fraîchîtes": ("fraîchir",),
    "fraîchit": ("fraîchir",),
    "fraîchît": ("fraîchir",),
    "franchie": ("franchir",),
    "franchies": ("franchir",),
    "franchi": ("franchir",),
    "franchîmes": ("franchir",),
    "franchira": ("franchir",),
    "franchiraient": ("franchir",),
    "franchirai": ("franchir",),
    "franchirais": ("franchir",),
    "franchirait": ("franchir",),
    "franchiras": ("franchir",),
    "franchirent": ("franchir",),
    "franchirez": ("franchir",),
    "franchiriez": ("franchir",),
    "franchirions": ("franchir",),
    "franchirons": ("franchir",),
    "franchiront": ("franchir",),
    "franchis": ("franchir",),
    "franchissaient": ("franchir",),
    "franchissais": ("franchir",),
    "franchissait": ("franchir",),
    "franchissant": ("franchir",),
    "franchissent": ("franchir",),
    "franchisse": ("franchir",),
    "franchisses": ("franchir",),
    "franchissez": ("franchir",),
    "franchissiez": ("franchir",),
    "franchissions": ("franchir",),
    "franchissons": ("franchir",),
    "franchîtes": ("franchir",),
    "franchit": ("franchir",),
    "franchît": ("franchir",),
    "frangeaient": ("franger",),
    "frangeai": ("franger",),
    "frangeais": ("franger",),
    "frangeait": ("franger",),
    "frangea": ("franger",),
    "frangeâmes": ("franger",),
    "frangeant": ("franger",),
    "frangeas": ("franger",),
    "frangeassent": ("franger",),
    "frangeasses": ("franger",),
    "frangeasse": ("franger",),
    "frangeassiez": ("franger",),
    "frangeassions": ("franger",),
    "frangeâtes": ("franger",),
    "frangeât": ("franger",),
    "frangée": ("franger",),
    "frangées": ("franger",),
    "frangé": ("franger",),
    "frangent": ("franger",),
    "frangeons": ("franger",),
    "frange": ("franger",),
    "frangera": ("franger",),
    "frangeraient": ("franger",),
    "frangerai": ("franger",),
    "frangerais": ("franger",),
    "frangerait": ("franger",),
    "frangeras": ("franger",),
    "frangèrent": ("franger",),
    "frangerez": ("franger",),
    "frangeriez": ("franger",),
    "frangerions": ("franger",),
    "frangerons": ("franger",),
    "frangeront": ("franger",),
    "frangés": ("franger",),
    "franges": ("franger",),
    "frangez": ("franger",),
    "frangiez": ("franger",),
    "frangions": ("franger",),
    "fraient": ("frayer",),
    "fraie": ("frayer",),
    "fraiera": ("frayer",),
    "fraieraient": ("frayer",),
    "fraierai": ("frayer",),
    "fraierais": ("frayer",),
    "fraierait": ("frayer",),
    "fraieras": ("frayer",),
    "fraierez": ("frayer",),
    "fraieriez": ("frayer",),
    "fraierions": ("frayer",),
    "fraierons": ("frayer",),
    "fraieront": ("frayer",),
    "fraies": ("frayer",),
    "frayaient": ("frayer",),
    "frayai": ("frayer",),
    "frayais": ("frayer",),
    "frayait": ("frayer",),
    "fraya": ("frayer",),
    "frayâmes": ("frayer",),
    "frayant": ("frayer",),
    "frayas": ("frayer",),
    "frayassent": ("frayer",),
    "frayasses": ("frayer",),
    "frayasse": ("frayer",),
    "frayassiez": ("frayer",),
    "frayassions": ("frayer",),
    "frayâtes": ("frayer",),
    "frayât": ("frayer",),
    "frayée": ("frayer",),
    "frayées": ("frayer",),
    "frayé": ("frayer",),
    "frayent": ("frayer",),
    "fraye": ("frayer",),
    "frayera": ("frayer",),
    "frayeraient": ("frayer",),
    "frayerai": ("frayer",),
    "frayerais": ("frayer",),
    "frayerait": ("frayer",),
    "frayeras": ("frayer",),
    "frayèrent": ("frayer",),
    "frayerez": ("frayer",),
    "frayeriez": ("frayer",),
    "frayerions": ("frayer",),
    "frayerons": ("frayer",),
    "frayeront": ("frayer",),
    "frayés": ("frayer",),
    "frayes": ("frayer",),
    "frayez": ("frayer",),
    "frayiez": ("frayer",),
    "frayions": ("frayer",),
    "frayons": ("frayer",),
    "frémi": ("frémir",),
    "frémîmes": ("frémir",),
    "frémira": ("frémir",),
    "frémiraient": ("frémir",),
    "frémirai": ("frémir",),
    "frémirais": ("frémir",),
    "frémirait": ("frémir",),
    "frémiras": ("frémir",),
    "frémirent": ("frémir",),
    "frémirez": ("frémir",),
    "frémiriez": ("frémir",),
    "frémirions": ("frémir",),
    "frémirons": ("frémir",),
    "frémiront": ("frémir",),
    "frémis": ("frémir",),
    "frémissaient": ("frémir",),
    "frémissais": ("frémir",),
    "frémissait": ("frémir",),
    "frémissant": ("frémir",),
    "frémissent": ("frémir",),
    "frémisse": ("frémir",),
    "frémisses": ("frémir",),
    "frémissez": ("frémir",),
    "frémissiez": ("frémir",),
    "frémissions": ("frémir",),
    "frémissons": ("frémir",),
    "frémîtes": ("frémir",),
    "frémit": ("frémir",),
    "frémît": ("frémir",),
    "frétaient": ("fréter",),
    "frétai": ("fréter",),
    "frétais": ("fréter",),
    "frétait": ("fréter",),
    "fréta": ("fréter",),
    "frétâmes": ("fréter",),
    "frétant": ("fréter",),
    "frétas": ("fréter",),
    "frétassent": ("fréter",),
    "frétasses": ("fréter",),
    "frétasse": ("fréter",),
    "frétassiez": ("fréter",),
    "frétassions": ("fréter",),
    "frétâtes": ("fréter",),
    "frétât": ("fréter",),
    "frétée": ("fréter",),
    "frétées": ("fréter",),
    "frété": ("fréter",),
    "frètent": ("fréter",),
    "frète": ("fréter",),
    "frétera": ("fréter",),
    "fréteraient": ("fréter",),
    "fréterai": ("fréter",),
    "fréterais": ("fréter",),
    "fréterait": ("fréter",),
    "fréteras": ("fréter",),
    "frétèrent": ("fréter",),
    "fréterez": ("fréter",),
    "fréteriez": ("fréter",),
    "fréterions": ("fréter",),
    "fréterons": ("fréter",),
    "fréteront": ("fréter",),
    "frétés": ("fréter",),
    "frètes": ("fréter",),
    "frétez": ("fréter",),
    "frétiez": ("fréter",),
    "frétions": ("fréter",),
    "frétons": ("fréter",),
    "fricassaient": ("fricasser",),
    "fricassai": ("fricasser",),
    "fricassais": ("fricasser",),
    "fricassait": ("fricasser",),
    "fricassa": ("fricasser",),
    "fricassâmes": ("fricasser",),
    "fricassant": ("fricasser",),
    "fricassas": ("fricasser",),
    "fricassassent": ("fricasser",),
    "fricassasses": ("fricasser",),
    "fricassasse": ("fricasser",),
    "fricassassiez": ("fricasser",),
    "fricassassions": ("fricasser",),
    "fricassâtes": ("fricasser",),
    "fricassât": ("fricasser",),
    "fricassée": ("fricasser",),
    "fricassées": ("fricasser",),
    "fricassé": ("fricasser",),
    "fricassent": ("fricasser",),
    "fricasse": ("fricasser",),
    "fricassera": ("fricasser",),
    "fricasseraient": ("fricasser",),
    "fricasserai": ("fricasser",),
    "fricasserais": ("fricasser",),
    "fricasserait": ("fricasser",),
    "fricasseras": ("fricasser",),
    "fricassèrent": ("fricasser",),
    "fricasserez": ("fricasser",),
    "fricasseriez": ("fricasser",),
    "fricasserions": ("fricasser",),
    "fricasserons": ("fricasser",),
    "fricasseront": ("fricasser",),
    "fricassés": ("fricasser",),
    "fricasses": ("fricasser",),
    "fricassez": ("fricasser",),
    "fricassiez": ("fricasser",),
    "fricassions": ("fricasser",),
    "fricassons": ("fricasser",),
    "frigidifiaient": ("frigidifier",),
    "frigidifiai": ("frigidifier",),
    "frigidifiais": ("frigidifier",),
    "frigidifiait": ("frigidifier",),
    "frigidifia": ("frigidifier",),
    "frigidifiâmes": ("frigidifier",),
    "frigidifiant": ("frigidifier",),
    "frigidifias": ("frigidifier",),
    "frigidifiassent": ("frigidifier",),
    "frigidifiasses": ("frigidifier",),
    "frigidifiasse": ("frigidifier",),
    "frigidifiassiez": ("frigidifier",),
    "frigidifiassions": ("frigidifier",),
    "frigidifiâtes": ("frigidifier",),
    "frigidifiât": ("frigidifier",),
    "frigidifiée": ("frigidifier",),
    "frigidifiées": ("frigidifier",),
    "frigidifié": ("frigidifier",),
    "frigidifient": ("frigidifier",),
    "frigidifie": ("frigidifier",),
    "frigidifiera": ("frigidifier",),
    "frigidifieraient": ("frigidifier",),
    "frigidifierai": ("frigidifier",),
    "frigidifierais": ("frigidifier",),
    "frigidifierait": ("frigidifier",),
    "frigidifieras": ("frigidifier",),
    "frigidifièrent": ("frigidifier",),
    "frigidifierez": ("frigidifier",),
    "frigidifieriez": ("frigidifier",),
    "frigidifierions": ("frigidifier",),
    "frigidifierons": ("frigidifier",),
    "frigidifieront": ("frigidifier",),
    "frigidifiés": ("frigidifier",),
    "frigidifies": ("frigidifier",),
    "frigidifiez": ("frigidifier",),
    "frigidifiiez": ("frigidifier",),
    "frigidifiions": ("frigidifier",),
    "frigidifions": ("frigidifier",),
    "frigorifiaient": ("frigorifier",),
    "frigorifiai": ("frigorifier",),
    "frigorifiais": ("frigorifier",),
    "frigorifiait": ("frigorifier",),
    "frigorifia": ("frigorifier",),
    "frigorifiâmes": ("frigorifier",),
    "frigorifiant": ("frigorifier",),
    "frigorifias": ("frigorifier",),
    "frigorifiassent": ("frigorifier",),
    "frigorifiasses": ("frigorifier",),
    "frigorifiasse": ("frigorifier",),
    "frigorifiassiez": ("frigorifier",),
    "frigorifiassions": ("frigorifier",),
    "frigorifiâtes": ("frigorifier",),
    "frigorifiât": ("frigorifier",),
    "frigorifiée": ("frigorifier",),
    "frigorifiées": ("frigorifier",),
    "frigorifié": ("frigorifier",),
    "frigorifient": ("frigorifier",),
    "frigorifie": ("frigorifier",),
    "frigorifiera": ("frigorifier",),
    "frigorifieraient": ("frigorifier",),
    "frigorifierai": ("frigorifier",),
    "frigorifierais": ("frigorifier",),
    "frigorifierait": ("frigorifier",),
    "frigorifieras": ("frigorifier",),
    "frigorifièrent": ("frigorifier",),
    "frigorifierez": ("frigorifier",),
    "frigorifieriez": ("frigorifier",),
    "frigorifierions": ("frigorifier",),
    "frigorifierons": ("frigorifier",),
    "frigorifieront": ("frigorifier",),
    "frigorifiés": ("frigorifier",),
    "frigorifies": ("frigorifier",),
    "frigorifiez": ("frigorifier",),
    "frigorifiiez": ("frigorifier",),
    "frigorifiions": ("frigorifier",),
    "frigorifions": ("frigorifier",),
    "frigorifugeaient": ("frigorifuger",),
    "frigorifugeai": ("frigorifuger",),
    "frigorifugeais": ("frigorifuger",),
    "frigorifugeait": ("frigorifuger",),
    "frigorifugea": ("frigorifuger",),
    "frigorifugeâmes": ("frigorifuger",),
    "frigorifugeant": ("frigorifuger",),
    "frigorifugeas": ("frigorifuger",),
    "frigorifugeassent": ("frigorifuger",),
    "frigorifugeasses": ("frigorifuger",),
    "frigorifugeasse": ("frigorifuger",),
    "frigorifugeassiez": ("frigorifuger",),
    "frigorifugeassions": ("frigorifuger",),
    "frigorifugeâtes": ("frigorifuger",),
    "frigorifugeât": ("frigorifuger",),
    "frigorifugée": ("frigorifuger",),
    "frigorifugées": ("frigorifuger",),
    "frigorifugé": ("frigorifuger",),
    "frigorifugent": ("frigorifuger",),
    "frigorifugeons": ("frigorifuger",),
    "frigorifuge": ("frigorifuger",),
    "frigorifugera": ("frigorifuger",),
    "frigorifugeraient": ("frigorifuger",),
    "frigorifugerai": ("frigorifuger",),
    "frigorifugerais": ("frigorifuger",),
    "frigorifugerait": ("frigorifuger",),
    "frigorifugeras": ("frigorifuger",),
    "frigorifugèrent": ("frigorifuger",),
    "frigorifugerez": ("frigorifuger",),
    "frigorifugeriez": ("frigorifuger",),
    "frigorifugerions": ("frigorifuger",),
    "frigorifugerons": ("frigorifuger",),
    "frigorifugeront": ("frigorifuger",),
    "frigorifugés": ("frigorifuger",),
    "frigorifuges": ("frigorifuger",),
    "frigorifugez": ("frigorifuger",),
    "frigorifugiez": ("frigorifuger",),
    "frigorifugions": ("frigorifuger",),
    "frimassaient": ("frimasser",),
    "frimassait": ("frimasser",),
    "frimassa": ("frimasser",),
    "frimassant": ("frimasser",),
    "frimassassent": ("frimasser",),
    "frimassât": ("frimasser",),
    "frimassé": ("frimasser",),
    "frimassent": ("frimasser",),
    "frimasse": ("frimasser",),
    "frimassera": ("frimasser",),
    "frimasseraient": ("frimasser",),
    "frimasserait": ("frimasser",),
    "frimassèrent": ("frimasser",),
    "frimasseront": ("frimasser",),
    "frira": ("frire",),
    "friraient": ("frire",),
    "frirai": ("frire",),
    "frirais": ("frire",),
    "frirait": ("frire",),
    "friras": ("frire",),
    "frirez": ("frire",),
    "fririez": ("frire",),
    "fririons": ("frire",),
    "frirons": ("frire",),
    "friront": ("frire",),
    "frisent": ("frire",),
    "fris": ("frire",),
    "frite": ("frire",),
    "frites": ("frire",),
    "frit": ("frire",),
    "frits": ("frire",),
    "friselaient": ("friseler",),
    "friselai": ("friseler",),
    "friselais": ("friseler",),
    "friselait": ("friseler",),
    "frisela": ("friseler",),
    "friselâmes": ("friseler",),
    "friselant": ("friseler",),
    "friselas": ("friseler",),
    "friselassent": ("friseler",),
    "friselasses": ("friseler",),
    "friselasse": ("friseler",),
    "friselassiez": ("friseler",),
    "friselassions": ("friseler",),
    "friselâtes": ("friseler",),
    "friselât": ("friseler",),
    "friselée": ("friseler",),
    "friselées": ("friseler",),
    "friselé": ("friseler",),
    "frisèlent": ("friseler",),
    "frisèle": ("friseler",),
    "frisèlera": ("friseler",),
    "frisèleraient": ("friseler",),
    "frisèlerai": ("friseler",),
    "frisèlerais": ("friseler",),
    "frisèlerait": ("friseler",),
    "frisèleras": ("friseler",),
    "friselèrent": ("friseler",),
    "frisèlerez": ("friseler",),
    "frisèleriez": ("friseler",),
    "frisèlerions": ("friseler",),
    "frisèlerons": ("friseler",),
    "frisèleront": ("friseler",),
    "friselés": ("friseler",),
    "frisèles": ("friseler",),
    "friselez": ("friseler",),
    "friseliez": ("friseler",),
    "friselions": ("friseler",),
    "friselons": ("friseler",),
    "froidi": ("froidir",),
    "froidîmes": ("froidir",),
    "froidira": ("froidir",),
    "froidiraient": ("froidir",),
    "froidirai": ("froidir",),
    "froidirais": ("froidir",),
    "froidirait": ("froidir",),
    "froidiras": ("froidir",),
    "froidirent": ("froidir",),
    "froidirez": ("froidir",),
    "froidiriez": ("froidir",),
    "froidirions": ("froidir",),
    "froidirons": ("froidir",),
    "froidiront": ("froidir",),
    "froidis": ("froidir",),
    "froidissaient": ("froidir",),
    "froidissais": ("froidir",),
    "froidissait": ("froidir",),
    "froidissant": ("froidir",),
    "froidissent": ("froidir",),
    "froidisse": ("froidir",),
    "froidisses": ("froidir",),
    "froidissez": ("froidir",),
    "froidissiez": ("froidir",),
    "froidissions": ("froidir",),
    "froidissons": ("froidir",),
    "froidîtes": ("froidir",),
    "froidit": ("froidir",),
    "froidît": ("froidir",),
    "fromageaient": ("fromager",),
    "fromageai": ("fromager",),
    "fromageais": ("fromager",),
    "fromageait": ("fromager",),
    "fromagea": ("fromager",),
    "fromageâmes": ("fromager",),
    "fromageant": ("fromager",),
    "fromageas": ("fromager",),
    "fromageassent": ("fromager",),
    "fromageasses": ("fromager",),
    "fromageasse": ("fromager",),
    "fromageassiez": ("fromager",),
    "fromageassions": ("fromager",),
    "fromageâtes": ("fromager",),
    "fromageât": ("fromager",),
    "fromagée": ("fromager",),
    "fromagées": ("fromager",),
    "fromagé": ("fromager",),
    "fromagent": ("fromager",),
    "fromageons": ("fromager",),
    "fromage": ("fromager",),
    "fromagera": ("fromager",),
    "fromageraient": ("fromager",),
    "fromagerai": ("fromager",),
    "fromagerais": ("fromager",),
    "fromagerait": ("fromager",),
    "fromageras": ("fromager",),
    "fromagèrent": ("fromager",),
    "fromagerez": ("fromager",),
    "fromageriez": ("fromager",),
    "fromagerions": ("fromager",),
    "fromagerons": ("fromager",),
    "fromageront": ("fromager",),
    "fromagés": ("fromager",),
    "fromages": ("fromager",),
    "fromagez": ("fromager",),
    "fromagiez": ("fromager",),
    "fromagions": ("fromager",),
    "fronçaient": ("froncer",),
    "fronçai": ("froncer",),
    "fronçais": ("froncer",),
    "fronçait": ("froncer",),
    "fronça": ("froncer",),
    "fronçâmes": ("froncer",),
    "fronçant": ("froncer",),
    "fronças": ("froncer",),
    "fronçassent": ("froncer",),
    "fronçasses": ("froncer",),
    "fronçasse": ("froncer",),
    "fronçassiez": ("froncer",),
    "fronçassions": ("froncer",),
    "fronçâtes": ("froncer",),
    "fronçât": ("froncer",),
    "froncée": ("froncer",),
    "froncées": ("froncer",),
    "froncé": ("froncer",),
    "froncent": ("froncer",),
    "fronce": ("froncer",),
    "froncera": ("froncer",),
    "fronceraient": ("froncer",),
    "froncerai": ("froncer",),
    "froncerais": ("froncer",),
    "froncerait": ("froncer",),
    "fronceras": ("froncer",),
    "froncèrent": ("froncer",),
    "froncerez": ("froncer",),
    "fronceriez": ("froncer",),
    "froncerions": ("froncer",),
    "froncerons": ("froncer",),
    "fronceront": ("froncer",),
    "froncés": ("froncer",),
    "fronces": ("froncer",),
    "froncez": ("froncer",),
    "fronciez": ("froncer",),
    "froncions": ("froncer",),
    "fronçons": ("froncer",),
    "fructifiaient": ("fructifier",),
    "fructifiai": ("fructifier",),
    "fructifiais": ("fructifier",),
    "fructifiait": ("fructifier",),
    "fructifia": ("fructifier",),
    "fructifiâmes": ("fructifier",),
    "fructifiant": ("fructifier",),
    "fructifias": ("fructifier",),
    "fructifiassent": ("fructifier",),
    "fructifiasses": ("fructifier",),
    "fructifiasse": ("fructifier",),
    "fructifiassiez": ("fructifier",),
    "fructifiassions": ("fructifier",),
    "fructifiâtes": ("fructifier",),
    "fructifiât": ("fructifier",),
    "fructifié": ("fructifier",),
    "fructifient": ("fructifier",),
    "fructifie": ("fructifier",),
    "fructifiera": ("fructifier",),
    "fructifieraient": ("fructifier",),
    "fructifierai": ("fructifier",),
    "fructifierais": ("fructifier",),
    "fructifierait": ("fructifier",),
    "fructifieras": ("fructifier",),
    "fructifièrent": ("fructifier",),
    "fructifierez": ("fructifier",),
    "fructifieriez": ("fructifier",),
    "fructifierions": ("fructifier",),
    "fructifierons": ("fructifier",),
    "fructifieront": ("fructifier",),
    "fructifies": ("fructifier",),
    "fructifiez": ("fructifier",),
    "fructifiiez": ("fructifier",),
    "fructifiions": ("fructifier",),
    "fructifions": ("fructifier",),
    "fuient": ("fuir",),
    "fuie": ("fuir",),
    "fuies": ("fuir",),
    "fui": ("fuir",),
    "fuîmes": ("fuir",),
    "fuira": ("fuir",),
    "fuiraient": ("fuir",),
    "fuirai": ("fuir",),
    "fuirais": ("fuir",),
    "fuirait": ("fuir",),
    "fuiras": ("fuir",),
    "fuirent": ("fuir",),
    "fuirez": ("fuir",),
    "fuiriez": ("fuir",),
    "fuirions": ("fuir",),
    "fuirons": ("fuir",),
    "fuiront": ("fuir",),
    "fuis": ("fuir",),
    "fuissent": ("fuir",),
    "fuisses": ("fuir",),
    "fuisse": ("fuir",),
    "fuissiez": ("fuir",),
    "fuissions": ("fuir",),
    "fuîtes": ("fuir",),
    "fuit": ("fuir",),
    "fuît": ("fuir",),
    "fuyaient": ("fuir",),
    "fuyais": ("fuir",),
    "fuyait": ("fuir",),
    "fuyant": ("fuir",),
    "fuyez": ("fuir",),
    "fuyiez": ("fuir",),
    "fuyions": ("fuir",),
    "fuyons": ("fuir",),
    "fumassaient": ("fumasser",),
    "fumassai": ("fumasser",),
    "fumassais": ("fumasser",),
    "fumassait": ("fumasser",),
    "fumassa": ("fumasser",),
    "fumassâmes": ("fumasser",),
    "fumassant": ("fumasser",),
    "fumassas": ("fumasser",),
    "fumassassent": ("fumasser",),
    "fumassasses": ("fumasser",),
    "fumassasse": ("fumasser",),
    "fumassassiez": ("fumasser",),
    "fumassassions": ("fumasser",),
    "fumassâtes": ("fumasser",),
    "fumassât": ("fumasser",),
    "fumassée": ("fumasser",),
    "fumassées": ("fumasser",),
    "fumassé": ("fumasser",),
    "fumassent": ("fumasser",),
    "fumasse": ("fumasser",),
    "fumassera": ("fumasser",),
    "fumasseraient": ("fumasser",),
    "fumasserai": ("fumasser",),
    "fumasserais": ("fumasser",),
    "fumasserait": ("fumasser",),
    "fumasseras": ("fumasser",),
    "fumassèrent": ("fumasser",),
    "fumasserez": ("fumasser",),
    "fumasseriez": ("fumasser",),
    "fumasserions": ("fumasser",),
    "fumasserons": ("fumasser",),
    "fumasseront": ("fumasser",),
    "fumassés": ("fumasser",),
    "fumasses": ("fumasser",),
    "fumassez": ("fumasser",),
    "fumassiez": ("fumasser",),
    "fumassions": ("fumasser",),
    "fumassons": ("fumasser",),
    "fumigeaient": ("fumiger",),
    "fumigeai": ("fumiger",),
    "fumigeais": ("fumiger",),
    "fumigeait": ("fumiger",),
    "fumigea": ("fumiger",),
    "fumigeâmes": ("fumiger",),
    "fumigeant": ("fumiger",),
    "fumigeas": ("fumiger",),
    "fumigeassent": ("fumiger",),
    "fumigeasses": ("fumiger",),
    "fumigeasse": ("fumiger",),
    "fumigeassiez": ("fumiger",),
    "fumigeassions": ("fumiger",),
    "fumigeâtes": ("fumiger",),
    "fumigeât": ("fumiger",),
    "fumigée": ("fumiger",),
    "fumigées": ("fumiger",),
    "fumigé": ("fumiger",),
    "fumigent": ("fumiger",),
    "fumigeons": ("fumiger",),
    "fumige": ("fumiger",),
    "fumigera": ("fumiger",),
    "fumigeraient": ("fumiger",),
    "fumigerai": ("fumiger",),
    "fumigerais": ("fumiger",),
    "fumigerait": ("fumiger",),
    "fumigeras": ("fumiger",),
    "fumigèrent": ("fumiger",),
    "fumigerez": ("fumiger",),
    "fumigeriez": ("fumiger",),
    "fumigerions": ("fumiger",),
    "fumigerons": ("fumiger",),
    "fumigeront": ("fumiger",),
    "fumigés": ("fumiger",),
    "fumiges": ("fumiger",),
    "fumigez": ("fumiger",),
    "fumigiez": ("fumiger",),
    "fumigions": ("fumiger",),
    "furetaient": ("fureter",),
    "furetai": ("fureter",),
    "furetais": ("fureter",),
    "furetait": ("fureter",),
    "fureta": ("fureter",),
    "furetâmes": ("fureter",),
    "furetant": ("fureter",),
    "furetas": ("fureter",),
    "furetassent": ("fureter",),
    "furetasses": ("fureter",),
    "furetasse": ("fureter",),
    "furetassiez": ("fureter",),
    "furetassions": ("fureter",),
    "furetâtes": ("fureter",),
    "furetât": ("fureter",),
    "fureté": ("fureter",),
    "furètent": ("fureter",),
    "furète": ("fureter",),
    "furètera": ("fureter",),
    "furèteraient": ("fureter",),
    "furèterai": ("fureter",),
    "furèterais": ("fureter",),
    "furèterait": ("fureter",),
    "furèteras": ("fureter",),
    "furetèrent": ("fureter",),
    "furèterez": ("fureter",),
    "furèteriez": ("fureter",),
    "furèterions": ("fureter",),
    "furèterons": ("fureter",),
    "furèteront": ("fureter",),
    "furètes": ("fureter",),
    "furetez": ("fureter",),
    "furetiez": ("fureter",),
    "furetions": ("fureter",),
    "furetons": ("fureter",),
    "fuselaient": ("fuseler",),
    "fuselai": ("fuseler",),
    "fuselais": ("fuseler",),
    "fuselait": ("fuseler",),
    "fusela": ("fuseler",),
    "fuselâmes": ("fuseler",),
    "fuselant": ("fuseler",),
    "fuselas": ("fuseler",),
    "fuselassent": ("fuseler",),
    "fuselasses": ("fuseler",),
    "fuselasse": ("fuseler",),
    "fuselassiez": ("fuseler",),
    "fuselassions": ("fuseler",),
    "fuselâtes": ("fuseler",),
    "fuselât": ("fuseler",),
    "fuselée": ("fuseler",),
    "fuselées": ("fuseler",),
    "fuselé": ("fuseler",),
    "fuselèrent": ("fuseler",),
    "fuselés": ("fuseler",),
    "fuselez": ("fuseler",),
    "fuseliez": ("fuseler",),
    "fuselions": ("fuseler",),
    "fusellent": ("fuseler",),
    "fuselle": ("fuseler",),
    "fusellera": ("fuseler",),
    "fuselleraient": ("fuseler",),
    "fusellerai": ("fuseler",),
    "fusellerais": ("fuseler",),
    "fusellerait": ("fuseler",),
    "fuselleras": ("fuseler",),
    "fusellerez": ("fuseler",),
    "fuselleriez": ("fuseler",),
    "fusellerions": ("fuseler",),
    "fusellerons": ("fuseler",),
    "fuselleront": ("fuseler",),
    "fuselles": ("fuseler",),
    "fuselons": ("fuseler",),
    "fustigeaient": ("fustiger",),
    "fustigeai": ("fustiger",),
    "fustigeais": ("fustiger",),
    "fustigeait": ("fustiger",),
    "fustigea": ("fustiger",),
    "fustigeâmes": ("fustiger",),
    "fustigeant": ("fustiger",),
    "fustigeas": ("fustiger",),
    "fustigeassent": ("fustiger",),
    "fustigeasses": ("fustiger",),
    "fustigeasse": ("fustiger",),
    "fustigeassiez": ("fustiger",),
    "fustigeassions": ("fustiger",),
    "fustigeâtes": ("fustiger",),
    "fustigeât": ("fustiger",),
    "fustigée": ("fustiger",),
    "fustigées": ("fustiger",),
    "fustigé": ("fustiger",),
    "fustigent": ("fustiger",),
    "fustigeons": ("fustiger",),
    "fustige": ("fustiger",),
    "fustigera": ("fustiger",),
    "fustigeraient": ("fustiger",),
    "fustigerai": ("fustiger",),
    "fustigerais": ("fustiger",),
    "fustigerait": ("fustiger",),
    "fustigeras": ("fustiger",),
    "fustigèrent": ("fustiger",),
    "fustigerez": ("fustiger",),
    "fustigeriez": ("fustiger",),
    "fustigerions": ("fustiger",),
    "fustigerons": ("fustiger",),
    "fustigeront": ("fustiger",),
    "fustigés": ("fustiger",),
    "fustiges": ("fustiger",),
    "fustigez": ("fustiger",),
    "fustigiez": ("fustiger",),
    "fustigions": ("fustiger",),
    "gabariaient": ("gabarier",),
    "gabariai": ("gabarier",),
    "gabariais": ("gabarier",),
    "gabariait": ("gabarier",),
    "gabaria": ("gabarier",),
    "gabariâmes": ("gabarier",),
    "gabariant": ("gabarier",),
    "gabarias": ("gabarier",),
    "gabariassent": ("gabarier",),
    "gabariasses": ("gabarier",),
    "gabariasse": ("gabarier",),
    "gabariassiez": ("gabarier",),
    "gabariassions": ("gabarier",),
    "gabariâtes": ("gabarier",),
    "gabariât": ("gabarier",),
    "gabariée": ("gabarier",),
    "gabariées": ("gabarier",),
    "gabarié": ("gabarier",),
    "gabarient": ("gabarier",),
    "gabarie": ("gabarier",),
    "gabariera": ("gabarier",),
    "gabarieraient": ("gabarier",),
    "gabarierai": ("gabarier",),
    "gabarierais": ("gabarier",),
    "gabarierait": ("gabarier",),
    "gabarieras": ("gabarier",),
    "gabarièrent": ("gabarier",),
    "gabarierez": ("gabarier",),
    "gabarieriez": ("gabarier",),
    "gabarierions": ("gabarier",),
    "gabarierons": ("gabarier",),
    "gabarieront": ("gabarier",),
    "gabariés": ("gabarier",),
    "gabaries": ("gabarier",),
    "gabariez": ("gabarier",),
    "gabariiez": ("gabarier",),
    "gabariions": ("gabarier",),
    "gabarions": ("gabarier",),
    "gageaient": ("gager",),
    "gageai": ("gager",),
    "gageais": ("gager",),
    "gageait": ("gager",),
    "gagea": ("gager",),
    "gageâmes": ("gager",),
    "gageant": ("gager",),
    "gageas": ("gager",),
    "gageassent": ("gager",),
    "gageasses": ("gager",),
    "gageasse": ("gager",),
    "gageassiez": ("gager",),
    "gageassions": ("gager",),
    "gageâtes": ("gager",),
    "gageât": ("gager",),
    "gagée": ("gager",),
    "gagées": ("gager",),
    "gagé": ("gager",),
    "gagent": ("gager",),
    "gageons": ("gager",),
    "gage": ("gager",),
    "gagera": ("gager",),
    "gageraient": ("gager",),
    "gagerai": ("gager",),
    "gagerais": ("gager",),
    "gagerait": ("gager",),
    "gageras": ("gager",),
    "gagèrent": ("gager",),
    "gagerez": ("gager",),
    "gageriez": ("gager",),
    "gagerions": ("gager",),
    "gagerons": ("gager",),
    "gageront": ("gager",),
    "gagés": ("gager",),
    "gages": ("gager",),
    "gagez": ("gager",),
    "gagiez": ("gager",),
    "gagions": ("gager",),
    "galégeaient": ("galéger",),
    "galégeai": ("galéger",),
    "galégeais": ("galéger",),
    "galégeait": ("galéger",),
    "galégea": ("galéger",),
    "galégeâmes": ("galéger",),
    "galégeant": ("galéger",),
    "galégeas": ("galéger",),
    "galégeassent": ("galéger",),
    "galégeasses": ("galéger",),
    "galégeasse": ("galéger",),
    "galégeassiez": ("galéger",),
    "galégeassions": ("galéger",),
    "galégeâtes": ("galéger",),
    "galégeât": ("galéger",),
    "galégé": ("galéger",),
    "galègent": ("galéger",),
    "galégeons": ("galéger",),
    "galège": ("galéger",),
    "galégera": ("galéger",),
    "galégeraient": ("galéger",),
    "galégerai": ("galéger",),
    "galégerais": ("galéger",),
    "galégerait": ("galéger",),
    "galégeras": ("galéger",),
    "galégèrent": ("galéger",),
    "galégerez": ("galéger",),
    "galégeriez": ("galéger",),
    "galégerions": ("galéger",),
    "galégerons": ("galéger",),
    "galégeront": ("galéger",),
    "galèges": ("galéger",),
    "galégez": ("galéger",),
    "galégiez": ("galéger",),
    "galégions": ("galéger",),
    "galéjaient": ("galéjer",),
    "galéjai": ("galéjer",),
    "galéjais": ("galéjer",),
    "galéjait": ("galéjer",),
    "galéja": ("galéjer",),
    "galéjâmes": ("galéjer",),
    "galéjant": ("galéjer",),
    "galéjas": ("galéjer",),
    "galéjassent": ("galéjer",),
    "galéjasses": ("galéjer",),
    "galéjasse": ("galéjer",),
    "galéjassiez": ("galéjer",),
    "galéjassions": ("galéjer",),
    "galéjâtes": ("galéjer",),
    "galéjât": ("galéjer",),
    "galéjée": ("galéjer",),
    "galéjées": ("galéjer",),
    "galéjé": ("galéjer",),
    "galèjent": ("galéjer",),
    "galèje": ("galéjer",),
    "galéjera": ("galéjer",),
    "galéjeraient": ("galéjer",),
    "galéjerai": ("galéjer",),
    "galéjerais": ("galéjer",),
    "galéjerait": ("galéjer",),
    "galéjeras": ("galéjer",),
    "galéjèrent": ("galéjer",),
    "galéjerez": ("galéjer",),
    "galéjeriez": ("galéjer",),
    "galéjerions": ("galéjer",),
    "galéjerons": ("galéjer",),
    "galéjeront": ("galéjer",),
    "galéjés": ("galéjer",),
    "galèjes": ("galéjer",),
    "galéjez": ("galéjer",),
    "galéjiez": ("galéjer",),
    "galéjions": ("galéjer",),
    "galéjons": ("galéjer",),
    "galéraient": ("galérer",),
    "galérai": ("galérer",),
    "galérais": ("galérer",),
    "galérait": ("galérer",),
    "galéra": ("galérer",),
    "galérâmes": ("galérer",),
    "galérant": ("galérer",),
    "galéras": ("galérer",),
    "galérassent": ("galérer",),
    "galérasses": ("galérer",),
    "galérasse": ("galérer",),
    "galérassiez": ("galérer",),
    "galérassions": ("galérer",),
    "galérâtes": ("galérer",),
    "galérât": ("galérer",),
    "galéré": ("galérer",),
    "galèrent": ("galérer",),
    "galère": ("galérer",),
    "galérera": ("galérer",),
    "galéreraient": ("galérer",),
    "galérerai": ("galérer",),
    "galérerais": ("galérer",),
    "galérerait": ("galérer",),
    "galéreras": ("galérer",),
    "galérèrent": ("galérer",),
    "galérerez": ("galérer",),
    "galéreriez": ("galérer",),
    "galérerions": ("galérer",),
    "galérerons": ("galérer",),
    "galéreront": ("galérer",),
    "galères": ("galérer",),
    "galérez": ("galérer",),
    "galériez": ("galérer",),
    "galérions": ("galérer",),
    "galérons": ("galérer",),
    "galetaient": ("galeter",),
    "galetai": ("galeter",),
    "galetais": ("galeter",),
    "galetait": ("galeter",),
    "galeta": ("galeter",),
    "galetâmes": ("galeter",),
    "galetant": ("galeter",),
    "galetas": ("galeter",),
    "galetassent": ("galeter",),
    "galetasses": ("galeter",),
    "galetasse": ("galeter",),
    "galetassiez": ("galeter",),
    "galetassions": ("galeter",),
    "galetâtes": ("galeter",),
    "galetât": ("galeter",),
    "galetée": ("galeter",),
    "galetées": ("galeter",),
    "galeté": ("galeter",),
    "galetèrent": ("galeter",),
    "galetés": ("galeter",),
    "galetez": ("galeter",),
    "galetiez": ("galeter",),
    "galetions": ("galeter",),
    "galetons": ("galeter",),
    "galettent": ("galeter",),
    "galette": ("galeter",),
    "galettera": ("galeter",),
    "galetteraient": ("galeter",),
    "galetterai": ("galeter",),
    "galetterais": ("galeter",),
    "galetterait": ("galeter",),
    "galetteras": ("galeter",),
    "galetterez": ("galeter",),
    "galetteriez": ("galeter",),
    "galetterions": ("galeter",),
    "galetterons": ("galeter",),
    "galetteront": ("galeter",),
    "galettes": ("galeter",),
    "gambergeaient": ("gamberger",),
    "gambergeai": ("gamberger",),
    "gambergeais": ("gamberger",),
    "gambergeait": ("gamberger",),
    "gambergea": ("gamberger",),
    "gambergeâmes": ("gamberger",),
    "gambergeant": ("gamberger",),
    "gambergeas": ("gamberger",),
    "gambergeassent": ("gamberger",),
    "gambergeasses": ("gamberger",),
    "gambergeasse": ("gamberger",),
    "gambergeassiez": ("gamberger",),
    "gambergeassions": ("gamberger",),
    "gambergeâtes": ("gamberger",),
    "gambergeât": ("gamberger",),
    "gambergée": ("gamberger",),
    "gambergées": ("gamberger",),
    "gambergé": ("gamberger",),
    "gambergent": ("gamberger",),
    "gambergeons": ("gamberger",),
    "gamberge": ("gamberger",),
    "gambergera": ("gamberger",),
    "gambergeraient": ("gamberger",),
    "gambergerai": ("gamberger",),
    "gambergerais": ("gamberger",),
    "gambergerait": ("gamberger",),
    "gambergeras": ("gamberger",),
    "gambergèrent": ("gamberger",),
    "gambergerez": ("gamberger",),
    "gambergeriez": ("gamberger",),
    "gambergerions": ("gamberger",),
    "gambergerons": ("gamberger",),
    "gambergeront": ("gamberger",),
    "gambergés": ("gamberger",),
    "gamberges": ("gamberger",),
    "gambergez": ("gamberger",),
    "gambergiez": ("gamberger",),
    "gambergions": ("gamberger",),
    "gambiaient": ("gambier",),
    "gambiai": ("gambier",),
    "gambiais": ("gambier",),
    "gambiait": ("gambier",),
    "gambia": ("gambier",),
    "gambiâmes": ("gambier",),
    "gambiant": ("gambier",),
    "gambias": ("gambier",),
    "gambiassent": ("gambier",),
    "gambiasses": ("gambier",),
    "gambiasse": ("gambier",),
    "gambiassiez": ("gambier",),
    "gambiassions": ("gambier",),
    "gambiâtes": ("gambier",),
    "gambiât": ("gambier",),
    "gambiée": ("gambier",),
    "gambiées": ("gambier",),
    "gambié": ("gambier",),
    "gambient": ("gambier",),
    "gambie": ("gambier",),
    "gambiera": ("gambier",),
    "gambieraient": ("gambier",),
    "gambierai": ("gambier",),
    "gambierais": ("gambier",),
    "gambierait": ("gambier",),
    "gambieras": ("gambier",),
    "gambièrent": ("gambier",),
    "gambierez": ("gambier",),
    "gambieriez": ("gambier",),
    "gambierions": ("gambier",),
    "gambierons": ("gambier",),
    "gambieront": ("gambier",),
    "gambiés": ("gambier",),
    "gambies": ("gambier",),
    "gambiez": ("gambier",),
    "gambiiez": ("gambier",),
    "gambiions": ("gambier",),
    "gambions": ("gambier",),
    "gangrenaient": ("gangrener",),
    "gangrenai": ("gangrener",),
    "gangrenais": ("gangrener",),
    "gangrenait": ("gangrener",),
    "gangrena": ("gangrener",),
    "gangrenâmes": ("gangrener",),
    "gangrenant": ("gangrener",),
    "gangrenas": ("gangrener",),
    "gangrenassent": ("gangrener",),
    "gangrenasses": ("gangrener",),
    "gangrenasse": ("gangrener",),
    "gangrenassiez": ("gangrener",),
    "gangrenassions": ("gangrener",),
    "gangrenâtes": ("gangrener",),
    "gangrenât": ("gangrener",),
    "gangrenée": ("gangrener",),
    "gangrenées": ("gangrener",),
    "gangrené": ("gangrener",),
    "gangrènent": ("gangrener",),
    "gangrène": ("gangrener",),
    "gangrènera": ("gangrener",),
    "gangrèneraient": ("gangrener",),
    "gangrènerai": ("gangrener",),
    "gangrènerais": ("gangrener",),
    "gangrènerait": ("gangrener",),
    "gangrèneras": ("gangrener",),
    "gangrenèrent": ("gangrener",),
    "gangrènerez": ("gangrener",),
    "gangrèneriez": ("gangrener",),
    "gangrènerions": ("gangrener",),
    "gangrènerons": ("gangrener",),
    "gangrèneront": ("gangrener",),
    "gangrenés": ("gangrener",),
    "gangrènes": ("gangrener",),
    "gangrenez": ("gangrener",),
    "gangreniez": ("gangrener",),
    "gangrenions": ("gangrener",),
    "gangrenons": ("gangrener",),
    "gantelaient": ("ganteler",),
    "gantelai": ("ganteler",),
    "gantelais": ("ganteler",),
    "gantelait": ("ganteler",),
    "gantela": ("ganteler",),
    "gantelâmes": ("ganteler",),
    "gantelant": ("ganteler",),
    "gantelas": ("ganteler",),
    "gantelassent": ("ganteler",),
    "gantelasses": ("ganteler",),
    "gantelasse": ("ganteler",),
    "gantelassiez": ("ganteler",),
    "gantelassions": ("ganteler",),
    "gantelâtes": ("ganteler",),
    "gantelât": ("ganteler",),
    "gantelée": ("ganteler",),
    "gantelées": ("ganteler",),
    "gantelé": ("ganteler",),
    "gantelèrent": ("ganteler",),
    "gantelés": ("ganteler",),
    "gantelez": ("ganteler",),
    "ganteliez": ("ganteler",),
    "gantelions": ("ganteler",),
    "gantellent": ("ganteler",),
    "gantelle": ("ganteler",),
    "gantellera": ("ganteler",),
    "gantelleraient": ("ganteler",),
    "gantellerai": ("ganteler",),
    "gantellerais": ("ganteler",),
    "gantellerait": ("ganteler",),
    "gantelleras": ("ganteler",),
    "gantellerez": ("ganteler",),
    "gantelleriez": ("ganteler",),
    "gantellerions": ("ganteler",),
    "gantellerons": ("ganteler",),
    "gantelleront": ("ganteler",),
    "gantelles": ("ganteler",),
    "gantelons": ("ganteler",),
    "garançaient": ("garancer",),
    "garançai": ("garancer",),
    "garançais": ("garancer",),
    "garançait": ("garancer",),
    "garança": ("garancer",),
    "garançâmes": ("garancer",),
    "garançant": ("garancer",),
    "garanças": ("garancer",),
    "garançassent": ("garancer",),
    "garançasses": ("garancer",),
    "garançasse": ("garancer",),
    "garançassiez": ("garancer",),
    "garançassions": ("garancer",),
    "garançâtes": ("garancer",),
    "garançât": ("garancer",),
    "garancée": ("garancer",),
    "garancées": ("garancer",),
    "garancé": ("garancer",),
    "garancent": ("garancer",),
    "garance": ("garancer",),
    "garancera": ("garancer",),
    "garanceraient": ("garancer",),
    "garancerai": ("garancer",),
    "garancerais": ("garancer",),
    "garancerait": ("garancer",),
    "garanceras": ("garancer",),
    "garancèrent": ("garancer",),
    "garancerez": ("garancer",),
    "garanceriez": ("garancer",),
    "garancerions": ("garancer",),
    "garancerons": ("garancer",),
    "garanceront": ("garancer",),
    "garancés": ("garancer",),
    "garances": ("garancer",),
    "garancez": ("garancer",),
    "garanciez": ("garancer",),
    "garancions": ("garancer",),
    "garançons": ("garancer",),
    "garantie": ("garantir",),
    "garanties": ("garantir",),
    "garanti": ("garantir",),
    "garantîmes": ("garantir",),
    "garantira": ("garantir",),
    "garantiraient": ("garantir",),
    "garantirai": ("garantir",),
    "garantirais": ("garantir",),
    "garantirait": ("garantir",),
    "garantiras": ("garantir",),
    "garantirent": ("garantir",),
    "garantirez": ("garantir",),
    "garantiriez": ("garantir",),
    "garantirions": ("garantir",),
    "garantirons": ("garantir",),
    "garantiront": ("garantir",),
    "garantis": ("garantir",),
    "garantissaient": ("garantir",),
    "garantissais": ("garantir",),
    "garantissait": ("garantir",),
    "garantissant": ("garantir",),
    "garantissent": ("garantir",),
    "garantisse": ("garantir",),
    "garantisses": ("garantir",),
    "garantissez": ("garantir",),
    "garantissiez": ("garantir",),
    "garantissions": ("garantir",),
    "garantissons": ("garantir",),
    "garantîtes": ("garantir",),
    "garantit": ("garantir",),
    "garantît": ("garantir",),
    "garnie": ("garnir",),
    "garnies": ("garnir",),
    "garni": ("garnir",),
    "garnîmes": ("garnir",),
    "garnira": ("garnir",),
    "garniraient": ("garnir",),
    "garnirai": ("garnir",),
    "garnirais": ("garnir",),
    "garnirait": ("garnir",),
    "garniras": ("garnir",),
    "garnirent": ("garnir",),
    "garnirez": ("garnir",),
    "garniriez": ("garnir",),
    "garnirions": ("garnir",),
    "garnirons": ("garnir",),
    "garniront": ("garnir",),
    "garnis": ("garnir",),
    "garnissaient": ("garnir",),
    "garnissais": ("garnir",),
    "garnissait": ("garnir",),
    "garnissant": ("garnir",),
    "garnissent": ("garnir",),
    "garnisse": ("garnir",),
    "garnisses": ("garnir",),
    "garnissez": ("garnir",),
    "garnissiez": ("garnir",),
    "garnissions": ("garnir",),
    "garnissons": ("garnir",),
    "garnîtes": ("garnir",),
    "garnit": ("garnir",),
    "garnît": ("garnir",),
    "gâtaient": ("gâter",),
    "gâtai": ("gâter",),
    "gâtais": ("gâter",),
    "gâtait": ("gâter",),
    "gâta": ("gâter",),
    "gâtâmes": ("gâter",),
    "gâtant": ("gâter",),
    "gâtas": ("gâter",),
    "gâtassent": ("gâter",),
    "gâtasses": ("gâter",),
    "gâtasse": ("gâter",),
    "gâtassiez": ("gâter",),
    "gâtassions": ("gâter",),
    "gâtâtes": ("gâter",),
    "gâtât": ("gâter",),
    "gâtée": ("gâter",),
    "gâtées": ("gâter",),
    "gâté": ("gâter",),
    "gâtent": ("gâter",),
    "gâte": ("gâter",),
    "gâtera": ("gâter",),
    "gâteraient": ("gâter",),
    "gâterai": ("gâter",),
    "gâterais": ("gâter",),
    "gâterait": ("gâter",),
    "gâteras": ("gâter",),
    "gâtèrent": ("gâter",),
    "gâterez": ("gâter",),
    "gâteriez": ("gâter",),
    "gâterions": ("gâter",),
    "gâterons": ("gâter",),
    "gâteront": ("gâter",),
    "gâtés": ("gâter",),
    "gâtes": ("gâter",),
    "gâtez": ("gâter",),
    "gâtiez": ("gâter",),
    "gâtions": ("gâter",),
    "gâtons": ("gâter",),
    "gâtifiaient": ("gâtifier",),
    "gâtifiai": ("gâtifier",),
    "gâtifiais": ("gâtifier",),
    "gâtifiait": ("gâtifier",),
    "gâtifia": ("gâtifier",),
    "gâtifiâmes": ("gâtifier",),
    "gâtifiant": ("gâtifier",),
    "gâtifias": ("gâtifier",),
    "gâtifiassent": ("gâtifier",),
    "gâtifiasses": ("gâtifier",),
    "gâtifiasse": ("gâtifier",),
    "gâtifiassiez": ("gâtifier",),
    "gâtifiassions": ("gâtifier",),
    "gâtifiâtes": ("gâtifier",),
    "gâtifiât": ("gâtifier",),
    "gâtifiée": ("gâtifier",),
    "gâtifiées": ("gâtifier",),
    "gâtifié": ("gâtifier",),
    "gâtifient": ("gâtifier",),
    "gâtifie": ("gâtifier",),
    "gâtifiera": ("gâtifier",),
    "gâtifieraient": ("gâtifier",),
    "gâtifierai": ("gâtifier",),
    "gâtifierais": ("gâtifier",),
    "gâtifierait": ("gâtifier",),
    "gâtifieras": ("gâtifier",),
    "gâtifièrent": ("gâtifier",),
    "gâtifierez": ("gâtifier",),
    "gâtifieriez": ("gâtifier",),
    "gâtifierions": ("gâtifier",),
    "gâtifierons": ("gâtifier",),
    "gâtifieront": ("gâtifier",),
    "gâtifiés": ("gâtifier",),
    "gâtifies": ("gâtifier",),
    "gâtifiez": ("gâtifier",),
    "gâtifiiez": ("gâtifier",),
    "gâtifiions": ("gâtifier",),
    "gâtifions": ("gâtifier",),
    "gauchie": ("gauchir",),
    "gauchies": ("gauchir",),
    "gauchi": ("gauchir",),
    "gauchîmes": ("gauchir",),
    "gauchira": ("gauchir",),
    "gauchiraient": ("gauchir",),
    "gauchirai": ("gauchir",),
    "gauchirais": ("gauchir",),
    "gauchirait": ("gauchir",),
    "gauchiras": ("gauchir",),
    "gauchirent": ("gauchir",),
    "gauchirez": ("gauchir",),
    "gauchiriez": ("gauchir",),
    "gauchirions": ("gauchir",),
    "gauchirons": ("gauchir",),
    "gauchiront": ("gauchir",),
    "gauchis": ("gauchir",),
    "gauchissaient": ("gauchir",),
    "gauchissais": ("gauchir",),
    "gauchissait": ("gauchir",),
    "gauchissant": ("gauchir",),
    "gauchissent": ("gauchir",),
    "gauchisse": ("gauchir",),
    "gauchisses": ("gauchir",),
    "gauchissez": ("gauchir",),
    "gauchissiez": ("gauchir",),
    "gauchissions": ("gauchir",),
    "gauchissons": ("gauchir",),
    "gauchîtes": ("gauchir",),
    "gauchit": ("gauchir",),
    "gauchît": ("gauchir",),
    "gaudie": ("gaudir",),
    "gaudies": ("gaudir",),
    "gaudi": ("gaudir",),
    "gaudîmes": ("gaudir",),
    "gaudira": ("gaudir",),
    "gaudiraient": ("gaudir",),
    "gaudirai": ("gaudir",),
    "gaudirais": ("gaudir",),
    "gaudirait": ("gaudir",),
    "gaudiras": ("gaudir",),
    "gaudirent": ("gaudir",),
    "gaudirez": ("gaudir",),
    "gaudiriez": ("gaudir",),
    "gaudirions": ("gaudir",),
    "gaudirons": ("gaudir",),
    "gaudiront": ("gaudir",),
    "gaudis": ("gaudir",),
    "gaudissaient": ("gaudir",),
    "gaudissais": ("gaudir",),
    "gaudissait": ("gaudir",),
    "gaudissant": ("gaudir",),
    "gaudissent": ("gaudir",),
    "gaudisse": ("gaudir",),
    "gaudisses": ("gaudir",),
    "gaudissez": ("gaudir",),
    "gaudissiez": ("gaudir",),
    "gaudissions": ("gaudir",),
    "gaudissons": ("gaudir",),
    "gaudîtes": ("gaudir",),
    "gaudit": ("gaudir",),
    "gaudît": ("gaudir",),
    "gazéifiaient": ("gazéifier",),
    "gazéifiai": ("gazéifier",),
    "gazéifiais": ("gazéifier",),
    "gazéifiait": ("gazéifier",),
    "gazéifia": ("gazéifier",),
    "gazéifiâmes": ("gazéifier",),
    "gazéifiant": ("gazéifier",),
    "gazéifias": ("gazéifier",),
    "gazéifiassent": ("gazéifier",),
    "gazéifiasses": ("gazéifier",),
    "gazéifiasse": ("gazéifier",),
    "gazéifiassiez": ("gazéifier",),
    "gazéifiassions": ("gazéifier",),
    "gazéifiâtes": ("gazéifier",),
    "gazéifiât": ("gazéifier",),
    "gazéifiée": ("gazéifier",),
    "gazéifiées": ("gazéifier",),
    "gazéifié": ("gazéifier",),
    "gazéifient": ("gazéifier",),
    "gazéifie": ("gazéifier",),
    "gazéifiera": ("gazéifier",),
    "gazéifieraient": ("gazéifier",),
    "gazéifierai": ("gazéifier",),
    "gazéifierais": ("gazéifier",),
    "gazéifierait": ("gazéifier",),
    "gazéifieras": ("gazéifier",),
    "gazéifièrent": ("gazéifier",),
    "gazéifierez": ("gazéifier",),
    "gazéifieriez": ("gazéifier",),
    "gazéifierions": ("gazéifier",),
    "gazéifierons": ("gazéifier",),
    "gazéifieront": ("gazéifier",),
    "gazéifiés": ("gazéifier",),
    "gazéifies": ("gazéifier",),
    "gazéifiez": ("gazéifier",),
    "gazéifiiez": ("gazéifier",),
    "gazéifiions": ("gazéifier",),
    "gazéifions": ("gazéifier",),
    "geignaient": ("geindre",),
    "geignais": ("geindre",),
    "geignait": ("geindre",),
    "geignant": ("geindre",),
    "geignent": ("geindre",),
    "geigne": ("geindre",),
    "geignes": ("geindre",),
    "geignez": ("geindre",),
    "geigniez": ("geindre",),
    "geignîmes": ("geindre",),
    "geignions": ("geindre",),
    "geignirent": ("geindre",),
    "geignis": ("geindre",),
    "geignissent": ("geindre",),
    "geignisses": ("geindre",),
    "geignisse": ("geindre",),
    "geignissiez": ("geindre",),
    "geignissions": ("geindre",),
    "geignîtes": ("geindre",),
    "geignit": ("geindre",),
    "geignît": ("geindre",),
    "geignons": ("geindre",),
    "geindra": ("geindre",),
    "geindraient": ("geindre",),
    "geindrai": ("geindre",),
    "geindrais": ("geindre",),
    "geindrait": ("geindre",),
    "geindras": ("geindre",),
    "geindrez": ("geindre",),
    "geindriez": ("geindre",),
    "geindrions": ("geindre",),
    "geindrons": ("geindre",),
    "geindront": ("geindre",),
    "geins": ("geindre",),
    "geint": ("geindre",),
    "gelaient": ("geler",),
    "gelai": ("geler",),
    "gelais": ("geler",),
    "gelait": ("geler",),
    "gela": ("geler",),
    "gelâmes": ("geler",),
    "gelant": ("geler",),
    "gelas": ("geler",),
    "gelassent": ("geler",),
    "gelasses": ("geler",),
    "gelasse": ("geler",),
    "gelassiez": ("geler",),
    "gelassions": ("geler",),
    "gelâtes": ("geler",),
    "gelât": ("geler",),
    "gelée": ("geler",),
    "gelées": ("geler",),
    "gelé": ("geler",),
    "gèlent": ("geler",),
    "gèle": ("geler",),
    "gèlera": ("geler",),
    "gèleraient": ("geler",),
    "gèlerai": ("geler",),
    "gèlerais": ("geler",),
    "gèlerait": ("geler",),
    "gèleras": ("geler",),
    "gelèrent": ("geler",),
    "gèlerez": ("geler",),
    "gèleriez": ("geler",),
    "gèlerions": ("geler",),
    "gèlerons": ("geler",),
    "gèleront": ("geler",),
    "gelés": ("geler",),
    "gèles": ("geler",),
    "gelez": ("geler",),
    "geliez": ("geler",),
    "gelions": ("geler",),
    "gelons": ("geler",),
    "gélifiaient": ("gélifier",),
    "gélifiai": ("gélifier",),
    "gélifiais": ("gélifier",),
    "gélifiait": ("gélifier",),
    "gélifia": ("gélifier",),
    "gélifiâmes": ("gélifier",),
    "gélifiant": ("gélifier",),
    "gélifias": ("gélifier",),
    "gélifiassent": ("gélifier",),
    "gélifiasses": ("gélifier",),
    "gélifiasse": ("gélifier",),
    "gélifiassiez": ("gélifier",),
    "gélifiassions": ("gélifier",),
    "gélifiâtes": ("gélifier",),
    "gélifiât": ("gélifier",),
    "gélifiée": ("gélifier",),
    "gélifiées": ("gélifier",),
    "gélifié": ("gélifier",),
    "gélifient": ("gélifier",),
    "gélifie": ("gélifier",),
    "gélifiera": ("gélifier",),
    "gélifieraient": ("gélifier",),
    "gélifierai": ("gélifier",),
    "gélifierais": ("gélifier",),
    "gélifierait": ("gélifier",),
    "gélifieras": ("gélifier",),
    "gélifièrent": ("gélifier",),
    "gélifierez": ("gélifier",),
    "gélifieriez": ("gélifier",),
    "gélifierions": ("gélifier",),
    "gélifierons": ("gélifier",),
    "gélifieront": ("gélifier",),
    "gélifiés": ("gélifier",),
    "gélifies": ("gélifier",),
    "gélifiez": ("gélifier",),
    "gélifiiez": ("gélifier",),
    "gélifiions": ("gélifier",),
    "gélifions": ("gélifier",),
    "gémie": ("gémir",),
    "gémies": ("gémir",),
    "gémi": ("gémir",),
    "gémîmes": ("gémir",),
    "gémira": ("gémir",),
    "gémiraient": ("gémir",),
    "gémirai": ("gémir",),
    "gémirais": ("gémir",),
    "gémirait": ("gémir",),
    "gémiras": ("gémir",),
    "gémirent": ("gémir",),
    "gémirez": ("gémir",),
    "gémiriez": ("gémir",),
    "gémirions": ("gémir",),
    "gémirons": ("gémir",),
    "gémiront": ("gémir",),
    "gémis": ("gémir",),
    "gémissaient": ("gémir",),
    "gémissais": ("gémir",),
    "gémissait": ("gémir",),
    "gémissant": ("gémir",),
    "gémissent": ("gémir",),
    "gémisse": ("gémir",),
    "gémisses": ("gémir",),
    "gémissez": ("gémir",),
    "gémissiez": ("gémir",),
    "gémissions": ("gémir",),
    "gémissons": ("gémir",),
    "gémîtes": ("gémir",),
    "gémit": ("gémir",),
    "gémît": ("gémir",),
    "généraient": ("générer",),
    "générai": ("générer",),
    "générais": ("générer",),
    "générait": ("générer",),
    "généra": ("générer",),
    "générâmes": ("générer",),
    "générant": ("générer",),
    "généras": ("générer",),
    "générassent": ("générer",),
    "générasses": ("générer",),
    "générasse": ("générer",),
    "générassiez": ("générer",),
    "générassions": ("générer",),
    "générâtes": ("générer",),
    "générât": ("générer",),
    "générée": ("générer",),
    "générées": ("générer",),
    "généré": ("générer",),
    "génèrent": ("générer",),
    "génère": ("générer",),
    "générera": ("générer",),
    "généreraient": ("générer",),
    "générerai": ("générer",),
    "générerais": ("générer",),
    "générerait": ("générer",),
    "généreras": ("générer",),
    "générèrent": ("générer",),
    "générerez": ("générer",),
    "généreriez": ("générer",),
    "générerions": ("générer",),
    "générerons": ("générer",),
    "généreront": ("générer",),
    "générés": ("générer",),
    "génères": ("générer",),
    "générez": ("générer",),
    "génériez": ("générer",),
    "générions": ("générer",),
    "générons": ("générer",),
    "genétaient": ("genéter",),
    "genétai": ("genéter",),
    "genétais": ("genéter",),
    "genétait": ("genéter",),
    "genéta": ("genéter",),
    "genétâmes": ("genéter",),
    "genétant": ("genéter",),
    "genétas": ("genéter",),
    "genétassent": ("genéter",),
    "genétasses": ("genéter",),
    "genétasse": ("genéter",),
    "genétassiez": ("genéter",),
    "genétassions": ("genéter",),
    "genétâtes": ("genéter",),
    "genétât": ("genéter",),
    "genétée": ("genéter",),
    "genétées": ("genéter",),
    "genété": ("genéter",),
    "genètent": ("genéter",),
    "genète": ("genéter",),
    "genétera": ("genéter",),
    "genéteraient": ("genéter",),
    "genéterai": ("genéter",),
    "genéterais": ("genéter",),
    "genéterait": ("genéter",),
    "genéteras": ("genéter",),
    "genétèrent": ("genéter",),
    "genéterez": ("genéter",),
    "genéteriez": ("genéter",),
    "genéterions": ("genéter",),
    "genéterons": ("genéter",),
    "genéteront": ("genéter",),
    "genétés": ("genéter",),
    "genètes": ("genéter",),
    "genétez": ("genéter",),
    "genétiez": ("genéter",),
    "genétions": ("genéter",),
    "genétons": ("genéter",),
    "géographiaient": ("géographier",),
    "géographiai": ("géographier",),
    "géographiais": ("géographier",),
    "géographiait": ("géographier",),
    "géographia": ("géographier",),
    "géographiâmes": ("géographier",),
    "géographiant": ("géographier",),
    "géographias": ("géographier",),
    "géographiassent": ("géographier",),
    "géographiasses": ("géographier",),
    "géographiasse": ("géographier",),
    "géographiassiez": ("géographier",),
    "géographiassions": ("géographier",),
    "géographiâtes": ("géographier",),
    "géographiât": ("géographier",),
    "géographiée": ("géographier",),
    "géographiées": ("géographier",),
    "géographié": ("géographier",),
    "géographient": ("géographier",),
    "géographie": ("géographier",),
    "géographiera": ("géographier",),
    "géographieraient": ("géographier",),
    "géographierai": ("géographier",),
    "géographierais": ("géographier",),
    "géographierait": ("géographier",),
    "géographieras": ("géographier",),
    "géographièrent": ("géographier",),
    "géographierez": ("géographier",),
    "géographieriez": ("géographier",),
    "géographierions": ("géographier",),
    "géographierons": ("géographier",),
    "géographieront": ("géographier",),
    "géographiés": ("géographier",),
    "géographies": ("géographier",),
    "géographiez": ("géographier",),
    "géographiiez": ("géographier",),
    "géographiions": ("géographier",),
    "géographions": ("géographier",),
    "gerçaient": ("gercer",),
    "gerçai": ("gercer",),
    "gerçais": ("gercer",),
    "gerçait": ("gercer",),
    "gerça": ("gercer",),
    "gerçâmes": ("gercer",),
    "gerçant": ("gercer",),
    "gerças": ("gercer",),
    "gerçassent": ("gercer",),
    "gerçasses": ("gercer",),
    "gerçasse": ("gercer",),
    "gerçassiez": ("gercer",),
    "gerçassions": ("gercer",),
    "gerçâtes": ("gercer",),
    "gerçât": ("gercer",),
    "gercée": ("gercer",),
    "gercées": ("gercer",),
    "gercé": ("gercer",),
    "gercent": ("gercer",),
    "gerce": ("gercer",),
    "gercera": ("gercer",),
    "gerceraient": ("gercer",),
    "gercerai": ("gercer",),
    "gercerais": ("gercer",),
    "gercerait": ("gercer",),
    "gerceras": ("gercer",),
    "gercèrent": ("gercer",),
    "gercerez": ("gercer",),
    "gerceriez": ("gercer",),
    "gercerions": ("gercer",),
    "gercerons": ("gercer",),
    "gerceront": ("gercer",),
    "gercés": ("gercer",),
    "gerces": ("gercer",),
    "gercez": ("gercer",),
    "gerciez": ("gercer",),
    "gercions": ("gercer",),
    "gerçons": ("gercer",),
    "géraient": ("gérer",),
    "gérai": ("gérer",),
    "gérais": ("gérer",),
    "gérait": ("gérer",),
    "géra": ("gérer",),
    "gérâmes": ("gérer",),
    "gérant": ("gérer",),
    "géras": ("gérer",),
    "gérassent": ("gérer",),
    "gérasses": ("gérer",),
    "gérasse": ("gérer",),
    "gérassiez": ("gérer",),
    "gérassions": ("gérer",),
    "gérâtes": ("gérer",),
    "gérât": ("gérer",),
    "gérée": ("gérer",),
    "gérées": ("gérer",),
    "géré": ("gérer",),
    "gèrent": ("gérer",),
    "gère": ("gérer",),
    "gérera": ("gérer",),
    "géreraient": ("gérer",),
    "gérerai": ("gérer",),
    "gérerais": ("gérer",),
    "gérerait": ("gérer",),
    "géreras": ("gérer",),
    "gérèrent": ("gérer",),
    "gérerez": ("gérer",),
    "géreriez": ("gérer",),
    "gérerions": ("gérer",),
    "gérerons": ("gérer",),
    "géreront": ("gérer",),
    "gérés": ("gérer",),
    "gères": ("gérer",),
    "gérez": ("gérer",),
    "gériez": ("gérer",),
    "gérions": ("gérer",),
    "gérons": ("gérer",),
    "gisaient": ("gésir",),
    "gisais": ("gésir",),
    "gisait": ("gésir",),
    "gisant": ("gésir",),
    "gisent": ("gésir",),
    "gisez": ("gésir",),
    "gisiez": ("gésir",),
    "gisions": ("gésir",),
    "gisons": ("gésir",),
    "gis": ("gésir",),
    "gît": ("gésir",),
    "giboient": ("giboyer",),
    "giboie": ("giboyer",),
    "giboiera": ("giboyer",),
    "giboieraient": ("giboyer",),
    "giboierai": ("giboyer",),
    "giboierais": ("giboyer",),
    "giboierait": ("giboyer",),
    "giboieras": ("giboyer",),
    "giboierez": ("giboyer",),
    "giboieriez": ("giboyer",),
    "giboierions": ("giboyer",),
    "giboierons": ("giboyer",),
    "giboieront": ("giboyer",),
    "giboies": ("giboyer",),
    "giboyaient": ("giboyer",),
    "giboyai": ("giboyer",),
    "giboyais": ("giboyer",),
    "giboyait": ("giboyer",),
    "giboya": ("giboyer",),
    "giboyâmes": ("giboyer",),
    "giboyant": ("giboyer",),
    "giboyas": ("giboyer",),
    "giboyassent": ("giboyer",),
    "giboyasses": ("giboyer",),
    "giboyasse": ("giboyer",),
    "giboyassiez": ("giboyer",),
    "giboyassions": ("giboyer",),
    "giboyâtes": ("giboyer",),
    "giboyât": ("giboyer",),
    "giboyé": ("giboyer",),
    "giboyèrent": ("giboyer",),
    "giboyez": ("giboyer",),
    "giboyiez": ("giboyer",),
    "giboyions": ("giboyer",),
    "giboyons": ("giboyer",),
    "giletaient": ("gileter",),
    "giletai": ("gileter",),
    "giletais": ("gileter",),
    "giletait": ("gileter",),
    "gileta": ("gileter",),
    "giletâmes": ("gileter",),
    "giletant": ("gileter",),
    "giletas": ("gileter",),
    "giletassent": ("gileter",),
    "giletasses": ("gileter",),
    "giletasse": ("gileter",),
    "giletassiez": ("gileter",),
    "giletassions": ("gileter",),
    "giletâtes": ("gileter",),
    "giletât": ("gileter",),
    "giletée": ("gileter",),
    "giletées": ("gileter",),
    "gileté": ("gileter",),
    "giletèrent": ("gileter",),
    "giletés": ("gileter",),
    "giletez": ("gileter",),
    "giletiez": ("gileter",),
    "giletions": ("gileter",),
    "giletons": ("gileter",),
    "gilettent": ("gileter",),
    "gilette": ("gileter",),
    "gilettera": ("gileter",),
    "giletteraient": ("gileter",),
    "giletterai": ("gileter",),
    "giletterais": ("gileter",),
    "giletterait": ("gileter",),
    "giletteras": ("gileter",),
    "giletterez": ("gileter",),
    "giletteriez": ("gileter",),
    "giletterions": ("gileter",),
    "giletterons": ("gileter",),
    "giletteront": ("gileter",),
    "gilettes": ("gileter",),
    "glaçaient": ("glacer",),
    "glaçai": ("glacer",),
    "glaçais": ("glacer",),
    "glaçait": ("glacer",),
    "glaça": ("glacer",),
    "glaçâmes": ("glacer",),
    "glaçant": ("glacer",),
    "glaças": ("glacer",),
    "glaçassent": ("glacer",),
    "glaçasses": ("glacer",),
    "glaçasse": ("glacer",),
    "glaçassiez": ("glacer",),
    "glaçassions": ("glacer",),
    "glaçâtes": ("glacer",),
    "glaçât": ("glacer",),
    "glacée": ("glacer",),
    "glacées": ("glacer",),
    "glacé": ("glacer",),
    "glacent": ("glacer",),
    "glace": ("glacer",),
    "glacera": ("glacer",),
    "glaceraient": ("glacer",),
    "glacerai": ("glacer",),
    "glacerais": ("glacer",),
    "glacerait": ("glacer",),
    "glaceras": ("glacer",),
    "glacèrent": ("glacer",),
    "glacerez": ("glacer",),
    "glaceriez": ("glacer",),
    "glacerions": ("glacer",),
    "glacerons": ("glacer",),
    "glaceront": ("glacer",),
    "glacés": ("glacer",),
    "glaces": ("glacer",),
    "glacez": ("glacer",),
    "glaciez": ("glacer",),
    "glacions": ("glacer",),
    "glaçons": ("glacer",),
    "glapie": ("glapir",),
    "glapies": ("glapir",),
    "glapi": ("glapir",),
    "glapîmes": ("glapir",),
    "glapira": ("glapir",),
    "glapiraient": ("glapir",),
    "glapirai": ("glapir",),
    "glapirais": ("glapir",),
    "glapirait": ("glapir",),
    "glapiras": ("glapir",),
    "glapirent": ("glapir",),
    "glapirez": ("glapir",),
    "glapiriez": ("glapir",),
    "glapirions": ("glapir",),
    "glapirons": ("glapir",),
    "glapiront": ("glapir",),
    "glapis": ("glapir",),
    "glapissaient": ("glapir",),
    "glapissais": ("glapir",),
    "glapissait": ("glapir",),
    "glapissant": ("glapir",),
    "glapissent": ("glapir",),
    "glapisse": ("glapir",),
    "glapisses": ("glapir",),
    "glapissez": ("glapir",),
    "glapissiez": ("glapir",),
    "glapissions": ("glapir",),
    "glapissons": ("glapir",),
    "glapîtes": ("glapir",),
    "glapit": ("glapir",),
    "glapît": ("glapir",),
    "glatie": ("glatir",),
    "glaties": ("glatir",),
    "glati": ("glatir",),
    "glatîmes": ("glatir",),
    "glatira": ("glatir",),
    "glatiraient": ("glatir",),
    "glatirai": ("glatir",),
    "glatirais": ("glatir",),
    "glatirait": ("glatir",),
    "glatiras": ("glatir",),
    "glatirent": ("glatir",),
    "glatirez": ("glatir",),
    "glatiriez": ("glatir",),
    "glatirions": ("glatir",),
    "glatirons": ("glatir",),
    "glatiront": ("glatir",),
    "glatis": ("glatir",),
    "glatissaient": ("glatir",),
    "glatissais": ("glatir",),
    "glatissait": ("glatir",),
    "glatissant": ("glatir",),
    "glatissent": ("glatir",),
    "glatisse": ("glatir",),
    "glatisses": ("glatir",),
    "glatissez": ("glatir",),
    "glatissiez": ("glatir",),
    "glatissions": ("glatir",),
    "glatissons": ("glatir",),
    "glatîtes": ("glatir",),
    "glatit": ("glatir",),
    "glatît": ("glatir",),
    "glénaient": ("gléner",),
    "glénai": ("gléner",),
    "glénais": ("gléner",),
    "glénait": ("gléner",),
    "gléna": ("gléner",),
    "glénâmes": ("gléner",),
    "glénant": ("gléner",),
    "glénas": ("gléner",),
    "glénassent": ("gléner",),
    "glénasses": ("gléner",),
    "glénasse": ("gléner",),
    "glénassiez": ("gléner",),
    "glénassions": ("gléner",),
    "glénâtes": ("gléner",),
    "glénât": ("gléner",),
    "glénée": ("gléner",),
    "glénées": ("gléner",),
    "gléné": ("gléner",),
    "glènent": ("gléner",),
    "glène": ("gléner",),
    "glénera": ("gléner",),
    "gléneraient": ("gléner",),
    "glénerai": ("gléner",),
    "glénerais": ("gléner",),
    "glénerait": ("gléner",),
    "gléneras": ("gléner",),
    "glénèrent": ("gléner",),
    "glénerez": ("gléner",),
    "gléneriez": ("gléner",),
    "glénerions": ("gléner",),
    "glénerons": ("gléner",),
    "gléneront": ("gléner",),
    "glénés": ("gléner",),
    "glènes": ("gléner",),
    "glénez": ("gléner",),
    "gléniez": ("gléner",),
    "glénions": ("gléner",),
    "glénons": ("gléner",),
    "gleyifiaient": ("gleyifier",),
    "gleyifiai": ("gleyifier",),
    "gleyifiais": ("gleyifier",),
    "gleyifiait": ("gleyifier",),
    "gleyifia": ("gleyifier",),
    "gleyifiâmes": ("gleyifier",),
    "gleyifiant": ("gleyifier",),
    "gleyifias": ("gleyifier",),
    "gleyifiassent": ("gleyifier",),
    "gleyifiasses": ("gleyifier",),
    "gleyifiasse": ("gleyifier",),
    "gleyifiassiez": ("gleyifier",),
    "gleyifiassions": ("gleyifier",),
    "gleyifiâtes": ("gleyifier",),
    "gleyifiât": ("gleyifier",),
    "gleyifiée": ("gleyifier",),
    "gleyifiées": ("gleyifier",),
    "gleyifié": ("gleyifier",),
    "gleyifient": ("gleyifier",),
    "gleyifie": ("gleyifier",),
    "gleyifiera": ("gleyifier",),
    "gleyifieraient": ("gleyifier",),
    "gleyifierai": ("gleyifier",),
    "gleyifierais": ("gleyifier",),
    "gleyifierait": ("gleyifier",),
    "gleyifieras": ("gleyifier",),
    "gleyifièrent": ("gleyifier",),
    "gleyifierez": ("gleyifier",),
    "gleyifieriez": ("gleyifier",),
    "gleyifierions": ("gleyifier",),
    "gleyifierons": ("gleyifier",),
    "gleyifieront": ("gleyifier",),
    "gleyifiés": ("gleyifier",),
    "gleyifies": ("gleyifier",),
    "gleyifiez": ("gleyifier",),
    "gleyifiiez": ("gleyifier",),
    "gleyifiions": ("gleyifier",),
    "gleyifions": ("gleyifier",),
    "glorifiaient": ("glorifier",),
    "glorifiai": ("glorifier",),
    "glorifiais": ("glorifier",),
    "glorifiait": ("glorifier",),
    "glorifia": ("glorifier",),
    "glorifiâmes": ("glorifier",),
    "glorifiant": ("glorifier",),
    "glorifias": ("glorifier",),
    "glorifiassent": ("glorifier",),
    "glorifiasses": ("glorifier",),
    "glorifiasse": ("glorifier",),
    "glorifiassiez": ("glorifier",),
    "glorifiassions": ("glorifier",),
    "glorifiâtes": ("glorifier",),
    "glorifiât": ("glorifier",),
    "glorifiée": ("glorifier",),
    "glorifiées": ("glorifier",),
    "glorifié": ("glorifier",),
    "glorifient": ("glorifier",),
    "glorifie": ("glorifier",),
    "glorifiera": ("glorifier",),
    "glorifieraient": ("glorifier",),
    "glorifierai": ("glorifier",),
    "glorifierais": ("glorifier",),
    "glorifierait": ("glorifier",),
    "glorifieras": ("glorifier",),
    "glorifièrent": ("glorifier",),
    "glorifierez": ("glorifier",),
    "glorifieriez": ("glorifier",),
    "glorifierions": ("glorifier",),
    "glorifierons": ("glorifier",),
    "glorifieront": ("glorifier",),
    "glorifiés": ("glorifier",),
    "glorifies": ("glorifier",),
    "glorifiez": ("glorifier",),
    "glorifiiez": ("glorifier",),
    "glorifiions": ("glorifier",),
    "glorifions": ("glorifier",),
    "gobergeaient": ("goberger",),
    "gobergeai": ("goberger",),
    "gobergeais": ("goberger",),
    "gobergeait": ("goberger",),
    "gobergea": ("goberger",),
    "gobergeâmes": ("goberger",),
    "gobergeant": ("goberger",),
    "gobergeas": ("goberger",),
    "gobergeassent": ("goberger",),
    "gobergeasses": ("goberger",),
    "gobergeasse": ("goberger",),
    "gobergeassiez": ("goberger",),
    "gobergeassions": ("goberger",),
    "gobergeâtes": ("goberger",),
    "gobergeât": ("goberger",),
    "gobergée": ("goberger",),
    "gobergées": ("goberger",),
    "gobergé": ("goberger",),
    "gobergent": ("goberger",),
    "gobergeons": ("goberger",),
    "goberge": ("goberger",),
    "gobergera": ("goberger",),
    "gobergeraient": ("goberger",),
    "gobergerai": ("goberger",),
    "gobergerais": ("goberger",),
    "gobergerait": ("goberger",),
    "gobergeras": ("goberger",),
    "gobergèrent": ("goberger",),
    "gobergerez": ("goberger",),
    "gobergeriez": ("goberger",),
    "gobergerions": ("goberger",),
    "gobergerons": ("goberger",),
    "gobergeront": ("goberger",),
    "gobergés": ("goberger",),
    "goberges": ("goberger",),
    "gobergez": ("goberger",),
    "gobergiez": ("goberger",),
    "gobergions": ("goberger",),
    "gobetaient": ("gobeter",),
    "gobetai": ("gobeter",),
    "gobetais": ("gobeter",),
    "gobetait": ("gobeter",),
    "gobeta": ("gobeter",),
    "gobetâmes": ("gobeter",),
    "gobetant": ("gobeter",),
    "gobetas": ("gobeter",),
    "gobetassent": ("gobeter",),
    "gobetasses": ("gobeter",),
    "gobetasse": ("gobeter",),
    "gobetassiez": ("gobeter",),
    "gobetassions": ("gobeter",),
    "gobetâtes": ("gobeter",),
    "gobetât": ("gobeter",),
    "gobetée": ("gobeter",),
    "gobetées": ("gobeter",),
    "gobeté": ("gobeter",),
    "gobetèrent": ("gobeter",),
    "gobetés": ("gobeter",),
    "gobetez": ("gobeter",),
    "gobetiez": ("gobeter",),
    "gobetions": ("gobeter",),
    "gobetons": ("gobeter",),
    "gobettent": ("gobeter",),
    "gobette": ("gobeter",),
    "gobettera": ("gobeter",),
    "gobetteraient": ("gobeter",),
    "gobetterai": ("gobeter",),
    "gobetterais": ("gobeter",),
    "gobetterait": ("gobeter",),
    "gobetteras": ("gobeter",),
    "gobetterez": ("gobeter",),
    "gobetteriez": ("gobeter",),
    "gobetterions": ("gobeter",),
    "gobetterons": ("gobeter",),
    "gobetteront": ("gobeter",),
    "gobettes": ("gobeter",),
    "gorgeaient": ("gorger",),
    "gorgeai": ("gorger",),
    "gorgeais": ("gorger",),
    "gorgeait": ("gorger",),
    "gorgea": ("gorger",),
    "gorgeâmes": ("gorger",),
    "gorgeant": ("gorger",),
    "gorgeas": ("gorger",),
    "gorgeassent": ("gorger",),
    "gorgeasses": ("gorger",),
    "gorgeasse": ("gorger",),
    "gorgeassiez": ("gorger",),
    "gorgeassions": ("gorger",),
    "gorgeâtes": ("gorger",),
    "gorgeât": ("gorger",),
    "gorgée": ("gorger",),
    "gorgées": ("gorger",),
    "gorgé": ("gorger",),
    "gorgent": ("gorger",),
    "gorgeons": ("gorger",),
    "gorge": ("gorger",),
    "gorgera": ("gorger",),
    "gorgeraient": ("gorger",),
    "gorgerai": ("gorger",),
    "gorgerais": ("gorger",),
    "gorgerait": ("gorger",),
    "gorgeras": ("gorger",),
    "gorgèrent": ("gorger",),
    "gorgerez": ("gorger",),
    "gorgeriez": ("gorger",),
    "gorgerions": ("gorger",),
    "gorgerons": ("gorger",),
    "gorgeront": ("gorger",),
    "gorgés": ("gorger",),
    "gorges": ("gorger",),
    "gorgez": ("gorger",),
    "gorgiez": ("gorger",),
    "gorgions": ("gorger",),
    "gougeaient": ("gouger",),
    "gougeai": ("gouger",),
    "gougeais": ("gouger",),
    "gougeait": ("gouger",),
    "gougea": ("gouger",),
    "gougeâmes": ("gouger",),
    "gougeant": ("gouger",),
    "gougeas": ("gouger",),
    "gougeassent": ("gouger",),
    "gougeasses": ("gouger",),
    "gougeasse": ("gouger",),
    "gougeassiez": ("gouger",),
    "gougeassions": ("gouger",),
    "gougeâtes": ("gouger",),
    "gougeât": ("gouger",),
    "gougée": ("gouger",),
    "gougées": ("gouger",),
    "gougé": ("gouger",),
    "gougent": ("gouger",),
    "gougeons": ("gouger",),
    "gouge": ("gouger",),
    "gougera": ("gouger",),
    "gougeraient": ("gouger",),
    "gougerai": ("gouger",),
    "gougerais": ("gouger",),
    "gougerait": ("gouger",),
    "gougeras": ("gouger",),
    "gougèrent": ("gouger",),
    "gougerez": ("gouger",),
    "gougeriez": ("gouger",),
    "gougerions": ("gouger",),
    "gougerons": ("gouger",),
    "gougeront": ("gouger",),
    "gougés": ("gouger",),
    "gouges": ("gouger",),
    "gougez": ("gouger",),
    "gougiez": ("gouger",),
    "gougions": ("gouger",),
    "grabelaient": ("grabeler",),
    "grabelai": ("grabeler",),
    "grabelais": ("grabeler",),
    "grabelait": ("grabeler",),
    "grabela": ("grabeler",),
    "grabelâmes": ("grabeler",),
    "grabelant": ("grabeler",),
    "grabelas": ("grabeler",),
    "grabelassent": ("grabeler",),
    "grabelasses": ("grabeler",),
    "grabelasse": ("grabeler",),
    "grabelassiez": ("grabeler",),
    "grabelassions": ("grabeler",),
    "grabelâtes": ("grabeler",),
    "grabelât": ("grabeler",),
    "grabelée": ("grabeler",),
    "grabelées": ("grabeler",),
    "grabelé": ("grabeler",),
    "grabelèrent": ("grabeler",),
    "grabelés": ("grabeler",),
    "grabelez": ("grabeler",),
    "grabeliez": ("grabeler",),
    "grabelions": ("grabeler",),
    "grabellent": ("grabeler",),
    "grabelle": ("grabeler",),
    "grabellera": ("grabeler",),
    "grabelleraient": ("grabeler",),
    "grabellerai": ("grabeler",),
    "grabellerais": ("grabeler",),
    "grabellerait": ("grabeler",),
    "grabelleras": ("grabeler",),
    "grabellerez": ("grabeler",),
    "grabelleriez": ("grabeler",),
    "grabellerions": ("grabeler",),
    "grabellerons": ("grabeler",),
    "grabelleront": ("grabeler",),
    "grabelles": ("grabeler",),
    "grabelons": ("grabeler",),
    "graciaient": ("gracier",),
    "graciai": ("gracier",),
    "graciais": ("gracier",),
    "graciait": ("gracier",),
    "gracia": ("gracier",),
    "graciâmes": ("gracier",),
    "graciant": ("gracier",),
    "gracias": ("gracier",),
    "graciassent": ("gracier",),
    "graciasses": ("gracier",),
    "graciasse": ("gracier",),
    "graciassiez": ("gracier",),
    "graciassions": ("gracier",),
    "graciâtes": ("gracier",),
    "graciât": ("gracier",),
    "graciée": ("gracier",),
    "graciées": ("gracier",),
    "gracié": ("gracier",),
    "gracient": ("gracier",),
    "gracie": ("gracier",),
    "graciera": ("gracier",),
    "gracieraient": ("gracier",),
    "gracierai": ("gracier",),
    "gracierais": ("gracier",),
    "gracierait": ("gracier",),
    "gracieras": ("gracier",),
    "gracièrent": ("gracier",),
    "gracierez": ("gracier",),
    "gracieriez": ("gracier",),
    "gracierions": ("gracier",),
    "gracierons": ("gracier",),
    "gracieront": ("gracier",),
    "graciés": ("gracier",),
    "gracies": ("gracier",),
    "graciez": ("gracier",),
    "graciiez": ("gracier",),
    "graciions": ("gracier",),
    "gracions": ("gracier",),
    "grandie": ("grandir",),
    "grandies": ("grandir",),
    "grandi": ("grandir",),
    "grandîmes": ("grandir",),
    "grandira": ("grandir",),
    "grandiraient": ("grandir",),
    "grandirai": ("grandir",),
    "grandirais": ("grandir",),
    "grandirait": ("grandir",),
    "grandiras": ("grandir",),
    "grandirent": ("grandir",),
    "grandirez": ("grandir",),
    "grandiriez": ("grandir",),
    "grandirions": ("grandir",),
    "grandirons": ("grandir",),
    "grandiront": ("grandir",),
    "grandis": ("grandir",),
    "grandissaient": ("grandir",),
    "grandissais": ("grandir",),
    "grandissait": ("grandir",),
    "grandissant": ("grandir",),
    "grandissent": ("grandir",),
    "grandisse": ("grandir",),
    "grandisses": ("grandir",),
    "grandissez": ("grandir",),
    "grandissiez": ("grandir",),
    "grandissions": ("grandir",),
    "grandissons": ("grandir",),
    "grandîtes": ("grandir",),
    "grandit": ("grandir",),
    "grandît": ("grandir",),
    "granoclassaient": ("granoclasser",),
    "granoclassai": ("granoclasser",),
    "granoclassais": ("granoclasser",),
    "granoclassait": ("granoclasser",),
    "granoclassa": ("granoclasser",),
    "granoclassâmes": ("granoclasser",),
    "granoclassant": ("granoclasser",),
    "granoclassas": ("granoclasser",),
    "granoclassassent": ("granoclasser",),
    "granoclassasses": ("granoclasser",),
    "granoclassasse": ("granoclasser",),
    "granoclassassiez": ("granoclasser",),
    "granoclassassions": ("granoclasser",),
    "granoclassâtes": ("granoclasser",),
    "granoclassât": ("granoclasser",),
    "granoclassée": ("granoclasser",),
    "granoclassées": ("granoclasser",),
    "granoclassé": ("granoclasser",),
    "granoclassent": ("granoclasser",),
    "granoclasse": ("granoclasser",),
    "granoclassera": ("granoclasser",),
    "granoclasseraient": ("granoclasser",),
    "granoclasserai": ("granoclasser",),
    "granoclasserais": ("granoclasser",),
    "granoclasserait": ("granoclasser",),
    "granoclasseras": ("granoclasser",),
    "granoclassèrent": ("granoclasser",),
    "granoclasserez": ("granoclasser",),
    "granoclasseriez": ("granoclasser",),
    "granoclasserions": ("granoclasser",),
    "granoclasserons": ("granoclasser",),
    "granoclasseront": ("granoclasser",),
    "granoclassés": ("granoclasser",),
    "granoclasses": ("granoclasser",),
    "granoclassez": ("granoclasser",),
    "granoclassiez": ("granoclasser",),
    "granoclassions": ("granoclasser",),
    "granoclassons": ("granoclasser",),
    "granuloclassaient": ("granuloclasser",),
    "granuloclassai": ("granuloclasser",),
    "granuloclassais": ("granuloclasser",),
    "granuloclassait": ("granuloclasser",),
    "granuloclassa": ("granuloclasser",),
    "granuloclassâmes": ("granuloclasser",),
    "granuloclassant": ("granuloclasser",),
    "granuloclassas": ("granuloclasser",),
    "granuloclassassent": ("granuloclasser",),
    "granuloclassasses": ("granuloclasser",),
    "granuloclassasse": ("granuloclasser",),
    "granuloclassassiez": ("granuloclasser",),
    "granuloclassassions": ("granuloclasser",),
    "granuloclassâtes": ("granuloclasser",),
    "granuloclassât": ("granuloclasser",),
    "granuloclassée": ("granuloclasser",),
    "granuloclassées": ("granuloclasser",),
    "granuloclassé": ("granuloclasser",),
    "granuloclassent": ("granuloclasser",),
    "granuloclasse": ("granuloclasser",),
    "granuloclassera": ("granuloclasser",),
    "granuloclasseraient": ("granuloclasser",),
    "granuloclasserai": ("granuloclasser",),
    "granuloclasserais": ("granuloclasser",),
    "granuloclasserait": ("granuloclasser",),
    "granuloclasseras": ("granuloclasser",),
    "granuloclassèrent": ("granuloclasser",),
    "granuloclasserez": ("granuloclasser",),
    "granuloclasseriez": ("granuloclasser",),
    "granuloclasserions": ("granuloclasser",),
    "granuloclasserons": ("granuloclasser",),
    "granuloclasseront": ("granuloclasser",),
    "granuloclassés": ("granuloclasser",),
    "granuloclasses": ("granuloclasser",),
    "granuloclassez": ("granuloclasser",),
    "granuloclassiez": ("granuloclasser",),
    "granuloclassions": ("granuloclasser",),
    "granuloclassons": ("granuloclasser",),
    "graphiaient": ("graphier",),
    "graphiai": ("graphier",),
    "graphiais": ("graphier",),
    "graphiait": ("graphier",),
    "graphia": ("graphier",),
    "graphiâmes": ("graphier",),
    "graphiant": ("graphier",),
    "graphias": ("graphier",),
    "graphiassent": ("graphier",),
    "graphiasses": ("graphier",),
    "graphiasse": ("graphier",),
    "graphiassiez": ("graphier",),
    "graphiassions": ("graphier",),
    "graphiâtes": ("graphier",),
    "graphiât": ("graphier",),
    "graphiée": ("graphier",),
    "graphiées": ("graphier",),
    "graphié": ("graphier",),
    "graphient": ("graphier",),
    "graphie": ("graphier",),
    "graphiera": ("graphier",),
    "graphieraient": ("graphier",),
    "graphierai": ("graphier",),
    "graphierais": ("graphier",),
    "graphierait": ("graphier",),
    "graphieras": ("graphier",),
    "graphièrent": ("graphier",),
    "graphierez": ("graphier",),
    "graphieriez": ("graphier",),
    "graphierions": ("graphier",),
    "graphierons": ("graphier",),
    "graphieront": ("graphier",),
    "graphiés": ("graphier",),
    "graphies": ("graphier",),
    "graphiez": ("graphier",),
    "graphiiez": ("graphier",),
    "graphiions": ("graphier",),
    "graphions": ("graphier",),
    "gratifiaient": ("gratifier",),
    "gratifiai": ("gratifier",),
    "gratifiais": ("gratifier",),
    "gratifiait": ("gratifier",),
    "gratifia": ("gratifier",),
    "gratifiâmes": ("gratifier",),
    "gratifiant": ("gratifier",),
    "gratifias": ("gratifier",),
    "gratifiassent": ("gratifier",),
    "gratifiasses": ("gratifier",),
    "gratifiasse": ("gratifier",),
    "gratifiassiez": ("gratifier",),
    "gratifiassions": ("gratifier",),
    "gratifiâtes": ("gratifier",),
    "gratifiât": ("gratifier",),
    "gratifiée": ("gratifier",),
    "gratifiées": ("gratifier",),
    "gratifié": ("gratifier",),
    "gratifient": ("gratifier",),
    "gratifie": ("gratifier",),
    "gratifiera": ("gratifier",),
    "gratifieraient": ("gratifier",),
    "gratifierai": ("gratifier",),
    "gratifierais": ("gratifier",),
    "gratifierait": ("gratifier",),
    "gratifieras": ("gratifier",),
    "gratifièrent": ("gratifier",),
    "gratifierez": ("gratifier",),
    "gratifieriez": ("gratifier",),
    "gratifierions": ("gratifier",),
    "gratifierons": ("gratifier",),
    "gratifieront": ("gratifier",),
    "gratifiés": ("gratifier",),
    "gratifies": ("gratifier",),
    "gratifiez": ("gratifier",),
    "gratifiiez": ("gratifier",),
    "gratifiions": ("gratifier",),
    "gratifions": ("gratifier",),
    "grattelaient": ("gratteler",),
    "grattelai": ("gratteler",),
    "grattelais": ("gratteler",),
    "grattelait": ("gratteler",),
    "grattela": ("gratteler",),
    "grattelâmes": ("gratteler",),
    "grattelant": ("gratteler",),
    "grattelas": ("gratteler",),
    "grattelassent": ("gratteler",),
    "grattelasses": ("gratteler",),
    "grattelasse": ("gratteler",),
    "grattelassiez": ("gratteler",),
    "grattelassions": ("gratteler",),
    "grattelâtes": ("gratteler",),
    "grattelât": ("gratteler",),
    "grattelée": ("gratteler",),
    "grattelées": ("gratteler",),
    "grattelé": ("gratteler",),
    "grattelèrent": ("gratteler",),
    "grattelés": ("gratteler",),
    "grattelez": ("gratteler",),
    "gratteliez": ("gratteler",),
    "grattelions": ("gratteler",),
    "grattellent": ("gratteler",),
    "grattelle": ("gratteler",),
    "grattellera": ("gratteler",),
    "grattelleraient": ("gratteler",),
    "grattellerai": ("gratteler",),
    "grattellerais": ("gratteler",),
    "grattellerait": ("gratteler",),
    "grattelleras": ("gratteler",),
    "grattellerez": ("gratteler",),
    "grattelleriez": ("gratteler",),
    "grattellerions": ("gratteler",),
    "grattellerons": ("gratteler",),
    "grattelleront": ("gratteler",),
    "grattelles": ("gratteler",),
    "grattelons": ("gratteler",),
    "gravelaient": ("graveler",),
    "gravelai": ("graveler",),
    "gravelais": ("graveler",),
    "gravelait": ("graveler",),
    "gravela": ("graveler",),
    "gravelâmes": ("graveler",),
    "gravelant": ("graveler",),
    "gravelas": ("graveler",),
    "gravelassent": ("graveler",),
    "gravelasses": ("graveler",),
    "gravelasse": ("graveler",),
    "gravelassiez": ("graveler",),
    "gravelassions": ("graveler",),
    "gravelâtes": ("graveler",),
    "gravelât": ("graveler",),
    "gravelée": ("graveler",),
    "gravelées": ("graveler",),
    "gravelé": ("graveler",),
    "gravelèrent": ("graveler",),
    "gravelés": ("graveler",),
    "gravelez": ("graveler",),
    "graveliez": ("graveler",),
    "gravelions": ("graveler",),
    "gravellent": ("graveler",),
    "gravelle": ("graveler",),
    "gravellera": ("graveler",),
    "gravelleraient": ("graveler",),
    "gravellerai": ("graveler",),
    "gravellerais": ("graveler",),
    "gravellerait": ("graveler",),
    "gravelleras": ("graveler",),
    "gravellerez": ("graveler",),
    "gravelleriez": ("graveler",),
    "gravellerions": ("graveler",),
    "gravellerons": ("graveler",),
    "gravelleront": ("graveler",),
    "gravelles": ("graveler",),
    "gravelons": ("graveler",),
    "gravie": ("gravir",),
    "gravies": ("gravir",),
    "gravi": ("gravir",),
    "gravîmes": ("gravir",),
    "gravira": ("gravir",),
    "graviraient": ("gravir",),
    "gravirai": ("gravir",),
    "gravirais": ("gravir",),
    "gravirait": ("gravir",),
    "graviras": ("gravir",),
    "gravirent": ("gravir",),
    "gravirez": ("gravir",),
    "graviriez": ("gravir",),
    "gravirions": ("gravir",),
    "gravirons": ("gravir",),
    "graviront": ("gravir",),
    "gravis": ("gravir",),
    "gravissaient": ("gravir",),
    "gravissais": ("gravir",),
    "gravissait": ("gravir",),
    "gravissant": ("gravir",),
    "gravissent": ("gravir",),
    "gravisse": ("gravir",),
    "gravisses": ("gravir",),
    "gravissez": ("gravir",),
    "gravissiez": ("gravir",),
    "gravissions": ("gravir",),
    "gravissons": ("gravir",),
    "gravîtes": ("gravir",),
    "gravit": ("gravir",),
    "gravît": ("gravir",),
    "gréaient": ("gréer",),
    "gréai": ("gréer",),
    "gréais": ("gréer",),
    "gréait": ("gréer",),
    "gréa": ("gréer",),
    "gréâmes": ("gréer",),
    "gréant": ("gréer",),
    "gréas": ("gréer",),
    "gréassent": ("gréer",),
    "gréasses": ("gréer",),
    "gréasse": ("gréer",),
    "gréassiez": ("gréer",),
    "gréassions": ("gréer",),
    "gréâtes": ("gréer",),
    "gréât": ("gréer",),
    "gréée": ("gréer",),
    "gréées": ("gréer",),
    "gréé": ("gréer",),
    "gréent": ("gréer",),
    "grée": ("gréer",),
    "gréera": ("gréer",),
    "gréeraient": ("gréer",),
    "gréerai": ("gréer",),
    "gréerais": ("gréer",),
    "gréerait": ("gréer",),
    "gréeras": ("gréer",),
    "gréèrent": ("gréer",),
    "gréerez": ("gréer",),
    "gréeriez": ("gréer",),
    "gréerions": ("gréer",),
    "gréerons": ("gréer",),
    "gréeront": ("gréer",),
    "gréés": ("gréer",),
    "grées": ("gréer",),
    "gréez": ("gréer",),
    "gréiez": ("gréer",),
    "gréions": ("gréer",),
    "gréons": ("gréer",),
    "grêlassaient": ("grêlasser",),
    "grêlassait": ("grêlasser",),
    "grêlassa": ("grêlasser",),
    "grêlassant": ("grêlasser",),
    "grêlassassent": ("grêlasser",),
    "grêlassât": ("grêlasser",),
    "grêlassé": ("grêlasser",),
    "grêlassent": ("grêlasser",),
    "grêlasse": ("grêlasser",),
    "grêlassera": ("grêlasser",),
    "grêlasseraient": ("grêlasser",),
    "grêlasserait": ("grêlasser",),
    "grêlassèrent": ("grêlasser",),
    "grêlasseront": ("grêlasser",),
    "grenelaient": ("greneler",),
    "grenelai": ("greneler",),
    "grenelais": ("greneler",),
    "grenelait": ("greneler",),
    "grenela": ("greneler",),
    "grenelâmes": ("greneler",),
    "grenelant": ("greneler",),
    "grenelas": ("greneler",),
    "grenelassent": ("greneler",),
    "grenelasses": ("greneler",),
    "grenelasse": ("greneler",),
    "grenelassiez": ("greneler",),
    "grenelassions": ("greneler",),
    "grenelâtes": ("greneler",),
    "grenelât": ("greneler",),
    "grenelée": ("greneler",),
    "grenelées": ("greneler",),
    "grenelé": ("greneler",),
    "grenelèrent": ("greneler",),
    "grenelés": ("greneler",),
    "grenelez": ("greneler",),
    "greneliez": ("greneler",),
    "grenelions": ("greneler",),
    "grenellent": ("greneler",),
    "grenelle": ("greneler",),
    "grenellera": ("greneler",),
    "grenelleraient": ("greneler",),
    "grenellerai": ("greneler",),
    "grenellerais": ("greneler",),
    "grenellerait": ("greneler",),
    "grenelleras": ("greneler",),
    "grenellerez": ("greneler",),
    "grenelleriez": ("greneler",),
    "grenellerions": ("greneler",),
    "grenellerons": ("greneler",),
    "grenelleront": ("greneler",),
    "grenelles": ("greneler",),
    "grenelons": ("greneler",),
    "grenaient": ("grener",),
    "grenai": ("grener",),
    "grenais": ("grener",),
    "grenait": ("grener",),
    "grena": ("grener",),
    "grenâmes": ("grener",),
    "grenant": ("grener",),
    "grenas": ("grener",),
    "grenassent": ("grener",),
    "grenasses": ("grener",),
    "grenasse": ("grener",),
    "grenassiez": ("grener",),
    "grenassions": ("grener",),
    "grenâtes": ("grener",),
    "grenât": ("grener",),
    "grenée": ("grener",),
    "grenées": ("grener",),
    "grené": ("grener",),
    "grènent": ("grener",),
    "grène": ("grener",),
    "grènera": ("grener",),
    "grèneraient": ("grener",),
    "grènerai": ("grener",),
    "grènerais": ("grener",),
    "grènerait": ("grener",),
    "grèneras": ("grener",),
    "grenèrent": ("grener",),
    "grènerez": ("grener",),
    "grèneriez": ("grener",),
    "grènerions": ("grener",),
    "grènerons": ("grener",),
    "grèneront": ("grener",),
    "grenés": ("grener",),
    "grènes": ("grener",),
    "grenez": ("grener",),
    "greniez": ("grener",),
    "grenions": ("grener",),
    "grenons": ("grener",),
    "grenetaient": ("greneter",),
    "grenetai": ("greneter",),
    "grenetais": ("greneter",),
    "grenetait": ("greneter",),
    "greneta": ("greneter",),
    "grenetâmes": ("greneter",),
    "grenetant": ("greneter",),
    "grenetas": ("greneter",),
    "grenetassent": ("greneter",),
    "grenetasses": ("greneter",),
    "grenetasse": ("greneter",),
    "grenetassiez": ("greneter",),
    "grenetassions": ("greneter",),
    "grenetâtes": ("greneter",),
    "grenetât": ("greneter",),
    "grenetée": ("greneter",),
    "grenetées": ("greneter",),
    "greneté": ("greneter",),
    "grenetèrent": ("greneter",),
    "grenetés": ("greneter",),
    "grenetez": ("greneter",),
    "grenetiez": ("greneter",),
    "grenetions": ("greneter",),
    "grenetons": ("greneter",),
    "grenettent": ("greneter",),
    "grenette": ("greneter",),
    "grenettera": ("greneter",),
    "grenetteraient": ("greneter",),
    "grenetterai": ("greneter",),
    "grenetterais": ("greneter",),
    "grenetterait": ("greneter",),
    "grenetteras": ("greneter",),
    "grenetterez": ("greneter",),
    "grenetteriez": ("greneter",),
    "grenetterions": ("greneter",),
    "grenetterons": ("greneter",),
    "grenetteront": ("greneter",),
    "grenettes": ("greneter",),
    "grésaient": ("gréser",),
    "grésai": ("gréser",),
    "grésais": ("gréser",),
    "grésait": ("gréser",),
    "grésa": ("gréser",),
    "grésâmes": ("gréser",),
    "grésant": ("gréser",),
    "grésas": ("gréser",),
    "grésassent": ("gréser",),
    "grésasses": ("gréser",),
    "grésasse": ("gréser",),
    "grésassiez": ("gréser",),
    "grésassions": ("gréser",),
    "grésâtes": ("gréser",),
    "grésât": ("gréser",),
    "grésée": ("gréser",),
    "grésées": ("gréser",),
    "grésé": ("gréser",),
    "grèsent": ("gréser",),
    "grèse": ("gréser",),
    "grésera": ("gréser",),
    "gréseraient": ("gréser",),
    "gréserai": ("gréser",),
    "gréserais": ("gréser",),
    "gréserait": ("gréser",),
    "gréseras": ("gréser",),
    "grésèrent": ("gréser",),
    "gréserez": ("gréser",),
    "gréseriez": ("gréser",),
    "gréserions": ("gréser",),
    "gréserons": ("gréser",),
    "gréseront": ("gréser",),
    "grésés": ("gréser",),
    "grèses": ("gréser",),
    "grésez": ("gréser",),
    "grésiez": ("gréser",),
    "grésions": ("gréser",),
    "grésons": ("gréser",),
    "grésifiaient": ("grésifier",),
    "grésifiai": ("grésifier",),
    "grésifiais": ("grésifier",),
    "grésifiait": ("grésifier",),
    "grésifia": ("grésifier",),
    "grésifiâmes": ("grésifier",),
    "grésifiant": ("grésifier",),
    "grésifias": ("grésifier",),
    "grésifiassent": ("grésifier",),
    "grésifiasses": ("grésifier",),
    "grésifiasse": ("grésifier",),
    "grésifiassiez": ("grésifier",),
    "grésifiassions": ("grésifier",),
    "grésifiâtes": ("grésifier",),
    "grésifiât": ("grésifier",),
    "grésifiée": ("grésifier",),
    "grésifiées": ("grésifier",),
    "grésifié": ("grésifier",),
    "grésifient": ("grésifier",),
    "grésifie": ("grésifier",),
    "grésifiera": ("grésifier",),
    "grésifieraient": ("grésifier",),
    "grésifierai": ("grésifier",),
    "grésifierais": ("grésifier",),
    "grésifierait": ("grésifier",),
    "grésifieras": ("grésifier",),
    "grésifièrent": ("grésifier",),
    "grésifierez": ("grésifier",),
    "grésifieriez": ("grésifier",),
    "grésifierions": ("grésifier",),
    "grésifierons": ("grésifier",),
    "grésifieront": ("grésifier",),
    "grésifiés": ("grésifier",),
    "grésifies": ("grésifier",),
    "grésifiez": ("grésifier",),
    "grésifiiez": ("grésifier",),
    "grésifiions": ("grésifier",),
    "grésifions": ("grésifier",),
    "grevaient": ("grever",),
    "grevai": ("grever",),
    "grevais": ("grever",),
    "grevait": ("grever",),
    "greva": ("grever",),
    "grevâmes": ("grever",),
    "grevant": ("grever",),
    "grevas": ("grever",),
    "grevassent": ("grever",),
    "grevasses": ("grever",),
    "grevasse": ("grever",),
    "grevassiez": ("grever",),
    "grevassions": ("grever",),
    "grevâtes": ("grever",),
    "grevât": ("grever",),
    "grevée": ("grever",),
    "grevées": ("grever",),
    "grevé": ("grever",),
    "grèvent": ("grever",),
    "grève": ("grever",),
    "grèvera": ("grever",),
    "grèveraient": ("grever",),
    "grèverai": ("grever",),
    "grèverais": ("grever",),
    "grèverait": ("grever",),
    "grèveras": ("grever",),
    "grevèrent": ("grever",),
    "grèverez": ("grever",),
    "grèveriez": ("grever",),
    "grèverions": ("grever",),
    "grèverons": ("grever",),
    "grèveront": ("grever",),
    "grevés": ("grever",),
    "grèves": ("grever",),
    "grevez": ("grever",),
    "greviez": ("grever",),
    "grevions": ("grever",),
    "grevons": ("grever",),
    "grillageaient": ("grillager",),
    "grillageai": ("grillager",),
    "grillageais": ("grillager",),
    "grillageait": ("grillager",),
    "grillagea": ("grillager",),
    "grillageâmes": ("grillager",),
    "grillageant": ("grillager",),
    "grillageas": ("grillager",),
    "grillageassent": ("grillager",),
    "grillageasses": ("grillager",),
    "grillageasse": ("grillager",),
    "grillageassiez": ("grillager",),
    "grillageassions": ("grillager",),
    "grillageâtes": ("grillager",),
    "grillageât": ("grillager",),
    "grillagée": ("grillager",),
    "grillagées": ("grillager",),
    "grillagé": ("grillager",),
    "grillagent": ("grillager",),
    "grillageons": ("grillager",),
    "grillage": ("grillager",),
    "grillagera": ("grillager",),
    "grillageraient": ("grillager",),
    "grillagerai": ("grillager",),
    "grillagerais": ("grillager",),
    "grillagerait": ("grillager",),
    "grillageras": ("grillager",),
    "grillagèrent": ("grillager",),
    "grillagerez": ("grillager",),
    "grillageriez": ("grillager",),
    "grillagerions": ("grillager",),
    "grillagerons": ("grillager",),
    "grillageront": ("grillager",),
    "grillagés": ("grillager",),
    "grillages": ("grillager",),
    "grillagez": ("grillager",),
    "grillagiez": ("grillager",),
    "grillagions": ("grillager",),
    "grimaçaient": ("grimacer",),
    "grimaçai": ("grimacer",),
    "grimaçais": ("grimacer",),
    "grimaçait": ("grimacer",),
    "grimaça": ("grimacer",),
    "grimaçâmes": ("grimacer",),
    "grimaçant": ("grimacer",),
    "grimaças": ("grimacer",),
    "grimaçassent": ("grimacer",),
    "grimaçasses": ("grimacer",),
    "grimaçasse": ("grimacer",),
    "grimaçassiez": ("grimacer",),
    "grimaçassions": ("grimacer",),
    "grimaçâtes": ("grimacer",),
    "grimaçât": ("grimacer",),
    "grimacée": ("grimacer",),
    "grimacées": ("grimacer",),
    "grimacé": ("grimacer",),
    "grimacent": ("grimacer",),
    "grimace": ("grimacer",),
    "grimacera": ("grimacer",),
    "grimaceraient": ("grimacer",),
    "grimacerai": ("grimacer",),
    "grimacerais": ("grimacer",),
    "grimacerait": ("grimacer",),
    "grimaceras": ("grimacer",),
    "grimacèrent": ("grimacer",),
    "grimacerez": ("grimacer",),
    "grimaceriez": ("grimacer",),
    "grimacerions": ("grimacer",),
    "grimacerons": ("grimacer",),
    "grimaceront": ("grimacer",),
    "grimacés": ("grimacer",),
    "grimaces": ("grimacer",),
    "grimacez": ("grimacer",),
    "grimaciez": ("grimacer",),
    "grimacions": ("grimacer",),
    "grimaçons": ("grimacer",),
    "grinçaient": ("grincer",),
    "grinçai": ("grincer",),
    "grinçais": ("grincer",),
    "grinçait": ("grincer",),
    "grinça": ("grincer",),
    "grinçâmes": ("grincer",),
    "grinçant": ("grincer",),
    "grinças": ("grincer",),
    "grinçassent": ("grincer",),
    "grinçasses": ("grincer",),
    "grinçasse": ("grincer",),
    "grinçassiez": ("grincer",),
    "grinçassions": ("grincer",),
    "grinçâtes": ("grincer",),
    "grinçât": ("grincer",),
    "grincée": ("grincer",),
    "grincées": ("grincer",),
    "grincé": ("grincer",),
    "grincent": ("grincer",),
    "grince": ("grincer",),
    "grincera": ("grincer",),
    "grinceraient": ("grincer",),
    "grincerai": ("grincer",),
    "grincerais": ("grincer",),
    "grincerait": ("grincer",),
    "grinceras": ("grincer",),
    "grincèrent": ("grincer",),
    "grincerez": ("grincer",),
    "grinceriez": ("grincer",),
    "grincerions": ("grincer",),
    "grincerons": ("grincer",),
    "grinceront": ("grincer",),
    "grincés": ("grincer",),
    "grinces": ("grincer",),
    "grincez": ("grincer",),
    "grinciez": ("grincer",),
    "grincions": ("grincer",),
    "grinçons": ("grincer",),
    "grivelaient": ("griveler",),
    "grivelai": ("griveler",),
    "grivelais": ("griveler",),
    "grivelait": ("griveler",),
    "grivela": ("griveler",),
    "grivelâmes": ("griveler",),
    "grivelant": ("griveler",),
    "grivelas": ("griveler",),
    "grivelassent": ("griveler",),
    "grivelasses": ("griveler",),
    "grivelasse": ("griveler",),
    "grivelassiez": ("griveler",),
    "grivelassions": ("griveler",),
    "grivelâtes": ("griveler",),
    "grivelât": ("griveler",),
    "grivelé": ("griveler",),
    "grivelèrent": ("griveler",),
    "grivelez": ("griveler",),
    "griveliez": ("griveler",),
    "grivelions": ("griveler",),
    "grivellent": ("griveler",),
    "grivelle": ("griveler",),
    "grivellera": ("griveler",),
    "grivelleraient": ("griveler",),
    "grivellerai": ("griveler",),
    "grivellerais": ("griveler",),
    "grivellerait": ("griveler",),
    "grivelleras": ("griveler",),
    "grivellerez": ("griveler",),
    "grivelleriez": ("griveler",),
    "grivellerions": ("griveler",),
    "grivellerons": ("griveler",),
    "grivelleront": ("griveler",),
    "grivelles": ("griveler",),
    "grivelons": ("griveler",),
    "grognassaient": ("grognasser",),
    "grognassai": ("grognasser",),
    "grognassais": ("grognasser",),
    "grognassait": ("grognasser",),
    "grognassa": ("grognasser",),
    "grognassâmes": ("grognasser",),
    "grognassant": ("grognasser",),
    "grognassas": ("grognasser",),
    "grognassassent": ("grognasser",),
    "grognassasses": ("grognasser",),
    "grognassasse": ("grognasser",),
    "grognassassiez": ("grognasser",),
    "grognassassions": ("grognasser",),
    "grognassâtes": ("grognasser",),
    "grognassât": ("grognasser",),
    "grognassé": ("grognasser",),
    "grognassent": ("grognasser",),
    "grognasse": ("grognasser",),
    "grognassera": ("grognasser",),
    "grognasseraient": ("grognasser",),
    "grognasserai": ("grognasser",),
    "grognasserais": ("grognasser",),
    "grognasserait": ("grognasser",),
    "grognasseras": ("grognasser",),
    "grognassèrent": ("grognasser",),
    "grognasserez": ("grognasser",),
    "grognasseriez": ("grognasser",),
    "grognasserions": ("grognasser",),
    "grognasserons": ("grognasser",),
    "grognasseront": ("grognasser",),
    "grognasses": ("grognasser",),
    "grognassez": ("grognasser",),
    "grognassiez": ("grognasser",),
    "grognassions": ("grognasser",),
    "grognassons": ("grognasser",),
    "grommelaient": ("grommeler",),
    "grommelai": ("grommeler",),
    "grommelais": ("grommeler",),
    "grommelait": ("grommeler",),
    "grommela": ("grommeler",),
    "grommelâmes": ("grommeler",),
    "grommelant": ("grommeler",),
    "grommelas": ("grommeler",),
    "grommelassent": ("grommeler",),
    "grommelasses": ("grommeler",),
    "grommelasse": ("grommeler",),
    "grommelassiez": ("grommeler",),
    "grommelassions": ("grommeler",),
    "grommelâtes": ("grommeler",),
    "grommelât": ("grommeler",),
    "grommelé": ("grommeler",),
    "grommelèrent": ("grommeler",),
    "grommelez": ("grommeler",),
    "grommeliez": ("grommeler",),
    "grommelions": ("grommeler",),
    "grommellent": ("grommeler",),
    "grommelle": ("grommeler",),
    "grommellera": ("grommeler",),
    "grommelleraient": ("grommeler",),
    "grommellerai": ("grommeler",),
    "grommellerais": ("grommeler",),
    "grommellerait": ("grommeler",),
    "grommelleras": ("grommeler",),
    "grommellerez": ("grommeler",),
    "grommelleriez": ("grommeler",),
    "grommellerions": ("grommeler",),
    "grommellerons": ("grommeler",),
    "grommelleront": ("grommeler",),
    "grommelles": ("grommeler",),
    "grommelons": ("grommeler",),
    "grossie": ("grossir",),
    "grossies": ("grossir",),
    "grossi": ("grossir",),
    "grossîmes": ("grossir",),
    "grossira": ("grossir",),
    "grossiraient": ("grossir",),
    "grossirai": ("grossir",),
    "grossirais": ("grossir",),
    "grossirait": ("grossir",),
    "grossiras": ("grossir",),
    "grossirent": ("grossir",),
    "grossirez": ("grossir",),
    "grossiriez": ("grossir",),
    "grossirions": ("grossir",),
    "grossirons": ("grossir",),
    "grossiront": ("grossir",),
    "grossis": ("grossir",),
    "grossissaient": ("grossir",),
    "grossissais": ("grossir",),
    "grossissait": ("grossir",),
    "grossissant": ("grossir",),
    "grossissent": ("grossir",),
    "grossisse": ("grossir",),
    "grossisses": ("grossir",),
    "grossissez": ("grossir",),
    "grossissiez": ("grossir",),
    "grossissions": ("grossir",),
    "grossissons": ("grossir",),
    "grossîtes": ("grossir",),
    "grossit": ("grossir",),
    "grossît": ("grossir",),
    "grossoient": ("grossoyer",),
    "grossoie": ("grossoyer",),
    "grossoiera": ("grossoyer",),
    "grossoieraient": ("grossoyer",),
    "grossoierai": ("grossoyer",),
    "grossoierais": ("grossoyer",),
    "grossoierait": ("grossoyer",),
    "grossoieras": ("grossoyer",),
    "grossoierez": ("grossoyer",),
    "grossoieriez": ("grossoyer",),
    "grossoierions": ("grossoyer",),
    "grossoierons": ("grossoyer",),
    "grossoieront": ("grossoyer",),
    "grossoies": ("grossoyer",),
    "grossoyaient": ("grossoyer",),
    "grossoyai": ("grossoyer",),
    "grossoyais": ("grossoyer",),
    "grossoyait": ("grossoyer",),
    "grossoya": ("grossoyer",),
    "grossoyâmes": ("grossoyer",),
    "grossoyant": ("grossoyer",),
    "grossoyas": ("grossoyer",),
    "grossoyassent": ("grossoyer",),
    "grossoyasses": ("grossoyer",),
    "grossoyasse": ("grossoyer",),
    "grossoyassiez": ("grossoyer",),
    "grossoyassions": ("grossoyer",),
    "grossoyâtes": ("grossoyer",),
    "grossoyât": ("grossoyer",),
    "grossoyée": ("grossoyer",),
    "grossoyées": ("grossoyer",),
    "grossoyé": ("grossoyer",),
    "grossoyèrent": ("grossoyer",),
    "grossoyés": ("grossoyer",),
    "grossoyez": ("grossoyer",),
    "grossoyiez": ("grossoyer",),
    "grossoyions": ("grossoyer",),
    "grossoyons": ("grossoyer",),
    "grugeaient": ("gruger",),
    "grugeai": ("gruger",),
    "grugeais": ("gruger",),
    "grugeait": ("gruger",),
    "grugea": ("gruger",),
    "grugeâmes": ("gruger",),
    "grugeant": ("gruger",),
    "grugeas": ("gruger",),
    "grugeassent": ("gruger",),
    "grugeasses": ("gruger",),
    "grugeasse": ("gruger",),
    "grugeassiez": ("gruger",),
    "grugeassions": ("gruger",),
    "grugeâtes": ("gruger",),
    "grugeât": ("gruger",),
    "grugée": ("gruger",),
    "grugées": ("gruger",),
    "grugé": ("gruger",),
    "grugent": ("gruger",),
    "grugeons": ("gruger",),
    "gruge": ("gruger",),
    "grugera": ("gruger",),
    "grugeraient": ("gruger",),
    "grugerai": ("gruger",),
    "grugerais": ("gruger",),
    "grugerait": ("gruger",),
    "grugeras": ("gruger",),
    "grugèrent": ("gruger",),
    "grugerez": ("gruger",),
    "grugeriez": ("gruger",),
    "grugerions": ("gruger",),
    "grugerons": ("gruger",),
    "grugeront": ("gruger",),
    "grugés": ("gruger",),
    "gruges": ("gruger",),
    "grugez": ("gruger",),
    "grugiez": ("gruger",),
    "grugions": ("gruger",),
    "grumelaient": ("grumeler",),
    "grumelai": ("grumeler",),
    "grumelais": ("grumeler",),
    "grumelait": ("grumeler",),
    "grumela": ("grumeler",),
    "grumelâmes": ("grumeler",),
    "grumelant": ("grumeler",),
    "grumelas": ("grumeler",),
    "grumelassent": ("grumeler",),
    "grumelasses": ("grumeler",),
    "grumelasse": ("grumeler",),
    "grumelassiez": ("grumeler",),
    "grumelassions": ("grumeler",),
    "grumelâtes": ("grumeler",),
    "grumelât": ("grumeler",),
    "grumelée": ("grumeler",),
    "grumelées": ("grumeler",),
    "grumelé": ("grumeler",),
    "grumelèrent": ("grumeler",),
    "grumelés": ("grumeler",),
    "grumelez": ("grumeler",),
    "grumeliez": ("grumeler",),
    "grumelions": ("grumeler",),
    "grumellent": ("grumeler",),
    "grumelle": ("grumeler",),
    "grumellera": ("grumeler",),
    "grumelleraient": ("grumeler",),
    "grumellerai": ("grumeler",),
    "grumellerais": ("grumeler",),
    "grumellerait": ("grumeler",),
    "grumelleras": ("grumeler",),
    "grumellerez": ("grumeler",),
    "grumelleriez": ("grumeler",),
    "grumellerions": ("grumeler",),
    "grumellerons": ("grumeler",),
    "grumelleront": ("grumeler",),
    "grumelles": ("grumeler",),
    "grumelons": ("grumeler",),
    "guéaient": ("guéer",),
    "guéai": ("guéer",),
    "guéais": ("guéer",),
    "guéait": ("guéer",),
    "guéa": ("guéer",),
    "guéâmes": ("guéer",),
    "guéant": ("guéer",),
    "guéas": ("guéer",),
    "guéassent": ("guéer",),
    "guéasses": ("guéer",),
    "guéasse": ("guéer",),
    "guéassiez": ("guéer",),
    "guéassions": ("guéer",),
    "guéâtes": ("guéer",),
    "guéât": ("guéer",),
    "guéée": ("guéer",),
    "guéées": ("guéer",),
    "guéé": ("guéer",),
    "guéent": ("guéer",),
    "guée": ("guéer",),
    "guéera": ("guéer",),
    "guéeraient": ("guéer",),
    "guéerai": ("guéer",),
    "guéerais": ("guéer",),
    "guéerait": ("guéer",),
    "guéeras": ("guéer",),
    "guéèrent": ("guéer",),
    "guéerez": ("guéer",),
    "guéeriez": ("guéer",),
    "guéerions": ("guéer",),
    "guéerons": ("guéer",),
    "guéeront": ("guéer",),
    "guéés": ("guéer",),
    "guées": ("guéer",),
    "guéez": ("guéer",),
    "guéiez": ("guéer",),
    "guéions": ("guéer",),
    "guéons": ("guéer",),
    "guérie": ("guérir",),
    "guéries": ("guérir",),
    "guéri": ("guérir",),
    "guérîmes": ("guérir",),
    "guérira": ("guérir",),
    "guériraient": ("guérir",),
    "guérirai": ("guérir",),
    "guérirais": ("guérir",),
    "guérirait": ("guérir",),
    "guériras": ("guérir",),
    "guérirent": ("guérir",),
    "guérirez": ("guérir",),
    "guéririez": ("guérir",),
    "guéririons": ("guérir",),
    "guérirons": ("guérir",),
    "guériront": ("guérir",),
    "guéris": ("guérir",),
    "guérissaient": ("guérir",),
    "guérissais": ("guérir",),
    "guérissait": ("guérir",),
    "guérissant": ("guérir",),
    "guérissent": ("guérir",),
    "guérisse": ("guérir",),
    "guérisses": ("guérir",),
    "guérissez": ("guérir",),
    "guérissiez": ("guérir",),
    "guérissions": ("guérir",),
    "guérissons": ("guérir",),
    "guérîtes": ("guérir",),
    "guérit": ("guérir",),
    "guérît": ("guérir",),
    "guerroient": ("guerroyer",),
    "guerroie": ("guerroyer",),
    "guerroiera": ("guerroyer",),
    "guerroieraient": ("guerroyer",),
    "guerroierai": ("guerroyer",),
    "guerroierais": ("guerroyer",),
    "guerroierait": ("guerroyer",),
    "guerroieras": ("guerroyer",),
    "guerroierez": ("guerroyer",),
    "guerroieriez": ("guerroyer",),
    "guerroierions": ("guerroyer",),
    "guerroierons": ("guerroyer",),
    "guerroieront": ("guerroyer",),
    "guerroies": ("guerroyer",),
    "guerroyaient": ("guerroyer",),
    "guerroyai": ("guerroyer",),
    "guerroyais": ("guerroyer",),
    "guerroyait": ("guerroyer",),
    "guerroya": ("guerroyer",),
    "guerroyâmes": ("guerroyer",),
    "guerroyant": ("guerroyer",),
    "guerroyas": ("guerroyer",),
    "guerroyassent": ("guerroyer",),
    "guerroyasses": ("guerroyer",),
    "guerroyasse": ("guerroyer",),
    "guerroyassiez": ("guerroyer",),
    "guerroyassions": ("guerroyer",),
    "guerroyâtes": ("guerroyer",),
    "guerroyât": ("guerroyer",),
    "guerroyé": ("guerroyer",),
    "guerroyèrent": ("guerroyer",),
    "guerroyez": ("guerroyer",),
    "guerroyiez": ("guerroyer",),
    "guerroyions": ("guerroyer",),
    "guerroyons": ("guerroyer",),
    "guillemetaient": ("guillemeter",),
    "guillemetai": ("guillemeter",),
    "guillemetais": ("guillemeter",),
    "guillemetait": ("guillemeter",),
    "guillemeta": ("guillemeter",),
    "guillemetâmes": ("guillemeter",),
    "guillemetant": ("guillemeter",),
    "guillemetas": ("guillemeter",),
    "guillemetassent": ("guillemeter",),
    "guillemetasses": ("guillemeter",),
    "guillemetasse": ("guillemeter",),
    "guillemetassiez": ("guillemeter",),
    "guillemetassions": ("guillemeter",),
    "guillemetâtes": ("guillemeter",),
    "guillemetât": ("guillemeter",),
    "guillemetée": ("guillemeter",),
    "guillemetées": ("guillemeter",),
    "guillemeté": ("guillemeter",),
    "guillemetèrent": ("guillemeter",),
    "guillemetés": ("guillemeter",),
    "guillemetez": ("guillemeter",),
    "guillemetiez": ("guillemeter",),
    "guillemetions": ("guillemeter",),
    "guillemetons": ("guillemeter",),
    "guillemettent": ("guillemeter",),
    "guillemette": ("guillemeter",),
    "guillemettera": ("guillemeter",),
    "guillemetteraient": ("guillemeter",),
    "guillemetterai": ("guillemeter",),
    "guillemetterais": ("guillemeter",),
    "guillemetterait": ("guillemeter",),
    "guillemetteras": ("guillemeter",),
    "guillemetterez": ("guillemeter",),
    "guillemetteriez": ("guillemeter",),
    "guillemetterions": ("guillemeter",),
    "guillemetterons": ("guillemeter",),
    "guillemetteront": ("guillemeter",),
    "guillemettes": ("guillemeter",),
    "haïe": ("haïr",),
    "haïes": ("haïr",),
    "haï": ("haïr",),
    "haïmes": ("haïr",),
    "haïra": ("haïr",),
    "haïraient": ("haïr",),
    "haïrai": ("haïr",),
    "haïrais": ("haïr",),
    "haïrait": ("haïr",),
    "haïras": ("haïr",),
    "haïrent": ("haïr",),
    "haïrez": ("haïr",),
    "haïriez": ("haïr",),
    "haïrions": ("haïr",),
    "haïrons": ("haïr",),
    "haïront": ("haïr",),
    "haïs": ("haïr",),
    "hais": ("haïr",),
    "haïssaient": ("haïr",),
    "haïssais": ("haïr",),
    "haïssait": ("haïr",),
    "haïssant": ("haïr",),
    "haïssent": ("haïr",),
    "haïsse": ("haïr",),
    "haïsses": ("haïr",),
    "haïssez": ("haïr",),
    "haïssiez": ("haïr",),
    "haïssions": ("haïr",),
    "haïssons": ("haïr",),
    "haïtes": ("haïr",),
    "haït": ("haïr",),
    "hait": ("haïr",),
    "halbrenaient": ("halbrener",),
    "halbrenai": ("halbrener",),
    "halbrenais": ("halbrener",),
    "halbrenait": ("halbrener",),
    "halbrena": ("halbrener",),
    "halbrenâmes": ("halbrener",),
    "halbrenant": ("halbrener",),
    "halbrenas": ("halbrener",),
    "halbrenassent": ("halbrener",),
    "halbrenasses": ("halbrener",),
    "halbrenasse": ("halbrener",),
    "halbrenassiez": ("halbrener",),
    "halbrenassions": ("halbrener",),
    "halbrenâtes": ("halbrener",),
    "halbrenât": ("halbrener",),
    "halbrenée": ("halbrener",),
    "halbrenées": ("halbrener",),
    "halbrené": ("halbrener",),
    "halbrènent": ("halbrener",),
    "halbrène": ("halbrener",),
    "halbrènera": ("halbrener",),
    "halbrèneraient": ("halbrener",),
    "halbrènerai": ("halbrener",),
    "halbrènerais": ("halbrener",),
    "halbrènerait": ("halbrener",),
    "halbrèneras": ("halbrener",),
    "halbrenèrent": ("halbrener",),
    "halbrènerez": ("halbrener",),
    "halbrèneriez": ("halbrener",),
    "halbrènerions": ("halbrener",),
    "halbrènerons": ("halbrener",),
    "halbrèneront": ("halbrener",),
    "halbrenés": ("halbrener",),
    "halbrènes": ("halbrener",),
    "halbrenez": ("halbrener",),
    "halbreniez": ("halbrener",),
    "halbrenions": ("halbrener",),
    "halbrenons": ("halbrener",),
    "halenaient": ("halener",),
    "halenai": ("halener",),
    "halenais": ("halener",),
    "halenait": ("halener",),
    "halena": ("halener",),
    "halenâmes": ("halener",),
    "halenant": ("halener",),
    "halenas": ("halener",),
    "halenassent": ("halener",),
    "halenasses": ("halener",),
    "halenasse": ("halener",),
    "halenassiez": ("halener",),
    "halenassions": ("halener",),
    "halenâtes": ("halener",),
    "halenât": ("halener",),
    "halenée": ("halener",),
    "halenées": ("halener",),
    "halené": ("halener",),
    "halènent": ("halener",),
    "halène": ("halener",),
    "halènera": ("halener",),
    "halèneraient": ("halener",),
    "halènerai": ("halener",),
    "halènerais": ("halener",),
    "halènerait": ("halener",),
    "halèneras": ("halener",),
    "halenèrent": ("halener",),
    "halènerez": ("halener",),
    "halèneriez": ("halener",),
    "halènerions": ("halener",),
    "halènerons": ("halener",),
    "halèneront": ("halener",),
    "halenés": ("halener",),
    "halènes": ("halener",),
    "halenez": ("halener",),
    "haleniez": ("halener",),
    "halenions": ("halener",),
    "halenons": ("halener",),
    "haletaient": ("haleter",),
    "haletai": ("haleter",),
    "haletais": ("haleter",),
    "haletait": ("haleter",),
    "haleta": ("haleter",),
    "haletâmes": ("haleter",),
    "haletant": ("haleter",),
    "haletas": ("haleter",),
    "haletassent": ("haleter",),
    "haletasses": ("haleter",),
    "haletasse": ("haleter",),
    "haletassiez": ("haleter",),
    "haletassions": ("haleter",),
    "haletâtes": ("haleter",),
    "haletât": ("haleter",),
    "haleté": ("haleter",),
    "halètent": ("haleter",),
    "halète": ("haleter",),
    "halètera": ("haleter",),
    "halèteraient": ("haleter",),
    "halèterai": ("haleter",),
    "halèterais": ("haleter",),
    "halèterait": ("haleter",),
    "halèteras": ("haleter",),
    "haletèrent": ("haleter",),
    "halèterez": ("haleter",),
    "halèteriez": ("haleter",),
    "halèterions": ("haleter",),
    "halèterons": ("haleter",),
    "halèteront": ("haleter",),
    "halètes": ("haleter",),
    "haletez": ("haleter",),
    "haletiez": ("haleter",),
    "haletions": ("haleter",),
    "haletons": ("haleter",),
    "halogénaient": ("halogéner",),
    "halogénai": ("halogéner",),
    "halogénais": ("halogéner",),
    "halogénait": ("halogéner",),
    "halogéna": ("halogéner",),
    "halogénâmes": ("halogéner",),
    "halogénant": ("halogéner",),
    "halogénas": ("halogéner",),
    "halogénassent": ("halogéner",),
    "halogénasses": ("halogéner",),
    "halogénasse": ("halogéner",),
    "halogénassiez": ("halogéner",),
    "halogénassions": ("halogéner",),
    "halogénâtes": ("halogéner",),
    "halogénât": ("halogéner",),
    "halogénée": ("halogéner",),
    "halogénées": ("halogéner",),
    "halogéné": ("halogéner",),
    "halogènent": ("halogéner",),
    "halogène": ("halogéner",),
    "halogénera": ("halogéner",),
    "halogéneraient": ("halogéner",),
    "halogénerai": ("halogéner",),
    "halogénerais": ("halogéner",),
    "halogénerait": ("halogéner",),
    "halogéneras": ("halogéner",),
    "halogénèrent": ("halogéner",),
    "halogénerez": ("halogéner",),
    "halogéneriez": ("halogéner",),
    "halogénerions": ("halogéner",),
    "halogénerons": ("halogéner",),
    "halogéneront": ("halogéner",),
    "halogénés": ("halogéner",),
    "halogènes": ("halogéner",),
    "halogénez": ("halogéner",),
    "halogéniez": ("halogéner",),
    "halogénions": ("halogéner",),
    "halogénons": ("halogéner",),
    "harassaient": ("harasser",),
    "harassai": ("harasser",),
    "harassais": ("harasser",),
    "harassait": ("harasser",),
    "harassa": ("harasser",),
    "harassâmes": ("harasser",),
    "harassant": ("harasser",),
    "harassas": ("harasser",),
    "harassassent": ("harasser",),
    "harassasses": ("harasser",),
    "harassasse": ("harasser",),
    "harassassiez": ("harasser",),
    "harassassions": ("harasser",),
    "harassâtes": ("harasser",),
    "harassât": ("harasser",),
    "harassée": ("harasser",),
    "harassées": ("harasser",),
    "harassé": ("harasser",),
    "harassent": ("harasser",),
    "harasse": ("harasser",),
    "harassera": ("harasser",),
    "harasseraient": ("harasser",),
    "harasserai": ("harasser",),
    "harasserais": ("harasser",),
    "harasserait": ("harasser",),
    "harasseras": ("harasser",),
    "harassèrent": ("harasser",),
    "harasserez": ("harasser",),
    "harasseriez": ("harasser",),
    "harasserions": ("harasser",),
    "harasserons": ("harasser",),
    "harasseront": ("harasser",),
    "harassés": ("harasser",),
    "harasses": ("harasser",),
    "harassez": ("harasser",),
    "harassiez": ("harasser",),
    "harassions": ("harasser",),
    "harassons": ("harasser",),
    "harcelaient": ("harceler",),
    "harcelai": ("harceler",),
    "harcelais": ("harceler",),
    "harcelait": ("harceler",),
    "harcela": ("harceler",),
    "harcelâmes": ("harceler",),
    "harcelant": ("harceler",),
    "harcelas": ("harceler",),
    "harcelassent": ("harceler",),
    "harcelasses": ("harceler",),
    "harcelasse": ("harceler",),
    "harcelassiez": ("harceler",),
    "harcelassions": ("harceler",),
    "harcelâtes": ("harceler",),
    "harcelât": ("harceler",),
    "harcelée": ("harceler",),
    "harcelées": ("harceler",),
    "harcelé": ("harceler",),
    "harcèlent": ("harceler",),
    "harcèle": ("harceler",),
    "harcèlera": ("harceler",),
    "harcèleraient": ("harceler",),
    "harcèlerai": ("harceler",),
    "harcèlerais": ("harceler",),
    "harcèlerait": ("harceler",),
    "harcèleras": ("harceler",),
    "harcelèrent": ("harceler",),
    "harcèlerez": ("harceler",),
    "harcèleriez": ("harceler",),
    "harcèlerions": ("harceler",),
    "harcèlerons": ("harceler",),
    "harcèleront": ("harceler",),
    "harcelés": ("harceler",),
    "harcèles": ("harceler",),
    "harcelez": ("harceler",),
    "harceliez": ("harceler",),
    "harcelions": ("harceler",),
    "harcelons": ("harceler",),
    "harmoniaient": ("harmonier",),
    "harmoniai": ("harmonier",),
    "harmoniais": ("harmonier",),
    "harmoniait": ("harmonier",),
    "harmonia": ("harmonier",),
    "harmoniâmes": ("harmonier",),
    "harmoniant": ("harmonier",),
    "harmonias": ("harmonier",),
    "harmoniassent": ("harmonier",),
    "harmoniasses": ("harmonier",),
    "harmoniasse": ("harmonier",),
    "harmoniassiez": ("harmonier",),
    "harmoniassions": ("harmonier",),
    "harmoniâtes": ("harmonier",),
    "harmoniât": ("harmonier",),
    "harmoniée": ("harmonier",),
    "harmoniées": ("harmonier",),
    "harmonié": ("harmonier",),
    "harmonient": ("harmonier",),
    "harmonie": ("harmonier",),
    "harmoniera": ("harmonier",),
    "harmonieraient": ("harmonier",),
    "harmonierai": ("harmonier",),
    "harmonierais": ("harmonier",),
    "harmonierait": ("harmonier",),
    "harmonieras": ("harmonier",),
    "harmonièrent": ("harmonier",),
    "harmonierez": ("harmonier",),
    "harmonieriez": ("harmonier",),
    "harmonierions": ("harmonier",),
    "harmonierons": ("harmonier",),
    "harmonieront": ("harmonier",),
    "harmoniés": ("harmonier",),
    "harmonies": ("harmonier",),
    "harmoniez": ("harmonier",),
    "harmoniiez": ("harmonier",),
    "harmoniions": ("harmonier",),
    "harmonions": ("harmonier",),
    "hâtaient": ("hâter",),
    "hâtai": ("hâter",),
    "hâtais": ("hâter",),
    "hâtait": ("hâter",),
    "hâta": ("hâter",),
    "hâtâmes": ("hâter",),
    "hâtant": ("hâter",),
    "hâtas": ("hâter",),
    "hâtassent": ("hâter",),
    "hâtasses": ("hâter",),
    "hâtasse": ("hâter",),
    "hâtassiez": ("hâter",),
    "hâtassions": ("hâter",),
    "hâtâtes": ("hâter",),
    "hâtât": ("hâter",),
    "hâtée": ("hâter",),
    "hâtées": ("hâter",),
    "hâté": ("hâter",),
    "hâtent": ("hâter",),
    "hâte": ("hâter",),
    "hâtera": ("hâter",),
    "hâteraient": ("hâter",),
    "hâterai": ("hâter",),
    "hâterais": ("hâter",),
    "hâterait": ("hâter",),
    "hâteras": ("hâter",),
    "hâtèrent": ("hâter",),
    "hâterez": ("hâter",),
    "hâteriez": ("hâter",),
    "hâterions": ("hâter",),
    "hâterons": ("hâter",),
    "hâteront": ("hâter",),
    "hâtés": ("hâter",),
    "hâtes": ("hâter",),
    "hâtez": ("hâter",),
    "hâtiez": ("hâter",),
    "hâtions": ("hâter",),
    "hâtons": ("hâter",),
    "havie": ("havir",),
    "havies": ("havir",),
    "havi": ("havir",),
    "havîmes": ("havir",),
    "havira": ("havir",),
    "haviraient": ("havir",),
    "havirai": ("havir",),
    "havirais": ("havir",),
    "havirait": ("havir",),
    "haviras": ("havir",),
    "havirent": ("havir",),
    "havirez": ("havir",),
    "haviriez": ("havir",),
    "havirions": ("havir",),
    "havirons": ("havir",),
    "haviront": ("havir",),
    "havis": ("havir",),
    "havissaient": ("havir",),
    "havissais": ("havir",),
    "havissait": ("havir",),
    "havissant": ("havir",),
    "havissent": ("havir",),
    "havisse": ("havir",),
    "havisses": ("havir",),
    "havissez": ("havir",),
    "havissiez": ("havir",),
    "havissions": ("havir",),
    "havissons": ("havir",),
    "havîtes": ("havir",),
    "havit": ("havir",),
    "havît": ("havir",),
    "hébergeaient": ("héberger",),
    "hébergeai": ("héberger",),
    "hébergeais": ("héberger",),
    "hébergeait": ("héberger",),
    "hébergea": ("héberger",),
    "hébergeâmes": ("héberger",),
    "hébergeant": ("héberger",),
    "hébergeas": ("héberger",),
    "hébergeassent": ("héberger",),
    "hébergeasses": ("héberger",),
    "hébergeasse": ("héberger",),
    "hébergeassiez": ("héberger",),
    "hébergeassions": ("héberger",),
    "hébergeâtes": ("héberger",),
    "hébergeât": ("héberger",),
    "hébergée": ("héberger",),
    "hébergées": ("héberger",),
    "hébergé": ("héberger",),
    "hébergent": ("héberger",),
    "hébergeons": ("héberger",),
    "héberge": ("héberger",),
    "hébergera": ("héberger",),
    "hébergeraient": ("héberger",),
    "hébergerai": ("héberger",),
    "hébergerais": ("héberger",),
    "hébergerait": ("héberger",),
    "hébergeras": ("héberger",),
    "hébergèrent": ("héberger",),
    "hébergerez": ("héberger",),
    "hébergeriez": ("héberger",),
    "hébergerions": ("héberger",),
    "hébergerons": ("héberger",),
    "hébergeront": ("héberger",),
    "hébergés": ("héberger",),
    "héberges": ("héberger",),
    "hébergez": ("héberger",),
    "hébergiez": ("héberger",),
    "hébergions": ("héberger",),
    "hébétaient": ("hébéter",),
    "hébétai": ("hébéter",),
    "hébétais": ("hébéter",),
    "hébétait": ("hébéter",),
    "hébéta": ("hébéter",),
    "hébétâmes": ("hébéter",),
    "hébétant": ("hébéter",),
    "hébétas": ("hébéter",),
    "hébétassent": ("hébéter",),
    "hébétasses": ("hébéter",),
    "hébétasse": ("hébéter",),
    "hébétassiez": ("hébéter",),
    "hébétassions": ("hébéter",),
    "hébétâtes": ("hébéter",),
    "hébétât": ("hébéter",),
    "hébétée": ("hébéter",),
    "hébétées": ("hébéter",),
    "hébété": ("hébéter",),
    "hébètent": ("hébéter",),
    "hébète": ("hébéter",),
    "hébétera": ("hébéter",),
    "hébéteraient": ("hébéter",),
    "hébéterai": ("hébéter",),
    "hébéterais": ("hébéter",),
    "hébéterait": ("hébéter",),
    "hébéteras": ("hébéter",),
    "hébétèrent": ("hébéter",),
    "hébéterez": ("hébéter",),
    "hébéteriez": ("hébéter",),
    "hébéterions": ("hébéter",),
    "hébéterons": ("hébéter",),
    "hébéteront": ("hébéter",),
    "hébétés": ("hébéter",),
    "hébètes": ("hébéter",),
    "hébétez": ("hébéter",),
    "hébétiez": ("hébéter",),
    "hébétions": ("hébéter",),
    "hébétons": ("hébéter",),
    "hélaient": ("héler",),
    "hélai": ("héler",),
    "hélais": ("héler",),
    "hélait": ("héler",),
    "héla": ("héler",),
    "hélâmes": ("héler",),
    "hélant": ("héler",),
    "hélas": ("héler",),
    "hélassent": ("héler",),
    "hélasses": ("héler",),
    "hélasse": ("héler",),
    "hélassiez": ("héler",),
    "hélassions": ("héler",),
    "hélâtes": ("héler",),
    "hélât": ("héler",),
    "hélée": ("héler",),
    "hélées": ("héler",),
    "hélé": ("héler",),
    "hèlent": ("héler",),
    "hèle": ("héler",),
    "hélera": ("héler",),
    "héleraient": ("héler",),
    "hélerai": ("héler",),
    "hélerais": ("héler",),
    "hélerait": ("héler",),
    "héleras": ("héler",),
    "hélèrent": ("héler",),
    "hélerez": ("héler",),
    "héleriez": ("héler",),
    "hélerions": ("héler",),
    "hélerons": ("héler",),
    "héleront": ("héler",),
    "hélés": ("héler",),
    "hèles": ("héler",),
    "hélez": ("héler",),
    "héliez": ("héler",),
    "hélions": ("héler",),
    "hélons": ("héler",),
    "henni": ("hennir",),
    "hennîmes": ("hennir",),
    "hennira": ("hennir",),
    "henniraient": ("hennir",),
    "hennirai": ("hennir",),
    "hennirais": ("hennir",),
    "hennirait": ("hennir",),
    "henniras": ("hennir",),
    "hennirent": ("hennir",),
    "hennirez": ("hennir",),
    "henniriez": ("hennir",),
    "hennirions": ("hennir",),
    "hennirons": ("hennir",),
    "henniront": ("hennir",),
    "hennis": ("hennir",),
    "hennissaient": ("hennir",),
    "hennissais": ("hennir",),
    "hennissait": ("hennir",),
    "hennissant": ("hennir",),
    "hennissent": ("hennir",),
    "hennisse": ("hennir",),
    "hennisses": ("hennir",),
    "hennissez": ("hennir",),
    "hennissiez": ("hennir",),
    "hennissions": ("hennir",),
    "hennissons": ("hennir",),
    "hennîtes": ("hennir",),
    "hennit": ("hennir",),
    "hennît": ("hennir",),
    "herbageaient": ("herbager",),
    "herbageai": ("herbager",),
    "herbageais": ("herbager",),
    "herbageait": ("herbager",),
    "herbagea": ("herbager",),
    "herbageâmes": ("herbager",),
    "herbageant": ("herbager",),
    "herbageas": ("herbager",),
    "herbageassent": ("herbager",),
    "herbageasses": ("herbager",),
    "herbageasse": ("herbager",),
    "herbageassiez": ("herbager",),
    "herbageassions": ("herbager",),
    "herbageâtes": ("herbager",),
    "herbageât": ("herbager",),
    "herbagée": ("herbager",),
    "herbagées": ("herbager",),
    "herbagé": ("herbager",),
    "herbagent": ("herbager",),
    "herbageons": ("herbager",),
    "herbage": ("herbager",),
    "herbagera": ("herbager",),
    "herbageraient": ("herbager",),
    "herbagerai": ("herbager",),
    "herbagerais": ("herbager",),
    "herbagerait": ("herbager",),
    "herbageras": ("herbager",),
    "herbagèrent": ("herbager",),
    "herbagerez": ("herbager",),
    "herbageriez": ("herbager",),
    "herbagerions": ("herbager",),
    "herbagerons": ("herbager",),
    "herbageront": ("herbager",),
    "herbagés": ("herbager",),
    "herbages": ("herbager",),
    "herbagez": ("herbager",),
    "herbagiez": ("herbager",),
    "herbagions": ("herbager",),
    "historiaient": ("historier",),
    "historiai": ("historier",),
    "historiais": ("historier",),
    "historiait": ("historier",),
    "historia": ("historier",),
    "historiâmes": ("historier",),
    "historiant": ("historier",),
    "historias": ("historier",),
    "historiassent": ("historier",),
    "historiasses": ("historier",),
    "historiasse": ("historier",),
    "historiassiez": ("historier",),
    "historiassions": ("historier",),
    "historiâtes": ("historier",),
    "historiât": ("historier",),
    "historiée": ("historier",),
    "historiées": ("historier",),
    "historié": ("historier",),
    "historient": ("historier",),
    "historie": ("historier",),
    "historiera": ("historier",),
    "historieraient": ("historier",),
    "historierai": ("historier",),
    "historierais": ("historier",),
    "historierait": ("historier",),
    "historieras": ("historier",),
    "historièrent": ("historier",),
    "historierez": ("historier",),
    "historieriez": ("historier",),
    "historierions": ("historier",),
    "historierons": ("historier",),
    "historieront": ("historier",),
    "historiés": ("historier",),
    "histories": ("historier",),
    "historiez": ("historier",),
    "historiiez": ("historier",),
    "historiions": ("historier",),
    "historions": ("historier",),
    "holographiaient": ("holographier",),
    "holographiai": ("holographier",),
    "holographiais": ("holographier",),
    "holographiait": ("holographier",),
    "holographia": ("holographier",),
    "holographiâmes": ("holographier",),
    "holographiant": ("holographier",),
    "holographias": ("holographier",),
    "holographiassent": ("holographier",),
    "holographiasses": ("holographier",),
    "holographiasse": ("holographier",),
    "holographiassiez": ("holographier",),
    "holographiassions": ("holographier",),
    "holographiâtes": ("holographier",),
    "holographiât": ("holographier",),
    "holographiée": ("holographier",),
    "holographiées": ("holographier",),
    "holographié": ("holographier",),
    "holographient": ("holographier",),
    "holographie": ("holographier",),
    "holographiera": ("holographier",),
    "holographieraient": ("holographier",),
    "holographierai": ("holographier",),
    "holographierais": ("holographier",),
    "holographierait": ("holographier",),
    "holographieras": ("holographier",),
    "holographièrent": ("holographier",),
    "holographierez": ("holographier",),
    "holographieriez": ("holographier",),
    "holographierions": ("holographier",),
    "holographierons": ("holographier",),
    "holographieront": ("holographier",),
    "holographiés": ("holographier",),
    "holographies": ("holographier",),
    "holographiez": ("holographier",),
    "holographiiez": ("holographier",),
    "holographiions": ("holographier",),
    "holographions": ("holographier",),
    "homogénéifiaient": ("homogénéifier",),
    "homogénéifiai": ("homogénéifier",),
    "homogénéifiais": ("homogénéifier",),
    "homogénéifiait": ("homogénéifier",),
    "homogénéifia": ("homogénéifier",),
    "homogénéifiâmes": ("homogénéifier",),
    "homogénéifiant": ("homogénéifier",),
    "homogénéifias": ("homogénéifier",),
    "homogénéifiassent": ("homogénéifier",),
    "homogénéifiasses": ("homogénéifier",),
    "homogénéifiasse": ("homogénéifier",),
    "homogénéifiassiez": ("homogénéifier",),
    "homogénéifiassions": ("homogénéifier",),
    "homogénéifiâtes": ("homogénéifier",),
    "homogénéifiât": ("homogénéifier",),
    "homogénéifiée": ("homogénéifier",),
    "homogénéifiées": ("homogénéifier",),
    "homogénéifié": ("homogénéifier",),
    "homogénéifient": ("homogénéifier",),
    "homogénéifie": ("homogénéifier",),
    "homogénéifiera": ("homogénéifier",),
    "homogénéifieraient": ("homogénéifier",),
    "homogénéifierai": ("homogénéifier",),
    "homogénéifierais": ("homogénéifier",),
    "homogénéifierait": ("homogénéifier",),
    "homogénéifieras": ("homogénéifier",),
    "homogénéifièrent": ("homogénéifier",),
    "homogénéifierez": ("homogénéifier",),
    "homogénéifieriez": ("homogénéifier",),
    "homogénéifierions": ("homogénéifier",),
    "homogénéifierons": ("homogénéifier",),
    "homogénéifieront": ("homogénéifier",),
    "homogénéifiés": ("homogénéifier",),
    "homogénéifies": ("homogénéifier",),
    "homogénéifiez": ("homogénéifier",),
    "homogénéifiiez": ("homogénéifier",),
    "homogénéifiions": ("homogénéifier",),
    "homogénéifions": ("homogénéifier",),
    "hongroient": ("hongroyer",),
    "hongroie": ("hongroyer",),
    "hongroiera": ("hongroyer",),
    "hongroieraient": ("hongroyer",),
    "hongroierai": ("hongroyer",),
    "hongroierais": ("hongroyer",),
    "hongroierait": ("hongroyer",),
    "hongroieras": ("hongroyer",),
    "hongroierez": ("hongroyer",),
    "hongroieriez": ("hongroyer",),
    "hongroierions": ("hongroyer",),
    "hongroierons": ("hongroyer",),
    "hongroieront": ("hongroyer",),
    "hongroies": ("hongroyer",),
    "hongroyaient": ("hongroyer",),
    "hongroyai": ("hongroyer",),
    "hongroyais": ("hongroyer",),
    "hongroyait": ("hongroyer",),
    "hongroya": ("hongroyer",),
    "hongroyâmes": ("hongroyer",),
    "hongroyant": ("hongroyer",),
    "hongroyas": ("hongroyer",),
    "hongroyassent": ("hongroyer",),
    "hongroyasses": ("hongroyer",),
    "hongroyasse": ("hongroyer",),
    "hongroyassiez": ("hongroyer",),
    "hongroyassions": ("hongroyer",),
    "hongroyâtes": ("hongroyer",),
    "hongroyât": ("hongroyer",),
    "hongroyée": ("hongroyer",),
    "hongroyées": ("hongroyer",),
    "hongroyé": ("hongroyer",),
    "hongroyèrent": ("hongroyer",),
    "hongroyés": ("hongroyer",),
    "hongroyez": ("hongroyer",),
    "hongroyiez": ("hongroyer",),
    "hongroyions": ("hongroyer",),
    "hongroyons": ("hongroyer",),
    "honnie": ("honnir",),
    "honnies": ("honnir",),
    "honni": ("honnir",),
    "honnîmes": ("honnir",),
    "honnira": ("honnir",),
    "honniraient": ("honnir",),
    "honnirai": ("honnir",),
    "honnirais": ("honnir",),
    "honnirait": ("honnir",),
    "honniras": ("honnir",),
    "honnirent": ("honnir",),
    "honnirez": ("honnir",),
    "honniriez": ("honnir",),
    "honnirions": ("honnir",),
    "honnirons": ("honnir",),
    "honniront": ("honnir",),
    "honnis": ("honnir",),
    "honnissaient": ("honnir",),
    "honnissais": ("honnir",),
    "honnissait": ("honnir",),
    "honnissant": ("honnir",),
    "honnissent": ("honnir",),
    "honnisse": ("honnir",),
    "honnisses": ("honnir",),
    "honnissez": ("honnir",),
    "honnissiez": ("honnir",),
    "honnissions": ("honnir",),
    "honnissons": ("honnir",),
    "honnîtes": ("honnir",),
    "honnit": ("honnir",),
    "honnît": ("honnir",),
    "hoquetaient": ("hoqueter",),
    "hoquetai": ("hoqueter",),
    "hoquetais": ("hoqueter",),
    "hoquetait": ("hoqueter",),
    "hoqueta": ("hoqueter",),
    "hoquetâmes": ("hoqueter",),
    "hoquetant": ("hoqueter",),
    "hoquetas": ("hoqueter",),
    "hoquetassent": ("hoqueter",),
    "hoquetasses": ("hoqueter",),
    "hoquetasse": ("hoqueter",),
    "hoquetassiez": ("hoqueter",),
    "hoquetassions": ("hoqueter",),
    "hoquetâtes": ("hoqueter",),
    "hoquetât": ("hoqueter",),
    "hoquetée": ("hoqueter",),
    "hoquetées": ("hoqueter",),
    "hoqueté": ("hoqueter",),
    "hoquètent": ("hoqueter",),
    "hoquète": ("hoqueter",),
    "hoquètera": ("hoqueter",),
    "hoquèteraient": ("hoqueter",),
    "hoquèterai": ("hoqueter",),
    "hoquèterais": ("hoqueter",),
    "hoquèterait": ("hoqueter",),
    "hoquèteras": ("hoqueter",),
    "hoquetèrent": ("hoqueter",),
    "hoquèterez": ("hoqueter",),
    "hoquèteriez": ("hoqueter",),
    "hoquèterions": ("hoqueter",),
    "hoquèterons": ("hoqueter",),
    "hoquèteront": ("hoqueter",),
    "hoquetés": ("hoqueter",),
    "hoquètes": ("hoqueter",),
    "hoquetez": ("hoqueter",),
    "hoquetiez": ("hoqueter",),
    "hoquetions": ("hoqueter",),
    "hoquetons": ("hoqueter",),
    "horrifiaient": ("horrifier",),
    "horrifiai": ("horrifier",),
    "horrifiais": ("horrifier",),
    "horrifiait": ("horrifier",),
    "horrifia": ("horrifier",),
    "horrifiâmes": ("horrifier",),
    "horrifiant": ("horrifier",),
    "horrifias": ("horrifier",),
    "horrifiassent": ("horrifier",),
    "horrifiasses": ("horrifier",),
    "horrifiasse": ("horrifier",),
    "horrifiassiez": ("horrifier",),
    "horrifiassions": ("horrifier",),
    "horrifiâtes": ("horrifier",),
    "horrifiât": ("horrifier",),
    "horrifiée": ("horrifier",),
    "horrifiées": ("horrifier",),
    "horrifié": ("horrifier",),
    "horrifient": ("horrifier",),
    "horrifie": ("horrifier",),
    "horrifiera": ("horrifier",),
    "horrifieraient": ("horrifier",),
    "horrifierai": ("horrifier",),
    "horrifierais": ("horrifier",),
    "horrifierait": ("horrifier",),
    "horrifieras": ("horrifier",),
    "horrifièrent": ("horrifier",),
    "horrifierez": ("horrifier",),
    "horrifieriez": ("horrifier",),
    "horrifierions": ("horrifier",),
    "horrifierons": ("horrifier",),
    "horrifieront": ("horrifier",),
    "horrifiés": ("horrifier",),
    "horrifies": ("horrifier",),
    "horrifiez": ("horrifier",),
    "horrifiiez": ("horrifier",),
    "horrifiions": ("horrifier",),
    "horrifions": ("horrifier",),
    "houillifiaient": ("houillifier",),
    "houillifiai": ("houillifier",),
    "houillifiais": ("houillifier",),
    "houillifiait": ("houillifier",),
    "houillifia": ("houillifier",),
    "houillifiâmes": ("houillifier",),
    "houillifiant": ("houillifier",),
    "houillifias": ("houillifier",),
    "houillifiassent": ("houillifier",),
    "houillifiasses": ("houillifier",),
    "houillifiasse": ("houillifier",),
    "houillifiassiez": ("houillifier",),
    "houillifiassions": ("houillifier",),
    "houillifiâtes": ("houillifier",),
    "houillifiât": ("houillifier",),
    "houillifiée": ("houillifier",),
    "houillifiées": ("houillifier",),
    "houillifié": ("houillifier",),
    "houillifient": ("houillifier",),
    "houillifie": ("houillifier",),
    "houillifiera": ("houillifier",),
    "houillifieraient": ("houillifier",),
    "houillifierai": ("houillifier",),
    "houillifierais": ("houillifier",),
    "houillifierait": ("houillifier",),
    "houillifieras": ("houillifier",),
    "houillifièrent": ("houillifier",),
    "houillifierez": ("houillifier",),
    "houillifieriez": ("houillifier",),
    "houillifierions": ("houillifier",),
    "houillifierons": ("houillifier",),
    "houillifieront": ("houillifier",),
    "houillifiés": ("houillifier",),
    "houillifies": ("houillifier",),
    "houillifiez": ("houillifier",),
    "houillifiiez": ("houillifier",),
    "houillifiions": ("houillifier",),
    "houillifions": ("houillifier",),
    "hourdie": ("hourdir",),
    "hourdies": ("hourdir",),
    "hourdi": ("hourdir",),
    "hourdîmes": ("hourdir",),
    "hourdira": ("hourdir",),
    "hourdiraient": ("hourdir",),
    "hourdirai": ("hourdir",),
    "hourdirais": ("hourdir",),
    "hourdirait": ("hourdir",),
    "hourdiras": ("hourdir",),
    "hourdirent": ("hourdir",),
    "hourdirez": ("hourdir",),
    "hourdiriez": ("hourdir",),
    "hourdirions": ("hourdir",),
    "hourdirons": ("hourdir",),
    "hourdiront": ("hourdir",),
    "hourdis": ("hourdir",),
    "hourdissaient": ("hourdir",),
    "hourdissais": ("hourdir",),
    "hourdissait": ("hourdir",),
    "hourdissant": ("hourdir",),
    "hourdissent": ("hourdir",),
    "hourdisse": ("hourdir",),
    "hourdisses": ("hourdir",),
    "hourdissez": ("hourdir",),
    "hourdissiez": ("hourdir",),
    "hourdissions": ("hourdir",),
    "hourdissons": ("hourdir",),
    "hourdîtes": ("hourdir",),
    "hourdit": ("hourdir",),
    "hourdît": ("hourdir",),
    "hui": ("huir",),
    "huîmes": ("huir",),
    "huira": ("huir",),
    "huiraient": ("huir",),
    "huirai": ("huir",),
    "huirais": ("huir",),
    "huirait": ("huir",),
    "huiras": ("huir",),
    "huirent": ("huir",),
    "huirez": ("huir",),
    "huiriez": ("huir",),
    "huirions": ("huir",),
    "huirons": ("huir",),
    "huiront": ("huir",),
    "huis": ("huir",),
    "huissaient": ("huir",),
    "huissais": ("huir",),
    "huissait": ("huir",),
    "huissant": ("huir",),
    "huissent": ("huir",),
    "huisse": ("huir",),
    "huisses": ("huir",),
    "huissez": ("huir",),
    "huissiez": ("huir",),
    "huissions": ("huir",),
    "huissons": ("huir",),
    "huîtes": ("huir",),
    "huit": ("huir",),
    "huît": ("huir",),
    "humidifiaient": ("humidifier",),
    "humidifiai": ("humidifier",),
    "humidifiais": ("humidifier",),
    "humidifiait": ("humidifier",),
    "humidifia": ("humidifier",),
    "humidifiâmes": ("humidifier",),
    "humidifiant": ("humidifier",),
    "humidifias": ("humidifier",),
    "humidifiassent": ("humidifier",),
    "humidifiasses": ("humidifier",),
    "humidifiasse": ("humidifier",),
    "humidifiassiez": ("humidifier",),
    "humidifiassions": ("humidifier",),
    "humidifiâtes": ("humidifier",),
    "humidifiât": ("humidifier",),
    "humidifiée": ("humidifier",),
    "humidifiées": ("humidifier",),
    "humidifié": ("humidifier",),
    "humidifient": ("humidifier",),
    "humidifie": ("humidifier",),
    "humidifiera": ("humidifier",),
    "humidifieraient": ("humidifier",),
    "humidifierai": ("humidifier",),
    "humidifierais": ("humidifier",),
    "humidifierait": ("humidifier",),
    "humidifieras": ("humidifier",),
    "humidifièrent": ("humidifier",),
    "humidifierez": ("humidifier",),
    "humidifieriez": ("humidifier",),
    "humidifierions": ("humidifier",),
    "humidifierons": ("humidifier",),
    "humidifieront": ("humidifier",),
    "humidifiés": ("humidifier",),
    "humidifies": ("humidifier",),
    "humidifiez": ("humidifier",),
    "humidifiiez": ("humidifier",),
    "humidifiions": ("humidifier",),
    "humidifions": ("humidifier",),
    "humifiaient": ("humifier",),
    "humifiai": ("humifier",),
    "humifiais": ("humifier",),
    "humifiait": ("humifier",),
    "humifia": ("humifier",),
    "humifiâmes": ("humifier",),
    "humifiant": ("humifier",),
    "humifias": ("humifier",),
    "humifiassent": ("humifier",),
    "humifiasses": ("humifier",),
    "humifiasse": ("humifier",),
    "humifiassiez": ("humifier",),
    "humifiassions": ("humifier",),
    "humifiâtes": ("humifier",),
    "humifiât": ("humifier",),
    "humifiée": ("humifier",),
    "humifiées": ("humifier",),
    "humifié": ("humifier",),
    "humifient": ("humifier",),
    "humifie": ("humifier",),
    "humifiera": ("humifier",),
    "humifieraient": ("humifier",),
    "humifierai": ("humifier",),
    "humifierais": ("humifier",),
    "humifierait": ("humifier",),
    "humifieras": ("humifier",),
    "humifièrent": ("humifier",),
    "humifierez": ("humifier",),
    "humifieriez": ("humifier",),
    "humifierions": ("humifier",),
    "humifierons": ("humifier",),
    "humifieront": ("humifier",),
    "humifiés": ("humifier",),
    "humifies": ("humifier",),
    "humifiez": ("humifier",),
    "humifiiez": ("humifier",),
    "humifiions": ("humifier",),
    "humifions": ("humifier",),
    "humiliaient": ("humilier",),
    "humiliai": ("humilier",),
    "humiliais": ("humilier",),
    "humiliait": ("humilier",),
    "humilia": ("humilier",),
    "humiliâmes": ("humilier",),
    "humiliant": ("humilier",),
    "humilias": ("humilier",),
    "humiliassent": ("humilier",),
    "humiliasses": ("humilier",),
    "humiliasse": ("humilier",),
    "humiliassiez": ("humilier",),
    "humiliassions": ("humilier",),
    "humiliâtes": ("humilier",),
    "humiliât": ("humilier",),
    "humiliée": ("humilier",),
    "humiliées": ("humilier",),
    "humilié": ("humilier",),
    "humilient": ("humilier",),
    "humilie": ("humilier",),
    "humiliera": ("humilier",),
    "humilieraient": ("humilier",),
    "humilierai": ("humilier",),
    "humilierais": ("humilier",),
    "humilierait": ("humilier",),
    "humilieras": ("humilier",),
    "humilièrent": ("humilier",),
    "humilierez": ("humilier",),
    "humilieriez": ("humilier",),
    "humilierions": ("humilier",),
    "humilierons": ("humilier",),
    "humilieront": ("humilier",),
    "humiliés": ("humilier",),
    "humilies": ("humilier",),
    "humiliez": ("humilier",),
    "humiliiez": ("humilier",),
    "humiliions": ("humilier",),
    "humilions": ("humilier",),
    "hydroensemençaient": ("hydroensemencer",),
    "hydroensemençai": ("hydroensemencer",),
    "hydroensemençais": ("hydroensemencer",),
    "hydroensemençait": ("hydroensemencer",),
    "hydroensemença": ("hydroensemencer",),
    "hydroensemençâmes": ("hydroensemencer",),
    "hydroensemençant": ("hydroensemencer",),
    "hydroensemenças": ("hydroensemencer",),
    "hydroensemençassent": ("hydroensemencer",),
    "hydroensemençasses": ("hydroensemencer",),
    "hydroensemençasse": ("hydroensemencer",),
    "hydroensemençassiez": ("hydroensemencer",),
    "hydroensemençassions": ("hydroensemencer",),
    "hydroensemençâtes": ("hydroensemencer",),
    "hydroensemençât": ("hydroensemencer",),
    "hydroensemencée": ("hydroensemencer",),
    "hydroensemencées": ("hydroensemencer",),
    "hydroensemencé": ("hydroensemencer",),
    "hydroensemencent": ("hydroensemencer",),
    "hydroensemence": ("hydroensemencer",),
    "hydroensemencera": ("hydroensemencer",),
    "hydroensemenceraient": ("hydroensemencer",),
    "hydroensemencerai": ("hydroensemencer",),
    "hydroensemencerais": ("hydroensemencer",),
    "hydroensemencerait": ("hydroensemencer",),
    "hydroensemenceras": ("hydroensemencer",),
    "hydroensemencèrent": ("hydroensemencer",),
    "hydroensemencerez": ("hydroensemencer",),
    "hydroensemenceriez": ("hydroensemencer",),
    "hydroensemencerions": ("hydroensemencer",),
    "hydroensemencerons": ("hydroensemencer",),
    "hydroensemenceront": ("hydroensemencer",),
    "hydroensemencés": ("hydroensemencer",),
    "hydroensemences": ("hydroensemencer",),
    "hydroensemencez": ("hydroensemencer",),
    "hydroensemenciez": ("hydroensemencer",),
    "hydroensemencions": ("hydroensemencer",),
    "hydroensemençons": ("hydroensemencer",),
    "hydrofinie": ("hydrofinir",),
    "hydrofinies": ("hydrofinir",),
    "hydrofini": ("hydrofinir",),
    "hydrofinîmes": ("hydrofinir",),
    "hydrofinira": ("hydrofinir",),
    "hydrofiniraient": ("hydrofinir",),
    "hydrofinirai": ("hydrofinir",),
    "hydrofinirais": ("hydrofinir",),
    "hydrofinirait": ("hydrofinir",),
    "hydrofiniras": ("hydrofinir",),
    "hydrofinirent": ("hydrofinir",),
    "hydrofinirez": ("hydrofinir",),
    "hydrofiniriez": ("hydrofinir",),
    "hydrofinirions": ("hydrofinir",),
    "hydrofinirons": ("hydrofinir",),
    "hydrofiniront": ("hydrofinir",),
    "hydrofinis": ("hydrofinir",),
    "hydrofinissaient": ("hydrofinir",),
    "hydrofinissais": ("hydrofinir",),
    "hydrofinissait": ("hydrofinir",),
    "hydrofinissant": ("hydrofinir",),
    "hydrofinissent": ("hydrofinir",),
    "hydrofinisse": ("hydrofinir",),
    "hydrofinisses": ("hydrofinir",),
    "hydrofinissez": ("hydrofinir",),
    "hydrofinissiez": ("hydrofinir",),
    "hydrofinissions": ("hydrofinir",),
    "hydrofinissons": ("hydrofinir",),
    "hydrofinîtes": ("hydrofinir",),
    "hydrofinit": ("hydrofinir",),
    "hydrofinît": ("hydrofinir",),
    "hydrofugeaient": ("hydrofuger",),
    "hydrofugeai": ("hydrofuger",),
    "hydrofugeais": ("hydrofuger",),
    "hydrofugeait": ("hydrofuger",),
    "hydrofugea": ("hydrofuger",),
    "hydrofugeâmes": ("hydrofuger",),
    "hydrofugeant": ("hydrofuger",),
    "hydrofugeas": ("hydrofuger",),
    "hydrofugeassent": ("hydrofuger",),
    "hydrofugeasses": ("hydrofuger",),
    "hydrofugeasse": ("hydrofuger",),
    "hydrofugeassiez": ("hydrofuger",),
    "hydrofugeassions": ("hydrofuger",),
    "hydrofugeâtes": ("hydrofuger",),
    "hydrofugeât": ("hydrofuger",),
    "hydrofugée": ("hydrofuger",),
    "hydrofugées": ("hydrofuger",),
    "hydrofugé": ("hydrofuger",),
    "hydrofugent": ("hydrofuger",),
    "hydrofugeons": ("hydrofuger",),
    "hydrofuge": ("hydrofuger",),
    "hydrofugera": ("hydrofuger",),
    "hydrofugeraient": ("hydrofuger",),
    "hydrofugerai": ("hydrofuger",),
    "hydrofugerais": ("hydrofuger",),
    "hydrofugerait": ("hydrofuger",),
    "hydrofugeras": ("hydrofuger",),
    "hydrofugèrent": ("hydrofuger",),
    "hydrofugerez": ("hydrofuger",),
    "hydrofugeriez": ("hydrofuger",),
    "hydrofugerions": ("hydrofuger",),
    "hydrofugerons": ("hydrofuger",),
    "hydrofugeront": ("hydrofuger",),
    "hydrofugés": ("hydrofuger",),
    "hydrofuges": ("hydrofuger",),
    "hydrofugez": ("hydrofuger",),
    "hydrofugiez": ("hydrofuger",),
    "hydrofugions": ("hydrofuger",),
    "hydrogénaient": ("hydrogéner",),
    "hydrogénai": ("hydrogéner",),
    "hydrogénais": ("hydrogéner",),
    "hydrogénait": ("hydrogéner",),
    "hydrogéna": ("hydrogéner",),
    "hydrogénâmes": ("hydrogéner",),
    "hydrogénant": ("hydrogéner",),
    "hydrogénas": ("hydrogéner",),
    "hydrogénassent": ("hydrogéner",),
    "hydrogénasses": ("hydrogéner",),
    "hydrogénasse": ("hydrogéner",),
    "hydrogénassiez": ("hydrogéner",),
    "hydrogénassions": ("hydrogéner",),
    "hydrogénâtes": ("hydrogéner",),
    "hydrogénât": ("hydrogéner",),
    "hydrogénée": ("hydrogéner",),
    "hydrogénées": ("hydrogéner",),
    "hydrogéné": ("hydrogéner",),
    "hydrogènent": ("hydrogéner",),
    "hydrogène": ("hydrogéner",),
    "hydrogénera": ("hydrogéner",),
    "hydrogéneraient": ("hydrogéner",),
    "hydrogénerai": ("hydrogéner",),
    "hydrogénerais": ("hydrogéner",),
    "hydrogénerait": ("hydrogéner",),
    "hydrogéneras": ("hydrogéner",),
    "hydrogénèrent": ("hydrogéner",),
    "hydrogénerez": ("hydrogéner",),
    "hydrogéneriez": ("hydrogéner",),
    "hydrogénerions": ("hydrogéner",),
    "hydrogénerons": ("hydrogéner",),
    "hydrogéneront": ("hydrogéner",),
    "hydrogénés": ("hydrogéner",),
    "hydrogènes": ("hydrogéner",),
    "hydrogénez": ("hydrogéner",),
    "hydrogéniez": ("hydrogéner",),
    "hydrogénions": ("hydrogéner",),
    "hydrogénons": ("hydrogéner",),
    "hypercorrigeaient": ("hypercorriger",),
    "hypercorrigeai": ("hypercorriger",),
    "hypercorrigeais": ("hypercorriger",),
    "hypercorrigeait": ("hypercorriger",),
    "hypercorrigea": ("hypercorriger",),
    "hypercorrigeâmes": ("hypercorriger",),
    "hypercorrigeant": ("hypercorriger",),
    "hypercorrigeas": ("hypercorriger",),
    "hypercorrigeassent": ("hypercorriger",),
    "hypercorrigeasses": ("hypercorriger",),
    "hypercorrigeasse": ("hypercorriger",),
    "hypercorrigeassiez": ("hypercorriger",),
    "hypercorrigeassions": ("hypercorriger",),
    "hypercorrigeâtes": ("hypercorriger",),
    "hypercorrigeât": ("hypercorriger",),
    "hypercorrigée": ("hypercorriger",),
    "hypercorrigées": ("hypercorriger",),
    "hypercorrigé": ("hypercorriger",),
    "hypercorrigent": ("hypercorriger",),
    "hypercorrigeons": ("hypercorriger",),
    "hypercorrige": ("hypercorriger",),
    "hypercorrigera": ("hypercorriger",),
    "hypercorrigeraient": ("hypercorriger",),
    "hypercorrigerai": ("hypercorriger",),
    "hypercorrigerais": ("hypercorriger",),
    "hypercorrigerait": ("hypercorriger",),
    "hypercorrigeras": ("hypercorriger",),
    "hypercorrigèrent": ("hypercorriger",),
    "hypercorrigerez": ("hypercorriger",),
    "hypercorrigeriez": ("hypercorriger",),
    "hypercorrigerions": ("hypercorriger",),
    "hypercorrigerons": ("hypercorriger",),
    "hypercorrigeront": ("hypercorriger",),
    "hypercorrigés": ("hypercorriger",),
    "hypercorriges": ("hypercorriger",),
    "hypercorrigez": ("hypercorriger",),
    "hypercorrigiez": ("hypercorriger",),
    "hypercorrigions": ("hypercorriger",),
    "hyperémiaient": ("hyperémier",),
    "hyperémiai": ("hyperémier",),
    "hyperémiais": ("hyperémier",),
    "hyperémiait": ("hyperémier",),
    "hyperémia": ("hyperémier",),
    "hyperémiâmes": ("hyperémier",),
    "hyperémiant": ("hyperémier",),
    "hyperémias": ("hyperémier",),
    "hyperémiassent": ("hyperémier",),
    "hyperémiasses": ("hyperémier",),
    "hyperémiasse": ("hyperémier",),
    "hyperémiassiez": ("hyperémier",),
    "hyperémiassions": ("hyperémier",),
    "hyperémiâtes": ("hyperémier",),
    "hyperémiât": ("hyperémier",),
    "hyperémiée": ("hyperémier",),
    "hyperémiées": ("hyperémier",),
    "hyperémié": ("hyperémier",),
    "hyperémient": ("hyperémier",),
    "hyperémie": ("hyperémier",),
    "hyperémiera": ("hyperémier",),
    "hyperémieraient": ("hyperémier",),
    "hyperémierai": ("hyperémier",),
    "hyperémierais": ("hyperémier",),
    "hyperémierait": ("hyperémier",),
    "hyperémieras": ("hyperémier",),
    "hyperémièrent": ("hyperémier",),
    "hyperémierez": ("hyperémier",),
    "hyperémieriez": ("hyperémier",),
    "hyperémierions": ("hyperémier",),
    "hyperémierons": ("hyperémier",),
    "hyperémieront": ("hyperémier",),
    "hyperémiés": ("hyperémier",),
    "hyperémies": ("hyperémier",),
    "hyperémiez": ("hyperémier",),
    "hyperémiiez": ("hyperémier",),
    "hyperémiions": ("hyperémier",),
    "hyperémions": ("hyperémier",),
    "hyperesthésiaient": ("hyperesthésier",),
    "hyperesthésiai": ("hyperesthésier",),
    "hyperesthésiais": ("hyperesthésier",),
    "hyperesthésiait": ("hyperesthésier",),
    "hyperesthésia": ("hyperesthésier",),
    "hyperesthésiâmes": ("hyperesthésier",),
    "hyperesthésiant": ("hyperesthésier",),
    "hyperesthésias": ("hyperesthésier",),
    "hyperesthésiassent": ("hyperesthésier",),
    "hyperesthésiasses": ("hyperesthésier",),
    "hyperesthésiasse": ("hyperesthésier",),
    "hyperesthésiassiez": ("hyperesthésier",),
    "hyperesthésiassions": ("hyperesthésier",),
    "hyperesthésiâtes": ("hyperesthésier",),
    "hyperesthésiât": ("hyperesthésier",),
    "hyperesthésiée": ("hyperesthésier",),
    "hyperesthésiées": ("hyperesthésier",),
    "hyperesthésié": ("hyperesthésier",),
    "hyperesthésient": ("hyperesthésier",),
    "hyperesthésie": ("hyperesthésier",),
    "hyperesthésiera": ("hyperesthésier",),
    "hyperesthésieraient": ("hyperesthésier",),
    "hyperesthésierai": ("hyperesthésier",),
    "hyperesthésierais": ("hyperesthésier",),
    "hyperesthésierait": ("hyperesthésier",),
    "hyperesthésieras": ("hyperesthésier",),
    "hyperesthésièrent": ("hyperesthésier",),
    "hyperesthésierez": ("hyperesthésier",),
    "hyperesthésieriez": ("hyperesthésier",),
    "hyperesthésierions": ("hyperesthésier",),
    "hyperesthésierons": ("hyperesthésier",),
    "hyperesthésieront": ("hyperesthésier",),
    "hyperesthésiés": ("hyperesthésier",),
    "hyperesthésies": ("hyperesthésier",),
    "hyperesthésiez": ("hyperesthésier",),
    "hyperesthésiiez": ("hyperesthésier",),
    "hyperesthésiions": ("hyperesthésier",),
    "hyperesthésions": ("hyperesthésier",),
    "hyperhémiaient": ("hyperhémier",),
    "hyperhémiai": ("hyperhémier",),
    "hyperhémiais": ("hyperhémier",),
    "hyperhémiait": ("hyperhémier",),
    "hyperhémia": ("hyperhémier",),
    "hyperhémiâmes": ("hyperhémier",),
    "hyperhémiant": ("hyperhémier",),
    "hyperhémias": ("hyperhémier",),
    "hyperhémiassent": ("hyperhémier",),
    "hyperhémiasses": ("hyperhémier",),
    "hyperhémiasse": ("hyperhémier",),
    "hyperhémiassiez": ("hyperhémier",),
    "hyperhémiassions": ("hyperhémier",),
    "hyperhémiâtes": ("hyperhémier",),
    "hyperhémiât": ("hyperhémier",),
    "hyperhémiée": ("hyperhémier",),
    "hyperhémiées": ("hyperhémier",),
    "hyperhémié": ("hyperhémier",),
    "hyperhémient": ("hyperhémier",),
    "hyperhémie": ("hyperhémier",),
    "hyperhémiera": ("hyperhémier",),
    "hyperhémieraient": ("hyperhémier",),
    "hyperhémierai": ("hyperhémier",),
    "hyperhémierais": ("hyperhémier",),
    "hyperhémierait": ("hyperhémier",),
    "hyperhémieras": ("hyperhémier",),
    "hyperhémièrent": ("hyperhémier",),
    "hyperhémierez": ("hyperhémier",),
    "hyperhémieriez": ("hyperhémier",),
    "hyperhémierions": ("hyperhémier",),
    "hyperhémierons": ("hyperhémier",),
    "hyperhémieront": ("hyperhémier",),
    "hyperhémiés": ("hyperhémier",),
    "hyperhémies": ("hyperhémier",),
    "hyperhémiez": ("hyperhémier",),
    "hyperhémiiez": ("hyperhémier",),
    "hyperhémiions": ("hyperhémier",),
    "hyperhémions": ("hyperhémier",),
    "hyperplasiaient": ("hyperplasier",),
    "hyperplasiai": ("hyperplasier",),
    "hyperplasiais": ("hyperplasier",),
    "hyperplasiait": ("hyperplasier",),
    "hyperplasia": ("hyperplasier",),
    "hyperplasiâmes": ("hyperplasier",),
    "hyperplasiant": ("hyperplasier",),
    "hyperplasias": ("hyperplasier",),
    "hyperplasiassent": ("hyperplasier",),
    "hyperplasiasses": ("hyperplasier",),
    "hyperplasiasse": ("hyperplasier",),
    "hyperplasiassiez": ("hyperplasier",),
    "hyperplasiassions": ("hyperplasier",),
    "hyperplasiâtes": ("hyperplasier",),
    "hyperplasiât": ("hyperplasier",),
    "hyperplasiée": ("hyperplasier",),
    "hyperplasiées": ("hyperplasier",),
    "hyperplasié": ("hyperplasier",),
    "hyperplasient": ("hyperplasier",),
    "hyperplasie": ("hyperplasier",),
    "hyperplasiera": ("hyperplasier",),
    "hyperplasieraient": ("hyperplasier",),
    "hyperplasierai": ("hyperplasier",),
    "hyperplasierais": ("hyperplasier",),
    "hyperplasierait": ("hyperplasier",),
    "hyperplasieras": ("hyperplasier",),
    "hyperplasièrent": ("hyperplasier",),
    "hyperplasierez": ("hyperplasier",),
    "hyperplasieriez": ("hyperplasier",),
    "hyperplasierions": ("hyperplasier",),
    "hyperplasierons": ("hyperplasier",),
    "hyperplasieront": ("hyperplasier",),
    "hyperplasiés": ("hyperplasier",),
    "hyperplasies": ("hyperplasier",),
    "hyperplasiez": ("hyperplasier",),
    "hyperplasiiez": ("hyperplasier",),
    "hyperplasiions": ("hyperplasier",),
    "hyperplasions": ("hyperplasier",),
    "hypertrophiaient": ("hypertrophier",),
    "hypertrophiai": ("hypertrophier",),
    "hypertrophiais": ("hypertrophier",),
    "hypertrophiait": ("hypertrophier",),
    "hypertrophia": ("hypertrophier",),
    "hypertrophiâmes": ("hypertrophier",),
    "hypertrophiant": ("hypertrophier",),
    "hypertrophias": ("hypertrophier",),
    "hypertrophiassent": ("hypertrophier",),
    "hypertrophiasses": ("hypertrophier",),
    "hypertrophiasse": ("hypertrophier",),
    "hypertrophiassiez": ("hypertrophier",),
    "hypertrophiassions": ("hypertrophier",),
    "hypertrophiâtes": ("hypertrophier",),
    "hypertrophiât": ("hypertrophier",),
    "hypertrophiée": ("hypertrophier",),
    "hypertrophiées": ("hypertrophier",),
    "hypertrophié": ("hypertrophier",),
    "hypertrophient": ("hypertrophier",),
    "hypertrophie": ("hypertrophier",),
    "hypertrophiera": ("hypertrophier",),
    "hypertrophieraient": ("hypertrophier",),
    "hypertrophierai": ("hypertrophier",),
    "hypertrophierais": ("hypertrophier",),
    "hypertrophierait": ("hypertrophier",),
    "hypertrophieras": ("hypertrophier",),
    "hypertrophièrent": ("hypertrophier",),
    "hypertrophierez": ("hypertrophier",),
    "hypertrophieriez": ("hypertrophier",),
    "hypertrophierions": ("hypertrophier",),
    "hypertrophierons": ("hypertrophier",),
    "hypertrophieront": ("hypertrophier",),
    "hypertrophiés": ("hypertrophier",),
    "hypertrophies": ("hypertrophier",),
    "hypertrophiez": ("hypertrophier",),
    "hypertrophiiez": ("hypertrophier",),
    "hypertrophiions": ("hypertrophier",),
    "hypertrophions": ("hypertrophier",),
    "hypolipidémiaient": ("hypolipidémier",),
    "hypolipidémiai": ("hypolipidémier",),
    "hypolipidémiais": ("hypolipidémier",),
    "hypolipidémiait": ("hypolipidémier",),
    "hypolipidémia": ("hypolipidémier",),
    "hypolipidémiâmes": ("hypolipidémier",),
    "hypolipidémiant": ("hypolipidémier",),
    "hypolipidémias": ("hypolipidémier",),
    "hypolipidémiassent": ("hypolipidémier",),
    "hypolipidémiasses": ("hypolipidémier",),
    "hypolipidémiasse": ("hypolipidémier",),
    "hypolipidémiassiez": ("hypolipidémier",),
    "hypolipidémiassions": ("hypolipidémier",),
    "hypolipidémiâtes": ("hypolipidémier",),
    "hypolipidémiât": ("hypolipidémier",),
    "hypolipidémiée": ("hypolipidémier",),
    "hypolipidémiées": ("hypolipidémier",),
    "hypolipidémié": ("hypolipidémier",),
    "hypolipidémient": ("hypolipidémier",),
    "hypolipidémie": ("hypolipidémier",),
    "hypolipidémiera": ("hypolipidémier",),
    "hypolipidémieraient": ("hypolipidémier",),
    "hypolipidémierai": ("hypolipidémier",),
    "hypolipidémierais": ("hypolipidémier",),
    "hypolipidémierait": ("hypolipidémier",),
    "hypolipidémieras": ("hypolipidémier",),
    "hypolipidémièrent": ("hypolipidémier",),
    "hypolipidémierez": ("hypolipidémier",),
    "hypolipidémieriez": ("hypolipidémier",),
    "hypolipidémierions": ("hypolipidémier",),
    "hypolipidémierons": ("hypolipidémier",),
    "hypolipidémieront": ("hypolipidémier",),
    "hypolipidémiés": ("hypolipidémier",),
    "hypolipidémies": ("hypolipidémier",),
    "hypolipidémiez": ("hypolipidémier",),
    "hypolipidémiiez": ("hypolipidémier",),
    "hypolipidémiions": ("hypolipidémier",),
    "hypolipidémions": ("hypolipidémier",),
    "hypostasiaient": ("hypostasier",),
    "hypostasiai": ("hypostasier",),
    "hypostasiais": ("hypostasier",),
    "hypostasiait": ("hypostasier",),
    "hypostasia": ("hypostasier",),
    "hypostasiâmes": ("hypostasier",),
    "hypostasiant": ("hypostasier",),
    "hypostasias": ("hypostasier",),
    "hypostasiassent": ("hypostasier",),
    "hypostasiasses": ("hypostasier",),
    "hypostasiasse": ("hypostasier",),
    "hypostasiassiez": ("hypostasier",),
    "hypostasiassions": ("hypostasier",),
    "hypostasiâtes": ("hypostasier",),
    "hypostasiât": ("hypostasier",),
    "hypostasiée": ("hypostasier",),
    "hypostasiées": ("hypostasier",),
    "hypostasié": ("hypostasier",),
    "hypostasient": ("hypostasier",),
    "hypostasie": ("hypostasier",),
    "hypostasiera": ("hypostasier",),
    "hypostasieraient": ("hypostasier",),
    "hypostasierai": ("hypostasier",),
    "hypostasierais": ("hypostasier",),
    "hypostasierait": ("hypostasier",),
    "hypostasieras": ("hypostasier",),
    "hypostasièrent": ("hypostasier",),
    "hypostasierez": ("hypostasier",),
    "hypostasieriez": ("hypostasier",),
    "hypostasierions": ("hypostasier",),
    "hypostasierons": ("hypostasier",),
    "hypostasieront": ("hypostasier",),
    "hypostasiés": ("hypostasier",),
    "hypostasies": ("hypostasier",),
    "hypostasiez": ("hypostasier",),
    "hypostasiiez": ("hypostasier",),
    "hypostasiions": ("hypostasier",),
    "hypostasions": ("hypostasier",),
    "hypothéquaient": ("hypothéquer",),
    "hypothéquai": ("hypothéquer",),
    "hypothéquais": ("hypothéquer",),
    "hypothéquait": ("hypothéquer",),
    "hypothéqua": ("hypothéquer",),
    "hypothéquâmes": ("hypothéquer",),
    "hypothéquant": ("hypothéquer",),
    "hypothéquas": ("hypothéquer",),
    "hypothéquassent": ("hypothéquer",),
    "hypothéquasses": ("hypothéquer",),
    "hypothéquasse": ("hypothéquer",),
    "hypothéquassiez": ("hypothéquer",),
    "hypothéquassions": ("hypothéquer",),
    "hypothéquâtes": ("hypothéquer",),
    "hypothéquât": ("hypothéquer",),
    "hypothéquée": ("hypothéquer",),
    "hypothéquées": ("hypothéquer",),
    "hypothéqué": ("hypothéquer",),
    "hypothèquent": ("hypothéquer",),
    "hypothèque": ("hypothéquer",),
    "hypothéquera": ("hypothéquer",),
    "hypothéqueraient": ("hypothéquer",),
    "hypothéquerai": ("hypothéquer",),
    "hypothéquerais": ("hypothéquer",),
    "hypothéquerait": ("hypothéquer",),
    "hypothéqueras": ("hypothéquer",),
    "hypothéquèrent": ("hypothéquer",),
    "hypothéquerez": ("hypothéquer",),
    "hypothéqueriez": ("hypothéquer",),
    "hypothéquerions": ("hypothéquer",),
    "hypothéquerons": ("hypothéquer",),
    "hypothéqueront": ("hypothéquer",),
    "hypothéqués": ("hypothéquer",),
    "hypothèques": ("hypothéquer",),
    "hypothéquez": ("hypothéquer",),
    "hypothéquiez": ("hypothéquer",),
    "hypothéquions": ("hypothéquer",),
    "hypothéquons": ("hypothéquer",),
    "idéaient": ("idéer",),
    "idéai": ("idéer",),
    "idéais": ("idéer",),
    "idéait": ("idéer",),
    "idéa": ("idéer",),
    "idéâmes": ("idéer",),
    "idéant": ("idéer",),
    "idéas": ("idéer",),
    "idéassent": ("idéer",),
    "idéasses": ("idéer",),
    "idéasse": ("idéer",),
    "idéassiez": ("idéer",),
    "idéassions": ("idéer",),
    "idéâtes": ("idéer",),
    "idéât": ("idéer",),
    "idéée": ("idéer",),
    "idéées": ("idéer",),
    "idéé": ("idéer",),
    "idéent": ("idéer",),
    "idée": ("idéer",),
    "idéera": ("idéer",),
    "idéeraient": ("idéer",),
    "idéerai": ("idéer",),
    "idéerais": ("idéer",),
    "idéerait": ("idéer",),
    "idéeras": ("idéer",),
    "idéèrent": ("idéer",),
    "idéerez": ("idéer",),
    "idéeriez": ("idéer",),
    "idéerions": ("idéer",),
    "idéerons": ("idéer",),
    "idéeront": ("idéer",),
    "idéés": ("idéer",),
    "idées": ("idéer",),
    "idéez": ("idéer",),
    "idéiez": ("idéer",),
    "idéions": ("idéer",),
    "idéons": ("idéer",),
    "identifiaient": ("identifier",),
    "identifiai": ("identifier",),
    "identifiais": ("identifier",),
    "identifiait": ("identifier",),
    "identifia": ("identifier",),
    "identifiâmes": ("identifier",),
    "identifiant": ("identifier",),
    "identifias": ("identifier",),
    "identifiassent": ("identifier",),
    "identifiasses": ("identifier",),
    "identifiasse": ("identifier",),
    "identifiassiez": ("identifier",),
    "identifiassions": ("identifier",),
    "identifiâtes": ("identifier",),
    "identifiât": ("identifier",),
    "identifiée": ("identifier",),
    "identifiées": ("identifier",),
    "identifié": ("identifier",),
    "identifient": ("identifier",),
    "identifie": ("identifier",),
    "identifiera": ("identifier",),
    "identifieraient": ("identifier",),
    "identifierai": ("identifier",),
    "identifierais": ("identifier",),
    "identifierait": ("identifier",),
    "identifieras": ("identifier",),
    "identifièrent": ("identifier",),
    "identifierez": ("identifier",),
    "identifieriez": ("identifier",),
    "identifierions": ("identifier",),
    "identifierons": ("identifier",),
    "identifieront": ("identifier",),
    "identifiés": ("identifier",),
    "identifies": ("identifier",),
    "identifiez": ("identifier",),
    "identifiiez": ("identifier",),
    "identifiions": ("identifier",),
    "identifions": ("identifier",),
    "idiotifiaient": ("idiotifier",),
    "idiotifiai": ("idiotifier",),
    "idiotifiais": ("idiotifier",),
    "idiotifiait": ("idiotifier",),
    "idiotifia": ("idiotifier",),
    "idiotifiâmes": ("idiotifier",),
    "idiotifiant": ("idiotifier",),
    "idiotifias": ("idiotifier",),
    "idiotifiassent": ("idiotifier",),
    "idiotifiasses": ("idiotifier",),
    "idiotifiasse": ("idiotifier",),
    "idiotifiassiez": ("idiotifier",),
    "idiotifiassions": ("idiotifier",),
    "idiotifiâtes": ("idiotifier",),
    "idiotifiât": ("idiotifier",),
    "idiotifiée": ("idiotifier",),
    "idiotifiées": ("idiotifier",),
    "idiotifié": ("idiotifier",),
    "idiotifient": ("idiotifier",),
    "idiotifie": ("idiotifier",),
    "idiotifiera": ("idiotifier",),
    "idiotifieraient": ("idiotifier",),
    "idiotifierai": ("idiotifier",),
    "idiotifierais": ("idiotifier",),
    "idiotifierait": ("idiotifier",),
    "idiotifieras": ("idiotifier",),
    "idiotifièrent": ("idiotifier",),
    "idiotifierez": ("idiotifier",),
    "idiotifieriez": ("idiotifier",),
    "idiotifierions": ("idiotifier",),
    "idiotifierons": ("idiotifier",),
    "idiotifieront": ("idiotifier",),
    "idiotifiés": ("idiotifier",),
    "idiotifies": ("idiotifier",),
    "idiotifiez": ("idiotifier",),
    "idiotifiiez": ("idiotifier",),
    "idiotifiions": ("idiotifier",),
    "idiotifions": ("idiotifier",),
    "ignifugeaient": ("ignifuger",),
    "ignifugeai": ("ignifuger",),
    "ignifugeais": ("ignifuger",),
    "ignifugeait": ("ignifuger",),
    "ignifugea": ("ignifuger",),
    "ignifugeâmes": ("ignifuger",),
    "ignifugeant": ("ignifuger",),
    "ignifugeas": ("ignifuger",),
    "ignifugeassent": ("ignifuger",),
    "ignifugeasses": ("ignifuger",),
    "ignifugeasse": ("ignifuger",),
    "ignifugeassiez": ("ignifuger",),
    "ignifugeassions": ("ignifuger",),
    "ignifugeâtes": ("ignifuger",),
    "ignifugeât": ("ignifuger",),
    "ignifugée": ("ignifuger",),
    "ignifugées": ("ignifuger",),
    "ignifugé": ("ignifuger",),
    "ignifugent": ("ignifuger",),
    "ignifugeons": ("ignifuger",),
    "ignifuge": ("ignifuger",),
    "ignifugera": ("ignifuger",),
    "ignifugeraient": ("ignifuger",),
    "ignifugerai": ("ignifuger",),
    "ignifugerais": ("ignifuger",),
    "ignifugerait": ("ignifuger",),
    "ignifugeras": ("ignifuger",),
    "ignifugèrent": ("ignifuger",),
    "ignifugerez": ("ignifuger",),
    "ignifugeriez": ("ignifuger",),
    "ignifugerions": ("ignifuger",),
    "ignifugerons": ("ignifuger",),
    "ignifugeront": ("ignifuger",),
    "ignifugés": ("ignifuger",),
    "ignifuges": ("ignifuger",),
    "ignifugez": ("ignifuger",),
    "ignifugiez": ("ignifuger",),
    "ignifugions": ("ignifuger",),
    "imageaient": ("imager",),
    "imageai": ("imager",),
    "imageais": ("imager",),
    "imageait": ("imager",),
    "imagea": ("imager",),
    "imageâmes": ("imager",),
    "imageant": ("imager",),
    "imageas": ("imager",),
    "imageassent": ("imager",),
    "imageasses": ("imager",),
    "imageasse": ("imager",),
    "imageassiez": ("imager",),
    "imageassions": ("imager",),
    "imageâtes": ("imager",),
    "imageât": ("imager",),
    "imagée": ("imager",),
    "imagées": ("imager",),
    "imagé": ("imager",),
    "imagent": ("imager",),
    "imageons": ("imager",),
    "image": ("imager",),
    "imagera": ("imager",),
    "imageraient": ("imager",),
    "imagerai": ("imager",),
    "imagerais": ("imager",),
    "imagerait": ("imager",),
    "imageras": ("imager",),
    "imagèrent": ("imager",),
    "imagerez": ("imager",),
    "imageriez": ("imager",),
    "imagerions": ("imager",),
    "imagerons": ("imager",),
    "imageront": ("imager",),
    "imagés": ("imager",),
    "images": ("imager",),
    "imagez": ("imager",),
    "imagiez": ("imager",),
    "imagions": ("imager",),
    "imboira": ("imboire",),
    "imboiraient": ("imboire",),
    "imboirai": ("imboire",),
    "imboirais": ("imboire",),
    "imboirait": ("imboire",),
    "imboiras": ("imboire",),
    "imboirez": ("imboire",),
    "imboiriez": ("imboire",),
    "imboirions": ("imboire",),
    "imboirons": ("imboire",),
    "imboiront": ("imboire",),
    "imbois": ("imboire",),
    "imboit": ("imboire",),
    "imboivent": ("imboire",),
    "imboive": ("imboire",),
    "imboives": ("imboire",),
    "imbue": ("imboire",),
    "imbues": ("imboire",),
    "imbu": ("imboire",),
    "imbûmes": ("imboire",),
    "imburent": ("imboire",),
    "imbus": ("imboire",),
    "imbussent": ("imboire",),
    "imbusses": ("imboire",),
    "imbusse": ("imboire",),
    "imbussiez": ("imboire",),
    "imbussions": ("imboire",),
    "imbûtes": ("imboire",),
    "imbut": ("imboire",),
    "imbût": ("imboire",),
    "imbuvaient": ("imboire",),
    "imbuvais": ("imboire",),
    "imbuvait": ("imboire",),
    "imbuvant": ("imboire",),
    "imbuvez": ("imboire",),
    "imbuviez": ("imboire",),
    "imbuvions": ("imboire",),
    "imbuvons": ("imboire",),
    "immensifiaient": ("immensifier",),
    "immensifiai": ("immensifier",),
    "immensifiais": ("immensifier",),
    "immensifiait": ("immensifier",),
    "immensifia": ("immensifier",),
    "immensifiâmes": ("immensifier",),
    "immensifiant": ("immensifier",),
    "immensifias": ("immensifier",),
    "immensifiassent": ("immensifier",),
    "immensifiasses": ("immensifier",),
    "immensifiasse": ("immensifier",),
    "immensifiassiez": ("immensifier",),
    "immensifiassions": ("immensifier",),
    "immensifiâtes": ("immensifier",),
    "immensifiât": ("immensifier",),
    "immensifiée": ("immensifier",),
    "immensifiées": ("immensifier",),
    "immensifié": ("immensifier",),
    "immensifient": ("immensifier",),
    "immensifie": ("immensifier",),
    "immensifiera": ("immensifier",),
    "immensifieraient": ("immensifier",),
    "immensifierai": ("immensifier",),
    "immensifierais": ("immensifier",),
    "immensifierait": ("immensifier",),
    "immensifieras": ("immensifier",),
    "immensifièrent": ("immensifier",),
    "immensifierez": ("immensifier",),
    "immensifieriez": ("immensifier",),
    "immensifierions": ("immensifier",),
    "immensifierons": ("immensifier",),
    "immensifieront": ("immensifier",),
    "immensifiés": ("immensifier",),
    "immensifies": ("immensifier",),
    "immensifiez": ("immensifier",),
    "immensifiiez": ("immensifier",),
    "immensifiions": ("immensifier",),
    "immensifions": ("immensifier",),
    "immergeaient": ("immerger",),
    "immergeai": ("immerger",),
    "immergeais": ("immerger",),
    "immergeait": ("immerger",),
    "immergea": ("immerger",),
    "immergeâmes": ("immerger",),
    "immergeant": ("immerger",),
    "immergeas": ("immerger",),
    "immergeassent": ("immerger",),
    "immergeasses": ("immerger",),
    "immergeasse": ("immerger",),
    "immergeassiez": ("immerger",),
    "immergeassions": ("immerger",),
    "immergeâtes": ("immerger",),
    "immergeât": ("immerger",),
    "immergée": ("immerger",),
    "immergées": ("immerger",),
    "immergé": ("immerger",),
    "immergent": ("immerger",),
    "immergeons": ("immerger",),
    "immerge": ("immerger",),
    "immergera": ("immerger",),
    "immergeraient": ("immerger",),
    "immergerai": ("immerger",),
    "immergerais": ("immerger",),
    "immergerait": ("immerger",),
    "immergeras": ("immerger",),
    "immergèrent": ("immerger",),
    "immergerez": ("immerger",),
    "immergeriez": ("immerger",),
    "immergerions": ("immerger",),
    "immergerons": ("immerger",),
    "immergeront": ("immerger",),
    "immergés": ("immerger",),
    "immerges": ("immerger",),
    "immergez": ("immerger",),
    "immergiez": ("immerger",),
    "immergions": ("immerger",),
    "immisçaient": ("immiscer",),
    "immisçai": ("immiscer",),
    "immisçais": ("immiscer",),
    "immisçait": ("immiscer",),
    "immisça": ("immiscer",),
    "immisçâmes": ("immiscer",),
    "immisçant": ("immiscer",),
    "immisças": ("immiscer",),
    "immisçassent": ("immiscer",),
    "immisçasses": ("immiscer",),
    "immisçasse": ("immiscer",),
    "immisçassiez": ("immiscer",),
    "immisçassions": ("immiscer",),
    "immisçâtes": ("immiscer",),
    "immisçât": ("immiscer",),
    "immiscée": ("immiscer",),
    "immiscées": ("immiscer",),
    "immiscé": ("immiscer",),
    "immiscent": ("immiscer",),
    "immisce": ("immiscer",),
    "immiscera": ("immiscer",),
    "immisceraient": ("immiscer",),
    "immiscerai": ("immiscer",),
    "immiscerais": ("immiscer",),
    "immiscerait": ("immiscer",),
    "immisceras": ("immiscer",),
    "immiscèrent": ("immiscer",),
    "immiscerez": ("immiscer",),
    "immisceriez": ("immiscer",),
    "immiscerions": ("immiscer",),
    "immiscerons": ("immiscer",),
    "immisceront": ("immiscer",),
    "immiscés": ("immiscer",),
    "immisces": ("immiscer",),
    "immiscez": ("immiscer",),
    "immisciez": ("immiscer",),
    "immiscions": ("immiscer",),
    "immisçons": ("immiscer",),
    "impartie": ("impartir",),
    "imparties": ("impartir",),
    "imparti": ("impartir",),
    "impartîmes": ("impartir",),
    "impartira": ("impartir",),
    "impartiraient": ("impartir",),
    "impartirai": ("impartir",),
    "impartirais": ("impartir",),
    "impartirait": ("impartir",),
    "impartiras": ("impartir",),
    "impartirent": ("impartir",),
    "impartirez": ("impartir",),
    "impartiriez": ("impartir",),
    "impartirions": ("impartir",),
    "impartirons": ("impartir",),
    "impartiront": ("impartir",),
    "impartis": ("impartir",),
    "impartissaient": ("impartir",),
    "impartissais": ("impartir",),
    "impartissait": ("impartir",),
    "impartissant": ("impartir",),
    "impartissent": ("impartir",),
    "impartisse": ("impartir",),
    "impartisses": ("impartir",),
    "impartissez": ("impartir",),
    "impartissiez": ("impartir",),
    "impartissions": ("impartir",),
    "impartissons": ("impartir",),
    "impartîtes": ("impartir",),
    "impartit": ("impartir",),
    "impartît": ("impartir",),
    "impétraient": ("impétrer",),
    "impétrai": ("impétrer",),
    "impétrais": ("impétrer",),
    "impétrait": ("impétrer",),
    "impétra": ("impétrer",),
    "impétrâmes": ("impétrer",),
    "impétrant": ("impétrer",),
    "impétras": ("impétrer",),
    "impétrassent": ("impétrer",),
    "impétrasses": ("impétrer",),
    "impétrasse": ("impétrer",),
    "impétrassiez": ("impétrer",),
    "impétrassions": ("impétrer",),
    "impétrâtes": ("impétrer",),
    "impétrât": ("impétrer",),
    "impétrée": ("impétrer",),
    "impétrées": ("impétrer",),
    "impétré": ("impétrer",),
    "impètrent": ("impétrer",),
    "impètre": ("impétrer",),
    "impétrera": ("impétrer",),
    "impétreraient": ("impétrer",),
    "impétrerai": ("impétrer",),
    "impétrerais": ("impétrer",),
    "impétrerait": ("impétrer",),
    "impétreras": ("impétrer",),
    "impétrèrent": ("impétrer",),
    "impétrerez": ("impétrer",),
    "impétreriez": ("impétrer",),
    "impétrerions": ("impétrer",),
    "impétrerons": ("impétrer",),
    "impétreront": ("impétrer",),
    "impétrés": ("impétrer",),
    "impètres": ("impétrer",),
    "impétrez": ("impétrer",),
    "impétriez": ("impétrer",),
    "impétrions": ("impétrer",),
    "impétrons": ("impétrer",),
    "imprégnaient": ("imprégner",),
    "imprégnai": ("imprégner",),
    "imprégnais": ("imprégner",),
    "imprégnait": ("imprégner",),
    "imprégna": ("imprégner",),
    "imprégnâmes": ("imprégner",),
    "imprégnant": ("imprégner",),
    "imprégnas": ("imprégner",),
    "imprégnassent": ("imprégner",),
    "imprégnasses": ("imprégner",),
    "imprégnasse": ("imprégner",),
    "imprégnassiez": ("imprégner",),
    "imprégnassions": ("imprégner",),
    "imprégnâtes": ("imprégner",),
    "imprégnât": ("imprégner",),
    "imprégnée": ("imprégner",),
    "imprégnées": ("imprégner",),
    "imprégné": ("imprégner",),
    "imprègnent": ("imprégner",),
    "imprègne": ("imprégner",),
    "imprégnera": ("imprégner",),
    "imprégneraient": ("imprégner",),
    "imprégnerai": ("imprégner",),
    "imprégnerais": ("imprégner",),
    "imprégnerait": ("imprégner",),
    "imprégneras": ("imprégner",),
    "imprégnèrent": ("imprégner",),
    "imprégnerez": ("imprégner",),
    "imprégneriez": ("imprégner",),
    "imprégnerions": ("imprégner",),
    "imprégnerons": ("imprégner",),
    "imprégneront": ("imprégner",),
    "imprégnés": ("imprégner",),
    "imprègnes": ("imprégner",),
    "imprégnez": ("imprégner",),
    "imprégniez": ("imprégner",),
    "imprégnions": ("imprégner",),
    "imprégnons": ("imprégner",),
    "inachevaient": ("inachever",),
    "inachevai": ("inachever",),
    "inachevais": ("inachever",),
    "inachevait": ("inachever",),
    "inacheva": ("inachever",),
    "inachevâmes": ("inachever",),
    "inachevant": ("inachever",),
    "inachevas": ("inachever",),
    "inachevassent": ("inachever",),
    "inachevasses": ("inachever",),
    "inachevasse": ("inachever",),
    "inachevassiez": ("inachever",),
    "inachevassions": ("inachever",),
    "inachevâtes": ("inachever",),
    "inachevât": ("inachever",),
    "inachevée": ("inachever",),
    "inachevées": ("inachever",),
    "inachevé": ("inachever",),
    "inachèvent": ("inachever",),
    "inachève": ("inachever",),
    "inachèvera": ("inachever",),
    "inachèveraient": ("inachever",),
    "inachèverai": ("inachever",),
    "inachèverais": ("inachever",),
    "inachèverait": ("inachever",),
    "inachèveras": ("inachever",),
    "inachevèrent": ("inachever",),
    "inachèverez": ("inachever",),
    "inachèveriez": ("inachever",),
    "inachèverions": ("inachever",),
    "inachèverons": ("inachever",),
    "inachèveront": ("inachever",),
    "inachevés": ("inachever",),
    "inachèves": ("inachever",),
    "inachevez": ("inachever",),
    "inacheviez": ("inachever",),
    "inachevions": ("inachever",),
    "inachevons": ("inachever",),
    "incarcéraient": ("incarcérer",),
    "incarcérai": ("incarcérer",),
    "incarcérais": ("incarcérer",),
    "incarcérait": ("incarcérer",),
    "incarcéra": ("incarcérer",),
    "incarcérâmes": ("incarcérer",),
    "incarcérant": ("incarcérer",),
    "incarcéras": ("incarcérer",),
    "incarcérassent": ("incarcérer",),
    "incarcérasses": ("incarcérer",),
    "incarcérasse": ("incarcérer",),
    "incarcérassiez": ("incarcérer",),
    "incarcérassions": ("incarcérer",),
    "incarcérâtes": ("incarcérer",),
    "incarcérât": ("incarcérer",),
    "incarcérée": ("incarcérer",),
    "incarcérées": ("incarcérer",),
    "incarcéré": ("incarcérer",),
    "incarcèrent": ("incarcérer",),
    "incarcère": ("incarcérer",),
    "incarcérera": ("incarcérer",),
    "incarcéreraient": ("incarcérer",),
    "incarcérerai": ("incarcérer",),
    "incarcérerais": ("incarcérer",),
    "incarcérerait": ("incarcérer",),
    "incarcéreras": ("incarcérer",),
    "incarcérèrent": ("incarcérer",),
    "incarcérerez": ("incarcérer",),
    "incarcéreriez": ("incarcérer",),
    "incarcérerions": ("incarcérer",),
    "incarcérerons": ("incarcérer",),
    "incarcéreront": ("incarcérer",),
    "incarcérés": ("incarcérer",),
    "incarcères": ("incarcérer",),
    "incarcérez": ("incarcérer",),
    "incarcériez": ("incarcérer",),
    "incarcérions": ("incarcérer",),
    "incarcérons": ("incarcérer",),
    "incendiaient": ("incendier",),
    "incendiai": ("incendier",),
    "incendiais": ("incendier",),
    "incendiait": ("incendier",),
    "incendia": ("incendier",),
    "incendiâmes": ("incendier",),
    "incendiant": ("incendier",),
    "incendias": ("incendier",),
    "incendiassent": ("incendier",),
    "incendiasses": ("incendier",),
    "incendiasse": ("incendier",),
    "incendiassiez": ("incendier",),
    "incendiassions": ("incendier",),
    "incendiâtes": ("incendier",),
    "incendiât": ("incendier",),
    "incendiée": ("incendier",),
    "incendiées": ("incendier",),
    "incendié": ("incendier",),
    "incendient": ("incendier",),
    "incendie": ("incendier",),
    "incendiera": ("incendier",),
    "incendieraient": ("incendier",),
    "incendierai": ("incendier",),
    "incendierais": ("incendier",),
    "incendierait": ("incendier",),
    "incendieras": ("incendier",),
    "incendièrent": ("incendier",),
    "incendierez": ("incendier",),
    "incendieriez": ("incendier",),
    "incendierions": ("incendier",),
    "incendierons": ("incendier",),
    "incendieront": ("incendier",),
    "incendiés": ("incendier",),
    "incendies": ("incendier",),
    "incendiez": ("incendier",),
    "incendiiez": ("incendier",),
    "incendiions": ("incendier",),
    "incendions": ("incendier",),
    "incéraient": ("incérer",),
    "incérai": ("incérer",),
    "incérais": ("incérer",),
    "incérait": ("incérer",),
    "incéra": ("incérer",),
    "incérâmes": ("incérer",),
    "incérant": ("incérer",),
    "incéras": ("incérer",),
    "incérassent": ("incérer",),
    "incérasses": ("incérer",),
    "incérasse": ("incérer",),
    "incérassiez": ("incérer",),
    "incérassions": ("incérer",),
    "incérâtes": ("incérer",),
    "incérât": ("incérer",),
    "incérée": ("incérer",),
    "incérées": ("incérer",),
    "incéré": ("incérer",),
    "incèrent": ("incérer",),
    "incère": ("incérer",),
    "incérera": ("incérer",),
    "incéreraient": ("incérer",),
    "incérerai": ("incérer",),
    "incérerais": ("incérer",),
    "incérerait": ("incérer",),
    "incéreras": ("incérer",),
    "incérèrent": ("incérer",),
    "incérerez": ("incérer",),
    "incéreriez": ("incérer",),
    "incérerions": ("incérer",),
    "incérerons": ("incérer",),
    "incéreront": ("incérer",),
    "incérés": ("incérer",),
    "incères": ("incérer",),
    "incérez": ("incérer",),
    "incériez": ("incérer",),
    "incérions": ("incérer",),
    "incérons": ("incérer",),
    "incinéraient": ("incinérer",),
    "incinérai": ("incinérer",),
    "incinérais": ("incinérer",),
    "incinérait": ("incinérer",),
    "incinéra": ("incinérer",),
    "incinérâmes": ("incinérer",),
    "incinérant": ("incinérer",),
    "incinéras": ("incinérer",),
    "incinérassent": ("incinérer",),
    "incinérasses": ("incinérer",),
    "incinérasse": ("incinérer",),
    "incinérassiez": ("incinérer",),
    "incinérassions": ("incinérer",),
    "incinérâtes": ("incinérer",),
    "incinérât": ("incinérer",),
    "incinérée": ("incinérer",),
    "incinérées": ("incinérer",),
    "incinéré": ("incinérer",),
    "incinèrent": ("incinérer",),
    "incinère": ("incinérer",),
    "incinérera": ("incinérer",),
    "incinéreraient": ("incinérer",),
    "incinérerai": ("incinérer",),
    "incinérerais": ("incinérer",),
    "incinérerait": ("incinérer",),
    "incinéreras": ("incinérer",),
    "incinérèrent": ("incinérer",),
    "incinérerez": ("incinérer",),
    "incinéreriez": ("incinérer",),
    "incinérerions": ("incinérer",),
    "incinérerons": ("incinérer",),
    "incinéreront": ("incinérer",),
    "incinérés": ("incinérer",),
    "incinères": ("incinérer",),
    "incinérez": ("incinérer",),
    "incinériez": ("incinérer",),
    "incinérions": ("incinérer",),
    "incinérons": ("incinérer",),
    "incluaient": ("inclure",),
    "incluais": ("inclure",),
    "incluait": ("inclure",),
    "incluant": ("inclure",),
    "incluent": ("inclure",),
    "inclue": ("inclure",),
    "inclues": ("inclure",),
    "incluez": ("inclure",),
    "incluiez": ("inclure",),
    "incluions": ("inclure",),
    "inclûmes": ("inclure",),
    "incluons": ("inclure",),
    "inclura": ("inclure",),
    "incluraient": ("inclure",),
    "inclurai": ("inclure",),
    "inclurais": ("inclure",),
    "inclurait": ("inclure",),
    "incluras": ("inclure",),
    "inclurent": ("inclure",),
    "inclurez": ("inclure",),
    "incluriez": ("inclure",),
    "inclurions": ("inclure",),
    "inclurons": ("inclure",),
    "incluront": ("inclure",),
    "incluse": ("inclure",),
    "incluses": ("inclure",),
    "inclus": ("inclure",),
    "inclussent": ("inclure",),
    "inclusses": ("inclure",),
    "inclusse": ("inclure",),
    "inclussiez": ("inclure",),
    "inclussions": ("inclure",),
    "inclûtes": ("inclure",),
    "inclut": ("inclure",),
    "inclût": ("inclure",),
    "incréaient": ("incréer",),
    "incréai": ("incréer",),
    "incréais": ("incréer",),
    "incréait": ("incréer",),
    "incréa": ("incréer",),
    "incréâmes": ("incréer",),
    "incréant": ("incréer",),
    "incréas": ("incréer",),
    "incréassent": ("incréer",),
    "incréasses": ("incréer",),
    "incréasse": ("incréer",),
    "incréassiez": ("incréer",),
    "incréassions": ("incréer",),
    "incréâtes": ("incréer",),
    "incréât": ("incréer",),
    "incréée": ("incréer",),
    "incréées": ("incréer",),
    "incréé": ("incréer",),
    "incréent": ("incréer",),
    "incrée": ("incréer",),
    "incréera": ("incréer",),
    "incréeraient": ("incréer",),
    "incréerai": ("incréer",),
    "incréerais": ("incréer",),
    "incréerait": ("incréer",),
    "incréeras": ("incréer",),
    "incréèrent": ("incréer",),
    "incréerez": ("incréer",),
    "incréeriez": ("incréer",),
    "incréerions": ("incréer",),
    "incréerons": ("incréer",),
    "incréeront": ("incréer",),
    "incréés": ("incréer",),
    "incrées": ("incréer",),
    "incréez": ("incréer",),
    "incréiez": ("incréer",),
    "incréions": ("incréer",),
    "incréons": ("incréer",),
    "indiçaient": ("indicer",),
    "indiçai": ("indicer",),
    "indiçais": ("indicer",),
    "indiçait": ("indicer",),
    "indiça": ("indicer",),
    "indiçâmes": ("indicer",),
    "indiçant": ("indicer",),
    "indiças": ("indicer",),
    "indiçassent": ("indicer",),
    "indiçasses": ("indicer",),
    "indiçasse": ("indicer",),
    "indiçassiez": ("indicer",),
    "indiçassions": ("indicer",),
    "indiçâtes": ("indicer",),
    "indiçât": ("indicer",),
    "indicée": ("indicer",),
    "indicées": ("indicer",),
    "indicé": ("indicer",),
    "indicent": ("indicer",),
    "indice": ("indicer",),
    "indicera": ("indicer",),
    "indiceraient": ("indicer",),
    "indicerai": ("indicer",),
    "indicerais": ("indicer",),
    "indicerait": ("indicer",),
    "indiceras": ("indicer",),
    "indicèrent": ("indicer",),
    "indicerez": ("indicer",),
    "indiceriez": ("indicer",),
    "indicerions": ("indicer",),
    "indicerons": ("indicer",),
    "indiceront": ("indicer",),
    "indicés": ("indicer",),
    "indices": ("indicer",),
    "indicez": ("indicer",),
    "indiciez": ("indicer",),
    "indicions": ("indicer",),
    "indiçons": ("indicer",),
    "indifférenciaient": ("indifférencier",),
    "indifférenciai": ("indifférencier",),
    "indifférenciais": ("indifférencier",),
    "indifférenciait": ("indifférencier",),
    "indifférencia": ("indifférencier",),
    "indifférenciâmes": ("indifférencier",),
    "indifférenciant": ("indifférencier",),
    "indifférencias": ("indifférencier",),
    "indifférenciassent": ("indifférencier",),
    "indifférenciasses": ("indifférencier",),
    "indifférenciasse": ("indifférencier",),
    "indifférenciassiez": ("indifférencier",),
    "indifférenciassions": ("indifférencier",),
    "indifférenciâtes": ("indifférencier",),
    "indifférenciât": ("indifférencier",),
    "indifférenciée": ("indifférencier",),
    "indifférenciées": ("indifférencier",),
    "indifférencié": ("indifférencier",),
    "indifférencient": ("indifférencier",),
    "indifférencie": ("indifférencier",),
    "indifférenciera": ("indifférencier",),
    "indifférencieraient": ("indifférencier",),
    "indifférencierai": ("indifférencier",),
    "indifférencierais": ("indifférencier",),
    "indifférencierait": ("indifférencier",),
    "indifférencieras": ("indifférencier",),
    "indifférencièrent": ("indifférencier",),
    "indifférencierez": ("indifférencier",),
    "indifférencieriez": ("indifférencier",),
    "indifférencierions": ("indifférencier",),
    "indifférencierons": ("indifférencier",),
    "indifférencieront": ("indifférencier",),
    "indifférenciés": ("indifférencier",),
    "indifférencies": ("indifférencier",),
    "indifférenciez": ("indifférencier",),
    "indifférenciiez": ("indifférencier",),
    "indifférenciions": ("indifférencier",),
    "indifférencions": ("indifférencier",),
    "indifféraient": ("indifférer",),
    "indifférai": ("indifférer",),
    "indifférais": ("indifférer",),
    "indifférait": ("indifférer",),
    "indifféra": ("indifférer",),
    "indifférâmes": ("indifférer",),
    "indifférant": ("indifférer",),
    "indifféras": ("indifférer",),
    "indifférassent": ("indifférer",),
    "indifférasses": ("indifférer",),
    "indifférasse": ("indifférer",),
    "indifférassiez": ("indifférer",),
    "indifférassions": ("indifférer",),
    "indifférâtes": ("indifférer",),
    "indifférât": ("indifférer",),
    "indifférée": ("indifférer",),
    "indifférées": ("indifférer",),
    "indifféré": ("indifférer",),
    "indiffèrent": ("indifférer",),
    "indiffère": ("indifférer",),
    "indifférera": ("indifférer",),
    "indifféreraient": ("indifférer",),
    "indifférerai": ("indifférer",),
    "indifférerais": ("indifférer",),
    "indifférerait": ("indifférer",),
    "indifféreras": ("indifférer",),
    "indifférèrent": ("indifférer",),
    "indifférerez": ("indifférer",),
    "indifféreriez": ("indifférer",),
    "indifférerions": ("indifférer",),
    "indifférerons": ("indifférer",),
    "indifféreront": ("indifférer",),
    "indifférés": ("indifférer",),
    "indiffères": ("indifférer",),
    "indifférez": ("indifférer",),
    "indiffériez": ("indifférer",),
    "indifférions": ("indifférer",),
    "indifférons": ("indifférer",),
    "indigéraient": ("indigérer",),
    "indigérai": ("indigérer",),
    "indigérais": ("indigérer",),
    "indigérait": ("indigérer",),
    "indigéra": ("indigérer",),
    "indigérâmes": ("indigérer",),
    "indigérant": ("indigérer",),
    "indigéras": ("indigérer",),
    "indigérassent": ("indigérer",),
    "indigérasses": ("indigérer",),
    "indigérasse": ("indigérer",),
    "indigérassiez": ("indigérer",),
    "indigérassions": ("indigérer",),
    "indigérâtes": ("indigérer",),
    "indigérât": ("indigérer",),
    "indigérée": ("indigérer",),
    "indigérées": ("indigérer",),
    "indigéré": ("indigérer",),
    "indigèrent": ("indigérer",),
    "indigère": ("indigérer",),
    "indigérera": ("indigérer",),
    "indigéreraient": ("indigérer",),
    "indigérerai": ("indigérer",),
    "indigérerais": ("indigérer",),
    "indigérerait": ("indigérer",),
    "indigéreras": ("indigérer",),
    "indigérèrent": ("indigérer",),
    "indigérerez": ("indigérer",),
    "indigéreriez": ("indigérer",),
    "indigérerions": ("indigérer",),
    "indigérerons": ("indigérer",),
    "indigéreront": ("indigérer",),
    "indigérés": ("indigérer",),
    "indigères": ("indigérer",),
    "indigérez": ("indigérer",),
    "indigériez": ("indigérer",),
    "indigérions": ("indigérer",),
    "indigérons": ("indigérer",),
    "induira": ("induire",),
    "induiraient": ("induire",),
    "induirai": ("induire",),
    "induirais": ("induire",),
    "induirait": ("induire",),
    "induiras": ("induire",),
    "induirez": ("induire",),
    "induiriez": ("induire",),
    "induirions": ("induire",),
    "induirons": ("induire",),
    "induiront": ("induire",),
    "induisaient": ("induire",),
    "induisais": ("induire",),
    "induisait": ("induire",),
    "induisant": ("induire",),
    "induisent": ("induire",),
    "induise": ("induire",),
    "induises": ("induire",),
    "induisez": ("induire",),
    "induisiez": ("induire",),
    "induisîmes": ("induire",),
    "induisions": ("induire",),
    "induisirent": ("induire",),
    "induisis": ("induire",),
    "induisissent": ("induire",),
    "induisisses": ("induire",),
    "induisisse": ("induire",),
    "induisissiez": ("induire",),
    "induisissions": ("induire",),
    "induisîtes": ("induire",),
    "induisit": ("induire",),
    "induisît": ("induire",),
    "induisons": ("induire",),
    "induis": ("induire",),
    "induite": ("induire",),
    "induites": ("induire",),
    "induit": ("induire",),
    "induits": ("induire",),
    "indulgenciaient": ("indulgencier",),
    "indulgenciai": ("indulgencier",),
    "indulgenciais": ("indulgencier",),
    "indulgenciait": ("indulgencier",),
    "indulgencia": ("indulgencier",),
    "indulgenciâmes": ("indulgencier",),
    "indulgenciant": ("indulgencier",),
    "indulgencias": ("indulgencier",),
    "indulgenciassent": ("indulgencier",),
    "indulgenciasses": ("indulgencier",),
    "indulgenciasse": ("indulgencier",),
    "indulgenciassiez": ("indulgencier",),
    "indulgenciassions": ("indulgencier",),
    "indulgenciâtes": ("indulgencier",),
    "indulgenciât": ("indulgencier",),
    "indulgenciée": ("indulgencier",),
    "indulgenciées": ("indulgencier",),
    "indulgencié": ("indulgencier",),
    "indulgencient": ("indulgencier",),
    "indulgencie": ("indulgencier",),
    "indulgenciera": ("indulgencier",),
    "indulgencieraient": ("indulgencier",),
    "indulgencierai": ("indulgencier",),
    "indulgencierais": ("indulgencier",),
    "indulgencierait": ("indulgencier",),
    "indulgencieras": ("indulgencier",),
    "indulgencièrent": ("indulgencier",),
    "indulgencierez": ("indulgencier",),
    "indulgencieriez": ("indulgencier",),
    "indulgencierions": ("indulgencier",),
    "indulgencierons": ("indulgencier",),
    "indulgencieront": ("indulgencier",),
    "indulgenciés": ("indulgencier",),
    "indulgencies": ("indulgencier",),
    "indulgenciez": ("indulgencier",),
    "indulgenciiez": ("indulgencier",),
    "indulgenciions": ("indulgencier",),
    "indulgencions": ("indulgencier",),
    "inféraient": ("inférer",),
    "inférai": ("inférer",),
    "inférais": ("inférer",),
    "inférait": ("inférer",),
    "inféra": ("inférer",),
    "inférâmes": ("inférer",),
    "inférant": ("inférer",),
    "inféras": ("inférer",),
    "inférassent": ("inférer",),
    "inférasses": ("inférer",),
    "inférasse": ("inférer",),
    "inférassiez": ("inférer",),
    "inférassions": ("inférer",),
    "inférâtes": ("inférer",),
    "inférât": ("inférer",),
    "inférée": ("inférer",),
    "inférées": ("inférer",),
    "inféré": ("inférer",),
    "infèrent": ("inférer",),
    "infère": ("inférer",),
    "inférera": ("inférer",),
    "inféreraient": ("inférer",),
    "inférerai": ("inférer",),
    "inférerais": ("inférer",),
    "inférerait": ("inférer",),
    "inféreras": ("inférer",),
    "inférèrent": ("inférer",),
    "inférerez": ("inférer",),
    "inféreriez": ("inférer",),
    "inférerions": ("inférer",),
    "inférerons": ("inférer",),
    "inféreront": ("inférer",),
    "inférés": ("inférer",),
    "infères": ("inférer",),
    "inférez": ("inférer",),
    "infériez": ("inférer",),
    "inférions": ("inférer",),
    "inférons": ("inférer",),
    "infléchie": ("infléchir",),
    "infléchies": ("infléchir",),
    "infléchi": ("infléchir",),
    "infléchîmes": ("infléchir",),
    "infléchira": ("infléchir",),
    "infléchiraient": ("infléchir",),
    "infléchirai": ("infléchir",),
    "infléchirais": ("infléchir",),
    "infléchirait": ("infléchir",),
    "infléchiras": ("infléchir",),
    "infléchirent": ("infléchir",),
    "infléchirez": ("infléchir",),
    "infléchiriez": ("infléchir",),
    "infléchirions": ("infléchir",),
    "infléchirons": ("infléchir",),
    "infléchiront": ("infléchir",),
    "infléchis": ("infléchir",),
    "infléchissaient": ("infléchir",),
    "infléchissais": ("infléchir",),
    "infléchissait": ("infléchir",),
    "infléchissant": ("infléchir",),
    "infléchissent": ("infléchir",),
    "infléchisse": ("infléchir",),
    "infléchisses": ("infléchir",),
    "infléchissez": ("infléchir",),
    "infléchissiez": ("infléchir",),
    "infléchissions": ("infléchir",),
    "infléchissons": ("infléchir",),
    "infléchîtes": ("infléchir",),
    "infléchit": ("infléchir",),
    "infléchît": ("infléchir",),
    "infligeaient": ("infliger",),
    "infligeai": ("infliger",),
    "infligeais": ("infliger",),
    "infligeait": ("infliger",),
    "infligea": ("infliger",),
    "infligeâmes": ("infliger",),
    "infligeant": ("infliger",),
    "infligeas": ("infliger",),
    "infligeassent": ("infliger",),
    "infligeasses": ("infliger",),
    "infligeasse": ("infliger",),
    "infligeassiez": ("infliger",),
    "infligeassions": ("infliger",),
    "infligeâtes": ("infliger",),
    "infligeât": ("infliger",),
    "infligée": ("infliger",),
    "infligées": ("infliger",),
    "infligé": ("infliger",),
    "infligent": ("infliger",),
    "infligeons": ("infliger",),
    "inflige": ("infliger",),
    "infligera": ("infliger",),
    "infligeraient": ("infliger",),
    "infligerai": ("infliger",),
    "infligerais": ("infliger",),
    "infligerait": ("infliger",),
    "infligeras": ("infliger",),
    "infligèrent": ("infliger",),
    "infligerez": ("infliger",),
    "infligeriez": ("infliger",),
    "infligerions": ("infliger",),
    "infligerons": ("infliger",),
    "infligeront": ("infliger",),
    "infligés": ("infliger",),
    "infliges": ("infliger",),
    "infligez": ("infliger",),
    "infligiez": ("infliger",),
    "infligions": ("infliger",),
    "influençaient": ("influencer",),
    "influençai": ("influencer",),
    "influençais": ("influencer",),
    "influençait": ("influencer",),
    "influença": ("influencer",),
    "influençâmes": ("influencer",),
    "influençant": ("influencer",),
    "influenças": ("influencer",),
    "influençassent": ("influencer",),
    "influençasses": ("influencer",),
    "influençasse": ("influencer",),
    "influençassiez": ("influencer",),
    "influençassions": ("influencer",),
    "influençâtes": ("influencer",),
    "influençât": ("influencer",),
    "influencée": ("influencer",),
    "influencées": ("influencer",),
    "influencé": ("influencer",),
    "influencent": ("influencer",),
    "influence": ("influencer",),
    "influencera": ("influencer",),
    "influenceraient": ("influencer",),
    "influencerai": ("influencer",),
    "influencerais": ("influencer",),
    "influencerait": ("influencer",),
    "influenceras": ("influencer",),
    "influencèrent": ("influencer",),
    "influencerez": ("influencer",),
    "influenceriez": ("influencer",),
    "influencerions": ("influencer",),
    "influencerons": ("influencer",),
    "influenceront": ("influencer",),
    "influencés": ("influencer",),
    "influences": ("influencer",),
    "influencez": ("influencer",),
    "influenciez": ("influencer",),
    "influencions": ("influencer",),
    "influençons": ("influencer",),
    "infondaient": ("infondre",),
    "infondais": ("infondre",),
    "infondait": ("infondre",),
    "infondant": ("infondre",),
    "infondent": ("infondre",),
    "infonde": ("infondre",),
    "infondes": ("infondre",),
    "infondez": ("infondre",),
    "infondiez": ("infondre",),
    "infondîmes": ("infondre",),
    "infondions": ("infondre",),
    "infondirent": ("infondre",),
    "infondis": ("infondre",),
    "infondissent": ("infondre",),
    "infondisses": ("infondre",),
    "infondisse": ("infondre",),
    "infondissiez": ("infondre",),
    "infondissions": ("infondre",),
    "infondîtes": ("infondre",),
    "infondit": ("infondre",),
    "infondît": ("infondre",),
    "infondons": ("infondre",),
    "infond": ("infondre",),
    "infondra": ("infondre",),
    "infondraient": ("infondre",),
    "infondrai": ("infondre",),
    "infondrais": ("infondre",),
    "infondrait": ("infondre",),
    "infondras": ("infondre",),
    "infondrez": ("infondre",),
    "infondriez": ("infondre",),
    "infondrions": ("infondre",),
    "infondrons": ("infondre",),
    "infondront": ("infondre",),
    "infonds": ("infondre",),
    "infondue": ("infondre",),
    "infondues": ("infondre",),
    "infondu": ("infondre",),
    "infondus": ("infondre",),
    "ingéniaient": ("ingénier",),
    "ingéniai": ("ingénier",),
    "ingéniais": ("ingénier",),
    "ingéniait": ("ingénier",),
    "ingénia": ("ingénier",),
    "ingéniâmes": ("ingénier",),
    "ingéniant": ("ingénier",),
    "ingénias": ("ingénier",),
    "ingéniassent": ("ingénier",),
    "ingéniasses": ("ingénier",),
    "ingéniasse": ("ingénier",),
    "ingéniassiez": ("ingénier",),
    "ingéniassions": ("ingénier",),
    "ingéniâtes": ("ingénier",),
    "ingéniât": ("ingénier",),
    "ingéniée": ("ingénier",),
    "ingéniées": ("ingénier",),
    "ingénié": ("ingénier",),
    "ingénient": ("ingénier",),
    "ingénie": ("ingénier",),
    "ingéniera": ("ingénier",),
    "ingénieraient": ("ingénier",),
    "ingénierai": ("ingénier",),
    "ingénierais": ("ingénier",),
    "ingénierait": ("ingénier",),
    "ingénieras": ("ingénier",),
    "ingénièrent": ("ingénier",),
    "ingénierez": ("ingénier",),
    "ingénieriez": ("ingénier",),
    "ingénierions": ("ingénier",),
    "ingénierons": ("ingénier",),
    "ingénieront": ("ingénier",),
    "ingéniés": ("ingénier",),
    "ingénies": ("ingénier",),
    "ingéniez": ("ingénier",),
    "ingéniiez": ("ingénier",),
    "ingéniions": ("ingénier",),
    "ingénions": ("ingénier",),
    "ingéraient": ("ingérer",),
    "ingérai": ("ingérer",),
    "ingérais": ("ingérer",),
    "ingérait": ("ingérer",),
    "ingéra": ("ingérer",),
    "ingérâmes": ("ingérer",),
    "ingérant": ("ingérer",),
    "ingéras": ("ingérer",),
    "ingérassent": ("ingérer",),
    "ingérasses": ("ingérer",),
    "ingérasse": ("ingérer",),
    "ingérassiez": ("ingérer",),
    "ingérassions": ("ingérer",),
    "ingérâtes": ("ingérer",),
    "ingérât": ("ingérer",),
    "ingérée": ("ingérer",),
    "ingérées": ("ingérer",),
    "ingéré": ("ingérer",),
    "ingèrent": ("ingérer",),
    "ingère": ("ingérer",),
    "ingérera": ("ingérer",),
    "ingéreraient": ("ingérer",),
    "ingérerai": ("ingérer",),
    "ingérerais": ("ingérer",),
    "ingérerait": ("ingérer",),
    "ingéreras": ("ingérer",),
    "ingérèrent": ("ingérer",),
    "ingérerez": ("ingérer",),
    "ingéreriez": ("ingérer",),
    "ingérerions": ("ingérer",),
    "ingérerons": ("ingérer",),
    "ingéreront": ("ingérer",),
    "ingérés": ("ingérer",),
    "ingères": ("ingérer",),
    "ingérez": ("ingérer",),
    "ingériez": ("ingérer",),
    "ingérions": ("ingérer",),
    "ingérons": ("ingérer",),
    "initiaient": ("initier",),
    "initiai": ("initier",),
    "initiais": ("initier",),
    "initiait": ("initier",),
    "initia": ("initier",),
    "initiâmes": ("initier",),
    "initiant": ("initier",),
    "initias": ("initier",),
    "initiassent": ("initier",),
    "initiasses": ("initier",),
    "initiasse": ("initier",),
    "initiassiez": ("initier",),
    "initiassions": ("initier",),
    "initiâtes": ("initier",),
    "initiât": ("initier",),
    "initiée": ("initier",),
    "initiées": ("initier",),
    "initié": ("initier",),
    "initient": ("initier",),
    "initie": ("initier",),
    "initiera": ("initier",),
    "initieraient": ("initier",),
    "initierai": ("initier",),
    "initierais": ("initier",),
    "initierait": ("initier",),
    "initieras": ("initier",),
    "initièrent": ("initier",),
    "initierez": ("initier",),
    "initieriez": ("initier",),
    "initierions": ("initier",),
    "initierons": ("initier",),
    "initieront": ("initier",),
    "initiés": ("initier",),
    "inities": ("initier",),
    "initiez": ("initier",),
    "initiiez": ("initier",),
    "initiions": ("initier",),
    "initions": ("initier",),
    "injuriaient": ("injurier",),
    "injuriai": ("injurier",),
    "injuriais": ("injurier",),
    "injuriait": ("injurier",),
    "injuria": ("injurier",),
    "injuriâmes": ("injurier",),
    "injuriant": ("injurier",),
    "injurias": ("injurier",),
    "injuriassent": ("injurier",),
    "injuriasses": ("injurier",),
    "injuriasse": ("injurier",),
    "injuriassiez": ("injurier",),
    "injuriassions": ("injurier",),
    "injuriâtes": ("injurier",),
    "injuriât": ("injurier",),
    "injuriée": ("injurier",),
    "injuriées": ("injurier",),
    "injurié": ("injurier",),
    "injurient": ("injurier",),
    "injurie": ("injurier",),
    "injuriera": ("injurier",),
    "injurieraient": ("injurier",),
    "injurierai": ("injurier",),
    "injurierais": ("injurier",),
    "injurierait": ("injurier",),
    "injurieras": ("injurier",),
    "injurièrent": ("injurier",),
    "injurierez": ("injurier",),
    "injurieriez": ("injurier",),
    "injurierions": ("injurier",),
    "injurierons": ("injurier",),
    "injurieront": ("injurier",),
    "injuriés": ("injurier",),
    "injuries": ("injurier",),
    "injuriez": ("injurier",),
    "injuriiez": ("injurier",),
    "injuriions": ("injurier",),
    "injurions": ("injurier",),
    "inquiétaient": ("inquiéter",),
    "inquiétai": ("inquiéter",),
    "inquiétais": ("inquiéter",),
    "inquiétait": ("inquiéter",),
    "inquiéta": ("inquiéter",),
    "inquiétâmes": ("inquiéter",),
    "inquiétant": ("inquiéter",),
    "inquiétas": ("inquiéter",),
    "inquiétassent": ("inquiéter",),
    "inquiétasses": ("inquiéter",),
    "inquiétasse": ("inquiéter",),
    "inquiétassiez": ("inquiéter",),
    "inquiétassions": ("inquiéter",),
    "inquiétâtes": ("inquiéter",),
    "inquiétât": ("inquiéter",),
    "inquiétée": ("inquiéter",),
    "inquiétées": ("inquiéter",),
    "inquiété": ("inquiéter",),
    "inquiètent": ("inquiéter",),
    "inquiète": ("inquiéter",),
    "inquiétera": ("inquiéter",),
    "inquiéteraient": ("inquiéter",),
    "inquiéterai": ("inquiéter",),
    "inquiéterais": ("inquiéter",),
    "inquiéterait": ("inquiéter",),
    "inquiéteras": ("inquiéter",),
    "inquiétèrent": ("inquiéter",),
    "inquiéterez": ("inquiéter",),
    "inquiéteriez": ("inquiéter",),
    "inquiéterions": ("inquiéter",),
    "inquiéterons": ("inquiéter",),
    "inquiéteront": ("inquiéter",),
    "inquiétés": ("inquiéter",),
    "inquiètes": ("inquiéter",),
    "inquiétez": ("inquiéter",),
    "inquiétiez": ("inquiéter",),
    "inquiétions": ("inquiéter",),
    "inquiétons": ("inquiéter",),
    "insatisfaisaient": ("insatisfaire",),
    "insatisfaisais": ("insatisfaire",),
    "insatisfaisait": ("insatisfaire",),
    "insatisfaisant": ("insatisfaire",),
    "insatisfaisiez": ("insatisfaire",),
    "insatisfaisions": ("insatisfaire",),
    "insatisfaisons": ("insatisfaire",),
    "insatisfais": ("insatisfaire",),
    "insatisfaite": ("insatisfaire",),
    "insatisfaites": ("insatisfaire",),
    "insatisfait": ("insatisfaire",),
    "insatisfaits": ("insatisfaire",),
    "insatisfassent": ("insatisfaire",),
    "insatisfasse": ("insatisfaire",),
    "insatisfasses": ("insatisfaire",),
    "insatisfassiez": ("insatisfaire",),
    "insatisfassions": ("insatisfaire",),
    "insatisfera": ("insatisfaire",),
    "insatisferaient": ("insatisfaire",),
    "insatisferai": ("insatisfaire",),
    "insatisferais": ("insatisfaire",),
    "insatisferait": ("insatisfaire",),
    "insatisferas": ("insatisfaire",),
    "insatisferez": ("insatisfaire",),
    "insatisferiez": ("insatisfaire",),
    "insatisferions": ("insatisfaire",),
    "insatisferons": ("insatisfaire",),
    "insatisferont": ("insatisfaire",),
    "insatisfîmes": ("insatisfaire",),
    "insatisfirent": ("insatisfaire",),
    "insatisfis": ("insatisfaire",),
    "insatisfissent": ("insatisfaire",),
    "insatisfisses": ("insatisfaire",),
    "insatisfisse": ("insatisfaire",),
    "insatisfissiez": ("insatisfaire",),
    "insatisfissions": ("insatisfaire",),
    "insatisfîtes": ("insatisfaire",),
    "insatisfit": ("insatisfaire",),
    "insatisfît": ("insatisfaire",),
    "insatisfont": ("insatisfaire",),
    "inscrira": ("inscrire",),
    "inscriraient": ("inscrire",),
    "inscrirai": ("inscrire",),
    "inscrirais": ("inscrire",),
    "inscrirait": ("inscrire",),
    "inscriras": ("inscrire",),
    "inscrirez": ("inscrire",),
    "inscririez": ("inscrire",),
    "inscririons": ("inscrire",),
    "inscrirons": ("inscrire",),
    "inscriront": ("inscrire",),
    "inscris": ("inscrire",),
    "inscrite": ("inscrire",),
    "inscrites": ("inscrire",),
    "inscrit": ("inscrire",),
    "inscrits": ("inscrire",),
    "inscrivaient": ("inscrire",),
    "inscrivais": ("inscrire",),
    "inscrivait": ("inscrire",),
    "inscrivant": ("inscrire",),
    "inscrivent": ("inscrire",),
    "inscrive": ("inscrire",),
    "inscrives": ("inscrire",),
    "inscrivez": ("inscrire",),
    "inscriviez": ("inscrire",),
    "inscrivîmes": ("inscrire",),
    "inscrivions": ("inscrire",),
    "inscrivirent": ("inscrire",),
    "inscrivis": ("inscrire",),
    "inscrivissent": ("inscrire",),
    "inscrivisses": ("inscrire",),
    "inscrivisse": ("inscrire",),
    "inscrivissiez": ("inscrire",),
    "inscrivissions": ("inscrire",),
    "inscrivîtes": ("inscrire",),
    "inscrivit": ("inscrire",),
    "inscrivît": ("inscrire",),
    "inscrivons": ("inscrire",),
    "inséraient": ("insérer",),
    "insérai": ("insérer",),
    "insérais": ("insérer",),
    "insérait": ("insérer",),
    "inséra": ("insérer",),
    "insérâmes": ("insérer",),
    "insérant": ("insérer",),
    "inséras": ("insérer",),
    "insérassent": ("insérer",),
    "insérasses": ("insérer",),
    "insérasse": ("insérer",),
    "insérassiez": ("insérer",),
    "insérassions": ("insérer",),
    "insérâtes": ("insérer",),
    "insérât": ("insérer",),
    "insérée": ("insérer",),
    "insérées": ("insérer",),
    "inséré": ("insérer",),
    "insèrent": ("insérer",),
    "insère": ("insérer",),
    "insérera": ("insérer",),
    "inséreraient": ("insérer",),
    "insérerai": ("insérer",),
    "insérerais": ("insérer",),
    "insérerait": ("insérer",),
    "inséreras": ("insérer",),
    "insérèrent": ("insérer",),
    "insérerez": ("insérer",),
    "inséreriez": ("insérer",),
    "insérerions": ("insérer",),
    "insérerons": ("insérer",),
    "inséreront": ("insérer",),
    "insérés": ("insérer",),
    "insères": ("insérer",),
    "insérez": ("insérer",),
    "insériez": ("insérer",),
    "insérions": ("insérer",),
    "insérons": ("insérer",),
    "instanciaient": ("instancier",),
    "instanciai": ("instancier",),
    "instanciais": ("instancier",),
    "instanciait": ("instancier",),
    "instancia": ("instancier",),
    "instanciâmes": ("instancier",),
    "instanciant": ("instancier",),
    "instancias": ("instancier",),
    "instanciassent": ("instancier",),
    "instanciasses": ("instancier",),
    "instanciasse": ("instancier",),
    "instanciassiez": ("instancier",),
    "instanciassions": ("instancier",),
    "instanciâtes": ("instancier",),
    "instanciât": ("instancier",),
    "instanciée": ("instancier",),
    "instanciées": ("instancier",),
    "instancié": ("instancier",),
    "instancient": ("instancier",),
    "instancie": ("instancier",),
    "instanciera": ("instancier",),
    "instancieraient": ("instancier",),
    "instancierai": ("instancier",),
    "instancierais": ("instancier",),
    "instancierait": ("instancier",),
    "instancieras": ("instancier",),
    "instancièrent": ("instancier",),
    "instancierez": ("instancier",),
    "instancieriez": ("instancier",),
    "instancierions": ("instancier",),
    "instancierons": ("instancier",),
    "instancieront": ("instancier",),
    "instanciés": ("instancier",),
    "instancies": ("instancier",),
    "instanciez": ("instancier",),
    "instanciiez": ("instancier",),
    "instanciions": ("instancier",),
    "instancions": ("instancier",),
    "instruira": ("instruire",),
    "instruiraient": ("instruire",),
    "instruirai": ("instruire",),
    "instruirais": ("instruire",),
    "instruirait": ("instruire",),
    "instruiras": ("instruire",),
    "instruirez": ("instruire",),
    "instruiriez": ("instruire",),
    "instruirions": ("instruire",),
    "instruirons": ("instruire",),
    "instruiront": ("instruire",),
    "instruisaient": ("instruire",),
    "instruisais": ("instruire",),
    "instruisait": ("instruire",),
    "instruisant": ("instruire",),
    "instruisent": ("instruire",),
    "instruise": ("instruire",),
    "instruises": ("instruire",),
    "instruisez": ("instruire",),
    "instruisiez": ("instruire",),
    "instruisîmes": ("instruire",),
    "instruisions": ("instruire",),
    "instruisirent": ("instruire",),
    "instruisis": ("instruire",),
    "instruisissent": ("instruire",),
    "instruisisses": ("instruire",),
    "instruisisse": ("instruire",),
    "instruisissiez": ("instruire",),
    "instruisissions": ("instruire",),
    "instruisîtes": ("instruire",),
    "instruisit": ("instruire",),
    "instruisît": ("instruire",),
    "instruisons": ("instruire",),
    "instruis": ("instruire",),
    "instruite": ("instruire",),
    "instruites": ("instruire",),
    "instruit": ("instruire",),
    "instruits": ("instruire",),
    "insurgeaient": ("insurger",),
    "insurgeai": ("insurger",),
    "insurgeais": ("insurger",),
    "insurgeait": ("insurger",),
    "insurgea": ("insurger",),
    "insurgeâmes": ("insurger",),
    "insurgeant": ("insurger",),
    "insurgeas": ("insurger",),
    "insurgeassent": ("insurger",),
    "insurgeasses": ("insurger",),
    "insurgeasse": ("insurger",),
    "insurgeassiez": ("insurger",),
    "insurgeassions": ("insurger",),
    "insurgeâtes": ("insurger",),
    "insurgeât": ("insurger",),
    "insurgée": ("insurger",),
    "insurgées": ("insurger",),
    "insurgé": ("insurger",),
    "insurgent": ("insurger",),
    "insurgeons": ("insurger",),
    "insurge": ("insurger",),
    "insurgera": ("insurger",),
    "insurgeraient": ("insurger",),
    "insurgerai": ("insurger",),
    "insurgerais": ("insurger",),
    "insurgerait": ("insurger",),
    "insurgeras": ("insurger",),
    "insurgèrent": ("insurger",),
    "insurgerez": ("insurger",),
    "insurgeriez": ("insurger",),
    "insurgerions": ("insurger",),
    "insurgerons": ("insurger",),
    "insurgeront": ("insurger",),
    "insurgés": ("insurger",),
    "insurges": ("insurger",),
    "insurgez": ("insurger",),
    "insurgiez": ("insurger",),
    "insurgions": ("insurger",),
    "intégraient": ("intégrer",),
    "intégrai": ("intégrer",),
    "intégrais": ("intégrer",),
    "intégrait": ("intégrer",),
    "intégra": ("intégrer",),
    "intégrâmes": ("intégrer",),
    "intégrant": ("intégrer",),
    "intégras": ("intégrer",),
    "intégrassent": ("intégrer",),
    "intégrasses": ("intégrer",),
    "intégrasse": ("intégrer",),
    "intégrassiez": ("intégrer",),
    "intégrassions": ("intégrer",),
    "intégrâtes": ("intégrer",),
    "intégrât": ("intégrer",),
    "intégrée": ("intégrer",),
    "intégrées": ("intégrer",),
    "intégré": ("intégrer",),
    "intègrent": ("intégrer",),
    "intègre": ("intégrer",),
    "intégrera": ("intégrer",),
    "intégreraient": ("intégrer",),
    "intégrerai": ("intégrer",),
    "intégrerais": ("intégrer",),
    "intégrerait": ("intégrer",),
    "intégreras": ("intégrer",),
    "intégrèrent": ("intégrer",),
    "intégrerez": ("intégrer",),
    "intégreriez": ("intégrer",),
    "intégrerions": ("intégrer",),
    "intégrerons": ("intégrer",),
    "intégreront": ("intégrer",),
    "intégrés": ("intégrer",),
    "intègres": ("intégrer",),
    "intégrez": ("intégrer",),
    "intégriez": ("intégrer",),
    "intégrions": ("intégrer",),
    "intégrons": ("intégrer",),
    "intensifiaient": ("intensifier",),
    "intensifiai": ("intensifier",),
    "intensifiais": ("intensifier",),
    "intensifiait": ("intensifier",),
    "intensifia": ("intensifier",),
    "intensifiâmes": ("intensifier",),
    "intensifiant": ("intensifier",),
    "intensifias": ("intensifier",),
    "intensifiassent": ("intensifier",),
    "intensifiasses": ("intensifier",),
    "intensifiasse": ("intensifier",),
    "intensifiassiez": ("intensifier",),
    "intensifiassions": ("intensifier",),
    "intensifiâtes": ("intensifier",),
    "intensifiât": ("intensifier",),
    "intensifiée": ("intensifier",),
    "intensifiées": ("intensifier",),
    "intensifié": ("intensifier",),
    "intensifient": ("intensifier",),
    "intensifie": ("intensifier",),
    "intensifiera": ("intensifier",),
    "intensifieraient": ("intensifier",),
    "intensifierai": ("intensifier",),
    "intensifierais": ("intensifier",),
    "intensifierait": ("intensifier",),
    "intensifieras": ("intensifier",),
    "intensifièrent": ("intensifier",),
    "intensifierez": ("intensifier",),
    "intensifieriez": ("intensifier",),
    "intensifierions": ("intensifier",),
    "intensifierons": ("intensifier",),
    "intensifieront": ("intensifier",),
    "intensifiés": ("intensifier",),
    "intensifies": ("intensifier",),
    "intensifiez": ("intensifier",),
    "intensifiiez": ("intensifier",),
    "intensifiions": ("intensifier",),
    "intensifions": ("intensifier",),
    "interagi": ("interagir",),
    "interagîmes": ("interagir",),
    "interagira": ("interagir",),
    "interagiraient": ("interagir",),
    "interagirai": ("interagir",),
    "interagirais": ("interagir",),
    "interagirait": ("interagir",),
    "interagiras": ("interagir",),
    "interagirent": ("interagir",),
    "interagirez": ("interagir",),
    "interagiriez": ("interagir",),
    "interagirions": ("interagir",),
    "interagirons": ("interagir",),
    "interagiront": ("interagir",),
    "interagis": ("interagir",),
    "interagissaient": ("interagir",),
    "interagissais": ("interagir",),
    "interagissait": ("interagir",),
    "interagissant": ("interagir",),
    "interagissent": ("interagir",),
    "interagisse": ("interagir",),
    "interagisses": ("interagir",),
    "interagissez": ("interagir",),
    "interagissiez": ("interagir",),
    "interagissions": ("interagir",),
    "interagissons": ("interagir",),
    "interagîtes": ("interagir",),
    "interagit": ("interagir",),
    "interagît": ("interagir",),
    "intercédaient": ("intercéder",),
    "intercédai": ("intercéder",),
    "intercédais": ("intercéder",),
    "intercédait": ("intercéder",),
    "intercéda": ("intercéder",),
    "intercédâmes": ("intercéder",),
    "intercédant": ("intercéder",),
    "intercédas": ("intercéder",),
    "intercédassent": ("intercéder",),
    "intercédasses": ("intercéder",),
    "intercédasse": ("intercéder",),
    "intercédassiez": ("intercéder",),
    "intercédassions": ("intercéder",),
    "intercédâtes": ("intercéder",),
    "intercédât": ("intercéder",),
    "intercédée": ("intercéder",),
    "intercédées": ("intercéder",),
    "intercédé": ("intercéder",),
    "intercèdent": ("intercéder",),
    "intercède": ("intercéder",),
    "intercédera": ("intercéder",),
    "intercéderaient": ("intercéder",),
    "intercéderai": ("intercéder",),
    "intercéderais": ("intercéder",),
    "intercéderait": ("intercéder",),
    "intercéderas": ("intercéder",),
    "intercédèrent": ("intercéder",),
    "intercéderez": ("intercéder",),
    "intercéderiez": ("intercéder",),
    "intercéderions": ("intercéder",),
    "intercéderons": ("intercéder",),
    "intercéderont": ("intercéder",),
    "intercédés": ("intercéder",),
    "intercèdes": ("intercéder",),
    "intercédez": ("intercéder",),
    "intercédiez": ("intercéder",),
    "intercédions": ("intercéder",),
    "intercédons": ("intercéder",),
    "interchangeaient": ("interchanger",),
    "interchangeai": ("interchanger",),
    "interchangeais": ("interchanger",),
    "interchangeait": ("interchanger",),
    "interchangea": ("interchanger",),
    "interchangeâmes": ("interchanger",),
    "interchangeant": ("interchanger",),
    "interchangeas": ("interchanger",),
    "interchangeassent": ("interchanger",),
    "interchangeasses": ("interchanger",),
    "interchangeasse": ("interchanger",),
    "interchangeassiez": ("interchanger",),
    "interchangeassions": ("interchanger",),
    "interchangeâtes": ("interchanger",),
    "interchangeât": ("interchanger",),
    "interchangée": ("interchanger",),
    "interchangées": ("interchanger",),
    "interchangé": ("interchanger",),
    "interchangent": ("interchanger",),
    "interchangeons": ("interchanger",),
    "interchange": ("interchanger",),
    "interchangera": ("interchanger",),
    "interchangeraient": ("interchanger",),
    "interchangerai": ("interchanger",),
    "interchangerais": ("interchanger",),
    "interchangerait": ("interchanger",),
    "interchangeras": ("interchanger",),
    "interchangèrent": ("interchanger",),
    "interchangerez": ("interchanger",),
    "interchangeriez": ("interchanger",),
    "interchangerions": ("interchanger",),
    "interchangerons": ("interchanger",),
    "interchangeront": ("interchanger",),
    "interchangés": ("interchanger",),
    "interchanges": ("interchanger",),
    "interchangez": ("interchanger",),
    "interchangiez": ("interchanger",),
    "interchangions": ("interchanger",),
    "interclassaient": ("interclasser",),
    "interclassai": ("interclasser",),
    "interclassais": ("interclasser",),
    "interclassait": ("interclasser",),
    "interclassa": ("interclasser",),
    "interclassâmes": ("interclasser",),
    "interclassant": ("interclasser",),
    "interclassas": ("interclasser",),
    "interclassassent": ("interclasser",),
    "interclassasses": ("interclasser",),
    "interclassasse": ("interclasser",),
    "interclassassiez": ("interclasser",),
    "interclassassions": ("interclasser",),
    "interclassâtes": ("interclasser",),
    "interclassât": ("interclasser",),
    "interclassée": ("interclasser",),
    "interclassées": ("interclasser",),
    "interclassé": ("interclasser",),
    "interclassent": ("interclasser",),
    "interclasse": ("interclasser",),
    "interclassera": ("interclasser",),
    "interclasseraient": ("interclasser",),
    "interclasserai": ("interclasser",),
    "interclasserais": ("interclasser",),
    "interclasserait": ("interclasser",),
    "interclasseras": ("interclasser",),
    "interclassèrent": ("interclasser",),
    "interclasserez": ("interclasser",),
    "interclasseriez": ("interclasser",),
    "interclasserions": ("interclasser",),
    "interclasserons": ("interclasser",),
    "interclasseront": ("interclasser",),
    "interclassés": ("interclasser",),
    "interclasses": ("interclasser",),
    "interclassez": ("interclasser",),
    "interclassiez": ("interclasser",),
    "interclassions": ("interclasser",),
    "interclassons": ("interclasser",),
    "interdîmes": ("interdire",),
    "interdira": ("interdire",),
    "interdiraient": ("interdire",),
    "interdirai": ("interdire",),
    "interdirais": ("interdire",),
    "interdirait": ("interdire",),
    "interdiras": ("interdire",),
    "interdirent": ("interdire",),
    "interdirez": ("interdire",),
    "interdiriez": ("interdire",),
    "interdirions": ("interdire",),
    "interdirons": ("interdire",),
    "interdiront": ("interdire",),
    "interdisaient": ("interdire",),
    "interdisais": ("interdire",),
    "interdisait": ("interdire",),
    "interdisant": ("interdire",),
    "interdisent": ("interdire",),
    "interdise": ("interdire",),
    "interdises": ("interdire",),
    "interdisez": ("interdire",),
    "interdisiez": ("interdire",),
    "interdisions": ("interdire",),
    "interdisons": ("interdire",),
    "interdis": ("interdire",),
    "interdissent": ("interdire",),
    "interdisses": ("interdire",),
    "interdisse": ("interdire",),
    "interdissiez": ("interdire",),
    "interdissions": ("interdire",),
    "interdite": ("interdire",),
    "interdîtes": ("interdire",),
    "interdites": ("interdire",),
    "interdit": ("interdire",),
    "interdits": ("interdire",),
    "interdît": ("interdire",),
    "interfaçaient": ("interfacer",),
    "interfaçai": ("interfacer",),
    "interfaçais": ("interfacer",),
    "interfaçait": ("interfacer",),
    "interfaça": ("interfacer",),
    "interfaçâmes": ("interfacer",),
    "interfaçant": ("interfacer",),
    "interfaças": ("interfacer",),
    "interfaçassent": ("interfacer",),
    "interfaçasses": ("interfacer",),
    "interfaçasse": ("interfacer",),
    "interfaçassiez": ("interfacer",),
    "interfaçassions": ("interfacer",),
    "interfaçâtes": ("interfacer",),
    "interfaçât": ("interfacer",),
    "interfacée": ("interfacer",),
    "interfacées": ("interfacer",),
    "interfacé": ("interfacer",),
    "interfacent": ("interfacer",),
    "interface": ("interfacer",),
    "interfacera": ("interfacer",),
    "interfaceraient": ("interfacer",),
    "interfacerai": ("interfacer",),
    "interfacerais": ("interfacer",),
    "interfacerait": ("interfacer",),
    "interfaceras": ("interfacer",),
    "interfacèrent": ("interfacer",),
    "interfacerez": ("interfacer",),
    "interfaceriez": ("interfacer",),
    "interfacerions": ("interfacer",),
    "interfacerons": ("interfacer",),
    "interfaceront": ("interfacer",),
    "interfacés": ("interfacer",),
    "interfaces": ("interfacer",),
    "interfacez": ("interfacer",),
    "interfaciez": ("interfacer",),
    "interfacions": ("interfacer",),
    "interfaçons": ("interfacer",),
    "interféraient": ("interférer",),
    "interférai": ("interférer",),
    "interférais": ("interférer",),
    "interférait": ("interférer",),
    "interféra": ("interférer",),
    "interférâmes": ("interférer",),
    "interférant": ("interférer",),
    "interféras": ("interférer",),
    "interférassent": ("interférer",),
    "interférasses": ("interférer",),
    "interférasse": ("interférer",),
    "interférassiez": ("interférer",),
    "interférassions": ("interférer",),
    "interférâtes": ("interférer",),
    "interférât": ("interférer",),
    "interféré": ("interférer",),
    "interfèrent": ("interférer",),
    "interfère": ("interférer",),
    "interférera": ("interférer",),
    "interféreraient": ("interférer",),
    "interférerai": ("interférer",),
    "interférerais": ("interférer",),
    "interférerait": ("interférer",),
    "interféreras": ("interférer",),
    "interférèrent": ("interférer",),
    "interférerez": ("interférer",),
    "interféreriez": ("interférer",),
    "interférerions": ("interférer",),
    "interférerons": ("interférer",),
    "interféreront": ("interférer",),
    "interfères": ("interférer",),
    "interférez": ("interférer",),
    "interfériez": ("interférer",),
    "interférions": ("interférer",),
    "interférons": ("interférer",),
    "interfoliaient": ("interfolier",),
    "interfoliai": ("interfolier",),
    "interfoliais": ("interfolier",),
    "interfoliait": ("interfolier",),
    "interfolia": ("interfolier",),
    "interfoliâmes": ("interfolier",),
    "interfoliant": ("interfolier",),
    "interfolias": ("interfolier",),
    "interfoliassent": ("interfolier",),
    "interfoliasses": ("interfolier",),
    "interfoliasse": ("interfolier",),
    "interfoliassiez": ("interfolier",),
    "interfoliassions": ("interfolier",),
    "interfoliâtes": ("interfolier",),
    "interfoliât": ("interfolier",),
    "interfoliée": ("interfolier",),
    "interfoliées": ("interfolier",),
    "interfolié": ("interfolier",),
    "interfolient": ("interfolier",),
    "interfolie": ("interfolier",),
    "interfoliera": ("interfolier",),
    "interfolieraient": ("interfolier",),
    "interfolierai": ("interfolier",),
    "interfolierais": ("interfolier",),
    "interfolierait": ("interfolier",),
    "interfolieras": ("interfolier",),
    "interfolièrent": ("interfolier",),
    "interfolierez": ("interfolier",),
    "interfolieriez": ("interfolier",),
    "interfolierions": ("interfolier",),
    "interfolierons": ("interfolier",),
    "interfolieront": ("interfolier",),
    "interfoliés": ("interfolier",),
    "interfolies": ("interfolier",),
    "interfoliez": ("interfolier",),
    "interfoliiez": ("interfolier",),
    "interfoliions": ("interfolier",),
    "interfolions": ("interfolier",),
    "interjetaient": ("interjeter",),
    "interjetai": ("interjeter",),
    "interjetais": ("interjeter",),
    "interjetait": ("interjeter",),
    "interjeta": ("interjeter",),
    "interjetâmes": ("interjeter",),
    "interjetant": ("interjeter",),
    "interjetas": ("interjeter",),
    "interjetassent": ("interjeter",),
    "interjetasses": ("interjeter",),
    "interjetasse": ("interjeter",),
    "interjetassiez": ("interjeter",),
    "interjetassions": ("interjeter",),
    "interjetâtes": ("interjeter",),
    "interjetât": ("interjeter",),
    "interjetée": ("interjeter",),
    "interjetées": ("interjeter",),
    "interjeté": ("interjeter",),
    "interjetèrent": ("interjeter",),
    "interjetés": ("interjeter",),
    "interjetez": ("interjeter",),
    "interjetiez": ("interjeter",),
    "interjetions": ("interjeter",),
    "interjetons": ("interjeter",),
    "interjettent": ("interjeter",),
    "interjette": ("interjeter",),
    "interjettera": ("interjeter",),
    "interjetteraient": ("interjeter",),
    "interjetterai": ("interjeter",),
    "interjetterais": ("interjeter",),
    "interjetterait": ("interjeter",),
    "interjetteras": ("interjeter",),
    "interjetterez": ("interjeter",),
    "interjetteriez": ("interjeter",),
    "interjetterions": ("interjeter",),
    "interjetterons": ("interjeter",),
    "interjetteront": ("interjeter",),
    "interjettes": ("interjeter",),
    "interpénétraient": ("interpénétrer",),
    "interpénétrai": ("interpénétrer",),
    "interpénétrais": ("interpénétrer",),
    "interpénétrait": ("interpénétrer",),
    "interpénétra": ("interpénétrer",),
    "interpénétrâmes": ("interpénétrer",),
    "interpénétrant": ("interpénétrer",),
    "interpénétras": ("interpénétrer",),
    "interpénétrassent": ("interpénétrer",),
    "interpénétrasses": ("interpénétrer",),
    "interpénétrasse": ("interpénétrer",),
    "interpénétrassiez": ("interpénétrer",),
    "interpénétrassions": ("interpénétrer",),
    "interpénétrâtes": ("interpénétrer",),
    "interpénétrât": ("interpénétrer",),
    "interpénétrée": ("interpénétrer",),
    "interpénétrées": ("interpénétrer",),
    "interpénétré": ("interpénétrer",),
    "interpénètrent": ("interpénétrer",),
    "interpénètre": ("interpénétrer",),
    "interpénétrera": ("interpénétrer",),
    "interpénétreraient": ("interpénétrer",),
    "interpénétrerai": ("interpénétrer",),
    "interpénétrerais": ("interpénétrer",),
    "interpénétrerait": ("interpénétrer",),
    "interpénétreras": ("interpénétrer",),
    "interpénétrèrent": ("interpénétrer",),
    "interpénétrerez": ("interpénétrer",),
    "interpénétreriez": ("interpénétrer",),
    "interpénétrerions": ("interpénétrer",),
    "interpénétrerons": ("interpénétrer",),
    "interpénétreront": ("interpénétrer",),
    "interpénétrés": ("interpénétrer",),
    "interpénètres": ("interpénétrer",),
    "interpénétrez": ("interpénétrer",),
    "interpénétriez": ("interpénétrer",),
    "interpénétrions": ("interpénétrer",),
    "interpénétrons": ("interpénétrer",),
    "interprétaient": ("interpréter",),
    "interprétai": ("interpréter",),
    "interprétais": ("interpréter",),
    "interprétait": ("interpréter",),
    "interpréta": ("interpréter",),
    "interprétâmes": ("interpréter",),
    "interprétant": ("interpréter",),
    "interprétas": ("interpréter",),
    "interprétassent": ("interpréter",),
    "interprétasses": ("interpréter",),
    "interprétasse": ("interpréter",),
    "interprétassiez": ("interpréter",),
    "interprétassions": ("interpréter",),
    "interprétâtes": ("interpréter",),
    "interprétât": ("interpréter",),
    "interprétée": ("interpréter",),
    "interprétées": ("interpréter",),
    "interprété": ("interpréter",),
    "interprètent": ("interpréter",),
    "interprète": ("interpréter",),
    "interprétera": ("interpréter",),
    "interpréteraient": ("interpréter",),
    "interpréterai": ("interpréter",),
    "interpréterais": ("interpréter",),
    "interpréterait": ("interpréter",),
    "interpréteras": ("interpréter",),
    "interprétèrent": ("interpréter",),
    "interpréterez": ("interpréter",),
    "interpréteriez": ("interpréter",),
    "interpréterions": ("interpréter",),
    "interpréterons": ("interpréter",),
    "interpréteront": ("interpréter",),
    "interprétés": ("interpréter",),
    "interprètes": ("interpréter",),
    "interprétez": ("interpréter",),
    "interprétiez": ("interpréter",),
    "interprétions": ("interpréter",),
    "interprétons": ("interpréter",),
    "interrogeaient": ("interroger",),
    "interrogeai": ("interroger",),
    "interrogeais": ("interroger",),
    "interrogeait": ("interroger",),
    "interrogea": ("interroger",),
    "interrogeâmes": ("interroger",),
    "interrogeant": ("interroger",),
    "interrogeas": ("interroger",),
    "interrogeassent": ("interroger",),
    "interrogeasses": ("interroger",),
    "interrogeasse": ("interroger",),
    "interrogeassiez": ("interroger",),
    "interrogeassions": ("interroger",),
    "interrogeâtes": ("interroger",),
    "interrogeât": ("interroger",),
    "interrogée": ("interroger",),
    "interrogées": ("interroger",),
    "interrogé": ("interroger",),
    "interrogent": ("interroger",),
    "interrogeons": ("interroger",),
    "interroge": ("interroger",),
    "interrogera": ("interroger",),
    "interrogeraient": ("interroger",),
    "interrogerai": ("interroger",),
    "interrogerais": ("interroger",),
    "interrogerait": ("interroger",),
    "interrogeras": ("interroger",),
    "interrogèrent": ("interroger",),
    "interrogerez": ("interroger",),
    "interrogeriez": ("interroger",),
    "interrogerions": ("interroger",),
    "interrogerons": ("interroger",),
    "interrogeront": ("interroger",),
    "interrogés": ("interroger",),
    "interroges": ("interroger",),
    "interrogez": ("interroger",),
    "interrogiez": ("interroger",),
    "interrogions": ("interroger",),
    "interrompaient": ("interrompre",),
    "interrompais": ("interrompre",),
    "interrompait": ("interrompre",),
    "interrompant": ("interrompre",),
    "interrompent": ("interrompre",),
    "interrompe": ("interrompre",),
    "interrompes": ("interrompre",),
    "interrompez": ("interrompre",),
    "interrompiez": ("interrompre",),
    "interrompîmes": ("interrompre",),
    "interrompions": ("interrompre",),
    "interrompirent": ("interrompre",),
    "interrompis": ("interrompre",),
    "interrompissent": ("interrompre",),
    "interrompisses": ("interrompre",),
    "interrompisse": ("interrompre",),
    "interrompissiez": ("interrompre",),
    "interrompissions": ("interrompre",),
    "interrompîtes": ("interrompre",),
    "interrompit": ("interrompre",),
    "interrompît": ("interrompre",),
    "interrompons": ("interrompre",),
    "interrompra": ("interrompre",),
    "interrompraient": ("interrompre",),
    "interromprai": ("interrompre",),
    "interromprais": ("interrompre",),
    "interromprait": ("interrompre",),
    "interrompras": ("interrompre",),
    "interromprez": ("interrompre",),
    "interrompriez": ("interrompre",),
    "interromprions": ("interrompre",),
    "interromprons": ("interrompre",),
    "interrompront": ("interrompre",),
    "interromps": ("interrompre",),
    "interrompt": ("interrompre",),
    "interrompue": ("interrompre",),
    "interrompues": ("interrompre",),
    "interrompu": ("interrompre",),
    "interrompus": ("interrompre",),
    "intervenaient": ("intervenir",),
    "intervenais": ("intervenir",),
    "intervenait": ("intervenir",),
    "intervenant": ("intervenir",),
    "intervenez": ("intervenir",),
    "interveniez": ("intervenir",),
    "intervenions": ("intervenir",),
    "intervenons": ("intervenir",),
    "intervenue": ("intervenir",),
    "intervenues": ("intervenir",),
    "intervenu": ("intervenir",),
    "intervenus": ("intervenir",),
    "interviendra": ("intervenir",),
    "interviendraient": ("intervenir",),
    "interviendrai": ("intervenir",),
    "interviendrais": ("intervenir",),
    "interviendrait": ("intervenir",),
    "interviendras": ("intervenir",),
    "interviendrez": ("intervenir",),
    "interviendriez": ("intervenir",),
    "interviendrions": ("intervenir",),
    "interviendrons": ("intervenir",),
    "interviendront": ("intervenir",),
    "interviennent": ("intervenir",),
    "intervienne": ("intervenir",),
    "interviennes": ("intervenir",),
    "interviens": ("intervenir",),
    "intervient": ("intervenir",),
    "intervînmes": ("intervenir",),
    "intervinrent": ("intervenir",),
    "intervins": ("intervenir",),
    "intervinssent": ("intervenir",),
    "intervinsses": ("intervenir",),
    "intervinsse": ("intervenir",),
    "intervinssiez": ("intervenir",),
    "intervinssions": ("intervenir",),
    "intervîntes": ("intervenir",),
    "intervint": ("intervenir",),
    "intervînt": ("intervenir",),
    "intervertie": ("intervertir",),
    "interverties": ("intervertir",),
    "interverti": ("intervertir",),
    "intervertîmes": ("intervertir",),
    "intervertira": ("intervertir",),
    "intervertiraient": ("intervertir",),
    "intervertirai": ("intervertir",),
    "intervertirais": ("intervertir",),
    "intervertirait": ("intervertir",),
    "intervertiras": ("intervertir",),
    "intervertirent": ("intervertir",),
    "intervertirez": ("intervertir",),
    "intervertiriez": ("intervertir",),
    "intervertirions": ("intervertir",),
    "intervertirons": ("intervertir",),
    "intervertiront": ("intervertir",),
    "intervertis": ("intervertir",),
    "intervertissaient": ("intervertir",),
    "intervertissais": ("intervertir",),
    "intervertissait": ("intervertir",),
    "intervertissant": ("intervertir",),
    "intervertissent": ("intervertir",),
    "intervertisse": ("intervertir",),
    "intervertisses": ("intervertir",),
    "intervertissez": ("intervertir",),
    "intervertissiez": ("intervertir",),
    "intervertissions": ("intervertir",),
    "intervertissons": ("intervertir",),
    "intervertîtes": ("intervertir",),
    "intervertit": ("intervertir",),
    "intervertît": ("intervertir",),
    "introduira": ("introduire",),
    "introduiraient": ("introduire",),
    "introduirai": ("introduire",),
    "introduirais": ("introduire",),
    "introduirait": ("introduire",),
    "introduiras": ("introduire",),
    "introduirez": ("introduire",),
    "introduiriez": ("introduire",),
    "introduirions": ("introduire",),
    "introduirons": ("introduire",),
    "introduiront": ("introduire",),
    "introduisaient": ("introduire",),
    "introduisais": ("introduire",),
    "introduisait": ("introduire",),
    "introduisant": ("introduire",),
    "introduisent": ("introduire",),
    "introduise": ("introduire",),
    "introduises": ("introduire",),
    "introduisez": ("introduire",),
    "introduisiez": ("introduire",),
    "introduisîmes": ("introduire",),
    "introduisions": ("introduire",),
    "introduisirent": ("introduire",),
    "introduisis": ("introduire",),
    "introduisissent": ("introduire",),
    "introduisisses": ("introduire",),
    "introduisisse": ("introduire",),
    "introduisissiez": ("introduire",),
    "introduisissions": ("introduire",),
    "introduisîtes": ("introduire",),
    "introduisit": ("introduire",),
    "introduisît": ("introduire",),
    "introduisons": ("introduire",),
    "introduis": ("introduire",),
    "introduite": ("introduire",),
    "introduites": ("introduire",),
    "introduit": ("introduire",),
    "introduits": ("introduire",),
    "introjetaient": ("introjeter",),
    "introjetai": ("introjeter",),
    "introjetais": ("introjeter",),
    "introjetait": ("introjeter",),
    "introjeta": ("introjeter",),
    "introjetâmes": ("introjeter",),
    "introjetant": ("introjeter",),
    "introjetas": ("introjeter",),
    "introjetassent": ("introjeter",),
    "introjetasses": ("introjeter",),
    "introjetasse": ("introjeter",),
    "introjetassiez": ("introjeter",),
    "introjetassions": ("introjeter",),
    "introjetâtes": ("introjeter",),
    "introjetât": ("introjeter",),
    "introjetée": ("introjeter",),
    "introjetées": ("introjeter",),
    "introjeté": ("introjeter",),
    "introjetèrent": ("introjeter",),
    "introjetés": ("introjeter",),
    "introjetez": ("introjeter",),
    "introjetiez": ("introjeter",),
    "introjetions": ("introjeter",),
    "introjetons": ("introjeter",),
    "introjettent": ("introjeter",),
    "introjette": ("introjeter",),
    "introjettera": ("introjeter",),
    "introjetteraient": ("introjeter",),
    "introjetterai": ("introjeter",),
    "introjetterais": ("introjeter",),
    "introjetterait": ("introjeter",),
    "introjetteras": ("introjeter",),
    "introjetterez": ("introjeter",),
    "introjetteriez": ("introjeter",),
    "introjetterions": ("introjeter",),
    "introjetterons": ("introjeter",),
    "introjetteront": ("introjeter",),
    "introjettes": ("introjeter",),
    "intromet": ("intromettre",),
    "intromets": ("intromettre",),
    "intromettaient": ("intromettre",),
    "intromettais": ("intromettre",),
    "intromettait": ("intromettre",),
    "intromettant": ("intromettre",),
    "intromettent": ("intromettre",),
    "intromette": ("intromettre",),
    "intromettes": ("intromettre",),
    "intromettez": ("intromettre",),
    "intromettiez": ("intromettre",),
    "intromettions": ("intromettre",),
    "intromettons": ("intromettre",),
    "intromettra": ("intromettre",),
    "intromettraient": ("intromettre",),
    "intromettrai": ("intromettre",),
    "intromettrais": ("intromettre",),
    "intromettrait": ("intromettre",),
    "intromettras": ("intromettre",),
    "intromettrez": ("intromettre",),
    "intromettriez": ("intromettre",),
    "intromettrions": ("intromettre",),
    "intromettrons": ("intromettre",),
    "intromettront": ("intromettre",),
    "intromîmes": ("intromettre",),
    "intromirent": ("intromettre",),
    "intromise": ("intromettre",),
    "intromises": ("intromettre",),
    "intromis": ("intromettre",),
    "intromissent": ("intromettre",),
    "intromisses": ("intromettre",),
    "intromisse": ("intromettre",),
    "intromissiez": ("intromettre",),
    "intromissions": ("intromettre",),
    "intromîtes": ("intromettre",),
    "intromit": ("intromettre",),
    "intromît": ("intromettre",),
    "introvertie": ("introvertir",),
    "introverties": ("introvertir",),
    "introverti": ("introvertir",),
    "introvertîmes": ("introvertir",),
    "introvertira": ("introvertir",),
    "introvertiraient": ("introvertir",),
    "introvertirai": ("introvertir",),
    "introvertirais": ("introvertir",),
    "introvertirait": ("introvertir",),
    "introvertiras": ("introvertir",),
    "introvertirent": ("introvertir",),
    "introvertirez": ("introvertir",),
    "introvertiriez": ("introvertir",),
    "introvertirions": ("introvertir",),
    "introvertirons": ("introvertir",),
    "introvertiront": ("introvertir",),
    "introvertis": ("introvertir",),
    "introvertissaient": ("introvertir",),
    "introvertissais": ("introvertir",),
    "introvertissait": ("introvertir",),
    "introvertissant": ("introvertir",),
    "introvertissent": ("introvertir",),
    "introvertisse": ("introvertir",),
    "introvertisses": ("introvertir",),
    "introvertissez": ("introvertir",),
    "introvertissiez": ("introvertir",),
    "introvertissions": ("introvertir",),
    "introvertissons": ("introvertir",),
    "introvertîtes": ("introvertir",),
    "introvertit": ("introvertir",),
    "introvertît": ("introvertir",),
    "inventoriaient": ("inventorier",),
    "inventoriai": ("inventorier",),
    "inventoriais": ("inventorier",),
    "inventoriait": ("inventorier",),
    "inventoria": ("inventorier",),
    "inventoriâmes": ("inventorier",),
    "inventoriant": ("inventorier",),
    "inventorias": ("inventorier",),
    "inventoriassent": ("inventorier",),
    "inventoriasses": ("inventorier",),
    "inventoriasse": ("inventorier",),
    "inventoriassiez": ("inventorier",),
    "inventoriassions": ("inventorier",),
    "inventoriâtes": ("inventorier",),
    "inventoriât": ("inventorier",),
    "inventoriée": ("inventorier",),
    "inventoriées": ("inventorier",),
    "inventorié": ("inventorier",),
    "inventorient": ("inventorier",),
    "inventorie": ("inventorier",),
    "inventoriera": ("inventorier",),
    "inventorieraient": ("inventorier",),
    "inventorierai": ("inventorier",),
    "inventorierais": ("inventorier",),
    "inventorierait": ("inventorier",),
    "inventorieras": ("inventorier",),
    "inventorièrent": ("inventorier",),
    "inventorierez": ("inventorier",),
    "inventorieriez": ("inventorier",),
    "inventorierions": ("inventorier",),
    "inventorierons": ("inventorier",),
    "inventorieront": ("inventorier",),
    "inventoriés": ("inventorier",),
    "inventories": ("inventorier",),
    "inventoriez": ("inventorier",),
    "inventoriiez": ("inventorier",),
    "inventoriions": ("inventorier",),
    "inventorions": ("inventorier",),
    "invertie": ("invertir",),
    "inverties": ("invertir",),
    "inverti": ("invertir",),
    "invertîmes": ("invertir",),
    "invertira": ("invertir",),
    "invertiraient": ("invertir",),
    "invertirai": ("invertir",),
    "invertirais": ("invertir",),
    "invertirait": ("invertir",),
    "invertiras": ("invertir",),
    "invertirent": ("invertir",),
    "invertirez": ("invertir",),
    "invertiriez": ("invertir",),
    "invertirions": ("invertir",),
    "invertirons": ("invertir",),
    "invertiront": ("invertir",),
    "invertis": ("invertir",),
    "invertissaient": ("invertir",),
    "invertissais": ("invertir",),
    "invertissait": ("invertir",),
    "invertissant": ("invertir",),
    "invertissent": ("invertir",),
    "invertisse": ("invertir",),
    "invertisses": ("invertir",),
    "invertissez": ("invertir",),
    "invertissiez": ("invertir",),
    "invertissions": ("invertir",),
    "invertissons": ("invertir",),
    "invertîtes": ("invertir",),
    "invertit": ("invertir",),
    "invertît": ("invertir",),
    "investie": ("investir",),
    "investies": ("investir",),
    "investi": ("investir",),
    "investîmes": ("investir",),
    "investira": ("investir",),
    "investiraient": ("investir",),
    "investirai": ("investir",),
    "investirais": ("investir",),
    "investirait": ("investir",),
    "investiras": ("investir",),
    "investirent": ("investir",),
    "investirez": ("investir",),
    "investiriez": ("investir",),
    "investirions": ("investir",),
    "investirons": ("investir",),
    "investiront": ("investir",),
    "investis": ("investir",),
    "investissaient": ("investir",),
    "investissais": ("investir",),
    "investissait": ("investir",),
    "investissant": ("investir",),
    "investissent": ("investir",),
    "investisse": ("investir",),
    "investisses": ("investir",),
    "investissez": ("investir",),
    "investissiez": ("investir",),
    "investissions": ("investir",),
    "investissons": ("investir",),
    "investîtes": ("investir",),
    "investit": ("investir",),
    "investît": ("investir",),
    "invétéraient": ("invétérer",),
    "invétérai": ("invétérer",),
    "invétérais": ("invétérer",),
    "invétérait": ("invétérer",),
    "invétéra": ("invétérer",),
    "invétérâmes": ("invétérer",),
    "invétérant": ("invétérer",),
    "invétéras": ("invétérer",),
    "invétérassent": ("invétérer",),
    "invétérasses": ("invétérer",),
    "invétérasse": ("invétérer",),
    "invétérassiez": ("invétérer",),
    "invétérassions": ("invétérer",),
    "invétérâtes": ("invétérer",),
    "invétérât": ("invétérer",),
    "invétérée": ("invétérer",),
    "invétérées": ("invétérer",),
    "invétéré": ("invétérer",),
    "invétèrent": ("invétérer",),
    "invétère": ("invétérer",),
    "invétérera": ("invétérer",),
    "invétéreraient": ("invétérer",),
    "invétérerai": ("invétérer",),
    "invétérerais": ("invétérer",),
    "invétérerait": ("invétérer",),
    "invétéreras": ("invétérer",),
    "invétérèrent": ("invétérer",),
    "invétérerez": ("invétérer",),
    "invétéreriez": ("invétérer",),
    "invétérerions": ("invétérer",),
    "invétérerons": ("invétérer",),
    "invétéreront": ("invétérer",),
    "invétérés": ("invétérer",),
    "invétères": ("invétérer",),
    "invétérez": ("invétérer",),
    "invétériez": ("invétérer",),
    "invétérions": ("invétérer",),
    "invétérons": ("invétérer",),
    "inviscéraient": ("inviscérer",),
    "inviscérai": ("inviscérer",),
    "inviscérais": ("inviscérer",),
    "inviscérait": ("inviscérer",),
    "inviscéra": ("inviscérer",),
    "inviscérâmes": ("inviscérer",),
    "inviscérant": ("inviscérer",),
    "inviscéras": ("inviscérer",),
    "inviscérassent": ("inviscérer",),
    "inviscérasses": ("inviscérer",),
    "inviscérasse": ("inviscérer",),
    "inviscérassiez": ("inviscérer",),
    "inviscérassions": ("inviscérer",),
    "inviscérâtes": ("inviscérer",),
    "inviscérât": ("inviscérer",),
    "inviscérée": ("inviscérer",),
    "inviscérées": ("inviscérer",),
    "inviscéré": ("inviscérer",),
    "inviscèrent": ("inviscérer",),
    "inviscère": ("inviscérer",),
    "inviscérera": ("inviscérer",),
    "inviscéreraient": ("inviscérer",),
    "inviscérerai": ("inviscérer",),
    "inviscérerais": ("inviscérer",),
    "inviscérerait": ("inviscérer",),
    "inviscéreras": ("inviscérer",),
    "inviscérèrent": ("inviscérer",),
    "inviscérerez": ("inviscérer",),
    "inviscéreriez": ("inviscérer",),
    "inviscérerions": ("inviscérer",),
    "inviscérerons": ("inviscérer",),
    "inviscéreront": ("inviscérer",),
    "inviscérés": ("inviscérer",),
    "inviscères": ("inviscérer",),
    "inviscérez": ("inviscérer",),
    "inviscériez": ("inviscérer",),
    "inviscérions": ("inviscérer",),
    "inviscérons": ("inviscérer",),
    "irradiaient": ("irradier",),
    "irradiai": ("irradier",),
    "irradiais": ("irradier",),
    "irradiait": ("irradier",),
    "irradia": ("irradier",),
    "irradiâmes": ("irradier",),
    "irradiant": ("irradier",),
    "irradias": ("irradier",),
    "irradiassent": ("irradier",),
    "irradiasses": ("irradier",),
    "irradiasse": ("irradier",),
    "irradiassiez": ("irradier",),
    "irradiassions": ("irradier",),
    "irradiâtes": ("irradier",),
    "irradiât": ("irradier",),
    "irradiée": ("irradier",),
    "irradiées": ("irradier",),
    "irradié": ("irradier",),
    "irradient": ("irradier",),
    "irradie": ("irradier",),
    "irradiera": ("irradier",),
    "irradieraient": ("irradier",),
    "irradierai": ("irradier",),
    "irradierais": ("irradier",),
    "irradierait": ("irradier",),
    "irradieras": ("irradier",),
    "irradièrent": ("irradier",),
    "irradierez": ("irradier",),
    "irradieriez": ("irradier",),
    "irradierions": ("irradier",),
    "irradierons": ("irradier",),
    "irradieront": ("irradier",),
    "irradiés": ("irradier",),
    "irradies": ("irradier",),
    "irradiez": ("irradier",),
    "irradiiez": ("irradier",),
    "irradiions": ("irradier",),
    "irradions": ("irradier",),
    "ischémiaient": ("ischémier",),
    "ischémiai": ("ischémier",),
    "ischémiais": ("ischémier",),
    "ischémiait": ("ischémier",),
    "ischémia": ("ischémier",),
    "ischémiâmes": ("ischémier",),
    "ischémiant": ("ischémier",),
    "ischémias": ("ischémier",),
    "ischémiassent": ("ischémier",),
    "ischémiasses": ("ischémier",),
    "ischémiasse": ("ischémier",),
    "ischémiassiez": ("ischémier",),
    "ischémiassions": ("ischémier",),
    "ischémiâtes": ("ischémier",),
    "ischémiât": ("ischémier",),
    "ischémiée": ("ischémier",),
    "ischémiées": ("ischémier",),
    "ischémié": ("ischémier",),
    "ischémient": ("ischémier",),
    "ischémie": ("ischémier",),
    "ischémiera": ("ischémier",),
    "ischémieraient": ("ischémier",),
    "ischémierai": ("ischémier",),
    "ischémierais": ("ischémier",),
    "ischémierait": ("ischémier",),
    "ischémieras": ("ischémier",),
    "ischémièrent": ("ischémier",),
    "ischémierez": ("ischémier",),
    "ischémieriez": ("ischémier",),
    "ischémierions": ("ischémier",),
    "ischémierons": ("ischémier",),
    "ischémieront": ("ischémier",),
    "ischémiés": ("ischémier",),
    "ischémies": ("ischémier",),
    "ischémiez": ("ischémier",),
    "ischémiiez": ("ischémier",),
    "ischémiions": ("ischémier",),
    "ischémions": ("ischémier",),
    "itéraient": ("itérer",),
    "itérai": ("itérer",),
    "itérais": ("itérer",),
    "itérait": ("itérer",),
    "itéra": ("itérer",),
    "itérâmes": ("itérer",),
    "itérant": ("itérer",),
    "itéras": ("itérer",),
    "itérassent": ("itérer",),
    "itérasses": ("itérer",),
    "itérasse": ("itérer",),
    "itérassiez": ("itérer",),
    "itérassions": ("itérer",),
    "itérâtes": ("itérer",),
    "itérât": ("itérer",),
    "itérée": ("itérer",),
    "itérées": ("itérer",),
    "itéré": ("itérer",),
    "itèrent": ("itérer",),
    "itère": ("itérer",),
    "itérera": ("itérer",),
    "itéreraient": ("itérer",),
    "itérerai": ("itérer",),
    "itérerais": ("itérer",),
    "itérerait": ("itérer",),
    "itéreras": ("itérer",),
    "itérèrent": ("itérer",),
    "itérerez": ("itérer",),
    "itéreriez": ("itérer",),
    "itérerions": ("itérer",),
    "itérerons": ("itérer",),
    "itéreront": ("itérer",),
    "itérés": ("itérer",),
    "itères": ("itérer",),
    "itérez": ("itérer",),
    "itériez": ("itérer",),
    "itérions": ("itérer",),
    "itérons": ("itérer",),
    "itinéraient": ("itinérer",),
    "itinérai": ("itinérer",),
    "itinérais": ("itinérer",),
    "itinérait": ("itinérer",),
    "itinéra": ("itinérer",),
    "itinérâmes": ("itinérer",),
    "itinérant": ("itinérer",),
    "itinéras": ("itinérer",),
    "itinérassent": ("itinérer",),
    "itinérasses": ("itinérer",),
    "itinérasse": ("itinérer",),
    "itinérassiez": ("itinérer",),
    "itinérassions": ("itinérer",),
    "itinérâtes": ("itinérer",),
    "itinérât": ("itinérer",),
    "itinéré": ("itinérer",),
    "itinèrent": ("itinérer",),
    "itinère": ("itinérer",),
    "itinérera": ("itinérer",),
    "itinéreraient": ("itinérer",),
    "itinérerai": ("itinérer",),
    "itinérerais": ("itinérer",),
    "itinérerait": ("itinérer",),
    "itinéreras": ("itinérer",),
    "itinérèrent": ("itinérer",),
    "itinérerez": ("itinérer",),
    "itinéreriez": ("itinérer",),
    "itinérerions": ("itinérer",),
    "itinérerons": ("itinérer",),
    "itinéreront": ("itinérer",),
    "itinères": ("itinérer",),
    "itinérez": ("itinérer",),
    "itinériez": ("itinérer",),
    "itinérions": ("itinérer",),
    "itinérons": ("itinérer",),
    "jacassaient": ("jacasser",),
    "jacassai": ("jacasser",),
    "jacassais": ("jacasser",),
    "jacassait": ("jacasser",),
    "jacassa": ("jacasser",),
    "jacassâmes": ("jacasser",),
    "jacassant": ("jacasser",),
    "jacassas": ("jacasser",),
    "jacassassent": ("jacasser",),
    "jacassasses": ("jacasser",),
    "jacassasse": ("jacasser",),
    "jacassassiez": ("jacasser",),
    "jacassassions": ("jacasser",),
    "jacassâtes": ("jacasser",),
    "jacassât": ("jacasser",),
    "jacassé": ("jacasser",),
    "jacassent": ("jacasser",),
    "jacasse": ("jacasser",),
    "jacassera": ("jacasser",),
    "jacasseraient": ("jacasser",),
    "jacasserai": ("jacasser",),
    "jacasserais": ("jacasser",),
    "jacasserait": ("jacasser",),
    "jacasseras": ("jacasser",),
    "jacassèrent": ("jacasser",),
    "jacasserez": ("jacasser",),
    "jacasseriez": ("jacasser",),
    "jacasserions": ("jacasser",),
    "jacasserons": ("jacasser",),
    "jacasseront": ("jacasser",),
    "jacasses": ("jacasser",),
    "jacassez": ("jacasser",),
    "jacassiez": ("jacasser",),
    "jacassions": ("jacasser",),
    "jacassons": ("jacasser",),
    "jachéraient": ("jachérer",),
    "jachérai": ("jachérer",),
    "jachérais": ("jachérer",),
    "jachérait": ("jachérer",),
    "jachéra": ("jachérer",),
    "jachérâmes": ("jachérer",),
    "jachérant": ("jachérer",),
    "jachéras": ("jachérer",),
    "jachérassent": ("jachérer",),
    "jachérasses": ("jachérer",),
    "jachérasse": ("jachérer",),
    "jachérassiez": ("jachérer",),
    "jachérassions": ("jachérer",),
    "jachérâtes": ("jachérer",),
    "jachérât": ("jachérer",),
    "jachérée": ("jachérer",),
    "jachérées": ("jachérer",),
    "jachéré": ("jachérer",),
    "jachèrent": ("jachérer",),
    "jachère": ("jachérer",),
    "jachérera": ("jachérer",),
    "jachéreraient": ("jachérer",),
    "jachérerai": ("jachérer",),
    "jachérerais": ("jachérer",),
    "jachérerait": ("jachérer",),
    "jachéreras": ("jachérer",),
    "jachérèrent": ("jachérer",),
    "jachérerez": ("jachérer",),
    "jachéreriez": ("jachérer",),
    "jachérerions": ("jachérer",),
    "jachérerons": ("jachérer",),
    "jachéreront": ("jachérer",),
    "jachérés": ("jachérer",),
    "jachères": ("jachérer",),
    "jachérez": ("jachérer",),
    "jachériez": ("jachérer",),
    "jachérions": ("jachérer",),
    "jachérons": ("jachérer",),
    "jaillie": ("jaillir",),
    "jaillies": ("jaillir",),
    "jailli": ("jaillir",),
    "jaillîmes": ("jaillir",),
    "jaillira": ("jaillir",),
    "jailliraient": ("jaillir",),
    "jaillirai": ("jaillir",),
    "jaillirais": ("jaillir",),
    "jaillirait": ("jaillir",),
    "jailliras": ("jaillir",),
    "jaillirent": ("jaillir",),
    "jaillirez": ("jaillir",),
    "jailliriez": ("jaillir",),
    "jaillirions": ("jaillir",),
    "jaillirons": ("jaillir",),
    "jailliront": ("jaillir",),
    "jaillis": ("jaillir",),
    "jaillissaient": ("jaillir",),
    "jaillissais": ("jaillir",),
    "jaillissait": ("jaillir",),
    "jaillissant": ("jaillir",),
    "jaillissent": ("jaillir",),
    "jaillisse": ("jaillir",),
    "jaillisses": ("jaillir",),
    "jaillissez": ("jaillir",),
    "jaillissiez": ("jaillir",),
    "jaillissions": ("jaillir",),
    "jaillissons": ("jaillir",),
    "jaillîtes": ("jaillir",),
    "jaillit": ("jaillir",),
    "jaillît": ("jaillir",),
    "jarretaient": ("jarreter",),
    "jarretai": ("jarreter",),
    "jarretais": ("jarreter",),
    "jarretait": ("jarreter",),
    "jarreta": ("jarreter",),
    "jarretâmes": ("jarreter",),
    "jarretant": ("jarreter",),
    "jarretas": ("jarreter",),
    "jarretassent": ("jarreter",),
    "jarretasses": ("jarreter",),
    "jarretasse": ("jarreter",),
    "jarretassiez": ("jarreter",),
    "jarretassions": ("jarreter",),
    "jarretâtes": ("jarreter",),
    "jarretât": ("jarreter",),
    "jarretée": ("jarreter",),
    "jarretées": ("jarreter",),
    "jarreté": ("jarreter",),
    "jarretèrent": ("jarreter",),
    "jarretés": ("jarreter",),
    "jarretez": ("jarreter",),
    "jarretiez": ("jarreter",),
    "jarretions": ("jarreter",),
    "jarretons": ("jarreter",),
    "jarrettent": ("jarreter",),
    "jarrette": ("jarreter",),
    "jarrettera": ("jarreter",),
    "jarretteraient": ("jarreter",),
    "jarretterai": ("jarreter",),
    "jarretterais": ("jarreter",),
    "jarretterait": ("jarreter",),
    "jarretteras": ("jarreter",),
    "jarretterez": ("jarreter",),
    "jarretteriez": ("jarreter",),
    "jarretterions": ("jarreter",),
    "jarretterons": ("jarreter",),
    "jarretteront": ("jarreter",),
    "jarrettes": ("jarreter",),
    "jaugeaient": ("jauger",),
    "jaugeai": ("jauger",),
    "jaugeais": ("jauger",),
    "jaugeait": ("jauger",),
    "jaugea": ("jauger",),
    "jaugeâmes": ("jauger",),
    "jaugeant": ("jauger",),
    "jaugeas": ("jauger",),
    "jaugeassent": ("jauger",),
    "jaugeasses": ("jauger",),
    "jaugeasse": ("jauger",),
    "jaugeassiez": ("jauger",),
    "jaugeassions": ("jauger",),
    "jaugeâtes": ("jauger",),
    "jaugeât": ("jauger",),
    "jaugée": ("jauger",),
    "jaugées": ("jauger",),
    "jaugé": ("jauger",),
    "jaugent": ("jauger",),
    "jaugeons": ("jauger",),
    "jauge": ("jauger",),
    "jaugera": ("jauger",),
    "jaugeraient": ("jauger",),
    "jaugerai": ("jauger",),
    "jaugerais": ("jauger",),
    "jaugerait": ("jauger",),
    "jaugeras": ("jauger",),
    "jaugèrent": ("jauger",),
    "jaugerez": ("jauger",),
    "jaugeriez": ("jauger",),
    "jaugerions": ("jauger",),
    "jaugerons": ("jauger",),
    "jaugeront": ("jauger",),
    "jaugés": ("jauger",),
    "jauges": ("jauger",),
    "jaugez": ("jauger",),
    "jaugiez": ("jauger",),
    "jaugions": ("jauger",),
    "jaunie": ("jaunir",),
    "jaunies": ("jaunir",),
    "jauni": ("jaunir",),
    "jaunîmes": ("jaunir",),
    "jaunira": ("jaunir",),
    "jauniraient": ("jaunir",),
    "jaunirai": ("jaunir",),
    "jaunirais": ("jaunir",),
    "jaunirait": ("jaunir",),
    "jauniras": ("jaunir",),
    "jaunirent": ("jaunir",),
    "jaunirez": ("jaunir",),
    "jauniriez": ("jaunir",),
    "jaunirions": ("jaunir",),
    "jaunirons": ("jaunir",),
    "jauniront": ("jaunir",),
    "jaunis": ("jaunir",),
    "jaunissaient": ("jaunir",),
    "jaunissais": ("jaunir",),
    "jaunissait": ("jaunir",),
    "jaunissant": ("jaunir",),
    "jaunissent": ("jaunir",),
    "jaunisse": ("jaunir",),
    "jaunisses": ("jaunir",),
    "jaunissez": ("jaunir",),
    "jaunissiez": ("jaunir",),
    "jaunissions": ("jaunir",),
    "jaunissons": ("jaunir",),
    "jaunîtes": ("jaunir",),
    "jaunit": ("jaunir",),
    "jaunît": ("jaunir",),
    "javelaient": ("javeler",),
    "javelai": ("javeler",),
    "javelais": ("javeler",),
    "javelait": ("javeler",),
    "javela": ("javeler",),
    "javelâmes": ("javeler",),
    "javelant": ("javeler",),
    "javelas": ("javeler",),
    "javelassent": ("javeler",),
    "javelasses": ("javeler",),
    "javelasse": ("javeler",),
    "javelassiez": ("javeler",),
    "javelassions": ("javeler",),
    "javelâtes": ("javeler",),
    "javelât": ("javeler",),
    "javelée": ("javeler",),
    "javelées": ("javeler",),
    "javelé": ("javeler",),
    "javelèrent": ("javeler",),
    "javelés": ("javeler",),
    "javelez": ("javeler",),
    "javeliez": ("javeler",),
    "javelions": ("javeler",),
    "javellent": ("javeler",),
    "javelle": ("javeler",),
    "javellera": ("javeler",),
    "javelleraient": ("javeler",),
    "javellerai": ("javeler",),
    "javellerais": ("javeler",),
    "javellerait": ("javeler",),
    "javelleras": ("javeler",),
    "javellerez": ("javeler",),
    "javelleriez": ("javeler",),
    "javellerions": ("javeler",),
    "javellerons": ("javeler",),
    "javelleront": ("javeler",),
    "javelles": ("javeler",),
    "javelons": ("javeler",),
    "jazzifiaient": ("jazzifier",),
    "jazzifiai": ("jazzifier",),
    "jazzifiais": ("jazzifier",),
    "jazzifiait": ("jazzifier",),
    "jazzifia": ("jazzifier",),
    "jazzifiâmes": ("jazzifier",),
    "jazzifiant": ("jazzifier",),
    "jazzifias": ("jazzifier",),
    "jazzifiassent": ("jazzifier",),
    "jazzifiasses": ("jazzifier",),
    "jazzifiasse": ("jazzifier",),
    "jazzifiassiez": ("jazzifier",),
    "jazzifiassions": ("jazzifier",),
    "jazzifiâtes": ("jazzifier",),
    "jazzifiât": ("jazzifier",),
    "jazzifié": ("jazzifier",),
    "jazzifient": ("jazzifier",),
    "jazzifie": ("jazzifier",),
    "jazzifiera": ("jazzifier",),
    "jazzifieraient": ("jazzifier",),
    "jazzifierai": ("jazzifier",),
    "jazzifierais": ("jazzifier",),
    "jazzifierait": ("jazzifier",),
    "jazzifieras": ("jazzifier",),
    "jazzifièrent": ("jazzifier",),
    "jazzifierez": ("jazzifier",),
    "jazzifieriez": ("jazzifier",),
    "jazzifierions": ("jazzifier",),
    "jazzifierons": ("jazzifier",),
    "jazzifieront": ("jazzifier",),
    "jazzifies": ("jazzifier",),
    "jazzifiez": ("jazzifier",),
    "jazzifiiez": ("jazzifier",),
    "jazzifiions": ("jazzifier",),
    "jazzifions": ("jazzifier",),
    "jetaient": ("jeter",),
    "jetai": ("jeter",),
    "jetais": ("jeter",),
    "jetait": ("jeter",),
    "jeta": ("jeter",),
    "jetâmes": ("jeter",),
    "jetant": ("jeter",),
    "jetas": ("jeter",),
    "jetassent": ("jeter",),
    "jetasses": ("jeter",),
    "jetasse": ("jeter",),
    "jetassiez": ("jeter",),
    "jetassions": ("jeter",),
    "jetâtes": ("jeter",),
    "jetât": ("jeter",),
    "jetée": ("jeter",),
    "jetées": ("jeter",),
    "jeté": ("jeter",),
    "jetèrent": ("jeter",),
    "jetés": ("jeter",),
    "jetez": ("jeter",),
    "jetiez": ("jeter",),
    "jetions": ("jeter",),
    "jetons": ("jeter",),
    "jettent": ("jeter",),
    "jette": ("jeter",),
    "jettera": ("jeter",),
    "jetteraient": ("jeter",),
    "jetterai": ("jeter",),
    "jetterais": ("jeter",),
    "jetterait": ("jeter",),
    "jetteras": ("jeter",),
    "jetterez": ("jeter",),
    "jetteriez": ("jeter",),
    "jetterions": ("jeter",),
    "jetterons": ("jeter",),
    "jetteront": ("jeter",),
    "jettes": ("jeter",),
    "joignaient": ("joindre",),
    "joignais": ("joindre",),
    "joignait": ("joindre",),
    "joignant": ("joindre",),
    "joignent": ("joindre",),
    "joigne": ("joindre",),
    "joignes": ("joindre",),
    "joignez": ("joindre",),
    "joigniez": ("joindre",),
    "joignîmes": ("joindre",),
    "joignions": ("joindre",),
    "joignirent": ("joindre",),
    "joignis": ("joindre",),
    "joignissent": ("joindre",),
    "joignisses": ("joindre",),
    "joignisse": ("joindre",),
    "joignissiez": ("joindre",),
    "joignissions": ("joindre",),
    "joignîtes": ("joindre",),
    "joignit": ("joindre",),
    "joignît": ("joindre",),
    "joignons": ("joindre",),
    "joindra": ("joindre",),
    "joindraient": ("joindre",),
    "joindrai": ("joindre",),
    "joindrais": ("joindre",),
    "joindrait": ("joindre",),
    "joindras": ("joindre",),
    "joindrez": ("joindre",),
    "joindriez": ("joindre",),
    "joindrions": ("joindre",),
    "joindrons": ("joindre",),
    "joindront": ("joindre",),
    "joins": ("joindre",),
    "jointe": ("joindre",),
    "jointes": ("joindre",),
    "joint": ("joindre",),
    "joints": ("joindre",),
    "jointoient": ("jointoyer",),
    "jointoie": ("jointoyer",),
    "jointoiera": ("jointoyer",),
    "jointoieraient": ("jointoyer",),
    "jointoierai": ("jointoyer",),
    "jointoierais": ("jointoyer",),
    "jointoierait": ("jointoyer",),
    "jointoieras": ("jointoyer",),
    "jointoierez": ("jointoyer",),
    "jointoieriez": ("jointoyer",),
    "jointoierions": ("jointoyer",),
    "jointoierons": ("jointoyer",),
    "jointoieront": ("jointoyer",),
    "jointoies": ("jointoyer",),
    "jointoyaient": ("jointoyer",),
    "jointoyai": ("jointoyer",),
    "jointoyais": ("jointoyer",),
    "jointoyait": ("jointoyer",),
    "jointoya": ("jointoyer",),
    "jointoyâmes": ("jointoyer",),
    "jointoyant": ("jointoyer",),
    "jointoyas": ("jointoyer",),
    "jointoyassent": ("jointoyer",),
    "jointoyasses": ("jointoyer",),
    "jointoyasse": ("jointoyer",),
    "jointoyassiez": ("jointoyer",),
    "jointoyassions": ("jointoyer",),
    "jointoyâtes": ("jointoyer",),
    "jointoyât": ("jointoyer",),
    "jointoyée": ("jointoyer",),
    "jointoyées": ("jointoyer",),
    "jointoyé": ("jointoyer",),
    "jointoyèrent": ("jointoyer",),
    "jointoyés": ("jointoyer",),
    "jointoyez": ("jointoyer",),
    "jointoyiez": ("jointoyer",),
    "jointoyions": ("jointoyer",),
    "jointoyons": ("jointoyer",),
    "jonçaient": ("joncer",),
    "jonçai": ("joncer",),
    "jonçais": ("joncer",),
    "jonçait": ("joncer",),
    "jonça": ("joncer",),
    "jonçâmes": ("joncer",),
    "jonçant": ("joncer",),
    "jonças": ("joncer",),
    "jonçassent": ("joncer",),
    "jonçasses": ("joncer",),
    "jonçasse": ("joncer",),
    "jonçassiez": ("joncer",),
    "jonçassions": ("joncer",),
    "jonçâtes": ("joncer",),
    "jonçât": ("joncer",),
    "joncée": ("joncer",),
    "joncées": ("joncer",),
    "joncé": ("joncer",),
    "joncent": ("joncer",),
    "jonce": ("joncer",),
    "joncera": ("joncer",),
    "jonceraient": ("joncer",),
    "joncerai": ("joncer",),
    "joncerais": ("joncer",),
    "joncerait": ("joncer",),
    "jonceras": ("joncer",),
    "joncèrent": ("joncer",),
    "joncerez": ("joncer",),
    "jonceriez": ("joncer",),
    "joncerions": ("joncer",),
    "joncerons": ("joncer",),
    "jonceront": ("joncer",),
    "joncés": ("joncer",),
    "jonces": ("joncer",),
    "joncez": ("joncer",),
    "jonciez": ("joncer",),
    "joncions": ("joncer",),
    "jonçons": ("joncer",),
    "joui": ("jouir",),
    "jouîmes": ("jouir",),
    "jouira": ("jouir",),
    "jouiraient": ("jouir",),
    "jouirai": ("jouir",),
    "jouirais": ("jouir",),
    "jouirait": ("jouir",),
    "jouiras": ("jouir",),
    "jouirent": ("jouir",),
    "jouirez": ("jouir",),
    "jouiriez": ("jouir",),
    "jouirions": ("jouir",),
    "jouirons": ("jouir",),
    "jouiront": ("jouir",),
    "jouis": ("jouir",),
    "jouissaient": ("jouir",),
    "jouissais": ("jouir",),
    "jouissait": ("jouir",),
    "jouissant": ("jouir",),
    "jouissent": ("jouir",),
    "jouisse": ("jouir",),
    "jouisses": ("jouir",),
    "jouissez": ("jouir",),
    "jouissiez": ("jouir",),
    "jouissions": ("jouir",),
    "jouissons": ("jouir",),
    "jouîtes": ("jouir",),
    "jouit": ("jouir",),
    "jouît": ("jouir",),
    "jugeaient": ("juger",),
    "jugeai": ("juger",),
    "jugeais": ("juger",),
    "jugeait": ("juger",),
    "jugea": ("juger",),
    "jugeâmes": ("juger",),
    "jugeant": ("juger",),
    "jugeas": ("juger",),
    "jugeassent": ("juger",),
    "jugeasses": ("juger",),
    "jugeasse": ("juger",),
    "jugeassiez": ("juger",),
    "jugeassions": ("juger",),
    "jugeâtes": ("juger",),
    "jugeât": ("juger",),
    "jugée": ("juger",),
    "jugées": ("juger",),
    "jugé": ("juger",),
    "jugent": ("juger",),
    "jugeons": ("juger",),
    "juge": ("juger",),
    "jugera": ("juger",),
    "jugeraient": ("juger",),
    "jugerai": ("juger",),
    "jugerais": ("juger",),
    "jugerait": ("juger",),
    "jugeras": ("juger",),
    "jugèrent": ("juger",),
    "jugerez": ("juger",),
    "jugeriez": ("juger",),
    "jugerions": ("juger",),
    "jugerons": ("juger",),
    "jugeront": ("juger",),
    "jugés": ("juger",),
    "juges": ("juger",),
    "jugez": ("juger",),
    "jugiez": ("juger",),
    "jugions": ("juger",),
    "jumelaient": ("jumeler",),
    "jumelai": ("jumeler",),
    "jumelais": ("jumeler",),
    "jumelait": ("jumeler",),
    "jumela": ("jumeler",),
    "jumelâmes": ("jumeler",),
    "jumelant": ("jumeler",),
    "jumelas": ("jumeler",),
    "jumelassent": ("jumeler",),
    "jumelasses": ("jumeler",),
    "jumelasse": ("jumeler",),
    "jumelassiez": ("jumeler",),
    "jumelassions": ("jumeler",),
    "jumelâtes": ("jumeler",),
    "jumelât": ("jumeler",),
    "jumelée": ("jumeler",),
    "jumelées": ("jumeler",),
    "jumelé": ("jumeler",),
    "jumelèrent": ("jumeler",),
    "jumelés": ("jumeler",),
    "jumelez": ("jumeler",),
    "jumeliez": ("jumeler",),
    "jumelions": ("jumeler",),
    "jumellent": ("jumeler",),
    "jumelle": ("jumeler",),
    "jumellera": ("jumeler",),
    "jumelleraient": ("jumeler",),
    "jumellerai": ("jumeler",),
    "jumellerais": ("jumeler",),
    "jumellerait": ("jumeler",),
    "jumelleras": ("jumeler",),
    "jumellerez": ("jumeler",),
    "jumelleriez": ("jumeler",),
    "jumellerions": ("jumeler",),
    "jumellerons": ("jumeler",),
    "jumelleront": ("jumeler",),
    "jumelles": ("jumeler",),
    "jumelons": ("jumeler",),
    "justiciaient": ("justicier",),
    "justiciai": ("justicier",),
    "justiciais": ("justicier",),
    "justiciait": ("justicier",),
    "justicia": ("justicier",),
    "justiciâmes": ("justicier",),
    "justiciant": ("justicier",),
    "justicias": ("justicier",),
    "justiciassent": ("justicier",),
    "justiciasses": ("justicier",),
    "justiciasse": ("justicier",),
    "justiciassiez": ("justicier",),
    "justiciassions": ("justicier",),
    "justiciâtes": ("justicier",),
    "justiciât": ("justicier",),
    "justiciée": ("justicier",),
    "justiciées": ("justicier",),
    "justicié": ("justicier",),
    "justicient": ("justicier",),
    "justicie": ("justicier",),
    "justiciera": ("justicier",),
    "justicieraient": ("justicier",),
    "justicierai": ("justicier",),
    "justicierais": ("justicier",),
    "justicierait": ("justicier",),
    "justicieras": ("justicier",),
    "justicièrent": ("justicier",),
    "justicierez": ("justicier",),
    "justicieriez": ("justicier",),
    "justicierions": ("justicier",),
    "justicierons": ("justicier",),
    "justicieront": ("justicier",),
    "justiciés": ("justicier",),
    "justicies": ("justicier",),
    "justiciez": ("justicier",),
    "justiciiez": ("justicier",),
    "justiciions": ("justicier",),
    "justicions": ("justicier",),
    "justifiaient": ("justifier",),
    "justifiai": ("justifier",),
    "justifiais": ("justifier",),
    "justifiait": ("justifier",),
    "justifia": ("justifier",),
    "justifiâmes": ("justifier",),
    "justifiant": ("justifier",),
    "justifias": ("justifier",),
    "justifiassent": ("justifier",),
    "justifiasses": ("justifier",),
    "justifiasse": ("justifier",),
    "justifiassiez": ("justifier",),
    "justifiassions": ("justifier",),
    "justifiâtes": ("justifier",),
    "justifiât": ("justifier",),
    "justifiée": ("justifier",),
    "justifiées": ("justifier",),
    "justifié": ("justifier",),
    "justifient": ("justifier",),
    "justifie": ("justifier",),
    "justifiera": ("justifier",),
    "justifieraient": ("justifier",),
    "justifierai": ("justifier",),
    "justifierais": ("justifier",),
    "justifierait": ("justifier",),
    "justifieras": ("justifier",),
    "justifièrent": ("justifier",),
    "justifierez": ("justifier",),
    "justifieriez": ("justifier",),
    "justifierions": ("justifier",),
    "justifierons": ("justifier",),
    "justifieront": ("justifier",),
    "justifiés": ("justifier",),
    "justifies": ("justifier",),
    "justifiez": ("justifier",),
    "justifiiez": ("justifier",),
    "justifiions": ("justifier",),
    "justifions": ("justifier",),
    "karstifiaient": ("karstifier",),
    "karstifiai": ("karstifier",),
    "karstifiais": ("karstifier",),
    "karstifiait": ("karstifier",),
    "karstifia": ("karstifier",),
    "karstifiâmes": ("karstifier",),
    "karstifiant": ("karstifier",),
    "karstifias": ("karstifier",),
    "karstifiassent": ("karstifier",),
    "karstifiasses": ("karstifier",),
    "karstifiasse": ("karstifier",),
    "karstifiassiez": ("karstifier",),
    "karstifiassions": ("karstifier",),
    "karstifiâtes": ("karstifier",),
    "karstifiât": ("karstifier",),
    "karstifiée": ("karstifier",),
    "karstifiées": ("karstifier",),
    "karstifié": ("karstifier",),
    "karstifient": ("karstifier",),
    "karstifie": ("karstifier",),
    "karstifiera": ("karstifier",),
    "karstifieraient": ("karstifier",),
    "karstifierai": ("karstifier",),
    "karstifierais": ("karstifier",),
    "karstifierait": ("karstifier",),
    "karstifieras": ("karstifier",),
    "karstifièrent": ("karstifier",),
    "karstifierez": ("karstifier",),
    "karstifieriez": ("karstifier",),
    "karstifierions": ("karstifier",),
    "karstifierons": ("karstifier",),
    "karstifieront": ("karstifier",),
    "karstifiés": ("karstifier",),
    "karstifies": ("karstifier",),
    "karstifiez": ("karstifier",),
    "karstifiiez": ("karstifier",),
    "karstifiions": ("karstifier",),
    "karstifions": ("karstifier",),
    "kilométraient": ("kilométrer",),
    "kilométrai": ("kilométrer",),
    "kilométrais": ("kilométrer",),
    "kilométrait": ("kilométrer",),
    "kilométra": ("kilométrer",),
    "kilométrâmes": ("kilométrer",),
    "kilométrant": ("kilométrer",),
    "kilométras": ("kilométrer",),
    "kilométrassent": ("kilométrer",),
    "kilométrasses": ("kilométrer",),
    "kilométrasse": ("kilométrer",),
    "kilométrassiez": ("kilométrer",),
    "kilométrassions": ("kilométrer",),
    "kilométrâtes": ("kilométrer",),
    "kilométrât": ("kilométrer",),
    "kilométrée": ("kilométrer",),
    "kilométrées": ("kilométrer",),
    "kilométré": ("kilométrer",),
    "kilomètrent": ("kilométrer",),
    "kilomètre": ("kilométrer",),
    "kilométrera": ("kilométrer",),
    "kilométreraient": ("kilométrer",),
    "kilométrerai": ("kilométrer",),
    "kilométrerais": ("kilométrer",),
    "kilométrerait": ("kilométrer",),
    "kilométreras": ("kilométrer",),
    "kilométrèrent": ("kilométrer",),
    "kilométrerez": ("kilométrer",),
    "kilométreriez": ("kilométrer",),
    "kilométrerions": ("kilométrer",),
    "kilométrerons": ("kilométrer",),
    "kilométreront": ("kilométrer",),
    "kilométrés": ("kilométrer",),
    "kilomètres": ("kilométrer",),
    "kilométrez": ("kilométrer",),
    "kilométriez": ("kilométrer",),
    "kilométrions": ("kilométrer",),
    "kilométrons": ("kilométrer",),
    "lacéraient": ("lacérer",),
    "lacérai": ("lacérer",),
    "lacérais": ("lacérer",),
    "lacérait": ("lacérer",),
    "lacéra": ("lacérer",),
    "lacérâmes": ("lacérer",),
    "lacérant": ("lacérer",),
    "lacéras": ("lacérer",),
    "lacérassent": ("lacérer",),
    "lacérasses": ("lacérer",),
    "lacérasse": ("lacérer",),
    "lacérassiez": ("lacérer",),
    "lacérassions": ("lacérer",),
    "lacérâtes": ("lacérer",),
    "lacérât": ("lacérer",),
    "lacérée": ("lacérer",),
    "lacérées": ("lacérer",),
    "lacéré": ("lacérer",),
    "lacèrent": ("lacer",),
    "lacère": ("lacérer",),
    "lacérera": ("lacérer",),
    "lacéreraient": ("lacérer",),
    "lacérerai": ("lacérer",),
    "lacérerais": ("lacérer",),
    "lacérerait": ("lacérer",),
    "lacéreras": ("lacérer",),
    "lacérèrent": ("lacérer",),
    "lacérerez": ("lacérer",),
    "lacéreriez": ("lacérer",),
    "lacérerions": ("lacérer",),
    "lacérerons": ("lacérer",),
    "lacéreront": ("lacérer",),
    "lacérés": ("lacérer",),
    "lacères": ("lacérer",),
    "lacérez": ("lacérer",),
    "lacériez": ("lacérer",),
    "lacérions": ("lacérer",),
    "lacérons": ("lacérer",),
    "laçaient": ("lacer",),
    "laçai": ("lacer",),
    "laçais": ("lacer",),
    "laçait": ("lacer",),
    "laça": ("lacer",),
    "laçâmes": ("lacer",),
    "laçant": ("lacer",),
    "laças": ("lacer",),
    "laçassent": ("lacer",),
    "laçasses": ("lacer",),
    "laçasse": ("lacer",),
    "laçassiez": ("lacer",),
    "laçassions": ("lacer",),
    "laçâtes": ("lacer",),
    "laçât": ("lacer",),
    "lacée": ("lacer",),
    "lacées": ("lacer",),
    "lacé": ("lacer",),
    "lacent": ("lacer",),
    "lace": ("lacer",),
    "lacera": ("lacer",),
    "laceraient": ("lacer",),
    "lacerai": ("lacer",),
    "lacerais": ("lacer",),
    "lacerait": ("lacer",),
    "laceras": ("lacer",),
    "lacerez": ("lacer",),
    "laceriez": ("lacer",),
    "lacerions": ("lacer",),
    "lacerons": ("lacer",),
    "laceront": ("lacer",),
    "lacés": ("lacer",),
    "laces": ("lacer",),
    "lacez": ("lacer",),
    "laciez": ("lacer",),
    "lacions": ("lacer",),
    "laçons": ("lacer",),
    "laidie": ("laidir",),
    "laidies": ("laidir",),
    "laidi": ("laidir",),
    "laidîmes": ("laidir",),
    "laidira": ("laidir",),
    "laidiraient": ("laidir",),
    "laidirai": ("laidir",),
    "laidirais": ("laidir",),
    "laidirait": ("laidir",),
    "laidiras": ("laidir",),
    "laidirent": ("laidir",),
    "laidirez": ("laidir",),
    "laidiriez": ("laidir",),
    "laidirions": ("laidir",),
    "laidirons": ("laidir",),
    "laidiront": ("laidir",),
    "laidis": ("laidir",),
    "laidissaient": ("laidir",),
    "laidissais": ("laidir",),
    "laidissait": ("laidir",),
    "laidissant": ("laidir",),
    "laidissent": ("laidir",),
    "laidisse": ("laidir",),
    "laidisses": ("laidir",),
    "laidissez": ("laidir",),
    "laidissiez": ("laidir",),
    "laidissions": ("laidir",),
    "laidissons": ("laidir",),
    "laidîtes": ("laidir",),
    "laidit": ("laidir",),
    "laidît": ("laidir",),
    "lamifiaient": ("lamifier",),
    "lamifiai": ("lamifier",),
    "lamifiais": ("lamifier",),
    "lamifiait": ("lamifier",),
    "lamifia": ("lamifier",),
    "lamifiâmes": ("lamifier",),
    "lamifiant": ("lamifier",),
    "lamifias": ("lamifier",),
    "lamifiassent": ("lamifier",),
    "lamifiasses": ("lamifier",),
    "lamifiasse": ("lamifier",),
    "lamifiassiez": ("lamifier",),
    "lamifiassions": ("lamifier",),
    "lamifiâtes": ("lamifier",),
    "lamifiât": ("lamifier",),
    "lamifiée": ("lamifier",),
    "lamifiées": ("lamifier",),
    "lamifié": ("lamifier",),
    "lamifient": ("lamifier",),
    "lamifie": ("lamifier",),
    "lamifiera": ("lamifier",),
    "lamifieraient": ("lamifier",),
    "lamifierai": ("lamifier",),
    "lamifierais": ("lamifier",),
    "lamifierait": ("lamifier",),
    "lamifieras": ("lamifier",),
    "lamifièrent": ("lamifier",),
    "lamifierez": ("lamifier",),
    "lamifieriez": ("lamifier",),
    "lamifierions": ("lamifier",),
    "lamifierons": ("lamifier",),
    "lamifieront": ("lamifier",),
    "lamifiés": ("lamifier",),
    "lamifies": ("lamifier",),
    "lamifiez": ("lamifier",),
    "lamifiiez": ("lamifier",),
    "lamifiions": ("lamifier",),
    "lamifions": ("lamifier",),
    "lançaient": ("lancer",),
    "lançai": ("lancer",),
    "lançais": ("lancer",),
    "lançait": ("lancer",),
    "lança": ("lancer",),
    "lançâmes": ("lancer",),
    "lançant": ("lancer",),
    "lanças": ("lancer",),
    "lançassent": ("lancer",),
    "lançasses": ("lancer",),
    "lançasse": ("lancer",),
    "lançassiez": ("lancer",),
    "lançassions": ("lancer",),
    "lançâtes": ("lancer",),
    "lançât": ("lancer",),
    "lancée": ("lancer",),
    "lancées": ("lancer",),
    "lancé": ("lancer",),
    "lancent": ("lancer",),
    "lance": ("lancer",),
    "lancera": ("lancer",),
    "lanceraient": ("lancer",),
    "lancerai": ("lancer",),
    "lancerais": ("lancer",),
    "lancerait": ("lancer",),
    "lanceras": ("lancer",),
    "lancèrent": ("lancer",),
    "lancerez": ("lancer",),
    "lanceriez": ("lancer",),
    "lancerions": ("lancer",),
    "lancerons": ("lancer",),
    "lanceront": ("lancer",),
    "lancés": ("lancer",),
    "lances": ("lancer",),
    "lancez": ("lancer",),
    "lanciez": ("lancer",),
    "lancions": ("lancer",),
    "lançons": ("lancer",),
    "langeaient": ("langer",),
    "langeai": ("langer",),
    "langeais": ("langer",),
    "langeait": ("langer",),
    "langea": ("langer",),
    "langeâmes": ("langer",),
    "langeant": ("langer",),
    "langeas": ("langer",),
    "langeassent": ("langer",),
    "langeasses": ("langer",),
    "langeasse": ("langer",),
    "langeassiez": ("langer",),
    "langeassions": ("langer",),
    "langeâtes": ("langer",),
    "langeât": ("langer",),
    "langée": ("langer",),
    "langées": ("langer",),
    "langé": ("langer",),
    "langent": ("langer",),
    "langeons": ("langer",),
    "lange": ("langer",),
    "langera": ("langer",),
    "langeraient": ("langer",),
    "langerai": ("langer",),
    "langerais": ("langer",),
    "langerait": ("langer",),
    "langeras": ("langer",),
    "langèrent": ("langer",),
    "langerez": ("langer",),
    "langeriez": ("langer",),
    "langerions": ("langer",),
    "langerons": ("langer",),
    "langeront": ("langer",),
    "langés": ("langer",),
    "langes": ("langer",),
    "langez": ("langer",),
    "langiez": ("langer",),
    "langions": ("langer",),
    "languetaient": ("langueter",),
    "languetai": ("langueter",),
    "languetais": ("langueter",),
    "languetait": ("langueter",),
    "langueta": ("langueter",),
    "languetâmes": ("langueter",),
    "languetant": ("langueter",),
    "languetas": ("langueter",),
    "languetassent": ("langueter",),
    "languetasses": ("langueter",),
    "languetasse": ("langueter",),
    "languetassiez": ("langueter",),
    "languetassions": ("langueter",),
    "languetâtes": ("langueter",),
    "languetât": ("langueter",),
    "languetée": ("langueter",),
    "languetées": ("langueter",),
    "langueté": ("langueter",),
    "languetèrent": ("langueter",),
    "languetés": ("langueter",),
    "languetez": ("langueter",),
    "languetiez": ("langueter",),
    "languetions": ("langueter",),
    "languetons": ("langueter",),
    "languettent": ("langueter",),
    "languette": ("langueter",),
    "languettera": ("langueter",),
    "languetteraient": ("langueter",),
    "languetterai": ("langueter",),
    "languetterais": ("langueter",),
    "languetterait": ("langueter",),
    "languetteras": ("langueter",),
    "languetterez": ("langueter",),
    "languetteriez": ("langueter",),
    "languetterions": ("langueter",),
    "languetterons": ("langueter",),
    "languetteront": ("langueter",),
    "languettes": ("langueter",),
    "languie": ("languir",),
    "languies": ("languir",),
    "langui": ("languir",),
    "languîmes": ("languir",),
    "languira": ("languir",),
    "languiraient": ("languir",),
    "languirai": ("languir",),
    "languirais": ("languir",),
    "languirait": ("languir",),
    "languiras": ("languir",),
    "languirent": ("languir",),
    "languirez": ("languir",),
    "languiriez": ("languir",),
    "languirions": ("languir",),
    "languirons": ("languir",),
    "languiront": ("languir",),
    "languis": ("languir",),
    "languissaient": ("languir",),
    "languissais": ("languir",),
    "languissait": ("languir",),
    "languissant": ("languir",),
    "languissent": ("languir",),
    "languisse": ("languir",),
    "languisses": ("languir",),
    "languissez": ("languir",),
    "languissiez": ("languir",),
    "languissions": ("languir",),
    "languissons": ("languir",),
    "languîtes": ("languir",),
    "languit": ("languir",),
    "languît": ("languir",),
    "lapidifiaient": ("lapidifier",),
    "lapidifiai": ("lapidifier",),
    "lapidifiais": ("lapidifier",),
    "lapidifiait": ("lapidifier",),
    "lapidifia": ("lapidifier",),
    "lapidifiâmes": ("lapidifier",),
    "lapidifiant": ("lapidifier",),
    "lapidifias": ("lapidifier",),
    "lapidifiassent": ("lapidifier",),
    "lapidifiasses": ("lapidifier",),
    "lapidifiasse": ("lapidifier",),
    "lapidifiassiez": ("lapidifier",),
    "lapidifiassions": ("lapidifier",),
    "lapidifiâtes": ("lapidifier",),
    "lapidifiât": ("lapidifier",),
    "lapidifiée": ("lapidifier",),
    "lapidifiées": ("lapidifier",),
    "lapidifié": ("lapidifier",),
    "lapidifient": ("lapidifier",),
    "lapidifie": ("lapidifier",),
    "lapidifiera": ("lapidifier",),
    "lapidifieraient": ("lapidifier",),
    "lapidifierai": ("lapidifier",),
    "lapidifierais": ("lapidifier",),
    "lapidifierait": ("lapidifier",),
    "lapidifieras": ("lapidifier",),
    "lapidifièrent": ("lapidifier",),
    "lapidifierez": ("lapidifier",),
    "lapidifieriez": ("lapidifier",),
    "lapidifierions": ("lapidifier",),
    "lapidifierons": ("lapidifier",),
    "lapidifieront": ("lapidifier",),
    "lapidifiés": ("lapidifier",),
    "lapidifies": ("lapidifier",),
    "lapidifiez": ("lapidifier",),
    "lapidifiiez": ("lapidifier",),
    "lapidifiions": ("lapidifier",),
    "lapidifions": ("lapidifier",),
    "larmoient": ("larmoyer",),
    "larmoie": ("larmoyer",),
    "larmoiera": ("larmoyer",),
    "larmoieraient": ("larmoyer",),
    "larmoierai": ("larmoyer",),
    "larmoierais": ("larmoyer",),
    "larmoierait": ("larmoyer",),
    "larmoieras": ("larmoyer",),
    "larmoierez": ("larmoyer",),
    "larmoieriez": ("larmoyer",),
    "larmoierions": ("larmoyer",),
    "larmoierons": ("larmoyer",),
    "larmoieront": ("larmoyer",),
    "larmoies": ("larmoyer",),
    "larmoyaient": ("larmoyer",),
    "larmoyai": ("larmoyer",),
    "larmoyais": ("larmoyer",),
    "larmoyait": ("larmoyer",),
    "larmoya": ("larmoyer",),
    "larmoyâmes": ("larmoyer",),
    "larmoyant": ("larmoyer",),
    "larmoyas": ("larmoyer",),
    "larmoyassent": ("larmoyer",),
    "larmoyasses": ("larmoyer",),
    "larmoyasse": ("larmoyer",),
    "larmoyassiez": ("larmoyer",),
    "larmoyassions": ("larmoyer",),
    "larmoyâtes": ("larmoyer",),
    "larmoyât": ("larmoyer",),
    "larmoyé": ("larmoyer",),
    "larmoyèrent": ("larmoyer",),
    "larmoyez": ("larmoyer",),
    "larmoyiez": ("larmoyer",),
    "larmoyions": ("larmoyer",),
    "larmoyons": ("larmoyer",),
    "lassaient": ("lasser",),
    "lassai": ("lasser",),
    "lassais": ("lasser",),
    "lassait": ("lasser",),
    "lassa": ("lasser",),
    "lassâmes": ("lasser",),
    "lassant": ("lasser",),
    "lassas": ("lasser",),
    "lassassent": ("lasser",),
    "lassasses": ("lasser",),
    "lassasse": ("lasser",),
    "lassassiez": ("lasser",),
    "lassassions": ("lasser",),
    "lassâtes": ("lasser",),
    "lassât": ("lasser",),
    "lassée": ("lasser",),
    "lassées": ("lasser",),
    "lassé": ("lasser",),
    "lassent": ("lasser",),
    "lasse": ("lasser",),
    "lassera": ("lasser",),
    "lasseraient": ("lasser",),
    "lasserai": ("lasser",),
    "lasserais": ("lasser",),
    "lasserait": ("lasser",),
    "lasseras": ("lasser",),
    "lassèrent": ("lasser",),
    "lasserez": ("lasser",),
    "lasseriez": ("lasser",),
    "lasserions": ("lasser",),
    "lasserons": ("lasser",),
    "lasseront": ("lasser",),
    "lassés": ("lasser",),
    "lasses": ("lasser",),
    "lassez": ("lasser",),
    "lassiez": ("lasser",),
    "lassions": ("lasser",),
    "lassons": ("lasser",),
    "latensifiaient": ("latensifier",),
    "latensifiai": ("latensifier",),
    "latensifiais": ("latensifier",),
    "latensifiait": ("latensifier",),
    "latensifia": ("latensifier",),
    "latensifiâmes": ("latensifier",),
    "latensifiant": ("latensifier",),
    "latensifias": ("latensifier",),
    "latensifiassent": ("latensifier",),
    "latensifiasses": ("latensifier",),
    "latensifiasse": ("latensifier",),
    "latensifiassiez": ("latensifier",),
    "latensifiassions": ("latensifier",),
    "latensifiâtes": ("latensifier",),
    "latensifiât": ("latensifier",),
    "latensifiée": ("latensifier",),
    "latensifiées": ("latensifier",),
    "latensifié": ("latensifier",),
    "latensifient": ("latensifier",),
    "latensifie": ("latensifier",),
    "latensifiera": ("latensifier",),
    "latensifieraient": ("latensifier",),
    "latensifierai": ("latensifier",),
    "latensifierais": ("latensifier",),
    "latensifierait": ("latensifier",),
    "latensifieras": ("latensifier",),
    "latensifièrent": ("latensifier",),
    "latensifierez": ("latensifier",),
    "latensifieriez": ("latensifier",),
    "latensifierions": ("latensifier",),
    "latensifierons": ("latensifier",),
    "latensifieront": ("latensifier",),
    "latensifiés": ("latensifier",),
    "latensifies": ("latensifier",),
    "latensifiez": ("latensifier",),
    "latensifiiez": ("latensifier",),
    "latensifiions": ("latensifier",),
    "latensifions": ("latensifier",),
    "laient": ("layer",),
    "laie": ("layer",),
    "laiera": ("layer",),
    "laieraient": ("layer",),
    "laierai": ("layer",),
    "laierais": ("layer",),
    "laierait": ("layer",),
    "laieras": ("layer",),
    "laierez": ("layer",),
    "laieriez": ("layer",),
    "laierions": ("layer",),
    "laierons": ("layer",),
    "laieront": ("layer",),
    "laies": ("layer",),
    "layaient": ("layer",),
    "layai": ("layer",),
    "layais": ("layer",),
    "layait": ("layer",),
    "laya": ("layer",),
    "layâmes": ("layer",),
    "layant": ("layer",),
    "layas": ("layer",),
    "layassent": ("layer",),
    "layasses": ("layer",),
    "layasse": ("layer",),
    "layassiez": ("layer",),
    "layassions": ("layer",),
    "layâtes": ("layer",),
    "layât": ("layer",),
    "layée": ("layer",),
    "layées": ("layer",),
    "layé": ("layer",),
    "layent": ("layer",),
    "laye": ("layer",),
    "layera": ("layer",),
    "layeraient": ("layer",),
    "layerai": ("layer",),
    "layerais": ("layer",),
    "layerait": ("layer",),
    "layeras": ("layer",),
    "layèrent": ("layer",),
    "layerez": ("layer",),
    "layeriez": ("layer",),
    "layerions": ("layer",),
    "layerons": ("layer",),
    "layeront": ("layer",),
    "layés": ("layer",),
    "layes": ("layer",),
    "layez": ("layer",),
    "layiez": ("layer",),
    "layions": ("layer",),
    "layons": ("layer",),
    "léchaient": ("lécher",),
    "léchai": ("lécher",),
    "léchais": ("lécher",),
    "léchait": ("lécher",),
    "lécha": ("lécher",),
    "léchâmes": ("lécher",),
    "léchant": ("lécher",),
    "léchas": ("lécher",),
    "léchassent": ("lécher",),
    "léchasses": ("lécher",),
    "léchasse": ("lécher",),
    "léchassiez": ("lécher",),
    "léchassions": ("lécher",),
    "léchâtes": ("lécher",),
    "léchât": ("lécher",),
    "léchée": ("lécher",),
    "léchées": ("lécher",),
    "léché": ("lécher",),
    "lèchent": ("lécher",),
    "lèche": ("lécher",),
    "léchera": ("lécher",),
    "lécheraient": ("lécher",),
    "lécherai": ("lécher",),
    "lécherais": ("lécher",),
    "lécherait": ("lécher",),
    "lécheras": ("lécher",),
    "léchèrent": ("lécher",),
    "lécherez": ("lécher",),
    "lécheriez": ("lécher",),
    "lécherions": ("lécher",),
    "lécherons": ("lécher",),
    "lécheront": ("lécher",),
    "léchés": ("lécher",),
    "lèches": ("lécher",),
    "léchez": ("lécher",),
    "léchiez": ("lécher",),
    "léchions": ("lécher",),
    "léchons": ("lécher",),
    "légiféraient": ("légiférer",),
    "légiférai": ("légiférer",),
    "légiférais": ("légiférer",),
    "légiférait": ("légiférer",),
    "légiféra": ("légiférer",),
    "légiférâmes": ("légiférer",),
    "légiférant": ("légiférer",),
    "légiféras": ("légiférer",),
    "légiférassent": ("légiférer",),
    "légiférasses": ("légiférer",),
    "légiférasse": ("légiférer",),
    "légiférassiez": ("légiférer",),
    "légiférassions": ("légiférer",),
    "légiférâtes": ("légiférer",),
    "légiférât": ("légiférer",),
    "légiférée": ("légiférer",),
    "légiférées": ("légiférer",),
    "légiféré": ("légiférer",),
    "légifèrent": ("légiférer",),
    "légifère": ("légiférer",),
    "légiférera": ("légiférer",),
    "légiféreraient": ("légiférer",),
    "légiférerai": ("légiférer",),
    "légiférerais": ("légiférer",),
    "légiférerait": ("légiférer",),
    "légiféreras": ("légiférer",),
    "légiférèrent": ("légiférer",),
    "légiférerez": ("légiférer",),
    "légiféreriez": ("légiférer",),
    "légiférerions": ("légiférer",),
    "légiférerons": ("légiférer",),
    "légiféreront": ("légiférer",),
    "légiférés": ("légiférer",),
    "légifères": ("légiférer",),
    "légiférez": ("légiférer",),
    "légifériez": ("légiférer",),
    "légiférions": ("légiférer",),
    "légiférons": ("légiférer",),
    "léguaient": ("léguer",),
    "léguai": ("léguer",),
    "léguais": ("léguer",),
    "léguait": ("léguer",),
    "légua": ("léguer",),
    "léguâmes": ("léguer",),
    "léguant": ("léguer",),
    "léguas": ("léguer",),
    "léguassent": ("léguer",),
    "léguasses": ("léguer",),
    "léguasse": ("léguer",),
    "léguassiez": ("léguer",),
    "léguassions": ("léguer",),
    "léguâtes": ("léguer",),
    "léguât": ("léguer",),
    "léguée": ("léguer",),
    "léguées": ("léguer",),
    "légué": ("léguer",),
    "lèguent": ("léguer",),
    "lègue": ("léguer",),
    "léguera": ("léguer",),
    "légueraient": ("léguer",),
    "léguerai": ("léguer",),
    "léguerais": ("léguer",),
    "léguerait": ("léguer",),
    "légueras": ("léguer",),
    "léguèrent": ("léguer",),
    "léguerez": ("léguer",),
    "légueriez": ("léguer",),
    "léguerions": ("léguer",),
    "léguerons": ("léguer",),
    "légueront": ("léguer",),
    "légués": ("léguer",),
    "lègues": ("léguer",),
    "léguez": ("léguer",),
    "léguiez": ("léguer",),
    "léguions": ("léguer",),
    "léguons": ("léguer",),
    "lénifiaient": ("lénifier",),
    "lénifiai": ("lénifier",),
    "lénifiais": ("lénifier",),
    "lénifiait": ("lénifier",),
    "lénifia": ("lénifier",),
    "lénifiâmes": ("lénifier",),
    "lénifiant": ("lénifier",),
    "lénifias": ("lénifier",),
    "lénifiassent": ("lénifier",),
    "lénifiasses": ("lénifier",),
    "lénifiasse": ("lénifier",),
    "lénifiassiez": ("lénifier",),
    "lénifiassions": ("lénifier",),
    "lénifiâtes": ("lénifier",),
    "lénifiât": ("lénifier",),
    "lénifiée": ("lénifier",),
    "lénifiées": ("lénifier",),
    "lénifié": ("lénifier",),
    "lénifient": ("lénifier",),
    "lénifie": ("lénifier",),
    "lénifiera": ("lénifier",),
    "lénifieraient": ("lénifier",),
    "lénifierai": ("lénifier",),
    "lénifierais": ("lénifier",),
    "lénifierait": ("lénifier",),
    "lénifieras": ("lénifier",),
    "lénifièrent": ("lénifier",),
    "lénifierez": ("lénifier",),
    "lénifieriez": ("lénifier",),
    "lénifierions": ("lénifier",),
    "lénifierons": ("lénifier",),
    "lénifieront": ("lénifier",),
    "lénifiés": ("lénifier",),
    "lénifies": ("lénifier",),
    "lénifiez": ("lénifier",),
    "lénifiiez": ("lénifier",),
    "lénifiions": ("lénifier",),
    "lénifions": ("lénifier",),
    "lésaient": ("léser",),
    "lésai": ("léser",),
    "lésais": ("léser",),
    "lésait": ("léser",),
    "lésa": ("léser",),
    "lésâmes": ("léser",),
    "lésant": ("léser",),
    "lésas": ("léser",),
    "lésassent": ("léser",),
    "lésasses": ("léser",),
    "lésasse": ("léser",),
    "lésassiez": ("léser",),
    "lésassions": ("léser",),
    "lésâtes": ("léser",),
    "lésât": ("léser",),
    "lésée": ("léser",),
    "lésées": ("léser",),
    "lésé": ("léser",),
    "lèsent": ("léser",),
    "lèse": ("léser",),
    "lésera": ("léser",),
    "léseraient": ("léser",),
    "léserai": ("léser",),
    "léserais": ("léser",),
    "léserait": ("léser",),
    "léseras": ("léser",),
    "lésèrent": ("léser",),
    "léserez": ("léser",),
    "léseriez": ("léser",),
    "léserions": ("léser",),
    "léserons": ("léser",),
    "léseront": ("léser",),
    "lésés": ("léser",),
    "lèses": ("léser",),
    "lésez": ("léser",),
    "lésiez": ("léser",),
    "lésions": ("léser",),
    "lésons": ("léser",),
    "levaient": ("lever",),
    "levai": ("lever",),
    "levais": ("lever",),
    "levait": ("lever",),
    "leva": ("lever",),
    "levâmes": ("lever",),
    "levant": ("lever",),
    "levas": ("lever",),
    "levassent": ("lever",),
    "levasses": ("lever",),
    "levasse": ("lever",),
    "levassiez": ("lever",),
    "levassions": ("lever",),
    "levâtes": ("lever",),
    "levât": ("lever",),
    "levée": ("lever",),
    "levées": ("lever",),
    "levé": ("lever",),
    "lèvent": ("lever",),
    "lève": ("lever",),
    "lèvera": ("lever",),
    "lèveraient": ("lever",),
    "lèverai": ("lever",),
    "lèverais": ("lever",),
    "lèverait": ("lever",),
    "lèveras": ("lever",),
    "levèrent": ("lever",),
    "lèverez": ("lever",),
    "lèveriez": ("lever",),
    "lèverions": ("lever",),
    "lèverons": ("lever",),
    "lèveront": ("lever",),
    "levés": ("lever",),
    "lèves": ("lever",),
    "levez": ("lever",),
    "leviez": ("lever",),
    "levions": ("lever",),
    "levons": ("lever",),
    "lévigeaient": ("léviger",),
    "lévigeai": ("léviger",),
    "lévigeais": ("léviger",),
    "lévigeait": ("léviger",),
    "lévigea": ("léviger",),
    "lévigeâmes": ("léviger",),
    "lévigeant": ("léviger",),
    "lévigeas": ("léviger",),
    "lévigeassent": ("léviger",),
    "lévigeasses": ("léviger",),
    "lévigeasse": ("léviger",),
    "lévigeassiez": ("léviger",),
    "lévigeassions": ("léviger",),
    "lévigeâtes": ("léviger",),
    "lévigeât": ("léviger",),
    "lévigée": ("léviger",),
    "lévigées": ("léviger",),
    "lévigé": ("léviger",),
    "lévigent": ("léviger",),
    "lévigeons": ("léviger",),
    "lévige": ("léviger",),
    "lévigera": ("léviger",),
    "lévigeraient": ("léviger",),
    "lévigerai": ("léviger",),
    "lévigerais": ("léviger",),
    "lévigerait": ("léviger",),
    "lévigeras": ("léviger",),
    "lévigèrent": ("léviger",),
    "lévigerez": ("léviger",),
    "lévigeriez": ("léviger",),
    "lévigerions": ("léviger",),
    "lévigerons": ("léviger",),
    "lévigeront": ("léviger",),
    "lévigés": ("léviger",),
    "léviges": ("léviger",),
    "lévigez": ("léviger",),
    "lévigiez": ("léviger",),
    "lévigions": ("léviger",),
    "levretaient": ("levreter",),
    "levretai": ("levreter",),
    "levretais": ("levreter",),
    "levretait": ("levreter",),
    "levreta": ("levreter",),
    "levretâmes": ("levreter",),
    "levretant": ("levreter",),
    "levretas": ("levreter",),
    "levretassent": ("levreter",),
    "levretasses": ("levreter",),
    "levretasse": ("levreter",),
    "levretassiez": ("levreter",),
    "levretassions": ("levreter",),
    "levretâtes": ("levreter",),
    "levretât": ("levreter",),
    "levretée": ("levreter",),
    "levretées": ("levreter",),
    "levreté": ("levreter",),
    "levretèrent": ("levreter",),
    "levretés": ("levreter",),
    "levretez": ("levreter",),
    "levretiez": ("levreter",),
    "levretions": ("levreter",),
    "levretons": ("levreter",),
    "levrettent": ("levreter",),
    "levrette": ("levreter",),
    "levrettera": ("levreter",),
    "levretteraient": ("levreter",),
    "levretterai": ("levreter",),
    "levretterais": ("levreter",),
    "levretterait": ("levreter",),
    "levretteras": ("levreter",),
    "levretterez": ("levreter",),
    "levretteriez": ("levreter",),
    "levretterions": ("levreter",),
    "levretterons": ("levreter",),
    "levretteront": ("levreter",),
    "levrettes": ("levreter",),
    "libéraient": ("libérer",),
    "libérai": ("libérer",),
    "libérais": ("libérer",),
    "libérait": ("libérer",),
    "libéra": ("libérer",),
    "libérâmes": ("libérer",),
    "libérant": ("libérer",),
    "libéras": ("libérer",),
    "libérassent": ("libérer",),
    "libérasses": ("libérer",),
    "libérasse": ("libérer",),
    "libérassiez": ("libérer",),
    "libérassions": ("libérer",),
    "libérâtes": ("libérer",),
    "libérât": ("libérer",),
    "libérée": ("libérer",),
    "libérées": ("libérer",),
    "libéré": ("libérer",),
    "libèrent": ("libérer",),
    "libère": ("libérer",),
    "libérera": ("libérer",),
    "libéreraient": ("libérer",),
    "libérerai": ("libérer",),
    "libérerais": ("libérer",),
    "libérerait": ("libérer",),
    "libéreras": ("libérer",),
    "libérèrent": ("libérer",),
    "libérerez": ("libérer",),
    "libéreriez": ("libérer",),
    "libérerions": ("libérer",),
    "libérerons": ("libérer",),
    "libéreront": ("libérer",),
    "libérés": ("libérer",),
    "libères": ("libérer",),
    "libérez": ("libérer",),
    "libériez": ("libérer",),
    "libérions": ("libérer",),
    "libérons": ("libérer",),
    "licenciaient": ("licencier",),
    "licenciai": ("licencier",),
    "licenciais": ("licencier",),
    "licenciait": ("licencier",),
    "licencia": ("licencier",),
    "licenciâmes": ("licencier",),
    "licenciant": ("licencier",),
    "licencias": ("licencier",),
    "licenciassent": ("licencier",),
    "licenciasses": ("licencier",),
    "licenciasse": ("licencier",),
    "licenciassiez": ("licencier",),
    "licenciassions": ("licencier",),
    "licenciâtes": ("licencier",),
    "licenciât": ("licencier",),
    "licenciée": ("licencier",),
    "licenciées": ("licencier",),
    "licencié": ("licencier",),
    "licencient": ("licencier",),
    "licencie": ("licencier",),
    "licenciera": ("licencier",),
    "licencieraient": ("licencier",),
    "licencierai": ("licencier",),
    "licencierais": ("licencier",),
    "licencierait": ("licencier",),
    "licencieras": ("licencier",),
    "licencièrent": ("licencier",),
    "licencierez": ("licencier",),
    "licencieriez": ("licencier",),
    "licencierions": ("licencier",),
    "licencierons": ("licencier",),
    "licencieront": ("licencier",),
    "licenciés": ("licencier",),
    "licencies": ("licencier",),
    "licenciez": ("licencier",),
    "licenciiez": ("licencier",),
    "licenciions": ("licencier",),
    "licencions": ("licencier",),
    "lichénifiaient": ("lichénifier",),
    "lichénifiai": ("lichénifier",),
    "lichénifiais": ("lichénifier",),
    "lichénifiait": ("lichénifier",),
    "lichénifia": ("lichénifier",),
    "lichénifiâmes": ("lichénifier",),
    "lichénifiant": ("lichénifier",),
    "lichénifias": ("lichénifier",),
    "lichénifiassent": ("lichénifier",),
    "lichénifiasses": ("lichénifier",),
    "lichénifiasse": ("lichénifier",),
    "lichénifiassiez": ("lichénifier",),
    "lichénifiassions": ("lichénifier",),
    "lichénifiâtes": ("lichénifier",),
    "lichénifiât": ("lichénifier",),
    "lichénifiée": ("lichénifier",),
    "lichénifiées": ("lichénifier",),
    "lichénifié": ("lichénifier",),
    "lichénifient": ("lichénifier",),
    "lichénifie": ("lichénifier",),
    "lichénifiera": ("lichénifier",),
    "lichénifieraient": ("lichénifier",),
    "lichénifierai": ("lichénifier",),
    "lichénifierais": ("lichénifier",),
    "lichénifierait": ("lichénifier",),
    "lichénifieras": ("lichénifier",),
    "lichénifièrent": ("lichénifier",),
    "lichénifierez": ("lichénifier",),
    "lichénifieriez": ("lichénifier",),
    "lichénifierions": ("lichénifier",),
    "lichénifierons": ("lichénifier",),
    "lichénifieront": ("lichénifier",),
    "lichénifiés": ("lichénifier",),
    "lichénifies": ("lichénifier",),
    "lichénifiez": ("lichénifier",),
    "lichénifiiez": ("lichénifier",),
    "lichénifiions": ("lichénifier",),
    "lichénifions": ("lichénifier",),
    "liégeaient": ("liéger",),
    "liégeai": ("liéger",),
    "liégeais": ("liéger",),
    "liégeait": ("liéger",),
    "liégea": ("liéger",),
    "liégeâmes": ("liéger",),
    "liégeant": ("liéger",),
    "liégeas": ("liéger",),
    "liégeassent": ("liéger",),
    "liégeasses": ("liéger",),
    "liégeasse": ("liéger",),
    "liégeassiez": ("liéger",),
    "liégeassions": ("liéger",),
    "liégeâtes": ("liéger",),
    "liégeât": ("liéger",),
    "liégée": ("liéger",),
    "liégées": ("liéger",),
    "liégé": ("liéger",),
    "liègent": ("liéger",),
    "liégeons": ("liéger",),
    "liège": ("liéger",),
    "liégera": ("liéger",),
    "liégeraient": ("liéger",),
    "liégerai": ("liéger",),
    "liégerais": ("liéger",),
    "liégerait": ("liéger",),
    "liégeras": ("liéger",),
    "liégèrent": ("liéger",),
    "liégerez": ("liéger",),
    "liégeriez": ("liéger",),
    "liégerions": ("liéger",),
    "liégerons": ("liéger",),
    "liégeront": ("liéger",),
    "liégés": ("liéger",),
    "lièges": ("liéger",),
    "liégez": ("liéger",),
    "liégiez": ("liéger",),
    "liégions": ("liéger",),
    "liaient": ("lier",),
    "liai": ("lier",),
    "liais": ("lier",),
    "liait": ("lier",),
    "lia": ("lier",),
    "liâmes": ("lier",),
    "liant": ("lier",),
    "lias": ("lier",),
    "liassent": ("lier",),
    "liasses": ("lier",),
    "liasse": ("lier",),
    "liassiez": ("lier",),
    "liassions": ("lier",),
    "liâtes": ("lier",),
    "liât": ("lier",),
    "liée": ("lier",),
    "liées": ("lier",),
    "lié": ("lier",),
    "lient": ("lier",),
    "lie": ("lier",),
    "liera": ("lier",),
    "lieraient": ("lier",),
    "lierai": ("lier",),
    "lierais": ("lier",),
    "lierait": ("lier",),
    "lieras": ("lier",),
    "lièrent": ("lier",),
    "lierez": ("lier",),
    "lieriez": ("lier",),
    "lierions": ("lier",),
    "lierons": ("lier",),
    "lieront": ("lier",),
    "liés": ("lier",),
    "lies": ("lier",),
    "liez": ("lier",),
    "liiez": ("lier",),
    "liions": ("lier",),
    "lions": ("lier",),
    "lignifiaient": ("lignifier",),
    "lignifiai": ("lignifier",),
    "lignifiais": ("lignifier",),
    "lignifiait": ("lignifier",),
    "lignifia": ("lignifier",),
    "lignifiâmes": ("lignifier",),
    "lignifiant": ("lignifier",),
    "lignifias": ("lignifier",),
    "lignifiassent": ("lignifier",),
    "lignifiasses": ("lignifier",),
    "lignifiasse": ("lignifier",),
    "lignifiassiez": ("lignifier",),
    "lignifiassions": ("lignifier",),
    "lignifiâtes": ("lignifier",),
    "lignifiât": ("lignifier",),
    "lignifiée": ("lignifier",),
    "lignifiées": ("lignifier",),
    "lignifié": ("lignifier",),
    "lignifient": ("lignifier",),
    "lignifie": ("lignifier",),
    "lignifiera": ("lignifier",),
    "lignifieraient": ("lignifier",),
    "lignifierai": ("lignifier",),
    "lignifierais": ("lignifier",),
    "lignifierait": ("lignifier",),
    "lignifieras": ("lignifier",),
    "lignifièrent": ("lignifier",),
    "lignifierez": ("lignifier",),
    "lignifieriez": ("lignifier",),
    "lignifierions": ("lignifier",),
    "lignifierons": ("lignifier",),
    "lignifieront": ("lignifier",),
    "lignifiés": ("lignifier",),
    "lignifies": ("lignifier",),
    "lignifiez": ("lignifier",),
    "lignifiiez": ("lignifier",),
    "lignifiions": ("lignifier",),
    "lignifions": ("lignifier",),
    "limogeaient": ("limoger",),
    "limogeai": ("limoger",),
    "limogeais": ("limoger",),
    "limogeait": ("limoger",),
    "limogea": ("limoger",),
    "limogeâmes": ("limoger",),
    "limogeant": ("limoger",),
    "limogeas": ("limoger",),
    "limogeassent": ("limoger",),
    "limogeasses": ("limoger",),
    "limogeasse": ("limoger",),
    "limogeassiez": ("limoger",),
    "limogeassions": ("limoger",),
    "limogeâtes": ("limoger",),
    "limogeât": ("limoger",),
    "limogée": ("limoger",),
    "limogées": ("limoger",),
    "limogé": ("limoger",),
    "limogent": ("limoger",),
    "limogeons": ("limoger",),
    "limoge": ("limoger",),
    "limogera": ("limoger",),
    "limogeraient": ("limoger",),
    "limogerai": ("limoger",),
    "limogerais": ("limoger",),
    "limogerait": ("limoger",),
    "limogeras": ("limoger",),
    "limogèrent": ("limoger",),
    "limogerez": ("limoger",),
    "limogeriez": ("limoger",),
    "limogerions": ("limoger",),
    "limogerons": ("limoger",),
    "limogeront": ("limoger",),
    "limogés": ("limoger",),
    "limoges": ("limoger",),
    "limogez": ("limoger",),
    "limogiez": ("limoger",),
    "limogions": ("limoger",),
    "lingeaient": ("linger",),
    "lingeai": ("linger",),
    "lingeais": ("linger",),
    "lingeait": ("linger",),
    "lingea": ("linger",),
    "lingeâmes": ("linger",),
    "lingeant": ("linger",),
    "lingeas": ("linger",),
    "lingeassent": ("linger",),
    "lingeasses": ("linger",),
    "lingeasse": ("linger",),
    "lingeassiez": ("linger",),
    "lingeassions": ("linger",),
    "lingeâtes": ("linger",),
    "lingeât": ("linger",),
    "lingée": ("linger",),
    "lingées": ("linger",),
    "lingé": ("linger",),
    "lingent": ("linger",),
    "lingeons": ("linger",),
    "linge": ("linger",),
    "lingera": ("linger",),
    "lingeraient": ("linger",),
    "lingerai": ("linger",),
    "lingerais": ("linger",),
    "lingerait": ("linger",),
    "lingeras": ("linger",),
    "lingèrent": ("linger",),
    "lingerez": ("linger",),
    "lingeriez": ("linger",),
    "lingerions": ("linger",),
    "lingerons": ("linger",),
    "lingeront": ("linger",),
    "lingés": ("linger",),
    "linges": ("linger",),
    "lingez": ("linger",),
    "lingiez": ("linger",),
    "lingions": ("linger",),
    "liquéfiaient": ("liquéfier",),
    "liquéfiai": ("liquéfier",),
    "liquéfiais": ("liquéfier",),
    "liquéfiait": ("liquéfier",),
    "liquéfia": ("liquéfier",),
    "liquéfiâmes": ("liquéfier",),
    "liquéfiant": ("liquéfier",),
    "liquéfias": ("liquéfier",),
    "liquéfiassent": ("liquéfier",),
    "liquéfiasses": ("liquéfier",),
    "liquéfiasse": ("liquéfier",),
    "liquéfiassiez": ("liquéfier",),
    "liquéfiassions": ("liquéfier",),
    "liquéfiâtes": ("liquéfier",),
    "liquéfiât": ("liquéfier",),
    "liquéfiée": ("liquéfier",),
    "liquéfiées": ("liquéfier",),
    "liquéfié": ("liquéfier",),
    "liquéfient": ("liquéfier",),
    "liquéfie": ("liquéfier",),
    "liquéfiera": ("liquéfier",),
    "liquéfieraient": ("liquéfier",),
    "liquéfierai": ("liquéfier",),
    "liquéfierais": ("liquéfier",),
    "liquéfierait": ("liquéfier",),
    "liquéfieras": ("liquéfier",),
    "liquéfièrent": ("liquéfier",),
    "liquéfierez": ("liquéfier",),
    "liquéfieriez": ("liquéfier",),
    "liquéfierions": ("liquéfier",),
    "liquéfierons": ("liquéfier",),
    "liquéfieront": ("liquéfier",),
    "liquéfiés": ("liquéfier",),
    "liquéfies": ("liquéfier",),
    "liquéfiez": ("liquéfier",),
    "liquéfiiez": ("liquéfier",),
    "liquéfiions": ("liquéfier",),
    "liquéfions": ("liquéfier",),
    "lira": ("lire",),
    "liraient": ("lire",),
    "lirai": ("lire",),
    "lirais": ("lire",),
    "lirait": ("lire",),
    "liras": ("lire",),
    "lirez": ("lire",),
    "liriez": ("lire",),
    "lirions": ("lire",),
    "lirons": ("lire",),
    "liront": ("lire",),
    "lisaient": ("lire",),
    "lisais": ("lire",),
    "lisait": ("lire",),
    "lisant": ("lire",),
    "lisent": ("lire",),
    "lise": ("lire",),
    "lises": ("lire",),
    "lisez": ("lire",),
    "lisiez": ("lire",),
    "lisions": ("lire",),
    "lisons": ("lire",),
    "lis": ("lire",),
    "lit": ("lire",),
    "lue": ("lire",),
    "lues": ("lire",),
    "lu": ("lire",),
    "lûmes": ("lire",),
    "lurent": ("lire",),
    "lus": ("lire",),
    "lussent": ("lire",),
    "lusses": ("lire",),
    "lusse": ("lire",),
    "lussiez": ("lire",),
    "lussions": ("lire",),
    "lûtes": ("lire",),
    "lut": ("lire",),
    "lût": ("lire",),
    "lithifiaient": ("lithifier",),
    "lithifiai": ("lithifier",),
    "lithifiais": ("lithifier",),
    "lithifiait": ("lithifier",),
    "lithifia": ("lithifier",),
    "lithifiâmes": ("lithifier",),
    "lithifiant": ("lithifier",),
    "lithifias": ("lithifier",),
    "lithifiassent": ("lithifier",),
    "lithifiasses": ("lithifier",),
    "lithifiasse": ("lithifier",),
    "lithifiassiez": ("lithifier",),
    "lithifiassions": ("lithifier",),
    "lithifiâtes": ("lithifier",),
    "lithifiât": ("lithifier",),
    "lithifiée": ("lithifier",),
    "lithifiées": ("lithifier",),
    "lithifié": ("lithifier",),
    "lithifient": ("lithifier",),
    "lithifie": ("lithifier",),
    "lithifiera": ("lithifier",),
    "lithifieraient": ("lithifier",),
    "lithifierai": ("lithifier",),
    "lithifierais": ("lithifier",),
    "lithifierait": ("lithifier",),
    "lithifieras": ("lithifier",),
    "lithifièrent": ("lithifier",),
    "lithifierez": ("lithifier",),
    "lithifieriez": ("lithifier",),
    "lithifierions": ("lithifier",),
    "lithifierons": ("lithifier",),
    "lithifieront": ("lithifier",),
    "lithifiés": ("lithifier",),
    "lithifies": ("lithifier",),
    "lithifiez": ("lithifier",),
    "lithifiiez": ("lithifier",),
    "lithifiions": ("lithifier",),
    "lithifions": ("lithifier",),
    "lithographiaient": ("lithographier",),
    "lithographiai": ("lithographier",),
    "lithographiais": ("lithographier",),
    "lithographiait": ("lithographier",),
    "lithographia": ("lithographier",),
    "lithographiâmes": ("lithographier",),
    "lithographiant": ("lithographier",),
    "lithographias": ("lithographier",),
    "lithographiassent": ("lithographier",),
    "lithographiasses": ("lithographier",),
    "lithographiasse": ("lithographier",),
    "lithographiassiez": ("lithographier",),
    "lithographiassions": ("lithographier",),
    "lithographiâtes": ("lithographier",),
    "lithographiât": ("lithographier",),
    "lithographiée": ("lithographier",),
    "lithographiées": ("lithographier",),
    "lithographié": ("lithographier",),
    "lithographient": ("lithographier",),
    "lithographie": ("lithographier",),
    "lithographiera": ("lithographier",),
    "lithographieraient": ("lithographier",),
    "lithographierai": ("lithographier",),
    "lithographierais": ("lithographier",),
    "lithographierait": ("lithographier",),
    "lithographieras": ("lithographier",),
    "lithographièrent": ("lithographier",),
    "lithographierez": ("lithographier",),
    "lithographieriez": ("lithographier",),
    "lithographierions": ("lithographier",),
    "lithographierons": ("lithographier",),
    "lithographieront": ("lithographier",),
    "lithographiés": ("lithographier",),
    "lithographies": ("lithographier",),
    "lithographiez": ("lithographier",),
    "lithographiiez": ("lithographier",),
    "lithographiions": ("lithographier",),
    "lithographions": ("lithographier",),
    "lithotypographiaient": ("lithotypographier",),
    "lithotypographiai": ("lithotypographier",),
    "lithotypographiais": ("lithotypographier",),
    "lithotypographiait": ("lithotypographier",),
    "lithotypographia": ("lithotypographier",),
    "lithotypographiâmes": ("lithotypographier",),
    "lithotypographiant": ("lithotypographier",),
    "lithotypographias": ("lithotypographier",),
    "lithotypographiassent": ("lithotypographier",),
    "lithotypographiasses": ("lithotypographier",),
    "lithotypographiasse": ("lithotypographier",),
    "lithotypographiassiez": ("lithotypographier",),
    "lithotypographiassions": ("lithotypographier",),
    "lithotypographiâtes": ("lithotypographier",),
    "lithotypographiât": ("lithotypographier",),
    "lithotypographiée": ("lithotypographier",),
    "lithotypographiées": ("lithotypographier",),
    "lithotypographié": ("lithotypographier",),
    "lithotypographient": ("lithotypographier",),
    "lithotypographie": ("lithotypographier",),
    "lithotypographiera": ("lithotypographier",),
    "lithotypographieraient": ("lithotypographier",),
    "lithotypographierai": ("lithotypographier",),
    "lithotypographierais": ("lithotypographier",),
    "lithotypographierait": ("lithotypographier",),
    "lithotypographieras": ("lithotypographier",),
    "lithotypographièrent": ("lithotypographier",),
    "lithotypographierez": ("lithotypographier",),
    "lithotypographieriez": ("lithotypographier",),
    "lithotypographierions": ("lithotypographier",),
    "lithotypographierons": ("lithotypographier",),
    "lithotypographieront": ("lithotypographier",),
    "lithotypographiés": ("lithotypographier",),
    "lithotypographies": ("lithotypographier",),
    "lithotypographiez": ("lithotypographier",),
    "lithotypographiiez": ("lithotypographier",),
    "lithotypographiions": ("lithotypographier",),
    "lithotypographions": ("lithotypographier",),
    "lixiviaient": ("lixivier",),
    "lixiviai": ("lixivier",),
    "lixiviais": ("lixivier",),
    "lixiviait": ("lixivier",),
    "lixivia": ("lixivier",),
    "lixiviâmes": ("lixivier",),
    "lixiviant": ("lixivier",),
    "lixivias": ("lixivier",),
    "lixiviassent": ("lixivier",),
    "lixiviasses": ("lixivier",),
    "lixiviasse": ("lixivier",),
    "lixiviassiez": ("lixivier",),
    "lixiviassions": ("lixivier",),
    "lixiviâtes": ("lixivier",),
    "lixiviât": ("lixivier",),
    "lixiviée": ("lixivier",),
    "lixiviées": ("lixivier",),
    "lixivié": ("lixivier",),
    "lixivient": ("lixivier",),
    "lixivie": ("lixivier",),
    "lixiviera": ("lixivier",),
    "lixivieraient": ("lixivier",),
    "lixivierai": ("lixivier",),
    "lixivierais": ("lixivier",),
    "lixivierait": ("lixivier",),
    "lixivieras": ("lixivier",),
    "lixivièrent": ("lixivier",),
    "lixivierez": ("lixivier",),
    "lixivieriez": ("lixivier",),
    "lixivierions": ("lixivier",),
    "lixivierons": ("lixivier",),
    "lixivieront": ("lixivier",),
    "lixiviés": ("lixivier",),
    "lixivies": ("lixivier",),
    "lixiviez": ("lixivier",),
    "lixiviiez": ("lixivier",),
    "lixiviions": ("lixivier",),
    "lixivions": ("lixivier",),
    "logeaient": ("loger",),
    "logeai": ("loger",),
    "logeais": ("loger",),
    "logeait": ("loger",),
    "logea": ("loger",),
    "logeâmes": ("loger",),
    "logeant": ("loger",),
    "logeas": ("loger",),
    "logeassent": ("loger",),
    "logeasses": ("loger",),
    "logeasse": ("loger",),
    "logeassiez": ("loger",),
    "logeassions": ("loger",),
    "logeâtes": ("loger",),
    "logeât": ("loger",),
    "logée": ("loger",),
    "logées": ("loger",),
    "logé": ("loger",),
    "logent": ("loger",),
    "logeons": ("loger",),
    "loge": ("loger",),
    "logera": ("loger",),
    "logeraient": ("loger",),
    "logerai": ("loger",),
    "logerais": ("loger",),
    "logerait": ("loger",),
    "logeras": ("loger",),
    "logèrent": ("loger",),
    "logerez": ("loger",),
    "logeriez": ("loger",),
    "logerions": ("loger",),
    "logerons": ("loger",),
    "logeront": ("loger",),
    "logés": ("loger",),
    "loges": ("loger",),
    "logez": ("loger",),
    "logiez": ("loger",),
    "logions": ("loger",),
    "longeaient": ("longer",),
    "longeai": ("longer",),
    "longeais": ("longer",),
    "longeait": ("longer",),
    "longea": ("longer",),
    "longeâmes": ("longer",),
    "longeant": ("longer",),
    "longeas": ("longer",),
    "longeassent": ("longer",),
    "longeasses": ("longer",),
    "longeasse": ("longer",),
    "longeassiez": ("longer",),
    "longeassions": ("longer",),
    "longeâtes": ("longer",),
    "longeât": ("longer",),
    "longée": ("longer",),
    "longées": ("longer",),
    "longé": ("longer",),
    "longent": ("longer",),
    "longeons": ("longer",),
    "longe": ("longer",),
    "longera": ("longer",),
    "longeraient": ("longer",),
    "longerai": ("longer",),
    "longerais": ("longer",),
    "longerait": ("longer",),
    "longeras": ("longer",),
    "longèrent": ("longer",),
    "longerez": ("longer",),
    "longeriez": ("longer",),
    "longerions": ("longer",),
    "longerons": ("longer",),
    "longeront": ("longer",),
    "longés": ("longer",),
    "longes": ("longer",),
    "longez": ("longer",),
    "longiez": ("longer",),
    "longions": ("longer",),
    "loquetaient": ("loqueter",),
    "loquetai": ("loqueter",),
    "loquetais": ("loqueter",),
    "loquetait": ("loqueter",),
    "loqueta": ("loqueter",),
    "loquetâmes": ("loqueter",),
    "loquetant": ("loqueter",),
    "loquetas": ("loqueter",),
    "loquetassent": ("loqueter",),
    "loquetasses": ("loqueter",),
    "loquetasse": ("loqueter",),
    "loquetassiez": ("loqueter",),
    "loquetassions": ("loqueter",),
    "loquetâtes": ("loqueter",),
    "loquetât": ("loqueter",),
    "loquetée": ("loqueter",),
    "loquetées": ("loqueter",),
    "loqueté": ("loqueter",),
    "loquetèrent": ("loqueter",),
    "loquetés": ("loqueter",),
    "loquetez": ("loqueter",),
    "loquetiez": ("loqueter",),
    "loquetions": ("loqueter",),
    "loquetons": ("loqueter",),
    "loquettent": ("loqueter",),
    "loquette": ("loqueter",),
    "loquettera": ("loqueter",),
    "loquetteraient": ("loqueter",),
    "loquetterai": ("loqueter",),
    "loquetterais": ("loqueter",),
    "loquetterait": ("loqueter",),
    "loquetteras": ("loqueter",),
    "loquetterez": ("loqueter",),
    "loquetteriez": ("loqueter",),
    "loquetterions": ("loqueter",),
    "loquetterons": ("loqueter",),
    "loquetteront": ("loqueter",),
    "loquettes": ("loqueter",),
    "losangeaient": ("losanger",),
    "losangeai": ("losanger",),
    "losangeais": ("losanger",),
    "losangeait": ("losanger",),
    "losangea": ("losanger",),
    "losangeâmes": ("losanger",),
    "losangeant": ("losanger",),
    "losangeas": ("losanger",),
    "losangeassent": ("losanger",),
    "losangeasses": ("losanger",),
    "losangeasse": ("losanger",),
    "losangeassiez": ("losanger",),
    "losangeassions": ("losanger",),
    "losangeâtes": ("losanger",),
    "losangeât": ("losanger",),
    "losangée": ("losanger",),
    "losangées": ("losanger",),
    "losangé": ("losanger",),
    "losangent": ("losanger",),
    "losangeons": ("losanger",),
    "losange": ("losanger",),
    "losangera": ("losanger",),
    "losangeraient": ("losanger",),
    "losangerai": ("losanger",),
    "losangerais": ("losanger",),
    "losangerait": ("losanger",),
    "losangeras": ("losanger",),
    "losangèrent": ("losanger",),
    "losangerez": ("losanger",),
    "losangeriez": ("losanger",),
    "losangerions": ("losanger",),
    "losangerons": ("losanger",),
    "losangeront": ("losanger",),
    "losangés": ("losanger",),
    "losanges": ("losanger",),
    "losangez": ("losanger",),
    "losangiez": ("losanger",),
    "losangions": ("losanger",),
    "lotie": ("lotir",),
    "loties": ("lotir",),
    "loti": ("lotir",),
    "lotîmes": ("lotir",),
    "lotira": ("lotir",),
    "lotiraient": ("lotir",),
    "lotirai": ("lotir",),
    "lotirais": ("lotir",),
    "lotirait": ("lotir",),
    "lotiras": ("lotir",),
    "lotirent": ("lotir",),
    "lotirez": ("lotir",),
    "lotiriez": ("lotir",),
    "lotirions": ("lotir",),
    "lotirons": ("lotir",),
    "lotiront": ("lotir",),
    "lotis": ("lotir",),
    "lotissaient": ("lotir",),
    "lotissais": ("lotir",),
    "lotissait": ("lotir",),
    "lotissant": ("lotir",),
    "lotissent": ("lotir",),
    "lotisse": ("lotir",),
    "lotisses": ("lotir",),
    "lotissez": ("lotir",),
    "lotissiez": ("lotir",),
    "lotissions": ("lotir",),
    "lotissons": ("lotir",),
    "lotîtes": ("lotir",),
    "lotit": ("lotir",),
    "lotît": ("lotir",),
    "louangeaient": ("louanger",),
    "louangeai": ("louanger",),
    "louangeais": ("louanger",),
    "louangeait": ("louanger",),
    "louangea": ("louanger",),
    "louangeâmes": ("louanger",),
    "louangeant": ("louanger",),
    "louangeas": ("louanger",),
    "louangeassent": ("louanger",),
    "louangeasses": ("louanger",),
    "louangeasse": ("louanger",),
    "louangeassiez": ("louanger",),
    "louangeassions": ("louanger",),
    "louangeâtes": ("louanger",),
    "louangeât": ("louanger",),
    "louangée": ("louanger",),
    "louangées": ("louanger",),
    "louangé": ("louanger",),
    "louangent": ("louanger",),
    "louangeons": ("louanger",),
    "louange": ("louanger",),
    "louangera": ("louanger",),
    "louangeraient": ("louanger",),
    "louangerai": ("louanger",),
    "louangerais": ("louanger",),
    "louangerait": ("louanger",),
    "louangeras": ("louanger",),
    "louangèrent": ("louanger",),
    "louangerez": ("louanger",),
    "louangeriez": ("louanger",),
    "louangerions": ("louanger",),
    "louangerons": ("louanger",),
    "louangeront": ("louanger",),
    "louangés": ("louanger",),
    "louanges": ("louanger",),
    "louangez": ("louanger",),
    "louangiez": ("louanger",),
    "louangions": ("louanger",),
    "louchi": ("louchir",),
    "louchîmes": ("louchir",),
    "louchira": ("louchir",),
    "louchiraient": ("louchir",),
    "louchirai": ("louchir",),
    "louchirais": ("louchir",),
    "louchirait": ("louchir",),
    "louchiras": ("louchir",),
    "louchirent": ("louchir",),
    "louchirez": ("louchir",),
    "louchiriez": ("louchir",),
    "louchirions": ("louchir",),
    "louchirons": ("louchir",),
    "louchiront": ("louchir",),
    "louchis": ("louchir",),
    "louchissaient": ("louchir",),
    "louchissais": ("louchir",),
    "louchissait": ("louchir",),
    "louchissant": ("louchir",),
    "louchissent": ("louchir",),
    "louchisse": ("louchir",),
    "louchisses": ("louchir",),
    "louchissez": ("louchir",),
    "louchissiez": ("louchir",),
    "louchissions": ("louchir",),
    "louchissons": ("louchir",),
    "louchîtes": ("louchir",),
    "louchit": ("louchir",),
    "louchît": ("louchir",),
    "louvetaient": ("louveter",),
    "louvetai": ("louveter",),
    "louvetais": ("louveter",),
    "louvetait": ("louveter",),
    "louveta": ("louveter",),
    "louvetâmes": ("louveter",),
    "louvetant": ("louveter",),
    "louvetas": ("louveter",),
    "louvetassent": ("louveter",),
    "louvetasses": ("louveter",),
    "louvetasse": ("louveter",),
    "louvetassiez": ("louveter",),
    "louvetassions": ("louveter",),
    "louvetâtes": ("louveter",),
    "louvetât": ("louveter",),
    "louvetée": ("louveter",),
    "louvetées": ("louveter",),
    "louveté": ("louveter",),
    "louvetèrent": ("louveter",),
    "louvetés": ("louveter",),
    "louvetez": ("louveter",),
    "louvetiez": ("louveter",),
    "louvetions": ("louveter",),
    "louvetons": ("louveter",),
    "louvettent": ("louveter",),
    "louvette": ("louveter",),
    "louvettera": ("louveter",),
    "louvetteraient": ("louveter",),
    "louvetterai": ("louveter",),
    "louvetterais": ("louveter",),
    "louvetterait": ("louveter",),
    "louvetteras": ("louveter",),
    "louvetterez": ("louveter",),
    "louvetteriez": ("louveter",),
    "louvetterions": ("louveter",),
    "louvetterons": ("louveter",),
    "louvetteront": ("louveter",),
    "louvettes": ("louveter",),
    "louvoient": ("louvoyer",),
    "louvoie": ("louvoyer",),
    "louvoiera": ("louvoyer",),
    "louvoieraient": ("louvoyer",),
    "louvoierai": ("louvoyer",),
    "louvoierais": ("louvoyer",),
    "louvoierait": ("louvoyer",),
    "louvoieras": ("louvoyer",),
    "louvoierez": ("louvoyer",),
    "louvoieriez": ("louvoyer",),
    "louvoierions": ("louvoyer",),
    "louvoierons": ("louvoyer",),
    "louvoieront": ("louvoyer",),
    "louvoies": ("louvoyer",),
    "louvoyaient": ("louvoyer",),
    "louvoyai": ("louvoyer",),
    "louvoyais": ("louvoyer",),
    "louvoyait": ("louvoyer",),
    "louvoya": ("louvoyer",),
    "louvoyâmes": ("louvoyer",),
    "louvoyant": ("louvoyer",),
    "louvoyas": ("louvoyer",),
    "louvoyassent": ("louvoyer",),
    "louvoyasses": ("louvoyer",),
    "louvoyasse": ("louvoyer",),
    "louvoyassiez": ("louvoyer",),
    "louvoyassions": ("louvoyer",),
    "louvoyâtes": ("louvoyer",),
    "louvoyât": ("louvoyer",),
    "louvoyé": ("louvoyer",),
    "louvoyèrent": ("louvoyer",),
    "louvoyez": ("louvoyer",),
    "louvoyiez": ("louvoyer",),
    "louvoyions": ("louvoyer",),
    "louvoyons": ("louvoyer",),
    "lubrifiaient": ("lubrifier",),
    "lubrifiai": ("lubrifier",),
    "lubrifiais": ("lubrifier",),
    "lubrifiait": ("lubrifier",),
    "lubrifia": ("lubrifier",),
    "lubrifiâmes": ("lubrifier",),
    "lubrifiant": ("lubrifier",),
    "lubrifias": ("lubrifier",),
    "lubrifiassent": ("lubrifier",),
    "lubrifiasses": ("lubrifier",),
    "lubrifiasse": ("lubrifier",),
    "lubrifiassiez": ("lubrifier",),
    "lubrifiassions": ("lubrifier",),
    "lubrifiâtes": ("lubrifier",),
    "lubrifiât": ("lubrifier",),
    "lubrifiée": ("lubrifier",),
    "lubrifiées": ("lubrifier",),
    "lubrifié": ("lubrifier",),
    "lubrifient": ("lubrifier",),
    "lubrifie": ("lubrifier",),
    "lubrifiera": ("lubrifier",),
    "lubrifieraient": ("lubrifier",),
    "lubrifierai": ("lubrifier",),
    "lubrifierais": ("lubrifier",),
    "lubrifierait": ("lubrifier",),
    "lubrifieras": ("lubrifier",),
    "lubrifièrent": ("lubrifier",),
    "lubrifierez": ("lubrifier",),
    "lubrifieriez": ("lubrifier",),
    "lubrifierions": ("lubrifier",),
    "lubrifierons": ("lubrifier",),
    "lubrifieront": ("lubrifier",),
    "lubrifiés": ("lubrifier",),
    "lubrifies": ("lubrifier",),
    "lubrifiez": ("lubrifier",),
    "lubrifiiez": ("lubrifier",),
    "lubrifiions": ("lubrifier",),
    "lubrifions": ("lubrifier",),
    "lugeaient": ("luger",),
    "lugeai": ("luger",),
    "lugeais": ("luger",),
    "lugeait": ("luger",),
    "lugea": ("luger",),
    "lugeâmes": ("luger",),
    "lugeant": ("luger",),
    "lugeas": ("luger",),
    "lugeassent": ("luger",),
    "lugeasses": ("luger",),
    "lugeasse": ("luger",),
    "lugeassiez": ("luger",),
    "lugeassions": ("luger",),
    "lugeâtes": ("luger",),
    "lugeât": ("luger",),
    "lugée": ("luger",),
    "lugées": ("luger",),
    "lugé": ("luger",),
    "lugent": ("luger",),
    "lugeons": ("luger",),
    "luge": ("luger",),
    "lugera": ("luger",),
    "lugeraient": ("luger",),
    "lugerai": ("luger",),
    "lugerais": ("luger",),
    "lugerait": ("luger",),
    "lugeras": ("luger",),
    "lugèrent": ("luger",),
    "lugerez": ("luger",),
    "lugeriez": ("luger",),
    "lugerions": ("luger",),
    "lugerons": ("luger",),
    "lugeront": ("luger",),
    "lugés": ("luger",),
    "luges": ("luger",),
    "lugez": ("luger",),
    "lugiez": ("luger",),
    "lugions": ("luger",),
    "lui": ("luire",),
    "luîmes": ("luire",),
    "luira": ("luire",),
    "luiraient": ("luire",),
    "luirai": ("luire",),
    "luirais": ("luire",),
    "luirait": ("luire",),
    "luiras": ("luire",),
    "luirent": ("luire",),
    "luirez": ("luire",),
    "luiriez": ("luire",),
    "luirions": ("luire",),
    "luirons": ("luire",),
    "luiront": ("luire",),
    "luisaient": ("luire",),
    "luisais": ("luire",),
    "luisait": ("luire",),
    "luisant": ("luire",),
    "luisent": ("luire",),
    "luise": ("luire",),
    "luises": ("luire",),
    "luisez": ("luire",),
    "luisiez": ("luire",),
    "luisîmes": ("luire",),
    "luisions": ("luire",),
    "luisirent": ("luire",),
    "luisis": ("luire",),
    "luisissent": ("luire",),
    "luisisses": ("luire",),
    "luisisse": ("luire",),
    "luisissiez": ("luire",),
    "luisissions": ("luire",),
    "luisîtes": ("luire",),
    "luisit": ("luire",),
    "luisît": ("luire",),
    "luisons": ("luire",),
    "luis": ("luire",),
    "luîtes": ("luire",),
    "luit": ("luire",),
    "macéraient": ("macérer",),
    "macérai": ("macérer",),
    "macérais": ("macérer",),
    "macérait": ("macérer",),
    "macéra": ("macérer",),
    "macérâmes": ("macérer",),
    "macérant": ("macérer",),
    "macéras": ("macérer",),
    "macérassent": ("macérer",),
    "macérasses": ("macérer",),
    "macérasse": ("macérer",),
    "macérassiez": ("macérer",),
    "macérassions": ("macérer",),
    "macérâtes": ("macérer",),
    "macérât": ("macérer",),
    "macérée": ("macérer",),
    "macérées": ("macérer",),
    "macéré": ("macérer",),
    "macèrent": ("macérer",),
    "macère": ("macérer",),
    "macérera": ("macérer",),
    "macéreraient": ("macérer",),
    "macérerai": ("macérer",),
    "macérerais": ("macérer",),
    "macérerait": ("macérer",),
    "macéreras": ("macérer",),
    "macérèrent": ("macérer",),
    "macérerez": ("macérer",),
    "macéreriez": ("macérer",),
    "macérerions": ("macérer",),
    "macérerons": ("macérer",),
    "macéreront": ("macérer",),
    "macérés": ("macérer",),
    "macères": ("macérer",),
    "macérez": ("macérer",),
    "macériez": ("macérer",),
    "macérions": ("macérer",),
    "macérons": ("macérer",),
    "macrophotographiaient": ("macrophotographier",),
    "macrophotographiai": ("macrophotographier",),
    "macrophotographiais": ("macrophotographier",),
    "macrophotographiait": ("macrophotographier",),
    "macrophotographia": ("macrophotographier",),
    "macrophotographiâmes": ("macrophotographier",),
    "macrophotographiant": ("macrophotographier",),
    "macrophotographias": ("macrophotographier",),
    "macrophotographiassent": ("macrophotographier",),
    "macrophotographiasses": ("macrophotographier",),
    "macrophotographiasse": ("macrophotographier",),
    "macrophotographiassiez": ("macrophotographier",),
    "macrophotographiassions": ("macrophotographier",),
    "macrophotographiâtes": ("macrophotographier",),
    "macrophotographiât": ("macrophotographier",),
    "macrophotographiée": ("macrophotographier",),
    "macrophotographiées": ("macrophotographier",),
    "macrophotographié": ("macrophotographier",),
    "macrophotographient": ("macrophotographier",),
    "macrophotographie": ("macrophotographier",),
    "macrophotographiera": ("macrophotographier",),
    "macrophotographieraient": ("macrophotographier",),
    "macrophotographierai": ("macrophotographier",),
    "macrophotographierais": ("macrophotographier",),
    "macrophotographierait": ("macrophotographier",),
    "macrophotographieras": ("macrophotographier",),
    "macrophotographièrent": ("macrophotographier",),
    "macrophotographierez": ("macrophotographier",),
    "macrophotographieriez": ("macrophotographier",),
    "macrophotographierions": ("macrophotographier",),
    "macrophotographierons": ("macrophotographier",),
    "macrophotographieront": ("macrophotographier",),
    "macrophotographiés": ("macrophotographier",),
    "macrophotographies": ("macrophotographier",),
    "macrophotographiez": ("macrophotographier",),
    "macrophotographiiez": ("macrophotographier",),
    "macrophotographiions": ("macrophotographier",),
    "macrophotographions": ("macrophotographier",),
    "madéfiaient": ("madéfier",),
    "madéfiai": ("madéfier",),
    "madéfiais": ("madéfier",),
    "madéfiait": ("madéfier",),
    "madéfia": ("madéfier",),
    "madéfiâmes": ("madéfier",),
    "madéfiant": ("madéfier",),
    "madéfias": ("madéfier",),
    "madéfiassent": ("madéfier",),
    "madéfiasses": ("madéfier",),
    "madéfiasse": ("madéfier",),
    "madéfiassiez": ("madéfier",),
    "madéfiassions": ("madéfier",),
    "madéfiâtes": ("madéfier",),
    "madéfiât": ("madéfier",),
    "madéfiée": ("madéfier",),
    "madéfiées": ("madéfier",),
    "madéfié": ("madéfier",),
    "madéfient": ("madéfier",),
    "madéfie": ("madéfier",),
    "madéfiera": ("madéfier",),
    "madéfieraient": ("madéfier",),
    "madéfierai": ("madéfier",),
    "madéfierais": ("madéfier",),
    "madéfierait": ("madéfier",),
    "madéfieras": ("madéfier",),
    "madéfièrent": ("madéfier",),
    "madéfierez": ("madéfier",),
    "madéfieriez": ("madéfier",),
    "madéfierions": ("madéfier",),
    "madéfierons": ("madéfier",),
    "madéfieront": ("madéfier",),
    "madéfiés": ("madéfier",),
    "madéfies": ("madéfier",),
    "madéfiez": ("madéfier",),
    "madéfiiez": ("madéfier",),
    "madéfiions": ("madéfier",),
    "madéfions": ("madéfier",),
    "magnésiaient": ("magnésier",),
    "magnésiai": ("magnésier",),
    "magnésiais": ("magnésier",),
    "magnésiait": ("magnésier",),
    "magnésia": ("magnésier",),
    "magnésiâmes": ("magnésier",),
    "magnésiant": ("magnésier",),
    "magnésias": ("magnésier",),
    "magnésiassent": ("magnésier",),
    "magnésiasses": ("magnésier",),
    "magnésiasse": ("magnésier",),
    "magnésiassiez": ("magnésier",),
    "magnésiassions": ("magnésier",),
    "magnésiâtes": ("magnésier",),
    "magnésiât": ("magnésier",),
    "magnésiée": ("magnésier",),
    "magnésiées": ("magnésier",),
    "magnésié": ("magnésier",),
    "magnésient": ("magnésier",),
    "magnésie": ("magnésier",),
    "magnésiera": ("magnésier",),
    "magnésieraient": ("magnésier",),
    "magnésierai": ("magnésier",),
    "magnésierais": ("magnésier",),
    "magnésierait": ("magnésier",),
    "magnésieras": ("magnésier",),
    "magnésièrent": ("magnésier",),
    "magnésierez": ("magnésier",),
    "magnésieriez": ("magnésier",),
    "magnésierions": ("magnésier",),
    "magnésierons": ("magnésier",),
    "magnésieront": ("magnésier",),
    "magnésiés": ("magnésier",),
    "magnésies": ("magnésier",),
    "magnésiez": ("magnésier",),
    "magnésiiez": ("magnésier",),
    "magnésiions": ("magnésier",),
    "magnésions": ("magnésier",),
    "magnifiaient": ("magnifier",),
    "magnifiai": ("magnifier",),
    "magnifiais": ("magnifier",),
    "magnifiait": ("magnifier",),
    "magnifia": ("magnifier",),
    "magnifiâmes": ("magnifier",),
    "magnifiant": ("magnifier",),
    "magnifias": ("magnifier",),
    "magnifiassent": ("magnifier",),
    "magnifiasses": ("magnifier",),
    "magnifiasse": ("magnifier",),
    "magnifiassiez": ("magnifier",),
    "magnifiassions": ("magnifier",),
    "magnifiâtes": ("magnifier",),
    "magnifiât": ("magnifier",),
    "magnifiée": ("magnifier",),
    "magnifiées": ("magnifier",),
    "magnifié": ("magnifier",),
    "magnifient": ("magnifier",),
    "magnifie": ("magnifier",),
    "magnifiera": ("magnifier",),
    "magnifieraient": ("magnifier",),
    "magnifierai": ("magnifier",),
    "magnifierais": ("magnifier",),
    "magnifierait": ("magnifier",),
    "magnifieras": ("magnifier",),
    "magnifièrent": ("magnifier",),
    "magnifierez": ("magnifier",),
    "magnifieriez": ("magnifier",),
    "magnifierions": ("magnifier",),
    "magnifierons": ("magnifier",),
    "magnifieront": ("magnifier",),
    "magnifiés": ("magnifier",),
    "magnifies": ("magnifier",),
    "magnifiez": ("magnifier",),
    "magnifiiez": ("magnifier",),
    "magnifiions": ("magnifier",),
    "magnifions": ("magnifier",),
    "maigrie": ("maigrir",),
    "maigries": ("maigrir",),
    "maigri": ("maigrir",),
    "maigrîmes": ("maigrir",),
    "maigrira": ("maigrir",),
    "maigriraient": ("maigrir",),
    "maigrirai": ("maigrir",),
    "maigrirais": ("maigrir",),
    "maigrirait": ("maigrir",),
    "maigriras": ("maigrir",),
    "maigrirent": ("maigrir",),
    "maigrirez": ("maigrir",),
    "maigririez": ("maigrir",),
    "maigririons": ("maigrir",),
    "maigrirons": ("maigrir",),
    "maigriront": ("maigrir",),
    "maigris": ("maigrir",),
    "maigrissaient": ("maigrir",),
    "maigrissais": ("maigrir",),
    "maigrissait": ("maigrir",),
    "maigrissant": ("maigrir",),
    "maigrissent": ("maigrir",),
    "maigrisse": ("maigrir",),
    "maigrisses": ("maigrir",),
    "maigrissez": ("maigrir",),
    "maigrissiez": ("maigrir",),
    "maigrissions": ("maigrir",),
    "maigrissons": ("maigrir",),
    "maigrîtes": ("maigrir",),
    "maigrit": ("maigrir",),
    "maigrît": ("maigrir",),
    "mailletaient": ("mailleter",),
    "mailletai": ("mailleter",),
    "mailletais": ("mailleter",),
    "mailletait": ("mailleter",),
    "mailleta": ("mailleter",),
    "mailletâmes": ("mailleter",),
    "mailletant": ("mailleter",),
    "mailletas": ("mailleter",),
    "mailletassent": ("mailleter",),
    "mailletasses": ("mailleter",),
    "mailletasse": ("mailleter",),
    "mailletassiez": ("mailleter",),
    "mailletassions": ("mailleter",),
    "mailletâtes": ("mailleter",),
    "mailletât": ("mailleter",),
    "mailletée": ("mailleter",),
    "mailletées": ("mailleter",),
    "mailleté": ("mailleter",),
    "mailletèrent": ("mailleter",),
    "mailletés": ("mailleter",),
    "mailletez": ("mailleter",),
    "mailletiez": ("mailleter",),
    "mailletions": ("mailleter",),
    "mailletons": ("mailleter",),
    "maillettent": ("mailleter",),
    "maillette": ("mailleter",),
    "maillettera": ("mailleter",),
    "mailletteraient": ("mailleter",),
    "mailletterai": ("mailleter",),
    "mailletterais": ("mailleter",),
    "mailletterait": ("mailleter",),
    "mailletteras": ("mailleter",),
    "mailletterez": ("mailleter",),
    "mailletteriez": ("mailleter",),
    "mailletterions": ("mailleter",),
    "mailletterons": ("mailleter",),
    "mailletteront": ("mailleter",),
    "maillettes": ("mailleter",),
    "maintenaient": ("maintenir",),
    "maintenais": ("maintenir",),
    "maintenait": ("maintenir",),
    "maintenant": ("maintenir",),
    "maintenez": ("maintenir",),
    "mainteniez": ("maintenir",),
    "maintenions": ("maintenir",),
    "maintenons": ("maintenir",),
    "maintenue": ("maintenir",),
    "maintenues": ("maintenir",),
    "maintenu": ("maintenir",),
    "maintenus": ("maintenir",),
    "maintiendra": ("maintenir",),
    "maintiendraient": ("maintenir",),
    "maintiendrai": ("maintenir",),
    "maintiendrais": ("maintenir",),
    "maintiendrait": ("maintenir",),
    "maintiendras": ("maintenir",),
    "maintiendrez": ("maintenir",),
    "maintiendriez": ("maintenir",),
    "maintiendrions": ("maintenir",),
    "maintiendrons": ("maintenir",),
    "maintiendront": ("maintenir",),
    "maintiennent": ("maintenir",),
    "maintienne": ("maintenir",),
    "maintiennes": ("maintenir",),
    "maintiens": ("maintenir",),
    "maintient": ("maintenir",),
    "maintînmes": ("maintenir",),
    "maintinrent": ("maintenir",),
    "maintins": ("maintenir",),
    "maintinssent": ("maintenir",),
    "maintinsses": ("maintenir",),
    "maintinsse": ("maintenir",),
    "maintinssiez": ("maintenir",),
    "maintinssions": ("maintenir",),
    "maintîntes": ("maintenir",),
    "maintint": ("maintenir",),
    "maintînt": ("maintenir",),
    "malchançaient": ("malchancer",),
    "malchançai": ("malchancer",),
    "malchançais": ("malchancer",),
    "malchançait": ("malchancer",),
    "malchança": ("malchancer",),
    "malchançâmes": ("malchancer",),
    "malchançant": ("malchancer",),
    "malchanças": ("malchancer",),
    "malchançassent": ("malchancer",),
    "malchançasses": ("malchancer",),
    "malchançasse": ("malchancer",),
    "malchançassiez": ("malchancer",),
    "malchançassions": ("malchancer",),
    "malchançâtes": ("malchancer",),
    "malchançât": ("malchancer",),
    "malchancé": ("malchancer",),
    "malchancent": ("malchancer",),
    "malchance": ("malchancer",),
    "malchancera": ("malchancer",),
    "malchanceraient": ("malchancer",),
    "malchancerai": ("malchancer",),
    "malchancerais": ("malchancer",),
    "malchancerait": ("malchancer",),
    "malchanceras": ("malchancer",),
    "malchancèrent": ("malchancer",),
    "malchancerez": ("malchancer",),
    "malchanceriez": ("malchancer",),
    "malchancerions": ("malchancer",),
    "malchancerons": ("malchancer",),
    "malchanceront": ("malchancer",),
    "malchances": ("malchancer",),
    "malchancez": ("malchancer",),
    "malchanciez": ("malchancer",),
    "malchancions": ("malchancer",),
    "malchançons": ("malchancer",),
    "maléficiaient": ("maléficier",),
    "maléficiai": ("maléficier",),
    "maléficiais": ("maléficier",),
    "maléficiait": ("maléficier",),
    "maléficia": ("maléficier",),
    "maléficiâmes": ("maléficier",),
    "maléficiant": ("maléficier",),
    "maléficias": ("maléficier",),
    "maléficiassent": ("maléficier",),
    "maléficiasses": ("maléficier",),
    "maléficiasse": ("maléficier",),
    "maléficiassiez": ("maléficier",),
    "maléficiassions": ("maléficier",),
    "maléficiâtes": ("maléficier",),
    "maléficiât": ("maléficier",),
    "maléficiée": ("maléficier",),
    "maléficiées": ("maléficier",),
    "maléficié": ("maléficier",),
    "maléficient": ("maléficier",),
    "maléficie": ("maléficier",),
    "maléficiera": ("maléficier",),
    "maléficieraient": ("maléficier",),
    "maléficierai": ("maléficier",),
    "maléficierais": ("maléficier",),
    "maléficierait": ("maléficier",),
    "maléficieras": ("maléficier",),
    "maléficièrent": ("maléficier",),
    "maléficierez": ("maléficier",),
    "maléficieriez": ("maléficier",),
    "maléficierions": ("maléficier",),
    "maléficierons": ("maléficier",),
    "maléficieront": ("maléficier",),
    "maléficiés": ("maléficier",),
    "maléficies": ("maléficier",),
    "maléficiez": ("maléficier",),
    "maléficiiez": ("maléficier",),
    "maléficiions": ("maléficier",),
    "maléficions": ("maléficier",),
    "malléaient": ("malléer",),
    "malléai": ("malléer",),
    "malléais": ("malléer",),
    "malléait": ("malléer",),
    "malléa": ("malléer",),
    "malléâmes": ("malléer",),
    "malléant": ("malléer",),
    "malléas": ("malléer",),
    "malléassent": ("malléer",),
    "malléasses": ("malléer",),
    "malléasse": ("malléer",),
    "malléassiez": ("malléer",),
    "malléassions": ("malléer",),
    "malléâtes": ("malléer",),
    "malléât": ("malléer",),
    "malléée": ("malléer",),
    "malléées": ("malléer",),
    "malléé": ("malléer",),
    "malléent": ("malléer",),
    "mallée": ("malléer",),
    "malléera": ("malléer",),
    "malléeraient": ("malléer",),
    "malléerai": ("malléer",),
    "malléerais": ("malléer",),
    "malléerait": ("malléer",),
    "malléeras": ("malléer",),
    "malléèrent": ("malléer",),
    "malléerez": ("malléer",),
    "malléeriez": ("malléer",),
    "malléerions": ("malléer",),
    "malléerons": ("malléer",),
    "malléeront": ("malléer",),
    "malléés": ("malléer",),
    "mallées": ("malléer",),
    "malléez": ("malléer",),
    "malléiez": ("malléer",),
    "malléions": ("malléer",),
    "malléons": ("malléer",),
    "malmenaient": ("malmener",),
    "malmenai": ("malmener",),
    "malmenais": ("malmener",),
    "malmenait": ("malmener",),
    "malmena": ("malmener",),
    "malmenâmes": ("malmener",),
    "malmenant": ("malmener",),
    "malmenas": ("malmener",),
    "malmenassent": ("malmener",),
    "malmenasses": ("malmener",),
    "malmenasse": ("malmener",),
    "malmenassiez": ("malmener",),
    "malmenassions": ("malmener",),
    "malmenâtes": ("malmener",),
    "malmenât": ("malmener",),
    "malmenée": ("malmener",),
    "malmenées": ("malmener",),
    "malmené": ("malmener",),
    "malmènent": ("malmener",),
    "malmène": ("malmener",),
    "malmènera": ("malmener",),
    "malmèneraient": ("malmener",),
    "malmènerai": ("malmener",),
    "malmènerais": ("malmener",),
    "malmènerait": ("malmener",),
    "malmèneras": ("malmener",),
    "malmenèrent": ("malmener",),
    "malmènerez": ("malmener",),
    "malmèneriez": ("malmener",),
    "malmènerions": ("malmener",),
    "malmènerons": ("malmener",),
    "malmèneront": ("malmener",),
    "malmenés": ("malmener",),
    "malmènes": ("malmener",),
    "malmenez": ("malmener",),
    "malmeniez": ("malmener",),
    "malmenions": ("malmener",),
    "malmenons": ("malmener",),
    "manageaient": ("manager",),
    "manageai": ("manager",),
    "manageais": ("manager",),
    "manageait": ("manager",),
    "managea": ("manager",),
    "manageâmes": ("manager",),
    "manageant": ("manager",),
    "manageas": ("manager",),
    "manageassent": ("manager",),
    "manageasses": ("manager",),
    "manageasse": ("manager",),
    "manageassiez": ("manager",),
    "manageassions": ("manager",),
    "manageâtes": ("manager",),
    "manageât": ("manager",),
    "managée": ("manager",),
    "managées": ("manager",),
    "managé": ("manager",),
    "managent": ("manager",),
    "manageons": ("manager",),
    "manage": ("manager",),
    "managera": ("manager",),
    "manageraient": ("manager",),
    "managerai": ("manager",),
    "managerais": ("manager",),
    "managerait": ("manager",),
    "manageras": ("manager",),
    "managèrent": ("manager",),
    "managerez": ("manager",),
    "manageriez": ("manager",),
    "managerions": ("manager",),
    "managerons": ("manager",),
    "manageront": ("manager",),
    "managés": ("manager",),
    "manages": ("manager",),
    "managez": ("manager",),
    "managiez": ("manager",),
    "managions": ("manager",),
    "manégeaient": ("manéger",),
    "manégeai": ("manéger",),
    "manégeais": ("manéger",),
    "manégeait": ("manéger",),
    "manégea": ("manéger",),
    "manégeâmes": ("manéger",),
    "manégeant": ("manéger",),
    "manégeas": ("manéger",),
    "manégeassent": ("manéger",),
    "manégeasses": ("manéger",),
    "manégeasse": ("manéger",),
    "manégeassiez": ("manéger",),
    "manégeassions": ("manéger",),
    "manégeâtes": ("manéger",),
    "manégeât": ("manéger",),
    "manégée": ("manéger",),
    "manégées": ("manéger",),
    "manégé": ("manéger",),
    "manègent": ("manéger",),
    "manégeons": ("manéger",),
    "manège": ("manéger",),
    "manégera": ("manéger",),
    "manégeraient": ("manéger",),
    "manégerai": ("manéger",),
    "manégerais": ("manéger",),
    "manégerait": ("manéger",),
    "manégeras": ("manéger",),
    "manégèrent": ("manéger",),
    "manégerez": ("manéger",),
    "manégeriez": ("manéger",),
    "manégerions": ("manéger",),
    "manégerons": ("manéger",),
    "manégeront": ("manéger",),
    "manégés": ("manéger",),
    "manèges": ("manéger",),
    "manégez": ("manéger",),
    "manégiez": ("manéger",),
    "manégions": ("manéger",),
    "mangeaient": ("manger",),
    "mangeai": ("manger",),
    "mangeais": ("manger",),
    "mangeait": ("manger",),
    "mangea": ("manger",),
    "mangeâmes": ("manger",),
    "mangeant": ("manger",),
    "mangeas": ("manger",),
    "mangeassent": ("manger",),
    "mangeasses": ("manger",),
    "mangeasse": ("manger",),
    "mangeassiez": ("manger",),
    "mangeassions": ("manger",),
    "mangeâtes": ("manger",),
    "mangeât": ("manger",),
    "mangée": ("manger",),
    "mangées": ("manger",),
    "mangé": ("manger",),
    "mangent": ("manger",),
    "mangeons": ("manger",),
    "mange": ("manger",),
    "mangera": ("manger",),
    "mangeraient": ("manger",),
    "mangerai": ("manger",),
    "mangerais": ("manger",),
    "mangerait": ("manger",),
    "mangeras": ("manger",),
    "mangèrent": ("manger",),
    "mangerez": ("manger",),
    "mangeriez": ("manger",),
    "mangerions": ("manger",),
    "mangerons": ("manger",),
    "mangeront": ("manger",),
    "mangés": ("manger",),
    "manges": ("manger",),
    "mangez": ("manger",),
    "mangiez": ("manger",),
    "mangions": ("manger",),
    "maniéraient": ("maniérer",),
    "maniérai": ("maniérer",),
    "maniérais": ("maniérer",),
    "maniérait": ("maniérer",),
    "maniéra": ("maniérer",),
    "maniérâmes": ("maniérer",),
    "maniérant": ("maniérer",),
    "maniéras": ("maniérer",),
    "maniérassent": ("maniérer",),
    "maniérasses": ("maniérer",),
    "maniérasse": ("maniérer",),
    "maniérassiez": ("maniérer",),
    "maniérassions": ("maniérer",),
    "maniérâtes": ("maniérer",),
    "maniérât": ("maniérer",),
    "maniérée": ("maniérer",),
    "maniérées": ("maniérer",),
    "maniéré": ("maniérer",),
    "manièrent": ("manier",),
    "manière": ("maniérer",),
    "maniérera": ("maniérer",),
    "maniéreraient": ("maniérer",),
    "maniérerai": ("maniérer",),
    "maniérerais": ("maniérer",),
    "maniérerait": ("maniérer",),
    "maniéreras": ("maniérer",),
    "maniérèrent": ("maniérer",),
    "maniérerez": ("maniérer",),
    "maniéreriez": ("maniérer",),
    "maniérerions": ("maniérer",),
    "maniérerons": ("maniérer",),
    "maniéreront": ("maniérer",),
    "maniérés": ("maniérer",),
    "manières": ("maniérer",),
    "maniérez": ("maniérer",),
    "maniériez": ("maniérer",),
    "maniérions": ("maniérer",),
    "maniérons": ("maniérer",),
    "maniaient": ("manier",),
    "maniai": ("manier",),
    "maniais": ("manier",),
    "maniait": ("manier",),
    "mania": ("manier",),
    "maniâmes": ("manier",),
    "maniant": ("manier",),
    "manias": ("manier",),
    "maniassent": ("manier",),
    "maniasses": ("manier",),
    "maniasse": ("manier",),
    "maniassiez": ("manier",),
    "maniassions": ("manier",),
    "maniâtes": ("manier",),
    "maniât": ("manier",),
    "maniée": ("manier",),
    "maniées": ("manier",),
    "manié": ("manier",),
    "manient": ("manier",),
    "manie": ("manier",),
    "maniera": ("manier",),
    "manieraient": ("manier",),
    "manierai": ("manier",),
    "manierais": ("manier",),
    "manierait": ("manier",),
    "manieras": ("manier",),
    "manierez": ("manier",),
    "manieriez": ("manier",),
    "manierions": ("manier",),
    "manierons": ("manier",),
    "manieront": ("manier",),
    "maniés": ("manier",),
    "manies": ("manier",),
    "maniez": ("manier",),
    "maniiez": ("manier",),
    "maniions": ("manier",),
    "manions": ("manier",),
    "manigançaient": ("manigancer",),
    "manigançai": ("manigancer",),
    "manigançais": ("manigancer",),
    "manigançait": ("manigancer",),
    "manigança": ("manigancer",),
    "manigançâmes": ("manigancer",),
    "manigançant": ("manigancer",),
    "maniganças": ("manigancer",),
    "manigançassent": ("manigancer",),
    "manigançasses": ("manigancer",),
    "manigançasse": ("manigancer",),
    "manigançassiez": ("manigancer",),
    "manigançassions": ("manigancer",),
    "manigançâtes": ("manigancer",),
    "manigançât": ("manigancer",),
    "manigancée": ("manigancer",),
    "manigancées": ("manigancer",),
    "manigancé": ("manigancer",),
    "manigancent": ("manigancer",),
    "manigance": ("manigancer",),
    "manigancera": ("manigancer",),
    "maniganceraient": ("manigancer",),
    "manigancerai": ("manigancer",),
    "manigancerais": ("manigancer",),
    "manigancerait": ("manigancer",),
    "maniganceras": ("manigancer",),
    "manigancèrent": ("manigancer",),
    "manigancerez": ("manigancer",),
    "maniganceriez": ("manigancer",),
    "manigancerions": ("manigancer",),
    "manigancerons": ("manigancer",),
    "maniganceront": ("manigancer",),
    "manigancés": ("manigancer",),
    "manigances": ("manigancer",),
    "manigancez": ("manigancer",),
    "maniganciez": ("manigancer",),
    "manigancions": ("manigancer",),
    "manigançons": ("manigancer",),
    "mantelaient": ("manteler",),
    "mantelai": ("manteler",),
    "mantelais": ("manteler",),
    "mantelait": ("manteler",),
    "mantela": ("manteler",),
    "mantelâmes": ("manteler",),
    "mantelant": ("manteler",),
    "mantelas": ("manteler",),
    "mantelassent": ("manteler",),
    "mantelasses": ("manteler",),
    "mantelasse": ("manteler",),
    "mantelassiez": ("manteler",),
    "mantelassions": ("manteler",),
    "mantelâtes": ("manteler",),
    "mantelât": ("manteler",),
    "mantelée": ("manteler",),
    "mantelées": ("manteler",),
    "mantelé": ("manteler",),
    "mantèlent": ("manteler",),
    "mantèle": ("manteler",),
    "mantèlera": ("manteler",),
    "mantèleraient": ("manteler",),
    "mantèlerai": ("manteler",),
    "mantèlerais": ("manteler",),
    "mantèlerait": ("manteler",),
    "mantèleras": ("manteler",),
    "mantelèrent": ("manteler",),
    "mantèlerez": ("manteler",),
    "mantèleriez": ("manteler",),
    "mantèlerions": ("manteler",),
    "mantèlerons": ("manteler",),
    "mantèleront": ("manteler",),
    "mantelés": ("manteler",),
    "mantèles": ("manteler",),
    "mantelez": ("manteler",),
    "manteliez": ("manteler",),
    "mantelions": ("manteler",),
    "mantelons": ("manteler",),
    "margeaient": ("marger",),
    "margeai": ("marger",),
    "margeais": ("marger",),
    "margeait": ("marger",),
    "margea": ("marger",),
    "margeâmes": ("marger",),
    "margeant": ("marger",),
    "margeas": ("marger",),
    "margeassent": ("marger",),
    "margeasses": ("marger",),
    "margeasse": ("marger",),
    "margeassiez": ("marger",),
    "margeassions": ("marger",),
    "margeâtes": ("marger",),
    "margeât": ("marger",),
    "margée": ("marger",),
    "margées": ("marger",),
    "margé": ("marger",),
    "margent": ("marger",),
    "margeons": ("marger",),
    "marge": ("marger",),
    "margera": ("marger",),
    "margeraient": ("marger",),
    "margerai": ("marger",),
    "margerais": ("marger",),
    "margerait": ("marger",),
    "margeras": ("marger",),
    "margèrent": ("marger",),
    "margerez": ("marger",),
    "margeriez": ("marger",),
    "margerions": ("marger",),
    "margerons": ("marger",),
    "margeront": ("marger",),
    "margés": ("marger",),
    "marges": ("marger",),
    "margez": ("marger",),
    "margiez": ("marger",),
    "margions": ("marger",),
    "mariaient": ("marier",),
    "mariai": ("marier",),
    "mariais": ("marier",),
    "mariait": ("marier",),
    "maria": ("marier",),
    "mariâmes": ("marier",),
    "mariant": ("marier",),
    "marias": ("marier",),
    "mariassent": ("marier",),
    "mariasses": ("marier",),
    "mariasse": ("marier",),
    "mariassiez": ("marier",),
    "mariassions": ("marier",),
    "mariâtes": ("marier",),
    "mariât": ("marier",),
    "mariée": ("marier",),
    "mariées": ("marier",),
    "marié": ("marier",),
    "marient": ("marier",),
    "marie": ("marier",),
    "mariera": ("marier",),
    "marieraient": ("marier",),
    "marierai": ("marier",),
    "marierais": ("marier",),
    "marierait": ("marier",),
    "marieras": ("marier",),
    "marièrent": ("marier",),
    "marierez": ("marier",),
    "marieriez": ("marier",),
    "marierions": ("marier",),
    "marierons": ("marier",),
    "marieront": ("marier",),
    "mariés": ("marier",),
    "maries": ("marier",),
    "mariez": ("marier",),
    "mariiez": ("marier",),
    "mariions": ("marier",),
    "marions": ("marier",),
    "marquetaient": ("marqueter",),
    "marquetai": ("marqueter",),
    "marquetais": ("marqueter",),
    "marquetait": ("marqueter",),
    "marqueta": ("marqueter",),
    "marquetâmes": ("marqueter",),
    "marquetant": ("marqueter",),
    "marquetas": ("marqueter",),
    "marquetassent": ("marqueter",),
    "marquetasses": ("marqueter",),
    "marquetasse": ("marqueter",),
    "marquetassiez": ("marqueter",),
    "marquetassions": ("marqueter",),
    "marquetâtes": ("marqueter",),
    "marquetât": ("marqueter",),
    "marquetée": ("marqueter",),
    "marquetées": ("marqueter",),
    "marqueté": ("marqueter",),
    "marquetèrent": ("marqueter",),
    "marquetés": ("marqueter",),
    "marquetez": ("marqueter",),
    "marquetiez": ("marqueter",),
    "marquetions": ("marqueter",),
    "marquetons": ("marqueter",),
    "marquettent": ("marqueter",),
    "marquette": ("marqueter",),
    "marquettera": ("marqueter",),
    "marquetteraient": ("marqueter",),
    "marquetterai": ("marqueter",),
    "marquetterais": ("marqueter",),
    "marquetterait": ("marqueter",),
    "marquetteras": ("marqueter",),
    "marquetterez": ("marqueter",),
    "marquetteriez": ("marqueter",),
    "marquetterions": ("marqueter",),
    "marquetterons": ("marqueter",),
    "marquetteront": ("marqueter",),
    "marquettes": ("marqueter",),
    "marrie": ("marrir",),
    "marries": ("marrir",),
    "marri": ("marrir",),
    "marrîmes": ("marrir",),
    "marrira": ("marrir",),
    "marriraient": ("marrir",),
    "marrirai": ("marrir",),
    "marrirais": ("marrir",),
    "marrirait": ("marrir",),
    "marriras": ("marrir",),
    "marrirent": ("marrir",),
    "marrirez": ("marrir",),
    "marririez": ("marrir",),
    "marririons": ("marrir",),
    "marrirons": ("marrir",),
    "marriront": ("marrir",),
    "marris": ("marrir",),
    "marrissaient": ("marrir",),
    "marrissais": ("marrir",),
    "marrissait": ("marrir",),
    "marrissant": ("marrir",),
    "marrissent": ("marrir",),
    "marrisse": ("marrir",),
    "marrisses": ("marrir",),
    "marrissez": ("marrir",),
    "marrissiez": ("marrir",),
    "marrissions": ("marrir",),
    "marrissons": ("marrir",),
    "marrîtes": ("marrir",),
    "marrit": ("marrir",),
    "marrît": ("marrir",),
    "martelaient": ("marteler",),
    "martelai": ("marteler",),
    "martelais": ("marteler",),
    "martelait": ("marteler",),
    "martela": ("marteler",),
    "martelâmes": ("marteler",),
    "martelant": ("marteler",),
    "martelas": ("marteler",),
    "martelassent": ("marteler",),
    "martelasses": ("marteler",),
    "martelasse": ("marteler",),
    "martelassiez": ("marteler",),
    "martelassions": ("marteler",),
    "martelâtes": ("marteler",),
    "martelât": ("marteler",),
    "martelée": ("marteler",),
    "martelées": ("marteler",),
    "martelé": ("marteler",),
    "martèlent": ("marteler",),
    "martèle": ("marteler",),
    "martèlera": ("marteler",),
    "martèleraient": ("marteler",),
    "martèlerai": ("marteler",),
    "martèlerais": ("marteler",),
    "martèlerait": ("marteler",),
    "martèleras": ("marteler",),
    "martelèrent": ("marteler",),
    "martèlerez": ("marteler",),
    "martèleriez": ("marteler",),
    "martèlerions": ("marteler",),
    "martèlerons": ("marteler",),
    "martèleront": ("marteler",),
    "martelés": ("marteler",),
    "martèles": ("marteler",),
    "martelez": ("marteler",),
    "marteliez": ("marteler",),
    "martelions": ("marteler",),
    "martelons": ("marteler",),
    "massaient": ("masser",),
    "massai": ("masser",),
    "massais": ("masser",),
    "massait": ("masser",),
    "massa": ("masser",),
    "massâmes": ("masser",),
    "massant": ("masser",),
    "massas": ("masser",),
    "massassent": ("masser",),
    "massasses": ("masser",),
    "massasse": ("masser",),
    "massassiez": ("masser",),
    "massassions": ("masser",),
    "massâtes": ("masser",),
    "massât": ("masser",),
    "massée": ("masser",),
    "massées": ("masser",),
    "massé": ("masser",),
    "massent": ("masser",),
    "masse": ("masser",),
    "massera": ("masser",),
    "masseraient": ("masser",),
    "masserai": ("masser",),
    "masserais": ("masser",),
    "masserait": ("masser",),
    "masseras": ("masser",),
    "massèrent": ("masser",),
    "masserez": ("masser",),
    "masseriez": ("masser",),
    "masserions": ("masser",),
    "masserons": ("masser",),
    "masseront": ("masser",),
    "massés": ("masser",),
    "masses": ("masser",),
    "massez": ("masser",),
    "massiez": ("masser",),
    "massions": ("masser",),
    "massons": ("masser",),
    "massifiaient": ("massifier",),
    "massifiai": ("massifier",),
    "massifiais": ("massifier",),
    "massifiait": ("massifier",),
    "massifia": ("massifier",),
    "massifiâmes": ("massifier",),
    "massifiant": ("massifier",),
    "massifias": ("massifier",),
    "massifiassent": ("massifier",),
    "massifiasses": ("massifier",),
    "massifiasse": ("massifier",),
    "massifiassiez": ("massifier",),
    "massifiassions": ("massifier",),
    "massifiâtes": ("massifier",),
    "massifiât": ("massifier",),
    "massifiée": ("massifier",),
    "massifiées": ("massifier",),
    "massifié": ("massifier",),
    "massifient": ("massifier",),
    "massifie": ("massifier",),
    "massifiera": ("massifier",),
    "massifieraient": ("massifier",),
    "massifierai": ("massifier",),
    "massifierais": ("massifier",),
    "massifierait": ("massifier",),
    "massifieras": ("massifier",),
    "massifièrent": ("massifier",),
    "massifierez": ("massifier",),
    "massifieriez": ("massifier",),
    "massifierions": ("massifier",),
    "massifierons": ("massifier",),
    "massifieront": ("massifier",),
    "massifiés": ("massifier",),
    "massifies": ("massifier",),
    "massifiez": ("massifier",),
    "massifiiez": ("massifier",),
    "massifiions": ("massifier",),
    "massifions": ("massifier",),
    "matelassaient": ("matelasser",),
    "matelassai": ("matelasser",),
    "matelassais": ("matelasser",),
    "matelassait": ("matelasser",),
    "matelassa": ("matelasser",),
    "matelassâmes": ("matelasser",),
    "matelassant": ("matelasser",),
    "matelassas": ("matelasser",),
    "matelassassent": ("matelasser",),
    "matelassasses": ("matelasser",),
    "matelassasse": ("matelasser",),
    "matelassassiez": ("matelasser",),
    "matelassassions": ("matelasser",),
    "matelassâtes": ("matelasser",),
    "matelassât": ("matelasser",),
    "matelassée": ("matelasser",),
    "matelassées": ("matelasser",),
    "matelassé": ("matelasser",),
    "matelassent": ("matelasser",),
    "matelasse": ("matelasser",),
    "matelassera": ("matelasser",),
    "matelasseraient": ("matelasser",),
    "matelasserai": ("matelasser",),
    "matelasserais": ("matelasser",),
    "matelasserait": ("matelasser",),
    "matelasseras": ("matelasser",),
    "matelassèrent": ("matelasser",),
    "matelasserez": ("matelasser",),
    "matelasseriez": ("matelasser",),
    "matelasserions": ("matelasser",),
    "matelasserons": ("matelasser",),
    "matelasseront": ("matelasser",),
    "matelassés": ("matelasser",),
    "matelasses": ("matelasser",),
    "matelassez": ("matelasser",),
    "matelassiez": ("matelasser",),
    "matelassions": ("matelasser",),
    "matelassons": ("matelasser",),
    "matifiaient": ("matifier",),
    "matifiai": ("matifier",),
    "matifiais": ("matifier",),
    "matifiait": ("matifier",),
    "matifia": ("matifier",),
    "matifiâmes": ("matifier",),
    "matifiant": ("matifier",),
    "matifias": ("matifier",),
    "matifiassent": ("matifier",),
    "matifiasses": ("matifier",),
    "matifiasse": ("matifier",),
    "matifiassiez": ("matifier",),
    "matifiassions": ("matifier",),
    "matifiâtes": ("matifier",),
    "matifiât": ("matifier",),
    "matifiée": ("matifier",),
    "matifiées": ("matifier",),
    "matifié": ("matifier",),
    "matifient": ("matifier",),
    "matifie": ("matifier",),
    "matifiera": ("matifier",),
    "matifieraient": ("matifier",),
    "matifierai": ("matifier",),
    "matifierais": ("matifier",),
    "matifierait": ("matifier",),
    "matifieras": ("matifier",),
    "matifièrent": ("matifier",),
    "matifierez": ("matifier",),
    "matifieriez": ("matifier",),
    "matifierions": ("matifier",),
    "matifierons": ("matifier",),
    "matifieront": ("matifier",),
    "matifiés": ("matifier",),
    "matifies": ("matifier",),
    "matifiez": ("matifier",),
    "matifiiez": ("matifier",),
    "matifiions": ("matifier",),
    "matifions": ("matifier",),
    "matie": ("matir",),
    "maties": ("matir",),
    "mati": ("matir",),
    "matîmes": ("matir",),
    "matira": ("matir",),
    "matiraient": ("matir",),
    "matirai": ("matir",),
    "matirais": ("matir",),
    "matirait": ("matir",),
    "matiras": ("matir",),
    "matirent": ("matir",),
    "matirez": ("matir",),
    "matiriez": ("matir",),
    "matirions": ("matir",),
    "matirons": ("matir",),
    "matiront": ("matir",),
    "matis": ("matir",),
    "matissaient": ("matir",),
    "matissais": ("matir",),
    "matissait": ("matir",),
    "matissant": ("matir",),
    "matissent": ("matir",),
    "matisse": ("matir",),
    "matisses": ("matir",),
    "matissez": ("matir",),
    "matissiez": ("matir",),
    "matissions": ("matir",),
    "matissons": ("matir",),
    "matîtes": ("matir",),
    "matit": ("matir",),
    "matît": ("matir",),
    "matriçaient": ("matricer",),
    "matriçai": ("matricer",),
    "matriçais": ("matricer",),
    "matriçait": ("matricer",),
    "matriça": ("matricer",),
    "matriçâmes": ("matricer",),
    "matriçant": ("matricer",),
    "matriças": ("matricer",),
    "matriçassent": ("matricer",),
    "matriçasses": ("matricer",),
    "matriçasse": ("matricer",),
    "matriçassiez": ("matricer",),
    "matriçassions": ("matricer",),
    "matriçâtes": ("matricer",),
    "matriçât": ("matricer",),
    "matricée": ("matricer",),
    "matricées": ("matricer",),
    "matricé": ("matricer",),
    "matricent": ("matricer",),
    "matrice": ("matricer",),
    "matricera": ("matricer",),
    "matriceraient": ("matricer",),
    "matricerai": ("matricer",),
    "matricerais": ("matricer",),
    "matricerait": ("matricer",),
    "matriceras": ("matricer",),
    "matricèrent": ("matricer",),
    "matricerez": ("matricer",),
    "matriceriez": ("matricer",),
    "matricerions": ("matricer",),
    "matricerons": ("matricer",),
    "matriceront": ("matricer",),
    "matricés": ("matricer",),
    "matrices": ("matricer",),
    "matricez": ("matricer",),
    "matriciez": ("matricer",),
    "matricions": ("matricer",),
    "matriçons": ("matricer",),
    "maudîmes": ("maudire",),
    "maudira": ("maudire",),
    "maudiraient": ("maudire",),
    "maudirai": ("maudire",),
    "maudirais": ("maudire",),
    "maudirait": ("maudire",),
    "maudiras": ("maudire",),
    "maudirent": ("maudire",),
    "maudirez": ("maudire",),
    "maudiriez": ("maudire",),
    "maudirions": ("maudire",),
    "maudirons": ("maudire",),
    "maudiront": ("maudire",),
    "maudis": ("maudire",),
    "maudissaient": ("maudire",),
    "maudissais": ("maudire",),
    "maudissait": ("maudire",),
    "maudissant": ("maudire",),
    "maudissent": ("maudire",),
    "maudisse": ("maudire",),
    "maudisses": ("maudire",),
    "maudissez": ("maudire",),
    "maudissiez": ("maudire",),
    "maudissions": ("maudire",),
    "maudissons": ("maudire",),
    "maudite": ("maudire",),
    "maudîtes": ("maudire",),
    "maudites": ("maudire",),
    "maudit": ("maudire",),
    "maudits": ("maudire",),
    "maudît": ("maudire",),
    "maugréaient": ("maugréer",),
    "maugréai": ("maugréer",),
    "maugréais": ("maugréer",),
    "maugréait": ("maugréer",),
    "maugréa": ("maugréer",),
    "maugréâmes": ("maugréer",),
    "maugréant": ("maugréer",),
    "maugréas": ("maugréer",),
    "maugréassent": ("maugréer",),
    "maugréasses": ("maugréer",),
    "maugréasse": ("maugréer",),
    "maugréassiez": ("maugréer",),
    "maugréassions": ("maugréer",),
    "maugréâtes": ("maugréer",),
    "maugréât": ("maugréer",),
    "maugréée": ("maugréer",),
    "maugréées": ("maugréer",),
    "maugréé": ("maugréer",),
    "maugréent": ("maugréer",),
    "maugrée": ("maugréer",),
    "maugréera": ("maugréer",),
    "maugréeraient": ("maugréer",),
    "maugréerai": ("maugréer",),
    "maugréerais": ("maugréer",),
    "maugréerait": ("maugréer",),
    "maugréeras": ("maugréer",),
    "maugréèrent": ("maugréer",),
    "maugréerez": ("maugréer",),
    "maugréeriez": ("maugréer",),
    "maugréerions": ("maugréer",),
    "maugréerons": ("maugréer",),
    "maugréeront": ("maugréer",),
    "maugréés": ("maugréer",),
    "maugrées": ("maugréer",),
    "maugréez": ("maugréer",),
    "maugréiez": ("maugréer",),
    "maugréions": ("maugréer",),
    "maugréons": ("maugréer",),
    "méchaient": ("mécher",),
    "méchai": ("mécher",),
    "méchais": ("mécher",),
    "méchait": ("mécher",),
    "mécha": ("mécher",),
    "méchâmes": ("mécher",),
    "méchant": ("mécher",),
    "méchas": ("mécher",),
    "méchassent": ("mécher",),
    "méchasses": ("mécher",),
    "méchasse": ("mécher",),
    "méchassiez": ("mécher",),
    "méchassions": ("mécher",),
    "méchâtes": ("mécher",),
    "méchât": ("mécher",),
    "méchée": ("mécher",),
    "méchées": ("mécher",),
    "méché": ("mécher",),
    "mèchent": ("mécher",),
    "mèche": ("mécher",),
    "méchera": ("mécher",),
    "mécheraient": ("mécher",),
    "mécherai": ("mécher",),
    "mécherais": ("mécher",),
    "mécherait": ("mécher",),
    "mécheras": ("mécher",),
    "méchèrent": ("mécher",),
    "mécherez": ("mécher",),
    "mécheriez": ("mécher",),
    "mécherions": ("mécher",),
    "mécherons": ("mécher",),
    "mécheront": ("mécher",),
    "méchés": ("mécher",),
    "mèches": ("mécher",),
    "méchez": ("mécher",),
    "méchiez": ("mécher",),
    "méchions": ("mécher",),
    "méchons": ("mécher",),
    "mécomprenaient": ("mécomprendre",),
    "mécomprenais": ("mécomprendre",),
    "mécomprenait": ("mécomprendre",),
    "mécomprenant": ("mécomprendre",),
    "mécomprend": ("mécomprendre",),
    "mécomprendra": ("mécomprendre",),
    "mécomprendraient": ("mécomprendre",),
    "mécomprendrai": ("mécomprendre",),
    "mécomprendrais": ("mécomprendre",),
    "mécomprendrait": ("mécomprendre",),
    "mécomprendras": ("mécomprendre",),
    "mécomprendrez": ("mécomprendre",),
    "mécomprendriez": ("mécomprendre",),
    "mécomprendrions": ("mécomprendre",),
    "mécomprendrons": ("mécomprendre",),
    "mécomprendront": ("mécomprendre",),
    "mécomprends": ("mécomprendre",),
    "mécomprenez": ("mécomprendre",),
    "mécompreniez": ("mécomprendre",),
    "mécomprenions": ("mécomprendre",),
    "mécomprennent": ("mécomprendre",),
    "mécomprenne": ("mécomprendre",),
    "mécomprennes": ("mécomprendre",),
    "mécomprenons": ("mécomprendre",),
    "mécomprîmes": ("mécomprendre",),
    "mécomprirent": ("mécomprendre",),
    "mécomprise": ("mécomprendre",),
    "mécomprises": ("mécomprendre",),
    "mécompris": ("mécomprendre",),
    "mécomprissent": ("mécomprendre",),
    "mécomprisses": ("mécomprendre",),
    "mécomprisse": ("mécomprendre",),
    "mécomprissiez": ("mécomprendre",),
    "mécomprissions": ("mécomprendre",),
    "mécomprîtes": ("mécomprendre",),
    "mécomprit": ("mécomprendre",),
    "mécomprît": ("mécomprendre",),
    "méconduira": ("méconduire",),
    "méconduiraient": ("méconduire",),
    "méconduirai": ("méconduire",),
    "méconduirais": ("méconduire",),
    "méconduirait": ("méconduire",),
    "méconduiras": ("méconduire",),
    "méconduirez": ("méconduire",),
    "méconduiriez": ("méconduire",),
    "méconduirions": ("méconduire",),
    "méconduirons": ("méconduire",),
    "méconduiront": ("méconduire",),
    "méconduisaient": ("méconduire",),
    "méconduisais": ("méconduire",),
    "méconduisait": ("méconduire",),
    "méconduisant": ("méconduire",),
    "méconduisent": ("méconduire",),
    "méconduise": ("méconduire",),
    "méconduises": ("méconduire",),
    "méconduisez": ("méconduire",),
    "méconduisiez": ("méconduire",),
    "méconduisîmes": ("méconduire",),
    "méconduisions": ("méconduire",),
    "méconduisirent": ("méconduire",),
    "méconduisis": ("méconduire",),
    "méconduisissent": ("méconduire",),
    "méconduisisses": ("méconduire",),
    "méconduisisse": ("méconduire",),
    "méconduisissiez": ("méconduire",),
    "méconduisissions": ("méconduire",),
    "méconduisîtes": ("méconduire",),
    "méconduisit": ("méconduire",),
    "méconduisît": ("méconduire",),
    "méconduisons": ("méconduire",),
    "méconduis": ("méconduire",),
    "méconduite": ("méconduire",),
    "méconduites": ("méconduire",),
    "méconduit": ("méconduire",),
    "méconduits": ("méconduire",),
    "méconnais": ("méconnaître",),
    "méconnaissaient": ("méconnaître",),
    "méconnaissais": ("méconnaître",),
    "méconnaissait": ("méconnaître",),
    "méconnaissant": ("méconnaître",),
    "méconnaissent": ("méconnaître",),
    "méconnaisse": ("méconnaître",),
    "méconnaisses": ("méconnaître",),
    "méconnaissez": ("méconnaître",),
    "méconnaissiez": ("méconnaître",),
    "méconnaissions": ("méconnaître",),
    "méconnaissons": ("méconnaître",),
    "méconnaît": ("méconnaître",),
    "méconnaîtra": ("méconnaître",),
    "méconnaîtraient": ("méconnaître",),
    "méconnaîtrai": ("méconnaître",),
    "méconnaîtrais": ("méconnaître",),
    "méconnaîtrait": ("méconnaître",),
    "méconnaîtras": ("méconnaître",),
    "méconnaîtrez": ("méconnaître",),
    "méconnaîtriez": ("méconnaître",),
    "méconnaîtrions": ("méconnaître",),
    "méconnaîtrons": ("méconnaître",),
    "méconnaîtront": ("méconnaître",),
    "méconnue": ("méconnaître",),
    "méconnues": ("méconnaître",),
    "méconnu": ("méconnaître",),
    "méconnûmes": ("méconnaître",),
    "méconnurent": ("méconnaître",),
    "méconnus": ("méconnaître",),
    "méconnussent": ("méconnaître",),
    "méconnusses": ("méconnaître",),
    "méconnusse": ("méconnaître",),
    "méconnussiez": ("méconnaître",),
    "méconnussions": ("méconnaître",),
    "méconnûtes": ("méconnaître",),
    "méconnut": ("méconnaître",),
    "méconnût": ("méconnaître",),
    "médîmes": ("médire",),
    "médira": ("médire",),
    "médiraient": ("médire",),
    "médirai": ("médire",),
    "médirais": ("médire",),
    "médirait": ("médire",),
    "médiras": ("médire",),
    "médirent": ("médire",),
    "médirez": ("médire",),
    "médiriez": ("médire",),
    "médirions": ("médire",),
    "médirons": ("médire",),
    "médiront": ("médire",),
    "médisaient": ("médire",),
    "médisais": ("médire",),
    "médisait": ("médire",),
    "médisant": ("médire",),
    "médisent": ("médire",),
    "médise": ("médire",),
    "médises": ("médire",),
    "médisez": ("médire",),
    "médisiez": ("médire",),
    "médisions": ("médire",),
    "médisons": ("médire",),
    "médis": ("médire",),
    "médissent": ("médire",),
    "médisses": ("médire",),
    "médisse": ("médire",),
    "médissiez": ("médire",),
    "médissions": ("médire",),
    "médîtes": ("médire",),
    "médit": ("médire",),
    "médît": ("médire",),
    "méfiaient": ("méfier",),
    "méfiai": ("méfier",),
    "méfiais": ("méfier",),
    "méfiait": ("méfier",),
    "méfia": ("méfier",),
    "méfiâmes": ("méfier",),
    "méfiant": ("méfier",),
    "méfias": ("méfier",),
    "méfiassent": ("méfier",),
    "méfiasses": ("méfier",),
    "méfiasse": ("méfier",),
    "méfiassiez": ("méfier",),
    "méfiassions": ("méfier",),
    "méfiâtes": ("méfier",),
    "méfiât": ("méfier",),
    "méfiée": ("méfier",),
    "méfiées": ("méfier",),
    "méfié": ("méfier",),
    "méfient": ("méfier",),
    "méfie": ("méfier",),
    "méfiera": ("méfier",),
    "méfieraient": ("méfier",),
    "méfierai": ("méfier",),
    "méfierais": ("méfier",),
    "méfierait": ("méfier",),
    "méfieras": ("méfier",),
    "méfièrent": ("méfier",),
    "méfierez": ("méfier",),
    "méfieriez": ("méfier",),
    "méfierions": ("méfier",),
    "méfierons": ("méfier",),
    "méfieront": ("méfier",),
    "méfiés": ("méfier",),
    "méfies": ("méfier",),
    "méfiez": ("méfier",),
    "méfiiez": ("méfier",),
    "méfiions": ("méfier",),
    "méfions": ("méfier",),
    "mégie": ("mégir",),
    "mégies": ("mégir",),
    "mégi": ("mégir",),
    "mégîmes": ("mégir",),
    "mégira": ("mégir",),
    "mégiraient": ("mégir",),
    "mégirai": ("mégir",),
    "mégirais": ("mégir",),
    "mégirait": ("mégir",),
    "mégiras": ("mégir",),
    "mégirent": ("mégir",),
    "mégirez": ("mégir",),
    "mégiriez": ("mégir",),
    "mégirions": ("mégir",),
    "mégirons": ("mégir",),
    "mégiront": ("mégir",),
    "mégis": ("mégir",),
    "mégissaient": ("mégir",),
    "mégissais": ("mégir",),
    "mégissait": ("mégir",),
    "mégissant": ("mégir",),
    "mégissent": ("mégir",),
    "mégisse": ("mégir",),
    "mégisses": ("mégir",),
    "mégissez": ("mégir",),
    "mégissiez": ("mégir",),
    "mégissions": ("mégir",),
    "mégissons": ("mégir",),
    "mégîtes": ("mégir",),
    "mégit": ("mégir",),
    "mégît": ("mégir",),
    "méjugeaient": ("méjuger",),
    "méjugeai": ("méjuger",),
    "méjugeais": ("méjuger",),
    "méjugeait": ("méjuger",),
    "méjugea": ("méjuger",),
    "méjugeâmes": ("méjuger",),
    "méjugeant": ("méjuger",),
    "méjugeas": ("méjuger",),
    "méjugeassent": ("méjuger",),
    "méjugeasses": ("méjuger",),
    "méjugeasse": ("méjuger",),
    "méjugeassiez": ("méjuger",),
    "méjugeassions": ("méjuger",),
    "méjugeâtes": ("méjuger",),
    "méjugeât": ("méjuger",),
    "méjugée": ("méjuger",),
    "méjugées": ("méjuger",),
    "méjugé": ("méjuger",),
    "méjugent": ("méjuger",),
    "méjugeons": ("méjuger",),
    "méjuge": ("méjuger",),
    "méjugera": ("méjuger",),
    "méjugeraient": ("méjuger",),
    "méjugerai": ("méjuger",),
    "méjugerais": ("méjuger",),
    "méjugerait": ("méjuger",),
    "méjugeras": ("méjuger",),
    "méjugèrent": ("méjuger",),
    "méjugerez": ("méjuger",),
    "méjugeriez": ("méjuger",),
    "méjugerions": ("méjuger",),
    "méjugerons": ("méjuger",),
    "méjugeront": ("méjuger",),
    "méjugés": ("méjuger",),
    "méjuges": ("méjuger",),
    "méjugez": ("méjuger",),
    "méjugiez": ("méjuger",),
    "méjugions": ("méjuger",),
    "mélangeaient": ("mélanger",),
    "mélangeai": ("mélanger",),
    "mélangeais": ("mélanger",),
    "mélangeait": ("mélanger",),
    "mélangea": ("mélanger",),
    "mélangeâmes": ("mélanger",),
    "mélangeant": ("mélanger",),
    "mélangeas": ("mélanger",),
    "mélangeassent": ("mélanger",),
    "mélangeasses": ("mélanger",),
    "mélangeasse": ("mélanger",),
    "mélangeassiez": ("mélanger",),
    "mélangeassions": ("mélanger",),
    "mélangeâtes": ("mélanger",),
    "mélangeât": ("mélanger",),
    "mélangée": ("mélanger",),
    "mélangées": ("mélanger",),
    "mélangé": ("mélanger",),
    "mélangent": ("mélanger",),
    "mélangeons": ("mélanger",),
    "mélange": ("mélanger",),
    "mélangera": ("mélanger",),
    "mélangeraient": ("mélanger",),
    "mélangerai": ("mélanger",),
    "mélangerais": ("mélanger",),
    "mélangerait": ("mélanger",),
    "mélangeras": ("mélanger",),
    "mélangèrent": ("mélanger",),
    "mélangerez": ("mélanger",),
    "mélangeriez": ("mélanger",),
    "mélangerions": ("mélanger",),
    "mélangerons": ("mélanger",),
    "mélangeront": ("mélanger",),
    "mélangés": ("mélanger",),
    "mélanges": ("mélanger",),
    "mélangez": ("mélanger",),
    "mélangiez": ("mélanger",),
    "mélangions": ("mélanger",),
    "mellifiaient": ("mellifier",),
    "mellifiai": ("mellifier",),
    "mellifiais": ("mellifier",),
    "mellifiait": ("mellifier",),
    "mellifia": ("mellifier",),
    "mellifiâmes": ("mellifier",),
    "mellifiant": ("mellifier",),
    "mellifias": ("mellifier",),
    "mellifiassent": ("mellifier",),
    "mellifiasses": ("mellifier",),
    "mellifiasse": ("mellifier",),
    "mellifiassiez": ("mellifier",),
    "mellifiassions": ("mellifier",),
    "mellifiâtes": ("mellifier",),
    "mellifiât": ("mellifier",),
    "mellifiée": ("mellifier",),
    "mellifiées": ("mellifier",),
    "mellifié": ("mellifier",),
    "mellifient": ("mellifier",),
    "mellifie": ("mellifier",),
    "mellifiera": ("mellifier",),
    "mellifieraient": ("mellifier",),
    "mellifierai": ("mellifier",),
    "mellifierais": ("mellifier",),
    "mellifierait": ("mellifier",),
    "mellifieras": ("mellifier",),
    "mellifièrent": ("mellifier",),
    "mellifierez": ("mellifier",),
    "mellifieriez": ("mellifier",),
    "mellifierions": ("mellifier",),
    "mellifierons": ("mellifier",),
    "mellifieront": ("mellifier",),
    "mellifiés": ("mellifier",),
    "mellifies": ("mellifier",),
    "mellifiez": ("mellifier",),
    "mellifiiez": ("mellifier",),
    "mellifiions": ("mellifier",),
    "mellifions": ("mellifier",),
    "menaçaient": ("menacer",),
    "menaçai": ("menacer",),
    "menaçais": ("menacer",),
    "menaçait": ("menacer",),
    "menaça": ("menacer",),
    "menaçâmes": ("menacer",),
    "menaçant": ("menacer",),
    "menaças": ("menacer",),
    "menaçassent": ("menacer",),
    "menaçasses": ("menacer",),
    "menaçasse": ("menacer",),
    "menaçassiez": ("menacer",),
    "menaçassions": ("menacer",),
    "menaçâtes": ("menacer",),
    "menaçât": ("menacer",),
    "menacée": ("menacer",),
    "menacées": ("menacer",),
    "menacé": ("menacer",),
    "menacent": ("menacer",),
    "menace": ("menacer",),
    "menacera": ("menacer",),
    "menaceraient": ("menacer",),
    "menacerai": ("menacer",),
    "menacerais": ("menacer",),
    "menacerait": ("menacer",),
    "menaceras": ("menacer",),
    "menacèrent": ("menacer",),
    "menacerez": ("menacer",),
    "menaceriez": ("menacer",),
    "menacerions": ("menacer",),
    "menacerons": ("menacer",),
    "menaceront": ("menacer",),
    "menacés": ("menacer",),
    "menaces": ("menacer",),
    "menacez": ("menacer",),
    "menaciez": ("menacer",),
    "menacions": ("menacer",),
    "menaçons": ("menacer",),
    "ménageaient": ("ménager",),
    "ménageai": ("ménager",),
    "ménageais": ("ménager",),
    "ménageait": ("ménager",),
    "ménagea": ("ménager",),
    "ménageâmes": ("ménager",),
    "ménageant": ("ménager",),
    "ménageas": ("ménager",),
    "ménageassent": ("ménager",),
    "ménageasses": ("ménager",),
    "ménageasse": ("ménager",),
    "ménageassiez": ("ménager",),
    "ménageassions": ("ménager",),
    "ménageâtes": ("ménager",),
    "ménageât": ("ménager",),
    "ménagée": ("ménager",),
    "ménagées": ("ménager",),
    "ménagé": ("ménager",),
    "ménagent": ("ménager",),
    "ménageons": ("ménager",),
    "ménage": ("ménager",),
    "ménagera": ("ménager",),
    "ménageraient": ("ménager",),
    "ménagerai": ("ménager",),
    "ménagerais": ("ménager",),
    "ménagerait": ("ménager",),
    "ménageras": ("ménager",),
    "ménagèrent": ("ménager",),
    "ménagerez": ("ménager",),
    "ménageriez": ("ménager",),
    "ménagerions": ("ménager",),
    "ménagerons": ("ménager",),
    "ménageront": ("ménager",),
    "ménagés": ("ménager",),
    "ménages": ("ménager",),
    "ménagez": ("ménager",),
    "ménagiez": ("ménager",),
    "ménagions": ("ménager",),
    "mendiaient": ("mendier",),
    "mendiai": ("mendier",),
    "mendiais": ("mendier",),
    "mendiait": ("mendier",),
    "mendia": ("mendier",),
    "mendiâmes": ("mendier",),
    "mendiant": ("mendier",),
    "mendias": ("mendier",),
    "mendiassent": ("mendier",),
    "mendiasses": ("mendier",),
    "mendiasse": ("mendier",),
    "mendiassiez": ("mendier",),
    "mendiassions": ("mendier",),
    "mendiâtes": ("mendier",),
    "mendiât": ("mendier",),
    "mendiée": ("mendier",),
    "mendiées": ("mendier",),
    "mendié": ("mendier",),
    "mendient": ("mendier",),
    "mendie": ("mendier",),
    "mendiera": ("mendier",),
    "mendieraient": ("mendier",),
    "mendierai": ("mendier",),
    "mendierais": ("mendier",),
    "mendierait": ("mendier",),
    "mendieras": ("mendier",),
    "mendièrent": ("mendier",),
    "mendierez": ("mendier",),
    "mendieriez": ("mendier",),
    "mendierions": ("mendier",),
    "mendierons": ("mendier",),
    "mendieront": ("mendier",),
    "mendiés": ("mendier",),
    "mendies": ("mendier",),
    "mendiez": ("mendier",),
    "mendiiez": ("mendier",),
    "mendiions": ("mendier",),
    "mendions": ("mendier",),
    "menaient": ("mener",),
    "menai": ("mener",),
    "menais": ("mener",),
    "menait": ("mener",),
    "mena": ("mener",),
    "menâmes": ("mener",),
    "menant": ("mener",),
    "menas": ("mener",),
    "menassent": ("mener",),
    "menasses": ("mener",),
    "menasse": ("mener",),
    "menassiez": ("mener",),
    "menassions": ("mener",),
    "menâtes": ("mener",),
    "menât": ("mener",),
    "menée": ("mener",),
    "menées": ("mener",),
    "mené": ("mener",),
    "mènent": ("mener",),
    "mène": ("mener",),
    "mènera": ("mener",),
    "mèneraient": ("mener",),
    "mènerai": ("mener",),
    "mènerais": ("mener",),
    "mènerait": ("mener",),
    "mèneras": ("mener",),
    "menèrent": ("mener",),
    "mènerez": ("mener",),
    "mèneriez": ("mener",),
    "mènerions": ("mener",),
    "mènerons": ("mener",),
    "mèneront": ("mener",),
    "menés": ("mener",),
    "mènes": ("mener",),
    "menez": ("mener",),
    "meniez": ("mener",),
    "menions": ("mener",),
    "menons": ("mener",),
    "mens": ("mentir",),
    "mentaient": ("mentir",),
    "mentais": ("mentir",),
    "mentait": ("mentir",),
    "mentant": ("mentir",),
    "mentent": ("mentir",),
    "mente": ("mentir",),
    "mentes": ("mentir",),
    "mentez": ("mentir",),
    "mentiez": ("mentir",),
    "menti": ("mentir",),
    "mentîmes": ("mentir",),
    "mentions": ("mentir",),
    "mentira": ("mentir",),
    "mentiraient": ("mentir",),
    "mentirai": ("mentir",),
    "mentirais": ("mentir",),
    "mentirait": ("mentir",),
    "mentiras": ("mentir",),
    "mentirent": ("mentir",),
    "mentirez": ("mentir",),
    "mentiriez": ("mentir",),
    "mentirions": ("mentir",),
    "mentirons": ("mentir",),
    "mentiront": ("mentir",),
    "mentis": ("mentir",),
    "mentissent": ("mentir",),
    "mentisses": ("mentir",),
    "mentisse": ("mentir",),
    "mentissiez": ("mentir",),
    "mentissions": ("mentir",),
    "mentîtes": ("mentir",),
    "mentit": ("mentir",),
    "mentît": ("mentir",),
    "mentons": ("mentir",),
    "ment": ("mentir",),
    "méprenaient": ("méprendre",),
    "méprenais": ("méprendre",),
    "méprenait": ("méprendre",),
    "méprenant": ("méprendre",),
    "méprend": ("méprendre",),
    "méprendra": ("méprendre",),
    "méprendraient": ("méprendre",),
    "méprendrai": ("méprendre",),
    "méprendrais": ("méprendre",),
    "méprendrait": ("méprendre",),
    "méprendras": ("méprendre",),
    "méprendrez": ("méprendre",),
    "méprendriez": ("méprendre",),
    "méprendrions": ("méprendre",),
    "méprendrons": ("méprendre",),
    "méprendront": ("méprendre",),
    "méprends": ("méprendre",),
    "méprenez": ("méprendre",),
    "mépreniez": ("méprendre",),
    "méprenions": ("méprendre",),
    "méprennent": ("méprendre",),
    "méprenne": ("méprendre",),
    "méprennes": ("méprendre",),
    "méprenons": ("méprendre",),
    "méprîmes": ("méprendre",),
    "méprirent": ("méprendre",),
    "méprise": ("méprendre",),
    "méprises": ("méprendre",),
    "mépris": ("méprendre",),
    "méprissent": ("méprendre",),
    "méprisses": ("méprendre",),
    "méprisse": ("méprendre",),
    "méprissiez": ("méprendre",),
    "méprissions": ("méprendre",),
    "méprîtes": ("méprendre",),
    "méprit": ("méprendre",),
    "méprît": ("méprendre",),
    "merdoient": ("merdoyer",),
    "merdoie": ("merdoyer",),
    "merdoiera": ("merdoyer",),
    "merdoieraient": ("merdoyer",),
    "merdoierai": ("merdoyer",),
    "merdoierais": ("merdoyer",),
    "merdoierait": ("merdoyer",),
    "merdoieras": ("merdoyer",),
    "merdoierez": ("merdoyer",),
    "merdoieriez": ("merdoyer",),
    "merdoierions": ("merdoyer",),
    "merdoierons": ("merdoyer",),
    "merdoieront": ("merdoyer",),
    "merdoies": ("merdoyer",),
    "merdoyaient": ("merdoyer",),
    "merdoyai": ("merdoyer",),
    "merdoyais": ("merdoyer",),
    "merdoyait": ("merdoyer",),
    "merdoya": ("merdoyer",),
    "merdoyâmes": ("merdoyer",),
    "merdoyant": ("merdoyer",),
    "merdoyas": ("merdoyer",),
    "merdoyassent": ("merdoyer",),
    "merdoyasses": ("merdoyer",),
    "merdoyasse": ("merdoyer",),
    "merdoyassiez": ("merdoyer",),
    "merdoyassions": ("merdoyer",),
    "merdoyâtes": ("merdoyer",),
    "merdoyât": ("merdoyer",),
    "merdoyé": ("merdoyer",),
    "merdoyèrent": ("merdoyer",),
    "merdoyez": ("merdoyer",),
    "merdoyiez": ("merdoyer",),
    "merdoyions": ("merdoyer",),
    "merdoyons": ("merdoyer",),
    "mésadvenaient": ("mésadvenir",),
    "mésadvenais": ("mésadvenir",),
    "mésadvenait": ("mésadvenir",),
    "mésadvenant": ("mésadvenir",),
    "mésadvenez": ("mésadvenir",),
    "mésadveniez": ("mésadvenir",),
    "mésadvenions": ("mésadvenir",),
    "mésadvenons": ("mésadvenir",),
    "mésadvenue": ("mésadvenir",),
    "mésadvenues": ("mésadvenir",),
    "mésadvenu": ("mésadvenir",),
    "mésadvenus": ("mésadvenir",),
    "mésadviendra": ("mésadvenir",),
    "mésadviendraient": ("mésadvenir",),
    "mésadviendrai": ("mésadvenir",),
    "mésadviendrais": ("mésadvenir",),
    "mésadviendrait": ("mésadvenir",),
    "mésadviendras": ("mésadvenir",),
    "mésadviendrez": ("mésadvenir",),
    "mésadviendriez": ("mésadvenir",),
    "mésadviendrions": ("mésadvenir",),
    "mésadviendrons": ("mésadvenir",),
    "mésadviendront": ("mésadvenir",),
    "mésadviennent": ("mésadvenir",),
    "mésadvienne": ("mésadvenir",),
    "mésadviennes": ("mésadvenir",),
    "mésadviens": ("mésadvenir",),
    "mésadvient": ("mésadvenir",),
    "mésadvînmes": ("mésadvenir",),
    "mésadvinrent": ("mésadvenir",),
    "mésadvins": ("mésadvenir",),
    "mésadvinssent": ("mésadvenir",),
    "mésadvinsses": ("mésadvenir",),
    "mésadvinsse": ("mésadvenir",),
    "mésadvinssiez": ("mésadvenir",),
    "mésadvinssions": ("mésadvenir",),
    "mésadvîntes": ("mésadvenir",),
    "mésadvint": ("mésadvenir",),
    "mésadvînt": ("mésadvenir",),
    "mésalliaient": ("mésallier",),
    "mésalliai": ("mésallier",),
    "mésalliais": ("mésallier",),
    "mésalliait": ("mésallier",),
    "mésallia": ("mésallier",),
    "mésalliâmes": ("mésallier",),
    "mésalliant": ("mésallier",),
    "mésallias": ("mésallier",),
    "mésalliassent": ("mésallier",),
    "mésalliasses": ("mésallier",),
    "mésalliasse": ("mésallier",),
    "mésalliassiez": ("mésallier",),
    "mésalliassions": ("mésallier",),
    "mésalliâtes": ("mésallier",),
    "mésalliât": ("mésallier",),
    "mésalliée": ("mésallier",),
    "mésalliées": ("mésallier",),
    "mésallié": ("mésallier",),
    "mésallient": ("mésallier",),
    "mésallie": ("mésallier",),
    "mésalliera": ("mésallier",),
    "mésallieraient": ("mésallier",),
    "mésallierai": ("mésallier",),
    "mésallierais": ("mésallier",),
    "mésallierait": ("mésallier",),
    "mésallieras": ("mésallier",),
    "mésallièrent": ("mésallier",),
    "mésallierez": ("mésallier",),
    "mésallieriez": ("mésallier",),
    "mésallierions": ("mésallier",),
    "mésallierons": ("mésallier",),
    "mésallieront": ("mésallier",),
    "mésalliés": ("mésallier",),
    "mésallies": ("mésallier",),
    "mésalliez": ("mésallier",),
    "mésalliiez": ("mésallier",),
    "mésalliions": ("mésallier",),
    "mésallions": ("mésallier",),
    "mésavenaient": ("mésavenir",),
    "mésavenais": ("mésavenir",),
    "mésavenait": ("mésavenir",),
    "mésavenant": ("mésavenir",),
    "mésavenez": ("mésavenir",),
    "mésaveniez": ("mésavenir",),
    "mésavenions": ("mésavenir",),
    "mésavenons": ("mésavenir",),
    "mésavenue": ("mésavenir",),
    "mésavenues": ("mésavenir",),
    "mésavenu": ("mésavenir",),
    "mésavenus": ("mésavenir",),
    "mésaviendra": ("mésavenir",),
    "mésaviendraient": ("mésavenir",),
    "mésaviendrai": ("mésavenir",),
    "mésaviendrais": ("mésavenir",),
    "mésaviendrait": ("mésavenir",),
    "mésaviendras": ("mésavenir",),
    "mésaviendrez": ("mésavenir",),
    "mésaviendriez": ("mésavenir",),
    "mésaviendrions": ("mésavenir",),
    "mésaviendrons": ("mésavenir",),
    "mésaviendront": ("mésavenir",),
    "mésaviennent": ("mésavenir",),
    "mésavienne": ("mésavenir",),
    "mésaviennes": ("mésavenir",),
    "mésaviens": ("mésavenir",),
    "mésavient": ("mésavenir",),
    "mésavînmes": ("mésavenir",),
    "mésavinrent": ("mésavenir",),
    "mésavins": ("mésavenir",),
    "mésavinssent": ("mésavenir",),
    "mésavinsses": ("mésavenir",),
    "mésavinsse": ("mésavenir",),
    "mésavinssiez": ("mésavenir",),
    "mésavinssions": ("mésavenir",),
    "mésavîntes": ("mésavenir",),
    "mésavint": ("mésavenir",),
    "mésavînt": ("mésavenir",),
    "mésédifiaient": ("mésédifier",),
    "mésédifiai": ("mésédifier",),
    "mésédifiais": ("mésédifier",),
    "mésédifiait": ("mésédifier",),
    "mésédifia": ("mésédifier",),
    "mésédifiâmes": ("mésédifier",),
    "mésédifiant": ("mésédifier",),
    "mésédifias": ("mésédifier",),
    "mésédifiassent": ("mésédifier",),
    "mésédifiasses": ("mésédifier",),
    "mésédifiasse": ("mésédifier",),
    "mésédifiassiez": ("mésédifier",),
    "mésédifiassions": ("mésédifier",),
    "mésédifiâtes": ("mésédifier",),
    "mésédifiât": ("mésédifier",),
    "mésédifiée": ("mésédifier",),
    "mésédifiées": ("mésédifier",),
    "mésédifié": ("mésédifier",),
    "mésédifient": ("mésédifier",),
    "mésédifie": ("mésédifier",),
    "mésédifiera": ("mésédifier",),
    "mésédifieraient": ("mésédifier",),
    "mésédifierai": ("mésédifier",),
    "mésédifierais": ("mésédifier",),
    "mésédifierait": ("mésédifier",),
    "mésédifieras": ("mésédifier",),
    "mésédifièrent": ("mésédifier",),
    "mésédifierez": ("mésédifier",),
    "mésédifieriez": ("mésédifier",),
    "mésédifierions": ("mésédifier",),
    "mésédifierons": ("mésédifier",),
    "mésédifieront": ("mésédifier",),
    "mésédifiés": ("mésédifier",),
    "mésédifies": ("mésédifier",),
    "mésédifiez": ("mésédifier",),
    "mésédifiiez": ("mésédifier",),
    "mésédifiions": ("mésédifier",),
    "mésédifions": ("mésédifier",),
    "mésentendaient": ("mésentendre",),
    "mésentendais": ("mésentendre",),
    "mésentendait": ("mésentendre",),
    "mésentendant": ("mésentendre",),
    "mésentendent": ("mésentendre",),
    "mésentende": ("mésentendre",),
    "mésentendes": ("mésentendre",),
    "mésentendez": ("mésentendre",),
    "mésentendiez": ("mésentendre",),
    "mésentendîmes": ("mésentendre",),
    "mésentendions": ("mésentendre",),
    "mésentendirent": ("mésentendre",),
    "mésentendis": ("mésentendre",),
    "mésentendissent": ("mésentendre",),
    "mésentendisses": ("mésentendre",),
    "mésentendisse": ("mésentendre",),
    "mésentendissiez": ("mésentendre",),
    "mésentendissions": ("mésentendre",),
    "mésentendîtes": ("mésentendre",),
    "mésentendit": ("mésentendre",),
    "mésentendît": ("mésentendre",),
    "mésentendons": ("mésentendre",),
    "mésentend": ("mésentendre",),
    "mésentendra": ("mésentendre",),
    "mésentendraient": ("mésentendre",),
    "mésentendrai": ("mésentendre",),
    "mésentendrais": ("mésentendre",),
    "mésentendrait": ("mésentendre",),
    "mésentendras": ("mésentendre",),
    "mésentendrez": ("mésentendre",),
    "mésentendriez": ("mésentendre",),
    "mésentendrions": ("mésentendre",),
    "mésentendrons": ("mésentendre",),
    "mésentendront": ("mésentendre",),
    "mésentends": ("mésentendre",),
    "mésentendue": ("mésentendre",),
    "mésentendues": ("mésentendre",),
    "mésentendu": ("mésentendre",),
    "mésentendus": ("mésentendre",),
    "mésinterprétaient": ("mésinterpréter",),
    "mésinterprétai": ("mésinterpréter",),
    "mésinterprétais": ("mésinterpréter",),
    "mésinterprétait": ("mésinterpréter",),
    "mésinterpréta": ("mésinterpréter",),
    "mésinterprétâmes": ("mésinterpréter",),
    "mésinterprétant": ("mésinterpréter",),
    "mésinterprétas": ("mésinterpréter",),
    "mésinterprétassent": ("mésinterpréter",),
    "mésinterprétasses": ("mésinterpréter",),
    "mésinterprétasse": ("mésinterpréter",),
    "mésinterprétassiez": ("mésinterpréter",),
    "mésinterprétassions": ("mésinterpréter",),
    "mésinterprétâtes": ("mésinterpréter",),
    "mésinterprétât": ("mésinterpréter",),
    "mésinterprétée": ("mésinterpréter",),
    "mésinterprétées": ("mésinterpréter",),
    "mésinterprété": ("mésinterpréter",),
    "mésinterprètent": ("mésinterpréter",),
    "mésinterprète": ("mésinterpréter",),
    "mésinterprétera": ("mésinterpréter",),
    "mésinterpréteraient": ("mésinterpréter",),
    "mésinterpréterai": ("mésinterpréter",),
    "mésinterpréterais": ("mésinterpréter",),
    "mésinterpréterait": ("mésinterpréter",),
    "mésinterpréteras": ("mésinterpréter",),
    "mésinterprétèrent": ("mésinterpréter",),
    "mésinterpréterez": ("mésinterpréter",),
    "mésinterpréteriez": ("mésinterpréter",),
    "mésinterpréterions": ("mésinterpréter",),
    "mésinterpréterons": ("mésinterpréter",),
    "mésinterpréteront": ("mésinterpréter",),
    "mésinterprétés": ("mésinterpréter",),
    "mésinterprètes": ("mésinterpréter",),
    "mésinterprétez": ("mésinterpréter",),
    "mésinterprétiez": ("mésinterpréter",),
    "mésinterprétions": ("mésinterpréter",),
    "mésinterprétons": ("mésinterpréter",),
    "messéant": ("messeoir",),
    "métraient": ("métrer",),
    "métrai": ("métrer",),
    "métrais": ("métrer",),
    "métrait": ("métrer",),
    "métra": ("métrer",),
    "métrâmes": ("métrer",),
    "métrant": ("métrer",),
    "métras": ("métrer",),
    "métrassent": ("métrer",),
    "métrasses": ("métrer",),
    "métrasse": ("métrer",),
    "métrassiez": ("métrer",),
    "métrassions": ("métrer",),
    "métrâtes": ("métrer",),
    "métrât": ("métrer",),
    "métrée": ("métrer",),
    "métrées": ("métrer",),
    "métré": ("métrer",),
    "mètrent": ("métrer",),
    "mètre": ("métrer",),
    "métrera": ("métrer",),
    "métreraient": ("métrer",),
    "métrerai": ("métrer",),
    "métrerais": ("métrer",),
    "métrerait": ("métrer",),
    "métreras": ("métrer",),
    "métrèrent": ("métrer",),
    "métrerez": ("métrer",),
    "métreriez": ("métrer",),
    "métrerions": ("métrer",),
    "métrerons": ("métrer",),
    "métreront": ("métrer",),
    "métrés": ("métrer",),
    "mètres": ("métrer",),
    "métrez": ("métrer",),
    "métriez": ("métrer",),
    "métrions": ("métrer",),
    "métrons": ("métrer",),
    "met": ("mettre",),
    "mets": ("mettre",),
    "mettaient": ("mettre",),
    "mettais": ("mettre",),
    "mettait": ("mettre",),
    "mettant": ("mettre",),
    "mettent": ("mettre",),
    "mette": ("mettre",),
    "mettes": ("mettre",),
    "mettez": ("mettre",),
    "mettiez": ("mettre",),
    "mettions": ("mettre",),
    "mettons": ("mettre",),
    "mettra": ("mettre",),
    "mettraient": ("mettre",),
    "mettrai": ("mettre",),
    "mettrais": ("mettre",),
    "mettrait": ("mettre",),
    "mettras": ("mettre",),
    "mettrez": ("mettre",),
    "mettriez": ("mettre",),
    "mettrions": ("mettre",),
    "mettrons": ("mettre",),
    "mettront": ("mettre",),
    "mîmes": ("mettre",),
    "mirent": ("mettre",),
    "mise": ("mettre",),
    "mises": ("mettre",),
    "mis": ("mettre",),
    "missent": ("mettre",),
    "misses": ("mettre",),
    "misse": ("mettre",),
    "missiez": ("mettre",),
    "missions": ("mettre",),
    "mîtes": ("mettre",),
    "mit": ("mettre",),
    "mît": ("mettre",),
    "meurtrie": ("meurtrir",),
    "meurtries": ("meurtrir",),
    "meurtri": ("meurtrir",),
    "meurtrîmes": ("meurtrir",),
    "meurtrira": ("meurtrir",),
    "meurtriraient": ("meurtrir",),
    "meurtrirai": ("meurtrir",),
    "meurtrirais": ("meurtrir",),
    "meurtrirait": ("meurtrir",),
    "meurtriras": ("meurtrir",),
    "meurtrirent": ("meurtrir",),
    "meurtrirez": ("meurtrir",),
    "meurtririez": ("meurtrir",),
    "meurtririons": ("meurtrir",),
    "meurtrirons": ("meurtrir",),
    "meurtriront": ("meurtrir",),
    "meurtris": ("meurtrir",),
    "meurtrissaient": ("meurtrir",),
    "meurtrissais": ("meurtrir",),
    "meurtrissait": ("meurtrir",),
    "meurtrissant": ("meurtrir",),
    "meurtrissent": ("meurtrir",),
    "meurtrisse": ("meurtrir",),
    "meurtrisses": ("meurtrir",),
    "meurtrissez": ("meurtrir",),
    "meurtrissiez": ("meurtrir",),
    "meurtrissions": ("meurtrir",),
    "meurtrissons": ("meurtrir",),
    "meurtrîtes": ("meurtrir",),
    "meurtrit": ("meurtrir",),
    "meurtrît": ("meurtrir",),
    "mévendaient": ("mévendre",),
    "mévendais": ("mévendre",),
    "mévendait": ("mévendre",),
    "mévendant": ("mévendre",),
    "mévendent": ("mévendre",),
    "mévende": ("mévendre",),
    "mévendes": ("mévendre",),
    "mévendez": ("mévendre",),
    "mévendiez": ("mévendre",),
    "mévendîmes": ("mévendre",),
    "mévendions": ("mévendre",),
    "mévendirent": ("mévendre",),
    "mévendis": ("mévendre",),
    "mévendissent": ("mévendre",),
    "mévendisses": ("mévendre",),
    "mévendisse": ("mévendre",),
    "mévendissiez": ("mévendre",),
    "mévendissions": ("mévendre",),
    "mévendîtes": ("mévendre",),
    "mévendit": ("mévendre",),
    "mévendît": ("mévendre",),
    "mévendons": ("mévendre",),
    "mévend": ("mévendre",),
    "mévendra": ("mévendre",),
    "mévendraient": ("mévendre",),
    "mévendrai": ("mévendre",),
    "mévendrais": ("mévendre",),
    "mévendrait": ("mévendre",),
    "mévendras": ("mévendre",),
    "mévendrez": ("mévendre",),
    "mévendriez": ("mévendre",),
    "mévendrions": ("mévendre",),
    "mévendrons": ("mévendre",),
    "mévendront": ("mévendre",),
    "mévends": ("mévendre",),
    "mévendue": ("mévendre",),
    "mévendues": ("mévendre",),
    "mévendu": ("mévendre",),
    "mévendus": ("mévendre",),
    "microcopiaient": ("microcopier",),
    "microcopiai": ("microcopier",),
    "microcopiais": ("microcopier",),
    "microcopiait": ("microcopier",),
    "microcopia": ("microcopier",),
    "microcopiâmes": ("microcopier",),
    "microcopiant": ("microcopier",),
    "microcopias": ("microcopier",),
    "microcopiassent": ("microcopier",),
    "microcopiasses": ("microcopier",),
    "microcopiasse": ("microcopier",),
    "microcopiassiez": ("microcopier",),
    "microcopiassions": ("microcopier",),
    "microcopiâtes": ("microcopier",),
    "microcopiât": ("microcopier",),
    "microcopiée": ("microcopier",),
    "microcopiées": ("microcopier",),
    "microcopié": ("microcopier",),
    "microcopient": ("microcopier",),
    "microcopie": ("microcopier",),
    "microcopiera": ("microcopier",),
    "microcopieraient": ("microcopier",),
    "microcopierai": ("microcopier",),
    "microcopierais": ("microcopier",),
    "microcopierait": ("microcopier",),
    "microcopieras": ("microcopier",),
    "microcopièrent": ("microcopier",),
    "microcopierez": ("microcopier",),
    "microcopieriez": ("microcopier",),
    "microcopierions": ("microcopier",),
    "microcopierons": ("microcopier",),
    "microcopieront": ("microcopier",),
    "microcopiés": ("microcopier",),
    "microcopies": ("microcopier",),
    "microcopiez": ("microcopier",),
    "microcopiiez": ("microcopier",),
    "microcopiions": ("microcopier",),
    "microcopions": ("microcopier",),
    "microdisséquaient": ("microdisséquer",),
    "microdisséquai": ("microdisséquer",),
    "microdisséquais": ("microdisséquer",),
    "microdisséquait": ("microdisséquer",),
    "microdisséqua": ("microdisséquer",),
    "microdisséquâmes": ("microdisséquer",),
    "microdisséquant": ("microdisséquer",),
    "microdisséquas": ("microdisséquer",),
    "microdisséquassent": ("microdisséquer",),
    "microdisséquasses": ("microdisséquer",),
    "microdisséquasse": ("microdisséquer",),
    "microdisséquassiez": ("microdisséquer",),
    "microdisséquassions": ("microdisséquer",),
    "microdisséquâtes": ("microdisséquer",),
    "microdisséquât": ("microdisséquer",),
    "microdisséquée": ("microdisséquer",),
    "microdisséquées": ("microdisséquer",),
    "microdisséqué": ("microdisséquer",),
    "microdissèquent": ("microdisséquer",),
    "microdissèque": ("microdisséquer",),
    "microdisséquera": ("microdisséquer",),
    "microdisséqueraient": ("microdisséquer",),
    "microdisséquerai": ("microdisséquer",),
    "microdisséquerais": ("microdisséquer",),
    "microdisséquerait": ("microdisséquer",),
    "microdisséqueras": ("microdisséquer",),
    "microdisséquèrent": ("microdisséquer",),
    "microdisséquerez": ("microdisséquer",),
    "microdisséqueriez": ("microdisséquer",),
    "microdisséquerions": ("microdisséquer",),
    "microdisséquerons": ("microdisséquer",),
    "microdisséqueront": ("microdisséquer",),
    "microdisséqués": ("microdisséquer",),
    "microdissèques": ("microdisséquer",),
    "microdisséquez": ("microdisséquer",),
    "microdisséquiez": ("microdisséquer",),
    "microdisséquions": ("microdisséquer",),
    "microdisséquons": ("microdisséquer",),
    "microphotographiaient": ("microphotographier",),
    "microphotographiai": ("microphotographier",),
    "microphotographiais": ("microphotographier",),
    "microphotographiait": ("microphotographier",),
    "microphotographia": ("microphotographier",),
    "microphotographiâmes": ("microphotographier",),
    "microphotographiant": ("microphotographier",),
    "microphotographias": ("microphotographier",),
    "microphotographiassent": ("microphotographier",),
    "microphotographiasses": ("microphotographier",),
    "microphotographiasse": ("microphotographier",),
    "microphotographiassiez": ("microphotographier",),
    "microphotographiassions": ("microphotographier",),
    "microphotographiâtes": ("microphotographier",),
    "microphotographiât": ("microphotographier",),
    "microphotographiée": ("microphotographier",),
    "microphotographiées": ("microphotographier",),
    "microphotographié": ("microphotographier",),
    "microphotographient": ("microphotographier",),
    "microphotographie": ("microphotographier",),
    "microphotographiera": ("microphotographier",),
    "microphotographieraient": ("microphotographier",),
    "microphotographierai": ("microphotographier",),
    "microphotographierais": ("microphotographier",),
    "microphotographierait": ("microphotographier",),
    "microphotographieras": ("microphotographier",),
    "microphotographièrent": ("microphotographier",),
    "microphotographierez": ("microphotographier",),
    "microphotographieriez": ("microphotographier",),
    "microphotographierions": ("microphotographier",),
    "microphotographierons": ("microphotographier",),
    "microphotographieront": ("microphotographier",),
    "microphotographiés": ("microphotographier",),
    "microphotographies": ("microphotographier",),
    "microphotographiez": ("microphotographier",),
    "microphotographiiez": ("microphotographier",),
    "microphotographiions": ("microphotographier",),
    "microphotographions": ("microphotographier",),
    "millimétraient": ("millimétrer",),
    "millimétrai": ("millimétrer",),
    "millimétrais": ("millimétrer",),
    "millimétrait": ("millimétrer",),
    "millimétra": ("millimétrer",),
    "millimétrâmes": ("millimétrer",),
    "millimétrant": ("millimétrer",),
    "millimétras": ("millimétrer",),
    "millimétrassent": ("millimétrer",),
    "millimétrasses": ("millimétrer",),
    "millimétrasse": ("millimétrer",),
    "millimétrassiez": ("millimétrer",),
    "millimétrassions": ("millimétrer",),
    "millimétrâtes": ("millimétrer",),
    "millimétrât": ("millimétrer",),
    "millimétrée": ("millimétrer",),
    "millimétrées": ("millimétrer",),
    "millimétré": ("millimétrer",),
    "millimètrent": ("millimétrer",),
    "millimètre": ("millimétrer",),
    "millimétrera": ("millimétrer",),
    "millimétreraient": ("millimétrer",),
    "millimétrerai": ("millimétrer",),
    "millimétrerais": ("millimétrer",),
    "millimétrerait": ("millimétrer",),
    "millimétreras": ("millimétrer",),
    "millimétrèrent": ("millimétrer",),
    "millimétrerez": ("millimétrer",),
    "millimétreriez": ("millimétrer",),
    "millimétrerions": ("millimétrer",),
    "millimétrerons": ("millimétrer",),
    "millimétreront": ("millimétrer",),
    "millimétrés": ("millimétrer",),
    "millimètres": ("millimétrer",),
    "millimétrez": ("millimétrer",),
    "millimétriez": ("millimétrer",),
    "millimétrions": ("millimétrer",),
    "millimétrons": ("millimétrer",),
    "miméographiaient": ("miméographier",),
    "miméographiai": ("miméographier",),
    "miméographiais": ("miméographier",),
    "miméographiait": ("miméographier",),
    "miméographia": ("miméographier",),
    "miméographiâmes": ("miméographier",),
    "miméographiant": ("miméographier",),
    "miméographias": ("miméographier",),
    "miméographiassent": ("miméographier",),
    "miméographiasses": ("miméographier",),
    "miméographiasse": ("miméographier",),
    "miméographiassiez": ("miméographier",),
    "miméographiassions": ("miméographier",),
    "miméographiâtes": ("miméographier",),
    "miméographiât": ("miméographier",),
    "miméographiée": ("miméographier",),
    "miméographiées": ("miméographier",),
    "miméographié": ("miméographier",),
    "miméographient": ("miméographier",),
    "miméographie": ("miméographier",),
    "miméographiera": ("miméographier",),
    "miméographieraient": ("miméographier",),
    "miméographierai": ("miméographier",),
    "miméographierais": ("miméographier",),
    "miméographierait": ("miméographier",),
    "miméographieras": ("miméographier",),
    "miméographièrent": ("miméographier",),
    "miméographierez": ("miméographier",),
    "miméographieriez": ("miméographier",),
    "miméographierions": ("miméographier",),
    "miméographierons": ("miméographier",),
    "miméographieront": ("miméographier",),
    "miméographiés": ("miméographier",),
    "miméographies": ("miméographier",),
    "miméographiez": ("miméographier",),
    "miméographiiez": ("miméographier",),
    "miméographiions": ("miméographier",),
    "miméographions": ("miméographier",),
    "minçaient": ("mincer",),
    "minçai": ("mincer",),
    "minçais": ("mincer",),
    "minçait": ("mincer",),
    "minça": ("mincer",),
    "minçâmes": ("mincer",),
    "minçant": ("mincer",),
    "minças": ("mincer",),
    "minçassent": ("mincer",),
    "minçasses": ("mincer",),
    "minçasse": ("mincer",),
    "minçassiez": ("mincer",),
    "minçassions": ("mincer",),
    "minçâtes": ("mincer",),
    "minçât": ("mincer",),
    "mincée": ("mincer",),
    "mincées": ("mincer",),
    "mincé": ("mincer",),
    "mincent": ("mincer",),
    "mince": ("mincer",),
    "mincera": ("mincer",),
    "minceraient": ("mincer",),
    "mincerai": ("mincer",),
    "mincerais": ("mincer",),
    "mincerait": ("mincer",),
    "minceras": ("mincer",),
    "mincèrent": ("mincer",),
    "mincerez": ("mincer",),
    "minceriez": ("mincer",),
    "mincerions": ("mincer",),
    "mincerons": ("mincer",),
    "minceront": ("mincer",),
    "mincés": ("mincer",),
    "minces": ("mincer",),
    "mincez": ("mincer",),
    "minciez": ("mincer",),
    "mincions": ("mincer",),
    "minçons": ("mincer",),
    "mincie": ("mincir",),
    "mincies": ("mincir",),
    "minci": ("mincir",),
    "mincîmes": ("mincir",),
    "mincira": ("mincir",),
    "minciraient": ("mincir",),
    "mincirai": ("mincir",),
    "mincirais": ("mincir",),
    "mincirait": ("mincir",),
    "minciras": ("mincir",),
    "mincirent": ("mincir",),
    "mincirez": ("mincir",),
    "minciriez": ("mincir",),
    "mincirions": ("mincir",),
    "mincirons": ("mincir",),
    "minciront": ("mincir",),
    "mincis": ("mincir",),
    "mincissaient": ("mincir",),
    "mincissais": ("mincir",),
    "mincissait": ("mincir",),
    "mincissant": ("mincir",),
    "mincissent": ("mincir",),
    "mincisse": ("mincir",),
    "mincisses": ("mincir",),
    "mincissez": ("mincir",),
    "mincissiez": ("mincir",),
    "mincissions": ("mincir",),
    "mincissons": ("mincir",),
    "mincîtes": ("mincir",),
    "mincit": ("mincir",),
    "mincît": ("mincir",),
    "mitigeaient": ("mitiger",),
    "mitigeai": ("mitiger",),
    "mitigeais": ("mitiger",),
    "mitigeait": ("mitiger",),
    "mitigea": ("mitiger",),
    "mitigeâmes": ("mitiger",),
    "mitigeant": ("mitiger",),
    "mitigeas": ("mitiger",),
    "mitigeassent": ("mitiger",),
    "mitigeasses": ("mitiger",),
    "mitigeasse": ("mitiger",),
    "mitigeassiez": ("mitiger",),
    "mitigeassions": ("mitiger",),
    "mitigeâtes": ("mitiger",),
    "mitigeât": ("mitiger",),
    "mitigée": ("mitiger",),
    "mitigées": ("mitiger",),
    "mitigé": ("mitiger",),
    "mitigent": ("mitiger",),
    "mitigeons": ("mitiger",),
    "mitige": ("mitiger",),
    "mitigera": ("mitiger",),
    "mitigeraient": ("mitiger",),
    "mitigerai": ("mitiger",),
    "mitigerais": ("mitiger",),
    "mitigerait": ("mitiger",),
    "mitigeras": ("mitiger",),
    "mitigèrent": ("mitiger",),
    "mitigerez": ("mitiger",),
    "mitigeriez": ("mitiger",),
    "mitigerions": ("mitiger",),
    "mitigerons": ("mitiger",),
    "mitigeront": ("mitiger",),
    "mitigés": ("mitiger",),
    "mitiges": ("mitiger",),
    "mitigez": ("mitiger",),
    "mitigiez": ("mitiger",),
    "mitigions": ("mitiger",),
    "modelaient": ("modeler",),
    "modelai": ("modeler",),
    "modelais": ("modeler",),
    "modelait": ("modeler",),
    "modela": ("modeler",),
    "modelâmes": ("modeler",),
    "modelant": ("modeler",),
    "modelas": ("modeler",),
    "modelassent": ("modeler",),
    "modelasses": ("modeler",),
    "modelasse": ("modeler",),
    "modelassiez": ("modeler",),
    "modelassions": ("modeler",),
    "modelâtes": ("modeler",),
    "modelât": ("modeler",),
    "modelée": ("modeler",),
    "modelées": ("modeler",),
    "modelé": ("modeler",),
    "modèlent": ("modeler",),
    "modèle": ("modeler",),
    "modèlera": ("modeler",),
    "modèleraient": ("modeler",),
    "modèlerai": ("modeler",),
    "modèlerais": ("modeler",),
    "modèlerait": ("modeler",),
    "modèleras": ("modeler",),
    "modelèrent": ("modeler",),
    "modèlerez": ("modeler",),
    "modèleriez": ("modeler",),
    "modèlerions": ("modeler",),
    "modèlerons": ("modeler",),
    "modèleront": ("modeler",),
    "modelés": ("modeler",),
    "modèles": ("modeler",),
    "modelez": ("modeler",),
    "modeliez": ("modeler",),
    "modelions": ("modeler",),
    "modelons": ("modeler",),
    "modéraient": ("modérer",),
    "modérai": ("modérer",),
    "modérais": ("modérer",),
    "modérait": ("modérer",),
    "modéra": ("modérer",),
    "modérâmes": ("modérer",),
    "modérant": ("modérer",),
    "modéras": ("modérer",),
    "modérassent": ("modérer",),
    "modérasses": ("modérer",),
    "modérasse": ("modérer",),
    "modérassiez": ("modérer",),
    "modérassions": ("modérer",),
    "modérâtes": ("modérer",),
    "modérât": ("modérer",),
    "modérée": ("modérer",),
    "modérées": ("modérer",),
    "modéré": ("modérer",),
    "modèrent": ("modérer",),
    "modère": ("modérer",),
    "modérera": ("modérer",),
    "modéreraient": ("modérer",),
    "modérerai": ("modérer",),
    "modérerais": ("modérer",),
    "modérerait": ("modérer",),
    "modéreras": ("modérer",),
    "modérèrent": ("modérer",),
    "modérerez": ("modérer",),
    "modéreriez": ("modérer",),
    "modérerions": ("modérer",),
    "modérerons": ("modérer",),
    "modéreront": ("modérer",),
    "modérés": ("modérer",),
    "modères": ("modérer",),
    "modérez": ("modérer",),
    "modériez": ("modérer",),
    "modérions": ("modérer",),
    "modérons": ("modérer",),
    "modifiaient": ("modifier",),
    "modifiai": ("modifier",),
    "modifiais": ("modifier",),
    "modifiait": ("modifier",),
    "modifia": ("modifier",),
    "modifiâmes": ("modifier",),
    "modifiant": ("modifier",),
    "modifias": ("modifier",),
    "modifiassent": ("modifier",),
    "modifiasses": ("modifier",),
    "modifiasse": ("modifier",),
    "modifiassiez": ("modifier",),
    "modifiassions": ("modifier",),
    "modifiâtes": ("modifier",),
    "modifiât": ("modifier",),
    "modifiée": ("modifier",),
    "modifiées": ("modifier",),
    "modifié": ("modifier",),
    "modifient": ("modifier",),
    "modifie": ("modifier",),
    "modifiera": ("modifier",),
    "modifieraient": ("modifier",),
    "modifierai": ("modifier",),
    "modifierais": ("modifier",),
    "modifierait": ("modifier",),
    "modifieras": ("modifier",),
    "modifièrent": ("modifier",),
    "modifierez": ("modifier",),
    "modifieriez": ("modifier",),
    "modifierions": ("modifier",),
    "modifierons": ("modifier",),
    "modifieront": ("modifier",),
    "modifiés": ("modifier",),
    "modifies": ("modifier",),
    "modifiez": ("modifier",),
    "modifiiez": ("modifier",),
    "modifiions": ("modifier",),
    "modifions": ("modifier",),
    "moinifiaient": ("moinifier",),
    "moinifiai": ("moinifier",),
    "moinifiais": ("moinifier",),
    "moinifiait": ("moinifier",),
    "moinifia": ("moinifier",),
    "moinifiâmes": ("moinifier",),
    "moinifiant": ("moinifier",),
    "moinifias": ("moinifier",),
    "moinifiassent": ("moinifier",),
    "moinifiasses": ("moinifier",),
    "moinifiasse": ("moinifier",),
    "moinifiassiez": ("moinifier",),
    "moinifiassions": ("moinifier",),
    "moinifiâtes": ("moinifier",),
    "moinifiât": ("moinifier",),
    "moinifiée": ("moinifier",),
    "moinifiées": ("moinifier",),
    "moinifié": ("moinifier",),
    "moinifient": ("moinifier",),
    "moinifie": ("moinifier",),
    "moinifiera": ("moinifier",),
    "moinifieraient": ("moinifier",),
    "moinifierai": ("moinifier",),
    "moinifierais": ("moinifier",),
    "moinifierait": ("moinifier",),
    "moinifieras": ("moinifier",),
    "moinifièrent": ("moinifier",),
    "moinifierez": ("moinifier",),
    "moinifieriez": ("moinifier",),
    "moinifierions": ("moinifier",),
    "moinifierons": ("moinifier",),
    "moinifieront": ("moinifier",),
    "moinifiés": ("moinifier",),
    "moinifies": ("moinifier",),
    "moinifiez": ("moinifier",),
    "moinifiiez": ("moinifier",),
    "moinifiions": ("moinifier",),
    "moinifions": ("moinifier",),
    "moisie": ("moisir",),
    "moisies": ("moisir",),
    "moisi": ("moisir",),
    "moisîmes": ("moisir",),
    "moisira": ("moisir",),
    "moisiraient": ("moisir",),
    "moisirai": ("moisir",),
    "moisirais": ("moisir",),
    "moisirait": ("moisir",),
    "moisiras": ("moisir",),
    "moisirent": ("moisir",),
    "moisirez": ("moisir",),
    "moisiriez": ("moisir",),
    "moisirions": ("moisir",),
    "moisirons": ("moisir",),
    "moisiront": ("moisir",),
    "moisis": ("moisir",),
    "moisissaient": ("moisir",),
    "moisissais": ("moisir",),
    "moisissait": ("moisir",),
    "moisissant": ("moisir",),
    "moisissent": ("moisir",),
    "moisisse": ("moisir",),
    "moisisses": ("moisir",),
    "moisissez": ("moisir",),
    "moisissiez": ("moisir",),
    "moisissions": ("moisir",),
    "moisissons": ("moisir",),
    "moisîtes": ("moisir",),
    "moisit": ("moisir",),
    "moisît": ("moisir",),
    "moitie": ("moitir",),
    "moities": ("moitir",),
    "moiti": ("moitir",),
    "moitîmes": ("moitir",),
    "moitira": ("moitir",),
    "moitiraient": ("moitir",),
    "moitirai": ("moitir",),
    "moitirais": ("moitir",),
    "moitirait": ("moitir",),
    "moitiras": ("moitir",),
    "moitirent": ("moitir",),
    "moitirez": ("moitir",),
    "moitiriez": ("moitir",),
    "moitirions": ("moitir",),
    "moitirons": ("moitir",),
    "moitiront": ("moitir",),
    "moitis": ("moitir",),
    "moitissaient": ("moitir",),
    "moitissais": ("moitir",),
    "moitissait": ("moitir",),
    "moitissant": ("moitir",),
    "moitissent": ("moitir",),
    "moitisse": ("moitir",),
    "moitisses": ("moitir",),
    "moitissez": ("moitir",),
    "moitissiez": ("moitir",),
    "moitissions": ("moitir",),
    "moitissons": ("moitir",),
    "moitîtes": ("moitir",),
    "moitit": ("moitir",),
    "moitît": ("moitir",),
    "moletaient": ("moleter",),
    "moletai": ("moleter",),
    "moletais": ("moleter",),
    "moletait": ("moleter",),
    "moleta": ("moleter",),
    "moletâmes": ("moleter",),
    "moletant": ("moleter",),
    "moletas": ("moleter",),
    "moletassent": ("moleter",),
    "moletasses": ("moleter",),
    "moletasse": ("moleter",),
    "moletassiez": ("moleter",),
    "moletassions": ("moleter",),
    "moletâtes": ("moleter",),
    "moletât": ("moleter",),
    "moletée": ("moleter",),
    "moletées": ("moleter",),
    "moleté": ("moleter",),
    "moletèrent": ("moleter",),
    "moletés": ("moleter",),
    "moletez": ("moleter",),
    "moletiez": ("moleter",),
    "moletions": ("moleter",),
    "moletons": ("moleter",),
    "molettent": ("moleter",),
    "molette": ("moleter",),
    "molettera": ("moleter",),
    "moletteraient": ("moleter",),
    "moletterai": ("moleter",),
    "moletterais": ("moleter",),
    "moletterait": ("moleter",),
    "moletteras": ("moleter",),
    "moletterez": ("moleter",),
    "moletteriez": ("moleter",),
    "moletterions": ("moleter",),
    "moletterons": ("moleter",),
    "moletteront": ("moleter",),
    "molettes": ("moleter",),
    "mollifiaient": ("mollifier",),
    "mollifiai": ("mollifier",),
    "mollifiais": ("mollifier",),
    "mollifiait": ("mollifier",),
    "mollifia": ("mollifier",),
    "mollifiâmes": ("mollifier",),
    "mollifiant": ("mollifier",),
    "mollifias": ("mollifier",),
    "mollifiassent": ("mollifier",),
    "mollifiasses": ("mollifier",),
    "mollifiasse": ("mollifier",),
    "mollifiassiez": ("mollifier",),
    "mollifiassions": ("mollifier",),
    "mollifiâtes": ("mollifier",),
    "mollifiât": ("mollifier",),
    "mollifiée": ("mollifier",),
    "mollifiées": ("mollifier",),
    "mollifié": ("mollifier",),
    "mollifient": ("mollifier",),
    "mollifie": ("mollifier",),
    "mollifiera": ("mollifier",),
    "mollifieraient": ("mollifier",),
    "mollifierai": ("mollifier",),
    "mollifierais": ("mollifier",),
    "mollifierait": ("mollifier",),
    "mollifieras": ("mollifier",),
    "mollifièrent": ("mollifier",),
    "mollifierez": ("mollifier",),
    "mollifieriez": ("mollifier",),
    "mollifierions": ("mollifier",),
    "mollifierons": ("mollifier",),
    "mollifieront": ("mollifier",),
    "mollifiés": ("mollifier",),
    "mollifies": ("mollifier",),
    "mollifiez": ("mollifier",),
    "mollifiiez": ("mollifier",),
    "mollifiions": ("mollifier",),
    "mollifions": ("mollifier",),
    "mollie": ("mollir",),
    "mollies": ("mollir",),
    "molli": ("mollir",),
    "mollîmes": ("mollir",),
    "mollira": ("mollir",),
    "molliraient": ("mollir",),
    "mollirai": ("mollir",),
    "mollirais": ("mollir",),
    "mollirait": ("mollir",),
    "molliras": ("mollir",),
    "mollirent": ("mollir",),
    "mollirez": ("mollir",),
    "molliriez": ("mollir",),
    "mollirions": ("mollir",),
    "mollirons": ("mollir",),
    "molliront": ("mollir",),
    "mollis": ("mollir",),
    "mollissaient": ("mollir",),
    "mollissais": ("mollir",),
    "mollissait": ("mollir",),
    "mollissant": ("mollir",),
    "mollissent": ("mollir",),
    "mollisse": ("mollir",),
    "mollisses": ("mollir",),
    "mollissez": ("mollir",),
    "mollissiez": ("mollir",),
    "mollissions": ("mollir",),
    "mollissons": ("mollir",),
    "mollîtes": ("mollir",),
    "mollit": ("mollir",),
    "mollît": ("mollir",),
    "momassaient": ("momasser",),
    "momassai": ("momasser",),
    "momassais": ("momasser",),
    "momassait": ("momasser",),
    "momassa": ("momasser",),
    "momassâmes": ("momasser",),
    "momassant": ("momasser",),
    "momassas": ("momasser",),
    "momassassent": ("momasser",),
    "momassasses": ("momasser",),
    "momassasse": ("momasser",),
    "momassassiez": ("momasser",),
    "momassassions": ("momasser",),
    "momassâtes": ("momasser",),
    "momassât": ("momasser",),
    "momassée": ("momasser",),
    "momassées": ("momasser",),
    "momassé": ("momasser",),
    "momassent": ("momasser",),
    "momasse": ("momasser",),
    "momassera": ("momasser",),
    "momasseraient": ("momasser",),
    "momasserai": ("momasser",),
    "momasserais": ("momasser",),
    "momasserait": ("momasser",),
    "momasseras": ("momasser",),
    "momassèrent": ("momasser",),
    "momasserez": ("momasser",),
    "momasseriez": ("momasser",),
    "momasserions": ("momasser",),
    "momasserons": ("momasser",),
    "momasseront": ("momasser",),
    "momassés": ("momasser",),
    "momasses": ("momasser",),
    "momassez": ("momasser",),
    "momassiez": ("momasser",),
    "momassions": ("momasser",),
    "momassons": ("momasser",),
    "momifiaient": ("momifier",),
    "momifiai": ("momifier",),
    "momifiais": ("momifier",),
    "momifiait": ("momifier",),
    "momifia": ("momifier",),
    "momifiâmes": ("momifier",),
    "momifiant": ("momifier",),
    "momifias": ("momifier",),
    "momifiassent": ("momifier",),
    "momifiasses": ("momifier",),
    "momifiasse": ("momifier",),
    "momifiassiez": ("momifier",),
    "momifiassions": ("momifier",),
    "momifiâtes": ("momifier",),
    "momifiât": ("momifier",),
    "momifiée": ("momifier",),
    "momifiées": ("momifier",),
    "momifié": ("momifier",),
    "momifient": ("momifier",),
    "momifie": ("momifier",),
    "momifiera": ("momifier",),
    "momifieraient": ("momifier",),
    "momifierai": ("momifier",),
    "momifierais": ("momifier",),
    "momifierait": ("momifier",),
    "momifieras": ("momifier",),
    "momifièrent": ("momifier",),
    "momifierez": ("momifier",),
    "momifieriez": ("momifier",),
    "momifierions": ("momifier",),
    "momifierons": ("momifier",),
    "momifieront": ("momifier",),
    "momifiés": ("momifier",),
    "momifies": ("momifier",),
    "momifiez": ("momifier",),
    "momifiiez": ("momifier",),
    "momifiions": ("momifier",),
    "momifions": ("momifier",),
    "mondifiaient": ("mondifier",),
    "mondifiai": ("mondifier",),
    "mondifiais": ("mondifier",),
    "mondifiait": ("mondifier",),
    "mondifia": ("mondifier",),
    "mondifiâmes": ("mondifier",),
    "mondifiant": ("mondifier",),
    "mondifias": ("mondifier",),
    "mondifiassent": ("mondifier",),
    "mondifiasses": ("mondifier",),
    "mondifiasse": ("mondifier",),
    "mondifiassiez": ("mondifier",),
    "mondifiassions": ("mondifier",),
    "mondifiâtes": ("mondifier",),
    "mondifiât": ("mondifier",),
    "mondifiée": ("mondifier",),
    "mondifiées": ("mondifier",),
    "mondifié": ("mondifier",),
    "mondifient": ("mondifier",),
    "mondifie": ("mondifier",),
    "mondifiera": ("mondifier",),
    "mondifieraient": ("mondifier",),
    "mondifierai": ("mondifier",),
    "mondifierais": ("mondifier",),
    "mondifierait": ("mondifier",),
    "mondifieras": ("mondifier",),
    "mondifièrent": ("mondifier",),
    "mondifierez": ("mondifier",),
    "mondifieriez": ("mondifier",),
    "mondifierions": ("mondifier",),
    "mondifierons": ("mondifier",),
    "mondifieront": ("mondifier",),
    "mondifiés": ("mondifier",),
    "mondifies": ("mondifier",),
    "mondifiez": ("mondifier",),
    "mondifiiez": ("mondifier",),
    "mondifiions": ("mondifier",),
    "mondifions": ("mondifier",),
    "monnaient": ("monnayer",),
    "monnaie": ("monnayer",),
    "monnaiera": ("monnayer",),
    "monnaieraient": ("monnayer",),
    "monnaierai": ("monnayer",),
    "monnaierais": ("monnayer",),
    "monnaierait": ("monnayer",),
    "monnaieras": ("monnayer",),
    "monnaierez": ("monnayer",),
    "monnaieriez": ("monnayer",),
    "monnaierions": ("monnayer",),
    "monnaierons": ("monnayer",),
    "monnaieront": ("monnayer",),
    "monnaies": ("monnayer",),
    "monnayaient": ("monnayer",),
    "monnayai": ("monnayer",),
    "monnayais": ("monnayer",),
    "monnayait": ("monnayer",),
    "monnaya": ("monnayer",),
    "monnayâmes": ("monnayer",),
    "monnayant": ("monnayer",),
    "monnayas": ("monnayer",),
    "monnayassent": ("monnayer",),
    "monnayasses": ("monnayer",),
    "monnayasse": ("monnayer",),
    "monnayassiez": ("monnayer",),
    "monnayassions": ("monnayer",),
    "monnayâtes": ("monnayer",),
    "monnayât": ("monnayer",),
    "monnayée": ("monnayer",),
    "monnayées": ("monnayer",),
    "monnayé": ("monnayer",),
    "monnayent": ("monnayer",),
    "monnaye": ("monnayer",),
    "monnayera": ("monnayer",),
    "monnayeraient": ("monnayer",),
    "monnayerai": ("monnayer",),
    "monnayerais": ("monnayer",),
    "monnayerait": ("monnayer",),
    "monnayeras": ("monnayer",),
    "monnayèrent": ("monnayer",),
    "monnayerez": ("monnayer",),
    "monnayeriez": ("monnayer",),
    "monnayerions": ("monnayer",),
    "monnayerons": ("monnayer",),
    "monnayeront": ("monnayer",),
    "monnayés": ("monnayer",),
    "monnayes": ("monnayer",),
    "monnayez": ("monnayer",),
    "monnayiez": ("monnayer",),
    "monnayions": ("monnayer",),
    "monnayons": ("monnayer",),
    "morcelaient": ("morceler",),
    "morcelai": ("morceler",),
    "morcelais": ("morceler",),
    "morcelait": ("morceler",),
    "morcela": ("morceler",),
    "morcelâmes": ("morceler",),
    "morcelant": ("morceler",),
    "morcelas": ("morceler",),
    "morcelassent": ("morceler",),
    "morcelasses": ("morceler",),
    "morcelasse": ("morceler",),
    "morcelassiez": ("morceler",),
    "morcelassions": ("morceler",),
    "morcelâtes": ("morceler",),
    "morcelât": ("morceler",),
    "morcelée": ("morceler",),
    "morcelées": ("morceler",),
    "morcelé": ("morceler",),
    "morcelèrent": ("morceler",),
    "morcelés": ("morceler",),
    "morcelez": ("morceler",),
    "morceliez": ("morceler",),
    "morcelions": ("morceler",),
    "morcellent": ("morceler",),
    "morcelle": ("morceler",),
    "morcellera": ("morceler",),
    "morcelleraient": ("morceler",),
    "morcellerai": ("morceler",),
    "morcellerais": ("morceler",),
    "morcellerait": ("morceler",),
    "morcelleras": ("morceler",),
    "morcellerez": ("morceler",),
    "morcelleriez": ("morceler",),
    "morcellerions": ("morceler",),
    "morcellerons": ("morceler",),
    "morcelleront": ("morceler",),
    "morcelles": ("morceler",),
    "morcelons": ("morceler",),
    "mordançaient": ("mordancer",),
    "mordançai": ("mordancer",),
    "mordançais": ("mordancer",),
    "mordançait": ("mordancer",),
    "mordança": ("mordancer",),
    "mordançâmes": ("mordancer",),
    "mordançant": ("mordancer",),
    "mordanças": ("mordancer",),
    "mordançassent": ("mordancer",),
    "mordançasses": ("mordancer",),
    "mordançasse": ("mordancer",),
    "mordançassiez": ("mordancer",),
    "mordançassions": ("mordancer",),
    "mordançâtes": ("mordancer",),
    "mordançât": ("mordancer",),
    "mordancée": ("mordancer",),
    "mordancées": ("mordancer",),
    "mordancé": ("mordancer",),
    "mordancent": ("mordancer",),
    "mordance": ("mordancer",),
    "mordancera": ("mordancer",),
    "mordanceraient": ("mordancer",),
    "mordancerai": ("mordancer",),
    "mordancerais": ("mordancer",),
    "mordancerait": ("mordancer",),
    "mordanceras": ("mordancer",),
    "mordancèrent": ("mordancer",),
    "mordancerez": ("mordancer",),
    "mordanceriez": ("mordancer",),
    "mordancerions": ("mordancer",),
    "mordancerons": ("mordancer",),
    "mordanceront": ("mordancer",),
    "mordancés": ("mordancer",),
    "mordances": ("mordancer",),
    "mordancez": ("mordancer",),
    "mordanciez": ("mordancer",),
    "mordancions": ("mordancer",),
    "mordançons": ("mordancer",),
    "mordaient": ("mordre",),
    "mordais": ("mordre",),
    "mordait": ("mordre",),
    "mordant": ("mordre",),
    "mordent": ("mordre",),
    "morde": ("mordre",),
    "mordes": ("mordre",),
    "mordez": ("mordre",),
    "mordiez": ("mordre",),
    "mordîmes": ("mordre",),
    "mordions": ("mordre",),
    "mordirent": ("mordre",),
    "mordis": ("mordre",),
    "mordissent": ("mordre",),
    "mordisses": ("mordre",),
    "mordisse": ("mordre",),
    "mordissiez": ("mordre",),
    "mordissions": ("mordre",),
    "mordîtes": ("mordre",),
    "mordit": ("mordre",),
    "mordît": ("mordre",),
    "mordons": ("mordre",),
    "mord": ("mordre",),
    "mordra": ("mordre",),
    "mordraient": ("mordre",),
    "mordrai": ("mordre",),
    "mordrais": ("mordre",),
    "mordrait": ("mordre",),
    "mordras": ("mordre",),
    "mordrez": ("mordre",),
    "mordriez": ("mordre",),
    "mordrions": ("mordre",),
    "mordrons": ("mordre",),
    "mordront": ("mordre",),
    "mords": ("mordre",),
    "mordue": ("mordre",),
    "mordues": ("mordre",),
    "mordu": ("mordre",),
    "mordus": ("mordre",),
    "morfondaient": ("morfondre",),
    "morfondais": ("morfondre",),
    "morfondait": ("morfondre",),
    "morfondant": ("morfondre",),
    "morfondent": ("morfondre",),
    "morfonde": ("morfondre",),
    "morfondes": ("morfondre",),
    "morfondez": ("morfondre",),
    "morfondiez": ("morfondre",),
    "morfondîmes": ("morfondre",),
    "morfondions": ("morfondre",),
    "morfondirent": ("morfondre",),
    "morfondis": ("morfondre",),
    "morfondissent": ("morfondre",),
    "morfondisses": ("morfondre",),
    "morfondisse": ("morfondre",),
    "morfondissiez": ("morfondre",),
    "morfondissions": ("morfondre",),
    "morfondîtes": ("morfondre",),
    "morfondit": ("morfondre",),
    "morfondît": ("morfondre",),
    "morfondons": ("morfondre",),
    "morfond": ("morfondre",),
    "morfondra": ("morfondre",),
    "morfondraient": ("morfondre",),
    "morfondrai": ("morfondre",),
    "morfondrais": ("morfondre",),
    "morfondrait": ("morfondre",),
    "morfondras": ("morfondre",),
    "morfondrez": ("morfondre",),
    "morfondriez": ("morfondre",),
    "morfondrions": ("morfondre",),
    "morfondrons": ("morfondre",),
    "morfondront": ("morfondre",),
    "morfonds": ("morfondre",),
    "morfondue": ("morfondre",),
    "morfondues": ("morfondre",),
    "morfondu": ("morfondre",),
    "morfondus": ("morfondre",),
    "morigénaient": ("morigéner",),
    "morigénai": ("morigéner",),
    "morigénais": ("morigéner",),
    "morigénait": ("morigéner",),
    "morigéna": ("morigéner",),
    "morigénâmes": ("morigéner",),
    "morigénant": ("morigéner",),
    "morigénas": ("morigéner",),
    "morigénassent": ("morigéner",),
    "morigénasses": ("morigéner",),
    "morigénasse": ("morigéner",),
    "morigénassiez": ("morigéner",),
    "morigénassions": ("morigéner",),
    "morigénâtes": ("morigéner",),
    "morigénât": ("morigéner",),
    "morigénée": ("morigéner",),
    "morigénées": ("morigéner",),
    "morigéné": ("morigéner",),
    "morigènent": ("morigéner",),
    "morigène": ("morigéner",),
    "morigénera": ("morigéner",),
    "morigéneraient": ("morigéner",),
    "morigénerai": ("morigéner",),
    "morigénerais": ("morigéner",),
    "morigénerait": ("morigéner",),
    "morigéneras": ("morigéner",),
    "morigénèrent": ("morigéner",),
    "morigénerez": ("morigéner",),
    "morigéneriez": ("morigéner",),
    "morigénerions": ("morigéner",),
    "morigénerons": ("morigéner",),
    "morigéneront": ("morigéner",),
    "morigénés": ("morigéner",),
    "morigènes": ("morigéner",),
    "morigénez": ("morigéner",),
    "morigéniez": ("morigéner",),
    "morigénions": ("morigéner",),
    "morigénons": ("morigéner",),
    "mortifiaient": ("mortifier",),
    "mortifiai": ("mortifier",),
    "mortifiais": ("mortifier",),
    "mortifiait": ("mortifier",),
    "mortifia": ("mortifier",),
    "mortifiâmes": ("mortifier",),
    "mortifiant": ("mortifier",),
    "mortifias": ("mortifier",),
    "mortifiassent": ("mortifier",),
    "mortifiasses": ("mortifier",),
    "mortifiasse": ("mortifier",),
    "mortifiassiez": ("mortifier",),
    "mortifiassions": ("mortifier",),
    "mortifiâtes": ("mortifier",),
    "mortifiât": ("mortifier",),
    "mortifiée": ("mortifier",),
    "mortifiées": ("mortifier",),
    "mortifié": ("mortifier",),
    "mortifient": ("mortifier",),
    "mortifie": ("mortifier",),
    "mortifiera": ("mortifier",),
    "mortifieraient": ("mortifier",),
    "mortifierai": ("mortifier",),
    "mortifierais": ("mortifier",),
    "mortifierait": ("mortifier",),
    "mortifieras": ("mortifier",),
    "mortifièrent": ("mortifier",),
    "mortifierez": ("mortifier",),
    "mortifieriez": ("mortifier",),
    "mortifierions": ("mortifier",),
    "mortifierons": ("mortifier",),
    "mortifieront": ("mortifier",),
    "mortifiés": ("mortifier",),
    "mortifies": ("mortifier",),
    "mortifiez": ("mortifier",),
    "mortifiiez": ("mortifier",),
    "mortifiions": ("mortifier",),
    "mortifions": ("mortifier",),
    "mouchetaient": ("moucheter",),
    "mouchetai": ("moucheter",),
    "mouchetais": ("moucheter",),
    "mouchetait": ("moucheter",),
    "moucheta": ("moucheter",),
    "mouchetâmes": ("moucheter",),
    "mouchetant": ("moucheter",),
    "mouchetas": ("moucheter",),
    "mouchetassent": ("moucheter",),
    "mouchetasses": ("moucheter",),
    "mouchetasse": ("moucheter",),
    "mouchetassiez": ("moucheter",),
    "mouchetassions": ("moucheter",),
    "mouchetâtes": ("moucheter",),
    "mouchetât": ("moucheter",),
    "mouchetée": ("moucheter",),
    "mouchetées": ("moucheter",),
    "moucheté": ("moucheter",),
    "mouchetèrent": ("moucheter",),
    "mouchetés": ("moucheter",),
    "mouchetez": ("moucheter",),
    "mouchetiez": ("moucheter",),
    "mouchetions": ("moucheter",),
    "mouchetons": ("moucheter",),
    "mouchettent": ("moucheter",),
    "mouchette": ("moucheter",),
    "mouchettera": ("moucheter",),
    "mouchetteraient": ("moucheter",),
    "mouchetterai": ("moucheter",),
    "mouchetterais": ("moucheter",),
    "mouchetterait": ("moucheter",),
    "mouchetteras": ("moucheter",),
    "mouchetterez": ("moucheter",),
    "mouchetteriez": ("moucheter",),
    "mouchetterions": ("moucheter",),
    "mouchetterons": ("moucheter",),
    "mouchetteront": ("moucheter",),
    "mouchettes": ("moucheter",),
    "moud": ("moudre",),
    "moudra": ("moudre",),
    "moudraient": ("moudre",),
    "moudrai": ("moudre",),
    "moudrais": ("moudre",),
    "moudrait": ("moudre",),
    "moudras": ("moudre",),
    "moudrez": ("moudre",),
    "moudriez": ("moudre",),
    "moudrions": ("moudre",),
    "moudrons": ("moudre",),
    "moudront": ("moudre",),
    "mouds": ("moudre",),
    "moulaient": ("moudre",),
    "moulais": ("moudre",),
    "moulait": ("moudre",),
    "moulant": ("moudre",),
    "moulent": ("moudre",),
    "moule": ("moudre",),
    "moules": ("moudre",),
    "moulez": ("moudre",),
    "mouliez": ("moudre",),
    "moulions": ("moudre",),
    "moulons": ("moudre",),
    "moulue": ("moudre",),
    "moulues": ("moudre",),
    "moulu": ("moudre",),
    "moulûmes": ("moudre",),
    "moulurent": ("moudre",),
    "moulus": ("moudre",),
    "moulussent": ("moudre",),
    "moulusses": ("moudre",),
    "moulusse": ("moudre",),
    "moulussiez": ("moudre",),
    "moulussions": ("moudre",),
    "moulûtes": ("moudre",),
    "moulut": ("moudre",),
    "moulût": ("moudre",),
    "mouillassaient": ("mouillasser",),
    "mouillassait": ("mouillasser",),
    "mouillassa": ("mouillasser",),
    "mouillassant": ("mouillasser",),
    "mouillassassent": ("mouillasser",),
    "mouillassât": ("mouillasser",),
    "mouillassé": ("mouillasser",),
    "mouillassent": ("mouillasser",),
    "mouillasse": ("mouillasser",),
    "mouillassera": ("mouillasser",),
    "mouillasseraient": ("mouillasser",),
    "mouillasserait": ("mouillasser",),
    "mouillassèrent": ("mouillasser",),
    "mouillasseront": ("mouillasser",),
    "meurent": ("mourir",),
    "meure": ("mourir",),
    "meures": ("mourir",),
    "meurs": ("mourir",),
    "meurt": ("mourir",),
    "morte": ("mourir",),
    "mortes": ("mourir",),
    "mort": ("mourir",),
    "morts": ("mourir",),
    "mouraient": ("mourir",),
    "mourais": ("mourir",),
    "mourait": ("mourir",),
    "mourant": ("mourir",),
    "mourez": ("mourir",),
    "mouriez": ("mourir",),
    "mourions": ("mourir",),
    "mourons": ("mourir",),
    "mourra": ("mourir",),
    "mourraient": ("mourir",),
    "mourrai": ("mourir",),
    "mourrais": ("mourir",),
    "mourrait": ("mourir",),
    "mourras": ("mourir",),
    "mourrez": ("mourir",),
    "mourriez": ("mourir",),
    "mourrions": ("mourir",),
    "mourrons": ("mourir",),
    "mourront": ("mourir",),
    "mourûmes": ("mourir",),
    "moururent": ("mourir",),
    "mourus": ("mourir",),
    "mourussent": ("mourir",),
    "mourusses": ("mourir",),
    "mourusse": ("mourir",),
    "mourussiez": ("mourir",),
    "mourussions": ("mourir",),
    "mourûtes": ("mourir",),
    "mourut": ("mourir",),
    "mourût": ("mourir",),
    "meus": ("mouvoir",),
    "meut": ("mouvoir",),
    "meuvent": ("mouvoir",),
    "meuve": ("mouvoir",),
    "meuves": ("mouvoir",),
    "mouvaient": ("mouvoir",),
    "mouvais": ("mouvoir",),
    "mouvait": ("mouvoir",),
    "mouvant": ("mouvoir",),
    "mouvez": ("mouvoir",),
    "mouviez": ("mouvoir",),
    "mouvions": ("mouvoir",),
    "mouvons": ("mouvoir",),
    "mouvra": ("mouvoir",),
    "mouvraient": ("mouvoir",),
    "mouvrai": ("mouvoir",),
    "mouvrais": ("mouvoir",),
    "mouvrait": ("mouvoir",),
    "mouvras": ("mouvoir",),
    "mouvrez": ("mouvoir",),
    "mouvriez": ("mouvoir",),
    "mouvrions": ("mouvoir",),
    "mouvrons": ("mouvoir",),
    "mouvront": ("mouvoir",),
    "mue": ("mouvoir",),
    "mues": ("mouvoir",),
    "mû": ("mouvoir",),
    "mûmes": ("mouvoir",),
    "murent": ("mouvoir",),
    "mus": ("mouvoir",),
    "mussent": ("mouvoir",),
    "musses": ("mouvoir",),
    "musse": ("mouvoir",),
    "mussiez": ("mouvoir",),
    "mussions": ("mouvoir",),
    "mûtes": ("mouvoir",),
    "mut": ("mouvoir",),
    "mût": ("mouvoir",),
    "moient": ("moyer",),
    "moie": ("moyer",),
    "moiera": ("moyer",),
    "moieraient": ("moyer",),
    "moierai": ("moyer",),
    "moierais": ("moyer",),
    "moierait": ("moyer",),
    "moieras": ("moyer",),
    "moierez": ("moyer",),
    "moieriez": ("moyer",),
    "moierions": ("moyer",),
    "moierons": ("moyer",),
    "moieront": ("moyer",),
    "moies": ("moyer",),
    "moyaient": ("moyer",),
    "moyai": ("moyer",),
    "moyais": ("moyer",),
    "moyait": ("moyer",),
    "moya": ("moyer",),
    "moyâmes": ("moyer",),
    "moyant": ("moyer",),
    "moyas": ("moyer",),
    "moyassent": ("moyer",),
    "moyasses": ("moyer",),
    "moyasse": ("moyer",),
    "moyassiez": ("moyer",),
    "moyassions": ("moyer",),
    "moyâtes": ("moyer",),
    "moyât": ("moyer",),
    "moyée": ("moyer",),
    "moyées": ("moyer",),
    "moyé": ("moyer",),
    "moyèrent": ("moyer",),
    "moyés": ("moyer",),
    "moyez": ("moyer",),
    "moyiez": ("moyer",),
    "moyions": ("moyer",),
    "moyons": ("moyer",),
    "mugie": ("mugir",),
    "mugies": ("mugir",),
    "mugi": ("mugir",),
    "mugîmes": ("mugir",),
    "mugira": ("mugir",),
    "mugiraient": ("mugir",),
    "mugirai": ("mugir",),
    "mugirais": ("mugir",),
    "mugirait": ("mugir",),
    "mugiras": ("mugir",),
    "mugirent": ("mugir",),
    "mugirez": ("mugir",),
    "mugiriez": ("mugir",),
    "mugirions": ("mugir",),
    "mugirons": ("mugir",),
    "mugiront": ("mugir",),
    "mugis": ("mugir",),
    "mugissaient": ("mugir",),
    "mugissais": ("mugir",),
    "mugissait": ("mugir",),
    "mugissant": ("mugir",),
    "mugissent": ("mugir",),
    "mugisse": ("mugir",),
    "mugisses": ("mugir",),
    "mugissez": ("mugir",),
    "mugissiez": ("mugir",),
    "mugissions": ("mugir",),
    "mugissons": ("mugir",),
    "mugîtes": ("mugir",),
    "mugit": ("mugir",),
    "mugît": ("mugir",),
    "muguetaient": ("mugueter",),
    "muguetai": ("mugueter",),
    "muguetais": ("mugueter",),
    "muguetait": ("mugueter",),
    "mugueta": ("mugueter",),
    "muguetâmes": ("mugueter",),
    "muguetant": ("mugueter",),
    "muguetas": ("mugueter",),
    "muguetassent": ("mugueter",),
    "muguetasses": ("mugueter",),
    "muguetasse": ("mugueter",),
    "muguetassiez": ("mugueter",),
    "muguetassions": ("mugueter",),
    "muguetâtes": ("mugueter",),
    "muguetât": ("mugueter",),
    "muguetée": ("mugueter",),
    "muguetées": ("mugueter",),
    "mugueté": ("mugueter",),
    "muguetèrent": ("mugueter",),
    "muguetés": ("mugueter",),
    "muguetez": ("mugueter",),
    "muguetiez": ("mugueter",),
    "muguetions": ("mugueter",),
    "muguetons": ("mugueter",),
    "muguettent": ("mugueter",),
    "muguette": ("mugueter",),
    "muguettera": ("mugueter",),
    "muguetteraient": ("mugueter",),
    "muguetterai": ("mugueter",),
    "muguetterais": ("mugueter",),
    "muguetterait": ("mugueter",),
    "muguetteras": ("mugueter",),
    "muguetterez": ("mugueter",),
    "muguetteriez": ("mugueter",),
    "muguetterions": ("mugueter",),
    "muguetterons": ("mugueter",),
    "muguetteront": ("mugueter",),
    "muguettes": ("mugueter",),
    "multigraphiaient": ("multigraphier",),
    "multigraphiai": ("multigraphier",),
    "multigraphiais": ("multigraphier",),
    "multigraphiait": ("multigraphier",),
    "multigraphia": ("multigraphier",),
    "multigraphiâmes": ("multigraphier",),
    "multigraphiant": ("multigraphier",),
    "multigraphias": ("multigraphier",),
    "multigraphiassent": ("multigraphier",),
    "multigraphiasses": ("multigraphier",),
    "multigraphiasse": ("multigraphier",),
    "multigraphiassiez": ("multigraphier",),
    "multigraphiassions": ("multigraphier",),
    "multigraphiâtes": ("multigraphier",),
    "multigraphiât": ("multigraphier",),
    "multigraphiée": ("multigraphier",),
    "multigraphiées": ("multigraphier",),
    "multigraphié": ("multigraphier",),
    "multigraphient": ("multigraphier",),
    "multigraphie": ("multigraphier",),
    "multigraphiera": ("multigraphier",),
    "multigraphieraient": ("multigraphier",),
    "multigraphierai": ("multigraphier",),
    "multigraphierais": ("multigraphier",),
    "multigraphierait": ("multigraphier",),
    "multigraphieras": ("multigraphier",),
    "multigraphièrent": ("multigraphier",),
    "multigraphierez": ("multigraphier",),
    "multigraphieriez": ("multigraphier",),
    "multigraphierions": ("multigraphier",),
    "multigraphierons": ("multigraphier",),
    "multigraphieront": ("multigraphier",),
    "multigraphiés": ("multigraphier",),
    "multigraphies": ("multigraphier",),
    "multigraphiez": ("multigraphier",),
    "multigraphiiez": ("multigraphier",),
    "multigraphiions": ("multigraphier",),
    "multigraphions": ("multigraphier",),
    "multipliaient": ("multiplier",),
    "multipliai": ("multiplier",),
    "multipliais": ("multiplier",),
    "multipliait": ("multiplier",),
    "multiplia": ("multiplier",),
    "multipliâmes": ("multiplier",),
    "multipliant": ("multiplier",),
    "multiplias": ("multiplier",),
    "multipliassent": ("multiplier",),
    "multipliasses": ("multiplier",),
    "multipliasse": ("multiplier",),
    "multipliassiez": ("multiplier",),
    "multipliassions": ("multiplier",),
    "multipliâtes": ("multiplier",),
    "multipliât": ("multiplier",),
    "multipliée": ("multiplier",),
    "multipliées": ("multiplier",),
    "multiplié": ("multiplier",),
    "multiplient": ("multiplier",),
    "multiplie": ("multiplier",),
    "multipliera": ("multiplier",),
    "multiplieraient": ("multiplier",),
    "multiplierai": ("multiplier",),
    "multiplierais": ("multiplier",),
    "multiplierait": ("multiplier",),
    "multiplieras": ("multiplier",),
    "multiplièrent": ("multiplier",),
    "multiplierez": ("multiplier",),
    "multiplieriez": ("multiplier",),
    "multiplierions": ("multiplier",),
    "multiplierons": ("multiplier",),
    "multiplieront": ("multiplier",),
    "multipliés": ("multiplier",),
    "multiplies": ("multiplier",),
    "multipliez": ("multiplier",),
    "multipliiez": ("multiplier",),
    "multipliions": ("multiplier",),
    "multiplions": ("multiplier",),
    "munie": ("munir",),
    "munies": ("munir",),
    "muni": ("munir",),
    "munîmes": ("munir",),
    "munira": ("munir",),
    "muniraient": ("munir",),
    "munirai": ("munir",),
    "munirais": ("munir",),
    "munirait": ("munir",),
    "muniras": ("munir",),
    "munirent": ("munir",),
    "munirez": ("munir",),
    "muniriez": ("munir",),
    "munirions": ("munir",),
    "munirons": ("munir",),
    "muniront": ("munir",),
    "munis": ("munir",),
    "munissaient": ("munir",),
    "munissais": ("munir",),
    "munissait": ("munir",),
    "munissant": ("munir",),
    "munissent": ("munir",),
    "munisse": ("munir",),
    "munisses": ("munir",),
    "munissez": ("munir",),
    "munissiez": ("munir",),
    "munissions": ("munir",),
    "munissons": ("munir",),
    "munîtes": ("munir",),
    "munit": ("munir",),
    "munît": ("munir",),
    "mûrie": ("mûrir",),
    "mûries": ("mûrir",),
    "mûri": ("mûrir",),
    "mûrîmes": ("mûrir",),
    "mûrira": ("mûrir",),
    "mûriraient": ("mûrir",),
    "mûrirai": ("mûrir",),
    "mûrirais": ("mûrir",),
    "mûrirait": ("mûrir",),
    "mûriras": ("mûrir",),
    "mûrirent": ("mûrir",),
    "mûrirez": ("mûrir",),
    "mûririez": ("mûrir",),
    "mûririons": ("mûrir",),
    "mûrirons": ("mûrir",),
    "mûriront": ("mûrir",),
    "mûris": ("mûrir",),
    "mûrissaient": ("mûrir",),
    "mûrissais": ("mûrir",),
    "mûrissait": ("mûrir",),
    "mûrissant": ("mûrir",),
    "mûrissent": ("mûrir",),
    "mûrisse": ("mûrir",),
    "mûrisses": ("mûrir",),
    "mûrissez": ("mûrir",),
    "mûrissiez": ("mûrir",),
    "mûrissions": ("mûrir",),
    "mûrissons": ("mûrir",),
    "mûrîtes": ("mûrir",),
    "mûrit": ("mûrir",),
    "mûrît": ("mûrir",),
    "muséifiaient": ("muséifier",),
    "muséifiai": ("muséifier",),
    "muséifiais": ("muséifier",),
    "muséifiait": ("muséifier",),
    "muséifia": ("muséifier",),
    "muséifiâmes": ("muséifier",),
    "muséifiant": ("muséifier",),
    "muséifias": ("muséifier",),
    "muséifiassent": ("muséifier",),
    "muséifiasses": ("muséifier",),
    "muséifiasse": ("muséifier",),
    "muséifiassiez": ("muséifier",),
    "muséifiassions": ("muséifier",),
    "muséifiâtes": ("muséifier",),
    "muséifiât": ("muséifier",),
    "muséifiée": ("muséifier",),
    "muséifiées": ("muséifier",),
    "muséifié": ("muséifier",),
    "muséifient": ("muséifier",),
    "muséifie": ("muséifier",),
    "muséifiera": ("muséifier",),
    "muséifieraient": ("muséifier",),
    "muséifierai": ("muséifier",),
    "muséifierais": ("muséifier",),
    "muséifierait": ("muséifier",),
    "muséifieras": ("muséifier",),
    "muséifièrent": ("muséifier",),
    "muséifierez": ("muséifier",),
    "muséifieriez": ("muséifier",),
    "muséifierions": ("muséifier",),
    "muséifierons": ("muséifier",),
    "muséifieront": ("muséifier",),
    "muséifiés": ("muséifier",),
    "muséifies": ("muséifier",),
    "muséifiez": ("muséifier",),
    "muséifiiez": ("muséifier",),
    "muséifiions": ("muséifier",),
    "muséifions": ("muséifier",),
    "muselaient": ("museler",),
    "muselai": ("museler",),
    "muselais": ("museler",),
    "muselait": ("museler",),
    "musela": ("museler",),
    "muselâmes": ("museler",),
    "muselant": ("museler",),
    "muselas": ("museler",),
    "muselassent": ("museler",),
    "muselasses": ("museler",),
    "muselasse": ("museler",),
    "muselassiez": ("museler",),
    "muselassions": ("museler",),
    "muselâtes": ("museler",),
    "muselât": ("museler",),
    "muselée": ("museler",),
    "muselées": ("museler",),
    "muselé": ("museler",),
    "muselèrent": ("museler",),
    "muselés": ("museler",),
    "muselez": ("museler",),
    "museliez": ("museler",),
    "muselions": ("museler",),
    "musellent": ("museler",),
    "muselle": ("museler",),
    "musellera": ("museler",),
    "muselleraient": ("museler",),
    "musellerai": ("museler",),
    "musellerais": ("museler",),
    "musellerait": ("museler",),
    "muselleras": ("museler",),
    "musellerez": ("museler",),
    "muselleriez": ("museler",),
    "musellerions": ("museler",),
    "musellerons": ("museler",),
    "muselleront": ("museler",),
    "muselles": ("museler",),
    "muselons": ("museler",),
    "museletaient": ("museleter",),
    "museletai": ("museleter",),
    "museletais": ("museleter",),
    "museletait": ("museleter",),
    "museleta": ("museleter",),
    "museletâmes": ("museleter",),
    "museletant": ("museleter",),
    "museletas": ("museleter",),
    "museletassent": ("museleter",),
    "museletasses": ("museleter",),
    "museletasse": ("museleter",),
    "museletassiez": ("museleter",),
    "museletassions": ("museleter",),
    "museletâtes": ("museleter",),
    "museletât": ("museleter",),
    "museletée": ("museleter",),
    "museletées": ("museleter",),
    "museleté": ("museleter",),
    "museletèrent": ("museleter",),
    "museletés": ("museleter",),
    "museletez": ("museleter",),
    "museletiez": ("museleter",),
    "museletions": ("museleter",),
    "museletons": ("museleter",),
    "muselettent": ("museleter",),
    "muselette": ("museleter",),
    "muselettera": ("museleter",),
    "museletteraient": ("museleter",),
    "museletterai": ("museleter",),
    "museletterais": ("museleter",),
    "museletterait": ("museleter",),
    "museletteras": ("museleter",),
    "museletterez": ("museleter",),
    "museletteriez": ("museleter",),
    "museletterions": ("museleter",),
    "museletterons": ("museleter",),
    "museletteront": ("museleter",),
    "muselettes": ("museleter",),
    "mystifiaient": ("mystifier",),
    "mystifiai": ("mystifier",),
    "mystifiais": ("mystifier",),
    "mystifiait": ("mystifier",),
    "mystifia": ("mystifier",),
    "mystifiâmes": ("mystifier",),
    "mystifiant": ("mystifier",),
    "mystifias": ("mystifier",),
    "mystifiassent": ("mystifier",),
    "mystifiasses": ("mystifier",),
    "mystifiasse": ("mystifier",),
    "mystifiassiez": ("mystifier",),
    "mystifiassions": ("mystifier",),
    "mystifiâtes": ("mystifier",),
    "mystifiât": ("mystifier",),
    "mystifiée": ("mystifier",),
    "mystifiées": ("mystifier",),
    "mystifié": ("mystifier",),
    "mystifient": ("mystifier",),
    "mystifie": ("mystifier",),
    "mystifiera": ("mystifier",),
    "mystifieraient": ("mystifier",),
    "mystifierai": ("mystifier",),
    "mystifierais": ("mystifier",),
    "mystifierait": ("mystifier",),
    "mystifieras": ("mystifier",),
    "mystifièrent": ("mystifier",),
    "mystifierez": ("mystifier",),
    "mystifieriez": ("mystifier",),
    "mystifierions": ("mystifier",),
    "mystifierons": ("mystifier",),
    "mystifieront": ("mystifier",),
    "mystifiés": ("mystifier",),
    "mystifies": ("mystifier",),
    "mystifiez": ("mystifier",),
    "mystifiiez": ("mystifier",),
    "mystifiions": ("mystifier",),
    "mystifions": ("mystifier",),
    "mythifiaient": ("mythifier",),
    "mythifiai": ("mythifier",),
    "mythifiais": ("mythifier",),
    "mythifiait": ("mythifier",),
    "mythifia": ("mythifier",),
    "mythifiâmes": ("mythifier",),
    "mythifiant": ("mythifier",),
    "mythifias": ("mythifier",),
    "mythifiassent": ("mythifier",),
    "mythifiasses": ("mythifier",),
    "mythifiasse": ("mythifier",),
    "mythifiassiez": ("mythifier",),
    "mythifiassions": ("mythifier",),
    "mythifiâtes": ("mythifier",),
    "mythifiât": ("mythifier",),
    "mythifiée": ("mythifier",),
    "mythifiées": ("mythifier",),
    "mythifié": ("mythifier",),
    "mythifient": ("mythifier",),
    "mythifie": ("mythifier",),
    "mythifiera": ("mythifier",),
    "mythifieraient": ("mythifier",),
    "mythifierai": ("mythifier",),
    "mythifierais": ("mythifier",),
    "mythifierait": ("mythifier",),
    "mythifieras": ("mythifier",),
    "mythifièrent": ("mythifier",),
    "mythifierez": ("mythifier",),
    "mythifieriez": ("mythifier",),
    "mythifierions": ("mythifier",),
    "mythifierons": ("mythifier",),
    "mythifieront": ("mythifier",),
    "mythifiés": ("mythifier",),
    "mythifies": ("mythifier",),
    "mythifiez": ("mythifier",),
    "mythifiiez": ("mythifier",),
    "mythifiions": ("mythifier",),
    "mythifions": ("mythifier",),
    "nageaient": ("nager",),
    "nageai": ("nager",),
    "nageais": ("nager",),
    "nageait": ("nager",),
    "nagea": ("nager",),
    "nageâmes": ("nager",),
    "nageant": ("nager",),
    "nageas": ("nager",),
    "nageassent": ("nager",),
    "nageasses": ("nager",),
    "nageasse": ("nager",),
    "nageassiez": ("nager",),
    "nageassions": ("nager",),
    "nageâtes": ("nager",),
    "nageât": ("nager",),
    "nagée": ("nager",),
    "nagées": ("nager",),
    "nagé": ("nager",),
    "nagent": ("nager",),
    "nageons": ("nager",),
    "nage": ("nager",),
    "nagera": ("nager",),
    "nageraient": ("nager",),
    "nagerai": ("nager",),
    "nagerais": ("nager",),
    "nagerait": ("nager",),
    "nageras": ("nager",),
    "nagèrent": ("nager",),
    "nagerez": ("nager",),
    "nageriez": ("nager",),
    "nagerions": ("nager",),
    "nagerons": ("nager",),
    "nageront": ("nager",),
    "nagés": ("nager",),
    "nages": ("nager",),
    "nagez": ("nager",),
    "nagiez": ("nager",),
    "nagions": ("nager",),
    "nais": ("naître",),
    "naissaient": ("naître",),
    "naissais": ("naître",),
    "naissait": ("naître",),
    "naissant": ("naître",),
    "naissent": ("naître",),
    "naisse": ("naître",),
    "naisses": ("naître",),
    "naissez": ("naître",),
    "naissiez": ("naître",),
    "naissions": ("naître",),
    "naissons": ("naître",),
    "naît": ("naître",),
    "naîtra": ("naître",),
    "naîtraient": ("naître",),
    "naîtrai": ("naître",),
    "naîtrais": ("naître",),
    "naîtrait": ("naître",),
    "naîtras": ("naître",),
    "naîtrez": ("naître",),
    "naîtriez": ("naître",),
    "naîtrions": ("naître",),
    "naîtrons": ("naître",),
    "naîtront": ("naître",),
    "naquîmes": ("naître",),
    "naquirent": ("naître",),
    "naquis": ("naître",),
    "naquissent": ("naître",),
    "naquisses": ("naître",),
    "naquisse": ("naître",),
    "naquissiez": ("naître",),
    "naquissions": ("naître",),
    "naquîtes": ("naître",),
    "naquit": ("naître",),
    "naquît": ("naître",),
    "née": ("naître",),
    "nées": ("naître",),
    "né": ("naître",),
    "nés": ("naître",),
    "nanifiaient": ("nanifier",),
    "nanifiai": ("nanifier",),
    "nanifiais": ("nanifier",),
    "nanifiait": ("nanifier",),
    "nanifia": ("nanifier",),
    "nanifiâmes": ("nanifier",),
    "nanifiant": ("nanifier",),
    "nanifias": ("nanifier",),
    "nanifiassent": ("nanifier",),
    "nanifiasses": ("nanifier",),
    "nanifiasse": ("nanifier",),
    "nanifiassiez": ("nanifier",),
    "nanifiassions": ("nanifier",),
    "nanifiâtes": ("nanifier",),
    "nanifiât": ("nanifier",),
    "nanifiée": ("nanifier",),
    "nanifiées": ("nanifier",),
    "nanifié": ("nanifier",),
    "nanifient": ("nanifier",),
    "nanifie": ("nanifier",),
    "nanifiera": ("nanifier",),
    "nanifieraient": ("nanifier",),
    "nanifierai": ("nanifier",),
    "nanifierais": ("nanifier",),
    "nanifierait": ("nanifier",),
    "nanifieras": ("nanifier",),
    "nanifièrent": ("nanifier",),
    "nanifierez": ("nanifier",),
    "nanifieriez": ("nanifier",),
    "nanifierions": ("nanifier",),
    "nanifierons": ("nanifier",),
    "nanifieront": ("nanifier",),
    "nanifiés": ("nanifier",),
    "nanifies": ("nanifier",),
    "nanifiez": ("nanifier",),
    "nanifiiez": ("nanifier",),
    "nanifiions": ("nanifier",),
    "nanifions": ("nanifier",),
    "nantie": ("nantir",),
    "nanties": ("nantir",),
    "nanti": ("nantir",),
    "nantîmes": ("nantir",),
    "nantira": ("nantir",),
    "nantiraient": ("nantir",),
    "nantirai": ("nantir",),
    "nantirais": ("nantir",),
    "nantirait": ("nantir",),
    "nantiras": ("nantir",),
    "nantirent": ("nantir",),
    "nantirez": ("nantir",),
    "nantiriez": ("nantir",),
    "nantirions": ("nantir",),
    "nantirons": ("nantir",),
    "nantiront": ("nantir",),
    "nantis": ("nantir",),
    "nantissaient": ("nantir",),
    "nantissais": ("nantir",),
    "nantissait": ("nantir",),
    "nantissant": ("nantir",),
    "nantissent": ("nantir",),
    "nantisse": ("nantir",),
    "nantisses": ("nantir",),
    "nantissez": ("nantir",),
    "nantissiez": ("nantir",),
    "nantissions": ("nantir",),
    "nantissons": ("nantir",),
    "nantîtes": ("nantir",),
    "nantit": ("nantir",),
    "nantît": ("nantir",),
    "naufrageaient": ("naufrager",),
    "naufrageai": ("naufrager",),
    "naufrageais": ("naufrager",),
    "naufrageait": ("naufrager",),
    "naufragea": ("naufrager",),
    "naufrageâmes": ("naufrager",),
    "naufrageant": ("naufrager",),
    "naufrageas": ("naufrager",),
    "naufrageassent": ("naufrager",),
    "naufrageasses": ("naufrager",),
    "naufrageasse": ("naufrager",),
    "naufrageassiez": ("naufrager",),
    "naufrageassions": ("naufrager",),
    "naufrageâtes": ("naufrager",),
    "naufrageât": ("naufrager",),
    "naufragé": ("naufrager",),
    "naufragent": ("naufrager",),
    "naufrageons": ("naufrager",),
    "naufrage": ("naufrager",),
    "naufragera": ("naufrager",),
    "naufrageraient": ("naufrager",),
    "naufragerai": ("naufrager",),
    "naufragerais": ("naufrager",),
    "naufragerait": ("naufrager",),
    "naufrageras": ("naufrager",),
    "naufragèrent": ("naufrager",),
    "naufragerez": ("naufrager",),
    "naufrageriez": ("naufrager",),
    "naufragerions": ("naufrager",),
    "naufragerons": ("naufrager",),
    "naufrageront": ("naufrager",),
    "naufrages": ("naufrager",),
    "naufragez": ("naufrager",),
    "naufragiez": ("naufrager",),
    "naufragions": ("naufrager",),
    "nazifiaient": ("nazifier",),
    "nazifiai": ("nazifier",),
    "nazifiais": ("nazifier",),
    "nazifiait": ("nazifier",),
    "nazifia": ("nazifier",),
    "nazifiâmes": ("nazifier",),
    "nazifiant": ("nazifier",),
    "nazifias": ("nazifier",),
    "nazifiassent": ("nazifier",),
    "nazifiasses": ("nazifier",),
    "nazifiasse": ("nazifier",),
    "nazifiassiez": ("nazifier",),
    "nazifiassions": ("nazifier",),
    "nazifiâtes": ("nazifier",),
    "nazifiât": ("nazifier",),
    "nazifiée": ("nazifier",),
    "nazifiées": ("nazifier",),
    "nazifié": ("nazifier",),
    "nazifient": ("nazifier",),
    "nazifie": ("nazifier",),
    "nazifiera": ("nazifier",),
    "nazifieraient": ("nazifier",),
    "nazifierai": ("nazifier",),
    "nazifierais": ("nazifier",),
    "nazifierait": ("nazifier",),
    "nazifieras": ("nazifier",),
    "nazifièrent": ("nazifier",),
    "nazifierez": ("nazifier",),
    "nazifieriez": ("nazifier",),
    "nazifierions": ("nazifier",),
    "nazifierons": ("nazifier",),
    "nazifieront": ("nazifier",),
    "nazifiés": ("nazifier",),
    "nazifies": ("nazifier",),
    "nazifiez": ("nazifier",),
    "nazifiiez": ("nazifier",),
    "nazifiions": ("nazifier",),
    "nazifions": ("nazifier",),
    "néantie": ("néantir",),
    "néanties": ("néantir",),
    "néanti": ("néantir",),
    "néantîmes": ("néantir",),
    "néantira": ("néantir",),
    "néantiraient": ("néantir",),
    "néantirai": ("néantir",),
    "néantirais": ("néantir",),
    "néantirait": ("néantir",),
    "néantiras": ("néantir",),
    "néantirent": ("néantir",),
    "néantirez": ("néantir",),
    "néantiriez": ("néantir",),
    "néantirions": ("néantir",),
    "néantirons": ("néantir",),
    "néantiront": ("néantir",),
    "néantis": ("néantir",),
    "néantissaient": ("néantir",),
    "néantissais": ("néantir",),
    "néantissait": ("néantir",),
    "néantissant": ("néantir",),
    "néantissent": ("néantir",),
    "néantisse": ("néantir",),
    "néantisses": ("néantir",),
    "néantissez": ("néantir",),
    "néantissiez": ("néantir",),
    "néantissions": ("néantir",),
    "néantissons": ("néantir",),
    "néantîtes": ("néantir",),
    "néantit": ("néantir",),
    "néantît": ("néantir",),
    "négligeaient": ("négliger",),
    "négligeai": ("négliger",),
    "négligeais": ("négliger",),
    "négligeait": ("négliger",),
    "négligea": ("négliger",),
    "négligeâmes": ("négliger",),
    "négligeant": ("négliger",),
    "négligeas": ("négliger",),
    "négligeassent": ("négliger",),
    "négligeasses": ("négliger",),
    "négligeasse": ("négliger",),
    "négligeassiez": ("négliger",),
    "négligeassions": ("négliger",),
    "négligeâtes": ("négliger",),
    "négligeât": ("négliger",),
    "négligée": ("négliger",),
    "négligées": ("négliger",),
    "négligé": ("négliger",),
    "négligent": ("négliger",),
    "négligeons": ("négliger",),
    "néglige": ("négliger",),
    "négligera": ("négliger",),
    "négligeraient": ("négliger",),
    "négligerai": ("négliger",),
    "négligerais": ("négliger",),
    "négligerait": ("négliger",),
    "négligeras": ("négliger",),
    "négligèrent": ("négliger",),
    "négligerez": ("négliger",),
    "négligeriez": ("négliger",),
    "négligerions": ("négliger",),
    "négligerons": ("négliger",),
    "négligeront": ("négliger",),
    "négligés": ("négliger",),
    "négliges": ("négliger",),
    "négligez": ("négliger",),
    "négligiez": ("négliger",),
    "négligions": ("négliger",),
    "négociaient": ("négocier",),
    "négociai": ("négocier",),
    "négociais": ("négocier",),
    "négociait": ("négocier",),
    "négocia": ("négocier",),
    "négociâmes": ("négocier",),
    "négociant": ("négocier",),
    "négocias": ("négocier",),
    "négociassent": ("négocier",),
    "négociasses": ("négocier",),
    "négociasse": ("négocier",),
    "négociassiez": ("négocier",),
    "négociassions": ("négocier",),
    "négociâtes": ("négocier",),
    "négociât": ("négocier",),
    "négociée": ("négocier",),
    "négociées": ("négocier",),
    "négocié": ("négocier",),
    "négocient": ("négocier",),
    "négocie": ("négocier",),
    "négociera": ("négocier",),
    "négocieraient": ("négocier",),
    "négocierai": ("négocier",),
    "négocierais": ("négocier",),
    "négocierait": ("négocier",),
    "négocieras": ("négocier",),
    "négocièrent": ("négocier",),
    "négocierez": ("négocier",),
    "négocieriez": ("négocier",),
    "négocierions": ("négocier",),
    "négocierons": ("négocier",),
    "négocieront": ("négocier",),
    "négociés": ("négocier",),
    "négocies": ("négocier",),
    "négociez": ("négocier",),
    "négociiez": ("négocier",),
    "négociions": ("négocier",),
    "négocions": ("négocier",),
    "négrifiaient": ("négrifier",),
    "négrifiai": ("négrifier",),
    "négrifiais": ("négrifier",),
    "négrifiait": ("négrifier",),
    "négrifia": ("négrifier",),
    "négrifiâmes": ("négrifier",),
    "négrifiant": ("négrifier",),
    "négrifias": ("négrifier",),
    "négrifiassent": ("négrifier",),
    "négrifiasses": ("négrifier",),
    "négrifiasse": ("négrifier",),
    "négrifiassiez": ("négrifier",),
    "négrifiassions": ("négrifier",),
    "négrifiâtes": ("négrifier",),
    "négrifiât": ("négrifier",),
    "négrifiée": ("négrifier",),
    "négrifiées": ("négrifier",),
    "négrifié": ("négrifier",),
    "négrifient": ("négrifier",),
    "négrifie": ("négrifier",),
    "négrifiera": ("négrifier",),
    "négrifieraient": ("négrifier",),
    "négrifierai": ("négrifier",),
    "négrifierais": ("négrifier",),
    "négrifierait": ("négrifier",),
    "négrifieras": ("négrifier",),
    "négrifièrent": ("négrifier",),
    "négrifierez": ("négrifier",),
    "négrifieriez": ("négrifier",),
    "négrifierions": ("négrifier",),
    "négrifierons": ("négrifier",),
    "négrifieront": ("négrifier",),
    "négrifiés": ("négrifier",),
    "négrifies": ("négrifier",),
    "négrifiez": ("négrifier",),
    "négrifiiez": ("négrifier",),
    "négrifiions": ("négrifier",),
    "négrifions": ("négrifier",),
    "neigeassaient": ("neigeasser",),
    "neigeassait": ("neigeasser",),
    "neigeassa": ("neigeasser",),
    "neigeassant": ("neigeasser",),
    "neigeassassent": ("neigeasser",),
    "neigeassât": ("neigeasser",),
    "neigeassé": ("neigeasser",),
    "neigeassent": ("neiger",),
    "neigeasse": ("neigeasser",),
    "neigeassera": ("neigeasser",),
    "neigeasseraient": ("neigeasser",),
    "neigeasserait": ("neigeasser",),
    "neigeassèrent": ("neigeasser",),
    "neigeasseront": ("neigeasser",),
    "neigeaient": ("neiger",),
    "neigeait": ("neiger",),
    "neigea": ("neiger",),
    "neigeant": ("neiger",),
    "neigeât": ("neiger",),
    "neigé": ("neiger",),
    "neigent": ("neiger",),
    "neige": ("neiger",),
    "neigera": ("neiger",),
    "neigeraient": ("neiger",),
    "neigerait": ("neiger",),
    "neigèrent": ("neiger",),
    "neigeront": ("neiger",),
    "nettoient": ("nettoyer",),
    "nettoie": ("nettoyer",),
    "nettoiera": ("nettoyer",),
    "nettoieraient": ("nettoyer",),
    "nettoierai": ("nettoyer",),
    "nettoierais": ("nettoyer",),
    "nettoierait": ("nettoyer",),
    "nettoieras": ("nettoyer",),
    "nettoierez": ("nettoyer",),
    "nettoieriez": ("nettoyer",),
    "nettoierions": ("nettoyer",),
    "nettoierons": ("nettoyer",),
    "nettoieront": ("nettoyer",),
    "nettoies": ("nettoyer",),
    "nettoyaient": ("nettoyer",),
    "nettoyai": ("nettoyer",),
    "nettoyais": ("nettoyer",),
    "nettoyait": ("nettoyer",),
    "nettoya": ("nettoyer",),
    "nettoyâmes": ("nettoyer",),
    "nettoyant": ("nettoyer",),
    "nettoyas": ("nettoyer",),
    "nettoyassent": ("nettoyer",),
    "nettoyasses": ("nettoyer",),
    "nettoyasse": ("nettoyer",),
    "nettoyassiez": ("nettoyer",),
    "nettoyassions": ("nettoyer",),
    "nettoyâtes": ("nettoyer",),
    "nettoyât": ("nettoyer",),
    "nettoyée": ("nettoyer",),
    "nettoyées": ("nettoyer",),
    "nettoyé": ("nettoyer",),
    "nettoyèrent": ("nettoyer",),
    "nettoyés": ("nettoyer",),
    "nettoyez": ("nettoyer",),
    "nettoyiez": ("nettoyer",),
    "nettoyions": ("nettoyer",),
    "nettoyons": ("nettoyer",),
    "neutrographiaient": ("neutrographier",),
    "neutrographiai": ("neutrographier",),
    "neutrographiais": ("neutrographier",),
    "neutrographiait": ("neutrographier",),
    "neutrographia": ("neutrographier",),
    "neutrographiâmes": ("neutrographier",),
    "neutrographiant": ("neutrographier",),
    "neutrographias": ("neutrographier",),
    "neutrographiassent": ("neutrographier",),
    "neutrographiasses": ("neutrographier",),
    "neutrographiasse": ("neutrographier",),
    "neutrographiassiez": ("neutrographier",),
    "neutrographiassions": ("neutrographier",),
    "neutrographiâtes": ("neutrographier",),
    "neutrographiât": ("neutrographier",),
    "neutrographiée": ("neutrographier",),
    "neutrographiées": ("neutrographier",),
    "neutrographié": ("neutrographier",),
    "neutrographient": ("neutrographier",),
    "neutrographie": ("neutrographier",),
    "neutrographiera": ("neutrographier",),
    "neutrographieraient": ("neutrographier",),
    "neutrographierai": ("neutrographier",),
    "neutrographierais": ("neutrographier",),
    "neutrographierait": ("neutrographier",),
    "neutrographieras": ("neutrographier",),
    "neutrographièrent": ("neutrographier",),
    "neutrographierez": ("neutrographier",),
    "neutrographieriez": ("neutrographier",),
    "neutrographierions": ("neutrographier",),
    "neutrographierons": ("neutrographier",),
    "neutrographieront": ("neutrographier",),
    "neutrographiés": ("neutrographier",),
    "neutrographies": ("neutrographier",),
    "neutrographiez": ("neutrographier",),
    "neutrographiiez": ("neutrographier",),
    "neutrographiions": ("neutrographier",),
    "neutrographions": ("neutrographier",),
    "nickelaient": ("nickeler",),
    "nickelai": ("nickeler",),
    "nickelais": ("nickeler",),
    "nickelait": ("nickeler",),
    "nickela": ("nickeler",),
    "nickelâmes": ("nickeler",),
    "nickelant": ("nickeler",),
    "nickelas": ("nickeler",),
    "nickelassent": ("nickeler",),
    "nickelasses": ("nickeler",),
    "nickelasse": ("nickeler",),
    "nickelassiez": ("nickeler",),
    "nickelassions": ("nickeler",),
    "nickelâtes": ("nickeler",),
    "nickelât": ("nickeler",),
    "nickelée": ("nickeler",),
    "nickelées": ("nickeler",),
    "nickelé": ("nickeler",),
    "nickelèrent": ("nickeler",),
    "nickelés": ("nickeler",),
    "nickelez": ("nickeler",),
    "nickeliez": ("nickeler",),
    "nickelions": ("nickeler",),
    "nickellent": ("nickeler",),
    "nickelle": ("nickeler",),
    "nickellera": ("nickeler",),
    "nickelleraient": ("nickeler",),
    "nickellerai": ("nickeler",),
    "nickellerais": ("nickeler",),
    "nickellerait": ("nickeler",),
    "nickelleras": ("nickeler",),
    "nickellerez": ("nickeler",),
    "nickelleriez": ("nickeler",),
    "nickellerions": ("nickeler",),
    "nickellerons": ("nickeler",),
    "nickelleront": ("nickeler",),
    "nickelles": ("nickeler",),
    "nickelons": ("nickeler",),
    "nidifiaient": ("nidifier",),
    "nidifiai": ("nidifier",),
    "nidifiais": ("nidifier",),
    "nidifiait": ("nidifier",),
    "nidifia": ("nidifier",),
    "nidifiâmes": ("nidifier",),
    "nidifiant": ("nidifier",),
    "nidifias": ("nidifier",),
    "nidifiassent": ("nidifier",),
    "nidifiasses": ("nidifier",),
    "nidifiasse": ("nidifier",),
    "nidifiassiez": ("nidifier",),
    "nidifiassions": ("nidifier",),
    "nidifiâtes": ("nidifier",),
    "nidifiât": ("nidifier",),
    "nidifié": ("nidifier",),
    "nidifient": ("nidifier",),
    "nidifie": ("nidifier",),
    "nidifiera": ("nidifier",),
    "nidifieraient": ("nidifier",),
    "nidifierai": ("nidifier",),
    "nidifierais": ("nidifier",),
    "nidifierait": ("nidifier",),
    "nidifieras": ("nidifier",),
    "nidifièrent": ("nidifier",),
    "nidifierez": ("nidifier",),
    "nidifieriez": ("nidifier",),
    "nidifierions": ("nidifier",),
    "nidifierons": ("nidifier",),
    "nidifieront": ("nidifier",),
    "nidifies": ("nidifier",),
    "nidifiez": ("nidifier",),
    "nidifiiez": ("nidifier",),
    "nidifiions": ("nidifier",),
    "nidifions": ("nidifier",),
    "niaient": ("nier",),
    "niai": ("nier",),
    "niais": ("nier",),
    "niait": ("nier",),
    "nia": ("nier",),
    "niâmes": ("nier",),
    "niant": ("nier",),
    "nias": ("nier",),
    "niassent": ("nier",),
    "niasses": ("nier",),
    "niasse": ("nier",),
    "niassiez": ("nier",),
    "niassions": ("nier",),
    "niâtes": ("nier",),
    "niât": ("nier",),
    "niée": ("nier",),
    "niées": ("nier",),
    "nié": ("nier",),
    "nient": ("nier",),
    "nie": ("nier",),
    "niera": ("nier",),
    "nieraient": ("nier",),
    "nierai": ("nier",),
    "nierais": ("nier",),
    "nierait": ("nier",),
    "nieras": ("nier",),
    "nièrent": ("nier",),
    "nierez": ("nier",),
    "nieriez": ("nier",),
    "nierions": ("nier",),
    "nierons": ("nier",),
    "nieront": ("nier",),
    "niés": ("nier",),
    "nies": ("nier",),
    "niez": ("nier",),
    "niiez": ("nier",),
    "niions": ("nier",),
    "nions": ("nier",),
    "niquetaient": ("niqueter",),
    "niquetai": ("niqueter",),
    "niquetais": ("niqueter",),
    "niquetait": ("niqueter",),
    "niqueta": ("niqueter",),
    "niquetâmes": ("niqueter",),
    "niquetant": ("niqueter",),
    "niquetas": ("niqueter",),
    "niquetassent": ("niqueter",),
    "niquetasses": ("niqueter",),
    "niquetasse": ("niqueter",),
    "niquetassiez": ("niqueter",),
    "niquetassions": ("niqueter",),
    "niquetâtes": ("niqueter",),
    "niquetât": ("niqueter",),
    "niquetée": ("niqueter",),
    "niquetées": ("niqueter",),
    "niqueté": ("niqueter",),
    "niquetèrent": ("niqueter",),
    "niquetés": ("niqueter",),
    "niquetez": ("niqueter",),
    "niquetiez": ("niqueter",),
    "niquetions": ("niqueter",),
    "niquetons": ("niqueter",),
    "niquettent": ("niqueter",),
    "niquette": ("niqueter",),
    "niquettera": ("niqueter",),
    "niquetteraient": ("niqueter",),
    "niquetterai": ("niqueter",),
    "niquetterais": ("niqueter",),
    "niquetterait": ("niqueter",),
    "niquetteras": ("niqueter",),
    "niquetterez": ("niqueter",),
    "niquetteriez": ("niqueter",),
    "niquetterions": ("niqueter",),
    "niquetterons": ("niqueter",),
    "niquetteront": ("niqueter",),
    "niquettes": ("niqueter",),
    "nitrifiaient": ("nitrifier",),
    "nitrifiai": ("nitrifier",),
    "nitrifiais": ("nitrifier",),
    "nitrifiait": ("nitrifier",),
    "nitrifia": ("nitrifier",),
    "nitrifiâmes": ("nitrifier",),
    "nitrifiant": ("nitrifier",),
    "nitrifias": ("nitrifier",),
    "nitrifiassent": ("nitrifier",),
    "nitrifiasses": ("nitrifier",),
    "nitrifiasse": ("nitrifier",),
    "nitrifiassiez": ("nitrifier",),
    "nitrifiassions": ("nitrifier",),
    "nitrifiâtes": ("nitrifier",),
    "nitrifiât": ("nitrifier",),
    "nitrifiée": ("nitrifier",),
    "nitrifiées": ("nitrifier",),
    "nitrifié": ("nitrifier",),
    "nitrifient": ("nitrifier",),
    "nitrifie": ("nitrifier",),
    "nitrifiera": ("nitrifier",),
    "nitrifieraient": ("nitrifier",),
    "nitrifierai": ("nitrifier",),
    "nitrifierais": ("nitrifier",),
    "nitrifierait": ("nitrifier",),
    "nitrifieras": ("nitrifier",),
    "nitrifièrent": ("nitrifier",),
    "nitrifierez": ("nitrifier",),
    "nitrifieriez": ("nitrifier",),
    "nitrifierions": ("nitrifier",),
    "nitrifierons": ("nitrifier",),
    "nitrifieront": ("nitrifier",),
    "nitrifiés": ("nitrifier",),
    "nitrifies": ("nitrifier",),
    "nitrifiez": ("nitrifier",),
    "nitrifiiez": ("nitrifier",),
    "nitrifiions": ("nitrifier",),
    "nitrifions": ("nitrifier",),
    "nivelaient": ("niveler",),
    "nivelai": ("niveler",),
    "nivelais": ("niveler",),
    "nivelait": ("niveler",),
    "nivela": ("niveler",),
    "nivelâmes": ("niveler",),
    "nivelant": ("niveler",),
    "nivelas": ("niveler",),
    "nivelassent": ("niveler",),
    "nivelasses": ("niveler",),
    "nivelasse": ("niveler",),
    "nivelassiez": ("niveler",),
    "nivelassions": ("niveler",),
    "nivelâtes": ("niveler",),
    "nivelât": ("niveler",),
    "nivelée": ("niveler",),
    "nivelées": ("niveler",),
    "nivelé": ("niveler",),
    "nivelèrent": ("niveler",),
    "nivelés": ("niveler",),
    "nivelez": ("niveler",),
    "niveliez": ("niveler",),
    "nivelions": ("niveler",),
    "nivellent": ("niveler",),
    "nivelle": ("niveler",),
    "nivellera": ("niveler",),
    "nivelleraient": ("niveler",),
    "nivellerai": ("niveler",),
    "nivellerais": ("niveler",),
    "nivellerait": ("niveler",),
    "nivelleras": ("niveler",),
    "nivellerez": ("niveler",),
    "nivelleriez": ("niveler",),
    "nivellerions": ("niveler",),
    "nivellerons": ("niveler",),
    "nivelleront": ("niveler",),
    "nivelles": ("niveler",),
    "nivelons": ("niveler",),
    "noçaient": ("nocer",),
    "noçai": ("nocer",),
    "noçais": ("nocer",),
    "noçait": ("nocer",),
    "noça": ("nocer",),
    "noçâmes": ("nocer",),
    "noçant": ("nocer",),
    "noças": ("nocer",),
    "noçassent": ("nocer",),
    "noçasses": ("nocer",),
    "noçasse": ("nocer",),
    "noçassiez": ("nocer",),
    "noçassions": ("nocer",),
    "noçâtes": ("nocer",),
    "noçât": ("nocer",),
    "nocé": ("nocer",),
    "nocent": ("nocer",),
    "noce": ("nocer",),
    "nocera": ("nocer",),
    "noceraient": ("nocer",),
    "nocerai": ("nocer",),
    "nocerais": ("nocer",),
    "nocerait": ("nocer",),
    "noceras": ("nocer",),
    "nocèrent": ("nocer",),
    "nocerez": ("nocer",),
    "noceriez": ("nocer",),
    "nocerions": ("nocer",),
    "nocerons": ("nocer",),
    "noceront": ("nocer",),
    "noces": ("nocer",),
    "nocez": ("nocer",),
    "nociez": ("nocer",),
    "nocions": ("nocer",),
    "noçons": ("nocer",),
    "noircie": ("noircir",),
    "noircies": ("noircir",),
    "noirci": ("noircir",),
    "noircîmes": ("noircir",),
    "noircira": ("noircir",),
    "noirciraient": ("noircir",),
    "noircirai": ("noircir",),
    "noircirais": ("noircir",),
    "noircirait": ("noircir",),
    "noirciras": ("noircir",),
    "noircirent": ("noircir",),
    "noircirez": ("noircir",),
    "noirciriez": ("noircir",),
    "noircirions": ("noircir",),
    "noircirons": ("noircir",),
    "noirciront": ("noircir",),
    "noircis": ("noircir",),
    "noircissaient": ("noircir",),
    "noircissais": ("noircir",),
    "noircissait": ("noircir",),
    "noircissant": ("noircir",),
    "noircissent": ("noircir",),
    "noircisse": ("noircir",),
    "noircisses": ("noircir",),
    "noircissez": ("noircir",),
    "noircissiez": ("noircir",),
    "noircissions": ("noircir",),
    "noircissons": ("noircir",),
    "noircîtes": ("noircir",),
    "noircit": ("noircir",),
    "noircît": ("noircir",),
    "noquetaient": ("noqueter",),
    "noquetai": ("noqueter",),
    "noquetais": ("noqueter",),
    "noquetait": ("noqueter",),
    "noqueta": ("noqueter",),
    "noquetâmes": ("noqueter",),
    "noquetant": ("noqueter",),
    "noquetas": ("noqueter",),
    "noquetassent": ("noqueter",),
    "noquetasses": ("noqueter",),
    "noquetasse": ("noqueter",),
    "noquetassiez": ("noqueter",),
    "noquetassions": ("noqueter",),
    "noquetâtes": ("noqueter",),
    "noquetât": ("noqueter",),
    "noquetée": ("noqueter",),
    "noquetées": ("noqueter",),
    "noqueté": ("noqueter",),
    "noquetèrent": ("noqueter",),
    "noquetés": ("noqueter",),
    "noquetez": ("noqueter",),
    "noquetiez": ("noqueter",),
    "noquetions": ("noqueter",),
    "noquetons": ("noqueter",),
    "noquettent": ("noqueter",),
    "noquette": ("noqueter",),
    "noquettera": ("noqueter",),
    "noquetteraient": ("noqueter",),
    "noquetterai": ("noqueter",),
    "noquetterais": ("noqueter",),
    "noquetterait": ("noqueter",),
    "noquetteras": ("noqueter",),
    "noquetterez": ("noqueter",),
    "noquetteriez": ("noqueter",),
    "noquetterions": ("noqueter",),
    "noquetterons": ("noqueter",),
    "noquetteront": ("noqueter",),
    "noquettes": ("noqueter",),
    "nordi": ("nordir",),
    "nordîmes": ("nordir",),
    "nordira": ("nordir",),
    "nordiraient": ("nordir",),
    "nordirai": ("nordir",),
    "nordirais": ("nordir",),
    "nordirait": ("nordir",),
    "nordiras": ("nordir",),
    "nordirent": ("nordir",),
    "nordirez": ("nordir",),
    "nordiriez": ("nordir",),
    "nordirions": ("nordir",),
    "nordirons": ("nordir",),
    "nordiront": ("nordir",),
    "nordis": ("nordir",),
    "nordissaient": ("nordir",),
    "nordissais": ("nordir",),
    "nordissait": ("nordir",),
    "nordissant": ("nordir",),
    "nordissent": ("nordir",),
    "nordisse": ("nordir",),
    "nordisses": ("nordir",),
    "nordissez": ("nordir",),
    "nordissiez": ("nordir",),
    "nordissions": ("nordir",),
    "nordissons": ("nordir",),
    "nordîtes": ("nordir",),
    "nordit": ("nordir",),
    "nordît": ("nordir",),
    "notariaient": ("notarier",),
    "notariai": ("notarier",),
    "notariais": ("notarier",),
    "notariait": ("notarier",),
    "notaria": ("notarier",),
    "notariâmes": ("notarier",),
    "notariant": ("notarier",),
    "notarias": ("notarier",),
    "notariassent": ("notarier",),
    "notariasses": ("notarier",),
    "notariasse": ("notarier",),
    "notariassiez": ("notarier",),
    "notariassions": ("notarier",),
    "notariâtes": ("notarier",),
    "notariât": ("notarier",),
    "notariée": ("notarier",),
    "notariées": ("notarier",),
    "notarié": ("notarier",),
    "notarient": ("notarier",),
    "notarie": ("notarier",),
    "notariera": ("notarier",),
    "notarieraient": ("notarier",),
    "notarierai": ("notarier",),
    "notarierais": ("notarier",),
    "notarierait": ("notarier",),
    "notarieras": ("notarier",),
    "notarièrent": ("notarier",),
    "notarierez": ("notarier",),
    "notarieriez": ("notarier",),
    "notarierions": ("notarier",),
    "notarierons": ("notarier",),
    "notarieront": ("notarier",),
    "notariés": ("notarier",),
    "notaries": ("notarier",),
    "notariez": ("notarier",),
    "notariiez": ("notarier",),
    "notariions": ("notarier",),
    "notarions": ("notarier",),
    "notifiaient": ("notifier",),
    "notifiai": ("notifier",),
    "notifiais": ("notifier",),
    "notifiait": ("notifier",),
    "notifia": ("notifier",),
    "notifiâmes": ("notifier",),
    "notifiant": ("notifier",),
    "notifias": ("notifier",),
    "notifiassent": ("notifier",),
    "notifiasses": ("notifier",),
    "notifiasse": ("notifier",),
    "notifiassiez": ("notifier",),
    "notifiassions": ("notifier",),
    "notifiâtes": ("notifier",),
    "notifiât": ("notifier",),
    "notifiée": ("notifier",),
    "notifiées": ("notifier",),
    "notifié": ("notifier",),
    "notifient": ("notifier",),
    "notifie": ("notifier",),
    "notifiera": ("notifier",),
    "notifieraient": ("notifier",),
    "notifierai": ("notifier",),
    "notifierais": ("notifier",),
    "notifierait": ("notifier",),
    "notifieras": ("notifier",),
    "notifièrent": ("notifier",),
    "notifierez": ("notifier",),
    "notifieriez": ("notifier",),
    "notifierions": ("notifier",),
    "notifierons": ("notifier",),
    "notifieront": ("notifier",),
    "notifiés": ("notifier",),
    "notifies": ("notifier",),
    "notifiez": ("notifier",),
    "notifiiez": ("notifier",),
    "notifiions": ("notifier",),
    "notifions": ("notifier",),
    "nourrie": ("nourrir",),
    "nourries": ("nourrir",),
    "nourri": ("nourrir",),
    "nourrîmes": ("nourrir",),
    "nourrira": ("nourrir",),
    "nourriraient": ("nourrir",),
    "nourrirai": ("nourrir",),
    "nourrirais": ("nourrir",),
    "nourrirait": ("nourrir",),
    "nourriras": ("nourrir",),
    "nourrirent": ("nourrir",),
    "nourrirez": ("nourrir",),
    "nourririez": ("nourrir",),
    "nourririons": ("nourrir",),
    "nourrirons": ("nourrir",),
    "nourriront": ("nourrir",),
    "nourris": ("nourrir",),
    "nourrissaient": ("nourrir",),
    "nourrissais": ("nourrir",),
    "nourrissait": ("nourrir",),
    "nourrissant": ("nourrir",),
    "nourrissent": ("nourrir",),
    "nourrisse": ("nourrir",),
    "nourrisses": ("nourrir",),
    "nourrissez": ("nourrir",),
    "nourrissiez": ("nourrir",),
    "nourrissions": ("nourrir",),
    "nourrissons": ("nourrir",),
    "nourrîtes": ("nourrir",),
    "nourrit": ("nourrir",),
    "nourrît": ("nourrir",),
    "noient": ("noyer",),
    "noie": ("noyer",),
    "noiera": ("noyer",),
    "noieraient": ("noyer",),
    "noierai": ("noyer",),
    "noierais": ("noyer",),
    "noierait": ("noyer",),
    "noieras": ("noyer",),
    "noierez": ("noyer",),
    "noieriez": ("noyer",),
    "noierions": ("noyer",),
    "noierons": ("noyer",),
    "noieront": ("noyer",),
    "noies": ("noyer",),
    "noyaient": ("noyer",),
    "noyai": ("noyer",),
    "noyais": ("noyer",),
    "noyait": ("noyer",),
    "noya": ("noyer",),
    "noyâmes": ("noyer",),
    "noyant": ("noyer",),
    "noyas": ("noyer",),
    "noyassent": ("noyer",),
    "noyasses": ("noyer",),
    "noyasse": ("noyer",),
    "noyassiez": ("noyer",),
    "noyassions": ("noyer",),
    "noyâtes": ("noyer",),
    "noyât": ("noyer",),
    "noyée": ("noyer",),
    "noyées": ("noyer",),
    "noyé": ("noyer",),
    "noyèrent": ("noyer",),
    "noyés": ("noyer",),
    "noyez": ("noyer",),
    "noyiez": ("noyer",),
    "noyions": ("noyer",),
    "noyons": ("noyer",),
    "nuageaient": ("nuager",),
    "nuageai": ("nuager",),
    "nuageais": ("nuager",),
    "nuageait": ("nuager",),
    "nuagea": ("nuager",),
    "nuageâmes": ("nuager",),
    "nuageant": ("nuager",),
    "nuageas": ("nuager",),
    "nuageassent": ("nuager",),
    "nuageasses": ("nuager",),
    "nuageasse": ("nuager",),
    "nuageassiez": ("nuager",),
    "nuageassions": ("nuager",),
    "nuageâtes": ("nuager",),
    "nuageât": ("nuager",),
    "nuagée": ("nuager",),
    "nuagées": ("nuager",),
    "nuagé": ("nuager",),
    "nuagent": ("nuager",),
    "nuageons": ("nuager",),
    "nuage": ("nuager",),
    "nuagera": ("nuager",),
    "nuageraient": ("nuager",),
    "nuagerai": ("nuager",),
    "nuagerais": ("nuager",),
    "nuagerait": ("nuager",),
    "nuageras": ("nuager",),
    "nuagèrent": ("nuager",),
    "nuagerez": ("nuager",),
    "nuageriez": ("nuager",),
    "nuagerions": ("nuager",),
    "nuagerons": ("nuager",),
    "nuageront": ("nuager",),
    "nuagés": ("nuager",),
    "nuages": ("nuager",),
    "nuagez": ("nuager",),
    "nuagiez": ("nuager",),
    "nuagions": ("nuager",),
    "nuançaient": ("nuancer",),
    "nuançai": ("nuancer",),
    "nuançais": ("nuancer",),
    "nuançait": ("nuancer",),
    "nuança": ("nuancer",),
    "nuançâmes": ("nuancer",),
    "nuançant": ("nuancer",),
    "nuanças": ("nuancer",),
    "nuançassent": ("nuancer",),
    "nuançasses": ("nuancer",),
    "nuançasse": ("nuancer",),
    "nuançassiez": ("nuancer",),
    "nuançassions": ("nuancer",),
    "nuançâtes": ("nuancer",),
    "nuançât": ("nuancer",),
    "nuancée": ("nuancer",),
    "nuancées": ("nuancer",),
    "nuancé": ("nuancer",),
    "nuancent": ("nuancer",),
    "nuance": ("nuancer",),
    "nuancera": ("nuancer",),
    "nuanceraient": ("nuancer",),
    "nuancerai": ("nuancer",),
    "nuancerais": ("nuancer",),
    "nuancerait": ("nuancer",),
    "nuanceras": ("nuancer",),
    "nuancèrent": ("nuancer",),
    "nuancerez": ("nuancer",),
    "nuanceriez": ("nuancer",),
    "nuancerions": ("nuancer",),
    "nuancerons": ("nuancer",),
    "nuanceront": ("nuancer",),
    "nuancés": ("nuancer",),
    "nuances": ("nuancer",),
    "nuancez": ("nuancer",),
    "nuanciez": ("nuancer",),
    "nuancions": ("nuancer",),
    "nuançons": ("nuancer",),
    "nui": ("nuire",),
    "nuira": ("nuire",),
    "nuiraient": ("nuire",),
    "nuirai": ("nuire",),
    "nuirais": ("nuire",),
    "nuirait": ("nuire",),
    "nuiras": ("nuire",),
    "nuirez": ("nuire",),
    "nuiriez": ("nuire",),
    "nuirions": ("nuire",),
    "nuirons": ("nuire",),
    "nuiront": ("nuire",),
    "nuisaient": ("nuire",),
    "nuisais": ("nuire",),
    "nuisait": ("nuire",),
    "nuisant": ("nuire",),
    "nuisent": ("nuire",),
    "nuise": ("nuire",),
    "nuises": ("nuire",),
    "nuisez": ("nuire",),
    "nuisiez": ("nuire",),
    "nuisîmes": ("nuire",),
    "nuisions": ("nuire",),
    "nuisirent": ("nuire",),
    "nuisis": ("nuire",),
    "nuisissent": ("nuire",),
    "nuisisses": ("nuire",),
    "nuisisse": ("nuire",),
    "nuisissiez": ("nuire",),
    "nuisissions": ("nuire",),
    "nuisîtes": ("nuire",),
    "nuisit": ("nuire",),
    "nuisît": ("nuire",),
    "nuisons": ("nuire",),
    "nuis": ("nuire",),
    "nuit": ("nuire",),
    "nullifiaient": ("nullifier",),
    "nullifiai": ("nullifier",),
    "nullifiais": ("nullifier",),
    "nullifiait": ("nullifier",),
    "nullifia": ("nullifier",),
    "nullifiâmes": ("nullifier",),
    "nullifiant": ("nullifier",),
    "nullifias": ("nullifier",),
    "nullifiassent": ("nullifier",),
    "nullifiasses": ("nullifier",),
    "nullifiasse": ("nullifier",),
    "nullifiassiez": ("nullifier",),
    "nullifiassions": ("nullifier",),
    "nullifiâtes": ("nullifier",),
    "nullifiât": ("nullifier",),
    "nullifiée": ("nullifier",),
    "nullifiées": ("nullifier",),
    "nullifié": ("nullifier",),
    "nullifient": ("nullifier",),
    "nullifie": ("nullifier",),
    "nullifiera": ("nullifier",),
    "nullifieraient": ("nullifier",),
    "nullifierai": ("nullifier",),
    "nullifierais": ("nullifier",),
    "nullifierait": ("nullifier",),
    "nullifieras": ("nullifier",),
    "nullifièrent": ("nullifier",),
    "nullifierez": ("nullifier",),
    "nullifieriez": ("nullifier",),
    "nullifierions": ("nullifier",),
    "nullifierons": ("nullifier",),
    "nullifieront": ("nullifier",),
    "nullifiés": ("nullifier",),
    "nullifies": ("nullifier",),
    "nullifiez": ("nullifier",),
    "nullifiiez": ("nullifier",),
    "nullifiions": ("nullifier",),
    "nullifions": ("nullifier",),
    "obéi": ("obéir",),
    "obéîmes": ("obéir",),
    "obéira": ("obéir",),
    "obéiraient": ("obéir",),
    "obéirai": ("obéir",),
    "obéirais": ("obéir",),
    "obéirait": ("obéir",),
    "obéiras": ("obéir",),
    "obéirent": ("obéir",),
    "obéirez": ("obéir",),
    "obéiriez": ("obéir",),
    "obéirions": ("obéir",),
    "obéirons": ("obéir",),
    "obéiront": ("obéir",),
    "obéis": ("obéir",),
    "obéissaient": ("obéir",),
    "obéissais": ("obéir",),
    "obéissait": ("obéir",),
    "obéissant": ("obéir",),
    "obéissent": ("obéir",),
    "obéisse": ("obéir",),
    "obéisses": ("obéir",),
    "obéissez": ("obéir",),
    "obéissiez": ("obéir",),
    "obéissions": ("obéir",),
    "obéissons": ("obéir",),
    "obéîtes": ("obéir",),
    "obéit": ("obéir",),
    "obéît": ("obéir",),
    "obéraient": ("obérer",),
    "obérai": ("obérer",),
    "obérais": ("obérer",),
    "obérait": ("obérer",),
    "obéra": ("obérer",),
    "obérâmes": ("obérer",),
    "obérant": ("obérer",),
    "obéras": ("obérer",),
    "obérassent": ("obérer",),
    "obérasses": ("obérer",),
    "obérasse": ("obérer",),
    "obérassiez": ("obérer",),
    "obérassions": ("obérer",),
    "obérâtes": ("obérer",),
    "obérât": ("obérer",),
    "obérée": ("obérer",),
    "obérées": ("obérer",),
    "obéré": ("obérer",),
    "obèrent": ("obérer",),
    "obère": ("obérer",),
    "obérera": ("obérer",),
    "obéreraient": ("obérer",),
    "obérerai": ("obérer",),
    "obérerais": ("obérer",),
    "obérerait": ("obérer",),
    "obéreras": ("obérer",),
    "obérèrent": ("obérer",),
    "obérerez": ("obérer",),
    "obéreriez": ("obérer",),
    "obérerions": ("obérer",),
    "obérerons": ("obérer",),
    "obéreront": ("obérer",),
    "obérés": ("obérer",),
    "obères": ("obérer",),
    "obérez": ("obérer",),
    "obériez": ("obérer",),
    "obérions": ("obérer",),
    "obérons": ("obérer",),
    "obligeaient": ("obliger",),
    "obligeai": ("obliger",),
    "obligeais": ("obliger",),
    "obligeait": ("obliger",),
    "obligea": ("obliger",),
    "obligeâmes": ("obliger",),
    "obligeant": ("obliger",),
    "obligeas": ("obliger",),
    "obligeassent": ("obliger",),
    "obligeasses": ("obliger",),
    "obligeasse": ("obliger",),
    "obligeassiez": ("obliger",),
    "obligeassions": ("obliger",),
    "obligeâtes": ("obliger",),
    "obligeât": ("obliger",),
    "obligée": ("obliger",),
    "obligées": ("obliger",),
    "obligé": ("obliger",),
    "obligent": ("obliger",),
    "obligeons": ("obliger",),
    "oblige": ("obliger",),
    "obligera": ("obliger",),
    "obligeraient": ("obliger",),
    "obligerai": ("obliger",),
    "obligerais": ("obliger",),
    "obligerait": ("obliger",),
    "obligeras": ("obliger",),
    "obligèrent": ("obliger",),
    "obligerez": ("obliger",),
    "obligeriez": ("obliger",),
    "obligerions": ("obliger",),
    "obligerons": ("obliger",),
    "obligeront": ("obliger",),
    "obligés": ("obliger",),
    "obliges": ("obliger",),
    "obligez": ("obliger",),
    "obligiez": ("obliger",),
    "obligions": ("obliger",),
    "oblitéraient": ("oblitérer",),
    "oblitérai": ("oblitérer",),
    "oblitérais": ("oblitérer",),
    "oblitérait": ("oblitérer",),
    "oblitéra": ("oblitérer",),
    "oblitérâmes": ("oblitérer",),
    "oblitérant": ("oblitérer",),
    "oblitéras": ("oblitérer",),
    "oblitérassent": ("oblitérer",),
    "oblitérasses": ("oblitérer",),
    "oblitérasse": ("oblitérer",),
    "oblitérassiez": ("oblitérer",),
    "oblitérassions": ("oblitérer",),
    "oblitérâtes": ("oblitérer",),
    "oblitérât": ("oblitérer",),
    "oblitérée": ("oblitérer",),
    "oblitérées": ("oblitérer",),
    "oblitéré": ("oblitérer",),
    "oblitèrent": ("oblitérer",),
    "oblitère": ("oblitérer",),
    "oblitérera": ("oblitérer",),
    "oblitéreraient": ("oblitérer",),
    "oblitérerai": ("oblitérer",),
    "oblitérerais": ("oblitérer",),
    "oblitérerait": ("oblitérer",),
    "oblitéreras": ("oblitérer",),
    "oblitérèrent": ("oblitérer",),
    "oblitérerez": ("oblitérer",),
    "oblitéreriez": ("oblitérer",),
    "oblitérerions": ("oblitérer",),
    "oblitérerons": ("oblitérer",),
    "oblitéreront": ("oblitérer",),
    "oblitérés": ("oblitérer",),
    "oblitères": ("oblitérer",),
    "oblitérez": ("oblitérer",),
    "oblitériez": ("oblitérer",),
    "oblitérions": ("oblitérer",),
    "oblitérons": ("oblitérer",),
    "obscurcie": ("obscurcir",),
    "obscurcies": ("obscurcir",),
    "obscurci": ("obscurcir",),
    "obscurcîmes": ("obscurcir",),
    "obscurcira": ("obscurcir",),
    "obscurciraient": ("obscurcir",),
    "obscurcirai": ("obscurcir",),
    "obscurcirais": ("obscurcir",),
    "obscurcirait": ("obscurcir",),
    "obscurciras": ("obscurcir",),
    "obscurcirent": ("obscurcir",),
    "obscurcirez": ("obscurcir",),
    "obscurciriez": ("obscurcir",),
    "obscurcirions": ("obscurcir",),
    "obscurcirons": ("obscurcir",),
    "obscurciront": ("obscurcir",),
    "obscurcis": ("obscurcir",),
    "obscurcissaient": ("obscurcir",),
    "obscurcissais": ("obscurcir",),
    "obscurcissait": ("obscurcir",),
    "obscurcissant": ("obscurcir",),
    "obscurcissent": ("obscurcir",),
    "obscurcisse": ("obscurcir",),
    "obscurcisses": ("obscurcir",),
    "obscurcissez": ("obscurcir",),
    "obscurcissiez": ("obscurcir",),
    "obscurcissions": ("obscurcir",),
    "obscurcissons": ("obscurcir",),
    "obscurcîtes": ("obscurcir",),
    "obscurcit": ("obscurcir",),
    "obscurcît": ("obscurcir",),
    "obsédaient": ("obséder",),
    "obsédai": ("obséder",),
    "obsédais": ("obséder",),
    "obsédait": ("obséder",),
    "obséda": ("obséder",),
    "obsédâmes": ("obséder",),
    "obsédant": ("obséder",),
    "obsédas": ("obséder",),
    "obsédassent": ("obséder",),
    "obsédasses": ("obséder",),
    "obsédasse": ("obséder",),
    "obsédassiez": ("obséder",),
    "obsédassions": ("obséder",),
    "obsédâtes": ("obséder",),
    "obsédât": ("obséder",),
    "obsédée": ("obséder",),
    "obsédées": ("obséder",),
    "obsédé": ("obséder",),
    "obsèdent": ("obséder",),
    "obsède": ("obséder",),
    "obsédera": ("obséder",),
    "obséderaient": ("obséder",),
    "obséderai": ("obséder",),
    "obséderais": ("obséder",),
    "obséderait": ("obséder",),
    "obséderas": ("obséder",),
    "obsédèrent": ("obséder",),
    "obséderez": ("obséder",),
    "obséderiez": ("obséder",),
    "obséderions": ("obséder",),
    "obséderons": ("obséder",),
    "obséderont": ("obséder",),
    "obsédés": ("obséder",),
    "obsèdes": ("obséder",),
    "obsédez": ("obséder",),
    "obsédiez": ("obséder",),
    "obsédions": ("obséder",),
    "obsédons": ("obséder",),
    "obtempéraient": ("obtempérer",),
    "obtempérai": ("obtempérer",),
    "obtempérais": ("obtempérer",),
    "obtempérait": ("obtempérer",),
    "obtempéra": ("obtempérer",),
    "obtempérâmes": ("obtempérer",),
    "obtempérant": ("obtempérer",),
    "obtempéras": ("obtempérer",),
    "obtempérassent": ("obtempérer",),
    "obtempérasses": ("obtempérer",),
    "obtempérasse": ("obtempérer",),
    "obtempérassiez": ("obtempérer",),
    "obtempérassions": ("obtempérer",),
    "obtempérâtes": ("obtempérer",),
    "obtempérât": ("obtempérer",),
    "obtempéré": ("obtempérer",),
    "obtempèrent": ("obtempérer",),
    "obtempère": ("obtempérer",),
    "obtempérera": ("obtempérer",),
    "obtempéreraient": ("obtempérer",),
    "obtempérerai": ("obtempérer",),
    "obtempérerais": ("obtempérer",),
    "obtempérerait": ("obtempérer",),
    "obtempéreras": ("obtempérer",),
    "obtempérèrent": ("obtempérer",),
    "obtempérerez": ("obtempérer",),
    "obtempéreriez": ("obtempérer",),
    "obtempérerions": ("obtempérer",),
    "obtempérerons": ("obtempérer",),
    "obtempéreront": ("obtempérer",),
    "obtempères": ("obtempérer",),
    "obtempérez": ("obtempérer",),
    "obtempériez": ("obtempérer",),
    "obtempérions": ("obtempérer",),
    "obtempérons": ("obtempérer",),
    "obtenaient": ("obtenir",),
    "obtenais": ("obtenir",),
    "obtenait": ("obtenir",),
    "obtenant": ("obtenir",),
    "obtenez": ("obtenir",),
    "obteniez": ("obtenir",),
    "obtenions": ("obtenir",),
    "obtenons": ("obtenir",),
    "obtenue": ("obtenir",),
    "obtenues": ("obtenir",),
    "obtenu": ("obtenir",),
    "obtenus": ("obtenir",),
    "obtiendra": ("obtenir",),
    "obtiendraient": ("obtenir",),
    "obtiendrai": ("obtenir",),
    "obtiendrais": ("obtenir",),
    "obtiendrait": ("obtenir",),
    "obtiendras": ("obtenir",),
    "obtiendrez": ("obtenir",),
    "obtiendriez": ("obtenir",),
    "obtiendrions": ("obtenir",),
    "obtiendrons": ("obtenir",),
    "obtiendront": ("obtenir",),
    "obtiennent": ("obtenir",),
    "obtienne": ("obtenir",),
    "obtiennes": ("obtenir",),
    "obtiens": ("obtenir",),
    "obtient": ("obtenir",),
    "obtînmes": ("obtenir",),
    "obtinrent": ("obtenir",),
    "obtins": ("obtenir",),
    "obtinssent": ("obtenir",),
    "obtinsses": ("obtenir",),
    "obtinsse": ("obtenir",),
    "obtinssiez": ("obtenir",),
    "obtinssions": ("obtenir",),
    "obtîntes": ("obtenir",),
    "obtint": ("obtenir",),
    "obtînt": ("obtenir",),
    "obvenaient": ("obvenir",),
    "obvenais": ("obvenir",),
    "obvenait": ("obvenir",),
    "obvenant": ("obvenir",),
    "obvenez": ("obvenir",),
    "obveniez": ("obvenir",),
    "obvenions": ("obvenir",),
    "obvenons": ("obvenir",),
    "obvenue": ("obvenir",),
    "obvenues": ("obvenir",),
    "obvenu": ("obvenir",),
    "obvenus": ("obvenir",),
    "obviendra": ("obvenir",),
    "obviendraient": ("obvenir",),
    "obviendrai": ("obvenir",),
    "obviendrais": ("obvenir",),
    "obviendrait": ("obvenir",),
    "obviendras": ("obvenir",),
    "obviendrez": ("obvenir",),
    "obviendriez": ("obvenir",),
    "obviendrions": ("obvenir",),
    "obviendrons": ("obvenir",),
    "obviendront": ("obvenir",),
    "obviennent": ("obvenir",),
    "obvienne": ("obvenir",),
    "obviennes": ("obvenir",),
    "obviens": ("obvenir",),
    "obvient": ("obvier",),
    "obvînmes": ("obvenir",),
    "obvinrent": ("obvenir",),
    "obvins": ("obvenir",),
    "obvinssent": ("obvenir",),
    "obvinsses": ("obvenir",),
    "obvinsse": ("obvenir",),
    "obvinssiez": ("obvenir",),
    "obvinssions": ("obvenir",),
    "obvîntes": ("obvenir",),
    "obvint": ("obvenir",),
    "obvînt": ("obvenir",),
    "obviaient": ("obvier",),
    "obviai": ("obvier",),
    "obviais": ("obvier",),
    "obviait": ("obvier",),
    "obvia": ("obvier",),
    "obviâmes": ("obvier",),
    "obviant": ("obvier",),
    "obvias": ("obvier",),
    "obviassent": ("obvier",),
    "obviasses": ("obvier",),
    "obviasse": ("obvier",),
    "obviassiez": ("obvier",),
    "obviassions": ("obvier",),
    "obviâtes": ("obvier",),
    "obviât": ("obvier",),
    "obvié": ("obvier",),
    "obvie": ("obvier",),
    "obviera": ("obvier",),
    "obvieraient": ("obvier",),
    "obvierai": ("obvier",),
    "obvierais": ("obvier",),
    "obvierait": ("obvier",),
    "obvieras": ("obvier",),
    "obvièrent": ("obvier",),
    "obvierez": ("obvier",),
    "obvieriez": ("obvier",),
    "obvierions": ("obvier",),
    "obvierons": ("obvier",),
    "obvieront": ("obvier",),
    "obvies": ("obvier",),
    "obviez": ("obvier",),
    "obviiez": ("obvier",),
    "obviions": ("obvier",),
    "obvions": ("obvier",),
    "occise": ("occire",),
    "occises": ("occire",),
    "occis": ("occire",),
    "occit": ("occire",),
    "occluaient": ("occlure",),
    "occluais": ("occlure",),
    "occluait": ("occlure",),
    "occluant": ("occlure",),
    "occluent": ("occlure",),
    "occlue": ("occlure",),
    "occlues": ("occlure",),
    "occluez": ("occlure",),
    "occluiez": ("occlure",),
    "occluions": ("occlure",),
    "occlûmes": ("occlure",),
    "occluons": ("occlure",),
    "occlura": ("occlure",),
    "occluraient": ("occlure",),
    "occlurai": ("occlure",),
    "occlurais": ("occlure",),
    "occlurait": ("occlure",),
    "occluras": ("occlure",),
    "occlurent": ("occlure",),
    "occlurez": ("occlure",),
    "occluriez": ("occlure",),
    "occlurions": ("occlure",),
    "occlurons": ("occlure",),
    "occluront": ("occlure",),
    "occluse": ("occlure",),
    "occluses": ("occlure",),
    "occlus": ("occlure",),
    "occlussent": ("occlure",),
    "occlusses": ("occlure",),
    "occlusse": ("occlure",),
    "occlussiez": ("occlure",),
    "occlussions": ("occlure",),
    "occlûtes": ("occlure",),
    "occlut": ("occlure",),
    "occlût": ("occlure",),
    "octaviaient": ("octavier",),
    "octaviai": ("octavier",),
    "octaviais": ("octavier",),
    "octaviait": ("octavier",),
    "octavia": ("octavier",),
    "octaviâmes": ("octavier",),
    "octaviant": ("octavier",),
    "octavias": ("octavier",),
    "octaviassent": ("octavier",),
    "octaviasses": ("octavier",),
    "octaviasse": ("octavier",),
    "octaviassiez": ("octavier",),
    "octaviassions": ("octavier",),
    "octaviâtes": ("octavier",),
    "octaviât": ("octavier",),
    "octaviée": ("octavier",),
    "octaviées": ("octavier",),
    "octavié": ("octavier",),
    "octavient": ("octavier",),
    "octavie": ("octavier",),
    "octaviera": ("octavier",),
    "octavieraient": ("octavier",),
    "octavierai": ("octavier",),
    "octavierais": ("octavier",),
    "octavierait": ("octavier",),
    "octavieras": ("octavier",),
    "octavièrent": ("octavier",),
    "octavierez": ("octavier",),
    "octavieriez": ("octavier",),
    "octavierions": ("octavier",),
    "octavierons": ("octavier",),
    "octavieront": ("octavier",),
    "octaviés": ("octavier",),
    "octavies": ("octavier",),
    "octaviez": ("octavier",),
    "octaviiez": ("octavier",),
    "octaviions": ("octavier",),
    "octavions": ("octavier",),
    "octroient": ("octroyer",),
    "octroie": ("octroyer",),
    "octroiera": ("octroyer",),
    "octroieraient": ("octroyer",),
    "octroierai": ("octroyer",),
    "octroierais": ("octroyer",),
    "octroierait": ("octroyer",),
    "octroieras": ("octroyer",),
    "octroierez": ("octroyer",),
    "octroieriez": ("octroyer",),
    "octroierions": ("octroyer",),
    "octroierons": ("octroyer",),
    "octroieront": ("octroyer",),
    "octroies": ("octroyer",),
    "octroyaient": ("octroyer",),
    "octroyai": ("octroyer",),
    "octroyais": ("octroyer",),
    "octroyait": ("octroyer",),
    "octroya": ("octroyer",),
    "octroyâmes": ("octroyer",),
    "octroyant": ("octroyer",),
    "octroyas": ("octroyer",),
    "octroyassent": ("octroyer",),
    "octroyasses": ("octroyer",),
    "octroyasse": ("octroyer",),
    "octroyassiez": ("octroyer",),
    "octroyassions": ("octroyer",),
    "octroyâtes": ("octroyer",),
    "octroyât": ("octroyer",),
    "octroyée": ("octroyer",),
    "octroyées": ("octroyer",),
    "octroyé": ("octroyer",),
    "octroyèrent": ("octroyer",),
    "octroyés": ("octroyer",),
    "octroyez": ("octroyer",),
    "octroyiez": ("octroyer",),
    "octroyions": ("octroyer",),
    "octroyons": ("octroyer",),
    "oedématiaient": ("oedématier",),
    "oedématiai": ("oedématier",),
    "oedématiais": ("oedématier",),
    "oedématiait": ("oedématier",),
    "oedématia": ("oedématier",),
    "oedématiâmes": ("oedématier",),
    "oedématiant": ("oedématier",),
    "oedématias": ("oedématier",),
    "oedématiassent": ("oedématier",),
    "oedématiasses": ("oedématier",),
    "oedématiasse": ("oedématier",),
    "oedématiassiez": ("oedématier",),
    "oedématiassions": ("oedématier",),
    "oedématiâtes": ("oedématier",),
    "oedématiât": ("oedématier",),
    "oedématiée": ("oedématier",),
    "oedématiées": ("oedématier",),
    "oedématié": ("oedématier",),
    "oedématient": ("oedématier",),
    "oedématie": ("oedématier",),
    "oedématiera": ("oedématier",),
    "oedématieraient": ("oedématier",),
    "oedématierai": ("oedématier",),
    "oedématierais": ("oedématier",),
    "oedématierait": ("oedématier",),
    "oedématieras": ("oedématier",),
    "oedématièrent": ("oedématier",),
    "oedématierez": ("oedématier",),
    "oedématieriez": ("oedématier",),
    "oedématierions": ("oedématier",),
    "oedématierons": ("oedématier",),
    "oedématieront": ("oedématier",),
    "oedématiés": ("oedématier",),
    "oedématies": ("oedématier",),
    "oedématiez": ("oedématier",),
    "oedématiiez": ("oedématier",),
    "oedématiions": ("oedématier",),
    "oedémations": ("oedématier",),
    "officiaient": ("officier",),
    "officiai": ("officier",),
    "officiais": ("officier",),
    "officiait": ("officier",),
    "officia": ("officier",),
    "officiâmes": ("officier",),
    "officiant": ("officier",),
    "officias": ("officier",),
    "officiassent": ("officier",),
    "officiasses": ("officier",),
    "officiasse": ("officier",),
    "officiassiez": ("officier",),
    "officiassions": ("officier",),
    "officiâtes": ("officier",),
    "officiât": ("officier",),
    "officié": ("officier",),
    "officient": ("officier",),
    "officie": ("officier",),
    "officiera": ("officier",),
    "officieraient": ("officier",),
    "officierai": ("officier",),
    "officierais": ("officier",),
    "officierait": ("officier",),
    "officieras": ("officier",),
    "officièrent": ("officier",),
    "officierez": ("officier",),
    "officieriez": ("officier",),
    "officierions": ("officier",),
    "officierons": ("officier",),
    "officieront": ("officier",),
    "officies": ("officier",),
    "officiez": ("officier",),
    "officiiez": ("officier",),
    "officiions": ("officier",),
    "officions": ("officier",),
    "offerte": ("offrir",),
    "offertes": ("offrir",),
    "offert": ("offrir",),
    "offerts": ("offrir",),
    "offraient": ("offrir",),
    "offrais": ("offrir",),
    "offrait": ("offrir",),
    "offrant": ("offrir",),
    "offrent": ("offrir",),
    "offre": ("offrir",),
    "offres": ("offrir",),
    "offrez": ("offrir",),
    "offriez": ("offrir",),
    "offrîmes": ("offrir",),
    "offrions": ("offrir",),
    "offrira": ("offrir",),
    "offriraient": ("offrir",),
    "offrirai": ("offrir",),
    "offrirais": ("offrir",),
    "offrirait": ("offrir",),
    "offriras": ("offrir",),
    "offrirent": ("offrir",),
    "offrirez": ("offrir",),
    "offririez": ("offrir",),
    "offririons": ("offrir",),
    "offrirons": ("offrir",),
    "offriront": ("offrir",),
    "offris": ("offrir",),
    "offrissent": ("offrir",),
    "offrisses": ("offrir",),
    "offrisse": ("offrir",),
    "offrissiez": ("offrir",),
    "offrissions": ("offrir",),
    "offrîtes": ("offrir",),
    "offrit": ("offrir",),
    "offrît": ("offrir",),
    "offrons": ("offrir",),
    "oignaient": ("oindre",),
    "oignais": ("oindre",),
    "oignait": ("oindre",),
    "oignant": ("oindre",),
    "oignent": ("oindre",),
    "oigne": ("oindre",),
    "oignes": ("oindre",),
    "oignez": ("oindre",),
    "oigniez": ("oindre",),
    "oignîmes": ("oindre",),
    "oignions": ("oindre",),
    "oignirent": ("oindre",),
    "oignis": ("oindre",),
    "oignissent": ("oindre",),
    "oignisses": ("oindre",),
    "oignisse": ("oindre",),
    "oignissiez": ("oindre",),
    "oignissions": ("oindre",),
    "oignîtes": ("oindre",),
    "oignit": ("oindre",),
    "oignît": ("oindre",),
    "oignons": ("oindre",),
    "oindra": ("oindre",),
    "oindraient": ("oindre",),
    "oindrai": ("oindre",),
    "oindrais": ("oindre",),
    "oindrait": ("oindre",),
    "oindras": ("oindre",),
    "oindrez": ("oindre",),
    "oindriez": ("oindre",),
    "oindrions": ("oindre",),
    "oindrons": ("oindre",),
    "oindront": ("oindre",),
    "oins": ("oindre",),
    "ointe": ("oindre",),
    "ointes": ("oindre",),
    "oint": ("oindre",),
    "oints": ("oindre",),
    "oiselaient": ("oiseler",),
    "oiselai": ("oiseler",),
    "oiselais": ("oiseler",),
    "oiselait": ("oiseler",),
    "oisela": ("oiseler",),
    "oiselâmes": ("oiseler",),
    "oiselant": ("oiseler",),
    "oiselas": ("oiseler",),
    "oiselassent": ("oiseler",),
    "oiselasses": ("oiseler",),
    "oiselasse": ("oiseler",),
    "oiselassiez": ("oiseler",),
    "oiselassions": ("oiseler",),
    "oiselâtes": ("oiseler",),
    "oiselât": ("oiseler",),
    "oiselé": ("oiseler",),
    "oiselèrent": ("oiseler",),
    "oiselez": ("oiseler",),
    "oiseliez": ("oiseler",),
    "oiselions": ("oiseler",),
    "oisellent": ("oiseler",),
    "oiselle": ("oiseler",),
    "oisellera": ("oiseler",),
    "oiselleraient": ("oiseler",),
    "oisellerai": ("oiseler",),
    "oisellerais": ("oiseler",),
    "oisellerait": ("oiseler",),
    "oiselleras": ("oiseler",),
    "oisellerez": ("oiseler",),
    "oiselleriez": ("oiseler",),
    "oisellerions": ("oiseler",),
    "oisellerons": ("oiseler",),
    "oiselleront": ("oiseler",),
    "oiselles": ("oiseler",),
    "oiselons": ("oiseler",),
    "olographiaient": ("olographier",),
    "olographiai": ("olographier",),
    "olographiais": ("olographier",),
    "olographiait": ("olographier",),
    "olographia": ("olographier",),
    "olographiâmes": ("olographier",),
    "olographiant": ("olographier",),
    "olographias": ("olographier",),
    "olographiassent": ("olographier",),
    "olographiasses": ("olographier",),
    "olographiasse": ("olographier",),
    "olographiassiez": ("olographier",),
    "olographiassions": ("olographier",),
    "olographiâtes": ("olographier",),
    "olographiât": ("olographier",),
    "olographiée": ("olographier",),
    "olographiées": ("olographier",),
    "olographié": ("olographier",),
    "olographient": ("olographier",),
    "olographie": ("olographier",),
    "olographiera": ("olographier",),
    "olographieraient": ("olographier",),
    "olographierai": ("olographier",),
    "olographierais": ("olographier",),
    "olographierait": ("olographier",),
    "olographieras": ("olographier",),
    "olographièrent": ("olographier",),
    "olographierez": ("olographier",),
    "olographieriez": ("olographier",),
    "olographierions": ("olographier",),
    "olographierons": ("olographier",),
    "olographieront": ("olographier",),
    "olographiés": ("olographier",),
    "olographies": ("olographier",),
    "olographiez": ("olographier",),
    "olographiiez": ("olographier",),
    "olographiions": ("olographier",),
    "olographions": ("olographier",),
    "ombrageaient": ("ombrager",),
    "ombrageai": ("ombrager",),
    "ombrageais": ("ombrager",),
    "ombrageait": ("ombrager",),
    "ombragea": ("ombrager",),
    "ombrageâmes": ("ombrager",),
    "ombrageant": ("ombrager",),
    "ombrageas": ("ombrager",),
    "ombrageassent": ("ombrager",),
    "ombrageasses": ("ombrager",),
    "ombrageasse": ("ombrager",),
    "ombrageassiez": ("ombrager",),
    "ombrageassions": ("ombrager",),
    "ombrageâtes": ("ombrager",),
    "ombrageât": ("ombrager",),
    "ombragée": ("ombrager",),
    "ombragées": ("ombrager",),
    "ombragé": ("ombrager",),
    "ombragent": ("ombrager",),
    "ombrageons": ("ombrager",),
    "ombrage": ("ombrager",),
    "ombragera": ("ombrager",),
    "ombrageraient": ("ombrager",),
    "ombragerai": ("ombrager",),
    "ombragerais": ("ombrager",),
    "ombragerait": ("ombrager",),
    "ombrageras": ("ombrager",),
    "ombragèrent": ("ombrager",),
    "ombragerez": ("ombrager",),
    "ombrageriez": ("ombrager",),
    "ombragerions": ("ombrager",),
    "ombragerons": ("ombrager",),
    "ombrageront": ("ombrager",),
    "ombragés": ("ombrager",),
    "ombrages": ("ombrager",),
    "ombragez": ("ombrager",),
    "ombragiez": ("ombrager",),
    "ombragions": ("ombrager",),
    "omet": ("omettre",),
    "omets": ("omettre",),
    "omettaient": ("omettre",),
    "omettais": ("omettre",),
    "omettait": ("omettre",),
    "omettant": ("omettre",),
    "omettent": ("omettre",),
    "omette": ("omettre",),
    "omettes": ("omettre",),
    "omettez": ("omettre",),
    "omettiez": ("omettre",),
    "omettions": ("omettre",),
    "omettons": ("omettre",),
    "omettra": ("omettre",),
    "omettraient": ("omettre",),
    "omettrai": ("omettre",),
    "omettrais": ("omettre",),
    "omettrait": ("omettre",),
    "omettras": ("omettre",),
    "omettrez": ("omettre",),
    "omettriez": ("omettre",),
    "omettrions": ("omettre",),
    "omettrons": ("omettre",),
    "omettront": ("omettre",),
    "omîmes": ("omettre",),
    "omirent": ("omettre",),
    "omise": ("omettre",),
    "omises": ("omettre",),
    "omis": ("omettre",),
    "omissent": ("omettre",),
    "omisses": ("omettre",),
    "omisse": ("omettre",),
    "omissiez": ("omettre",),
    "omissions": ("omettre",),
    "omîtes": ("omettre",),
    "omit": ("omettre",),
    "omît": ("omettre",),
    "ondoient": ("ondoyer",),
    "ondoie": ("ondoyer",),
    "ondoiera": ("ondoyer",),
    "ondoieraient": ("ondoyer",),
    "ondoierai": ("ondoyer",),
    "ondoierais": ("ondoyer",),
    "ondoierait": ("ondoyer",),
    "ondoieras": ("ondoyer",),
    "ondoierez": ("ondoyer",),
    "ondoieriez": ("ondoyer",),
    "ondoierions": ("ondoyer",),
    "ondoierons": ("ondoyer",),
    "ondoieront": ("ondoyer",),
    "ondoies": ("ondoyer",),
    "ondoyaient": ("ondoyer",),
    "ondoyai": ("ondoyer",),
    "ondoyais": ("ondoyer",),
    "ondoyait": ("ondoyer",),
    "ondoya": ("ondoyer",),
    "ondoyâmes": ("ondoyer",),
    "ondoyant": ("ondoyer",),
    "ondoyas": ("ondoyer",),
    "ondoyassent": ("ondoyer",),
    "ondoyasses": ("ondoyer",),
    "ondoyasse": ("ondoyer",),
    "ondoyassiez": ("ondoyer",),
    "ondoyassions": ("ondoyer",),
    "ondoyâtes": ("ondoyer",),
    "ondoyât": ("ondoyer",),
    "ondoyée": ("ondoyer",),
    "ondoyées": ("ondoyer",),
    "ondoyé": ("ondoyer",),
    "ondoyèrent": ("ondoyer",),
    "ondoyés": ("ondoyer",),
    "ondoyez": ("ondoyer",),
    "ondoyiez": ("ondoyer",),
    "ondoyions": ("ondoyer",),
    "ondoyons": ("ondoyer",),
    "opacifiaient": ("opacifier",),
    "opacifiai": ("opacifier",),
    "opacifiais": ("opacifier",),
    "opacifiait": ("opacifier",),
    "opacifia": ("opacifier",),
    "opacifiâmes": ("opacifier",),
    "opacifiant": ("opacifier",),
    "opacifias": ("opacifier",),
    "opacifiassent": ("opacifier",),
    "opacifiasses": ("opacifier",),
    "opacifiasse": ("opacifier",),
    "opacifiassiez": ("opacifier",),
    "opacifiassions": ("opacifier",),
    "opacifiâtes": ("opacifier",),
    "opacifiât": ("opacifier",),
    "opacifiée": ("opacifier",),
    "opacifiées": ("opacifier",),
    "opacifié": ("opacifier",),
    "opacifient": ("opacifier",),
    "opacifie": ("opacifier",),
    "opacifiera": ("opacifier",),
    "opacifieraient": ("opacifier",),
    "opacifierai": ("opacifier",),
    "opacifierais": ("opacifier",),
    "opacifierait": ("opacifier",),
    "opacifieras": ("opacifier",),
    "opacifièrent": ("opacifier",),
    "opacifierez": ("opacifier",),
    "opacifieriez": ("opacifier",),
    "opacifierions": ("opacifier",),
    "opacifierons": ("opacifier",),
    "opacifieront": ("opacifier",),
    "opacifiés": ("opacifier",),
    "opacifies": ("opacifier",),
    "opacifiez": ("opacifier",),
    "opacifiiez": ("opacifier",),
    "opacifiions": ("opacifier",),
    "opacifions": ("opacifier",),
    "opéraient": ("opérer",),
    "opérai": ("opérer",),
    "opérais": ("opérer",),
    "opérait": ("opérer",),
    "opéra": ("opérer",),
    "opérâmes": ("opérer",),
    "opérant": ("opérer",),
    "opéras": ("opérer",),
    "opérassent": ("opérer",),
    "opérasses": ("opérer",),
    "opérasse": ("opérer",),
    "opérassiez": ("opérer",),
    "opérassions": ("opérer",),
    "opérâtes": ("opérer",),
    "opérât": ("opérer",),
    "opérée": ("opérer",),
    "opérées": ("opérer",),
    "opéré": ("opérer",),
    "opèrent": ("opérer",),
    "opère": ("opérer",),
    "opérera": ("opérer",),
    "opéreraient": ("opérer",),
    "opérerai": ("opérer",),
    "opérerais": ("opérer",),
    "opérerait": ("opérer",),
    "opéreras": ("opérer",),
    "opérèrent": ("opérer",),
    "opérerez": ("opérer",),
    "opéreriez": ("opérer",),
    "opérerions": ("opérer",),
    "opérerons": ("opérer",),
    "opéreront": ("opérer",),
    "opérés": ("opérer",),
    "opères": ("opérer",),
    "opérez": ("opérer",),
    "opériez": ("opérer",),
    "opérions": ("opérer",),
    "opérons": ("opérer",),
    "opiaçaient": ("opiacer",),
    "opiaçai": ("opiacer",),
    "opiaçais": ("opiacer",),
    "opiaçait": ("opiacer",),
    "opiaça": ("opiacer",),
    "opiaçâmes": ("opiacer",),
    "opiaçant": ("opiacer",),
    "opiaças": ("opiacer",),
    "opiaçassent": ("opiacer",),
    "opiaçasses": ("opiacer",),
    "opiaçasse": ("opiacer",),
    "opiaçassiez": ("opiacer",),
    "opiaçassions": ("opiacer",),
    "opiaçâtes": ("opiacer",),
    "opiaçât": ("opiacer",),
    "opiacée": ("opiacer",),
    "opiacées": ("opiacer",),
    "opiacé": ("opiacer",),
    "opiacent": ("opiacer",),
    "opiace": ("opiacer",),
    "opiacera": ("opiacer",),
    "opiaceraient": ("opiacer",),
    "opiacerai": ("opiacer",),
    "opiacerais": ("opiacer",),
    "opiacerait": ("opiacer",),
    "opiaceras": ("opiacer",),
    "opiacèrent": ("opiacer",),
    "opiacerez": ("opiacer",),
    "opiaceriez": ("opiacer",),
    "opiacerions": ("opiacer",),
    "opiacerons": ("opiacer",),
    "opiaceront": ("opiacer",),
    "opiacés": ("opiacer",),
    "opiaces": ("opiacer",),
    "opiacez": ("opiacer",),
    "opiaciez": ("opiacer",),
    "opiacions": ("opiacer",),
    "opiaçons": ("opiacer",),
    "orangeaient": ("oranger",),
    "orangeai": ("oranger",),
    "orangeais": ("oranger",),
    "orangeait": ("oranger",),
    "orangea": ("oranger",),
    "orangeâmes": ("oranger",),
    "orangeant": ("oranger",),
    "orangeas": ("oranger",),
    "orangeassent": ("oranger",),
    "orangeasses": ("oranger",),
    "orangeasse": ("oranger",),
    "orangeassiez": ("oranger",),
    "orangeassions": ("oranger",),
    "orangeâtes": ("oranger",),
    "orangeât": ("oranger",),
    "orangée": ("oranger",),
    "orangées": ("oranger",),
    "orangé": ("oranger",),
    "orangent": ("oranger",),
    "orangeons": ("oranger",),
    "orange": ("oranger",),
    "orangera": ("oranger",),
    "orangeraient": ("oranger",),
    "orangerai": ("oranger",),
    "orangerais": ("oranger",),
    "orangerait": ("oranger",),
    "orangeras": ("oranger",),
    "orangèrent": ("oranger",),
    "orangerez": ("oranger",),
    "orangeriez": ("oranger",),
    "orangerions": ("oranger",),
    "orangerons": ("oranger",),
    "orangeront": ("oranger",),
    "orangés": ("oranger",),
    "oranges": ("oranger",),
    "orangez": ("oranger",),
    "orangiez": ("oranger",),
    "orangions": ("oranger",),
    "ordonnançaient": ("ordonnancer",),
    "ordonnançai": ("ordonnancer",),
    "ordonnançais": ("ordonnancer",),
    "ordonnançait": ("ordonnancer",),
    "ordonnança": ("ordonnancer",),
    "ordonnançâmes": ("ordonnancer",),
    "ordonnançant": ("ordonnancer",),
    "ordonnanças": ("ordonnancer",),
    "ordonnançassent": ("ordonnancer",),
    "ordonnançasses": ("ordonnancer",),
    "ordonnançasse": ("ordonnancer",),
    "ordonnançassiez": ("ordonnancer",),
    "ordonnançassions": ("ordonnancer",),
    "ordonnançâtes": ("ordonnancer",),
    "ordonnançât": ("ordonnancer",),
    "ordonnancée": ("ordonnancer",),
    "ordonnancées": ("ordonnancer",),
    "ordonnancé": ("ordonnancer",),
    "ordonnancent": ("ordonnancer",),
    "ordonnance": ("ordonnancer",),
    "ordonnancera": ("ordonnancer",),
    "ordonnanceraient": ("ordonnancer",),
    "ordonnancerai": ("ordonnancer",),
    "ordonnancerais": ("ordonnancer",),
    "ordonnancerait": ("ordonnancer",),
    "ordonnanceras": ("ordonnancer",),
    "ordonnancèrent": ("ordonnancer",),
    "ordonnancerez": ("ordonnancer",),
    "ordonnanceriez": ("ordonnancer",),
    "ordonnancerions": ("ordonnancer",),
    "ordonnancerons": ("ordonnancer",),
    "ordonnanceront": ("ordonnancer",),
    "ordonnancés": ("ordonnancer",),
    "ordonnances": ("ordonnancer",),
    "ordonnancez": ("ordonnancer",),
    "ordonnanciez": ("ordonnancer",),
    "ordonnancions": ("ordonnancer",),
    "ordonnançons": ("ordonnancer",),
    "orfévraient": ("orfévrer",),
    "orfévrai": ("orfévrer",),
    "orfévrais": ("orfévrer",),
    "orfévrait": ("orfévrer",),
    "orfévra": ("orfévrer",),
    "orfévrâmes": ("orfévrer",),
    "orfévrant": ("orfévrer",),
    "orfévras": ("orfévrer",),
    "orfévrassent": ("orfévrer",),
    "orfévrasses": ("orfévrer",),
    "orfévrasse": ("orfévrer",),
    "orfévrassiez": ("orfévrer",),
    "orfévrassions": ("orfévrer",),
    "orfévrâtes": ("orfévrer",),
    "orfévrât": ("orfévrer",),
    "orfévrée": ("orfévrer",),
    "orfévrées": ("orfévrer",),
    "orfévré": ("orfévrer",),
    "orfèvrent": ("orfévrer",),
    "orfèvre": ("orfévrer",),
    "orfévrera": ("orfévrer",),
    "orfévreraient": ("orfévrer",),
    "orfévrerai": ("orfévrer",),
    "orfévrerais": ("orfévrer",),
    "orfévrerait": ("orfévrer",),
    "orfévreras": ("orfévrer",),
    "orfévrèrent": ("orfévrer",),
    "orfévrerez": ("orfévrer",),
    "orfévreriez": ("orfévrer",),
    "orfévrerions": ("orfévrer",),
    "orfévrerons": ("orfévrer",),
    "orfévreront": ("orfévrer",),
    "orfévrés": ("orfévrer",),
    "orfèvres": ("orfévrer",),
    "orfévrez": ("orfévrer",),
    "orfévriez": ("orfévrer",),
    "orfévrions": ("orfévrer",),
    "orfévrons": ("orfévrer",),
    "organifiaient": ("organifier",),
    "organifiai": ("organifier",),
    "organifiais": ("organifier",),
    "organifiait": ("organifier",),
    "organifia": ("organifier",),
    "organifiâmes": ("organifier",),
    "organifiant": ("organifier",),
    "organifias": ("organifier",),
    "organifiassent": ("organifier",),
    "organifiasses": ("organifier",),
    "organifiasse": ("organifier",),
    "organifiassiez": ("organifier",),
    "organifiassions": ("organifier",),
    "organifiâtes": ("organifier",),
    "organifiât": ("organifier",),
    "organifiée": ("organifier",),
    "organifiées": ("organifier",),
    "organifié": ("organifier",),
    "organifient": ("organifier",),
    "organifie": ("organifier",),
    "organifiera": ("organifier",),
    "organifieraient": ("organifier",),
    "organifierai": ("organifier",),
    "organifierais": ("organifier",),
    "organifierait": ("organifier",),
    "organifieras": ("organifier",),
    "organifièrent": ("organifier",),
    "organifierez": ("organifier",),
    "organifieriez": ("organifier",),
    "organifierions": ("organifier",),
    "organifierons": ("organifier",),
    "organifieront": ("organifier",),
    "organifiés": ("organifier",),
    "organifies": ("organifier",),
    "organifiez": ("organifier",),
    "organifiiez": ("organifier",),
    "organifiions": ("organifier",),
    "organifions": ("organifier",),
    "orniéraient": ("orniérer",),
    "orniérai": ("orniérer",),
    "orniérais": ("orniérer",),
    "orniérait": ("orniérer",),
    "orniéra": ("orniérer",),
    "orniérâmes": ("orniérer",),
    "orniérant": ("orniérer",),
    "orniéras": ("orniérer",),
    "orniérassent": ("orniérer",),
    "orniérasses": ("orniérer",),
    "orniérasse": ("orniérer",),
    "orniérassiez": ("orniérer",),
    "orniérassions": ("orniérer",),
    "orniérâtes": ("orniérer",),
    "orniérât": ("orniérer",),
    "orniérée": ("orniérer",),
    "orniérées": ("orniérer",),
    "orniéré": ("orniérer",),
    "ornièrent": ("orniérer",),
    "ornière": ("orniérer",),
    "orniérera": ("orniérer",),
    "orniéreraient": ("orniérer",),
    "orniérerai": ("orniérer",),
    "orniérerais": ("orniérer",),
    "orniérerait": ("orniérer",),
    "orniéreras": ("orniérer",),
    "orniérèrent": ("orniérer",),
    "orniérerez": ("orniérer",),
    "orniéreriez": ("orniérer",),
    "orniérerions": ("orniérer",),
    "orniérerons": ("orniérer",),
    "orniéreront": ("orniérer",),
    "orniérés": ("orniérer",),
    "ornières": ("orniérer",),
    "orniérez": ("orniérer",),
    "orniériez": ("orniérer",),
    "orniérions": ("orniérer",),
    "orniérons": ("orniérer",),
    "orthographiaient": ("orthographier",),
    "orthographiai": ("orthographier",),
    "orthographiais": ("orthographier",),
    "orthographiait": ("orthographier",),
    "orthographia": ("orthographier",),
    "orthographiâmes": ("orthographier",),
    "orthographiant": ("orthographier",),
    "orthographias": ("orthographier",),
    "orthographiassent": ("orthographier",),
    "orthographiasses": ("orthographier",),
    "orthographiasse": ("orthographier",),
    "orthographiassiez": ("orthographier",),
    "orthographiassions": ("orthographier",),
    "orthographiâtes": ("orthographier",),
    "orthographiât": ("orthographier",),
    "orthographiée": ("orthographier",),
    "orthographiées": ("orthographier",),
    "orthographié": ("orthographier",),
    "orthographient": ("orthographier",),
    "orthographie": ("orthographier",),
    "orthographiera": ("orthographier",),
    "orthographieraient": ("orthographier",),
    "orthographierai": ("orthographier",),
    "orthographierais": ("orthographier",),
    "orthographierait": ("orthographier",),
    "orthographieras": ("orthographier",),
    "orthographièrent": ("orthographier",),
    "orthographierez": ("orthographier",),
    "orthographieriez": ("orthographier",),
    "orthographierions": ("orthographier",),
    "orthographierons": ("orthographier",),
    "orthographieront": ("orthographier",),
    "orthographiés": ("orthographier",),
    "orthographies": ("orthographier",),
    "orthographiez": ("orthographier",),
    "orthographiiez": ("orthographier",),
    "orthographiions": ("orthographier",),
    "orthographions": ("orthographier",),
    "ortiaient": ("ortier",),
    "ortiai": ("ortier",),
    "ortiais": ("ortier",),
    "ortiait": ("ortier",),
    "ortia": ("ortier",),
    "ortiâmes": ("ortier",),
    "ortiant": ("ortier",),
    "ortias": ("ortier",),
    "ortiassent": ("ortier",),
    "ortiasses": ("ortier",),
    "ortiasse": ("ortier",),
    "ortiassiez": ("ortier",),
    "ortiassions": ("ortier",),
    "ortiâtes": ("ortier",),
    "ortiât": ("ortier",),
    "ortiée": ("ortier",),
    "ortiées": ("ortier",),
    "ortié": ("ortier",),
    "ortient": ("ortier",),
    "ortie": ("ortier",),
    "ortiera": ("ortier",),
    "ortieraient": ("ortier",),
    "ortierai": ("ortier",),
    "ortierais": ("ortier",),
    "ortierait": ("ortier",),
    "ortieras": ("ortier",),
    "ortièrent": ("ortier",),
    "ortierez": ("ortier",),
    "ortieriez": ("ortier",),
    "ortierions": ("ortier",),
    "ortierons": ("ortier",),
    "ortieront": ("ortier",),
    "ortiés": ("ortier",),
    "orties": ("ortier",),
    "ortiez": ("ortier",),
    "ortiiez": ("ortier",),
    "ortiions": ("ortier",),
    "ortions": ("ortier",),
    "ossifiaient": ("ossifier",),
    "ossifiai": ("ossifier",),
    "ossifiais": ("ossifier",),
    "ossifiait": ("ossifier",),
    "ossifia": ("ossifier",),
    "ossifiâmes": ("ossifier",),
    "ossifiant": ("ossifier",),
    "ossifias": ("ossifier",),
    "ossifiassent": ("ossifier",),
    "ossifiasses": ("ossifier",),
    "ossifiasse": ("ossifier",),
    "ossifiassiez": ("ossifier",),
    "ossifiassions": ("ossifier",),
    "ossifiâtes": ("ossifier",),
    "ossifiât": ("ossifier",),
    "ossifiée": ("ossifier",),
    "ossifiées": ("ossifier",),
    "ossifié": ("ossifier",),
    "ossifient": ("ossifier",),
    "ossifie": ("ossifier",),
    "ossifiera": ("ossifier",),
    "ossifieraient": ("ossifier",),
    "ossifierai": ("ossifier",),
    "ossifierais": ("ossifier",),
    "ossifierait": ("ossifier",),
    "ossifieras": ("ossifier",),
    "ossifièrent": ("ossifier",),
    "ossifierez": ("ossifier",),
    "ossifieriez": ("ossifier",),
    "ossifierions": ("ossifier",),
    "ossifierons": ("ossifier",),
    "ossifieront": ("ossifier",),
    "ossifiés": ("ossifier",),
    "ossifies": ("ossifier",),
    "ossifiez": ("ossifier",),
    "ossifiiez": ("ossifier",),
    "ossifiions": ("ossifier",),
    "ossifions": ("ossifier",),
    "oubliaient": ("oublier",),
    "oubliai": ("oublier",),
    "oubliais": ("oublier",),
    "oubliait": ("oublier",),
    "oublia": ("oublier",),
    "oubliâmes": ("oublier",),
    "oubliant": ("oublier",),
    "oublias": ("oublier",),
    "oubliassent": ("oublier",),
    "oubliasses": ("oublier",),
    "oubliasse": ("oublier",),
    "oubliassiez": ("oublier",),
    "oubliassions": ("oublier",),
    "oubliâtes": ("oublier",),
    "oubliât": ("oublier",),
    "oubliée": ("oublier",),
    "oubliées": ("oublier",),
    "oublié": ("oublier",),
    "oublient": ("oublier",),
    "oublie": ("oublier",),
    "oubliera": ("oublier",),
    "oublieraient": ("oublier",),
    "oublierai": ("oublier",),
    "oublierais": ("oublier",),
    "oublierait": ("oublier",),
    "oublieras": ("oublier",),
    "oublièrent": ("oublier",),
    "oublierez": ("oublier",),
    "oublieriez": ("oublier",),
    "oublierions": ("oublier",),
    "oublierons": ("oublier",),
    "oublieront": ("oublier",),
    "oubliés": ("oublier",),
    "oublies": ("oublier",),
    "oubliez": ("oublier",),
    "oubliiez": ("oublier",),
    "oubliions": ("oublier",),
    "oublions": ("oublier",),
    "ouestie": ("ouestir",),
    "ouesties": ("ouestir",),
    "ouesti": ("ouestir",),
    "ouestîmes": ("ouestir",),
    "ouestira": ("ouestir",),
    "ouestiraient": ("ouestir",),
    "ouestirai": ("ouestir",),
    "ouestirais": ("ouestir",),
    "ouestirait": ("ouestir",),
    "ouestiras": ("ouestir",),
    "ouestirent": ("ouestir",),
    "ouestirez": ("ouestir",),
    "ouestiriez": ("ouestir",),
    "ouestirions": ("ouestir",),
    "ouestirons": ("ouestir",),
    "ouestiront": ("ouestir",),
    "ouestis": ("ouestir",),
    "ouestissaient": ("ouestir",),
    "ouestissais": ("ouestir",),
    "ouestissait": ("ouestir",),
    "ouestissant": ("ouestir",),
    "ouestissent": ("ouestir",),
    "ouestisse": ("ouestir",),
    "ouestisses": ("ouestir",),
    "ouestissez": ("ouestir",),
    "ouestissiez": ("ouestir",),
    "ouestissions": ("ouestir",),
    "ouestissons": ("ouestir",),
    "ouestîtes": ("ouestir",),
    "ouestit": ("ouestir",),
    "ouestît": ("ouestir",),
    "oient": ("ouïr",),
    "oie": ("ouïr",),
    "oies": ("ouïr",),
    "ois": ("ouïr",),
    "oit": ("ouïr",),
    "orra": ("ouïr",),
    "orraient": ("ouïr",),
    "orrai": ("ouïr",),
    "orrais": ("ouïr",),
    "orrait": ("ouïr",),
    "orras": ("ouïr",),
    "orrez": ("ouïr",),
    "orriez": ("ouïr",),
    "orrions": ("ouïr",),
    "orrons": ("ouïr",),
    "orront": ("ouïr",),
    "ouïe": ("ouïr",),
    "ouïes": ("ouïr",),
    "ouï": ("ouïr",),
    "ouïmes": ("ouïr",),
    "ouïra": ("ouïr",),
    "ouïraient": ("ouïr",),
    "ouïrai": ("ouïr",),
    "ouïrais": ("ouïr",),
    "ouïrait": ("ouïr",),
    "ouïras": ("ouïr",),
    "ouïrent": ("ouïr",),
    "ouïrez": ("ouïr",),
    "ouïriez": ("ouïr",),
    "ouïrions": ("ouïr",),
    "ouïrons": ("ouïr",),
    "ouïront": ("ouïr",),
    "ouïs": ("ouïr",),
    "ouïssaient": ("ouïr",),
    "ouïssais": ("ouïr",),
    "ouïssait": ("ouïr",),
    "ouïssent": ("ouïr",),
    "ouïsse": ("ouïr",),
    "ouïsses": ("ouïr",),
    "ouïssez": ("ouïr",),
    "ouïssiez": ("ouïr",),
    "ouïssions": ("ouïr",),
    "ouïssons": ("ouïr",),
    "ouïtes": ("ouïr",),
    "ouït": ("ouïr",),
    "oyaient": ("ouïr",),
    "oyais": ("ouïr",),
    "oyait": ("ouïr",),
    "oyant": ("ouïr",),
    "oyez": ("ouïr",),
    "oyiez": ("ouïr",),
    "oyions": ("ouïr",),
    "oyons": ("ouïr",),
    "ourdie": ("ourdir",),
    "ourdies": ("ourdir",),
    "ourdi": ("ourdir",),
    "ourdîmes": ("ourdir",),
    "ourdira": ("ourdir",),
    "ourdiraient": ("ourdir",),
    "ourdirai": ("ourdir",),
    "ourdirais": ("ourdir",),
    "ourdirait": ("ourdir",),
    "ourdiras": ("ourdir",),
    "ourdirent": ("ourdir",),
    "ourdirez": ("ourdir",),
    "ourdiriez": ("ourdir",),
    "ourdirions": ("ourdir",),
    "ourdirons": ("ourdir",),
    "ourdiront": ("ourdir",),
    "ourdis": ("ourdir",),
    "ourdissaient": ("ourdir",),
    "ourdissais": ("ourdir",),
    "ourdissait": ("ourdir",),
    "ourdissant": ("ourdir",),
    "ourdissent": ("ourdir",),
    "ourdisse": ("ourdir",),
    "ourdisses": ("ourdir",),
    "ourdissez": ("ourdir",),
    "ourdissiez": ("ourdir",),
    "ourdissions": ("ourdir",),
    "ourdissons": ("ourdir",),
    "ourdîtes": ("ourdir",),
    "ourdit": ("ourdir",),
    "ourdît": ("ourdir",),
    "outrageaient": ("outrager",),
    "outrageai": ("outrager",),
    "outrageais": ("outrager",),
    "outrageait": ("outrager",),
    "outragea": ("outrager",),
    "outrageâmes": ("outrager",),
    "outrageant": ("outrager",),
    "outrageas": ("outrager",),
    "outrageassent": ("outrager",),
    "outrageasses": ("outrager",),
    "outrageasse": ("outrager",),
    "outrageassiez": ("outrager",),
    "outrageassions": ("outrager",),
    "outrageâtes": ("outrager",),
    "outrageât": ("outrager",),
    "outragée": ("outrager",),
    "outragées": ("outrager",),
    "outragé": ("outrager",),
    "outragent": ("outrager",),
    "outrageons": ("outrager",),
    "outrage": ("outrager",),
    "outragera": ("outrager",),
    "outrageraient": ("outrager",),
    "outragerai": ("outrager",),
    "outragerais": ("outrager",),
    "outragerait": ("outrager",),
    "outrageras": ("outrager",),
    "outragèrent": ("outrager",),
    "outragerez": ("outrager",),
    "outrageriez": ("outrager",),
    "outragerions": ("outrager",),
    "outragerons": ("outrager",),
    "outrageront": ("outrager",),
    "outragés": ("outrager",),
    "outrages": ("outrager",),
    "outragez": ("outrager",),
    "outragiez": ("outrager",),
    "outragions": ("outrager",),
    "outrepassaient": ("outrepasser",),
    "outrepassai": ("outrepasser",),
    "outrepassais": ("outrepasser",),
    "outrepassait": ("outrepasser",),
    "outrepassa": ("outrepasser",),
    "outrepassâmes": ("outrepasser",),
    "outrepassant": ("outrepasser",),
    "outrepassas": ("outrepasser",),
    "outrepassassent": ("outrepasser",),
    "outrepassasses": ("outrepasser",),
    "outrepassasse": ("outrepasser",),
    "outrepassassiez": ("outrepasser",),
    "outrepassassions": ("outrepasser",),
    "outrepassâtes": ("outrepasser",),
    "outrepassât": ("outrepasser",),
    "outrepassée": ("outrepasser",),
    "outrepassées": ("outrepasser",),
    "outrepassé": ("outrepasser",),
    "outrepassent": ("outrepasser",),
    "outrepasse": ("outrepasser",),
    "outrepassera": ("outrepasser",),
    "outrepasseraient": ("outrepasser",),
    "outrepasserai": ("outrepasser",),
    "outrepasserais": ("outrepasser",),
    "outrepasserait": ("outrepasser",),
    "outrepasseras": ("outrepasser",),
    "outrepassèrent": ("outrepasser",),
    "outrepasserez": ("outrepasser",),
    "outrepasseriez": ("outrepasser",),
    "outrepasserions": ("outrepasser",),
    "outrepasserons": ("outrepasser",),
    "outrepasseront": ("outrepasser",),
    "outrepassés": ("outrepasser",),
    "outrepasses": ("outrepasser",),
    "outrepassez": ("outrepasser",),
    "outrepassiez": ("outrepasser",),
    "outrepassions": ("outrepasser",),
    "outrepassons": ("outrepasser",),
    "ouvrageaient": ("ouvrager",),
    "ouvrageai": ("ouvrager",),
    "ouvrageais": ("ouvrager",),
    "ouvrageait": ("ouvrager",),
    "ouvragea": ("ouvrager",),
    "ouvrageâmes": ("ouvrager",),
    "ouvrageant": ("ouvrager",),
    "ouvrageas": ("ouvrager",),
    "ouvrageassent": ("ouvrager",),
    "ouvrageasses": ("ouvrager",),
    "ouvrageasse": ("ouvrager",),
    "ouvrageassiez": ("ouvrager",),
    "ouvrageassions": ("ouvrager",),
    "ouvrageâtes": ("ouvrager",),
    "ouvrageât": ("ouvrager",),
    "ouvragée": ("ouvrager",),
    "ouvragées": ("ouvrager",),
    "ouvragé": ("ouvrager",),
    "ouvragent": ("ouvrager",),
    "ouvrageons": ("ouvrager",),
    "ouvrage": ("ouvrager",),
    "ouvragera": ("ouvrager",),
    "ouvrageraient": ("ouvrager",),
    "ouvragerai": ("ouvrager",),
    "ouvragerais": ("ouvrager",),
    "ouvragerait": ("ouvrager",),
    "ouvrageras": ("ouvrager",),
    "ouvragèrent": ("ouvrager",),
    "ouvragerez": ("ouvrager",),
    "ouvrageriez": ("ouvrager",),
    "ouvragerions": ("ouvrager",),
    "ouvragerons": ("ouvrager",),
    "ouvrageront": ("ouvrager",),
    "ouvragés": ("ouvrager",),
    "ouvrages": ("ouvrager",),
    "ouvragez": ("ouvrager",),
    "ouvragiez": ("ouvrager",),
    "ouvragions": ("ouvrager",),
    "ouverte": ("ouvrir",),
    "ouvertes": ("ouvrir",),
    "ouvert": ("ouvrir",),
    "ouverts": ("ouvrir",),
    "ouvraient": ("ouvrir",),
    "ouvrais": ("ouvrir",),
    "ouvrait": ("ouvrir",),
    "ouvrant": ("ouvrir",),
    "ouvrent": ("ouvrir",),
    "ouvre": ("ouvrir",),
    "ouvres": ("ouvrir",),
    "ouvrez": ("ouvrir",),
    "ouvriez": ("ouvrir",),
    "ouvrîmes": ("ouvrir",),
    "ouvrions": ("ouvrir",),
    "ouvrira": ("ouvrir",),
    "ouvriraient": ("ouvrir",),
    "ouvrirai": ("ouvrir",),
    "ouvrirais": ("ouvrir",),
    "ouvrirait": ("ouvrir",),
    "ouvriras": ("ouvrir",),
    "ouvrirent": ("ouvrir",),
    "ouvrirez": ("ouvrir",),
    "ouvririez": ("ouvrir",),
    "ouvririons": ("ouvrir",),
    "ouvrirons": ("ouvrir",),
    "ouvriront": ("ouvrir",),
    "ouvris": ("ouvrir",),
    "ouvrissent": ("ouvrir",),
    "ouvrisses": ("ouvrir",),
    "ouvrisse": ("ouvrir",),
    "ouvrissiez": ("ouvrir",),
    "ouvrissions": ("ouvrir",),
    "ouvrîtes": ("ouvrir",),
    "ouvrit": ("ouvrir",),
    "ouvrît": ("ouvrir",),
    "ouvrons": ("ouvrir",),
    "oxygénaient": ("oxygéner",),
    "oxygénai": ("oxygéner",),
    "oxygénais": ("oxygéner",),
    "oxygénait": ("oxygéner",),
    "oxygéna": ("oxygéner",),
    "oxygénâmes": ("oxygéner",),
    "oxygénant": ("oxygéner",),
    "oxygénas": ("oxygéner",),
    "oxygénassent": ("oxygéner",),
    "oxygénasses": ("oxygéner",),
    "oxygénasse": ("oxygéner",),
    "oxygénassiez": ("oxygéner",),
    "oxygénassions": ("oxygéner",),
    "oxygénâtes": ("oxygéner",),
    "oxygénât": ("oxygéner",),
    "oxygénée": ("oxygéner",),
    "oxygénées": ("oxygéner",),
    "oxygéné": ("oxygéner",),
    "oxygènent": ("oxygéner",),
    "oxygène": ("oxygéner",),
    "oxygénera": ("oxygéner",),
    "oxygéneraient": ("oxygéner",),
    "oxygénerai": ("oxygéner",),
    "oxygénerais": ("oxygéner",),
    "oxygénerait": ("oxygéner",),
    "oxygéneras": ("oxygéner",),
    "oxygénèrent": ("oxygéner",),
    "oxygénerez": ("oxygéner",),
    "oxygéneriez": ("oxygéner",),
    "oxygénerions": ("oxygéner",),
    "oxygénerons": ("oxygéner",),
    "oxygéneront": ("oxygéner",),
    "oxygénés": ("oxygéner",),
    "oxygènes": ("oxygéner",),
    "oxygénez": ("oxygéner",),
    "oxygéniez": ("oxygéner",),
    "oxygénions": ("oxygéner",),
    "oxygénons": ("oxygéner",),
    "pacageaient": ("pacager",),
    "pacageai": ("pacager",),
    "pacageais": ("pacager",),
    "pacageait": ("pacager",),
    "pacagea": ("pacager",),
    "pacageâmes": ("pacager",),
    "pacageant": ("pacager",),
    "pacageas": ("pacager",),
    "pacageassent": ("pacager",),
    "pacageasses": ("pacager",),
    "pacageasse": ("pacager",),
    "pacageassiez": ("pacager",),
    "pacageassions": ("pacager",),
    "pacageâtes": ("pacager",),
    "pacageât": ("pacager",),
    "pacagée": ("pacager",),
    "pacagées": ("pacager",),
    "pacagé": ("pacager",),
    "pacagent": ("pacager",),
    "pacageons": ("pacager",),
    "pacage": ("pacager",),
    "pacagera": ("pacager",),
    "pacageraient": ("pacager",),
    "pacagerai": ("pacager",),
    "pacagerais": ("pacager",),
    "pacagerait": ("pacager",),
    "pacageras": ("pacager",),
    "pacagèrent": ("pacager",),
    "pacagerez": ("pacager",),
    "pacageriez": ("pacager",),
    "pacagerions": ("pacager",),
    "pacagerons": ("pacager",),
    "pacageront": ("pacager",),
    "pacagés": ("pacager",),
    "pacages": ("pacager",),
    "pacagez": ("pacager",),
    "pacagiez": ("pacager",),
    "pacagions": ("pacager",),
    "pacifiaient": ("pacifier",),
    "pacifiai": ("pacifier",),
    "pacifiais": ("pacifier",),
    "pacifiait": ("pacifier",),
    "pacifia": ("pacifier",),
    "pacifiâmes": ("pacifier",),
    "pacifiant": ("pacifier",),
    "pacifias": ("pacifier",),
    "pacifiassent": ("pacifier",),
    "pacifiasses": ("pacifier",),
    "pacifiasse": ("pacifier",),
    "pacifiassiez": ("pacifier",),
    "pacifiassions": ("pacifier",),
    "pacifiâtes": ("pacifier",),
    "pacifiât": ("pacifier",),
    "pacifiée": ("pacifier",),
    "pacifiées": ("pacifier",),
    "pacifié": ("pacifier",),
    "pacifient": ("pacifier",),
    "pacifie": ("pacifier",),
    "pacifiera": ("pacifier",),
    "pacifieraient": ("pacifier",),
    "pacifierai": ("pacifier",),
    "pacifierais": ("pacifier",),
    "pacifierait": ("pacifier",),
    "pacifieras": ("pacifier",),
    "pacifièrent": ("pacifier",),
    "pacifierez": ("pacifier",),
    "pacifieriez": ("pacifier",),
    "pacifierions": ("pacifier",),
    "pacifierons": ("pacifier",),
    "pacifieront": ("pacifier",),
    "pacifiés": ("pacifier",),
    "pacifies": ("pacifier",),
    "pacifiez": ("pacifier",),
    "pacifiiez": ("pacifier",),
    "pacifiions": ("pacifier",),
    "pacifions": ("pacifier",),
    "pagaient": ("pagayer",),
    "pagaie": ("pagayer",),
    "pagaiera": ("pagayer",),
    "pagaieraient": ("pagayer",),
    "pagaierai": ("pagayer",),
    "pagaierais": ("pagayer",),
    "pagaierait": ("pagayer",),
    "pagaieras": ("pagayer",),
    "pagaierez": ("pagayer",),
    "pagaieriez": ("pagayer",),
    "pagaierions": ("pagayer",),
    "pagaierons": ("pagayer",),
    "pagaieront": ("pagayer",),
    "pagaies": ("pagayer",),
    "pagayaient": ("pagayer",),
    "pagayai": ("pagayer",),
    "pagayais": ("pagayer",),
    "pagayait": ("pagayer",),
    "pagaya": ("pagayer",),
    "pagayâmes": ("pagayer",),
    "pagayant": ("pagayer",),
    "pagayas": ("pagayer",),
    "pagayassent": ("pagayer",),
    "pagayasses": ("pagayer",),
    "pagayasse": ("pagayer",),
    "pagayassiez": ("pagayer",),
    "pagayassions": ("pagayer",),
    "pagayâtes": ("pagayer",),
    "pagayât": ("pagayer",),
    "pagayé": ("pagayer",),
    "pagayent": ("pagayer",),
    "pagaye": ("pagayer",),
    "pagayera": ("pagayer",),
    "pagayeraient": ("pagayer",),
    "pagayerai": ("pagayer",),
    "pagayerais": ("pagayer",),
    "pagayerait": ("pagayer",),
    "pagayeras": ("pagayer",),
    "pagayèrent": ("pagayer",),
    "pagayerez": ("pagayer",),
    "pagayeriez": ("pagayer",),
    "pagayerions": ("pagayer",),
    "pagayerons": ("pagayer",),
    "pagayeront": ("pagayer",),
    "pagayes": ("pagayer",),
    "pagayez": ("pagayer",),
    "pagayiez": ("pagayer",),
    "pagayions": ("pagayer",),
    "pagayons": ("pagayer",),
    "pageaient": ("pager",),
    "pageai": ("pager",),
    "pageais": ("pager",),
    "pageait": ("pager",),
    "pagea": ("pager",),
    "pageâmes": ("pager",),
    "pageant": ("pager",),
    "pageas": ("pager",),
    "pageassent": ("pager",),
    "pageasses": ("pager",),
    "pageasse": ("pager",),
    "pageassiez": ("pager",),
    "pageassions": ("pager",),
    "pageâtes": ("pager",),
    "pageât": ("pager",),
    "pagée": ("pager",),
    "pagées": ("pager",),
    "pagé": ("pager",),
    "pagent": ("pager",),
    "pageons": ("pager",),
    "page": ("pager",),
    "pagera": ("pager",),
    "pageraient": ("pager",),
    "pagerai": ("pager",),
    "pagerais": ("pager",),
    "pagerait": ("pager",),
    "pageras": ("pager",),
    "pagèrent": ("pager",),
    "pagerez": ("pager",),
    "pageriez": ("pager",),
    "pagerions": ("pager",),
    "pagerons": ("pager",),
    "pageront": ("pager",),
    "pagés": ("pager",),
    "pages": ("pager",),
    "pagez": ("pager",),
    "pagiez": ("pager",),
    "pagions": ("pager",),
    "pailletaient": ("pailleter",),
    "pailletai": ("pailleter",),
    "pailletais": ("pailleter",),
    "pailletait": ("pailleter",),
    "pailleta": ("pailleter",),
    "pailletâmes": ("pailleter",),
    "pailletant": ("pailleter",),
    "pailletas": ("pailleter",),
    "pailletassent": ("pailleter",),
    "pailletasses": ("pailleter",),
    "pailletasse": ("pailleter",),
    "pailletassiez": ("pailleter",),
    "pailletassions": ("pailleter",),
    "pailletâtes": ("pailleter",),
    "pailletât": ("pailleter",),
    "pailletée": ("pailleter",),
    "pailletées": ("pailleter",),
    "pailleté": ("pailleter",),
    "pailletèrent": ("pailleter",),
    "pailletés": ("pailleter",),
    "pailletez": ("pailleter",),
    "pailletiez": ("pailleter",),
    "pailletions": ("pailleter",),
    "pailletons": ("pailleter",),
    "paillettent": ("pailleter",),
    "paillette": ("pailleter",),
    "paillettera": ("pailleter",),
    "pailletteraient": ("pailleter",),
    "pailletterai": ("pailleter",),
    "pailletterais": ("pailleter",),
    "pailletterait": ("pailleter",),
    "pailletteras": ("pailleter",),
    "pailletterez": ("pailleter",),
    "pailletteriez": ("pailleter",),
    "pailletterions": ("pailleter",),
    "pailletterons": ("pailleter",),
    "pailletteront": ("pailleter",),
    "paillettes": ("pailleter",),
    "paisselaient": ("paisseler",),
    "paisselai": ("paisseler",),
    "paisselais": ("paisseler",),
    "paisselait": ("paisseler",),
    "paissela": ("paisseler",),
    "paisselâmes": ("paisseler",),
    "paisselant": ("paisseler",),
    "paisselas": ("paisseler",),
    "paisselassent": ("paisseler",),
    "paisselasses": ("paisseler",),
    "paisselasse": ("paisseler",),
    "paisselassiez": ("paisseler",),
    "paisselassions": ("paisseler",),
    "paisselâtes": ("paisseler",),
    "paisselât": ("paisseler",),
    "paisselée": ("paisseler",),
    "paisselées": ("paisseler",),
    "paisselé": ("paisseler",),
    "paisselèrent": ("paisseler",),
    "paisselés": ("paisseler",),
    "paisselez": ("paisseler",),
    "paisseliez": ("paisseler",),
    "paisselions": ("paisseler",),
    "paissellent": ("paisseler",),
    "paisselle": ("paisseler",),
    "paissellera": ("paisseler",),
    "paisselleraient": ("paisseler",),
    "paissellerai": ("paisseler",),
    "paissellerais": ("paisseler",),
    "paissellerait": ("paisseler",),
    "paisselleras": ("paisseler",),
    "paissellerez": ("paisseler",),
    "paisselleriez": ("paisseler",),
    "paissellerions": ("paisseler",),
    "paissellerons": ("paisseler",),
    "paisselleront": ("paisseler",),
    "paisselles": ("paisseler",),
    "paisselons": ("paisseler",),
    "pais": ("paître",),
    "paissaient": ("paître",),
    "paissais": ("paître",),
    "paissait": ("paître",),
    "paissant": ("paître",),
    "paissent": ("paître",),
    "paisse": ("paître",),
    "paisses": ("paître",),
    "paissez": ("paître",),
    "paissiez": ("paître",),
    "paissions": ("paître",),
    "paissons": ("paître",),
    "paît": ("paître",),
    "paîtra": ("paître",),
    "paîtraient": ("paître",),
    "paîtrai": ("paître",),
    "paîtrais": ("paître",),
    "paîtrait": ("paître",),
    "paîtras": ("paître",),
    "paîtrez": ("paître",),
    "paîtriez": ("paître",),
    "paîtrions": ("paître",),
    "paîtrons": ("paître",),
    "paîtront": ("paître",),
    "pu": ("pouvoir",),
    "paletaient": ("paleter",),
    "paletai": ("paleter",),
    "paletais": ("paleter",),
    "paletait": ("paleter",),
    "paleta": ("paleter",),
    "paletâmes": ("paleter",),
    "paletant": ("paleter",),
    "paletas": ("paleter",),
    "paletassent": ("paleter",),
    "paletasses": ("paleter",),
    "paletasse": ("paleter",),
    "paletassiez": ("paleter",),
    "paletassions": ("paleter",),
    "paletâtes": ("paleter",),
    "paletât": ("paleter",),
    "paletée": ("paleter",),
    "paletées": ("paleter",),
    "paleté": ("paleter",),
    "paletèrent": ("paleter",),
    "paletés": ("paleter",),
    "paletez": ("paleter",),
    "paletiez": ("paleter",),
    "paletions": ("paleter",),
    "paletons": ("paleter",),
    "palettent": ("paleter",),
    "palette": ("paleter",),
    "palettera": ("paleter",),
    "paletteraient": ("paleter",),
    "paletterai": ("paleter",),
    "paletterais": ("paleter",),
    "paletterait": ("paleter",),
    "paletteras": ("paleter",),
    "paletterez": ("paleter",),
    "paletteriez": ("paleter",),
    "paletterions": ("paleter",),
    "paletterons": ("paleter",),
    "paletteront": ("paleter",),
    "palettes": ("paleter",),
    "palifiaient": ("palifier",),
    "palifiai": ("palifier",),
    "palifiais": ("palifier",),
    "palifiait": ("palifier",),
    "palifia": ("palifier",),
    "palifiâmes": ("palifier",),
    "palifiant": ("palifier",),
    "palifias": ("palifier",),
    "palifiassent": ("palifier",),
    "palifiasses": ("palifier",),
    "palifiasse": ("palifier",),
    "palifiassiez": ("palifier",),
    "palifiassions": ("palifier",),
    "palifiâtes": ("palifier",),
    "palifiât": ("palifier",),
    "palifiée": ("palifier",),
    "palifiées": ("palifier",),
    "palifié": ("palifier",),
    "palifient": ("palifier",),
    "palifie": ("palifier",),
    "palifiera": ("palifier",),
    "palifieraient": ("palifier",),
    "palifierai": ("palifier",),
    "palifierais": ("palifier",),
    "palifierait": ("palifier",),
    "palifieras": ("palifier",),
    "palifièrent": ("palifier",),
    "palifierez": ("palifier",),
    "palifieriez": ("palifier",),
    "palifierions": ("palifier",),
    "palifierons": ("palifier",),
    "palifieront": ("palifier",),
    "palifiés": ("palifier",),
    "palifies": ("palifier",),
    "palifiez": ("palifier",),
    "palifiiez": ("palifier",),
    "palifiions": ("palifier",),
    "palifions": ("palifier",),
    "pâlie": ("pâlir",),
    "pâlies": ("pâlir",),
    "pâli": ("pâlir",),
    "pâlîmes": ("pâlir",),
    "pâlira": ("pâlir",),
    "pâliraient": ("pâlir",),
    "pâlirai": ("pâlir",),
    "pâlirais": ("pâlir",),
    "pâlirait": ("pâlir",),
    "pâliras": ("pâlir",),
    "pâlirent": ("pâlir",),
    "pâlirez": ("pâlir",),
    "pâliriez": ("pâlir",),
    "pâlirions": ("pâlir",),
    "pâlirons": ("pâlir",),
    "pâliront": ("pâlir",),
    "pâlis": ("pâlir",),
    "pâlissaient": ("pâlir",),
    "pâlissais": ("pâlir",),
    "pâlissait": ("pâlir",),
    "pâlissant": ("pâlir",),
    "pâlissent": ("pâlir",),
    "pâlisse": ("pâlir",),
    "pâlisses": ("pâlir",),
    "pâlissez": ("pâlir",),
    "pâlissiez": ("pâlir",),
    "pâlissions": ("pâlir",),
    "pâlissons": ("pâlir",),
    "pâlîtes": ("pâlir",),
    "pâlit": ("pâlir",),
    "pâlît": ("pâlir",),
    "palliaient": ("pallier",),
    "palliai": ("pallier",),
    "palliais": ("pallier",),
    "palliait": ("pallier",),
    "pallia": ("pallier",),
    "palliâmes": ("pallier",),
    "palliant": ("pallier",),
    "pallias": ("pallier",),
    "palliassent": ("pallier",),
    "palliasses": ("pallier",),
    "palliasse": ("pallier",),
    "palliassiez": ("pallier",),
    "palliassions": ("pallier",),
    "palliâtes": ("pallier",),
    "palliât": ("pallier",),
    "palliée": ("pallier",),
    "palliées": ("pallier",),
    "pallié": ("pallier",),
    "pallient": ("pallier",),
    "pallie": ("pallier",),
    "palliera": ("pallier",),
    "pallieraient": ("pallier",),
    "pallierai": ("pallier",),
    "pallierais": ("pallier",),
    "pallierait": ("pallier",),
    "pallieras": ("pallier",),
    "pallièrent": ("pallier",),
    "pallierez": ("pallier",),
    "pallieriez": ("pallier",),
    "pallierions": ("pallier",),
    "pallierons": ("pallier",),
    "pallieront": ("pallier",),
    "palliés": ("pallier",),
    "pallies": ("pallier",),
    "palliez": ("pallier",),
    "palliiez": ("pallier",),
    "palliions": ("pallier",),
    "pallions": ("pallier",),
    "pâmaient": ("pâmer",),
    "pâmai": ("pâmer",),
    "pâmais": ("pâmer",),
    "pâmait": ("pâmer",),
    "pâma": ("pâmer",),
    "pâmâmes": ("pâmer",),
    "pâmant": ("pâmer",),
    "pâmas": ("pâmer",),
    "pâmassent": ("pâmer",),
    "pâmasses": ("pâmer",),
    "pâmasse": ("pâmer",),
    "pâmassiez": ("pâmer",),
    "pâmassions": ("pâmer",),
    "pâmâtes": ("pâmer",),
    "pâmât": ("pâmer",),
    "pâmée": ("pâmer",),
    "pâmées": ("pâmer",),
    "pâmé": ("pâmer",),
    "pâment": ("pâmer",),
    "pâme": ("pâmer",),
    "pâmera": ("pâmer",),
    "pâmeraient": ("pâmer",),
    "pâmerai": ("pâmer",),
    "pâmerais": ("pâmer",),
    "pâmerait": ("pâmer",),
    "pâmeras": ("pâmer",),
    "pâmèrent": ("pâmer",),
    "pâmerez": ("pâmer",),
    "pâmeriez": ("pâmer",),
    "pâmerions": ("pâmer",),
    "pâmerons": ("pâmer",),
    "pâmeront": ("pâmer",),
    "pâmés": ("pâmer",),
    "pâmes": ("pâmer",),
    "pâmez": ("pâmer",),
    "pâmiez": ("pâmer",),
    "pâmions": ("pâmer",),
    "pâmons": ("pâmer",),
    "panifiaient": ("panifier",),
    "panifiai": ("panifier",),
    "panifiais": ("panifier",),
    "panifiait": ("panifier",),
    "panifia": ("panifier",),
    "panifiâmes": ("panifier",),
    "panifiant": ("panifier",),
    "panifias": ("panifier",),
    "panifiassent": ("panifier",),
    "panifiasses": ("panifier",),
    "panifiasse": ("panifier",),
    "panifiassiez": ("panifier",),
    "panifiassions": ("panifier",),
    "panifiâtes": ("panifier",),
    "panifiât": ("panifier",),
    "panifiée": ("panifier",),
    "panifiées": ("panifier",),
    "panifié": ("panifier",),
    "panifient": ("panifier",),
    "panifie": ("panifier",),
    "panifiera": ("panifier",),
    "panifieraient": ("panifier",),
    "panifierai": ("panifier",),
    "panifierais": ("panifier",),
    "panifierait": ("panifier",),
    "panifieras": ("panifier",),
    "panifièrent": ("panifier",),
    "panifierez": ("panifier",),
    "panifieriez": ("panifier",),
    "panifierions": ("panifier",),
    "panifierons": ("panifier",),
    "panifieront": ("panifier",),
    "panifiés": ("panifier",),
    "panifies": ("panifier",),
    "panifiez": ("panifier",),
    "panifiiez": ("panifier",),
    "panifiions": ("panifier",),
    "panifions": ("panifier",),
    "pantelaient": ("panteler",),
    "pantelai": ("panteler",),
    "pantelais": ("panteler",),
    "pantelait": ("panteler",),
    "pantela": ("panteler",),
    "pantelâmes": ("panteler",),
    "pantelant": ("panteler",),
    "pantelas": ("panteler",),
    "pantelassent": ("panteler",),
    "pantelasses": ("panteler",),
    "pantelasse": ("panteler",),
    "pantelassiez": ("panteler",),
    "pantelassions": ("panteler",),
    "pantelâtes": ("panteler",),
    "pantelât": ("panteler",),
    "pantelé": ("panteler",),
    "pantelèrent": ("panteler",),
    "pantelez": ("panteler",),
    "panteliez": ("panteler",),
    "pantelions": ("panteler",),
    "pantellent": ("panteler",),
    "pantelle": ("panteler",),
    "pantellera": ("panteler",),
    "pantelleraient": ("panteler",),
    "pantellerai": ("panteler",),
    "pantellerais": ("panteler",),
    "pantellerait": ("panteler",),
    "pantelleras": ("panteler",),
    "pantellerez": ("panteler",),
    "pantelleriez": ("panteler",),
    "pantellerions": ("panteler",),
    "pantellerons": ("panteler",),
    "pantelleront": ("panteler",),
    "pantelles": ("panteler",),
    "pantelons": ("panteler",),
    "pantographiaient": ("pantographier",),
    "pantographiai": ("pantographier",),
    "pantographiais": ("pantographier",),
    "pantographiait": ("pantographier",),
    "pantographia": ("pantographier",),
    "pantographiâmes": ("pantographier",),
    "pantographiant": ("pantographier",),
    "pantographias": ("pantographier",),
    "pantographiassent": ("pantographier",),
    "pantographiasses": ("pantographier",),
    "pantographiasse": ("pantographier",),
    "pantographiassiez": ("pantographier",),
    "pantographiassions": ("pantographier",),
    "pantographiâtes": ("pantographier",),
    "pantographiât": ("pantographier",),
    "pantographiée": ("pantographier",),
    "pantographiées": ("pantographier",),
    "pantographié": ("pantographier",),
    "pantographient": ("pantographier",),
    "pantographie": ("pantographier",),
    "pantographiera": ("pantographier",),
    "pantographieraient": ("pantographier",),
    "pantographierai": ("pantographier",),
    "pantographierais": ("pantographier",),
    "pantographierait": ("pantographier",),
    "pantographieras": ("pantographier",),
    "pantographièrent": ("pantographier",),
    "pantographierez": ("pantographier",),
    "pantographieriez": ("pantographier",),
    "pantographierions": ("pantographier",),
    "pantographierons": ("pantographier",),
    "pantographieront": ("pantographier",),
    "pantographiés": ("pantographier",),
    "pantographies": ("pantographier",),
    "pantographiez": ("pantographier",),
    "pantographiiez": ("pantographier",),
    "pantographiions": ("pantographier",),
    "pantographions": ("pantographier",),
    "paperassaient": ("paperasser",),
    "paperassai": ("paperasser",),
    "paperassais": ("paperasser",),
    "paperassait": ("paperasser",),
    "paperassa": ("paperasser",),
    "paperassâmes": ("paperasser",),
    "paperassant": ("paperasser",),
    "paperassas": ("paperasser",),
    "paperassassent": ("paperasser",),
    "paperassasses": ("paperasser",),
    "paperassasse": ("paperasser",),
    "paperassassiez": ("paperasser",),
    "paperassassions": ("paperasser",),
    "paperassâtes": ("paperasser",),
    "paperassât": ("paperasser",),
    "paperassé": ("paperasser",),
    "paperassent": ("paperasser",),
    "paperasse": ("paperasser",),
    "paperassera": ("paperasser",),
    "paperasseraient": ("paperasser",),
    "paperasserai": ("paperasser",),
    "paperasserais": ("paperasser",),
    "paperasserait": ("paperasser",),
    "paperasseras": ("paperasser",),
    "paperassèrent": ("paperasser",),
    "paperasserez": ("paperasser",),
    "paperasseriez": ("paperasser",),
    "paperasserions": ("paperasser",),
    "paperasserons": ("paperasser",),
    "paperasseront": ("paperasser",),
    "paperasses": ("paperasser",),
    "paperassez": ("paperasser",),
    "paperassiez": ("paperasser",),
    "paperassions": ("paperasser",),
    "paperassons": ("paperasser",),
    "papiétaient": ("papiéter",),
    "papiétai": ("papiéter",),
    "papiétais": ("papiéter",),
    "papiétait": ("papiéter",),
    "papiéta": ("papiéter",),
    "papiétâmes": ("papiéter",),
    "papiétant": ("papiéter",),
    "papiétas": ("papiéter",),
    "papiétassent": ("papiéter",),
    "papiétasses": ("papiéter",),
    "papiétasse": ("papiéter",),
    "papiétassiez": ("papiéter",),
    "papiétassions": ("papiéter",),
    "papiétâtes": ("papiéter",),
    "papiétât": ("papiéter",),
    "papiétée": ("papiéter",),
    "papiétées": ("papiéter",),
    "papiété": ("papiéter",),
    "papiètent": ("papiéter",),
    "papiète": ("papiéter",),
    "papiétera": ("papiéter",),
    "papiéteraient": ("papiéter",),
    "papiéterai": ("papiéter",),
    "papiéterais": ("papiéter",),
    "papiéterait": ("papiéter",),
    "papiéteras": ("papiéter",),
    "papiétèrent": ("papiéter",),
    "papiéterez": ("papiéter",),
    "papiéteriez": ("papiéter",),
    "papiéterions": ("papiéter",),
    "papiéterons": ("papiéter",),
    "papiéteront": ("papiéter",),
    "papiétés": ("papiéter",),
    "papiètes": ("papiéter",),
    "papiétez": ("papiéter",),
    "papiétiez": ("papiéter",),
    "papiétions": ("papiéter",),
    "papiétons": ("papiéter",),
    "paquetaient": ("paqueter",),
    "paquetai": ("paqueter",),
    "paquetais": ("paqueter",),
    "paquetait": ("paqueter",),
    "paqueta": ("paqueter",),
    "paquetâmes": ("paqueter",),
    "paquetant": ("paqueter",),
    "paquetas": ("paqueter",),
    "paquetassent": ("paqueter",),
    "paquetasses": ("paqueter",),
    "paquetasse": ("paqueter",),
    "paquetassiez": ("paqueter",),
    "paquetassions": ("paqueter",),
    "paquetâtes": ("paqueter",),
    "paquetât": ("paqueter",),
    "paquetée": ("paqueter",),
    "paquetées": ("paqueter",),
    "paqueté": ("paqueter",),
    "paquetèrent": ("paqueter",),
    "paquetés": ("paqueter",),
    "paquetez": ("paqueter",),
    "paquetiez": ("paqueter",),
    "paquetions": ("paqueter",),
    "paquetons": ("paqueter",),
    "paquettent": ("paqueter",),
    "paquette": ("paqueter",),
    "paquettera": ("paqueter",),
    "paquetteraient": ("paqueter",),
    "paquetterai": ("paqueter",),
    "paquetterais": ("paqueter",),
    "paquetterait": ("paqueter",),
    "paquetteras": ("paqueter",),
    "paquetterez": ("paqueter",),
    "paquetteriez": ("paqueter",),
    "paquetterions": ("paqueter",),
    "paquetterons": ("paqueter",),
    "paquetteront": ("paqueter",),
    "paquettes": ("paqueter",),
    "parachevaient": ("parachever",),
    "parachevai": ("parachever",),
    "parachevais": ("parachever",),
    "parachevait": ("parachever",),
    "paracheva": ("parachever",),
    "parachevâmes": ("parachever",),
    "parachevant": ("parachever",),
    "parachevas": ("parachever",),
    "parachevassent": ("parachever",),
    "parachevasses": ("parachever",),
    "parachevasse": ("parachever",),
    "parachevassiez": ("parachever",),
    "parachevassions": ("parachever",),
    "parachevâtes": ("parachever",),
    "parachevât": ("parachever",),
    "parachevée": ("parachever",),
    "parachevées": ("parachever",),
    "parachevé": ("parachever",),
    "parachèvent": ("parachever",),
    "parachève": ("parachever",),
    "parachèvera": ("parachever",),
    "parachèveraient": ("parachever",),
    "parachèverai": ("parachever",),
    "parachèverais": ("parachever",),
    "parachèverait": ("parachever",),
    "parachèveras": ("parachever",),
    "parachevèrent": ("parachever",),
    "parachèverez": ("parachever",),
    "parachèveriez": ("parachever",),
    "parachèverions": ("parachever",),
    "parachèverons": ("parachever",),
    "parachèveront": ("parachever",),
    "parachevés": ("parachever",),
    "parachèves": ("parachever",),
    "parachevez": ("parachever",),
    "paracheviez": ("parachever",),
    "parachevions": ("parachever",),
    "parachevons": ("parachever",),
    "parais": ("paraître",),
    "paraissaient": ("paraître",),
    "paraissais": ("paraître",),
    "paraissait": ("paraître",),
    "paraissant": ("paraître",),
    "paraissent": ("paraître",),
    "paraisse": ("paraître",),
    "paraisses": ("paraître",),
    "paraissez": ("paraître",),
    "paraissiez": ("paraître",),
    "paraissions": ("paraître",),
    "paraissons": ("paraître",),
    "paraît": ("paraître",),
    "paraîtra": ("paraître",),
    "paraîtraient": ("paraître",),
    "paraîtrai": ("paraître",),
    "paraîtrais": ("paraître",),
    "paraîtrait": ("paraître",),
    "paraîtras": ("paraître",),
    "paraîtrez": ("paraître",),
    "paraîtriez": ("paraître",),
    "paraîtrions": ("paraître",),
    "paraîtrons": ("paraître",),
    "paraîtront": ("paraître",),
    "parue": ("paraître",),
    "parues": ("paraître",),
    "paru": ("paraître",),
    "parûmes": ("paraître",),
    "parurent": ("paraître",),
    "parus": ("paraître",),
    "parussent": ("paraître",),
    "parusses": ("paraître",),
    "parusse": ("paraître",),
    "parussiez": ("paraître",),
    "parussions": ("paraître",),
    "parûtes": ("paraître",),
    "parut": ("paraître",),
    "parût": ("paraître",),
    "paramétraient": ("paramétrer",),
    "paramétrai": ("paramétrer",),
    "paramétrais": ("paramétrer",),
    "paramétrait": ("paramétrer",),
    "paramétra": ("paramétrer",),
    "paramétrâmes": ("paramétrer",),
    "paramétrant": ("paramétrer",),
    "paramétras": ("paramétrer",),
    "paramétrassent": ("paramétrer",),
    "paramétrasses": ("paramétrer",),
    "paramétrasse": ("paramétrer",),
    "paramétrassiez": ("paramétrer",),
    "paramétrassions": ("paramétrer",),
    "paramétrâtes": ("paramétrer",),
    "paramétrât": ("paramétrer",),
    "paramétrée": ("paramétrer",),
    "paramétrées": ("paramétrer",),
    "paramétré": ("paramétrer",),
    "paramètrent": ("paramétrer",),
    "paramètre": ("paramétrer",),
    "paramétrera": ("paramétrer",),
    "paramétreraient": ("paramétrer",),
    "paramétrerai": ("paramétrer",),
    "paramétrerais": ("paramétrer",),
    "paramétrerait": ("paramétrer",),
    "paramétreras": ("paramétrer",),
    "paramétrèrent": ("paramétrer",),
    "paramétrerez": ("paramétrer",),
    "paramétreriez": ("paramétrer",),
    "paramétrerions": ("paramétrer",),
    "paramétrerons": ("paramétrer",),
    "paramétreront": ("paramétrer",),
    "paramétrés": ("paramétrer",),
    "paramètres": ("paramétrer",),
    "paramétrez": ("paramétrer",),
    "paramétriez": ("paramétrer",),
    "paramétrions": ("paramétrer",),
    "paramétrons": ("paramétrer",),
    "parcouraient": ("parcourir",),
    "parcourais": ("parcourir",),
    "parcourait": ("parcourir",),
    "parcourant": ("parcourir",),
    "parcourent": ("parcourir",),
    "parcoure": ("parcourir",),
    "parcoures": ("parcourir",),
    "parcourez": ("parcourir",),
    "parcouriez": ("parcourir",),
    "parcourions": ("parcourir",),
    "parcourons": ("parcourir",),
    "parcourra": ("parcourir",),
    "parcourraient": ("parcourir",),
    "parcourrai": ("parcourir",),
    "parcourrais": ("parcourir",),
    "parcourrait": ("parcourir",),
    "parcourras": ("parcourir",),
    "parcourrez": ("parcourir",),
    "parcourriez": ("parcourir",),
    "parcourrions": ("parcourir",),
    "parcourrons": ("parcourir",),
    "parcourront": ("parcourir",),
    "parcours": ("parcourir",),
    "parcourt": ("parcourir",),
    "parcourue": ("parcourir",),
    "parcourues": ("parcourir",),
    "parcouru": ("parcourir",),
    "parcourûmes": ("parcourir",),
    "parcoururent": ("parcourir",),
    "parcourus": ("parcourir",),
    "parcourussent": ("parcourir",),
    "parcourusses": ("parcourir",),
    "parcourusse": ("parcourir",),
    "parcourussiez": ("parcourir",),
    "parcourussions": ("parcourir",),
    "parcourûtes": ("parcourir",),
    "parcourut": ("parcourir",),
    "parcourût": ("parcourir",),
    "parenthésaient": ("parenthéser",),
    "parenthésai": ("parenthéser",),
    "parenthésais": ("parenthéser",),
    "parenthésait": ("parenthéser",),
    "parenthésa": ("parenthéser",),
    "parenthésâmes": ("parenthéser",),
    "parenthésant": ("parenthéser",),
    "parenthésas": ("parenthéser",),
    "parenthésassent": ("parenthéser",),
    "parenthésasses": ("parenthéser",),
    "parenthésasse": ("parenthéser",),
    "parenthésassiez": ("parenthéser",),
    "parenthésassions": ("parenthéser",),
    "parenthésâtes": ("parenthéser",),
    "parenthésât": ("parenthéser",),
    "parenthésée": ("parenthéser",),
    "parenthésées": ("parenthéser",),
    "parenthésé": ("parenthéser",),
    "parenthèsent": ("parenthéser",),
    "parenthèse": ("parenthéser",),
    "parenthésera": ("parenthéser",),
    "parenthéseraient": ("parenthéser",),
    "parenthéserai": ("parenthéser",),
    "parenthéserais": ("parenthéser",),
    "parenthéserait": ("parenthéser",),
    "parenthéseras": ("parenthéser",),
    "parenthésèrent": ("parenthéser",),
    "parenthéserez": ("parenthéser",),
    "parenthéseriez": ("parenthéser",),
    "parenthéserions": ("parenthéser",),
    "parenthéserons": ("parenthéser",),
    "parenthéseront": ("parenthéser",),
    "parenthésés": ("parenthéser",),
    "parenthèses": ("parenthéser",),
    "parenthésez": ("parenthéser",),
    "parenthésiez": ("parenthéser",),
    "parenthésions": ("parenthéser",),
    "parenthésons": ("parenthéser",),
    "parfaisaient": ("parfaire",),
    "parfaisais": ("parfaire",),
    "parfaisait": ("parfaire",),
    "parfaisant": ("parfaire",),
    "parfaisiez": ("parfaire",),
    "parfaisions": ("parfaire",),
    "parfaisons": ("parfaire",),
    "parfais": ("parfaire",),
    "parfaite": ("parfaire",),
    "parfaites": ("parfaire",),
    "parfait": ("parfaire",),
    "parfaits": ("parfaire",),
    "parfassent": ("parfaire",),
    "parfasse": ("parfaire",),
    "parfasses": ("parfaire",),
    "parfassiez": ("parfaire",),
    "parfassions": ("parfaire",),
    "parfera": ("parfaire",),
    "parferaient": ("parfaire",),
    "parferai": ("parfaire",),
    "parferais": ("parfaire",),
    "parferait": ("parfaire",),
    "parferas": ("parfaire",),
    "parferez": ("parfaire",),
    "parferiez": ("parfaire",),
    "parferions": ("parfaire",),
    "parferons": ("parfaire",),
    "parferont": ("parfaire",),
    "parfîmes": ("parfaire",),
    "parfirent": ("parfaire",),
    "parfis": ("parfaire",),
    "parfissent": ("parfaire",),
    "parfisses": ("parfaire",),
    "parfisse": ("parfaire",),
    "parfissiez": ("parfaire",),
    "parfissions": ("parfaire",),
    "parfîtes": ("parfaire",),
    "parfit": ("parfaire",),
    "parfît": ("parfaire",),
    "parfont": ("parfaire",),
    "parfondaient": ("parfondre",),
    "parfondais": ("parfondre",),
    "parfondait": ("parfondre",),
    "parfondant": ("parfondre",),
    "parfondent": ("parfondre",),
    "parfonde": ("parfondre",),
    "parfondes": ("parfondre",),
    "parfondez": ("parfondre",),
    "parfondiez": ("parfondre",),
    "parfondîmes": ("parfondre",),
    "parfondions": ("parfondre",),
    "parfondirent": ("parfondre",),
    "parfondis": ("parfondre",),
    "parfondissent": ("parfondre",),
    "parfondisses": ("parfondre",),
    "parfondisse": ("parfondre",),
    "parfondissiez": ("parfondre",),
    "parfondissions": ("parfondre",),
    "parfondîtes": ("parfondre",),
    "parfondit": ("parfondre",),
    "parfondît": ("parfondre",),
    "parfondons": ("parfondre",),
    "parfond": ("parfondre",),
    "parfondra": ("parfondre",),
    "parfondraient": ("parfondre",),
    "parfondrai": ("parfondre",),
    "parfondrais": ("parfondre",),
    "parfondrait": ("parfondre",),
    "parfondras": ("parfondre",),
    "parfondrez": ("parfondre",),
    "parfondriez": ("parfondre",),
    "parfondrions": ("parfondre",),
    "parfondrons": ("parfondre",),
    "parfondront": ("parfondre",),
    "parfonds": ("parfondre",),
    "parfondue": ("parfondre",),
    "parfondues": ("parfondre",),
    "parfondu": ("parfondre",),
    "parfondus": ("parfondre",),
    "parfournie": ("parfournir",),
    "parfournies": ("parfournir",),
    "parfourni": ("parfournir",),
    "parfournîmes": ("parfournir",),
    "parfournira": ("parfournir",),
    "parfourniraient": ("parfournir",),
    "parfournirai": ("parfournir",),
    "parfournirais": ("parfournir",),
    "parfournirait": ("parfournir",),
    "parfourniras": ("parfournir",),
    "parfournirent": ("parfournir",),
    "parfournirez": ("parfournir",),
    "parfourniriez": ("parfournir",),
    "parfournirions": ("parfournir",),
    "parfournirons": ("parfournir",),
    "parfourniront": ("parfournir",),
    "parfournis": ("parfournir",),
    "parfournissaient": ("parfournir",),
    "parfournissais": ("parfournir",),
    "parfournissait": ("parfournir",),
    "parfournissant": ("parfournir",),
    "parfournissent": ("parfournir",),
    "parfournisse": ("parfournir",),
    "parfournisses": ("parfournir",),
    "parfournissez": ("parfournir",),
    "parfournissiez": ("parfournir",),
    "parfournissions": ("parfournir",),
    "parfournissons": ("parfournir",),
    "parfournîtes": ("parfournir",),
    "parfournit": ("parfournir",),
    "parfournît": ("parfournir",),
    "pariaient": ("parier",),
    "pariai": ("parier",),
    "pariais": ("parier",),
    "pariait": ("parier",),
    "paria": ("parier",),
    "pariâmes": ("parier",),
    "pariant": ("parier",),
    "parias": ("parier",),
    "pariassent": ("parier",),
    "pariasses": ("parier",),
    "pariasse": ("parier",),
    "pariassiez": ("parier",),
    "pariassions": ("parier",),
    "pariâtes": ("parier",),
    "pariât": ("parier",),
    "pariée": ("parier",),
    "pariées": ("parier",),
    "parié": ("parier",),
    "parient": ("parier",),
    "parie": ("parier",),
    "pariera": ("parier",),
    "parieraient": ("parier",),
    "parierai": ("parier",),
    "parierais": ("parier",),
    "parierait": ("parier",),
    "parieras": ("parier",),
    "parièrent": ("parier",),
    "parierez": ("parier",),
    "parieriez": ("parier",),
    "parierions": ("parier",),
    "parierons": ("parier",),
    "parieront": ("parier",),
    "pariés": ("parier",),
    "paries": ("parier",),
    "pariez": ("parier",),
    "pariiez": ("parier",),
    "pariions": ("parier",),
    "parions": ("parier",),
    "parodiaient": ("parodier",),
    "parodiai": ("parodier",),
    "parodiais": ("parodier",),
    "parodiait": ("parodier",),
    "parodia": ("parodier",),
    "parodiâmes": ("parodier",),
    "parodiant": ("parodier",),
    "parodias": ("parodier",),
    "parodiassent": ("parodier",),
    "parodiasses": ("parodier",),
    "parodiasse": ("parodier",),
    "parodiassiez": ("parodier",),
    "parodiassions": ("parodier",),
    "parodiâtes": ("parodier",),
    "parodiât": ("parodier",),
    "parodiée": ("parodier",),
    "parodiées": ("parodier",),
    "parodié": ("parodier",),
    "parodient": ("parodier",),
    "parodie": ("parodier",),
    "parodiera": ("parodier",),
    "parodieraient": ("parodier",),
    "parodierai": ("parodier",),
    "parodierais": ("parodier",),
    "parodierait": ("parodier",),
    "parodieras": ("parodier",),
    "parodièrent": ("parodier",),
    "parodierez": ("parodier",),
    "parodieriez": ("parodier",),
    "parodierions": ("parodier",),
    "parodierons": ("parodier",),
    "parodieront": ("parodier",),
    "parodiés": ("parodier",),
    "parodies": ("parodier",),
    "parodiez": ("parodier",),
    "parodiiez": ("parodier",),
    "parodiions": ("parodier",),
    "parodions": ("parodier",),
    "parquetaient": ("parqueter",),
    "parquetai": ("parqueter",),
    "parquetais": ("parqueter",),
    "parquetait": ("parqueter",),
    "parqueta": ("parqueter",),
    "parquetâmes": ("parqueter",),
    "parquetant": ("parqueter",),
    "parquetas": ("parqueter",),
    "parquetassent": ("parqueter",),
    "parquetasses": ("parqueter",),
    "parquetasse": ("parqueter",),
    "parquetassiez": ("parqueter",),
    "parquetassions": ("parqueter",),
    "parquetâtes": ("parqueter",),
    "parquetât": ("parqueter",),
    "parquetée": ("parqueter",),
    "parquetées": ("parqueter",),
    "parqueté": ("parqueter",),
    "parquetèrent": ("parqueter",),
    "parquetés": ("parqueter",),
    "parquetez": ("parqueter",),
    "parquetiez": ("parqueter",),
    "parquetions": ("parqueter",),
    "parquetons": ("parqueter",),
    "parquettent": ("parqueter",),
    "parquette": ("parqueter",),
    "parquettera": ("parqueter",),
    "parquetteraient": ("parqueter",),
    "parquetterai": ("parqueter",),
    "parquetterais": ("parqueter",),
    "parquetterait": ("parqueter",),
    "parquetteras": ("parqueter",),
    "parquetterez": ("parqueter",),
    "parquetteriez": ("parqueter",),
    "parquetterions": ("parqueter",),
    "parquetterons": ("parqueter",),
    "parquetteront": ("parqueter",),
    "parquettes": ("parqueter",),
    "parsemaient": ("parsemer",),
    "parsemai": ("parsemer",),
    "parsemais": ("parsemer",),
    "parsemait": ("parsemer",),
    "parsema": ("parsemer",),
    "parsemâmes": ("parsemer",),
    "parsemant": ("parsemer",),
    "parsemas": ("parsemer",),
    "parsemassent": ("parsemer",),
    "parsemasses": ("parsemer",),
    "parsemasse": ("parsemer",),
    "parsemassiez": ("parsemer",),
    "parsemassions": ("parsemer",),
    "parsemâtes": ("parsemer",),
    "parsemât": ("parsemer",),
    "parsemée": ("parsemer",),
    "parsemées": ("parsemer",),
    "parsemé": ("parsemer",),
    "parsèment": ("parsemer",),
    "parsème": ("parsemer",),
    "parsèmera": ("parsemer",),
    "parsèmeraient": ("parsemer",),
    "parsèmerai": ("parsemer",),
    "parsèmerais": ("parsemer",),
    "parsèmerait": ("parsemer",),
    "parsèmeras": ("parsemer",),
    "parsemèrent": ("parsemer",),
    "parsèmerez": ("parsemer",),
    "parsèmeriez": ("parsemer",),
    "parsèmerions": ("parsemer",),
    "parsèmerons": ("parsemer",),
    "parsèmeront": ("parsemer",),
    "parsemés": ("parsemer",),
    "parsèmes": ("parsemer",),
    "parsemez": ("parsemer",),
    "parsemiez": ("parsemer",),
    "parsemions": ("parsemer",),
    "parsemons": ("parsemer",),
    "partageaient": ("partager",),
    "partageai": ("partager",),
    "partageais": ("partager",),
    "partageait": ("partager",),
    "partagea": ("partager",),
    "partageâmes": ("partager",),
    "partageant": ("partager",),
    "partageas": ("partager",),
    "partageassent": ("partager",),
    "partageasses": ("partager",),
    "partageasse": ("partager",),
    "partageassiez": ("partager",),
    "partageassions": ("partager",),
    "partageâtes": ("partager",),
    "partageât": ("partager",),
    "partagée": ("partager",),
    "partagées": ("partager",),
    "partagé": ("partager",),
    "partagent": ("partager",),
    "partageons": ("partager",),
    "partage": ("partager",),
    "partagera": ("partager",),
    "partageraient": ("partager",),
    "partagerai": ("partager",),
    "partagerais": ("partager",),
    "partagerait": ("partager",),
    "partageras": ("partager",),
    "partagèrent": ("partager",),
    "partagerez": ("partager",),
    "partageriez": ("partager",),
    "partagerions": ("partager",),
    "partagerons": ("partager",),
    "partageront": ("partager",),
    "partagés": ("partager",),
    "partages": ("partager",),
    "partagez": ("partager",),
    "partagiez": ("partager",),
    "partagions": ("partager",),
    "pars": ("partir",),
    "partaient": ("partir",),
    "partais": ("partir",),
    "partait": ("partir",),
    "partant": ("partir",),
    "partent": ("partir",),
    "parte": ("partir",),
    "partes": ("partir",),
    "partez": ("partir",),
    "partie": ("partir",),
    "parties": ("partir",),
    "partiez": ("partir",),
    "parti": ("partir",),
    "partîmes": ("partir",),
    "partions": ("partir",),
    "partira": ("partir",),
    "partiraient": ("partir",),
    "partirai": ("partir",),
    "partirais": ("partir",),
    "partirait": ("partir",),
    "partiras": ("partir",),
    "partirent": ("partir",),
    "partirez": ("partir",),
    "partiriez": ("partir",),
    "partirions": ("partir",),
    "partirons": ("partir",),
    "partiront": ("partir",),
    "partis": ("partir",),
    "partissent": ("partir",),
    "partisses": ("partir",),
    "partisse": ("partir",),
    "partissiez": ("partir",),
    "partissions": ("partir",),
    "partîtes": ("partir",),
    "partit": ("partir",),
    "partît": ("partir",),
    "partons": ("partir",),
    "part": ("partir",),
    "parvenaient": ("parvenir",),
    "parvenais": ("parvenir",),
    "parvenait": ("parvenir",),
    "parvenant": ("parvenir",),
    "parvenez": ("parvenir",),
    "parveniez": ("parvenir",),
    "parvenions": ("parvenir",),
    "parvenons": ("parvenir",),
    "parvenue": ("parvenir",),
    "parvenues": ("parvenir",),
    "parvenu": ("parvenir",),
    "parvenus": ("parvenir",),
    "parviendra": ("parvenir",),
    "parviendraient": ("parvenir",),
    "parviendrai": ("parvenir",),
    "parviendrais": ("parvenir",),
    "parviendrait": ("parvenir",),
    "parviendras": ("parvenir",),
    "parviendrez": ("parvenir",),
    "parviendriez": ("parvenir",),
    "parviendrions": ("parvenir",),
    "parviendrons": ("parvenir",),
    "parviendront": ("parvenir",),
    "parviennent": ("parvenir",),
    "parvienne": ("parvenir",),
    "parviennes": ("parvenir",),
    "parviens": ("parvenir",),
    "parvient": ("parvenir",),
    "parvînmes": ("parvenir",),
    "parvinrent": ("parvenir",),
    "parvins": ("parvenir",),
    "parvinssent": ("parvenir",),
    "parvinsses": ("parvenir",),
    "parvinsse": ("parvenir",),
    "parvinssiez": ("parvenir",),
    "parvinssions": ("parvenir",),
    "parvîntes": ("parvenir",),
    "parvint": ("parvenir",),
    "parvînt": ("parvenir",),
    "passageaient": ("passager",),
    "passageai": ("passager",),
    "passageais": ("passager",),
    "passageait": ("passager",),
    "passagea": ("passager",),
    "passageâmes": ("passager",),
    "passageant": ("passager",),
    "passageas": ("passager",),
    "passageassent": ("passager",),
    "passageasses": ("passager",),
    "passageasse": ("passager",),
    "passageassiez": ("passager",),
    "passageassions": ("passager",),
    "passageâtes": ("passager",),
    "passageât": ("passager",),
    "passagé": ("passager",),
    "passagent": ("passager",),
    "passageons": ("passager",),
    "passage": ("passager",),
    "passagera": ("passager",),
    "passageraient": ("passager",),
    "passagerai": ("passager",),
    "passagerais": ("passager",),
    "passagerait": ("passager",),
    "passageras": ("passager",),
    "passagèrent": ("passager",),
    "passagerez": ("passager",),
    "passageriez": ("passager",),
    "passagerions": ("passager",),
    "passagerons": ("passager",),
    "passageront": ("passager",),
    "passages": ("passager",),
    "passagez": ("passager",),
    "passagiez": ("passager",),
    "passagions": ("passager",),
    "passégeaient": ("passéger",),
    "passégeai": ("passéger",),
    "passégeais": ("passéger",),
    "passégeait": ("passéger",),
    "passégea": ("passéger",),
    "passégeâmes": ("passéger",),
    "passégeant": ("passéger",),
    "passégeas": ("passéger",),
    "passégeassent": ("passéger",),
    "passégeasses": ("passéger",),
    "passégeasse": ("passéger",),
    "passégeassiez": ("passéger",),
    "passégeassions": ("passéger",),
    "passégeâtes": ("passéger",),
    "passégeât": ("passéger",),
    "passégée": ("passéger",),
    "passégées": ("passéger",),
    "passégé": ("passéger",),
    "passègent": ("passéger",),
    "passégeons": ("passéger",),
    "passège": ("passéger",),
    "passégera": ("passéger",),
    "passégeraient": ("passéger",),
    "passégerai": ("passéger",),
    "passégerais": ("passéger",),
    "passégerait": ("passéger",),
    "passégeras": ("passéger",),
    "passégèrent": ("passéger",),
    "passégerez": ("passéger",),
    "passégeriez": ("passéger",),
    "passégerions": ("passéger",),
    "passégerons": ("passéger",),
    "passégeront": ("passéger",),
    "passégés": ("passéger",),
    "passèges": ("passéger",),
    "passégez": ("passéger",),
    "passégiez": ("passéger",),
    "passégions": ("passéger",),
    "passaient": ("passer",),
    "passai": ("passer",),
    "passais": ("passer",),
    "passait": ("passer",),
    "passa": ("passer",),
    "passâmes": ("passer",),
    "passant": ("passer",),
    "passas": ("passer",),
    "passassent": ("passer",),
    "passasses": ("passer",),
    "passasse": ("passer",),
    "passassiez": ("passer",),
    "passassions": ("passer",),
    "passâtes": ("passer",),
    "passât": ("passer",),
    "passée": ("passer",),
    "passées": ("passer",),
    "passé": ("passer",),
    "passent": ("passer",),
    "passe": ("passer",),
    "passera": ("passer",),
    "passeraient": ("passer",),
    "passerai": ("passer",),
    "passerais": ("passer",),
    "passerait": ("passer",),
    "passeras": ("passer",),
    "passèrent": ("passer",),
    "passerez": ("passer",),
    "passeriez": ("passer",),
    "passerions": ("passer",),
    "passerons": ("passer",),
    "passeront": ("passer",),
    "passés": ("passer",),
    "passes": ("passer",),
    "passez": ("passer",),
    "passiez": ("passer",),
    "passions": ("passer",),
    "passons": ("passer",),
    "patarassaient": ("patarasser",),
    "patarassai": ("patarasser",),
    "patarassais": ("patarasser",),
    "patarassait": ("patarasser",),
    "patarassa": ("patarasser",),
    "patarassâmes": ("patarasser",),
    "patarassant": ("patarasser",),
    "patarassas": ("patarasser",),
    "patarassassent": ("patarasser",),
    "patarassasses": ("patarasser",),
    "patarassasse": ("patarasser",),
    "patarassassiez": ("patarasser",),
    "patarassassions": ("patarasser",),
    "patarassâtes": ("patarasser",),
    "patarassât": ("patarasser",),
    "patarassée": ("patarasser",),
    "patarassées": ("patarasser",),
    "patarassé": ("patarasser",),
    "patarassent": ("patarasser",),
    "patarasse": ("patarasser",),
    "patarassera": ("patarasser",),
    "patarasseraient": ("patarasser",),
    "patarasserai": ("patarasser",),
    "patarasserais": ("patarasser",),
    "patarasserait": ("patarasser",),
    "patarasseras": ("patarasser",),
    "patarassèrent": ("patarasser",),
    "patarasserez": ("patarasser",),
    "patarasseriez": ("patarasser",),
    "patarasserions": ("patarasser",),
    "patarasserons": ("patarasser",),
    "patarasseront": ("patarasser",),
    "patarassés": ("patarasser",),
    "patarasses": ("patarasser",),
    "patarassez": ("patarasser",),
    "patarassiez": ("patarasser",),
    "patarassions": ("patarasser",),
    "patarassons": ("patarasser",),
    "pataugeaient": ("patauger",),
    "pataugeai": ("patauger",),
    "pataugeais": ("patauger",),
    "pataugeait": ("patauger",),
    "pataugea": ("patauger",),
    "pataugeâmes": ("patauger",),
    "pataugeant": ("patauger",),
    "pataugeas": ("patauger",),
    "pataugeassent": ("patauger",),
    "pataugeasses": ("patauger",),
    "pataugeasse": ("patauger",),
    "pataugeassiez": ("patauger",),
    "pataugeassions": ("patauger",),
    "pataugeâtes": ("patauger",),
    "pataugeât": ("patauger",),
    "pataugé": ("patauger",),
    "pataugent": ("patauger",),
    "pataugeons": ("patauger",),
    "patauge": ("patauger",),
    "pataugera": ("patauger",),
    "pataugeraient": ("patauger",),
    "pataugerai": ("patauger",),
    "pataugerais": ("patauger",),
    "pataugerait": ("patauger",),
    "pataugeras": ("patauger",),
    "pataugèrent": ("patauger",),
    "pataugerez": ("patauger",),
    "pataugeriez": ("patauger",),
    "pataugerions": ("patauger",),
    "pataugerons": ("patauger",),
    "pataugeront": ("patauger",),
    "patauges": ("patauger",),
    "pataugez": ("patauger",),
    "pataugiez": ("patauger",),
    "pataugions": ("patauger",),
    "pâtaient": ("pâter",),
    "pâtai": ("pâter",),
    "pâtais": ("pâter",),
    "pâtait": ("pâter",),
    "pâta": ("pâter",),
    "pâtâmes": ("pâter",),
    "pâtant": ("pâter",),
    "pâtas": ("pâter",),
    "pâtassent": ("pâter",),
    "pâtasses": ("pâter",),
    "pâtasse": ("pâter",),
    "pâtassiez": ("pâter",),
    "pâtassions": ("pâter",),
    "pâtâtes": ("pâter",),
    "pâtât": ("pâter",),
    "pâté": ("pâter",),
    "pâtent": ("pâter",),
    "pâte": ("pâter",),
    "pâtera": ("pâter",),
    "pâteraient": ("pâter",),
    "pâterai": ("pâter",),
    "pâterais": ("pâter",),
    "pâterait": ("pâter",),
    "pâteras": ("pâter",),
    "pâtèrent": ("pâter",),
    "pâterez": ("pâter",),
    "pâteriez": ("pâter",),
    "pâterions": ("pâter",),
    "pâterons": ("pâter",),
    "pâteront": ("pâter",),
    "pâtes": ("pâter",),
    "pâtez": ("pâter",),
    "pâtiez": ("pâter",),
    "pâtions": ("pâter",),
    "pâtons": ("pâter",),
    "pâti": ("pâtir",),
    "pâtîmes": ("pâtir",),
    "pâtira": ("pâtir",),
    "pâtiraient": ("pâtir",),
    "pâtirai": ("pâtir",),
    "pâtirais": ("pâtir",),
    "pâtirait": ("pâtir",),
    "pâtiras": ("pâtir",),
    "pâtirent": ("pâtir",),
    "pâtirez": ("pâtir",),
    "pâtiriez": ("pâtir",),
    "pâtirions": ("pâtir",),
    "pâtirons": ("pâtir",),
    "pâtiront": ("pâtir",),
    "pâtis": ("pâtir",),
    "pâtissaient": ("pâtir",),
    "pâtissais": ("pâtir",),
    "pâtissait": ("pâtir",),
    "pâtissant": ("pâtir",),
    "pâtissent": ("pâtir",),
    "pâtisse": ("pâtir",),
    "pâtisses": ("pâtir",),
    "pâtissez": ("pâtir",),
    "pâtissiez": ("pâtir",),
    "pâtissions": ("pâtir",),
    "pâtissons": ("pâtir",),
    "pâtîtes": ("pâtir",),
    "pâtit": ("pâtir",),
    "pâtît": ("pâtir",),
    "paumoient": ("paumoyer",),
    "paumoie": ("paumoyer",),
    "paumoiera": ("paumoyer",),
    "paumoieraient": ("paumoyer",),
    "paumoierai": ("paumoyer",),
    "paumoierais": ("paumoyer",),
    "paumoierait": ("paumoyer",),
    "paumoieras": ("paumoyer",),
    "paumoierez": ("paumoyer",),
    "paumoieriez": ("paumoyer",),
    "paumoierions": ("paumoyer",),
    "paumoierons": ("paumoyer",),
    "paumoieront": ("paumoyer",),
    "paumoies": ("paumoyer",),
    "paumoyaient": ("paumoyer",),
    "paumoyai": ("paumoyer",),
    "paumoyais": ("paumoyer",),
    "paumoyait": ("paumoyer",),
    "paumoya": ("paumoyer",),
    "paumoyâmes": ("paumoyer",),
    "paumoyant": ("paumoyer",),
    "paumoyas": ("paumoyer",),
    "paumoyassent": ("paumoyer",),
    "paumoyasses": ("paumoyer",),
    "paumoyasse": ("paumoyer",),
    "paumoyassiez": ("paumoyer",),
    "paumoyassions": ("paumoyer",),
    "paumoyâtes": ("paumoyer",),
    "paumoyât": ("paumoyer",),
    "paumoyée": ("paumoyer",),
    "paumoyées": ("paumoyer",),
    "paumoyé": ("paumoyer",),
    "paumoyèrent": ("paumoyer",),
    "paumoyés": ("paumoyer",),
    "paumoyez": ("paumoyer",),
    "paumoyiez": ("paumoyer",),
    "paumoyions": ("paumoyer",),
    "paumoyons": ("paumoyer",),
    "paient": ("payer",),
    "paie": ("payer",),
    "paiera": ("payer",),
    "paieraient": ("payer",),
    "paierai": ("payer",),
    "paierais": ("payer",),
    "paierait": ("payer",),
    "paieras": ("payer",),
    "paierez": ("payer",),
    "paieriez": ("payer",),
    "paierions": ("payer",),
    "paierons": ("payer",),
    "paieront": ("payer",),
    "paies": ("payer",),
    "payaient": ("payer",),
    "payai": ("payer",),
    "payais": ("payer",),
    "payait": ("payer",),
    "paya": ("payer",),
    "payâmes": ("payer",),
    "payant": ("payer",),
    "payas": ("payer",),
    "payassent": ("payer",),
    "payasses": ("payer",),
    "payasse": ("payer",),
    "payassiez": ("payer",),
    "payassions": ("payer",),
    "payâtes": ("payer",),
    "payât": ("payer",),
    "payée": ("payer",),
    "payées": ("payer",),
    "payé": ("payer",),
    "payent": ("payer",),
    "paye": ("payer",),
    "payera": ("payer",),
    "payeraient": ("payer",),
    "payerai": ("payer",),
    "payerais": ("payer",),
    "payerait": ("payer",),
    "payeras": ("payer",),
    "payèrent": ("payer",),
    "payerez": ("payer",),
    "payeriez": ("payer",),
    "payerions": ("payer",),
    "payerons": ("payer",),
    "payeront": ("payer",),
    "payés": ("payer",),
    "payes": ("payer",),
    "payez": ("payer",),
    "payiez": ("payer",),
    "payions": ("payer",),
    "payons": ("payer",),
    "paysageaient": ("paysager",),
    "paysageai": ("paysager",),
    "paysageais": ("paysager",),
    "paysageait": ("paysager",),
    "paysagea": ("paysager",),
    "paysageâmes": ("paysager",),
    "paysageant": ("paysager",),
    "paysageas": ("paysager",),
    "paysageassent": ("paysager",),
    "paysageasses": ("paysager",),
    "paysageasse": ("paysager",),
    "paysageassiez": ("paysager",),
    "paysageassions": ("paysager",),
    "paysageâtes": ("paysager",),
    "paysageât": ("paysager",),
    "paysagée": ("paysager",),
    "paysagées": ("paysager",),
    "paysagé": ("paysager",),
    "paysagent": ("paysager",),
    "paysageons": ("paysager",),
    "paysage": ("paysager",),
    "paysagera": ("paysager",),
    "paysageraient": ("paysager",),
    "paysagerai": ("paysager",),
    "paysagerais": ("paysager",),
    "paysagerait": ("paysager",),
    "paysageras": ("paysager",),
    "paysagèrent": ("paysager",),
    "paysagerez": ("paysager",),
    "paysageriez": ("paysager",),
    "paysagerions": ("paysager",),
    "paysagerons": ("paysager",),
    "paysageront": ("paysager",),
    "paysagés": ("paysager",),
    "paysages": ("paysager",),
    "paysagez": ("paysager",),
    "paysagiez": ("paysager",),
    "paysagions": ("paysager",),
    "peignaient": ("peindre",),
    "peignais": ("peindre",),
    "peignait": ("peindre",),
    "peignant": ("peindre",),
    "peignent": ("peindre",),
    "peigne": ("peindre",),
    "peignes": ("peindre",),
    "peignez": ("peindre",),
    "peigniez": ("peindre",),
    "peignîmes": ("peindre",),
    "peignions": ("peindre",),
    "peignirent": ("peindre",),
    "peignis": ("peindre",),
    "peignissent": ("peindre",),
    "peignisses": ("peindre",),
    "peignisse": ("peindre",),
    "peignissiez": ("peindre",),
    "peignissions": ("peindre",),
    "peignîtes": ("peindre",),
    "peignit": ("peindre",),
    "peignît": ("peindre",),
    "peignons": ("peindre",),
    "peindra": ("peindre",),
    "peindraient": ("peindre",),
    "peindrai": ("peindre",),
    "peindrais": ("peindre",),
    "peindrait": ("peindre",),
    "peindras": ("peindre",),
    "peindrez": ("peindre",),
    "peindriez": ("peindre",),
    "peindrions": ("peindre",),
    "peindrons": ("peindre",),
    "peindront": ("peindre",),
    "peins": ("peindre",),
    "peinte": ("peindre",),
    "peintes": ("peindre",),
    "peint": ("peindre",),
    "peints": ("peindre",),
    "pelaient": ("peler",),
    "pelai": ("peler",),
    "pelais": ("peler",),
    "pelait": ("peler",),
    "pela": ("peler",),
    "pelâmes": ("peler",),
    "pelant": ("peler",),
    "pelas": ("peler",),
    "pelassent": ("peler",),
    "pelasses": ("peler",),
    "pelasse": ("peler",),
    "pelassiez": ("peler",),
    "pelassions": ("peler",),
    "pelâtes": ("peler",),
    "pelât": ("peler",),
    "pelée": ("peler",),
    "pelées": ("peler",),
    "pelé": ("peler",),
    "pèlent": ("peler",),
    "pèle": ("peler",),
    "pèlera": ("peler",),
    "pèleraient": ("peler",),
    "pèlerai": ("peler",),
    "pèlerais": ("peler",),
    "pèlerait": ("peler",),
    "pèleras": ("peler",),
    "pelèrent": ("peler",),
    "pèlerez": ("peler",),
    "pèleriez": ("peler",),
    "pèlerions": ("peler",),
    "pèlerons": ("peler",),
    "pèleront": ("peler",),
    "pelés": ("peler",),
    "pèles": ("peler",),
    "pelez": ("peler",),
    "peliez": ("peler",),
    "pelions": ("peler",),
    "pelons": ("peler",),
    "pelletaient": ("pelleter",),
    "pelletai": ("pelleter",),
    "pelletais": ("pelleter",),
    "pelletait": ("pelleter",),
    "pelleta": ("pelleter",),
    "pelletâmes": ("pelleter",),
    "pelletant": ("pelleter",),
    "pelletas": ("pelleter",),
    "pelletassent": ("pelleter",),
    "pelletasses": ("pelleter",),
    "pelletasse": ("pelleter",),
    "pelletassiez": ("pelleter",),
    "pelletassions": ("pelleter",),
    "pelletâtes": ("pelleter",),
    "pelletât": ("pelleter",),
    "pelletée": ("pelleter",),
    "pelletées": ("pelleter",),
    "pelleté": ("pelleter",),
    "pelletèrent": ("pelleter",),
    "pelletés": ("pelleter",),
    "pelletez": ("pelleter",),
    "pelletiez": ("pelleter",),
    "pelletions": ("pelleter",),
    "pelletons": ("pelleter",),
    "pellettent": ("pelleter",),
    "pellette": ("pelleter",),
    "pellettera": ("pelleter",),
    "pelletteraient": ("pelleter",),
    "pelletterai": ("pelleter",),
    "pelletterais": ("pelleter",),
    "pelletterait": ("pelleter",),
    "pelletteras": ("pelleter",),
    "pelletterez": ("pelleter",),
    "pelletteriez": ("pelleter",),
    "pelletterions": ("pelleter",),
    "pelletterons": ("pelleter",),
    "pelletteront": ("pelleter",),
    "pellettes": ("pelleter",),
    "pendaient": ("pendre",),
    "pendais": ("pendre",),
    "pendait": ("pendre",),
    "pendant": ("pendre",),
    "pendent": ("pendre",),
    "pende": ("pendre",),
    "pendes": ("pendre",),
    "pendez": ("pendre",),
    "pendiez": ("pendre",),
    "pendîmes": ("pendre",),
    "pendions": ("pendre",),
    "pendirent": ("pendre",),
    "pendis": ("pendre",),
    "pendissent": ("pendre",),
    "pendisses": ("pendre",),
    "pendisse": ("pendre",),
    "pendissiez": ("pendre",),
    "pendissions": ("pendre",),
    "pendîtes": ("pendre",),
    "pendit": ("pendre",),
    "pendît": ("pendre",),
    "pendons": ("pendre",),
    "pend": ("pendre",),
    "pendra": ("pendre",),
    "pendraient": ("pendre",),
    "pendrai": ("pendre",),
    "pendrais": ("pendre",),
    "pendrait": ("pendre",),
    "pendras": ("pendre",),
    "pendrez": ("pendre",),
    "pendriez": ("pendre",),
    "pendrions": ("pendre",),
    "pendrons": ("pendre",),
    "pendront": ("pendre",),
    "pends": ("pendre",),
    "pendue": ("pendre",),
    "pendues": ("pendre",),
    "pendu": ("pendre",),
    "pendus": ("pendre",),
    "pénétraient": ("pénétrer",),
    "pénétrai": ("pénétrer",),
    "pénétrais": ("pénétrer",),
    "pénétrait": ("pénétrer",),
    "pénétra": ("pénétrer",),
    "pénétrâmes": ("pénétrer",),
    "pénétrant": ("pénétrer",),
    "pénétras": ("pénétrer",),
    "pénétrassent": ("pénétrer",),
    "pénétrasses": ("pénétrer",),
    "pénétrasse": ("pénétrer",),
    "pénétrassiez": ("pénétrer",),
    "pénétrassions": ("pénétrer",),
    "pénétrâtes": ("pénétrer",),
    "pénétrât": ("pénétrer",),
    "pénétrée": ("pénétrer",),
    "pénétrées": ("pénétrer",),
    "pénétré": ("pénétrer",),
    "pénètrent": ("pénétrer",),
    "pénètre": ("pénétrer",),
    "pénétrera": ("pénétrer",),
    "pénétreraient": ("pénétrer",),
    "pénétrerai": ("pénétrer",),
    "pénétrerais": ("pénétrer",),
    "pénétrerait": ("pénétrer",),
    "pénétreras": ("pénétrer",),
    "pénétrèrent": ("pénétrer",),
    "pénétrerez": ("pénétrer",),
    "pénétreriez": ("pénétrer",),
    "pénétrerions": ("pénétrer",),
    "pénétrerons": ("pénétrer",),
    "pénétreront": ("pénétrer",),
    "pénétrés": ("pénétrer",),
    "pénètres": ("pénétrer",),
    "pénétrez": ("pénétrer",),
    "pénétriez": ("pénétrer",),
    "pénétrions": ("pénétrer",),
    "pénétrons": ("pénétrer",),
    "pépiaient": ("pépier",),
    "pépiai": ("pépier",),
    "pépiais": ("pépier",),
    "pépiait": ("pépier",),
    "pépia": ("pépier",),
    "pépiâmes": ("pépier",),
    "pépiant": ("pépier",),
    "pépias": ("pépier",),
    "pépiassent": ("pépier",),
    "pépiasses": ("pépier",),
    "pépiasse": ("pépier",),
    "pépiassiez": ("pépier",),
    "pépiassions": ("pépier",),
    "pépiâtes": ("pépier",),
    "pépiât": ("pépier",),
    "pépiée": ("pépier",),
    "pépiées": ("pépier",),
    "pépié": ("pépier",),
    "pépient": ("pépier",),
    "pépie": ("pépier",),
    "pépiera": ("pépier",),
    "pépieraient": ("pépier",),
    "pépierai": ("pépier",),
    "pépierais": ("pépier",),
    "pépierait": ("pépier",),
    "pépieras": ("pépier",),
    "pépièrent": ("pépier",),
    "pépierez": ("pépier",),
    "pépieriez": ("pépier",),
    "pépierions": ("pépier",),
    "pépierons": ("pépier",),
    "pépieront": ("pépier",),
    "pépiés": ("pépier",),
    "pépies": ("pépier",),
    "pépiez": ("pépier",),
    "pépiiez": ("pépier",),
    "pépiions": ("pépier",),
    "pépions": ("pépier",),
    "peptonifiaient": ("peptonifier",),
    "peptonifiai": ("peptonifier",),
    "peptonifiais": ("peptonifier",),
    "peptonifiait": ("peptonifier",),
    "peptonifia": ("peptonifier",),
    "peptonifiâmes": ("peptonifier",),
    "peptonifiant": ("peptonifier",),
    "peptonifias": ("peptonifier",),
    "peptonifiassent": ("peptonifier",),
    "peptonifiasses": ("peptonifier",),
    "peptonifiasse": ("peptonifier",),
    "peptonifiassiez": ("peptonifier",),
    "peptonifiassions": ("peptonifier",),
    "peptonifiâtes": ("peptonifier",),
    "peptonifiât": ("peptonifier",),
    "peptonifiée": ("peptonifier",),
    "peptonifiées": ("peptonifier",),
    "peptonifié": ("peptonifier",),
    "peptonifient": ("peptonifier",),
    "peptonifie": ("peptonifier",),
    "peptonifiera": ("peptonifier",),
    "peptonifieraient": ("peptonifier",),
    "peptonifierai": ("peptonifier",),
    "peptonifierais": ("peptonifier",),
    "peptonifierait": ("peptonifier",),
    "peptonifieras": ("peptonifier",),
    "peptonifièrent": ("peptonifier",),
    "peptonifierez": ("peptonifier",),
    "peptonifieriez": ("peptonifier",),
    "peptonifierions": ("peptonifier",),
    "peptonifierons": ("peptonifier",),
    "peptonifieront": ("peptonifier",),
    "peptonifiés": ("peptonifier",),
    "peptonifies": ("peptonifier",),
    "peptonifiez": ("peptonifier",),
    "peptonifiiez": ("peptonifier",),
    "peptonifiions": ("peptonifier",),
    "peptonifions": ("peptonifier",),
    "perçaient": ("percer",),
    "perçai": ("percer",),
    "perçais": ("percer",),
    "perçait": ("percer",),
    "perça": ("percer",),
    "perçâmes": ("percer",),
    "perçant": ("percer",),
    "perças": ("percer",),
    "perçassent": ("percer",),
    "perçasses": ("percer",),
    "perçasse": ("percer",),
    "perçassiez": ("percer",),
    "perçassions": ("percer",),
    "perçâtes": ("percer",),
    "perçât": ("percer",),
    "percée": ("percer",),
    "percées": ("percer",),
    "percé": ("percer",),
    "percent": ("percer",),
    "perce": ("percer",),
    "percera": ("percer",),
    "perceraient": ("percer",),
    "percerai": ("percer",),
    "percerais": ("percer",),
    "percerait": ("percer",),
    "perceras": ("percer",),
    "percèrent": ("percer",),
    "percerez": ("percer",),
    "perceriez": ("percer",),
    "percerions": ("percer",),
    "percerons": ("percer",),
    "perceront": ("percer",),
    "percés": ("percer",),
    "perces": ("percer",),
    "percez": ("percer",),
    "perciez": ("percer",),
    "percions": ("percer",),
    "perçons": ("percer",),
    "percevaient": ("percevoir",),
    "percevais": ("percevoir",),
    "percevait": ("percevoir",),
    "percevant": ("percevoir",),
    "percevez": ("percevoir",),
    "perceviez": ("percevoir",),
    "percevions": ("percevoir",),
    "percevons": ("percevoir",),
    "percevra": ("percevoir",),
    "percevraient": ("percevoir",),
    "percevrai": ("percevoir",),
    "percevrais": ("percevoir",),
    "percevrait": ("percevoir",),
    "percevras": ("percevoir",),
    "percevrez": ("percevoir",),
    "percevriez": ("percevoir",),
    "percevrions": ("percevoir",),
    "percevrons": ("percevoir",),
    "percevront": ("percevoir",),
    "perçois": ("percevoir",),
    "perçoit": ("percevoir",),
    "perçoivent": ("percevoir",),
    "perçoive": ("percevoir",),
    "perçoives": ("percevoir",),
    "perçue": ("percevoir",),
    "perçues": ("percevoir",),
    "perçu": ("percevoir",),
    "perçûmes": ("percevoir",),
    "perçurent": ("percevoir",),
    "perçus": ("percevoir",),
    "perçussent": ("percevoir",),
    "perçusses": ("percevoir",),
    "perçusse": ("percevoir",),
    "perçussiez": ("percevoir",),
    "perçussions": ("percevoir",),
    "perçûtes": ("percevoir",),
    "perçut": ("percevoir",),
    "perçût": ("percevoir",),
    "percluse": ("perclure",),
    "percluses": ("perclure",),
    "perclus": ("perclure",),
    "perclut": ("perclure",),
    "perdaient": ("perdre",),
    "perdais": ("perdre",),
    "perdait": ("perdre",),
    "perdant": ("perdre",),
    "perdent": ("perdre",),
    "perde": ("perdre",),
    "perdes": ("perdre",),
    "perdez": ("perdre",),
    "perdiez": ("perdre",),
    "perdîmes": ("perdre",),
    "perdions": ("perdre",),
    "perdirent": ("perdre",),
    "perdis": ("perdre",),
    "perdissent": ("perdre",),
    "perdisses": ("perdre",),
    "perdisse": ("perdre",),
    "perdissiez": ("perdre",),
    "perdissions": ("perdre",),
    "perdîtes": ("perdre",),
    "perdit": ("perdre",),
    "perdît": ("perdre",),
    "perdons": ("perdre",),
    "perd": ("perdre",),
    "perdra": ("perdre",),
    "perdraient": ("perdre",),
    "perdrai": ("perdre",),
    "perdrais": ("perdre",),
    "perdrait": ("perdre",),
    "perdras": ("perdre",),
    "perdrez": ("perdre",),
    "perdriez": ("perdre",),
    "perdrions": ("perdre",),
    "perdrons": ("perdre",),
    "perdront": ("perdre",),
    "perds": ("perdre",),
    "perdue": ("perdre",),
    "perdues": ("perdre",),
    "perdu": ("perdre",),
    "perdus": ("perdre",),
    "peréquaient": ("peréquer",),
    "peréquai": ("peréquer",),
    "peréquais": ("peréquer",),
    "peréquait": ("peréquer",),
    "peréqua": ("peréquer",),
    "peréquâmes": ("peréquer",),
    "peréquant": ("peréquer",),
    "peréquas": ("peréquer",),
    "peréquassent": ("peréquer",),
    "peréquasses": ("peréquer",),
    "peréquasse": ("peréquer",),
    "peréquassiez": ("peréquer",),
    "peréquassions": ("peréquer",),
    "peréquâtes": ("peréquer",),
    "peréquât": ("peréquer",),
    "peréquée": ("peréquer",),
    "peréquées": ("peréquer",),
    "peréqué": ("peréquer",),
    "perèquent": ("peréquer",),
    "perèque": ("peréquer",),
    "peréquera": ("peréquer",),
    "peréqueraient": ("peréquer",),
    "peréquerai": ("peréquer",),
    "peréquerais": ("peréquer",),
    "peréquerait": ("peréquer",),
    "peréqueras": ("peréquer",),
    "peréquèrent": ("peréquer",),
    "peréquerez": ("peréquer",),
    "peréqueriez": ("peréquer",),
    "peréquerions": ("peréquer",),
    "peréquerons": ("peréquer",),
    "peréqueront": ("peréquer",),
    "peréqués": ("peréquer",),
    "perèques": ("peréquer",),
    "peréquez": ("peréquer",),
    "peréquiez": ("peréquer",),
    "peréquions": ("peréquer",),
    "peréquons": ("peréquer",),
    "péri": ("périr",),
    "pérîmes": ("périr",),
    "périra": ("périr",),
    "périraient": ("périr",),
    "périrai": ("périr",),
    "périrais": ("périr",),
    "périrait": ("périr",),
    "périras": ("périr",),
    "périrent": ("périr",),
    "périrez": ("périr",),
    "péririez": ("périr",),
    "péririons": ("périr",),
    "périrons": ("périr",),
    "périront": ("périr",),
    "péris": ("périr",),
    "périssaient": ("périr",),
    "périssais": ("périr",),
    "périssait": ("périr",),
    "périssant": ("périr",),
    "périssent": ("périr",),
    "périsse": ("périr",),
    "périsses": ("périr",),
    "périssez": ("périr",),
    "périssiez": ("périr",),
    "périssions": ("périr",),
    "périssons": ("périr",),
    "pérîtes": ("périr",),
    "périt": ("périr",),
    "pérît": ("périr",),
    "permet": ("permettre",),
    "permets": ("permettre",),
    "permettaient": ("permettre",),
    "permettais": ("permettre",),
    "permettait": ("permettre",),
    "permettant": ("permettre",),
    "permettent": ("permettre",),
    "permette": ("permettre",),
    "permettes": ("permettre",),
    "permettez": ("permettre",),
    "permettiez": ("permettre",),
    "permettions": ("permettre",),
    "permettons": ("permettre",),
    "permettra": ("permettre",),
    "permettraient": ("permettre",),
    "permettrai": ("permettre",),
    "permettrais": ("permettre",),
    "permettrait": ("permettre",),
    "permettras": ("permettre",),
    "permettrez": ("permettre",),
    "permettriez": ("permettre",),
    "permettrions": ("permettre",),
    "permettrons": ("permettre",),
    "permettront": ("permettre",),
    "permîmes": ("permettre",),
    "permirent": ("permettre",),
    "permise": ("permettre",),
    "permises": ("permettre",),
    "permis": ("permettre",),
    "permissent": ("permettre",),
    "permisses": ("permettre",),
    "permisse": ("permettre",),
    "permissiez": ("permettre",),
    "permissions": ("permettre",),
    "permîtes": ("permettre",),
    "permit": ("permettre",),
    "permît": ("permettre",),
    "perpétraient": ("perpétrer",),
    "perpétrai": ("perpétrer",),
    "perpétrais": ("perpétrer",),
    "perpétrait": ("perpétrer",),
    "perpétra": ("perpétrer",),
    "perpétrâmes": ("perpétrer",),
    "perpétrant": ("perpétrer",),
    "perpétras": ("perpétrer",),
    "perpétrassent": ("perpétrer",),
    "perpétrasses": ("perpétrer",),
    "perpétrasse": ("perpétrer",),
    "perpétrassiez": ("perpétrer",),
    "perpétrassions": ("perpétrer",),
    "perpétrâtes": ("perpétrer",),
    "perpétrât": ("perpétrer",),
    "perpétrée": ("perpétrer",),
    "perpétrées": ("perpétrer",),
    "perpétré": ("perpétrer",),
    "perpètrent": ("perpétrer",),
    "perpètre": ("perpétrer",),
    "perpétrera": ("perpétrer",),
    "perpétreraient": ("perpétrer",),
    "perpétrerai": ("perpétrer",),
    "perpétrerais": ("perpétrer",),
    "perpétrerait": ("perpétrer",),
    "perpétreras": ("perpétrer",),
    "perpétrèrent": ("perpétrer",),
    "perpétrerez": ("perpétrer",),
    "perpétreriez": ("perpétrer",),
    "perpétrerions": ("perpétrer",),
    "perpétrerons": ("perpétrer",),
    "perpétreront": ("perpétrer",),
    "perpétrés": ("perpétrer",),
    "perpètres": ("perpétrer",),
    "perpétrez": ("perpétrer",),
    "perpétriez": ("perpétrer",),
    "perpétrions": ("perpétrer",),
    "perpétrons": ("perpétrer",),
    "persévéraient": ("persévérer",),
    "persévérai": ("persévérer",),
    "persévérais": ("persévérer",),
    "persévérait": ("persévérer",),
    "persévéra": ("persévérer",),
    "persévérâmes": ("persévérer",),
    "persévérant": ("persévérer",),
    "persévéras": ("persévérer",),
    "persévérassent": ("persévérer",),
    "persévérasses": ("persévérer",),
    "persévérasse": ("persévérer",),
    "persévérassiez": ("persévérer",),
    "persévérassions": ("persévérer",),
    "persévérâtes": ("persévérer",),
    "persévérât": ("persévérer",),
    "persévéré": ("persévérer",),
    "persévèrent": ("persévérer",),
    "persévère": ("persévérer",),
    "persévérera": ("persévérer",),
    "persévéreraient": ("persévérer",),
    "persévérerai": ("persévérer",),
    "persévérerais": ("persévérer",),
    "persévérerait": ("persévérer",),
    "persévéreras": ("persévérer",),
    "persévérèrent": ("persévérer",),
    "persévérerez": ("persévérer",),
    "persévéreriez": ("persévérer",),
    "persévérerions": ("persévérer",),
    "persévérerons": ("persévérer",),
    "persévéreront": ("persévérer",),
    "persévères": ("persévérer",),
    "persévérez": ("persévérer",),
    "persévériez": ("persévérer",),
    "persévérions": ("persévérer",),
    "persévérons": ("persévérer",),
    "personnifiaient": ("personnifier",),
    "personnifiai": ("personnifier",),
    "personnifiais": ("personnifier",),
    "personnifiait": ("personnifier",),
    "personnifia": ("personnifier",),
    "personnifiâmes": ("personnifier",),
    "personnifiant": ("personnifier",),
    "personnifias": ("personnifier",),
    "personnifiassent": ("personnifier",),
    "personnifiasses": ("personnifier",),
    "personnifiasse": ("personnifier",),
    "personnifiassiez": ("personnifier",),
    "personnifiassions": ("personnifier",),
    "personnifiâtes": ("personnifier",),
    "personnifiât": ("personnifier",),
    "personnifiée": ("personnifier",),
    "personnifiées": ("personnifier",),
    "personnifié": ("personnifier",),
    "personnifient": ("personnifier",),
    "personnifie": ("personnifier",),
    "personnifiera": ("personnifier",),
    "personnifieraient": ("personnifier",),
    "personnifierai": ("personnifier",),
    "personnifierais": ("personnifier",),
    "personnifierait": ("personnifier",),
    "personnifieras": ("personnifier",),
    "personnifièrent": ("personnifier",),
    "personnifierez": ("personnifier",),
    "personnifieriez": ("personnifier",),
    "personnifierions": ("personnifier",),
    "personnifierons": ("personnifier",),
    "personnifieront": ("personnifier",),
    "personnifiés": ("personnifier",),
    "personnifies": ("personnifier",),
    "personnifiez": ("personnifier",),
    "personnifiiez": ("personnifier",),
    "personnifiions": ("personnifier",),
    "personnifions": ("personnifier",),
    "pervertie": ("pervertir",),
    "perverties": ("pervertir",),
    "perverti": ("pervertir",),
    "pervertîmes": ("pervertir",),
    "pervertira": ("pervertir",),
    "pervertiraient": ("pervertir",),
    "pervertirai": ("pervertir",),
    "pervertirais": ("pervertir",),
    "pervertirait": ("pervertir",),
    "pervertiras": ("pervertir",),
    "pervertirent": ("pervertir",),
    "pervertirez": ("pervertir",),
    "pervertiriez": ("pervertir",),
    "pervertirions": ("pervertir",),
    "pervertirons": ("pervertir",),
    "pervertiront": ("pervertir",),
    "pervertis": ("pervertir",),
    "pervertissaient": ("pervertir",),
    "pervertissais": ("pervertir",),
    "pervertissait": ("pervertir",),
    "pervertissant": ("pervertir",),
    "pervertissent": ("pervertir",),
    "pervertisse": ("pervertir",),
    "pervertisses": ("pervertir",),
    "pervertissez": ("pervertir",),
    "pervertissiez": ("pervertir",),
    "pervertissions": ("pervertir",),
    "pervertissons": ("pervertir",),
    "pervertîtes": ("pervertir",),
    "pervertit": ("pervertir",),
    "pervertît": ("pervertir",),
    "pesaient": ("peser",),
    "pesai": ("peser",),
    "pesais": ("peser",),
    "pesait": ("peser",),
    "pesa": ("peser",),
    "pesâmes": ("peser",),
    "pesant": ("peser",),
    "pesas": ("peser",),
    "pesassent": ("peser",),
    "pesasses": ("peser",),
    "pesasse": ("peser",),
    "pesassiez": ("peser",),
    "pesassions": ("peser",),
    "pesâtes": ("peser",),
    "pesât": ("peser",),
    "pesée": ("peser",),
    "pesées": ("peser",),
    "pesé": ("peser",),
    "pèsent": ("peser",),
    "pèse": ("peser",),
    "pèsera": ("peser",),
    "pèseraient": ("peser",),
    "pèserai": ("peser",),
    "pèserais": ("peser",),
    "pèserait": ("peser",),
    "pèseras": ("peser",),
    "pesèrent": ("peser",),
    "pèserez": ("peser",),
    "pèseriez": ("peser",),
    "pèserions": ("peser",),
    "pèserons": ("peser",),
    "pèseront": ("peser",),
    "pesés": ("peser",),
    "pèses": ("peser",),
    "pesez": ("peser",),
    "pesiez": ("peser",),
    "pesions": ("peser",),
    "pesons": ("peser",),
    "pestiféraient": ("pestiférer",),
    "pestiférai": ("pestiférer",),
    "pestiférais": ("pestiférer",),
    "pestiférait": ("pestiférer",),
    "pestiféra": ("pestiférer",),
    "pestiférâmes": ("pestiférer",),
    "pestiférant": ("pestiférer",),
    "pestiféras": ("pestiférer",),
    "pestiférassent": ("pestiférer",),
    "pestiférasses": ("pestiférer",),
    "pestiférasse": ("pestiférer",),
    "pestiférassiez": ("pestiférer",),
    "pestiférassions": ("pestiférer",),
    "pestiférâtes": ("pestiférer",),
    "pestiférât": ("pestiférer",),
    "pestiférée": ("pestiférer",),
    "pestiférées": ("pestiférer",),
    "pestiféré": ("pestiférer",),
    "pestifèrent": ("pestiférer",),
    "pestifère": ("pestiférer",),
    "pestiférera": ("pestiférer",),
    "pestiféreraient": ("pestiférer",),
    "pestiférerai": ("pestiférer",),
    "pestiférerais": ("pestiférer",),
    "pestiférerait": ("pestiférer",),
    "pestiféreras": ("pestiférer",),
    "pestiférèrent": ("pestiférer",),
    "pestiférerez": ("pestiférer",),
    "pestiféreriez": ("pestiférer",),
    "pestiférerions": ("pestiférer",),
    "pestiférerons": ("pestiférer",),
    "pestiféreront": ("pestiférer",),
    "pestiférés": ("pestiférer",),
    "pestifères": ("pestiférer",),
    "pestiférez": ("pestiférer",),
    "pestifériez": ("pestiférer",),
    "pestiférions": ("pestiférer",),
    "pestiférons": ("pestiférer",),
    "pétaient": ("péter",),
    "pétai": ("péter",),
    "pétais": ("péter",),
    "pétait": ("péter",),
    "péta": ("péter",),
    "pétâmes": ("péter",),
    "pétant": ("péter",),
    "pétas": ("péter",),
    "pétassent": ("péter",),
    "pétasses": ("péter",),
    "pétasse": ("péter",),
    "pétassiez": ("péter",),
    "pétassions": ("péter",),
    "pétâtes": ("péter",),
    "pétât": ("péter",),
    "pétée": ("péter",),
    "pétées": ("péter",),
    "pété": ("péter",),
    "pètent": ("péter",),
    "pète": ("péter",),
    "pétera": ("péter",),
    "péteraient": ("péter",),
    "péterai": ("péter",),
    "péterais": ("péter",),
    "péterait": ("péter",),
    "péteras": ("péter",),
    "pétèrent": ("péter",),
    "péterez": ("péter",),
    "péteriez": ("péter",),
    "péterions": ("péter",),
    "péterons": ("péter",),
    "péteront": ("péter",),
    "pétés": ("péter",),
    "pètes": ("péter",),
    "pétez": ("péter",),
    "pétiez": ("péter",),
    "pétions": ("péter",),
    "pétons": ("péter",),
    "pétrifiaient": ("pétrifier",),
    "pétrifiai": ("pétrifier",),
    "pétrifiais": ("pétrifier",),
    "pétrifiait": ("pétrifier",),
    "pétrifia": ("pétrifier",),
    "pétrifiâmes": ("pétrifier",),
    "pétrifiant": ("pétrifier",),
    "pétrifias": ("pétrifier",),
    "pétrifiassent": ("pétrifier",),
    "pétrifiasses": ("pétrifier",),
    "pétrifiasse": ("pétrifier",),
    "pétrifiassiez": ("pétrifier",),
    "pétrifiassions": ("pétrifier",),
    "pétrifiâtes": ("pétrifier",),
    "pétrifiât": ("pétrifier",),
    "pétrifiée": ("pétrifier",),
    "pétrifiées": ("pétrifier",),
    "pétrifié": ("pétrifier",),
    "pétrifient": ("pétrifier",),
    "pétrifie": ("pétrifier",),
    "pétrifiera": ("pétrifier",),
    "pétrifieraient": ("pétrifier",),
    "pétrifierai": ("pétrifier",),
    "pétrifierais": ("pétrifier",),
    "pétrifierait": ("pétrifier",),
    "pétrifieras": ("pétrifier",),
    "pétrifièrent": ("pétrifier",),
    "pétrifierez": ("pétrifier",),
    "pétrifieriez": ("pétrifier",),
    "pétrifierions": ("pétrifier",),
    "pétrifierons": ("pétrifier",),
    "pétrifieront": ("pétrifier",),
    "pétrifiés": ("pétrifier",),
    "pétrifies": ("pétrifier",),
    "pétrifiez": ("pétrifier",),
    "pétrifiiez": ("pétrifier",),
    "pétrifiions": ("pétrifier",),
    "pétrifions": ("pétrifier",),
    "pétrie": ("pétrir",),
    "pétries": ("pétrir",),
    "pétri": ("pétrir",),
    "pétrîmes": ("pétrir",),
    "pétrira": ("pétrir",),
    "pétriraient": ("pétrir",),
    "pétrirai": ("pétrir",),
    "pétrirais": ("pétrir",),
    "pétrirait": ("pétrir",),
    "pétriras": ("pétrir",),
    "pétrirent": ("pétrir",),
    "pétrirez": ("pétrir",),
    "pétririez": ("pétrir",),
    "pétririons": ("pétrir",),
    "pétrirons": ("pétrir",),
    "pétriront": ("pétrir",),
    "pétris": ("pétrir",),
    "pétrissaient": ("pétrir",),
    "pétrissais": ("pétrir",),
    "pétrissait": ("pétrir",),
    "pétrissant": ("pétrir",),
    "pétrissent": ("pétrir",),
    "pétrisse": ("pétrir",),
    "pétrisses": ("pétrir",),
    "pétrissez": ("pétrir",),
    "pétrissiez": ("pétrir",),
    "pétrissions": ("pétrir",),
    "pétrissons": ("pétrir",),
    "pétrîtes": ("pétrir",),
    "pétrit": ("pétrir",),
    "pétrît": ("pétrir",),
    "phonographiaient": ("phonographier",),
    "phonographiai": ("phonographier",),
    "phonographiais": ("phonographier",),
    "phonographiait": ("phonographier",),
    "phonographia": ("phonographier",),
    "phonographiâmes": ("phonographier",),
    "phonographiant": ("phonographier",),
    "phonographias": ("phonographier",),
    "phonographiassent": ("phonographier",),
    "phonographiasses": ("phonographier",),
    "phonographiasse": ("phonographier",),
    "phonographiassiez": ("phonographier",),
    "phonographiassions": ("phonographier",),
    "phonographiâtes": ("phonographier",),
    "phonographiât": ("phonographier",),
    "phonographiée": ("phonographier",),
    "phonographiées": ("phonographier",),
    "phonographié": ("phonographier",),
    "phonographient": ("phonographier",),
    "phonographie": ("phonographier",),
    "phonographiera": ("phonographier",),
    "phonographieraient": ("phonographier",),
    "phonographierai": ("phonographier",),
    "phonographierais": ("phonographier",),
    "phonographierait": ("phonographier",),
    "phonographieras": ("phonographier",),
    "phonographièrent": ("phonographier",),
    "phonographierez": ("phonographier",),
    "phonographieriez": ("phonographier",),
    "phonographierions": ("phonographier",),
    "phonographierons": ("phonographier",),
    "phonographieront": ("phonographier",),
    "phonographiés": ("phonographier",),
    "phonographies": ("phonographier",),
    "phonographiez": ("phonographier",),
    "phonographiiez": ("phonographier",),
    "phonographiions": ("phonographier",),
    "phonographions": ("phonographier",),
    "photocopiaient": ("photocopier",),
    "photocopiai": ("photocopier",),
    "photocopiais": ("photocopier",),
    "photocopiait": ("photocopier",),
    "photocopia": ("photocopier",),
    "photocopiâmes": ("photocopier",),
    "photocopiant": ("photocopier",),
    "photocopias": ("photocopier",),
    "photocopiassent": ("photocopier",),
    "photocopiasses": ("photocopier",),
    "photocopiasse": ("photocopier",),
    "photocopiassiez": ("photocopier",),
    "photocopiassions": ("photocopier",),
    "photocopiâtes": ("photocopier",),
    "photocopiât": ("photocopier",),
    "photocopiée": ("photocopier",),
    "photocopiées": ("photocopier",),
    "photocopié": ("photocopier",),
    "photocopient": ("photocopier",),
    "photocopie": ("photocopier",),
    "photocopiera": ("photocopier",),
    "photocopieraient": ("photocopier",),
    "photocopierai": ("photocopier",),
    "photocopierais": ("photocopier",),
    "photocopierait": ("photocopier",),
    "photocopieras": ("photocopier",),
    "photocopièrent": ("photocopier",),
    "photocopierez": ("photocopier",),
    "photocopieriez": ("photocopier",),
    "photocopierions": ("photocopier",),
    "photocopierons": ("photocopier",),
    "photocopieront": ("photocopier",),
    "photocopiés": ("photocopier",),
    "photocopies": ("photocopier",),
    "photocopiez": ("photocopier",),
    "photocopiiez": ("photocopier",),
    "photocopiions": ("photocopier",),
    "photocopions": ("photocopier",),
    "photographiaient": ("photographier",),
    "photographiai": ("photographier",),
    "photographiais": ("photographier",),
    "photographiait": ("photographier",),
    "photographia": ("photographier",),
    "photographiâmes": ("photographier",),
    "photographiant": ("photographier",),
    "photographias": ("photographier",),
    "photographiassent": ("photographier",),
    "photographiasses": ("photographier",),
    "photographiasse": ("photographier",),
    "photographiassiez": ("photographier",),
    "photographiassions": ("photographier",),
    "photographiâtes": ("photographier",),
    "photographiât": ("photographier",),
    "photographiée": ("photographier",),
    "photographiées": ("photographier",),
    "photographié": ("photographier",),
    "photographient": ("photographier",),
    "photographie": ("photographier",),
    "photographiera": ("photographier",),
    "photographieraient": ("photographier",),
    "photographierai": ("photographier",),
    "photographierais": ("photographier",),
    "photographierait": ("photographier",),
    "photographieras": ("photographier",),
    "photographièrent": ("photographier",),
    "photographierez": ("photographier",),
    "photographieriez": ("photographier",),
    "photographierions": ("photographier",),
    "photographierons": ("photographier",),
    "photographieront": ("photographier",),
    "photographiés": ("photographier",),
    "photographies": ("photographier",),
    "photographiez": ("photographier",),
    "photographiiez": ("photographier",),
    "photographiions": ("photographier",),
    "photographions": ("photographier",),
    "photométraient": ("photométrer",),
    "photométrai": ("photométrer",),
    "photométrais": ("photométrer",),
    "photométrait": ("photométrer",),
    "photométra": ("photométrer",),
    "photométrâmes": ("photométrer",),
    "photométrant": ("photométrer",),
    "photométras": ("photométrer",),
    "photométrassent": ("photométrer",),
    "photométrasses": ("photométrer",),
    "photométrasse": ("photométrer",),
    "photométrassiez": ("photométrer",),
    "photométrassions": ("photométrer",),
    "photométrâtes": ("photométrer",),
    "photométrât": ("photométrer",),
    "photométrée": ("photométrer",),
    "photométrées": ("photométrer",),
    "photométré": ("photométrer",),
    "photomètrent": ("photométrer",),
    "photomètre": ("photométrer",),
    "photométrera": ("photométrer",),
    "photométreraient": ("photométrer",),
    "photométrerai": ("photométrer",),
    "photométrerais": ("photométrer",),
    "photométrerait": ("photométrer",),
    "photométreras": ("photométrer",),
    "photométrèrent": ("photométrer",),
    "photométrerez": ("photométrer",),
    "photométreriez": ("photométrer",),
    "photométrerions": ("photométrer",),
    "photométrerons": ("photométrer",),
    "photométreront": ("photométrer",),
    "photométrés": ("photométrer",),
    "photomètres": ("photométrer",),
    "photométrez": ("photométrer",),
    "photométriez": ("photométrer",),
    "photométrions": ("photométrer",),
    "photométrons": ("photométrer",),
    "phototélécopiaient": ("phototélécopier",),
    "phototélécopiai": ("phototélécopier",),
    "phototélécopiais": ("phototélécopier",),
    "phototélécopiait": ("phototélécopier",),
    "phototélécopia": ("phototélécopier",),
    "phototélécopiâmes": ("phototélécopier",),
    "phototélécopiant": ("phototélécopier",),
    "phototélécopias": ("phototélécopier",),
    "phototélécopiassent": ("phototélécopier",),
    "phototélécopiasses": ("phototélécopier",),
    "phototélécopiasse": ("phototélécopier",),
    "phototélécopiassiez": ("phototélécopier",),
    "phototélécopiassions": ("phototélécopier",),
    "phototélécopiâtes": ("phototélécopier",),
    "phototélécopiât": ("phototélécopier",),
    "phototélécopiée": ("phototélécopier",),
    "phototélécopiées": ("phototélécopier",),
    "phototélécopié": ("phototélécopier",),
    "phototélécopient": ("phototélécopier",),
    "phototélécopie": ("phototélécopier",),
    "phototélécopiera": ("phototélécopier",),
    "phototélécopieraient": ("phototélécopier",),
    "phototélécopierai": ("phototélécopier",),
    "phototélécopierais": ("phototélécopier",),
    "phototélécopierait": ("phototélécopier",),
    "phototélécopieras": ("phototélécopier",),
    "phototélécopièrent": ("phototélécopier",),
    "phototélécopierez": ("phototélécopier",),
    "phototélécopieriez": ("phototélécopier",),
    "phototélécopierions": ("phototélécopier",),
    "phototélécopierons": ("phototélécopier",),
    "phototélécopieront": ("phototélécopier",),
    "phototélécopiés": ("phototélécopier",),
    "phototélécopies": ("phototélécopier",),
    "phototélécopiez": ("phototélécopier",),
    "phototélécopiiez": ("phototélécopier",),
    "phototélécopiions": ("phototélécopier",),
    "phototélécopions": ("phototélécopier",),
    "piégeaient": ("piéger",),
    "piégeai": ("piéger",),
    "piégeais": ("piéger",),
    "piégeait": ("piéger",),
    "piégea": ("piéger",),
    "piégeâmes": ("piéger",),
    "piégeant": ("piéger",),
    "piégeas": ("piéger",),
    "piégeassent": ("piéger",),
    "piégeasses": ("piéger",),
    "piégeasse": ("piéger",),
    "piégeassiez": ("piéger",),
    "piégeassions": ("piéger",),
    "piégeâtes": ("piéger",),
    "piégeât": ("piéger",),
    "piégée": ("piéger",),
    "piégées": ("piéger",),
    "piégé": ("piéger",),
    "piègent": ("piéger",),
    "piégeons": ("piéger",),
    "piège": ("piéger",),
    "piégera": ("piéger",),
    "piégeraient": ("piéger",),
    "piégerai": ("piéger",),
    "piégerais": ("piéger",),
    "piégerait": ("piéger",),
    "piégeras": ("piéger",),
    "piégèrent": ("piéger",),
    "piégerez": ("piéger",),
    "piégeriez": ("piéger",),
    "piégerions": ("piéger",),
    "piégerons": ("piéger",),
    "piégeront": ("piéger",),
    "piégés": ("piéger",),
    "pièges": ("piéger",),
    "piégez": ("piéger",),
    "piégiez": ("piéger",),
    "piégions": ("piéger",),
    "piétaient": ("piéter",),
    "piétai": ("piéter",),
    "piétais": ("piéter",),
    "piétait": ("piéter",),
    "piéta": ("piéter",),
    "piétâmes": ("piéter",),
    "piétant": ("piéter",),
    "piétas": ("piéter",),
    "piétassent": ("piéter",),
    "piétasses": ("piéter",),
    "piétasse": ("piéter",),
    "piétassiez": ("piéter",),
    "piétassions": ("piéter",),
    "piétâtes": ("piéter",),
    "piétât": ("piéter",),
    "piétée": ("piéter",),
    "piétées": ("piéter",),
    "piété": ("piéter",),
    "piètent": ("piéter",),
    "piète": ("piéter",),
    "piétera": ("piéter",),
    "piéteraient": ("piéter",),
    "piéterai": ("piéter",),
    "piéterais": ("piéter",),
    "piéterait": ("piéter",),
    "piéteras": ("piéter",),
    "piétèrent": ("piéter",),
    "piéterez": ("piéter",),
    "piéteriez": ("piéter",),
    "piéterions": ("piéter",),
    "piéterons": ("piéter",),
    "piéteront": ("piéter",),
    "piétés": ("piéter",),
    "piètes": ("piéter",),
    "piétez": ("piéter",),
    "piétiez": ("piéter",),
    "piétions": ("piéter",),
    "piétons": ("piéter",),
    "pifométraient": ("pifométrer",),
    "pifométrai": ("pifométrer",),
    "pifométrais": ("pifométrer",),
    "pifométrait": ("pifométrer",),
    "pifométra": ("pifométrer",),
    "pifométrâmes": ("pifométrer",),
    "pifométrant": ("pifométrer",),
    "pifométras": ("pifométrer",),
    "pifométrassent": ("pifométrer",),
    "pifométrasses": ("pifométrer",),
    "pifométrasse": ("pifométrer",),
    "pifométrassiez": ("pifométrer",),
    "pifométrassions": ("pifométrer",),
    "pifométrâtes": ("pifométrer",),
    "pifométrât": ("pifométrer",),
    "pifométrée": ("pifométrer",),
    "pifométrées": ("pifométrer",),
    "pifométré": ("pifométrer",),
    "pifomètrent": ("pifométrer",),
    "pifomètre": ("pifométrer",),
    "pifométrera": ("pifométrer",),
    "pifométreraient": ("pifométrer",),
    "pifométrerai": ("pifométrer",),
    "pifométrerais": ("pifométrer",),
    "pifométrerait": ("pifométrer",),
    "pifométreras": ("pifométrer",),
    "pifométrèrent": ("pifométrer",),
    "pifométrerez": ("pifométrer",),
    "pifométreriez": ("pifométrer",),
    "pifométrerions": ("pifométrer",),
    "pifométrerons": ("pifométrer",),
    "pifométreront": ("pifométrer",),
    "pifométrés": ("pifométrer",),
    "pifomètres": ("pifométrer",),
    "pifométrez": ("pifométrer",),
    "pifométriez": ("pifométrer",),
    "pifométrions": ("pifométrer",),
    "pifométrons": ("pifométrer",),
    "pigeaient": ("piger",),
    "pigeai": ("piger",),
    "pigeais": ("piger",),
    "pigeait": ("piger",),
    "pigea": ("piger",),
    "pigeâmes": ("piger",),
    "pigeant": ("piger",),
    "pigeas": ("piger",),
    "pigeassent": ("piger",),
    "pigeasses": ("piger",),
    "pigeasse": ("piger",),
    "pigeassiez": ("piger",),
    "pigeassions": ("piger",),
    "pigeâtes": ("piger",),
    "pigeât": ("piger",),
    "pigée": ("piger",),
    "pigées": ("piger",),
    "pigé": ("piger",),
    "pigent": ("piger",),
    "pigeons": ("piger",),
    "pige": ("piger",),
    "pigera": ("piger",),
    "pigeraient": ("piger",),
    "pigerai": ("piger",),
    "pigerais": ("piger",),
    "pigerait": ("piger",),
    "pigeras": ("piger",),
    "pigèrent": ("piger",),
    "pigerez": ("piger",),
    "pigeriez": ("piger",),
    "pigerions": ("piger",),
    "pigerons": ("piger",),
    "pigeront": ("piger",),
    "pigés": ("piger",),
    "piges": ("piger",),
    "pigez": ("piger",),
    "pigiez": ("piger",),
    "pigions": ("piger",),
    "piloriaient": ("pilorier",),
    "piloriai": ("pilorier",),
    "piloriais": ("pilorier",),
    "piloriait": ("pilorier",),
    "piloria": ("pilorier",),
    "piloriâmes": ("pilorier",),
    "piloriant": ("pilorier",),
    "pilorias": ("pilorier",),
    "piloriassent": ("pilorier",),
    "piloriasses": ("pilorier",),
    "piloriasse": ("pilorier",),
    "piloriassiez": ("pilorier",),
    "piloriassions": ("pilorier",),
    "piloriâtes": ("pilorier",),
    "piloriât": ("pilorier",),
    "piloriée": ("pilorier",),
    "piloriées": ("pilorier",),
    "pilorié": ("pilorier",),
    "pilorient": ("pilorier",),
    "pilorie": ("pilorier",),
    "piloriera": ("pilorier",),
    "pilorieraient": ("pilorier",),
    "pilorierai": ("pilorier",),
    "pilorierais": ("pilorier",),
    "pilorierait": ("pilorier",),
    "pilorieras": ("pilorier",),
    "pilorièrent": ("pilorier",),
    "pilorierez": ("pilorier",),
    "pilorieriez": ("pilorier",),
    "pilorierions": ("pilorier",),
    "pilorierons": ("pilorier",),
    "pilorieront": ("pilorier",),
    "piloriés": ("pilorier",),
    "pilories": ("pilorier",),
    "piloriez": ("pilorier",),
    "piloriiez": ("pilorier",),
    "piloriions": ("pilorier",),
    "pilorions": ("pilorier",),
    "pinçaient": ("pincer",),
    "pinçai": ("pincer",),
    "pinçais": ("pincer",),
    "pinçait": ("pincer",),
    "pinça": ("pincer",),
    "pinçâmes": ("pincer",),
    "pinçant": ("pincer",),
    "pinças": ("pincer",),
    "pinçassent": ("pincer",),
    "pinçasses": ("pincer",),
    "pinçasse": ("pincer",),
    "pinçassiez": ("pincer",),
    "pinçassions": ("pincer",),
    "pinçâtes": ("pincer",),
    "pinçât": ("pincer",),
    "pincée": ("pincer",),
    "pincées": ("pincer",),
    "pincé": ("pincer",),
    "pincent": ("pincer",),
    "pince": ("pincer",),
    "pincera": ("pincer",),
    "pinceraient": ("pincer",),
    "pincerai": ("pincer",),
    "pincerais": ("pincer",),
    "pincerait": ("pincer",),
    "pinceras": ("pincer",),
    "pincèrent": ("pincer",),
    "pincerez": ("pincer",),
    "pinceriez": ("pincer",),
    "pincerions": ("pincer",),
    "pincerons": ("pincer",),
    "pinceront": ("pincer",),
    "pincés": ("pincer",),
    "pinces": ("pincer",),
    "pincez": ("pincer",),
    "pinciez": ("pincer",),
    "pincions": ("pincer",),
    "pinçons": ("pincer",),
    "pincetaient": ("pinceter",),
    "pincetai": ("pinceter",),
    "pincetais": ("pinceter",),
    "pincetait": ("pinceter",),
    "pinceta": ("pinceter",),
    "pincetâmes": ("pinceter",),
    "pincetant": ("pinceter",),
    "pincetas": ("pinceter",),
    "pincetassent": ("pinceter",),
    "pincetasses": ("pinceter",),
    "pincetasse": ("pinceter",),
    "pincetassiez": ("pinceter",),
    "pincetassions": ("pinceter",),
    "pincetâtes": ("pinceter",),
    "pincetât": ("pinceter",),
    "pincetée": ("pinceter",),
    "pincetées": ("pinceter",),
    "pinceté": ("pinceter",),
    "pincetèrent": ("pinceter",),
    "pincetés": ("pinceter",),
    "pincetez": ("pinceter",),
    "pincetiez": ("pinceter",),
    "pincetions": ("pinceter",),
    "pincetons": ("pinceter",),
    "pincettent": ("pinceter",),
    "pincette": ("pinceter",),
    "pincettera": ("pinceter",),
    "pincetteraient": ("pinceter",),
    "pincetterai": ("pinceter",),
    "pincetterais": ("pinceter",),
    "pincetterait": ("pinceter",),
    "pincetteras": ("pinceter",),
    "pincetterez": ("pinceter",),
    "pincetteriez": ("pinceter",),
    "pincetterions": ("pinceter",),
    "pincetterons": ("pinceter",),
    "pincetteront": ("pinceter",),
    "pincettes": ("pinceter",),
    "pionçaient": ("pioncer",),
    "pionçai": ("pioncer",),
    "pionçais": ("pioncer",),
    "pionçait": ("pioncer",),
    "pionça": ("pioncer",),
    "pionçâmes": ("pioncer",),
    "pionçant": ("pioncer",),
    "pionças": ("pioncer",),
    "pionçassent": ("pioncer",),
    "pionçasses": ("pioncer",),
    "pionçasse": ("pioncer",),
    "pionçassiez": ("pioncer",),
    "pionçassions": ("pioncer",),
    "pionçâtes": ("pioncer",),
    "pionçât": ("pioncer",),
    "pioncé": ("pioncer",),
    "pioncent": ("pioncer",),
    "pionce": ("pioncer",),
    "pioncera": ("pioncer",),
    "pionceraient": ("pioncer",),
    "pioncerai": ("pioncer",),
    "pioncerais": ("pioncer",),
    "pioncerait": ("pioncer",),
    "pionceras": ("pioncer",),
    "pioncèrent": ("pioncer",),
    "pioncerez": ("pioncer",),
    "pionceriez": ("pioncer",),
    "pioncerions": ("pioncer",),
    "pioncerons": ("pioncer",),
    "pionceront": ("pioncer",),
    "pionces": ("pioncer",),
    "pioncez": ("pioncer",),
    "pionciez": ("pioncer",),
    "pioncions": ("pioncer",),
    "pionçons": ("pioncer",),
    "piquetaient": ("piqueter",),
    "piquetai": ("piqueter",),
    "piquetais": ("piqueter",),
    "piquetait": ("piqueter",),
    "piqueta": ("piqueter",),
    "piquetâmes": ("piqueter",),
    "piquetant": ("piqueter",),
    "piquetas": ("piqueter",),
    "piquetassent": ("piqueter",),
    "piquetasses": ("piqueter",),
    "piquetasse": ("piqueter",),
    "piquetassiez": ("piqueter",),
    "piquetassions": ("piqueter",),
    "piquetâtes": ("piqueter",),
    "piquetât": ("piqueter",),
    "piquetée": ("piqueter",),
    "piquetées": ("piqueter",),
    "piqueté": ("piqueter",),
    "piquetèrent": ("piqueter",),
    "piquetés": ("piqueter",),
    "piquetez": ("piqueter",),
    "piquetiez": ("piqueter",),
    "piquetions": ("piqueter",),
    "piquetons": ("piqueter",),
    "piquettent": ("piqueter",),
    "piquette": ("piqueter",),
    "piquettera": ("piqueter",),
    "piquetteraient": ("piqueter",),
    "piquetterai": ("piqueter",),
    "piquetterais": ("piqueter",),
    "piquetterait": ("piqueter",),
    "piquetteras": ("piqueter",),
    "piquetterez": ("piqueter",),
    "piquetteriez": ("piqueter",),
    "piquetterions": ("piqueter",),
    "piquetterons": ("piqueter",),
    "piquetteront": ("piqueter",),
    "piquettes": ("piqueter",),
    "plaçaient": ("placer",),
    "plaçai": ("placer",),
    "plaçais": ("placer",),
    "plaçait": ("placer",),
    "plaça": ("placer",),
    "plaçâmes": ("placer",),
    "plaçant": ("placer",),
    "plaças": ("placer",),
    "plaçassent": ("placer",),
    "plaçasses": ("placer",),
    "plaçasse": ("placer",),
    "plaçassiez": ("placer",),
    "plaçassions": ("placer",),
    "plaçâtes": ("placer",),
    "plaçât": ("placer",),
    "placée": ("placer",),
    "placées": ("placer",),
    "placé": ("placer",),
    "placent": ("placer",),
    "place": ("placer",),
    "placera": ("placer",),
    "placeraient": ("placer",),
    "placerai": ("placer",),
    "placerais": ("placer",),
    "placerait": ("placer",),
    "placeras": ("placer",),
    "placèrent": ("placer",),
    "placerez": ("placer",),
    "placeriez": ("placer",),
    "placerions": ("placer",),
    "placerons": ("placer",),
    "placeront": ("placer",),
    "placés": ("placer",),
    "places": ("placer",),
    "placez": ("placer",),
    "placiez": ("placer",),
    "placions": ("placer",),
    "plaçons": ("placer",),
    "plagiaient": ("plagier",),
    "plagiai": ("plagier",),
    "plagiais": ("plagier",),
    "plagiait": ("plagier",),
    "plagia": ("plagier",),
    "plagiâmes": ("plagier",),
    "plagiant": ("plagier",),
    "plagias": ("plagier",),
    "plagiassent": ("plagier",),
    "plagiasses": ("plagier",),
    "plagiasse": ("plagier",),
    "plagiassiez": ("plagier",),
    "plagiassions": ("plagier",),
    "plagiâtes": ("plagier",),
    "plagiât": ("plagier",),
    "plagiée": ("plagier",),
    "plagiées": ("plagier",),
    "plagié": ("plagier",),
    "plagient": ("plagier",),
    "plagie": ("plagier",),
    "plagiera": ("plagier",),
    "plagieraient": ("plagier",),
    "plagierai": ("plagier",),
    "plagierais": ("plagier",),
    "plagierait": ("plagier",),
    "plagieras": ("plagier",),
    "plagièrent": ("plagier",),
    "plagierez": ("plagier",),
    "plagieriez": ("plagier",),
    "plagierions": ("plagier",),
    "plagierons": ("plagier",),
    "plagieront": ("plagier",),
    "plagiés": ("plagier",),
    "plagies": ("plagier",),
    "plagiez": ("plagier",),
    "plagiiez": ("plagier",),
    "plagiions": ("plagier",),
    "plagions": ("plagier",),
    "plaignaient": ("plaindre",),
    "plaignais": ("plaindre",),
    "plaignait": ("plaindre",),
    "plaignant": ("plaindre",),
    "plaignent": ("plaindre",),
    "plaigne": ("plaindre",),
    "plaignes": ("plaindre",),
    "plaignez": ("plaindre",),
    "plaigniez": ("plaindre",),
    "plaignîmes": ("plaindre",),
    "plaignions": ("plaindre",),
    "plaignirent": ("plaindre",),
    "plaignis": ("plaindre",),
    "plaignissent": ("plaindre",),
    "plaignisses": ("plaindre",),
    "plaignisse": ("plaindre",),
    "plaignissiez": ("plaindre",),
    "plaignissions": ("plaindre",),
    "plaignîtes": ("plaindre",),
    "plaignit": ("plaindre",),
    "plaignît": ("plaindre",),
    "plaignons": ("plaindre",),
    "plaindra": ("plaindre",),
    "plaindraient": ("plaindre",),
    "plaindrai": ("plaindre",),
    "plaindrais": ("plaindre",),
    "plaindrait": ("plaindre",),
    "plaindras": ("plaindre",),
    "plaindrez": ("plaindre",),
    "plaindriez": ("plaindre",),
    "plaindrions": ("plaindre",),
    "plaindrons": ("plaindre",),
    "plaindront": ("plaindre",),
    "plains": ("plaindre",),
    "plainte": ("plaindre",),
    "plaintes": ("plaindre",),
    "plaint": ("plaindre",),
    "plaints": ("plaindre",),
    "plaira": ("plaire",),
    "plairaient": ("plaire",),
    "plairai": ("plaire",),
    "plairais": ("plaire",),
    "plairait": ("plaire",),
    "plairas": ("plaire",),
    "plairez": ("plaire",),
    "plairiez": ("plaire",),
    "plairions": ("plaire",),
    "plairons": ("plaire",),
    "plairont": ("plaire",),
    "plaisaient": ("plaire",),
    "plaisais": ("plaire",),
    "plaisait": ("plaire",),
    "plaisant": ("plaire",),
    "plaisent": ("plaire",),
    "plaise": ("plaire",),
    "plaises": ("plaire",),
    "plaisez": ("plaire",),
    "plaisiez": ("plaire",),
    "plaisions": ("plaire",),
    "plaisons": ("plaire",),
    "plais": ("plaire",),
    "plaît": ("plaire",),
    "plue": ("plaire",),
    "plues": ("plaire",),
    "plu": ("pleuvoir",),
    "plûmes": ("plaire",),
    "plurent": ("pleuvoir",),
    "plus": ("plaire",),
    "plussent": ("pleuvoir",),
    "plusses": ("plaire",),
    "plusse": ("plaire",),
    "plussiez": ("plaire",),
    "plussions": ("plaire",),
    "plûtes": ("plaire",),
    "plut": ("pleuvoir",),
    "plût": ("pleuvoir",),
    "planchéiaient": ("planchéier",),
    "planchéiai": ("planchéier",),
    "planchéiais": ("planchéier",),
    "planchéiait": ("planchéier",),
    "planchéia": ("planchéier",),
    "planchéiâmes": ("planchéier",),
    "planchéiant": ("planchéier",),
    "planchéias": ("planchéier",),
    "planchéiassent": ("planchéier",),
    "planchéiasses": ("planchéier",),
    "planchéiasse": ("planchéier",),
    "planchéiassiez": ("planchéier",),
    "planchéiassions": ("planchéier",),
    "planchéiâtes": ("planchéier",),
    "planchéiât": ("planchéier",),
    "planchéiée": ("planchéier",),
    "planchéiées": ("planchéier",),
    "planchéié": ("planchéier",),
    "planchéient": ("planchéier",),
    "planchéie": ("planchéier",),
    "planchéiera": ("planchéier",),
    "planchéieraient": ("planchéier",),
    "planchéierai": ("planchéier",),
    "planchéierais": ("planchéier",),
    "planchéierait": ("planchéier",),
    "planchéieras": ("planchéier",),
    "planchéièrent": ("planchéier",),
    "planchéierez": ("planchéier",),
    "planchéieriez": ("planchéier",),
    "planchéierions": ("planchéier",),
    "planchéierons": ("planchéier",),
    "planchéieront": ("planchéier",),
    "planchéiés": ("planchéier",),
    "planchéies": ("planchéier",),
    "planchéiez": ("planchéier",),
    "planchéiiez": ("planchéier",),
    "planchéiions": ("planchéier",),
    "planchéions": ("planchéier",),
    "planétaient": ("planéter",),
    "planétai": ("planéter",),
    "planétais": ("planéter",),
    "planétait": ("planéter",),
    "planéta": ("planéter",),
    "planétâmes": ("planéter",),
    "planétant": ("planéter",),
    "planétas": ("planéter",),
    "planétassent": ("planéter",),
    "planétasses": ("planéter",),
    "planétasse": ("planéter",),
    "planétassiez": ("planéter",),
    "planétassions": ("planéter",),
    "planétâtes": ("planéter",),
    "planétât": ("planéter",),
    "planétée": ("planéter",),
    "planétées": ("planéter",),
    "planété": ("planéter",),
    "planètent": ("planéter",),
    "planète": ("planéter",),
    "planétera": ("planéter",),
    "planéteraient": ("planéter",),
    "planéterai": ("planéter",),
    "planéterais": ("planéter",),
    "planéterait": ("planéter",),
    "planéteras": ("planéter",),
    "planétèrent": ("planéter",),
    "planéterez": ("planéter",),
    "planéteriez": ("planéter",),
    "planéterions": ("planéter",),
    "planéterons": ("planéter",),
    "planéteront": ("planéter",),
    "planétés": ("planéter",),
    "planètes": ("planéter",),
    "planétez": ("planéter",),
    "planétiez": ("planéter",),
    "planétions": ("planéter",),
    "planétons": ("planéter",),
    "planifiaient": ("planifier",),
    "planifiai": ("planifier",),
    "planifiais": ("planifier",),
    "planifiait": ("planifier",),
    "planifia": ("planifier",),
    "planifiâmes": ("planifier",),
    "planifiant": ("planifier",),
    "planifias": ("planifier",),
    "planifiassent": ("planifier",),
    "planifiasses": ("planifier",),
    "planifiasse": ("planifier",),
    "planifiassiez": ("planifier",),
    "planifiassions": ("planifier",),
    "planifiâtes": ("planifier",),
    "planifiât": ("planifier",),
    "planifiée": ("planifier",),
    "planifiées": ("planifier",),
    "planifié": ("planifier",),
    "planifient": ("planifier",),
    "planifie": ("planifier",),
    "planifiera": ("planifier",),
    "planifieraient": ("planifier",),
    "planifierai": ("planifier",),
    "planifierais": ("planifier",),
    "planifierait": ("planifier",),
    "planifieras": ("planifier",),
    "planifièrent": ("planifier",),
    "planifierez": ("planifier",),
    "planifieriez": ("planifier",),
    "planifierions": ("planifier",),
    "planifierons": ("planifier",),
    "planifieront": ("planifier",),
    "planifiés": ("planifier",),
    "planifies": ("planifier",),
    "planifiez": ("planifier",),
    "planifiiez": ("planifier",),
    "planifiions": ("planifier",),
    "planifions": ("planifier",),
    "planimétraient": ("planimétrer",),
    "planimétrai": ("planimétrer",),
    "planimétrais": ("planimétrer",),
    "planimétrait": ("planimétrer",),
    "planimétra": ("planimétrer",),
    "planimétrâmes": ("planimétrer",),
    "planimétrant": ("planimétrer",),
    "planimétras": ("planimétrer",),
    "planimétrassent": ("planimétrer",),
    "planimétrasses": ("planimétrer",),
    "planimétrasse": ("planimétrer",),
    "planimétrassiez": ("planimétrer",),
    "planimétrassions": ("planimétrer",),
    "planimétrâtes": ("planimétrer",),
    "planimétrât": ("planimétrer",),
    "planimétrée": ("planimétrer",),
    "planimétrées": ("planimétrer",),
    "planimétré": ("planimétrer",),
    "planimètrent": ("planimétrer",),
    "planimètre": ("planimétrer",),
    "planimétrera": ("planimétrer",),
    "planimétreraient": ("planimétrer",),
    "planimétrerai": ("planimétrer",),
    "planimétrerais": ("planimétrer",),
    "planimétrerait": ("planimétrer",),
    "planimétreras": ("planimétrer",),
    "planimétrèrent": ("planimétrer",),
    "planimétrerez": ("planimétrer",),
    "planimétreriez": ("planimétrer",),
    "planimétrerions": ("planimétrer",),
    "planimétrerons": ("planimétrer",),
    "planimétreront": ("planimétrer",),
    "planimétrés": ("planimétrer",),
    "planimètres": ("planimétrer",),
    "planimétrez": ("planimétrer",),
    "planimétriez": ("planimétrer",),
    "planimétrions": ("planimétrer",),
    "planimétrons": ("planimétrer",),
    "plasmifiaient": ("plasmifier",),
    "plasmifiai": ("plasmifier",),
    "plasmifiais": ("plasmifier",),
    "plasmifiait": ("plasmifier",),
    "plasmifia": ("plasmifier",),
    "plasmifiâmes": ("plasmifier",),
    "plasmifiant": ("plasmifier",),
    "plasmifias": ("plasmifier",),
    "plasmifiassent": ("plasmifier",),
    "plasmifiasses": ("plasmifier",),
    "plasmifiasse": ("plasmifier",),
    "plasmifiassiez": ("plasmifier",),
    "plasmifiassions": ("plasmifier",),
    "plasmifiâtes": ("plasmifier",),
    "plasmifiât": ("plasmifier",),
    "plasmifiée": ("plasmifier",),
    "plasmifiées": ("plasmifier",),
    "plasmifié": ("plasmifier",),
    "plasmifient": ("plasmifier",),
    "plasmifie": ("plasmifier",),
    "plasmifiera": ("plasmifier",),
    "plasmifieraient": ("plasmifier",),
    "plasmifierai": ("plasmifier",),
    "plasmifierais": ("plasmifier",),
    "plasmifierait": ("plasmifier",),
    "plasmifieras": ("plasmifier",),
    "plasmifièrent": ("plasmifier",),
    "plasmifierez": ("plasmifier",),
    "plasmifieriez": ("plasmifier",),
    "plasmifierions": ("plasmifier",),
    "plasmifierons": ("plasmifier",),
    "plasmifieront": ("plasmifier",),
    "plasmifiés": ("plasmifier",),
    "plasmifies": ("plasmifier",),
    "plasmifiez": ("plasmifier",),
    "plasmifiiez": ("plasmifier",),
    "plasmifiions": ("plasmifier",),
    "plasmifions": ("plasmifier",),
    "plastifiaient": ("plastifier",),
    "plastifiai": ("plastifier",),
    "plastifiais": ("plastifier",),
    "plastifiait": ("plastifier",),
    "plastifia": ("plastifier",),
    "plastifiâmes": ("plastifier",),
    "plastifiant": ("plastifier",),
    "plastifias": ("plastifier",),
    "plastifiassent": ("plastifier",),
    "plastifiasses": ("plastifier",),
    "plastifiasse": ("plastifier",),
    "plastifiassiez": ("plastifier",),
    "plastifiassions": ("plastifier",),
    "plastifiâtes": ("plastifier",),
    "plastifiât": ("plastifier",),
    "plastifiée": ("plastifier",),
    "plastifiées": ("plastifier",),
    "plastifié": ("plastifier",),
    "plastifient": ("plastifier",),
    "plastifie": ("plastifier",),
    "plastifiera": ("plastifier",),
    "plastifieraient": ("plastifier",),
    "plastifierai": ("plastifier",),
    "plastifierais": ("plastifier",),
    "plastifierait": ("plastifier",),
    "plastifieras": ("plastifier",),
    "plastifièrent": ("plastifier",),
    "plastifierez": ("plastifier",),
    "plastifieriez": ("plastifier",),
    "plastifierions": ("plastifier",),
    "plastifierons": ("plastifier",),
    "plastifieront": ("plastifier",),
    "plastifiés": ("plastifier",),
    "plastifies": ("plastifier",),
    "plastifiez": ("plastifier",),
    "plastifiiez": ("plastifier",),
    "plastifiions": ("plastifier",),
    "plastifions": ("plastifier",),
    "pleigeaient": ("pleiger",),
    "pleigeai": ("pleiger",),
    "pleigeais": ("pleiger",),
    "pleigeait": ("pleiger",),
    "pleigea": ("pleiger",),
    "pleigeâmes": ("pleiger",),
    "pleigeant": ("pleiger",),
    "pleigeas": ("pleiger",),
    "pleigeassent": ("pleiger",),
    "pleigeasses": ("pleiger",),
    "pleigeasse": ("pleiger",),
    "pleigeassiez": ("pleiger",),
    "pleigeassions": ("pleiger",),
    "pleigeâtes": ("pleiger",),
    "pleigeât": ("pleiger",),
    "pleigée": ("pleiger",),
    "pleigées": ("pleiger",),
    "pleigé": ("pleiger",),
    "pleigent": ("pleiger",),
    "pleigeons": ("pleiger",),
    "pleige": ("pleiger",),
    "pleigera": ("pleiger",),
    "pleigeraient": ("pleiger",),
    "pleigerai": ("pleiger",),
    "pleigerais": ("pleiger",),
    "pleigerait": ("pleiger",),
    "pleigeras": ("pleiger",),
    "pleigèrent": ("pleiger",),
    "pleigerez": ("pleiger",),
    "pleigeriez": ("pleiger",),
    "pleigerions": ("pleiger",),
    "pleigerons": ("pleiger",),
    "pleigeront": ("pleiger",),
    "pleigés": ("pleiger",),
    "pleiges": ("pleiger",),
    "pleigez": ("pleiger",),
    "pleigiez": ("pleiger",),
    "pleigions": ("pleiger",),
    "pleuvassaient": ("pleuvasser",),
    "pleuvassait": ("pleuvasser",),
    "pleuvassa": ("pleuvasser",),
    "pleuvassant": ("pleuvasser",),
    "pleuvassassent": ("pleuvasser",),
    "pleuvassât": ("pleuvasser",),
    "pleuvassé": ("pleuvasser",),
    "pleuvassent": ("pleuvasser",),
    "pleuvasse": ("pleuvasser",),
    "pleuvassera": ("pleuvasser",),
    "pleuvasseraient": ("pleuvasser",),
    "pleuvasserait": ("pleuvasser",),
    "pleuvassèrent": ("pleuvasser",),
    "pleuvasseront": ("pleuvasser",),
    "pleut": ("pleuvoir",),
    "pleuvaient": ("pleuvoir",),
    "pleuvait": ("pleuvoir",),
    "pleuvant": ("pleuvoir",),
    "pleuvent": ("pleuvoir",),
    "pleuve": ("pleuvoir",),
    "pleuvra": ("pleuvoir",),
    "pleuvraient": ("pleuvoir",),
    "pleuvrait": ("pleuvoir",),
    "pleuvront": ("pleuvoir",),
    "pliaient": ("plier",),
    "pliai": ("plier",),
    "pliais": ("plier",),
    "pliait": ("plier",),
    "plia": ("plier",),
    "pliâmes": ("plier",),
    "pliant": ("plier",),
    "plias": ("plier",),
    "pliassent": ("plier",),
    "pliasses": ("plier",),
    "pliasse": ("plier",),
    "pliassiez": ("plier",),
    "pliassions": ("plier",),
    "pliâtes": ("plier",),
    "pliât": ("plier",),
    "pliée": ("plier",),
    "pliées": ("plier",),
    "plié": ("plier",),
    "plient": ("plier",),
    "plie": ("plier",),
    "pliera": ("plier",),
    "plieraient": ("plier",),
    "plierai": ("plier",),
    "plierais": ("plier",),
    "plierait": ("plier",),
    "plieras": ("plier",),
    "plièrent": ("plier",),
    "plierez": ("plier",),
    "plieriez": ("plier",),
    "plierions": ("plier",),
    "plierons": ("plier",),
    "plieront": ("plier",),
    "pliés": ("plier",),
    "plies": ("plier",),
    "pliez": ("plier",),
    "pliiez": ("plier",),
    "pliions": ("plier",),
    "plions": ("plier",),
    "plongeaient": ("plonger",),
    "plongeai": ("plonger",),
    "plongeais": ("plonger",),
    "plongeait": ("plonger",),
    "plongea": ("plonger",),
    "plongeâmes": ("plonger",),
    "plongeant": ("plonger",),
    "plongeas": ("plonger",),
    "plongeassent": ("plonger",),
    "plongeasses": ("plonger",),
    "plongeasse": ("plonger",),
    "plongeassiez": ("plonger",),
    "plongeassions": ("plonger",),
    "plongeâtes": ("plonger",),
    "plongeât": ("plonger",),
    "plongée": ("plonger",),
    "plongées": ("plonger",),
    "plongé": ("plonger",),
    "plongent": ("plonger",),
    "plongeons": ("plonger",),
    "plonge": ("plonger",),
    "plongera": ("plonger",),
    "plongeraient": ("plonger",),
    "plongerai": ("plonger",),
    "plongerais": ("plonger",),
    "plongerait": ("plonger",),
    "plongeras": ("plonger",),
    "plongèrent": ("plonger",),
    "plongerez": ("plonger",),
    "plongeriez": ("plonger",),
    "plongerions": ("plonger",),
    "plongerons": ("plonger",),
    "plongeront": ("plonger",),
    "plongés": ("plonger",),
    "plonges": ("plonger",),
    "plongez": ("plonger",),
    "plongiez": ("plonger",),
    "plongions": ("plonger",),
    "ploient": ("ployer",),
    "ploie": ("ployer",),
    "ploiera": ("ployer",),
    "ploieraient": ("ployer",),
    "ploierai": ("ployer",),
    "ploierais": ("ployer",),
    "ploierait": ("ployer",),
    "ploieras": ("ployer",),
    "ploierez": ("ployer",),
    "ploieriez": ("ployer",),
    "ploierions": ("ployer",),
    "ploierons": ("ployer",),
    "ploieront": ("ployer",),
    "ploies": ("ployer",),
    "ployaient": ("ployer",),
    "ployai": ("ployer",),
    "ployais": ("ployer",),
    "ployait": ("ployer",),
    "ploya": ("ployer",),
    "ployâmes": ("ployer",),
    "ployant": ("ployer",),
    "ployas": ("ployer",),
    "ployassent": ("ployer",),
    "ployasses": ("ployer",),
    "ployasse": ("ployer",),
    "ployassiez": ("ployer",),
    "ployassions": ("ployer",),
    "ployâtes": ("ployer",),
    "ployât": ("ployer",),
    "ployée": ("ployer",),
    "ployées": ("ployer",),
    "ployé": ("ployer",),
    "ployèrent": ("ployer",),
    "ployés": ("ployer",),
    "ployez": ("ployer",),
    "ployiez": ("ployer",),
    "ployions": ("ployer",),
    "ployons": ("ployer",),
    "pochetaient": ("pocheter",),
    "pochetai": ("pocheter",),
    "pochetais": ("pocheter",),
    "pochetait": ("pocheter",),
    "pocheta": ("pocheter",),
    "pochetâmes": ("pocheter",),
    "pochetant": ("pocheter",),
    "pochetas": ("pocheter",),
    "pochetassent": ("pocheter",),
    "pochetasses": ("pocheter",),
    "pochetasse": ("pocheter",),
    "pochetassiez": ("pocheter",),
    "pochetassions": ("pocheter",),
    "pochetâtes": ("pocheter",),
    "pochetât": ("pocheter",),
    "pochetée": ("pocheter",),
    "pochetées": ("pocheter",),
    "pocheté": ("pocheter",),
    "pochetèrent": ("pocheter",),
    "pochetés": ("pocheter",),
    "pochetez": ("pocheter",),
    "pochetiez": ("pocheter",),
    "pochetions": ("pocheter",),
    "pochetons": ("pocheter",),
    "pochettent": ("pocheter",),
    "pochette": ("pocheter",),
    "pochettera": ("pocheter",),
    "pochetteraient": ("pocheter",),
    "pochetterai": ("pocheter",),
    "pochetterais": ("pocheter",),
    "pochetterait": ("pocheter",),
    "pochetteras": ("pocheter",),
    "pochetterez": ("pocheter",),
    "pochetteriez": ("pocheter",),
    "pochetterions": ("pocheter",),
    "pochetterons": ("pocheter",),
    "pochetteront": ("pocheter",),
    "pochettes": ("pocheter",),
    "poignaient": ("poindre",),
    "poignait": ("poindre",),
    "poignent": ("poindre",),
    "poindra": ("poindre",),
    "poindraient": ("poindre",),
    "poindrait": ("poindre",),
    "poindront": ("poindre",),
    "point": ("poindre",),
    "poliçaient": ("policer",),
    "poliçai": ("policer",),
    "poliçais": ("policer",),
    "poliçait": ("policer",),
    "poliça": ("policer",),
    "poliçâmes": ("policer",),
    "poliçant": ("policer",),
    "poliças": ("policer",),
    "poliçassent": ("policer",),
    "poliçasses": ("policer",),
    "poliçasse": ("policer",),
    "poliçassiez": ("policer",),
    "poliçassions": ("policer",),
    "poliçâtes": ("policer",),
    "poliçât": ("policer",),
    "policée": ("policer",),
    "policées": ("policer",),
    "policé": ("policer",),
    "policent": ("policer",),
    "police": ("policer",),
    "policera": ("policer",),
    "policeraient": ("policer",),
    "policerai": ("policer",),
    "policerais": ("policer",),
    "policerait": ("policer",),
    "policeras": ("policer",),
    "policèrent": ("policer",),
    "policerez": ("policer",),
    "policeriez": ("policer",),
    "policerions": ("policer",),
    "policerons": ("policer",),
    "policeront": ("policer",),
    "policés": ("policer",),
    "polices": ("policer",),
    "policez": ("policer",),
    "policiez": ("policer",),
    "policions": ("policer",),
    "poliçons": ("policer",),
    "polie": ("polir",),
    "polies": ("polir",),
    "poli": ("polir",),
    "polîmes": ("polir",),
    "polira": ("polir",),
    "poliraient": ("polir",),
    "polirai": ("polir",),
    "polirais": ("polir",),
    "polirait": ("polir",),
    "poliras": ("polir",),
    "polirent": ("polir",),
    "polirez": ("polir",),
    "poliriez": ("polir",),
    "polirions": ("polir",),
    "polirons": ("polir",),
    "poliront": ("polir",),
    "polis": ("polir",),
    "polissaient": ("polir",),
    "polissais": ("polir",),
    "polissait": ("polir",),
    "polissant": ("polir",),
    "polissent": ("polir",),
    "polisse": ("polir",),
    "polisses": ("polir",),
    "polissez": ("polir",),
    "polissiez": ("polir",),
    "polissions": ("polir",),
    "polissons": ("polir",),
    "polîtes": ("polir",),
    "polit": ("polir",),
    "polît": ("polir",),
    "polycopiaient": ("polycopier",),
    "polycopiai": ("polycopier",),
    "polycopiais": ("polycopier",),
    "polycopiait": ("polycopier",),
    "polycopia": ("polycopier",),
    "polycopiâmes": ("polycopier",),
    "polycopiant": ("polycopier",),
    "polycopias": ("polycopier",),
    "polycopiassent": ("polycopier",),
    "polycopiasses": ("polycopier",),
    "polycopiasse": ("polycopier",),
    "polycopiassiez": ("polycopier",),
    "polycopiassions": ("polycopier",),
    "polycopiâtes": ("polycopier",),
    "polycopiât": ("polycopier",),
    "polycopiée": ("polycopier",),
    "polycopiées": ("polycopier",),
    "polycopié": ("polycopier",),
    "polycopient": ("polycopier",),
    "polycopie": ("polycopier",),
    "polycopiera": ("polycopier",),
    "polycopieraient": ("polycopier",),
    "polycopierai": ("polycopier",),
    "polycopierais": ("polycopier",),
    "polycopierait": ("polycopier",),
    "polycopieras": ("polycopier",),
    "polycopièrent": ("polycopier",),
    "polycopierez": ("polycopier",),
    "polycopieriez": ("polycopier",),
    "polycopierions": ("polycopier",),
    "polycopierons": ("polycopier",),
    "polycopieront": ("polycopier",),
    "polycopiés": ("polycopier",),
    "polycopies": ("polycopier",),
    "polycopiez": ("polycopier",),
    "polycopiiez": ("polycopier",),
    "polycopiions": ("polycopier",),
    "polycopions": ("polycopier",),
    "polyestérifiaient": ("polyestérifier",),
    "polyestérifiai": ("polyestérifier",),
    "polyestérifiais": ("polyestérifier",),
    "polyestérifiait": ("polyestérifier",),
    "polyestérifia": ("polyestérifier",),
    "polyestérifiâmes": ("polyestérifier",),
    "polyestérifiant": ("polyestérifier",),
    "polyestérifias": ("polyestérifier",),
    "polyestérifiassent": ("polyestérifier",),
    "polyestérifiasses": ("polyestérifier",),
    "polyestérifiasse": ("polyestérifier",),
    "polyestérifiassiez": ("polyestérifier",),
    "polyestérifiassions": ("polyestérifier",),
    "polyestérifiâtes": ("polyestérifier",),
    "polyestérifiât": ("polyestérifier",),
    "polyestérifiée": ("polyestérifier",),
    "polyestérifiées": ("polyestérifier",),
    "polyestérifié": ("polyestérifier",),
    "polyestérifient": ("polyestérifier",),
    "polyestérifie": ("polyestérifier",),
    "polyestérifiera": ("polyestérifier",),
    "polyestérifieraient": ("polyestérifier",),
    "polyestérifierai": ("polyestérifier",),
    "polyestérifierais": ("polyestérifier",),
    "polyestérifierait": ("polyestérifier",),
    "polyestérifieras": ("polyestérifier",),
    "polyestérifièrent": ("polyestérifier",),
    "polyestérifierez": ("polyestérifier",),
    "polyestérifieriez": ("polyestérifier",),
    "polyestérifierions": ("polyestérifier",),
    "polyestérifierons": ("polyestérifier",),
    "polyestérifieront": ("polyestérifier",),
    "polyestérifiés": ("polyestérifier",),
    "polyestérifies": ("polyestérifier",),
    "polyestérifiez": ("polyestérifier",),
    "polyestérifiiez": ("polyestérifier",),
    "polyestérifiions": ("polyestérifier",),
    "polyestérifions": ("polyestérifier",),
    "polygraphiaient": ("polygraphier",),
    "polygraphiai": ("polygraphier",),
    "polygraphiais": ("polygraphier",),
    "polygraphiait": ("polygraphier",),
    "polygraphia": ("polygraphier",),
    "polygraphiâmes": ("polygraphier",),
    "polygraphiant": ("polygraphier",),
    "polygraphias": ("polygraphier",),
    "polygraphiassent": ("polygraphier",),
    "polygraphiasses": ("polygraphier",),
    "polygraphiasse": ("polygraphier",),
    "polygraphiassiez": ("polygraphier",),
    "polygraphiassions": ("polygraphier",),
    "polygraphiâtes": ("polygraphier",),
    "polygraphiât": ("polygraphier",),
    "polygraphiée": ("polygraphier",),
    "polygraphiées": ("polygraphier",),
    "polygraphié": ("polygraphier",),
    "polygraphient": ("polygraphier",),
    "polygraphie": ("polygraphier",),
    "polygraphiera": ("polygraphier",),
    "polygraphieraient": ("polygraphier",),
    "polygraphierai": ("polygraphier",),
    "polygraphierais": ("polygraphier",),
    "polygraphierait": ("polygraphier",),
    "polygraphieras": ("polygraphier",),
    "polygraphièrent": ("polygraphier",),
    "polygraphierez": ("polygraphier",),
    "polygraphieriez": ("polygraphier",),
    "polygraphierions": ("polygraphier",),
    "polygraphierons": ("polygraphier",),
    "polygraphieront": ("polygraphier",),
    "polygraphiés": ("polygraphier",),
    "polygraphies": ("polygraphier",),
    "polygraphiez": ("polygraphier",),
    "polygraphiiez": ("polygraphier",),
    "polygraphiions": ("polygraphier",),
    "polygraphions": ("polygraphier",),
    "pommelaient": ("pommeler",),
    "pommelai": ("pommeler",),
    "pommelais": ("pommeler",),
    "pommelait": ("pommeler",),
    "pommela": ("pommeler",),
    "pommelâmes": ("pommeler",),
    "pommelant": ("pommeler",),
    "pommelas": ("pommeler",),
    "pommelassent": ("pommeler",),
    "pommelasses": ("pommeler",),
    "pommelasse": ("pommeler",),
    "pommelassiez": ("pommeler",),
    "pommelassions": ("pommeler",),
    "pommelâtes": ("pommeler",),
    "pommelât": ("pommeler",),
    "pommelée": ("pommeler",),
    "pommelées": ("pommeler",),
    "pommelé": ("pommeler",),
    "pommelèrent": ("pommeler",),
    "pommelés": ("pommeler",),
    "pommelez": ("pommeler",),
    "pommeliez": ("pommeler",),
    "pommelions": ("pommeler",),
    "pommellent": ("pommeler",),
    "pommelle": ("pommeler",),
    "pommellera": ("pommeler",),
    "pommelleraient": ("pommeler",),
    "pommellerai": ("pommeler",),
    "pommellerais": ("pommeler",),
    "pommellerait": ("pommeler",),
    "pommelleras": ("pommeler",),
    "pommellerez": ("pommeler",),
    "pommelleriez": ("pommeler",),
    "pommellerions": ("pommeler",),
    "pommellerons": ("pommeler",),
    "pommelleront": ("pommeler",),
    "pommelles": ("pommeler",),
    "pommelons": ("pommeler",),
    "ponçaient": ("poncer",),
    "ponçai": ("poncer",),
    "ponçais": ("poncer",),
    "ponçait": ("poncer",),
    "ponça": ("poncer",),
    "ponçâmes": ("poncer",),
    "ponçant": ("poncer",),
    "ponças": ("poncer",),
    "ponçassent": ("poncer",),
    "ponçasses": ("poncer",),
    "ponçasse": ("poncer",),
    "ponçassiez": ("poncer",),
    "ponçassions": ("poncer",),
    "ponçâtes": ("poncer",),
    "ponçât": ("poncer",),
    "poncée": ("poncer",),
    "poncées": ("poncer",),
    "poncé": ("poncer",),
    "poncent": ("poncer",),
    "ponce": ("poncer",),
    "poncera": ("poncer",),
    "ponceraient": ("poncer",),
    "poncerai": ("poncer",),
    "poncerais": ("poncer",),
    "poncerait": ("poncer",),
    "ponceras": ("poncer",),
    "poncèrent": ("poncer",),
    "poncerez": ("poncer",),
    "ponceriez": ("poncer",),
    "poncerions": ("poncer",),
    "poncerons": ("poncer",),
    "ponceront": ("poncer",),
    "poncés": ("poncer",),
    "ponces": ("poncer",),
    "poncez": ("poncer",),
    "ponciez": ("poncer",),
    "poncions": ("poncer",),
    "ponçons": ("poncer",),
    "pondéraient": ("pondérer",),
    "pondérai": ("pondérer",),
    "pondérais": ("pondérer",),
    "pondérait": ("pondérer",),
    "pondéra": ("pondérer",),
    "pondérâmes": ("pondérer",),
    "pondérant": ("pondérer",),
    "pondéras": ("pondérer",),
    "pondérassent": ("pondérer",),
    "pondérasses": ("pondérer",),
    "pondérasse": ("pondérer",),
    "pondérassiez": ("pondérer",),
    "pondérassions": ("pondérer",),
    "pondérâtes": ("pondérer",),
    "pondérât": ("pondérer",),
    "pondérée": ("pondérer",),
    "pondérées": ("pondérer",),
    "pondéré": ("pondérer",),
    "pondèrent": ("pondérer",),
    "pondère": ("pondérer",),
    "pondérera": ("pondérer",),
    "pondéreraient": ("pondérer",),
    "pondérerai": ("pondérer",),
    "pondérerais": ("pondérer",),
    "pondérerait": ("pondérer",),
    "pondéreras": ("pondérer",),
    "pondérèrent": ("pondérer",),
    "pondérerez": ("pondérer",),
    "pondéreriez": ("pondérer",),
    "pondérerions": ("pondérer",),
    "pondérerons": ("pondérer",),
    "pondéreront": ("pondérer",),
    "pondérés": ("pondérer",),
    "pondères": ("pondérer",),
    "pondérez": ("pondérer",),
    "pondériez": ("pondérer",),
    "pondérions": ("pondérer",),
    "pondérons": ("pondérer",),
    "pondaient": ("pondre",),
    "pondais": ("pondre",),
    "pondait": ("pondre",),
    "pondant": ("pondre",),
    "pondent": ("pondre",),
    "ponde": ("pondre",),
    "pondes": ("pondre",),
    "pondez": ("pondre",),
    "pondiez": ("pondre",),
    "pondîmes": ("pondre",),
    "pondions": ("pondre",),
    "pondirent": ("pondre",),
    "pondis": ("pondre",),
    "pondissent": ("pondre",),
    "pondisses": ("pondre",),
    "pondisse": ("pondre",),
    "pondissiez": ("pondre",),
    "pondissions": ("pondre",),
    "pondîtes": ("pondre",),
    "pondit": ("pondre",),
    "pondît": ("pondre",),
    "pondons": ("pondre",),
    "pond": ("pondre",),
    "pondra": ("pondre",),
    "pondraient": ("pondre",),
    "pondrai": ("pondre",),
    "pondrais": ("pondre",),
    "pondrait": ("pondre",),
    "pondras": ("pondre",),
    "pondrez": ("pondre",),
    "pondriez": ("pondre",),
    "pondrions": ("pondre",),
    "pondrons": ("pondre",),
    "pondront": ("pondre",),
    "ponds": ("pondre",),
    "pondue": ("pondre",),
    "pondues": ("pondre",),
    "pondu": ("pondre",),
    "pondus": ("pondre",),
    "pontelaient": ("ponteler",),
    "pontelai": ("ponteler",),
    "pontelais": ("ponteler",),
    "pontelait": ("ponteler",),
    "pontela": ("ponteler",),
    "pontelâmes": ("ponteler",),
    "pontelant": ("ponteler",),
    "pontelas": ("ponteler",),
    "pontelassent": ("ponteler",),
    "pontelasses": ("ponteler",),
    "pontelasse": ("ponteler",),
    "pontelassiez": ("ponteler",),
    "pontelassions": ("ponteler",),
    "pontelâtes": ("ponteler",),
    "pontelât": ("ponteler",),
    "pontelée": ("ponteler",),
    "pontelées": ("ponteler",),
    "pontelé": ("ponteler",),
    "pontelèrent": ("ponteler",),
    "pontelés": ("ponteler",),
    "pontelez": ("ponteler",),
    "ponteliez": ("ponteler",),
    "pontelions": ("ponteler",),
    "pontellent": ("ponteler",),
    "pontelle": ("ponteler",),
    "pontellera": ("ponteler",),
    "pontelleraient": ("ponteler",),
    "pontellerai": ("ponteler",),
    "pontellerais": ("ponteler",),
    "pontellerait": ("ponteler",),
    "pontelleras": ("ponteler",),
    "pontellerez": ("ponteler",),
    "pontelleriez": ("ponteler",),
    "pontellerions": ("ponteler",),
    "pontellerons": ("ponteler",),
    "pontelleront": ("ponteler",),
    "pontelles": ("ponteler",),
    "pontelons": ("ponteler",),
    "pontifiaient": ("pontifier",),
    "pontifiai": ("pontifier",),
    "pontifiais": ("pontifier",),
    "pontifiait": ("pontifier",),
    "pontifia": ("pontifier",),
    "pontifiâmes": ("pontifier",),
    "pontifiant": ("pontifier",),
    "pontifias": ("pontifier",),
    "pontifiassent": ("pontifier",),
    "pontifiasses": ("pontifier",),
    "pontifiasse": ("pontifier",),
    "pontifiassiez": ("pontifier",),
    "pontifiassions": ("pontifier",),
    "pontifiâtes": ("pontifier",),
    "pontifiât": ("pontifier",),
    "pontifié": ("pontifier",),
    "pontifient": ("pontifier",),
    "pontifie": ("pontifier",),
    "pontifiera": ("pontifier",),
    "pontifieraient": ("pontifier",),
    "pontifierai": ("pontifier",),
    "pontifierais": ("pontifier",),
    "pontifierait": ("pontifier",),
    "pontifieras": ("pontifier",),
    "pontifièrent": ("pontifier",),
    "pontifierez": ("pontifier",),
    "pontifieriez": ("pontifier",),
    "pontifierions": ("pontifier",),
    "pontifierons": ("pontifier",),
    "pontifieront": ("pontifier",),
    "pontifies": ("pontifier",),
    "pontifiez": ("pontifier",),
    "pontifiiez": ("pontifier",),
    "pontifiions": ("pontifier",),
    "pontifions": ("pontifier",),
    "portageaient": ("portager",),
    "portageai": ("portager",),
    "portageais": ("portager",),
    "portageait": ("portager",),
    "portagea": ("portager",),
    "portageâmes": ("portager",),
    "portageant": ("portager",),
    "portageas": ("portager",),
    "portageassent": ("portager",),
    "portageasses": ("portager",),
    "portageasse": ("portager",),
    "portageassiez": ("portager",),
    "portageassions": ("portager",),
    "portageâtes": ("portager",),
    "portageât": ("portager",),
    "portagée": ("portager",),
    "portagées": ("portager",),
    "portagé": ("portager",),
    "portagent": ("portager",),
    "portageons": ("portager",),
    "portage": ("portager",),
    "portagera": ("portager",),
    "portageraient": ("portager",),
    "portagerai": ("portager",),
    "portagerais": ("portager",),
    "portagerait": ("portager",),
    "portageras": ("portager",),
    "portagèrent": ("portager",),
    "portagerez": ("portager",),
    "portageriez": ("portager",),
    "portagerions": ("portager",),
    "portagerons": ("portager",),
    "portageront": ("portager",),
    "portagés": ("portager",),
    "portages": ("portager",),
    "portagez": ("portager",),
    "portagiez": ("portager",),
    "portagions": ("portager",),
    "portraient": ("portraire",),
    "portraie": ("portraire",),
    "portraies": ("portraire",),
    "portraira": ("portraire",),
    "portrairaient": ("portraire",),
    "portrairai": ("portraire",),
    "portrairais": ("portraire",),
    "portrairait": ("portraire",),
    "portrairas": ("portraire",),
    "portrairez": ("portraire",),
    "portrairiez": ("portraire",),
    "portrairions": ("portraire",),
    "portrairons": ("portraire",),
    "portrairont": ("portraire",),
    "portrais": ("portraire",),
    "portraite": ("portraire",),
    "portraites": ("portraire",),
    "portrait": ("portraire",),
    "portraits": ("portraire",),
    "portrayaient": ("portraire",),
    "portrayais": ("portraire",),
    "portrayait": ("portraire",),
    "portrayant": ("portraire",),
    "portrayez": ("portraire",),
    "portrayiez": ("portraire",),
    "portrayions": ("portraire",),
    "portrayons": ("portraire",),
    "possédaient": ("posséder",),
    "possédai": ("posséder",),
    "possédais": ("posséder",),
    "possédait": ("posséder",),
    "posséda": ("posséder",),
    "possédâmes": ("posséder",),
    "possédant": ("posséder",),
    "possédas": ("posséder",),
    "possédassent": ("posséder",),
    "possédasses": ("posséder",),
    "possédasse": ("posséder",),
    "possédassiez": ("posséder",),
    "possédassions": ("posséder",),
    "possédâtes": ("posséder",),
    "possédât": ("posséder",),
    "possédée": ("posséder",),
    "possédées": ("posséder",),
    "possédé": ("posséder",),
    "possèdent": ("posséder",),
    "possède": ("posséder",),
    "possédera": ("posséder",),
    "posséderaient": ("posséder",),
    "posséderai": ("posséder",),
    "posséderais": ("posséder",),
    "posséderait": ("posséder",),
    "posséderas": ("posséder",),
    "possédèrent": ("posséder",),
    "posséderez": ("posséder",),
    "posséderiez": ("posséder",),
    "posséderions": ("posséder",),
    "posséderons": ("posséder",),
    "posséderont": ("posséder",),
    "possédés": ("posséder",),
    "possèdes": ("posséder",),
    "possédez": ("posséder",),
    "possédiez": ("posséder",),
    "possédions": ("posséder",),
    "possédons": ("posséder",),
    "postfaçaient": ("postfacer",),
    "postfaçai": ("postfacer",),
    "postfaçais": ("postfacer",),
    "postfaçait": ("postfacer",),
    "postfaça": ("postfacer",),
    "postfaçâmes": ("postfacer",),
    "postfaçant": ("postfacer",),
    "postfaças": ("postfacer",),
    "postfaçassent": ("postfacer",),
    "postfaçasses": ("postfacer",),
    "postfaçasse": ("postfacer",),
    "postfaçassiez": ("postfacer",),
    "postfaçassions": ("postfacer",),
    "postfaçâtes": ("postfacer",),
    "postfaçât": ("postfacer",),
    "postfacée": ("postfacer",),
    "postfacées": ("postfacer",),
    "postfacé": ("postfacer",),
    "postfacent": ("postfacer",),
    "postface": ("postfacer",),
    "postfacera": ("postfacer",),
    "postfaceraient": ("postfacer",),
    "postfacerai": ("postfacer",),
    "postfacerais": ("postfacer",),
    "postfacerait": ("postfacer",),
    "postfaceras": ("postfacer",),
    "postfacèrent": ("postfacer",),
    "postfacerez": ("postfacer",),
    "postfaceriez": ("postfacer",),
    "postfacerions": ("postfacer",),
    "postfacerons": ("postfacer",),
    "postfaceront": ("postfacer",),
    "postfacés": ("postfacer",),
    "postfaces": ("postfacer",),
    "postfacez": ("postfacer",),
    "postfaciez": ("postfacer",),
    "postfacions": ("postfacer",),
    "postfaçons": ("postfacer",),
    "potassaient": ("potasser",),
    "potassai": ("potasser",),
    "potassais": ("potasser",),
    "potassait": ("potasser",),
    "potassa": ("potasser",),
    "potassâmes": ("potasser",),
    "potassant": ("potasser",),
    "potassas": ("potasser",),
    "potassassent": ("potasser",),
    "potassasses": ("potasser",),
    "potassasse": ("potasser",),
    "potassassiez": ("potasser",),
    "potassassions": ("potasser",),
    "potassâtes": ("potasser",),
    "potassât": ("potasser",),
    "potassée": ("potasser",),
    "potassées": ("potasser",),
    "potassé": ("potasser",),
    "potassent": ("potasser",),
    "potasse": ("potasser",),
    "potassera": ("potasser",),
    "potasseraient": ("potasser",),
    "potasserai": ("potasser",),
    "potasserais": ("potasser",),
    "potasserait": ("potasser",),
    "potasseras": ("potasser",),
    "potassèrent": ("potasser",),
    "potasserez": ("potasser",),
    "potasseriez": ("potasser",),
    "potasserions": ("potasser",),
    "potasserons": ("potasser",),
    "potasseront": ("potasser",),
    "potassés": ("potasser",),
    "potasses": ("potasser",),
    "potassez": ("potasser",),
    "potassiez": ("potasser",),
    "potassions": ("potasser",),
    "potassons": ("potasser",),
    "potelaient": ("poteler",),
    "potelai": ("poteler",),
    "potelais": ("poteler",),
    "potelait": ("poteler",),
    "potela": ("poteler",),
    "potelâmes": ("poteler",),
    "potelant": ("poteler",),
    "potelas": ("poteler",),
    "potelassent": ("poteler",),
    "potelasses": ("poteler",),
    "potelasse": ("poteler",),
    "potelassiez": ("poteler",),
    "potelassions": ("poteler",),
    "potelâtes": ("poteler",),
    "potelât": ("poteler",),
    "potelée": ("poteler",),
    "potelées": ("poteler",),
    "potelé": ("poteler",),
    "potelèrent": ("poteler",),
    "potelés": ("poteler",),
    "potelez": ("poteler",),
    "poteliez": ("poteler",),
    "potelions": ("poteler",),
    "potellent": ("poteler",),
    "potelle": ("poteler",),
    "potellera": ("poteler",),
    "potelleraient": ("poteler",),
    "potellerai": ("poteler",),
    "potellerais": ("poteler",),
    "potellerait": ("poteler",),
    "potelleras": ("poteler",),
    "potellerez": ("poteler",),
    "potelleriez": ("poteler",),
    "potellerions": ("poteler",),
    "potellerons": ("poteler",),
    "potelleront": ("poteler",),
    "potelles": ("poteler",),
    "potelons": ("poteler",),
    "potentiaient": ("potentier",),
    "potentiai": ("potentier",),
    "potentiais": ("potentier",),
    "potentiait": ("potentier",),
    "potentia": ("potentier",),
    "potentiâmes": ("potentier",),
    "potentiant": ("potentier",),
    "potentias": ("potentier",),
    "potentiassent": ("potentier",),
    "potentiasses": ("potentier",),
    "potentiasse": ("potentier",),
    "potentiassiez": ("potentier",),
    "potentiassions": ("potentier",),
    "potentiâtes": ("potentier",),
    "potentiât": ("potentier",),
    "potentiée": ("potentier",),
    "potentiées": ("potentier",),
    "potentié": ("potentier",),
    "potentient": ("potentier",),
    "potentie": ("potentier",),
    "potentiera": ("potentier",),
    "potentieraient": ("potentier",),
    "potentierai": ("potentier",),
    "potentierais": ("potentier",),
    "potentierait": ("potentier",),
    "potentieras": ("potentier",),
    "potentièrent": ("potentier",),
    "potentierez": ("potentier",),
    "potentieriez": ("potentier",),
    "potentierions": ("potentier",),
    "potentierons": ("potentier",),
    "potentieront": ("potentier",),
    "potentiés": ("potentier",),
    "potenties": ("potentier",),
    "potentiez": ("potentier",),
    "potentiiez": ("potentier",),
    "potentiions": ("potentier",),
    "potentions": ("potentier",),
    "poudroient": ("poudroyer",),
    "poudroie": ("poudroyer",),
    "poudroiera": ("poudroyer",),
    "poudroieraient": ("poudroyer",),
    "poudroierai": ("poudroyer",),
    "poudroierais": ("poudroyer",),
    "poudroierait": ("poudroyer",),
    "poudroieras": ("poudroyer",),
    "poudroierez": ("poudroyer",),
    "poudroieriez": ("poudroyer",),
    "poudroierions": ("poudroyer",),
    "poudroierons": ("poudroyer",),
    "poudroieront": ("poudroyer",),
    "poudroies": ("poudroyer",),
    "poudroyaient": ("poudroyer",),
    "poudroyai": ("poudroyer",),
    "poudroyais": ("poudroyer",),
    "poudroyait": ("poudroyer",),
    "poudroya": ("poudroyer",),
    "poudroyâmes": ("poudroyer",),
    "poudroyant": ("poudroyer",),
    "poudroyas": ("poudroyer",),
    "poudroyassent": ("poudroyer",),
    "poudroyasses": ("poudroyer",),
    "poudroyasse": ("poudroyer",),
    "poudroyassiez": ("poudroyer",),
    "poudroyassions": ("poudroyer",),
    "poudroyâtes": ("poudroyer",),
    "poudroyât": ("poudroyer",),
    "poudroyé": ("poudroyer",),
    "poudroyèrent": ("poudroyer",),
    "poudroyez": ("poudroyer",),
    "poudroyiez": ("poudroyer",),
    "poudroyions": ("poudroyer",),
    "poudroyons": ("poudroyer",),
    "pourchassaient": ("pourchasser",),
    "pourchassai": ("pourchasser",),
    "pourchassais": ("pourchasser",),
    "pourchassait": ("pourchasser",),
    "pourchassa": ("pourchasser",),
    "pourchassâmes": ("pourchasser",),
    "pourchassant": ("pourchasser",),
    "pourchassas": ("pourchasser",),
    "pourchassassent": ("pourchasser",),
    "pourchassasses": ("pourchasser",),
    "pourchassasse": ("pourchasser",),
    "pourchassassiez": ("pourchasser",),
    "pourchassassions": ("pourchasser",),
    "pourchassâtes": ("pourchasser",),
    "pourchassât": ("pourchasser",),
    "pourchassée": ("pourchasser",),
    "pourchassées": ("pourchasser",),
    "pourchassé": ("pourchasser",),
    "pourchassent": ("pourchasser",),
    "pourchasse": ("pourchasser",),
    "pourchassera": ("pourchasser",),
    "pourchasseraient": ("pourchasser",),
    "pourchasserai": ("pourchasser",),
    "pourchasserais": ("pourchasser",),
    "pourchasserait": ("pourchasser",),
    "pourchasseras": ("pourchasser",),
    "pourchassèrent": ("pourchasser",),
    "pourchasserez": ("pourchasser",),
    "pourchasseriez": ("pourchasser",),
    "pourchasserions": ("pourchasser",),
    "pourchasserons": ("pourchasser",),
    "pourchasseront": ("pourchasser",),
    "pourchassés": ("pourchasser",),
    "pourchasses": ("pourchasser",),
    "pourchassez": ("pourchasser",),
    "pourchassiez": ("pourchasser",),
    "pourchassions": ("pourchasser",),
    "pourchassons": ("pourchasser",),
    "pourfendaient": ("pourfendre",),
    "pourfendais": ("pourfendre",),
    "pourfendait": ("pourfendre",),
    "pourfendant": ("pourfendre",),
    "pourfendent": ("pourfendre",),
    "pourfende": ("pourfendre",),
    "pourfendes": ("pourfendre",),
    "pourfendez": ("pourfendre",),
    "pourfendiez": ("pourfendre",),
    "pourfendîmes": ("pourfendre",),
    "pourfendions": ("pourfendre",),
    "pourfendirent": ("pourfendre",),
    "pourfendis": ("pourfendre",),
    "pourfendissent": ("pourfendre",),
    "pourfendisses": ("pourfendre",),
    "pourfendisse": ("pourfendre",),
    "pourfendissiez": ("pourfendre",),
    "pourfendissions": ("pourfendre",),
    "pourfendîtes": ("pourfendre",),
    "pourfendit": ("pourfendre",),
    "pourfendît": ("pourfendre",),
    "pourfendons": ("pourfendre",),
    "pourfend": ("pourfendre",),
    "pourfendra": ("pourfendre",),
    "pourfendraient": ("pourfendre",),
    "pourfendrai": ("pourfendre",),
    "pourfendrais": ("pourfendre",),
    "pourfendrait": ("pourfendre",),
    "pourfendras": ("pourfendre",),
    "pourfendrez": ("pourfendre",),
    "pourfendriez": ("pourfendre",),
    "pourfendrions": ("pourfendre",),
    "pourfendrons": ("pourfendre",),
    "pourfendront": ("pourfendre",),
    "pourfends": ("pourfendre",),
    "pourfendue": ("pourfendre",),
    "pourfendues": ("pourfendre",),
    "pourfendu": ("pourfendre",),
    "pourfendus": ("pourfendre",),
    "pourléchaient": ("pourlécher",),
    "pourléchai": ("pourlécher",),
    "pourléchais": ("pourlécher",),
    "pourléchait": ("pourlécher",),
    "pourlécha": ("pourlécher",),
    "pourléchâmes": ("pourlécher",),
    "pourléchant": ("pourlécher",),
    "pourléchas": ("pourlécher",),
    "pourléchassent": ("pourlécher",),
    "pourléchasses": ("pourlécher",),
    "pourléchasse": ("pourlécher",),
    "pourléchassiez": ("pourlécher",),
    "pourléchassions": ("pourlécher",),
    "pourléchâtes": ("pourlécher",),
    "pourléchât": ("pourlécher",),
    "pourléchée": ("pourlécher",),
    "pourléchées": ("pourlécher",),
    "pourléché": ("pourlécher",),
    "pourlèchent": ("pourlécher",),
    "pourlèche": ("pourlécher",),
    "pourléchera": ("pourlécher",),
    "pourlécheraient": ("pourlécher",),
    "pourlécherai": ("pourlécher",),
    "pourlécherais": ("pourlécher",),
    "pourlécherait": ("pourlécher",),
    "pourlécheras": ("pourlécher",),
    "pourléchèrent": ("pourlécher",),
    "pourlécherez": ("pourlécher",),
    "pourlécheriez": ("pourlécher",),
    "pourlécherions": ("pourlécher",),
    "pourlécherons": ("pourlécher",),
    "pourlécheront": ("pourlécher",),
    "pourléchés": ("pourlécher",),
    "pourlèches": ("pourlécher",),
    "pourléchez": ("pourlécher",),
    "pourléchiez": ("pourlécher",),
    "pourléchions": ("pourlécher",),
    "pourléchons": ("pourlécher",),
    "pourrie": ("pourrir",),
    "pourries": ("pourrir",),
    "pourri": ("pourrir",),
    "pourrîmes": ("pourrir",),
    "pourrira": ("pourrir",),
    "pourriraient": ("pourrir",),
    "pourrirai": ("pourrir",),
    "pourrirais": ("pourrir",),
    "pourrirait": ("pourrir",),
    "pourriras": ("pourrir",),
    "pourrirent": ("pourrir",),
    "pourrirez": ("pourrir",),
    "pourririez": ("pourrir",),
    "pourririons": ("pourrir",),
    "pourrirons": ("pourrir",),
    "pourriront": ("pourrir",),
    "pourris": ("pourrir",),
    "pourrissaient": ("pourrir",),
    "pourrissais": ("pourrir",),
    "pourrissait": ("pourrir",),
    "pourrissant": ("pourrir",),
    "pourrissent": ("pourrir",),
    "pourrisse": ("pourrir",),
    "pourrisses": ("pourrir",),
    "pourrissez": ("pourrir",),
    "pourrissiez": ("pourrir",),
    "pourrissions": ("pourrir",),
    "pourrissons": ("pourrir",),
    "pourrîtes": ("pourrir",),
    "pourrit": ("pourrir",),
    "pourrît": ("pourrir",),
    "poursuis": ("poursuivre",),
    "poursuit": ("poursuivre",),
    "poursuivaient": ("poursuivre",),
    "poursuivais": ("poursuivre",),
    "poursuivait": ("poursuivre",),
    "poursuivant": ("poursuivre",),
    "poursuivent": ("poursuivre",),
    "poursuive": ("poursuivre",),
    "poursuives": ("poursuivre",),
    "poursuivez": ("poursuivre",),
    "poursuivie": ("poursuivre",),
    "poursuivies": ("poursuivre",),
    "poursuiviez": ("poursuivre",),
    "poursuivi": ("poursuivre",),
    "poursuivîmes": ("poursuivre",),
    "poursuivions": ("poursuivre",),
    "poursuivirent": ("poursuivre",),
    "poursuivis": ("poursuivre",),
    "poursuivissent": ("poursuivre",),
    "poursuivisses": ("poursuivre",),
    "poursuivisse": ("poursuivre",),
    "poursuivissiez": ("poursuivre",),
    "poursuivissions": ("poursuivre",),
    "poursuivîtes": ("poursuivre",),
    "poursuivit": ("poursuivre",),
    "poursuivît": ("poursuivre",),
    "poursuivons": ("poursuivre",),
    "poursuivra": ("poursuivre",),
    "poursuivraient": ("poursuivre",),
    "poursuivrai": ("poursuivre",),
    "poursuivrais": ("poursuivre",),
    "poursuivrait": ("poursuivre",),
    "poursuivras": ("poursuivre",),
    "poursuivrez": ("poursuivre",),
    "poursuivriez": ("poursuivre",),
    "poursuivrions": ("poursuivre",),
    "poursuivrons": ("poursuivre",),
    "poursuivront": ("poursuivre",),
    "pourtraient": ("pourtraire",),
    "pourtraie": ("pourtraire",),
    "pourtraies": ("pourtraire",),
    "pourtraira": ("pourtraire",),
    "pourtrairaient": ("pourtraire",),
    "pourtrairai": ("pourtraire",),
    "pourtrairais": ("pourtraire",),
    "pourtrairait": ("pourtraire",),
    "pourtrairas": ("pourtraire",),
    "pourtrairez": ("pourtraire",),
    "pourtrairiez": ("pourtraire",),
    "pourtrairions": ("pourtraire",),
    "pourtrairons": ("pourtraire",),
    "pourtrairont": ("pourtraire",),
    "pourtrais": ("pourtraire",),
    "pourtraite": ("pourtraire",),
    "pourtraites": ("pourtraire",),
    "pourtrait": ("pourtraire",),
    "pourtraits": ("pourtraire",),
    "pourtrayaient": ("pourtraire",),
    "pourtrayais": ("pourtraire",),
    "pourtrayait": ("pourtraire",),
    "pourtrayant": ("pourtraire",),
    "pourtrayez": ("pourtraire",),
    "pourtrayiez": ("pourtraire",),
    "pourtrayions": ("pourtraire",),
    "pourtrayons": ("pourtraire",),
    "pourvoient": ("pourvoir",),
    "pourvoie": ("pourvoir",),
    "pourvoies": ("pourvoir",),
    "pourvoira": ("pourvoir",),
    "pourvoiraient": ("pourvoir",),
    "pourvoirai": ("pourvoir",),
    "pourvoirais": ("pourvoir",),
    "pourvoirait": ("pourvoir",),
    "pourvoiras": ("pourvoir",),
    "pourvoirez": ("pourvoir",),
    "pourvoiriez": ("pourvoir",),
    "pourvoirions": ("pourvoir",),
    "pourvoirons": ("pourvoir",),
    "pourvoiront": ("pourvoir",),
    "pourvois": ("pourvoir",),
    "pourvoit": ("pourvoir",),
    "pourvoyaient": ("pourvoir",),
    "pourvoyais": ("pourvoir",),
    "pourvoyait": ("pourvoir",),
    "pourvoyant": ("pourvoir",),
    "pourvoyez": ("pourvoir",),
    "pourvoyiez": ("pourvoir",),
    "pourvoyions": ("pourvoir",),
    "pourvoyons": ("pourvoir",),
    "pourvue": ("pourvoir",),
    "pourvues": ("pourvoir",),
    "pourvu": ("pourvoir",),
    "pourvûmes": ("pourvoir",),
    "pourvurent": ("pourvoir",),
    "pourvus": ("pourvoir",),
    "pourvussent": ("pourvoir",),
    "pourvusses": ("pourvoir",),
    "pourvusse": ("pourvoir",),
    "pourvussiez": ("pourvoir",),
    "pourvussions": ("pourvoir",),
    "pourvûtes": ("pourvoir",),
    "pourvut": ("pourvoir",),
    "pourvût": ("pourvoir",),
    "poussiéraient": ("poussiérer",),
    "poussiérai": ("poussiérer",),
    "poussiérais": ("poussiérer",),
    "poussiérait": ("poussiérer",),
    "poussiéra": ("poussiérer",),
    "poussiérâmes": ("poussiérer",),
    "poussiérant": ("poussiérer",),
    "poussiéras": ("poussiérer",),
    "poussiérassent": ("poussiérer",),
    "poussiérasses": ("poussiérer",),
    "poussiérasse": ("poussiérer",),
    "poussiérassiez": ("poussiérer",),
    "poussiérassions": ("poussiérer",),
    "poussiérâtes": ("poussiérer",),
    "poussiérât": ("poussiérer",),
    "poussiérée": ("poussiérer",),
    "poussiérées": ("poussiérer",),
    "poussiéré": ("poussiérer",),
    "poussièrent": ("poussiérer",),
    "poussière": ("poussiérer",),
    "poussiérera": ("poussiérer",),
    "poussiéreraient": ("poussiérer",),
    "poussiérerai": ("poussiérer",),
    "poussiérerais": ("poussiérer",),
    "poussiérerait": ("poussiérer",),
    "poussiéreras": ("poussiérer",),
    "poussiérèrent": ("poussiérer",),
    "poussiérerez": ("poussiérer",),
    "poussiéreriez": ("poussiérer",),
    "poussiérerions": ("poussiérer",),
    "poussiérerons": ("poussiérer",),
    "poussiéreront": ("poussiérer",),
    "poussiérés": ("poussiérer",),
    "poussières": ("poussiérer",),
    "poussiérez": ("poussiérer",),
    "poussiériez": ("poussiérer",),
    "poussiérions": ("poussiérer",),
    "poussiérons": ("poussiérer",),
    "peut": ("pouvoir",),
    "peuvent": ("pouvoir",),
    "peux": ("pouvoir",),
    "pourra": ("pouvoir",),
    "pourraient": ("pouvoir",),
    "pourrai": ("pouvoir",),
    "pourrais": ("pouvoir",),
    "pourrait": ("pouvoir",),
    "pourras": ("pouvoir",),
    "pourrez": ("pouvoir",),
    "pourriez": ("pouvoir",),
    "pourrions": ("pouvoir",),
    "pourrons": ("pouvoir",),
    "pourront": ("pouvoir",),
    "pouvaient": ("pouvoir",),
    "pouvais": ("pouvoir",),
    "pouvait": ("pouvoir",),
    "pouvant": ("pouvoir",),
    "pouvez": ("pouvoir",),
    "pouviez": ("pouvoir",),
    "pouvions": ("pouvoir",),
    "pouvons": ("pouvoir",),
    "puis": ("pouvoir",),
    "puissent": ("pouvoir",),
    "puisse": ("pouvoir",),
    "puisses": ("pouvoir",),
    "puissé": ("pouvoir",),
    "puissiez": ("pouvoir",),
    "puissions": ("pouvoir",),
    "pûmes": ("pouvoir",),
    "purent": ("pouvoir",),
    "pus": ("pouvoir",),
    "pussent": ("pouvoir",),
    "pusses": ("pouvoir",),
    "pusse": ("pouvoir",),
    "pussiez": ("pouvoir",),
    "pussions": ("pouvoir",),
    "pûtes": ("pouvoir",),
    "put": ("pouvoir",),
    "pût": ("pouvoir",),
    "préachetaient": ("préacheter",),
    "préachetai": ("préacheter",),
    "préachetais": ("préacheter",),
    "préachetait": ("préacheter",),
    "préacheta": ("préacheter",),
    "préachetâmes": ("préacheter",),
    "préachetant": ("préacheter",),
    "préachetas": ("préacheter",),
    "préachetassent": ("préacheter",),
    "préachetasses": ("préacheter",),
    "préachetasse": ("préacheter",),
    "préachetassiez": ("préacheter",),
    "préachetassions": ("préacheter",),
    "préachetâtes": ("préacheter",),
    "préachetât": ("préacheter",),
    "préachetée": ("préacheter",),
    "préachetées": ("préacheter",),
    "préacheté": ("préacheter",),
    "préachètent": ("préacheter",),
    "préachète": ("préacheter",),
    "préachètera": ("préacheter",),
    "préachèteraient": ("préacheter",),
    "préachèterai": ("préacheter",),
    "préachèterais": ("préacheter",),
    "préachèterait": ("préacheter",),
    "préachèteras": ("préacheter",),
    "préachetèrent": ("préacheter",),
    "préachèterez": ("préacheter",),
    "préachèteriez": ("préacheter",),
    "préachèterions": ("préacheter",),
    "préachèterons": ("préacheter",),
    "préachèteront": ("préacheter",),
    "préachetés": ("préacheter",),
    "préachètes": ("préacheter",),
    "préachetez": ("préacheter",),
    "préachetiez": ("préacheter",),
    "préachetions": ("préacheter",),
    "préachetons": ("préacheter",),
    "préannonçaient": ("préannoncer",),
    "préannonçai": ("préannoncer",),
    "préannonçais": ("préannoncer",),
    "préannonçait": ("préannoncer",),
    "préannonça": ("préannoncer",),
    "préannonçâmes": ("préannoncer",),
    "préannonçant": ("préannoncer",),
    "préannonças": ("préannoncer",),
    "préannonçassent": ("préannoncer",),
    "préannonçasses": ("préannoncer",),
    "préannonçasse": ("préannoncer",),
    "préannonçassiez": ("préannoncer",),
    "préannonçassions": ("préannoncer",),
    "préannonçâtes": ("préannoncer",),
    "préannonçât": ("préannoncer",),
    "préannoncée": ("préannoncer",),
    "préannoncées": ("préannoncer",),
    "préannoncé": ("préannoncer",),
    "préannoncent": ("préannoncer",),
    "préannonce": ("préannoncer",),
    "préannoncera": ("préannoncer",),
    "préannonceraient": ("préannoncer",),
    "préannoncerai": ("préannoncer",),
    "préannoncerais": ("préannoncer",),
    "préannoncerait": ("préannoncer",),
    "préannonceras": ("préannoncer",),
    "préannoncèrent": ("préannoncer",),
    "préannoncerez": ("préannoncer",),
    "préannonceriez": ("préannoncer",),
    "préannoncerions": ("préannoncer",),
    "préannoncerons": ("préannoncer",),
    "préannonceront": ("préannoncer",),
    "préannoncés": ("préannoncer",),
    "préannonces": ("préannoncer",),
    "préannoncez": ("préannoncer",),
    "préannonciez": ("préannoncer",),
    "préannoncions": ("préannoncer",),
    "préannonçons": ("préannoncer",),
    "préavertie": ("préavertir",),
    "préaverties": ("préavertir",),
    "préaverti": ("préavertir",),
    "préavertîmes": ("préavertir",),
    "préavertira": ("préavertir",),
    "préavertiraient": ("préavertir",),
    "préavertirai": ("préavertir",),
    "préavertirais": ("préavertir",),
    "préavertirait": ("préavertir",),
    "préavertiras": ("préavertir",),
    "préavertirent": ("préavertir",),
    "préavertirez": ("préavertir",),
    "préavertiriez": ("préavertir",),
    "préavertirions": ("préavertir",),
    "préavertirons": ("préavertir",),
    "préavertiront": ("préavertir",),
    "préavertis": ("préavertir",),
    "préavertissaient": ("préavertir",),
    "préavertissais": ("préavertir",),
    "préavertissait": ("préavertir",),
    "préavertissant": ("préavertir",),
    "préavertissent": ("préavertir",),
    "préavertisse": ("préavertir",),
    "préavertisses": ("préavertir",),
    "préavertissez": ("préavertir",),
    "préavertissiez": ("préavertir",),
    "préavertissions": ("préavertir",),
    "préavertissons": ("préavertir",),
    "préavertîtes": ("préavertir",),
    "préavertit": ("préavertir",),
    "préavertît": ("préavertir",),
    "précédaient": ("précéder",),
    "précédai": ("précéder",),
    "précédais": ("précéder",),
    "précédait": ("précéder",),
    "précéda": ("précéder",),
    "précédâmes": ("précéder",),
    "précédant": ("précéder",),
    "précédas": ("précéder",),
    "précédassent": ("précéder",),
    "précédasses": ("précéder",),
    "précédasse": ("précéder",),
    "précédassiez": ("précéder",),
    "précédassions": ("précéder",),
    "précédâtes": ("précéder",),
    "précédât": ("précéder",),
    "précédée": ("précéder",),
    "précédées": ("précéder",),
    "précédé": ("précéder",),
    "précèdent": ("précéder",),
    "précède": ("précéder",),
    "précédera": ("précéder",),
    "précéderaient": ("précéder",),
    "précéderai": ("précéder",),
    "précéderais": ("précéder",),
    "précéderait": ("précéder",),
    "précéderas": ("précéder",),
    "précédèrent": ("précéder",),
    "précéderez": ("précéder",),
    "précéderiez": ("précéder",),
    "précéderions": ("précéder",),
    "précéderons": ("précéder",),
    "précéderont": ("précéder",),
    "précédés": ("précéder",),
    "précèdes": ("précéder",),
    "précédez": ("précéder",),
    "précédiez": ("précéder",),
    "précédions": ("précéder",),
    "précédons": ("précéder",),
    "préchargeaient": ("précharger",),
    "préchargeai": ("précharger",),
    "préchargeais": ("précharger",),
    "préchargeait": ("précharger",),
    "préchargea": ("précharger",),
    "préchargeâmes": ("précharger",),
    "préchargeant": ("précharger",),
    "préchargeas": ("précharger",),
    "préchargeassent": ("précharger",),
    "préchargeasses": ("précharger",),
    "préchargeasse": ("précharger",),
    "préchargeassiez": ("précharger",),
    "préchargeassions": ("précharger",),
    "préchargeâtes": ("précharger",),
    "préchargeât": ("précharger",),
    "préchargée": ("précharger",),
    "préchargées": ("précharger",),
    "préchargé": ("précharger",),
    "préchargent": ("précharger",),
    "préchargeons": ("précharger",),
    "précharge": ("précharger",),
    "préchargera": ("précharger",),
    "préchargeraient": ("précharger",),
    "préchargerai": ("précharger",),
    "préchargerais": ("précharger",),
    "préchargerait": ("précharger",),
    "préchargeras": ("précharger",),
    "préchargèrent": ("précharger",),
    "préchargerez": ("précharger",),
    "préchargeriez": ("précharger",),
    "préchargerions": ("précharger",),
    "préchargerons": ("précharger",),
    "préchargeront": ("précharger",),
    "préchargés": ("précharger",),
    "précharges": ("précharger",),
    "préchargez": ("précharger",),
    "préchargiez": ("précharger",),
    "préchargions": ("précharger",),
    "préconcassaient": ("préconcasser",),
    "préconcassai": ("préconcasser",),
    "préconcassais": ("préconcasser",),
    "préconcassait": ("préconcasser",),
    "préconcassa": ("préconcasser",),
    "préconcassâmes": ("préconcasser",),
    "préconcassant": ("préconcasser",),
    "préconcassas": ("préconcasser",),
    "préconcassassent": ("préconcasser",),
    "préconcassasses": ("préconcasser",),
    "préconcassasse": ("préconcasser",),
    "préconcassassiez": ("préconcasser",),
    "préconcassassions": ("préconcasser",),
    "préconcassâtes": ("préconcasser",),
    "préconcassât": ("préconcasser",),
    "préconcassée": ("préconcasser",),
    "préconcassées": ("préconcasser",),
    "préconcassé": ("préconcasser",),
    "préconcassent": ("préconcasser",),
    "préconcasse": ("préconcasser",),
    "préconcassera": ("préconcasser",),
    "préconcasseraient": ("préconcasser",),
    "préconcasserai": ("préconcasser",),
    "préconcasserais": ("préconcasser",),
    "préconcasserait": ("préconcasser",),
    "préconcasseras": ("préconcasser",),
    "préconcassèrent": ("préconcasser",),
    "préconcasserez": ("préconcasser",),
    "préconcasseriez": ("préconcasser",),
    "préconcasserions": ("préconcasser",),
    "préconcasserons": ("préconcasser",),
    "préconcasseront": ("préconcasser",),
    "préconcassés": ("préconcasser",),
    "préconcasses": ("préconcasser",),
    "préconcassez": ("préconcasser",),
    "préconcassiez": ("préconcasser",),
    "préconcassions": ("préconcasser",),
    "préconcassons": ("préconcasser",),
    "préconcevaient": ("préconcevoir",),
    "préconcevais": ("préconcevoir",),
    "préconcevait": ("préconcevoir",),
    "préconcevant": ("préconcevoir",),
    "préconcevez": ("préconcevoir",),
    "préconceviez": ("préconcevoir",),
    "préconcevions": ("préconcevoir",),
    "préconcevons": ("préconcevoir",),
    "préconcevra": ("préconcevoir",),
    "préconcevraient": ("préconcevoir",),
    "préconcevrai": ("préconcevoir",),
    "préconcevrais": ("préconcevoir",),
    "préconcevrait": ("préconcevoir",),
    "préconcevras": ("préconcevoir",),
    "préconcevrez": ("préconcevoir",),
    "préconcevriez": ("préconcevoir",),
    "préconcevrions": ("préconcevoir",),
    "préconcevrons": ("préconcevoir",),
    "préconcevront": ("préconcevoir",),
    "préconçois": ("préconcevoir",),
    "préconçoit": ("préconcevoir",),
    "préconçoivent": ("préconcevoir",),
    "préconçoive": ("préconcevoir",),
    "préconçoives": ("préconcevoir",),
    "préconçue": ("préconcevoir",),
    "préconçues": ("préconcevoir",),
    "préconçu": ("préconcevoir",),
    "préconçûmes": ("préconcevoir",),
    "préconçurent": ("préconcevoir",),
    "préconçus": ("préconcevoir",),
    "préconçussent": ("préconcevoir",),
    "préconçusses": ("préconcevoir",),
    "préconçusse": ("préconcevoir",),
    "préconçussiez": ("préconcevoir",),
    "préconçussions": ("préconcevoir",),
    "préconçûtes": ("préconcevoir",),
    "préconçut": ("préconcevoir",),
    "préconçût": ("préconcevoir",),
    "préconnais": ("préconnaître",),
    "préconnaissaient": ("préconnaître",),
    "préconnaissais": ("préconnaître",),
    "préconnaissait": ("préconnaître",),
    "préconnaissant": ("préconnaître",),
    "préconnaissent": ("préconnaître",),
    "préconnaisse": ("préconnaître",),
    "préconnaisses": ("préconnaître",),
    "préconnaissez": ("préconnaître",),
    "préconnaissiez": ("préconnaître",),
    "préconnaissions": ("préconnaître",),
    "préconnaissons": ("préconnaître",),
    "préconnaît": ("préconnaître",),
    "préconnaîtra": ("préconnaître",),
    "préconnaîtraient": ("préconnaître",),
    "préconnaîtrai": ("préconnaître",),
    "préconnaîtrais": ("préconnaître",),
    "préconnaîtrait": ("préconnaître",),
    "préconnaîtras": ("préconnaître",),
    "préconnaîtrez": ("préconnaître",),
    "préconnaîtriez": ("préconnaître",),
    "préconnaîtrions": ("préconnaître",),
    "préconnaîtrons": ("préconnaître",),
    "préconnaîtront": ("préconnaître",),
    "préconnue": ("préconnaître",),
    "préconnues": ("préconnaître",),
    "préconnu": ("préconnaître",),
    "préconnûmes": ("préconnaître",),
    "préconnurent": ("préconnaître",),
    "préconnus": ("préconnaître",),
    "préconnussent": ("préconnaître",),
    "préconnusses": ("préconnaître",),
    "préconnusse": ("préconnaître",),
    "préconnussiez": ("préconnaître",),
    "préconnussions": ("préconnaître",),
    "préconnûtes": ("préconnaître",),
    "préconnut": ("préconnaître",),
    "préconnût": ("préconnaître",),
    "préconstruira": ("préconstruire",),
    "préconstruiraient": ("préconstruire",),
    "préconstruirai": ("préconstruire",),
    "préconstruirais": ("préconstruire",),
    "préconstruirait": ("préconstruire",),
    "préconstruiras": ("préconstruire",),
    "préconstruirez": ("préconstruire",),
    "préconstruiriez": ("préconstruire",),
    "préconstruirions": ("préconstruire",),
    "préconstruirons": ("préconstruire",),
    "préconstruiront": ("préconstruire",),
    "préconstruisaient": ("préconstruire",),
    "préconstruisais": ("préconstruire",),
    "préconstruisait": ("préconstruire",),
    "préconstruisant": ("préconstruire",),
    "préconstruisent": ("préconstruire",),
    "préconstruise": ("préconstruire",),
    "préconstruises": ("préconstruire",),
    "préconstruisez": ("préconstruire",),
    "préconstruisiez": ("préconstruire",),
    "préconstruisîmes": ("préconstruire",),
    "préconstruisions": ("préconstruire",),
    "préconstruisirent": ("préconstruire",),
    "préconstruisis": ("préconstruire",),
    "préconstruisissent": ("préconstruire",),
    "préconstruisisses": ("préconstruire",),
    "préconstruisisse": ("préconstruire",),
    "préconstruisissiez": ("préconstruire",),
    "préconstruisissions": ("préconstruire",),
    "préconstruisîtes": ("préconstruire",),
    "préconstruisit": ("préconstruire",),
    "préconstruisît": ("préconstruire",),
    "préconstruisons": ("préconstruire",),
    "préconstruis": ("préconstruire",),
    "préconstruite": ("préconstruire",),
    "préconstruites": ("préconstruire",),
    "préconstruit": ("préconstruire",),
    "préconstruits": ("préconstruire",),
    "précontraignaient": ("précontraindre",),
    "précontraignais": ("précontraindre",),
    "précontraignait": ("précontraindre",),
    "précontraignant": ("précontraindre",),
    "précontraignent": ("précontraindre",),
    "précontraigne": ("précontraindre",),
    "précontraignes": ("précontraindre",),
    "précontraignez": ("précontraindre",),
    "précontraigniez": ("précontraindre",),
    "précontraignîmes": ("précontraindre",),
    "précontraignions": ("précontraindre",),
    "précontraignirent": ("précontraindre",),
    "précontraignis": ("précontraindre",),
    "précontraignissent": ("précontraindre",),
    "précontraignisses": ("précontraindre",),
    "précontraignisse": ("précontraindre",),
    "précontraignissiez": ("précontraindre",),
    "précontraignissions": ("précontraindre",),
    "précontraignîtes": ("précontraindre",),
    "précontraignit": ("précontraindre",),
    "précontraignît": ("précontraindre",),
    "précontraignons": ("précontraindre",),
    "précontraindra": ("précontraindre",),
    "précontraindraient": ("précontraindre",),
    "précontraindrai": ("précontraindre",),
    "précontraindrais": ("précontraindre",),
    "précontraindrait": ("précontraindre",),
    "précontraindras": ("précontraindre",),
    "précontraindrez": ("précontraindre",),
    "précontraindriez": ("précontraindre",),
    "précontraindrions": ("précontraindre",),
    "précontraindrons": ("précontraindre",),
    "précontraindront": ("précontraindre",),
    "précontrains": ("précontraindre",),
    "précontrainte": ("précontraindre",),
    "précontraintes": ("précontraindre",),
    "précontraint": ("précontraindre",),
    "précontraints": ("précontraindre",),
    "précorrigeaient": ("précorriger",),
    "précorrigeai": ("précorriger",),
    "précorrigeais": ("précorriger",),
    "précorrigeait": ("précorriger",),
    "précorrigea": ("précorriger",),
    "précorrigeâmes": ("précorriger",),
    "précorrigeant": ("précorriger",),
    "précorrigeas": ("précorriger",),
    "précorrigeassent": ("précorriger",),
    "précorrigeasses": ("précorriger",),
    "précorrigeasse": ("précorriger",),
    "précorrigeassiez": ("précorriger",),
    "précorrigeassions": ("précorriger",),
    "précorrigeâtes": ("précorriger",),
    "précorrigeât": ("précorriger",),
    "précorrigée": ("précorriger",),
    "précorrigées": ("précorriger",),
    "précorrigé": ("précorriger",),
    "précorrigent": ("précorriger",),
    "précorrigeons": ("précorriger",),
    "précorrige": ("précorriger",),
    "précorrigera": ("précorriger",),
    "précorrigeraient": ("précorriger",),
    "précorrigerai": ("précorriger",),
    "précorrigerais": ("précorriger",),
    "précorrigerait": ("précorriger",),
    "précorrigeras": ("précorriger",),
    "précorrigèrent": ("précorriger",),
    "précorrigerez": ("précorriger",),
    "précorrigeriez": ("précorriger",),
    "précorrigerions": ("précorriger",),
    "précorrigerons": ("précorriger",),
    "précorrigeront": ("précorriger",),
    "précorrigés": ("précorriger",),
    "précorriges": ("précorriger",),
    "précorrigez": ("précorriger",),
    "précorrigiez": ("précorriger",),
    "précorrigions": ("précorriger",),
    "précuira": ("précuire",),
    "précuiraient": ("précuire",),
    "précuirai": ("précuire",),
    "précuirais": ("précuire",),
    "précuirait": ("précuire",),
    "précuiras": ("précuire",),
    "précuirez": ("précuire",),
    "précuiriez": ("précuire",),
    "précuirions": ("précuire",),
    "précuirons": ("précuire",),
    "précuiront": ("précuire",),
    "précuisaient": ("précuire",),
    "précuisais": ("précuire",),
    "précuisait": ("précuire",),
    "précuisant": ("précuire",),
    "précuisent": ("précuire",),
    "précuise": ("précuire",),
    "précuises": ("précuire",),
    "précuisez": ("précuire",),
    "précuisiez": ("précuire",),
    "précuisîmes": ("précuire",),
    "précuisions": ("précuire",),
    "précuisirent": ("précuire",),
    "précuisis": ("précuire",),
    "précuisissent": ("précuire",),
    "précuisisses": ("précuire",),
    "précuisisse": ("précuire",),
    "précuisissiez": ("précuire",),
    "précuisissions": ("précuire",),
    "précuisîtes": ("précuire",),
    "précuisit": ("précuire",),
    "précuisît": ("précuire",),
    "précuisons": ("précuire",),
    "précuis": ("précuire",),
    "précuite": ("précuire",),
    "précuites": ("précuire",),
    "précuit": ("précuire",),
    "précuits": ("précuire",),
    "prédécédaient": ("prédécéder",),
    "prédécédai": ("prédécéder",),
    "prédécédais": ("prédécéder",),
    "prédécédait": ("prédécéder",),
    "prédécéda": ("prédécéder",),
    "prédécédâmes": ("prédécéder",),
    "prédécédant": ("prédécéder",),
    "prédécédas": ("prédécéder",),
    "prédécédassent": ("prédécéder",),
    "prédécédasses": ("prédécéder",),
    "prédécédasse": ("prédécéder",),
    "prédécédassiez": ("prédécéder",),
    "prédécédassions": ("prédécéder",),
    "prédécédâtes": ("prédécéder",),
    "prédécédât": ("prédécéder",),
    "prédécédée": ("prédécéder",),
    "prédécédées": ("prédécéder",),
    "prédécédé": ("prédécéder",),
    "prédécèdent": ("prédécéder",),
    "prédécède": ("prédécéder",),
    "prédécédera": ("prédécéder",),
    "prédécéderaient": ("prédécéder",),
    "prédécéderai": ("prédécéder",),
    "prédécéderais": ("prédécéder",),
    "prédécéderait": ("prédécéder",),
    "prédécéderas": ("prédécéder",),
    "prédécédèrent": ("prédécéder",),
    "prédécéderez": ("prédécéder",),
    "prédécéderiez": ("prédécéder",),
    "prédécéderions": ("prédécéder",),
    "prédécéderons": ("prédécéder",),
    "prédécéderont": ("prédécéder",),
    "prédécédés": ("prédécéder",),
    "prédécèdes": ("prédécéder",),
    "prédécédez": ("prédécéder",),
    "prédécédiez": ("prédécéder",),
    "prédécédions": ("prédécéder",),
    "prédécédons": ("prédécéder",),
    "prédéfinie": ("prédéfinir",),
    "prédéfinies": ("prédéfinir",),
    "prédéfini": ("prédéfinir",),
    "prédéfinîmes": ("prédéfinir",),
    "prédéfinira": ("prédéfinir",),
    "prédéfiniraient": ("prédéfinir",),
    "prédéfinirai": ("prédéfinir",),
    "prédéfinirais": ("prédéfinir",),
    "prédéfinirait": ("prédéfinir",),
    "prédéfiniras": ("prédéfinir",),
    "prédéfinirent": ("prédéfinir",),
    "prédéfinirez": ("prédéfinir",),
    "prédéfiniriez": ("prédéfinir",),
    "prédéfinirions": ("prédéfinir",),
    "prédéfinirons": ("prédéfinir",),
    "prédéfiniront": ("prédéfinir",),
    "prédéfinis": ("prédéfinir",),
    "prédéfinissaient": ("prédéfinir",),
    "prédéfinissais": ("prédéfinir",),
    "prédéfinissait": ("prédéfinir",),
    "prédéfinissant": ("prédéfinir",),
    "prédéfinissent": ("prédéfinir",),
    "prédéfinisse": ("prédéfinir",),
    "prédéfinisses": ("prédéfinir",),
    "prédéfinissez": ("prédéfinir",),
    "prédéfinissiez": ("prédéfinir",),
    "prédéfinissions": ("prédéfinir",),
    "prédéfinissons": ("prédéfinir",),
    "prédéfinîtes": ("prédéfinir",),
    "prédéfinit": ("prédéfinir",),
    "prédéfinît": ("prédéfinir",),
    "prédigéraient": ("prédigérer",),
    "prédigérai": ("prédigérer",),
    "prédigérais": ("prédigérer",),
    "prédigérait": ("prédigérer",),
    "prédigéra": ("prédigérer",),
    "prédigérâmes": ("prédigérer",),
    "prédigérant": ("prédigérer",),
    "prédigéras": ("prédigérer",),
    "prédigérassent": ("prédigérer",),
    "prédigérasses": ("prédigérer",),
    "prédigérasse": ("prédigérer",),
    "prédigérassiez": ("prédigérer",),
    "prédigérassions": ("prédigérer",),
    "prédigérâtes": ("prédigérer",),
    "prédigérât": ("prédigérer",),
    "prédigérée": ("prédigérer",),
    "prédigérées": ("prédigérer",),
    "prédigéré": ("prédigérer",),
    "prédigèrent": ("prédigérer",),
    "prédigère": ("prédigérer",),
    "prédigérera": ("prédigérer",),
    "prédigéreraient": ("prédigérer",),
    "prédigérerai": ("prédigérer",),
    "prédigérerais": ("prédigérer",),
    "prédigérerait": ("prédigérer",),
    "prédigéreras": ("prédigérer",),
    "prédigérèrent": ("prédigérer",),
    "prédigérerez": ("prédigérer",),
    "prédigéreriez": ("prédigérer",),
    "prédigérerions": ("prédigérer",),
    "prédigérerons": ("prédigérer",),
    "prédigéreront": ("prédigérer",),
    "prédigérés": ("prédigérer",),
    "prédigères": ("prédigérer",),
    "prédigérez": ("prédigérer",),
    "prédigériez": ("prédigérer",),
    "prédigérions": ("prédigérer",),
    "prédigérons": ("prédigérer",),
    "prédîmes": ("prédire",),
    "prédira": ("prédire",),
    "prédiraient": ("prédire",),
    "prédirai": ("prédire",),
    "prédirais": ("prédire",),
    "prédirait": ("prédire",),
    "prédiras": ("prédire",),
    "prédirent": ("prédire",),
    "prédirez": ("prédire",),
    "prédiriez": ("prédire",),
    "prédirions": ("prédire",),
    "prédirons": ("prédire",),
    "prédiront": ("prédire",),
    "prédisaient": ("prédire",),
    "prédisais": ("prédire",),
    "prédisait": ("prédire",),
    "prédisant": ("prédire",),
    "prédisent": ("prédire",),
    "prédise": ("prédire",),
    "prédises": ("prédire",),
    "prédisez": ("prédire",),
    "prédisiez": ("prédire",),
    "prédisions": ("prédire",),
    "prédisons": ("prédire",),
    "prédis": ("prédire",),
    "prédissent": ("prédire",),
    "prédisses": ("prédire",),
    "prédisse": ("prédire",),
    "prédissiez": ("prédire",),
    "prédissions": ("prédire",),
    "prédite": ("prédire",),
    "prédîtes": ("prédire",),
    "prédites": ("prédire",),
    "prédit": ("prédire",),
    "prédits": ("prédire",),
    "prédît": ("prédire",),
    "préétablie": ("préétablir",),
    "préétablies": ("préétablir",),
    "préétabli": ("préétablir",),
    "préétablîmes": ("préétablir",),
    "préétablira": ("préétablir",),
    "préétabliraient": ("préétablir",),
    "préétablirai": ("préétablir",),
    "préétablirais": ("préétablir",),
    "préétablirait": ("préétablir",),
    "préétabliras": ("préétablir",),
    "préétablirent": ("préétablir",),
    "préétablirez": ("préétablir",),
    "préétabliriez": ("préétablir",),
    "préétablirions": ("préétablir",),
    "préétablirons": ("préétablir",),
    "préétabliront": ("préétablir",),
    "préétablis": ("préétablir",),
    "préétablissaient": ("préétablir",),
    "préétablissais": ("préétablir",),
    "préétablissait": ("préétablir",),
    "préétablissant": ("préétablir",),
    "préétablissent": ("préétablir",),
    "préétablisse": ("préétablir",),
    "préétablisses": ("préétablir",),
    "préétablissez": ("préétablir",),
    "préétablissiez": ("préétablir",),
    "préétablissions": ("préétablir",),
    "préétablissons": ("préétablir",),
    "préétablîtes": ("préétablir",),
    "préétablit": ("préétablir",),
    "préétablît": ("préétablir",),
    "préétudiaient": ("préétudier",),
    "préétudiai": ("préétudier",),
    "préétudiais": ("préétudier",),
    "préétudiait": ("préétudier",),
    "préétudia": ("préétudier",),
    "préétudiâmes": ("préétudier",),
    "préétudiant": ("préétudier",),
    "préétudias": ("préétudier",),
    "préétudiassent": ("préétudier",),
    "préétudiasses": ("préétudier",),
    "préétudiasse": ("préétudier",),
    "préétudiassiez": ("préétudier",),
    "préétudiassions": ("préétudier",),
    "préétudiâtes": ("préétudier",),
    "préétudiât": ("préétudier",),
    "préétudiée": ("préétudier",),
    "préétudiées": ("préétudier",),
    "préétudié": ("préétudier",),
    "préétudient": ("préétudier",),
    "préétudie": ("préétudier",),
    "préétudiera": ("préétudier",),
    "préétudieraient": ("préétudier",),
    "préétudierai": ("préétudier",),
    "préétudierais": ("préétudier",),
    "préétudierait": ("préétudier",),
    "préétudieras": ("préétudier",),
    "préétudièrent": ("préétudier",),
    "préétudierez": ("préétudier",),
    "préétudieriez": ("préétudier",),
    "préétudierions": ("préétudier",),
    "préétudierons": ("préétudier",),
    "préétudieront": ("préétudier",),
    "préétudiés": ("préétudier",),
    "préétudies": ("préétudier",),
    "préétudiez": ("préétudier",),
    "préétudiiez": ("préétudier",),
    "préétudiions": ("préétudier",),
    "préétudions": ("préétudier",),
    "préfaçaient": ("préfacer",),
    "préfaçai": ("préfacer",),
    "préfaçais": ("préfacer",),
    "préfaçait": ("préfacer",),
    "préfaça": ("préfacer",),
    "préfaçâmes": ("préfacer",),
    "préfaçant": ("préfacer",),
    "préfaças": ("préfacer",),
    "préfaçassent": ("préfacer",),
    "préfaçasses": ("préfacer",),
    "préfaçasse": ("préfacer",),
    "préfaçassiez": ("préfacer",),
    "préfaçassions": ("préfacer",),
    "préfaçâtes": ("préfacer",),
    "préfaçât": ("préfacer",),
    "préfacée": ("préfacer",),
    "préfacées": ("préfacer",),
    "préfacé": ("préfacer",),
    "préfacent": ("préfacer",),
    "préface": ("préfacer",),
    "préfacera": ("préfacer",),
    "préfaceraient": ("préfacer",),
    "préfacerai": ("préfacer",),
    "préfacerais": ("préfacer",),
    "préfacerait": ("préfacer",),
    "préfaceras": ("préfacer",),
    "préfacèrent": ("préfacer",),
    "préfacerez": ("préfacer",),
    "préfaceriez": ("préfacer",),
    "préfacerions": ("préfacer",),
    "préfacerons": ("préfacer",),
    "préfaceront": ("préfacer",),
    "préfacés": ("préfacer",),
    "préfaces": ("préfacer",),
    "préfacez": ("préfacer",),
    "préfaciez": ("préfacer",),
    "préfacions": ("préfacer",),
    "préfaçons": ("préfacer",),
    "préféraient": ("préférer",),
    "préférai": ("préférer",),
    "préférais": ("préférer",),
    "préférait": ("préférer",),
    "préféra": ("préférer",),
    "préférâmes": ("préférer",),
    "préférant": ("préférer",),
    "préféras": ("préférer",),
    "préférassent": ("préférer",),
    "préférasses": ("préférer",),
    "préférasse": ("préférer",),
    "préférassiez": ("préférer",),
    "préférassions": ("préférer",),
    "préférâtes": ("préférer",),
    "préférât": ("préférer",),
    "préférée": ("préférer",),
    "préférées": ("préférer",),
    "préféré": ("préférer",),
    "préfèrent": ("préférer",),
    "préfère": ("préférer",),
    "préférera": ("préférer",),
    "préféreraient": ("préférer",),
    "préférerai": ("préférer",),
    "préférerais": ("préférer",),
    "préférerait": ("préférer",),
    "préféreras": ("préférer",),
    "préférèrent": ("préférer",),
    "préférerez": ("préférer",),
    "préféreriez": ("préférer",),
    "préférerions": ("préférer",),
    "préférerons": ("préférer",),
    "préféreront": ("préférer",),
    "préférés": ("préférer",),
    "préfères": ("préférer",),
    "préférez": ("préférer",),
    "préfériez": ("préférer",),
    "préférions": ("préférer",),
    "préférons": ("préférer",),
    "préfinançaient": ("préfinancer",),
    "préfinançai": ("préfinancer",),
    "préfinançais": ("préfinancer",),
    "préfinançait": ("préfinancer",),
    "préfinança": ("préfinancer",),
    "préfinançâmes": ("préfinancer",),
    "préfinançant": ("préfinancer",),
    "préfinanças": ("préfinancer",),
    "préfinançassent": ("préfinancer",),
    "préfinançasses": ("préfinancer",),
    "préfinançasse": ("préfinancer",),
    "préfinançassiez": ("préfinancer",),
    "préfinançassions": ("préfinancer",),
    "préfinançâtes": ("préfinancer",),
    "préfinançât": ("préfinancer",),
    "préfinancée": ("préfinancer",),
    "préfinancées": ("préfinancer",),
    "préfinancé": ("préfinancer",),
    "préfinancent": ("préfinancer",),
    "préfinance": ("préfinancer",),
    "préfinancera": ("préfinancer",),
    "préfinanceraient": ("préfinancer",),
    "préfinancerai": ("préfinancer",),
    "préfinancerais": ("préfinancer",),
    "préfinancerait": ("préfinancer",),
    "préfinanceras": ("préfinancer",),
    "préfinancèrent": ("préfinancer",),
    "préfinancerez": ("préfinancer",),
    "préfinanceriez": ("préfinancer",),
    "préfinancerions": ("préfinancer",),
    "préfinancerons": ("préfinancer",),
    "préfinanceront": ("préfinancer",),
    "préfinancés": ("préfinancer",),
    "préfinances": ("préfinancer",),
    "préfinancez": ("préfinancer",),
    "préfinanciez": ("préfinancer",),
    "préfinancions": ("préfinancer",),
    "préfinançons": ("préfinancer",),
    "préinscrira": ("préinscrire",),
    "préinscriraient": ("préinscrire",),
    "préinscrirai": ("préinscrire",),
    "préinscrirais": ("préinscrire",),
    "préinscrirait": ("préinscrire",),
    "préinscriras": ("préinscrire",),
    "préinscrirez": ("préinscrire",),
    "préinscririez": ("préinscrire",),
    "préinscririons": ("préinscrire",),
    "préinscrirons": ("préinscrire",),
    "préinscriront": ("préinscrire",),
    "préinscris": ("préinscrire",),
    "préinscrite": ("préinscrire",),
    "préinscrites": ("préinscrire",),
    "préinscrit": ("préinscrire",),
    "préinscrits": ("préinscrire",),
    "préinscrivaient": ("préinscrire",),
    "préinscrivais": ("préinscrire",),
    "préinscrivait": ("préinscrire",),
    "préinscrivant": ("préinscrire",),
    "préinscrivent": ("préinscrire",),
    "préinscrive": ("préinscrire",),
    "préinscrives": ("préinscrire",),
    "préinscrivez": ("préinscrire",),
    "préinscriviez": ("préinscrire",),
    "préinscrivîmes": ("préinscrire",),
    "préinscrivions": ("préinscrire",),
    "préinscrivirent": ("préinscrire",),
    "préinscrivis": ("préinscrire",),
    "préinscrivissent": ("préinscrire",),
    "préinscrivisses": ("préinscrire",),
    "préinscrivisse": ("préinscrire",),
    "préinscrivissiez": ("préinscrire",),
    "préinscrivissions": ("préinscrire",),
    "préinscrivîtes": ("préinscrire",),
    "préinscrivit": ("préinscrire",),
    "préinscrivît": ("préinscrire",),
    "préinscrivons": ("préinscrire",),
    "préjudiciaient": ("préjudicier",),
    "préjudiciai": ("préjudicier",),
    "préjudiciais": ("préjudicier",),
    "préjudiciait": ("préjudicier",),
    "préjudicia": ("préjudicier",),
    "préjudiciâmes": ("préjudicier",),
    "préjudiciant": ("préjudicier",),
    "préjudicias": ("préjudicier",),
    "préjudiciassent": ("préjudicier",),
    "préjudiciasses": ("préjudicier",),
    "préjudiciasse": ("préjudicier",),
    "préjudiciassiez": ("préjudicier",),
    "préjudiciassions": ("préjudicier",),
    "préjudiciâtes": ("préjudicier",),
    "préjudiciât": ("préjudicier",),
    "préjudicié": ("préjudicier",),
    "préjudicient": ("préjudicier",),
    "préjudicie": ("préjudicier",),
    "préjudiciera": ("préjudicier",),
    "préjudicieraient": ("préjudicier",),
    "préjudicierai": ("préjudicier",),
    "préjudicierais": ("préjudicier",),
    "préjudicierait": ("préjudicier",),
    "préjudicieras": ("préjudicier",),
    "préjudicièrent": ("préjudicier",),
    "préjudicierez": ("préjudicier",),
    "préjudicieriez": ("préjudicier",),
    "préjudicierions": ("préjudicier",),
    "préjudicierons": ("préjudicier",),
    "préjudicieront": ("préjudicier",),
    "préjudicies": ("préjudicier",),
    "préjudiciez": ("préjudicier",),
    "préjudiciiez": ("préjudicier",),
    "préjudiciions": ("préjudicier",),
    "préjudicions": ("préjudicier",),
    "préjugeaient": ("préjuger",),
    "préjugeai": ("préjuger",),
    "préjugeais": ("préjuger",),
    "préjugeait": ("préjuger",),
    "préjugea": ("préjuger",),
    "préjugeâmes": ("préjuger",),
    "préjugeant": ("préjuger",),
    "préjugeas": ("préjuger",),
    "préjugeassent": ("préjuger",),
    "préjugeasses": ("préjuger",),
    "préjugeasse": ("préjuger",),
    "préjugeassiez": ("préjuger",),
    "préjugeassions": ("préjuger",),
    "préjugeâtes": ("préjuger",),
    "préjugeât": ("préjuger",),
    "préjugée": ("préjuger",),
    "préjugées": ("préjuger",),
    "préjugé": ("préjuger",),
    "préjugent": ("préjuger",),
    "préjugeons": ("préjuger",),
    "préjuge": ("préjuger",),
    "préjugera": ("préjuger",),
    "préjugeraient": ("préjuger",),
    "préjugerai": ("préjuger",),
    "préjugerais": ("préjuger",),
    "préjugerait": ("préjuger",),
    "préjugeras": ("préjuger",),
    "préjugèrent": ("préjuger",),
    "préjugerez": ("préjuger",),
    "préjugeriez": ("préjuger",),
    "préjugerions": ("préjuger",),
    "préjugerons": ("préjuger",),
    "préjugeront": ("préjuger",),
    "préjugés": ("préjuger",),
    "préjuges": ("préjuger",),
    "préjugez": ("préjuger",),
    "préjugiez": ("préjuger",),
    "préjugions": ("préjuger",),
    "prélassaient": ("prélasser",),
    "prélassai": ("prélasser",),
    "prélassais": ("prélasser",),
    "prélassait": ("prélasser",),
    "prélassa": ("prélasser",),
    "prélassâmes": ("prélasser",),
    "prélassant": ("prélasser",),
    "prélassas": ("prélasser",),
    "prélassassent": ("prélasser",),
    "prélassasses": ("prélasser",),
    "prélassasse": ("prélasser",),
    "prélassassiez": ("prélasser",),
    "prélassassions": ("prélasser",),
    "prélassâtes": ("prélasser",),
    "prélassât": ("prélasser",),
    "prélassée": ("prélasser",),
    "prélassées": ("prélasser",),
    "prélassé": ("prélasser",),
    "prélassent": ("prélasser",),
    "prélasse": ("prélasser",),
    "prélassera": ("prélasser",),
    "prélasseraient": ("prélasser",),
    "prélasserai": ("prélasser",),
    "prélasserais": ("prélasser",),
    "prélasserait": ("prélasser",),
    "prélasseras": ("prélasser",),
    "prélassèrent": ("prélasser",),
    "prélasserez": ("prélasser",),
    "prélasseriez": ("prélasser",),
    "prélasserions": ("prélasser",),
    "prélasserons": ("prélasser",),
    "prélasseront": ("prélasser",),
    "prélassés": ("prélasser",),
    "prélasses": ("prélasser",),
    "prélassez": ("prélasser",),
    "prélassiez": ("prélasser",),
    "prélassions": ("prélasser",),
    "prélassons": ("prélasser",),
    "préléguaient": ("préléguer",),
    "préléguai": ("préléguer",),
    "préléguais": ("préléguer",),
    "préléguait": ("préléguer",),
    "prélégua": ("préléguer",),
    "préléguâmes": ("préléguer",),
    "préléguant": ("préléguer",),
    "préléguas": ("préléguer",),
    "préléguassent": ("préléguer",),
    "préléguasses": ("préléguer",),
    "préléguasse": ("préléguer",),
    "préléguassiez": ("préléguer",),
    "préléguassions": ("préléguer",),
    "préléguâtes": ("préléguer",),
    "préléguât": ("préléguer",),
    "préléguée": ("préléguer",),
    "préléguées": ("préléguer",),
    "prélégué": ("préléguer",),
    "prélèguent": ("préléguer",),
    "prélègue": ("préléguer",),
    "préléguera": ("préléguer",),
    "prélégueraient": ("préléguer",),
    "préléguerai": ("préléguer",),
    "préléguerais": ("préléguer",),
    "préléguerait": ("préléguer",),
    "prélégueras": ("préléguer",),
    "préléguèrent": ("préléguer",),
    "préléguerez": ("préléguer",),
    "prélégueriez": ("préléguer",),
    "préléguerions": ("préléguer",),
    "préléguerons": ("préléguer",),
    "prélégueront": ("préléguer",),
    "prélégués": ("préléguer",),
    "prélègues": ("préléguer",),
    "préléguez": ("préléguer",),
    "préléguiez": ("préléguer",),
    "préléguions": ("préléguer",),
    "préléguons": ("préléguer",),
    "prélevaient": ("prélever",),
    "prélevai": ("prélever",),
    "prélevais": ("prélever",),
    "prélevait": ("prélever",),
    "préleva": ("prélever",),
    "prélevâmes": ("prélever",),
    "prélevant": ("prélever",),
    "prélevas": ("prélever",),
    "prélevassent": ("prélever",),
    "prélevasses": ("prélever",),
    "prélevasse": ("prélever",),
    "prélevassiez": ("prélever",),
    "prélevassions": ("prélever",),
    "prélevâtes": ("prélever",),
    "prélevât": ("prélever",),
    "prélevée": ("prélever",),
    "prélevées": ("prélever",),
    "prélevé": ("prélever",),
    "prélèvent": ("prélever",),
    "prélève": ("prélever",),
    "prélèvera": ("prélever",),
    "prélèveraient": ("prélever",),
    "prélèverai": ("prélever",),
    "prélèverais": ("prélever",),
    "prélèverait": ("prélever",),
    "prélèveras": ("prélever",),
    "prélevèrent": ("prélever",),
    "prélèverez": ("prélever",),
    "prélèveriez": ("prélever",),
    "prélèverions": ("prélever",),
    "prélèverons": ("prélever",),
    "prélèveront": ("prélever",),
    "prélevés": ("prélever",),
    "prélèves": ("prélever",),
    "prélevez": ("prélever",),
    "préleviez": ("prélever",),
    "prélevions": ("prélever",),
    "prélevons": ("prélever",),
    "prélira": ("prélire",),
    "préliraient": ("prélire",),
    "prélirai": ("prélire",),
    "prélirais": ("prélire",),
    "prélirait": ("prélire",),
    "préliras": ("prélire",),
    "prélirez": ("prélire",),
    "préliriez": ("prélire",),
    "prélirions": ("prélire",),
    "prélirons": ("prélire",),
    "préliront": ("prélire",),
    "prélisaient": ("prélire",),
    "prélisais": ("prélire",),
    "prélisait": ("prélire",),
    "prélisant": ("prélire",),
    "prélisent": ("prélire",),
    "prélise": ("prélire",),
    "prélises": ("prélire",),
    "prélisez": ("prélire",),
    "prélisiez": ("prélire",),
    "prélisions": ("prélire",),
    "prélisons": ("prélire",),
    "prélis": ("prélire",),
    "prélit": ("prélire",),
    "prélue": ("prélire",),
    "prélues": ("prélire",),
    "prélu": ("prélire",),
    "prélûmes": ("prélire",),
    "prélurent": ("prélire",),
    "prélus": ("prélire",),
    "prélussent": ("prélire",),
    "prélusses": ("prélire",),
    "prélusse": ("prélire",),
    "prélussiez": ("prélire",),
    "prélussions": ("prélire",),
    "prélûtes": ("prélire",),
    "prélut": ("prélire",),
    "prélût": ("prélire",),
    "prémunie": ("prémunir",),
    "prémunies": ("prémunir",),
    "prémuni": ("prémunir",),
    "prémunîmes": ("prémunir",),
    "prémunira": ("prémunir",),
    "prémuniraient": ("prémunir",),
    "prémunirai": ("prémunir",),
    "prémunirais": ("prémunir",),
    "prémunirait": ("prémunir",),
    "prémuniras": ("prémunir",),
    "prémunirent": ("prémunir",),
    "prémunirez": ("prémunir",),
    "prémuniriez": ("prémunir",),
    "prémunirions": ("prémunir",),
    "prémunirons": ("prémunir",),
    "prémuniront": ("prémunir",),
    "prémunis": ("prémunir",),
    "prémunissaient": ("prémunir",),
    "prémunissais": ("prémunir",),
    "prémunissait": ("prémunir",),
    "prémunissant": ("prémunir",),
    "prémunissent": ("prémunir",),
    "prémunisse": ("prémunir",),
    "prémunisses": ("prémunir",),
    "prémunissez": ("prémunir",),
    "prémunissiez": ("prémunir",),
    "prémunissions": ("prémunir",),
    "prémunissons": ("prémunir",),
    "prémunîtes": ("prémunir",),
    "prémunit": ("prémunir",),
    "prémunît": ("prémunir",),
    "prenaient": ("prendre",),
    "prenais": ("prendre",),
    "prenait": ("prendre",),
    "prenant": ("prendre",),
    "prend": ("prendre",),
    "prendra": ("prendre",),
    "prendraient": ("prendre",),
    "prendrai": ("prendre",),
    "prendrais": ("prendre",),
    "prendrait": ("prendre",),
    "prendras": ("prendre",),
    "prendrez": ("prendre",),
    "prendriez": ("prendre",),
    "prendrions": ("prendre",),
    "prendrons": ("prendre",),
    "prendront": ("prendre",),
    "prends": ("prendre",),
    "prenez": ("prendre",),
    "preniez": ("prendre",),
    "prenions": ("prendre",),
    "prennent": ("prendre",),
    "prenne": ("prendre",),
    "prennes": ("prendre",),
    "prenons": ("prendre",),
    "prîmes": ("prendre",),
    "prirent": ("prendre",),
    "prise": ("prendre",),
    "prises": ("prendre",),
    "pris": ("prendre",),
    "prissent": ("prendre",),
    "prisses": ("prendre",),
    "prisse": ("prendre",),
    "prissiez": ("prendre",),
    "prissions": ("prendre",),
    "prîtes": ("prendre",),
    "prit": ("prendre",),
    "prît": ("prendre",),
    "prépaient": ("prépayer",),
    "prépaie": ("prépayer",),
    "prépaiera": ("prépayer",),
    "prépaieraient": ("prépayer",),
    "prépaierai": ("prépayer",),
    "prépaierais": ("prépayer",),
    "prépaierait": ("prépayer",),
    "prépaieras": ("prépayer",),
    "prépaierez": ("prépayer",),
    "prépaieriez": ("prépayer",),
    "prépaierions": ("prépayer",),
    "prépaierons": ("prépayer",),
    "prépaieront": ("prépayer",),
    "prépaies": ("prépayer",),
    "prépayaient": ("prépayer",),
    "prépayai": ("prépayer",),
    "prépayais": ("prépayer",),
    "prépayait": ("prépayer",),
    "prépaya": ("prépayer",),
    "prépayâmes": ("prépayer",),
    "prépayant": ("prépayer",),
    "prépayas": ("prépayer",),
    "prépayassent": ("prépayer",),
    "prépayasses": ("prépayer",),
    "prépayasse": ("prépayer",),
    "prépayassiez": ("prépayer",),
    "prépayassions": ("prépayer",),
    "prépayâtes": ("prépayer",),
    "prépayât": ("prépayer",),
    "prépayée": ("prépayer",),
    "prépayées": ("prépayer",),
    "prépayé": ("prépayer",),
    "prépayent": ("prépayer",),
    "prépaye": ("prépayer",),
    "prépayera": ("prépayer",),
    "prépayeraient": ("prépayer",),
    "prépayerai": ("prépayer",),
    "prépayerais": ("prépayer",),
    "prépayerait": ("prépayer",),
    "prépayeras": ("prépayer",),
    "prépayèrent": ("prépayer",),
    "prépayerez": ("prépayer",),
    "prépayeriez": ("prépayer",),
    "prépayerions": ("prépayer",),
    "prépayerons": ("prépayer",),
    "prépayeront": ("prépayer",),
    "prépayés": ("prépayer",),
    "prépayes": ("prépayer",),
    "prépayez": ("prépayer",),
    "prépayiez": ("prépayer",),
    "prépayions": ("prépayer",),
    "prépayons": ("prépayer",),
    "préplastifiaient": ("préplastifier",),
    "préplastifiai": ("préplastifier",),
    "préplastifiais": ("préplastifier",),
    "préplastifiait": ("préplastifier",),
    "préplastifia": ("préplastifier",),
    "préplastifiâmes": ("préplastifier",),
    "préplastifiant": ("préplastifier",),
    "préplastifias": ("préplastifier",),
    "préplastifiassent": ("préplastifier",),
    "préplastifiasses": ("préplastifier",),
    "préplastifiasse": ("préplastifier",),
    "préplastifiassiez": ("préplastifier",),
    "préplastifiassions": ("préplastifier",),
    "préplastifiâtes": ("préplastifier",),
    "préplastifiât": ("préplastifier",),
    "préplastifiée": ("préplastifier",),
    "préplastifiées": ("préplastifier",),
    "préplastifié": ("préplastifier",),
    "préplastifient": ("préplastifier",),
    "préplastifie": ("préplastifier",),
    "préplastifiera": ("préplastifier",),
    "préplastifieraient": ("préplastifier",),
    "préplastifierai": ("préplastifier",),
    "préplastifierais": ("préplastifier",),
    "préplastifierait": ("préplastifier",),
    "préplastifieras": ("préplastifier",),
    "préplastifièrent": ("préplastifier",),
    "préplastifierez": ("préplastifier",),
    "préplastifieriez": ("préplastifier",),
    "préplastifierions": ("préplastifier",),
    "préplastifierons": ("préplastifier",),
    "préplastifieront": ("préplastifier",),
    "préplastifiés": ("préplastifier",),
    "préplastifies": ("préplastifier",),
    "préplastifiez": ("préplastifier",),
    "préplastifiiez": ("préplastifier",),
    "préplastifiions": ("préplastifier",),
    "préplastifions": ("préplastifier",),
    "prépondéraient": ("prépondérer",),
    "prépondérai": ("prépondérer",),
    "prépondérais": ("prépondérer",),
    "prépondérait": ("prépondérer",),
    "prépondéra": ("prépondérer",),
    "prépondérâmes": ("prépondérer",),
    "prépondérant": ("prépondérer",),
    "prépondéras": ("prépondérer",),
    "prépondérassent": ("prépondérer",),
    "prépondérasses": ("prépondérer",),
    "prépondérasse": ("prépondérer",),
    "prépondérassiez": ("prépondérer",),
    "prépondérassions": ("prépondérer",),
    "prépondérâtes": ("prépondérer",),
    "prépondérât": ("prépondérer",),
    "prépondéré": ("prépondérer",),
    "prépondèrent": ("prépondérer",),
    "prépondère": ("prépondérer",),
    "prépondérera": ("prépondérer",),
    "prépondéreraient": ("prépondérer",),
    "prépondérerai": ("prépondérer",),
    "prépondérerais": ("prépondérer",),
    "prépondérerait": ("prépondérer",),
    "prépondéreras": ("prépondérer",),
    "prépondérèrent": ("prépondérer",),
    "prépondérerez": ("prépondérer",),
    "prépondéreriez": ("prépondérer",),
    "prépondérerions": ("prépondérer",),
    "prépondérerons": ("prépondérer",),
    "prépondéreront": ("prépondérer",),
    "prépondères": ("prépondérer",),
    "prépondérez": ("prépondérer",),
    "prépondériez": ("prépondérer",),
    "prépondérions": ("prépondérer",),
    "prépondérons": ("prépondérer",),
    "prépubliaient": ("prépublier",),
    "prépubliai": ("prépublier",),
    "prépubliais": ("prépublier",),
    "prépubliait": ("prépublier",),
    "prépublia": ("prépublier",),
    "prépubliâmes": ("prépublier",),
    "prépubliant": ("prépublier",),
    "prépublias": ("prépublier",),
    "prépubliassent": ("prépublier",),
    "prépubliasses": ("prépublier",),
    "prépubliasse": ("prépublier",),
    "prépubliassiez": ("prépublier",),
    "prépubliassions": ("prépublier",),
    "prépubliâtes": ("prépublier",),
    "prépubliât": ("prépublier",),
    "prépubliée": ("prépublier",),
    "prépubliées": ("prépublier",),
    "prépublié": ("prépublier",),
    "prépublient": ("prépublier",),
    "prépublie": ("prépublier",),
    "prépubliera": ("prépublier",),
    "prépublieraient": ("prépublier",),
    "prépublierai": ("prépublier",),
    "prépublierais": ("prépublier",),
    "prépublierait": ("prépublier",),
    "prépublieras": ("prépublier",),
    "prépublièrent": ("prépublier",),
    "prépublierez": ("prépublier",),
    "prépublieriez": ("prépublier",),
    "prépublierions": ("prépublier",),
    "prépublierons": ("prépublier",),
    "prépublieront": ("prépublier",),
    "prépubliés": ("prépublier",),
    "prépublies": ("prépublier",),
    "prépubliez": ("prépublier",),
    "prépubliiez": ("prépublier",),
    "prépubliions": ("prépublier",),
    "prépublions": ("prépublier",),
    "prérédigeaient": ("prérédiger",),
    "prérédigeai": ("prérédiger",),
    "prérédigeais": ("prérédiger",),
    "prérédigeait": ("prérédiger",),
    "prérédigea": ("prérédiger",),
    "prérédigeâmes": ("prérédiger",),
    "prérédigeant": ("prérédiger",),
    "prérédigeas": ("prérédiger",),
    "prérédigeassent": ("prérédiger",),
    "prérédigeasses": ("prérédiger",),
    "prérédigeasse": ("prérédiger",),
    "prérédigeassiez": ("prérédiger",),
    "prérédigeassions": ("prérédiger",),
    "prérédigeâtes": ("prérédiger",),
    "prérédigeât": ("prérédiger",),
    "prérédigée": ("prérédiger",),
    "prérédigées": ("prérédiger",),
    "prérédigé": ("prérédiger",),
    "prérédigent": ("prérédiger",),
    "prérédigeons": ("prérédiger",),
    "prérédige": ("prérédiger",),
    "prérédigera": ("prérédiger",),
    "prérédigeraient": ("prérédiger",),
    "prérédigerai": ("prérédiger",),
    "prérédigerais": ("prérédiger",),
    "prérédigerait": ("prérédiger",),
    "prérédigeras": ("prérédiger",),
    "prérédigèrent": ("prérédiger",),
    "prérédigerez": ("prérédiger",),
    "prérédigeriez": ("prérédiger",),
    "prérédigerions": ("prérédiger",),
    "prérédigerons": ("prérédiger",),
    "prérédigeront": ("prérédiger",),
    "prérédigés": ("prérédiger",),
    "prérédiges": ("prérédiger",),
    "prérédigez": ("prérédiger",),
    "prérédigiez": ("prérédiger",),
    "prérédigions": ("prérédiger",),
    "préréduira": ("préréduire",),
    "préréduiraient": ("préréduire",),
    "préréduirai": ("préréduire",),
    "préréduirais": ("préréduire",),
    "préréduirait": ("préréduire",),
    "préréduiras": ("préréduire",),
    "préréduirez": ("préréduire",),
    "préréduiriez": ("préréduire",),
    "préréduirions": ("préréduire",),
    "préréduirons": ("préréduire",),
    "préréduiront": ("préréduire",),
    "préréduisaient": ("préréduire",),
    "préréduisais": ("préréduire",),
    "préréduisait": ("préréduire",),
    "préréduisant": ("préréduire",),
    "préréduisent": ("préréduire",),
    "préréduise": ("préréduire",),
    "préréduises": ("préréduire",),
    "préréduisez": ("préréduire",),
    "préréduisiez": ("préréduire",),
    "préréduisîmes": ("préréduire",),
    "préréduisions": ("préréduire",),
    "préréduisirent": ("préréduire",),
    "préréduisis": ("préréduire",),
    "préréduisissent": ("préréduire",),
    "préréduisisses": ("préréduire",),
    "préréduisisse": ("préréduire",),
    "préréduisissiez": ("préréduire",),
    "préréduisissions": ("préréduire",),
    "préréduisîtes": ("préréduire",),
    "préréduisit": ("préréduire",),
    "préréduisît": ("préréduire",),
    "préréduisons": ("préréduire",),
    "préréduis": ("préréduire",),
    "préréduite": ("préréduire",),
    "préréduites": ("préréduire",),
    "préréduit": ("préréduire",),
    "préréduits": ("préréduire",),
    "préréglaient": ("prérégler",),
    "préréglai": ("prérégler",),
    "préréglais": ("prérégler",),
    "préréglait": ("prérégler",),
    "prérégla": ("prérégler",),
    "préréglâmes": ("prérégler",),
    "préréglant": ("prérégler",),
    "préréglas": ("prérégler",),
    "préréglassent": ("prérégler",),
    "préréglasses": ("prérégler",),
    "préréglasse": ("prérégler",),
    "préréglassiez": ("prérégler",),
    "préréglassions": ("prérégler",),
    "préréglâtes": ("prérégler",),
    "préréglât": ("prérégler",),
    "préréglée": ("prérégler",),
    "préréglées": ("prérégler",),
    "préréglé": ("prérégler",),
    "prérèglent": ("prérégler",),
    "prérègle": ("prérégler",),
    "préréglera": ("prérégler",),
    "prérégleraient": ("prérégler",),
    "préréglerai": ("prérégler",),
    "préréglerais": ("prérégler",),
    "préréglerait": ("prérégler",),
    "prérégleras": ("prérégler",),
    "préréglèrent": ("prérégler",),
    "préréglerez": ("prérégler",),
    "prérégleriez": ("prérégler",),
    "préréglerions": ("prérégler",),
    "préréglerons": ("prérégler",),
    "prérégleront": ("prérégler",),
    "préréglés": ("prérégler",),
    "prérègles": ("prérégler",),
    "préréglez": ("prérégler",),
    "prérégliez": ("prérégler",),
    "préréglions": ("prérégler",),
    "préréglons": ("prérégler",),
    "prérequéraient": ("prérequérir",),
    "prérequérais": ("prérequérir",),
    "prérequérait": ("prérequérir",),
    "prérequérant": ("prérequérir",),
    "prérequérez": ("prérequérir",),
    "prérequériez": ("prérequérir",),
    "prérequérions": ("prérequérir",),
    "prérequérons": ("prérequérir",),
    "prérequerra": ("prérequérir",),
    "prérequerraient": ("prérequérir",),
    "prérequerrai": ("prérequérir",),
    "prérequerrais": ("prérequérir",),
    "prérequerrait": ("prérequérir",),
    "prérequerras": ("prérequérir",),
    "prérequerrez": ("prérequérir",),
    "prérequerriez": ("prérequérir",),
    "prérequerrions": ("prérequérir",),
    "prérequerrons": ("prérequérir",),
    "prérequerront": ("prérequérir",),
    "prérequièrent": ("prérequérir",),
    "prérequière": ("prérequérir",),
    "prérequières": ("prérequérir",),
    "prérequiers": ("prérequérir",),
    "prérequiert": ("prérequérir",),
    "prérequîmes": ("prérequérir",),
    "prérequirent": ("prérequérir",),
    "prérequise": ("prérequérir",),
    "prérequises": ("prérequérir",),
    "prérequis": ("prérequérir",),
    "prérequissent": ("prérequérir",),
    "prérequisses": ("prérequérir",),
    "prérequisse": ("prérequérir",),
    "prérequissiez": ("prérequérir",),
    "prérequissions": ("prérequérir",),
    "prérequîtes": ("prérequérir",),
    "prérequit": ("prérequérir",),
    "prérequît": ("prérequérir",),
    "présageaient": ("présager",),
    "présageai": ("présager",),
    "présageais": ("présager",),
    "présageait": ("présager",),
    "présagea": ("présager",),
    "présageâmes": ("présager",),
    "présageant": ("présager",),
    "présageas": ("présager",),
    "présageassent": ("présager",),
    "présageasses": ("présager",),
    "présageasse": ("présager",),
    "présageassiez": ("présager",),
    "présageassions": ("présager",),
    "présageâtes": ("présager",),
    "présageât": ("présager",),
    "présagée": ("présager",),
    "présagées": ("présager",),
    "présagé": ("présager",),
    "présagent": ("présager",),
    "présageons": ("présager",),
    "présage": ("présager",),
    "présagera": ("présager",),
    "présageraient": ("présager",),
    "présagerai": ("présager",),
    "présagerais": ("présager",),
    "présagerait": ("présager",),
    "présageras": ("présager",),
    "présagèrent": ("présager",),
    "présagerez": ("présager",),
    "présageriez": ("présager",),
    "présagerions": ("présager",),
    "présagerons": ("présager",),
    "présageront": ("présager",),
    "présagés": ("présager",),
    "présages": ("présager",),
    "présagez": ("présager",),
    "présagiez": ("présager",),
    "présagions": ("présager",),
    "présanctifiaient": ("présanctifier",),
    "présanctifiai": ("présanctifier",),
    "présanctifiais": ("présanctifier",),
    "présanctifiait": ("présanctifier",),
    "présanctifia": ("présanctifier",),
    "présanctifiâmes": ("présanctifier",),
    "présanctifiant": ("présanctifier",),
    "présanctifias": ("présanctifier",),
    "présanctifiassent": ("présanctifier",),
    "présanctifiasses": ("présanctifier",),
    "présanctifiasse": ("présanctifier",),
    "présanctifiassiez": ("présanctifier",),
    "présanctifiassions": ("présanctifier",),
    "présanctifiâtes": ("présanctifier",),
    "présanctifiât": ("présanctifier",),
    "présanctifiée": ("présanctifier",),
    "présanctifiées": ("présanctifier",),
    "présanctifié": ("présanctifier",),
    "présanctifient": ("présanctifier",),
    "présanctifie": ("présanctifier",),
    "présanctifiera": ("présanctifier",),
    "présanctifieraient": ("présanctifier",),
    "présanctifierai": ("présanctifier",),
    "présanctifierais": ("présanctifier",),
    "présanctifierait": ("présanctifier",),
    "présanctifieras": ("présanctifier",),
    "présanctifièrent": ("présanctifier",),
    "présanctifierez": ("présanctifier",),
    "présanctifieriez": ("présanctifier",),
    "présanctifierions": ("présanctifier",),
    "présanctifierons": ("présanctifier",),
    "présanctifieront": ("présanctifier",),
    "présanctifiés": ("présanctifier",),
    "présanctifies": ("présanctifier",),
    "présanctifiez": ("présanctifier",),
    "présanctifiiez": ("présanctifier",),
    "présanctifiions": ("présanctifier",),
    "présanctifions": ("présanctifier",),
    "prescrira": ("prescrire",),
    "prescriraient": ("prescrire",),
    "prescrirai": ("prescrire",),
    "prescrirais": ("prescrire",),
    "prescrirait": ("prescrire",),
    "prescriras": ("prescrire",),
    "prescrirez": ("prescrire",),
    "prescririez": ("prescrire",),
    "prescririons": ("prescrire",),
    "prescrirons": ("prescrire",),
    "prescriront": ("prescrire",),
    "prescris": ("prescrire",),
    "prescrite": ("prescrire",),
    "prescrites": ("prescrire",),
    "prescrit": ("prescrire",),
    "prescrits": ("prescrire",),
    "prescrivaient": ("prescrire",),
    "prescrivais": ("prescrire",),
    "prescrivait": ("prescrire",),
    "prescrivant": ("prescrire",),
    "prescrivent": ("prescrire",),
    "prescrive": ("prescrire",),
    "prescrives": ("prescrire",),
    "prescrivez": ("prescrire",),
    "prescriviez": ("prescrire",),
    "prescrivîmes": ("prescrire",),
    "prescrivions": ("prescrire",),
    "prescrivirent": ("prescrire",),
    "prescrivis": ("prescrire",),
    "prescrivissent": ("prescrire",),
    "prescrivisses": ("prescrire",),
    "prescrivisse": ("prescrire",),
    "prescrivissiez": ("prescrire",),
    "prescrivissions": ("prescrire",),
    "prescrivîtes": ("prescrire",),
    "prescrivit": ("prescrire",),
    "prescrivît": ("prescrire",),
    "prescrivons": ("prescrire",),
    "préséchaient": ("présécher",),
    "préséchai": ("présécher",),
    "préséchais": ("présécher",),
    "préséchait": ("présécher",),
    "présécha": ("présécher",),
    "préséchâmes": ("présécher",),
    "préséchant": ("présécher",),
    "préséchas": ("présécher",),
    "préséchassent": ("présécher",),
    "préséchasses": ("présécher",),
    "préséchasse": ("présécher",),
    "préséchassiez": ("présécher",),
    "préséchassions": ("présécher",),
    "préséchâtes": ("présécher",),
    "préséchât": ("présécher",),
    "préséchée": ("présécher",),
    "préséchées": ("présécher",),
    "préséché": ("présécher",),
    "présèchent": ("présécher",),
    "présèche": ("présécher",),
    "préséchera": ("présécher",),
    "présécheraient": ("présécher",),
    "présécherai": ("présécher",),
    "présécherais": ("présécher",),
    "présécherait": ("présécher",),
    "présécheras": ("présécher",),
    "préséchèrent": ("présécher",),
    "présécherez": ("présécher",),
    "présécheriez": ("présécher",),
    "présécherions": ("présécher",),
    "présécherons": ("présécher",),
    "présécheront": ("présécher",),
    "préséchés": ("présécher",),
    "présèches": ("présécher",),
    "préséchez": ("présécher",),
    "préséchiez": ("présécher",),
    "préséchions": ("présécher",),
    "préséchons": ("présécher",),
    "présentifiaient": ("présentifier",),
    "présentifiai": ("présentifier",),
    "présentifiais": ("présentifier",),
    "présentifiait": ("présentifier",),
    "présentifia": ("présentifier",),
    "présentifiâmes": ("présentifier",),
    "présentifiant": ("présentifier",),
    "présentifias": ("présentifier",),
    "présentifiassent": ("présentifier",),
    "présentifiasses": ("présentifier",),
    "présentifiasse": ("présentifier",),
    "présentifiassiez": ("présentifier",),
    "présentifiassions": ("présentifier",),
    "présentifiâtes": ("présentifier",),
    "présentifiât": ("présentifier",),
    "présentifiée": ("présentifier",),
    "présentifiées": ("présentifier",),
    "présentifié": ("présentifier",),
    "présentifient": ("présentifier",),
    "présentifie": ("présentifier",),
    "présentifiera": ("présentifier",),
    "présentifieraient": ("présentifier",),
    "présentifierai": ("présentifier",),
    "présentifierais": ("présentifier",),
    "présentifierait": ("présentifier",),
    "présentifieras": ("présentifier",),
    "présentifièrent": ("présentifier",),
    "présentifierez": ("présentifier",),
    "présentifieriez": ("présentifier",),
    "présentifierions": ("présentifier",),
    "présentifierons": ("présentifier",),
    "présentifieront": ("présentifier",),
    "présentifiés": ("présentifier",),
    "présentifies": ("présentifier",),
    "présentifiez": ("présentifier",),
    "présentifiiez": ("présentifier",),
    "présentifiions": ("présentifier",),
    "présentifions": ("présentifier",),
    "pressens": ("pressentir",),
    "pressentaient": ("pressentir",),
    "pressentais": ("pressentir",),
    "pressentait": ("pressentir",),
    "pressentant": ("pressentir",),
    "pressentent": ("pressentir",),
    "pressente": ("pressentir",),
    "pressentes": ("pressentir",),
    "pressentez": ("pressentir",),
    "pressentie": ("pressentir",),
    "pressenties": ("pressentir",),
    "pressentiez": ("pressentir",),
    "pressenti": ("pressentir",),
    "pressentîmes": ("pressentir",),
    "pressentions": ("pressentir",),
    "pressentira": ("pressentir",),
    "pressentiraient": ("pressentir",),
    "pressentirai": ("pressentir",),
    "pressentirais": ("pressentir",),
    "pressentirait": ("pressentir",),
    "pressentiras": ("pressentir",),
    "pressentirent": ("pressentir",),
    "pressentirez": ("pressentir",),
    "pressentiriez": ("pressentir",),
    "pressentirions": ("pressentir",),
    "pressentirons": ("pressentir",),
    "pressentiront": ("pressentir",),
    "pressentis": ("pressentir",),
    "pressentissent": ("pressentir",),
    "pressentisses": ("pressentir",),
    "pressentisse": ("pressentir",),
    "pressentissiez": ("pressentir",),
    "pressentissions": ("pressentir",),
    "pressentîtes": ("pressentir",),
    "pressentit": ("pressentir",),
    "pressentît": ("pressentir",),
    "pressentons": ("pressentir",),
    "pressent": ("pressentir",),
    "prétendaient": ("prétendre",),
    "prétendais": ("prétendre",),
    "prétendait": ("prétendre",),
    "prétendant": ("prétendre",),
    "prétendent": ("prétendre",),
    "prétende": ("prétendre",),
    "prétendes": ("prétendre",),
    "prétendez": ("prétendre",),
    "prétendiez": ("prétendre",),
    "prétendîmes": ("prétendre",),
    "prétendions": ("prétendre",),
    "prétendirent": ("prétendre",),
    "prétendis": ("prétendre",),
    "prétendissent": ("prétendre",),
    "prétendisses": ("prétendre",),
    "prétendisse": ("prétendre",),
    "prétendissiez": ("prétendre",),
    "prétendissions": ("prétendre",),
    "prétendîtes": ("prétendre",),
    "prétendit": ("prétendre",),
    "prétendît": ("prétendre",),
    "prétendons": ("prétendre",),
    "prétend": ("prétendre",),
    "prétendra": ("prétendre",),
    "prétendraient": ("prétendre",),
    "prétendrai": ("prétendre",),
    "prétendrais": ("prétendre",),
    "prétendrait": ("prétendre",),
    "prétendras": ("prétendre",),
    "prétendrez": ("prétendre",),
    "prétendriez": ("prétendre",),
    "prétendrions": ("prétendre",),
    "prétendrons": ("prétendre",),
    "prétendront": ("prétendre",),
    "prétends": ("prétendre",),
    "prétendue": ("prétendre",),
    "prétendues": ("prétendre",),
    "prétendu": ("prétendre",),
    "prétendus": ("prétendre",),
    "prévalaient": ("prévaloir",),
    "prévalais": ("prévaloir",),
    "prévalait": ("prévaloir",),
    "prévalant": ("prévaloir",),
    "prévalent": ("prévaloir",),
    "prévale": ("prévaloir",),
    "prévales": ("prévaloir",),
    "prévalez": ("prévaloir",),
    "prévaliez": ("prévaloir",),
    "prévalions": ("prévaloir",),
    "prévalons": ("prévaloir",),
    "prévalue": ("prévaloir",),
    "prévalues": ("prévaloir",),
    "prévalu": ("prévaloir",),
    "prévalûmes": ("prévaloir",),
    "prévalurent": ("prévaloir",),
    "prévalus": ("prévaloir",),
    "prévalussent": ("prévaloir",),
    "prévalusses": ("prévaloir",),
    "prévalusse": ("prévaloir",),
    "prévalussiez": ("prévaloir",),
    "prévalussions": ("prévaloir",),
    "prévalûtes": ("prévaloir",),
    "prévalut": ("prévaloir",),
    "prévalût": ("prévaloir",),
    "prévaudra": ("prévaloir",),
    "prévaudraient": ("prévaloir",),
    "prévaudrai": ("prévaloir",),
    "prévaudrais": ("prévaloir",),
    "prévaudrait": ("prévaloir",),
    "prévaudras": ("prévaloir",),
    "prévaudrez": ("prévaloir",),
    "prévaudriez": ("prévaloir",),
    "prévaudrions": ("prévaloir",),
    "prévaudrons": ("prévaloir",),
    "prévaudront": ("prévaloir",),
    "prévaut": ("prévaloir",),
    "prévaux": ("prévaloir",),
    "prévendaient": ("prévendre",),
    "prévendais": ("prévendre",),
    "prévendait": ("prévendre",),
    "prévendant": ("prévendre",),
    "prévendent": ("prévendre",),
    "prévende": ("prévendre",),
    "prévendes": ("prévendre",),
    "prévendez": ("prévendre",),
    "prévendiez": ("prévendre",),
    "prévendîmes": ("prévendre",),
    "prévendions": ("prévendre",),
    "prévendirent": ("prévendre",),
    "prévendis": ("prévendre",),
    "prévendissent": ("prévendre",),
    "prévendisses": ("prévendre",),
    "prévendisse": ("prévendre",),
    "prévendissiez": ("prévendre",),
    "prévendissions": ("prévendre",),
    "prévendîtes": ("prévendre",),
    "prévendit": ("prévendre",),
    "prévendît": ("prévendre",),
    "prévendons": ("prévendre",),
    "prévend": ("prévendre",),
    "prévendra": ("prévendre",),
    "prévendraient": ("prévendre",),
    "prévendrai": ("prévendre",),
    "prévendrais": ("prévendre",),
    "prévendrait": ("prévendre",),
    "prévendras": ("prévendre",),
    "prévendrez": ("prévendre",),
    "prévendriez": ("prévendre",),
    "prévendrions": ("prévendre",),
    "prévendrons": ("prévendre",),
    "prévendront": ("prévendre",),
    "prévends": ("prévendre",),
    "prévendue": ("prévendre",),
    "prévendues": ("prévendre",),
    "prévendu": ("prévendre",),
    "prévendus": ("prévendre",),
    "prévenaient": ("prévenir",),
    "prévenais": ("prévenir",),
    "prévenait": ("prévenir",),
    "prévenant": ("prévenir",),
    "prévenez": ("prévenir",),
    "préveniez": ("prévenir",),
    "prévenions": ("prévenir",),
    "prévenons": ("prévenir",),
    "prévenue": ("prévenir",),
    "prévenues": ("prévenir",),
    "prévenu": ("prévenir",),
    "prévenus": ("prévenir",),
    "préviendra": ("prévenir",),
    "préviendraient": ("prévenir",),
    "préviendrai": ("prévenir",),
    "préviendrais": ("prévenir",),
    "préviendrait": ("prévenir",),
    "préviendras": ("prévenir",),
    "préviendrez": ("prévenir",),
    "préviendriez": ("prévenir",),
    "préviendrions": ("prévenir",),
    "préviendrons": ("prévenir",),
    "préviendront": ("prévenir",),
    "préviennent": ("prévenir",),
    "prévienne": ("prévenir",),
    "préviennes": ("prévenir",),
    "préviens": ("prévenir",),
    "prévient": ("prévenir",),
    "prévînmes": ("prévenir",),
    "prévinrent": ("prévenir",),
    "prévins": ("prévenir",),
    "prévinssent": ("prévenir",),
    "prévinsses": ("prévenir",),
    "prévinsse": ("prévenir",),
    "prévinssiez": ("prévenir",),
    "prévinssions": ("prévenir",),
    "prévîntes": ("prévenir",),
    "prévint": ("prévenir",),
    "prévînt": ("prévenir",),
    "prévîmes": ("prévoir",),
    "prévirent": ("prévoir",),
    "prévis": ("prévoir",),
    "prévissent": ("prévoir",),
    "prévisses": ("prévoir",),
    "prévisse": ("prévoir",),
    "prévissiez": ("prévoir",),
    "prévissions": ("prévoir",),
    "prévîtes": ("prévoir",),
    "prévit": ("prévoir",),
    "prévît": ("prévoir",),
    "prévoient": ("prévoir",),
    "prévoie": ("prévoir",),
    "prévoies": ("prévoir",),
    "prévoira": ("prévoir",),
    "prévoiraient": ("prévoir",),
    "prévoirai": ("prévoir",),
    "prévoirais": ("prévoir",),
    "prévoirait": ("prévoir",),
    "prévoiras": ("prévoir",),
    "prévoirez": ("prévoir",),
    "prévoiriez": ("prévoir",),
    "prévoirions": ("prévoir",),
    "prévoirons": ("prévoir",),
    "prévoiront": ("prévoir",),
    "prévois": ("prévoir",),
    "prévoit": ("prévoir",),
    "prévoyaient": ("prévoir",),
    "prévoyais": ("prévoir",),
    "prévoyait": ("prévoir",),
    "prévoyant": ("prévoir",),
    "prévoyez": ("prévoir",),
    "prévoyiez": ("prévoir",),
    "prévoyions": ("prévoir",),
    "prévoyons": ("prévoir",),
    "prévue": ("prévoir",),
    "prévues": ("prévoir",),
    "prévu": ("prévoir",),
    "prévus": ("prévoir",),
    "priaient": ("prier",),
    "priai": ("prier",),
    "priais": ("prier",),
    "priait": ("prier",),
    "pria": ("prier",),
    "priâmes": ("prier",),
    "priant": ("prier",),
    "prias": ("prier",),
    "priassent": ("prier",),
    "priasses": ("prier",),
    "priasse": ("prier",),
    "priassiez": ("prier",),
    "priassions": ("prier",),
    "priâtes": ("prier",),
    "priât": ("prier",),
    "priée": ("prier",),
    "priées": ("prier",),
    "prié": ("prier",),
    "prient": ("prier",),
    "prie": ("prier",),
    "priera": ("prier",),
    "prieraient": ("prier",),
    "prierai": ("prier",),
    "prierais": ("prier",),
    "prierait": ("prier",),
    "prieras": ("prier",),
    "prièrent": ("prier",),
    "prierez": ("prier",),
    "prieriez": ("prier",),
    "prierions": ("prier",),
    "prierons": ("prier",),
    "prieront": ("prier",),
    "priés": ("prier",),
    "pries": ("prier",),
    "priez": ("prier",),
    "priiez": ("prier",),
    "priions": ("prier",),
    "prions": ("prier",),
    "privilégiaient": ("privilégier",),
    "privilégiai": ("privilégier",),
    "privilégiais": ("privilégier",),
    "privilégiait": ("privilégier",),
    "privilégia": ("privilégier",),
    "privilégiâmes": ("privilégier",),
    "privilégiant": ("privilégier",),
    "privilégias": ("privilégier",),
    "privilégiassent": ("privilégier",),
    "privilégiasses": ("privilégier",),
    "privilégiasse": ("privilégier",),
    "privilégiassiez": ("privilégier",),
    "privilégiassions": ("privilégier",),
    "privilégiâtes": ("privilégier",),
    "privilégiât": ("privilégier",),
    "privilégiée": ("privilégier",),
    "privilégiées": ("privilégier",),
    "privilégié": ("privilégier",),
    "privilégient": ("privilégier",),
    "privilégie": ("privilégier",),
    "privilégiera": ("privilégier",),
    "privilégieraient": ("privilégier",),
    "privilégierai": ("privilégier",),
    "privilégierais": ("privilégier",),
    "privilégierait": ("privilégier",),
    "privilégieras": ("privilégier",),
    "privilégièrent": ("privilégier",),
    "privilégierez": ("privilégier",),
    "privilégieriez": ("privilégier",),
    "privilégierions": ("privilégier",),
    "privilégierons": ("privilégier",),
    "privilégieront": ("privilégier",),
    "privilégiés": ("privilégier",),
    "privilégies": ("privilégier",),
    "privilégiez": ("privilégier",),
    "privilégiiez": ("privilégier",),
    "privilégiions": ("privilégier",),
    "privilégions": ("privilégier",),
    "procédaient": ("procéder",),
    "procédai": ("procéder",),
    "procédais": ("procéder",),
    "procédait": ("procéder",),
    "procéda": ("procéder",),
    "procédâmes": ("procéder",),
    "procédant": ("procéder",),
    "procédas": ("procéder",),
    "procédassent": ("procéder",),
    "procédasses": ("procéder",),
    "procédasse": ("procéder",),
    "procédassiez": ("procéder",),
    "procédassions": ("procéder",),
    "procédâtes": ("procéder",),
    "procédât": ("procéder",),
    "procédé": ("procéder",),
    "procèdent": ("procéder",),
    "procède": ("procéder",),
    "procédera": ("procéder",),
    "procéderaient": ("procéder",),
    "procéderai": ("procéder",),
    "procéderais": ("procéder",),
    "procéderait": ("procéder",),
    "procéderas": ("procéder",),
    "procédèrent": ("procéder",),
    "procéderez": ("procéder",),
    "procéderiez": ("procéder",),
    "procéderions": ("procéder",),
    "procéderons": ("procéder",),
    "procéderont": ("procéder",),
    "procèdes": ("procéder",),
    "procédez": ("procéder",),
    "procédiez": ("procéder",),
    "procédions": ("procéder",),
    "procédons": ("procéder",),
    "procréaient": ("procréer",),
    "procréai": ("procréer",),
    "procréais": ("procréer",),
    "procréait": ("procréer",),
    "procréa": ("procréer",),
    "procréâmes": ("procréer",),
    "procréant": ("procréer",),
    "procréas": ("procréer",),
    "procréassent": ("procréer",),
    "procréasses": ("procréer",),
    "procréasse": ("procréer",),
    "procréassiez": ("procréer",),
    "procréassions": ("procréer",),
    "procréâtes": ("procréer",),
    "procréât": ("procréer",),
    "procréée": ("procréer",),
    "procréées": ("procréer",),
    "procréé": ("procréer",),
    "procréent": ("procréer",),
    "procrée": ("procréer",),
    "procréera": ("procréer",),
    "procréeraient": ("procréer",),
    "procréerai": ("procréer",),
    "procréerais": ("procréer",),
    "procréerait": ("procréer",),
    "procréeras": ("procréer",),
    "procréèrent": ("procréer",),
    "procréerez": ("procréer",),
    "procréeriez": ("procréer",),
    "procréerions": ("procréer",),
    "procréerons": ("procréer",),
    "procréeront": ("procréer",),
    "procréés": ("procréer",),
    "procrées": ("procréer",),
    "procréez": ("procréer",),
    "procréiez": ("procréer",),
    "procréions": ("procréer",),
    "procréons": ("procréer",),
    "produira": ("produire",),
    "produiraient": ("produire",),
    "produirai": ("produire",),
    "produirais": ("produire",),
    "produirait": ("produire",),
    "produiras": ("produire",),
    "produirez": ("produire",),
    "produiriez": ("produire",),
    "produirions": ("produire",),
    "produirons": ("produire",),
    "produiront": ("produire",),
    "produisaient": ("produire",),
    "produisais": ("produire",),
    "produisait": ("produire",),
    "produisant": ("produire",),
    "produisent": ("produire",),
    "produise": ("produire",),
    "produises": ("produire",),
    "produisez": ("produire",),
    "produisiez": ("produire",),
    "produisîmes": ("produire",),
    "produisions": ("produire",),
    "produisirent": ("produire",),
    "produisis": ("produire",),
    "produisissent": ("produire",),
    "produisisses": ("produire",),
    "produisisse": ("produire",),
    "produisissiez": ("produire",),
    "produisissions": ("produire",),
    "produisîtes": ("produire",),
    "produisit": ("produire",),
    "produisît": ("produire",),
    "produisons": ("produire",),
    "produis": ("produire",),
    "produite": ("produire",),
    "produites": ("produire",),
    "produit": ("produire",),
    "produits": ("produire",),
    "proféraient": ("proférer",),
    "proférai": ("proférer",),
    "proférais": ("proférer",),
    "proférait": ("proférer",),
    "proféra": ("proférer",),
    "proférâmes": ("proférer",),
    "proférant": ("proférer",),
    "proféras": ("proférer",),
    "proférassent": ("proférer",),
    "proférasses": ("proférer",),
    "proférasse": ("proférer",),
    "proférassiez": ("proférer",),
    "proférassions": ("proférer",),
    "proférâtes": ("proférer",),
    "proférât": ("proférer",),
    "proférée": ("proférer",),
    "proférées": ("proférer",),
    "proféré": ("proférer",),
    "profèrent": ("proférer",),
    "profère": ("proférer",),
    "proférera": ("proférer",),
    "proféreraient": ("proférer",),
    "proférerai": ("proférer",),
    "proférerais": ("proférer",),
    "proférerait": ("proférer",),
    "proféreras": ("proférer",),
    "proférèrent": ("proférer",),
    "proférerez": ("proférer",),
    "proféreriez": ("proférer",),
    "proférerions": ("proférer",),
    "proférerons": ("proférer",),
    "proféreront": ("proférer",),
    "proférés": ("proférer",),
    "profères": ("proférer",),
    "proférez": ("proférer",),
    "profériez": ("proférer",),
    "proférions": ("proférer",),
    "proférons": ("proférer",),
    "projetaient": ("projeter",),
    "projetai": ("projeter",),
    "projetais": ("projeter",),
    "projetait": ("projeter",),
    "projeta": ("projeter",),
    "projetâmes": ("projeter",),
    "projetant": ("projeter",),
    "projetas": ("projeter",),
    "projetassent": ("projeter",),
    "projetasses": ("projeter",),
    "projetasse": ("projeter",),
    "projetassiez": ("projeter",),
    "projetassions": ("projeter",),
    "projetâtes": ("projeter",),
    "projetât": ("projeter",),
    "projetée": ("projeter",),
    "projetées": ("projeter",),
    "projeté": ("projeter",),
    "projetèrent": ("projeter",),
    "projetés": ("projeter",),
    "projetez": ("projeter",),
    "projetiez": ("projeter",),
    "projetions": ("projeter",),
    "projetons": ("projeter",),
    "projettent": ("projeter",),
    "projette": ("projeter",),
    "projettera": ("projeter",),
    "projetteraient": ("projeter",),
    "projetterai": ("projeter",),
    "projetterais": ("projeter",),
    "projetterait": ("projeter",),
    "projetteras": ("projeter",),
    "projetterez": ("projeter",),
    "projetteriez": ("projeter",),
    "projetterions": ("projeter",),
    "projetterons": ("projeter",),
    "projetteront": ("projeter",),
    "projettes": ("projeter",),
    "proliféraient": ("proliférer",),
    "proliférai": ("proliférer",),
    "proliférais": ("proliférer",),
    "proliférait": ("proliférer",),
    "proliféra": ("proliférer",),
    "proliférâmes": ("proliférer",),
    "proliférant": ("proliférer",),
    "proliféras": ("proliférer",),
    "proliférassent": ("proliférer",),
    "proliférasses": ("proliférer",),
    "proliférasse": ("proliférer",),
    "proliférassiez": ("proliférer",),
    "proliférassions": ("proliférer",),
    "proliférâtes": ("proliférer",),
    "proliférât": ("proliférer",),
    "proliféré": ("proliférer",),
    "prolifèrent": ("proliférer",),
    "prolifère": ("proliférer",),
    "proliférera": ("proliférer",),
    "proliféreraient": ("proliférer",),
    "proliférerai": ("proliférer",),
    "proliférerais": ("proliférer",),
    "proliférerait": ("proliférer",),
    "proliféreras": ("proliférer",),
    "proliférèrent": ("proliférer",),
    "proliférerez": ("proliférer",),
    "proliféreriez": ("proliférer",),
    "proliférerions": ("proliférer",),
    "proliférerons": ("proliférer",),
    "proliféreront": ("proliférer",),
    "prolifères": ("proliférer",),
    "proliférez": ("proliférer",),
    "prolifériez": ("proliférer",),
    "proliférions": ("proliférer",),
    "proliférons": ("proliférer",),
    "prolongeaient": ("prolonger",),
    "prolongeai": ("prolonger",),
    "prolongeais": ("prolonger",),
    "prolongeait": ("prolonger",),
    "prolongea": ("prolonger",),
    "prolongeâmes": ("prolonger",),
    "prolongeant": ("prolonger",),
    "prolongeas": ("prolonger",),
    "prolongeassent": ("prolonger",),
    "prolongeasses": ("prolonger",),
    "prolongeasse": ("prolonger",),
    "prolongeassiez": ("prolonger",),
    "prolongeassions": ("prolonger",),
    "prolongeâtes": ("prolonger",),
    "prolongeât": ("prolonger",),
    "prolongée": ("prolonger",),
    "prolongées": ("prolonger",),
    "prolongé": ("prolonger",),
    "prolongent": ("prolonger",),
    "prolongeons": ("prolonger",),
    "prolonge": ("prolonger",),
    "prolongera": ("prolonger",),
    "prolongeraient": ("prolonger",),
    "prolongerai": ("prolonger",),
    "prolongerais": ("prolonger",),
    "prolongerait": ("prolonger",),
    "prolongeras": ("prolonger",),
    "prolongèrent": ("prolonger",),
    "prolongerez": ("prolonger",),
    "prolongeriez": ("prolonger",),
    "prolongerions": ("prolonger",),
    "prolongerons": ("prolonger",),
    "prolongeront": ("prolonger",),
    "prolongés": ("prolonger",),
    "prolonges": ("prolonger",),
    "prolongez": ("prolonger",),
    "prolongiez": ("prolonger",),
    "prolongions": ("prolonger",),
    "promenaient": ("promener",),
    "promenai": ("promener",),
    "promenais": ("promener",),
    "promenait": ("promener",),
    "promena": ("promener",),
    "promenâmes": ("promener",),
    "promenant": ("promener",),
    "promenas": ("promener",),
    "promenassent": ("promener",),
    "promenasses": ("promener",),
    "promenasse": ("promener",),
    "promenassiez": ("promener",),
    "promenassions": ("promener",),
    "promenâtes": ("promener",),
    "promenât": ("promener",),
    "promenée": ("promener",),
    "promenées": ("promener",),
    "promené": ("promener",),
    "promènent": ("promener",),
    "promène": ("promener",),
    "promènera": ("promener",),
    "promèneraient": ("promener",),
    "promènerai": ("promener",),
    "promènerais": ("promener",),
    "promènerait": ("promener",),
    "promèneras": ("promener",),
    "promenèrent": ("promener",),
    "promènerez": ("promener",),
    "promèneriez": ("promener",),
    "promènerions": ("promener",),
    "promènerons": ("promener",),
    "promèneront": ("promener",),
    "promenés": ("promener",),
    "promènes": ("promener",),
    "promenez": ("promener",),
    "promeniez": ("promener",),
    "promenions": ("promener",),
    "promenons": ("promener",),
    "promet": ("promettre",),
    "promets": ("promettre",),
    "promettaient": ("promettre",),
    "promettais": ("promettre",),
    "promettait": ("promettre",),
    "promettant": ("promettre",),
    "promettent": ("promettre",),
    "promette": ("promettre",),
    "promettes": ("promettre",),
    "promettez": ("promettre",),
    "promettiez": ("promettre",),
    "promettions": ("promettre",),
    "promettons": ("promettre",),
    "promettra": ("promettre",),
    "promettraient": ("promettre",),
    "promettrai": ("promettre",),
    "promettrais": ("promettre",),
    "promettrait": ("promettre",),
    "promettras": ("promettre",),
    "promettrez": ("promettre",),
    "promettriez": ("promettre",),
    "promettrions": ("promettre",),
    "promettrons": ("promettre",),
    "promettront": ("promettre",),
    "promîmes": ("promettre",),
    "promirent": ("promettre",),
    "promise": ("promettre",),
    "promises": ("promettre",),
    "promis": ("promettre",),
    "promissent": ("promettre",),
    "promisses": ("promettre",),
    "promisse": ("promettre",),
    "promissiez": ("promettre",),
    "promissions": ("promettre",),
    "promîtes": ("promettre",),
    "promit": ("promettre",),
    "promît": ("promettre",),
    "promeus": ("promouvoir",),
    "promeut": ("promouvoir",),
    "promeuvent": ("promouvoir",),
    "promeuve": ("promouvoir",),
    "promeuves": ("promouvoir",),
    "promouvaient": ("promouvoir",),
    "promouvais": ("promouvoir",),
    "promouvait": ("promouvoir",),
    "promouvant": ("promouvoir",),
    "promouvez": ("promouvoir",),
    "promouviez": ("promouvoir",),
    "promouvions": ("promouvoir",),
    "promouvons": ("promouvoir",),
    "promouvra": ("promouvoir",),
    "promouvraient": ("promouvoir",),
    "promouvrai": ("promouvoir",),
    "promouvrais": ("promouvoir",),
    "promouvrait": ("promouvoir",),
    "promouvras": ("promouvoir",),
    "promouvrez": ("promouvoir",),
    "promouvriez": ("promouvoir",),
    "promouvrions": ("promouvoir",),
    "promouvrons": ("promouvoir",),
    "promouvront": ("promouvoir",),
    "promue": ("promouvoir",),
    "promues": ("promouvoir",),
    "promu": ("promouvoir",),
    "promûmes": ("promouvoir",),
    "promurent": ("promouvoir",),
    "promus": ("promouvoir",),
    "promussent": ("promouvoir",),
    "promusses": ("promouvoir",),
    "promusse": ("promouvoir",),
    "promussiez": ("promouvoir",),
    "promussions": ("promouvoir",),
    "promûtes": ("promouvoir",),
    "promut": ("promouvoir",),
    "promût": ("promouvoir",),
    "prononçaient": ("prononcer",),
    "prononçai": ("prononcer",),
    "prononçais": ("prononcer",),
    "prononçait": ("prononcer",),
    "prononça": ("prononcer",),
    "prononçâmes": ("prononcer",),
    "prononçant": ("prononcer",),
    "prononças": ("prononcer",),
    "prononçassent": ("prononcer",),
    "prononçasses": ("prononcer",),
    "prononçasse": ("prononcer",),
    "prononçassiez": ("prononcer",),
    "prononçassions": ("prononcer",),
    "prononçâtes": ("prononcer",),
    "prononçât": ("prononcer",),
    "prononcée": ("prononcer",),
    "prononcées": ("prononcer",),
    "prononcé": ("prononcer",),
    "prononcent": ("prononcer",),
    "prononce": ("prononcer",),
    "prononcera": ("prononcer",),
    "prononceraient": ("prononcer",),
    "prononcerai": ("prononcer",),
    "prononcerais": ("prononcer",),
    "prononcerait": ("prononcer",),
    "prononceras": ("prononcer",),
    "prononcèrent": ("prononcer",),
    "prononcerez": ("prononcer",),
    "prononceriez": ("prononcer",),
    "prononcerions": ("prononcer",),
    "prononcerons": ("prononcer",),
    "prononceront": ("prononcer",),
    "prononcés": ("prononcer",),
    "prononces": ("prononcer",),
    "prononcez": ("prononcer",),
    "prononciez": ("prononcer",),
    "prononcions": ("prononcer",),
    "prononçons": ("prononcer",),
    "propageaient": ("propager",),
    "propageai": ("propager",),
    "propageais": ("propager",),
    "propageait": ("propager",),
    "propagea": ("propager",),
    "propageâmes": ("propager",),
    "propageant": ("propager",),
    "propageas": ("propager",),
    "propageassent": ("propager",),
    "propageasses": ("propager",),
    "propageasse": ("propager",),
    "propageassiez": ("propager",),
    "propageassions": ("propager",),
    "propageâtes": ("propager",),
    "propageât": ("propager",),
    "propagée": ("propager",),
    "propagées": ("propager",),
    "propagé": ("propager",),
    "propagent": ("propager",),
    "propageons": ("propager",),
    "propage": ("propager",),
    "propagera": ("propager",),
    "propageraient": ("propager",),
    "propagerai": ("propager",),
    "propagerais": ("propager",),
    "propagerait": ("propager",),
    "propageras": ("propager",),
    "propagèrent": ("propager",),
    "propagerez": ("propager",),
    "propageriez": ("propager",),
    "propagerions": ("propager",),
    "propagerons": ("propager",),
    "propageront": ("propager",),
    "propagés": ("propager",),
    "propages": ("propager",),
    "propagez": ("propager",),
    "propagiez": ("propager",),
    "propagions": ("propager",),
    "prorogeaient": ("proroger",),
    "prorogeai": ("proroger",),
    "prorogeais": ("proroger",),
    "prorogeait": ("proroger",),
    "prorogea": ("proroger",),
    "prorogeâmes": ("proroger",),
    "prorogeant": ("proroger",),
    "prorogeas": ("proroger",),
    "prorogeassent": ("proroger",),
    "prorogeasses": ("proroger",),
    "prorogeasse": ("proroger",),
    "prorogeassiez": ("proroger",),
    "prorogeassions": ("proroger",),
    "prorogeâtes": ("proroger",),
    "prorogeât": ("proroger",),
    "prorogée": ("proroger",),
    "prorogées": ("proroger",),
    "prorogé": ("proroger",),
    "prorogent": ("proroger",),
    "prorogeons": ("proroger",),
    "proroge": ("proroger",),
    "prorogera": ("proroger",),
    "prorogeraient": ("proroger",),
    "prorogerai": ("proroger",),
    "prorogerais": ("proroger",),
    "prorogerait": ("proroger",),
    "prorogeras": ("proroger",),
    "prorogèrent": ("proroger",),
    "prorogerez": ("proroger",),
    "prorogeriez": ("proroger",),
    "prorogerions": ("proroger",),
    "prorogerons": ("proroger",),
    "prorogeront": ("proroger",),
    "prorogés": ("proroger",),
    "proroges": ("proroger",),
    "prorogez": ("proroger",),
    "prorogiez": ("proroger",),
    "prorogions": ("proroger",),
    "proscrira": ("proscrire",),
    "proscriraient": ("proscrire",),
    "proscrirai": ("proscrire",),
    "proscrirais": ("proscrire",),
    "proscrirait": ("proscrire",),
    "proscriras": ("proscrire",),
    "proscrirez": ("proscrire",),
    "proscririez": ("proscrire",),
    "proscririons": ("proscrire",),
    "proscrirons": ("proscrire",),
    "proscriront": ("proscrire",),
    "proscris": ("proscrire",),
    "proscrite": ("proscrire",),
    "proscrites": ("proscrire",),
    "proscrit": ("proscrire",),
    "proscrits": ("proscrire",),
    "proscrivaient": ("proscrire",),
    "proscrivais": ("proscrire",),
    "proscrivait": ("proscrire",),
    "proscrivant": ("proscrire",),
    "proscrivent": ("proscrire",),
    "proscrive": ("proscrire",),
    "proscrives": ("proscrire",),
    "proscrivez": ("proscrire",),
    "proscriviez": ("proscrire",),
    "proscrivîmes": ("proscrire",),
    "proscrivions": ("proscrire",),
    "proscrivirent": ("proscrire",),
    "proscrivis": ("proscrire",),
    "proscrivissent": ("proscrire",),
    "proscrivisses": ("proscrire",),
    "proscrivisse": ("proscrire",),
    "proscrivissiez": ("proscrire",),
    "proscrivissions": ("proscrire",),
    "proscrivîtes": ("proscrire",),
    "proscrivit": ("proscrire",),
    "proscrivît": ("proscrire",),
    "proscrivons": ("proscrire",),
    "prosodiaient": ("prosodier",),
    "prosodiai": ("prosodier",),
    "prosodiais": ("prosodier",),
    "prosodiait": ("prosodier",),
    "prosodia": ("prosodier",),
    "prosodiâmes": ("prosodier",),
    "prosodiant": ("prosodier",),
    "prosodias": ("prosodier",),
    "prosodiassent": ("prosodier",),
    "prosodiasses": ("prosodier",),
    "prosodiasse": ("prosodier",),
    "prosodiassiez": ("prosodier",),
    "prosodiassions": ("prosodier",),
    "prosodiâtes": ("prosodier",),
    "prosodiât": ("prosodier",),
    "prosodiée": ("prosodier",),
    "prosodiées": ("prosodier",),
    "prosodié": ("prosodier",),
    "prosodient": ("prosodier",),
    "prosodie": ("prosodier",),
    "prosodiera": ("prosodier",),
    "prosodieraient": ("prosodier",),
    "prosodierai": ("prosodier",),
    "prosodierais": ("prosodier",),
    "prosodierait": ("prosodier",),
    "prosodieras": ("prosodier",),
    "prosodièrent": ("prosodier",),
    "prosodierez": ("prosodier",),
    "prosodieriez": ("prosodier",),
    "prosodierions": ("prosodier",),
    "prosodierons": ("prosodier",),
    "prosodieront": ("prosodier",),
    "prosodiés": ("prosodier",),
    "prosodies": ("prosodier",),
    "prosodiez": ("prosodier",),
    "prosodiiez": ("prosodier",),
    "prosodiions": ("prosodier",),
    "prosodions": ("prosodier",),
    "prospéraient": ("prospérer",),
    "prospérai": ("prospérer",),
    "prospérais": ("prospérer",),
    "prospérait": ("prospérer",),
    "prospéra": ("prospérer",),
    "prospérâmes": ("prospérer",),
    "prospérant": ("prospérer",),
    "prospéras": ("prospérer",),
    "prospérassent": ("prospérer",),
    "prospérasses": ("prospérer",),
    "prospérasse": ("prospérer",),
    "prospérassiez": ("prospérer",),
    "prospérassions": ("prospérer",),
    "prospérâtes": ("prospérer",),
    "prospérât": ("prospérer",),
    "prospéré": ("prospérer",),
    "prospèrent": ("prospérer",),
    "prospère": ("prospérer",),
    "prospérera": ("prospérer",),
    "prospéreraient": ("prospérer",),
    "prospérerai": ("prospérer",),
    "prospérerais": ("prospérer",),
    "prospérerait": ("prospérer",),
    "prospéreras": ("prospérer",),
    "prospérèrent": ("prospérer",),
    "prospérerez": ("prospérer",),
    "prospéreriez": ("prospérer",),
    "prospérerions": ("prospérer",),
    "prospérerons": ("prospérer",),
    "prospéreront": ("prospérer",),
    "prospères": ("prospérer",),
    "prospérez": ("prospérer",),
    "prospériez": ("prospérer",),
    "prospérions": ("prospérer",),
    "prospérons": ("prospérer",),
    "protégeaient": ("protéger",),
    "protégeai": ("protéger",),
    "protégeais": ("protéger",),
    "protégeait": ("protéger",),
    "protégea": ("protéger",),
    "protégeâmes": ("protéger",),
    "protégeant": ("protéger",),
    "protégeas": ("protéger",),
    "protégeassent": ("protéger",),
    "protégeasses": ("protéger",),
    "protégeasse": ("protéger",),
    "protégeassiez": ("protéger",),
    "protégeassions": ("protéger",),
    "protégeâtes": ("protéger",),
    "protégeât": ("protéger",),
    "protégée": ("protéger",),
    "protégées": ("protéger",),
    "protégé": ("protéger",),
    "protègent": ("protéger",),
    "protégeons": ("protéger",),
    "protège": ("protéger",),
    "protégera": ("protéger",),
    "protégeraient": ("protéger",),
    "protégerai": ("protéger",),
    "protégerais": ("protéger",),
    "protégerait": ("protéger",),
    "protégeras": ("protéger",),
    "protégèrent": ("protéger",),
    "protégerez": ("protéger",),
    "protégeriez": ("protéger",),
    "protégerions": ("protéger",),
    "protégerons": ("protéger",),
    "protégeront": ("protéger",),
    "protégés": ("protéger",),
    "protèges": ("protéger",),
    "protégez": ("protéger",),
    "protégiez": ("protéger",),
    "protégions": ("protéger",),
    "provenaient": ("provenir",),
    "provenais": ("provenir",),
    "provenait": ("provenir",),
    "provenant": ("provenir",),
    "provenez": ("provenir",),
    "proveniez": ("provenir",),
    "provenions": ("provenir",),
    "provenons": ("provenir",),
    "provenue": ("provenir",),
    "provenues": ("provenir",),
    "provenu": ("provenir",),
    "provenus": ("provenir",),
    "proviendra": ("provenir",),
    "proviendraient": ("provenir",),
    "proviendrai": ("provenir",),
    "proviendrais": ("provenir",),
    "proviendrait": ("provenir",),
    "proviendras": ("provenir",),
    "proviendrez": ("provenir",),
    "proviendriez": ("provenir",),
    "proviendrions": ("provenir",),
    "proviendrons": ("provenir",),
    "proviendront": ("provenir",),
    "proviennent": ("provenir",),
    "provienne": ("provenir",),
    "proviennes": ("provenir",),
    "proviens": ("provenir",),
    "provient": ("provenir",),
    "provînmes": ("provenir",),
    "provinrent": ("provenir",),
    "provins": ("provenir",),
    "provinssent": ("provenir",),
    "provinsses": ("provenir",),
    "provinsse": ("provenir",),
    "provinssiez": ("provenir",),
    "provinssions": ("provenir",),
    "provîntes": ("provenir",),
    "provint": ("provenir",),
    "provînt": ("provenir",),
    "psalmodiaient": ("psalmodier",),
    "psalmodiai": ("psalmodier",),
    "psalmodiais": ("psalmodier",),
    "psalmodiait": ("psalmodier",),
    "psalmodia": ("psalmodier",),
    "psalmodiâmes": ("psalmodier",),
    "psalmodiant": ("psalmodier",),
    "psalmodias": ("psalmodier",),
    "psalmodiassent": ("psalmodier",),
    "psalmodiasses": ("psalmodier",),
    "psalmodiasse": ("psalmodier",),
    "psalmodiassiez": ("psalmodier",),
    "psalmodiassions": ("psalmodier",),
    "psalmodiâtes": ("psalmodier",),
    "psalmodiât": ("psalmodier",),
    "psalmodiée": ("psalmodier",),
    "psalmodiées": ("psalmodier",),
    "psalmodié": ("psalmodier",),
    "psalmodient": ("psalmodier",),
    "psalmodie": ("psalmodier",),
    "psalmodiera": ("psalmodier",),
    "psalmodieraient": ("psalmodier",),
    "psalmodierai": ("psalmodier",),
    "psalmodierais": ("psalmodier",),
    "psalmodierait": ("psalmodier",),
    "psalmodieras": ("psalmodier",),
    "psalmodièrent": ("psalmodier",),
    "psalmodierez": ("psalmodier",),
    "psalmodieriez": ("psalmodier",),
    "psalmodierions": ("psalmodier",),
    "psalmodierons": ("psalmodier",),
    "psalmodieront": ("psalmodier",),
    "psalmodiés": ("psalmodier",),
    "psalmodies": ("psalmodier",),
    "psalmodiez": ("psalmodier",),
    "psalmodiiez": ("psalmodier",),
    "psalmodiions": ("psalmodier",),
    "psalmodions": ("psalmodier",),
    "publiaient": ("publier",),
    "publiai": ("publier",),
    "publiais": ("publier",),
    "publiait": ("publier",),
    "publia": ("publier",),
    "publiâmes": ("publier",),
    "publiant": ("publier",),
    "publias": ("publier",),
    "publiassent": ("publier",),
    "publiasses": ("publier",),
    "publiasse": ("publier",),
    "publiassiez": ("publier",),
    "publiassions": ("publier",),
    "publiâtes": ("publier",),
    "publiât": ("publier",),
    "publiée": ("publier",),
    "publiées": ("publier",),
    "publié": ("publier",),
    "publient": ("publier",),
    "publie": ("publier",),
    "publiera": ("publier",),
    "publieraient": ("publier",),
    "publierai": ("publier",),
    "publierais": ("publier",),
    "publierait": ("publier",),
    "publieras": ("publier",),
    "publièrent": ("publier",),
    "publierez": ("publier",),
    "publieriez": ("publier",),
    "publierions": ("publier",),
    "publierons": ("publier",),
    "publieront": ("publier",),
    "publiés": ("publier",),
    "publies": ("publier",),
    "publiez": ("publier",),
    "publiiez": ("publier",),
    "publiions": ("publier",),
    "publions": ("publier",),
    "punie": ("punir",),
    "punies": ("punir",),
    "puni": ("punir",),
    "punîmes": ("punir",),
    "punira": ("punir",),
    "puniraient": ("punir",),
    "punirai": ("punir",),
    "punirais": ("punir",),
    "punirait": ("punir",),
    "puniras": ("punir",),
    "punirent": ("punir",),
    "punirez": ("punir",),
    "puniriez": ("punir",),
    "punirions": ("punir",),
    "punirons": ("punir",),
    "puniront": ("punir",),
    "punis": ("punir",),
    "punissaient": ("punir",),
    "punissais": ("punir",),
    "punissait": ("punir",),
    "punissant": ("punir",),
    "punissent": ("punir",),
    "punisse": ("punir",),
    "punisses": ("punir",),
    "punissez": ("punir",),
    "punissiez": ("punir",),
    "punissions": ("punir",),
    "punissons": ("punir",),
    "punîtes": ("punir",),
    "punit": ("punir",),
    "punît": ("punir",),
    "purgeaient": ("purger",),
    "purgeai": ("purger",),
    "purgeais": ("purger",),
    "purgeait": ("purger",),
    "purgea": ("purger",),
    "purgeâmes": ("purger",),
    "purgeant": ("purger",),
    "purgeas": ("purger",),
    "purgeassent": ("purger",),
    "purgeasses": ("purger",),
    "purgeasse": ("purger",),
    "purgeassiez": ("purger",),
    "purgeassions": ("purger",),
    "purgeâtes": ("purger",),
    "purgeât": ("purger",),
    "purgée": ("purger",),
    "purgées": ("purger",),
    "purgé": ("purger",),
    "purgent": ("purger",),
    "purgeons": ("purger",),
    "purge": ("purger",),
    "purgera": ("purger",),
    "purgeraient": ("purger",),
    "purgerai": ("purger",),
    "purgerais": ("purger",),
    "purgerait": ("purger",),
    "purgeras": ("purger",),
    "purgèrent": ("purger",),
    "purgerez": ("purger",),
    "purgeriez": ("purger",),
    "purgerions": ("purger",),
    "purgerons": ("purger",),
    "purgeront": ("purger",),
    "purgés": ("purger",),
    "purges": ("purger",),
    "purgez": ("purger",),
    "purgiez": ("purger",),
    "purgions": ("purger",),
    "purifiaient": ("purifier",),
    "purifiai": ("purifier",),
    "purifiais": ("purifier",),
    "purifiait": ("purifier",),
    "purifia": ("purifier",),
    "purifiâmes": ("purifier",),
    "purifiant": ("purifier",),
    "purifias": ("purifier",),
    "purifiassent": ("purifier",),
    "purifiasses": ("purifier",),
    "purifiasse": ("purifier",),
    "purifiassiez": ("purifier",),
    "purifiassions": ("purifier",),
    "purifiâtes": ("purifier",),
    "purifiât": ("purifier",),
    "purifiée": ("purifier",),
    "purifiées": ("purifier",),
    "purifié": ("purifier",),
    "purifient": ("purifier",),
    "purifie": ("purifier",),
    "purifiera": ("purifier",),
    "purifieraient": ("purifier",),
    "purifierai": ("purifier",),
    "purifierais": ("purifier",),
    "purifierait": ("purifier",),
    "purifieras": ("purifier",),
    "purifièrent": ("purifier",),
    "purifierez": ("purifier",),
    "purifieriez": ("purifier",),
    "purifierions": ("purifier",),
    "purifierons": ("purifier",),
    "purifieront": ("purifier",),
    "purifiés": ("purifier",),
    "purifies": ("purifier",),
    "purifiez": ("purifier",),
    "purifiiez": ("purifier",),
    "purifiions": ("purifier",),
    "purifions": ("purifier",),
    "putassaient": ("putasser",),
    "putassai": ("putasser",),
    "putassais": ("putasser",),
    "putassait": ("putasser",),
    "putassa": ("putasser",),
    "putassâmes": ("putasser",),
    "putassant": ("putasser",),
    "putassas": ("putasser",),
    "putassassent": ("putasser",),
    "putassasses": ("putasser",),
    "putassasse": ("putasser",),
    "putassassiez": ("putasser",),
    "putassassions": ("putasser",),
    "putassâtes": ("putasser",),
    "putassât": ("putasser",),
    "putassé": ("putasser",),
    "putassent": ("putasser",),
    "putasse": ("putasser",),
    "putassera": ("putasser",),
    "putasseraient": ("putasser",),
    "putasserai": ("putasser",),
    "putasserais": ("putasser",),
    "putasserait": ("putasser",),
    "putasseras": ("putasser",),
    "putassèrent": ("putasser",),
    "putasserez": ("putasser",),
    "putasseriez": ("putasser",),
    "putasserions": ("putasser",),
    "putasserons": ("putasser",),
    "putasseront": ("putasser",),
    "putasses": ("putasser",),
    "putassez": ("putasser",),
    "putassiez": ("putasser",),
    "putassions": ("putasser",),
    "putassons": ("putasser",),
    "putréfiaient": ("putréfier",),
    "putréfiai": ("putréfier",),
    "putréfiais": ("putréfier",),
    "putréfiait": ("putréfier",),
    "putréfia": ("putréfier",),
    "putréfiâmes": ("putréfier",),
    "putréfiant": ("putréfier",),
    "putréfias": ("putréfier",),
    "putréfiassent": ("putréfier",),
    "putréfiasses": ("putréfier",),
    "putréfiasse": ("putréfier",),
    "putréfiassiez": ("putréfier",),
    "putréfiassions": ("putréfier",),
    "putréfiâtes": ("putréfier",),
    "putréfiât": ("putréfier",),
    "putréfiée": ("putréfier",),
    "putréfiées": ("putréfier",),
    "putréfié": ("putréfier",),
    "putréfient": ("putréfier",),
    "putréfie": ("putréfier",),
    "putréfiera": ("putréfier",),
    "putréfieraient": ("putréfier",),
    "putréfierai": ("putréfier",),
    "putréfierais": ("putréfier",),
    "putréfierait": ("putréfier",),
    "putréfieras": ("putréfier",),
    "putréfièrent": ("putréfier",),
    "putréfierez": ("putréfier",),
    "putréfieriez": ("putréfier",),
    "putréfierions": ("putréfier",),
    "putréfierons": ("putréfier",),
    "putréfieront": ("putréfier",),
    "putréfiés": ("putréfier",),
    "putréfies": ("putréfier",),
    "putréfiez": ("putréfier",),
    "putréfiiez": ("putréfier",),
    "putréfiions": ("putréfier",),
    "putréfions": ("putréfier",),
    "pyrogénaient": ("pyrogéner",),
    "pyrogénai": ("pyrogéner",),
    "pyrogénais": ("pyrogéner",),
    "pyrogénait": ("pyrogéner",),
    "pyrogéna": ("pyrogéner",),
    "pyrogénâmes": ("pyrogéner",),
    "pyrogénant": ("pyrogéner",),
    "pyrogénas": ("pyrogéner",),
    "pyrogénassent": ("pyrogéner",),
    "pyrogénasses": ("pyrogéner",),
    "pyrogénasse": ("pyrogéner",),
    "pyrogénassiez": ("pyrogéner",),
    "pyrogénassions": ("pyrogéner",),
    "pyrogénâtes": ("pyrogéner",),
    "pyrogénât": ("pyrogéner",),
    "pyrogénée": ("pyrogéner",),
    "pyrogénées": ("pyrogéner",),
    "pyrogéné": ("pyrogéner",),
    "pyrogènent": ("pyrogéner",),
    "pyrogène": ("pyrogéner",),
    "pyrogénera": ("pyrogéner",),
    "pyrogéneraient": ("pyrogéner",),
    "pyrogénerai": ("pyrogéner",),
    "pyrogénerais": ("pyrogéner",),
    "pyrogénerait": ("pyrogéner",),
    "pyrogéneras": ("pyrogéner",),
    "pyrogénèrent": ("pyrogéner",),
    "pyrogénerez": ("pyrogéner",),
    "pyrogéneriez": ("pyrogéner",),
    "pyrogénerions": ("pyrogéner",),
    "pyrogénerons": ("pyrogéner",),
    "pyrogéneront": ("pyrogéner",),
    "pyrogénés": ("pyrogéner",),
    "pyrogènes": ("pyrogéner",),
    "pyrogénez": ("pyrogéner",),
    "pyrogéniez": ("pyrogéner",),
    "pyrogénions": ("pyrogéner",),
    "pyrogénons": ("pyrogéner",),
    "qualifiaient": ("qualifier",),
    "qualifiai": ("qualifier",),
    "qualifiais": ("qualifier",),
    "qualifiait": ("qualifier",),
    "qualifia": ("qualifier",),
    "qualifiâmes": ("qualifier",),
    "qualifiant": ("qualifier",),
    "qualifias": ("qualifier",),
    "qualifiassent": ("qualifier",),
    "qualifiasses": ("qualifier",),
    "qualifiasse": ("qualifier",),
    "qualifiassiez": ("qualifier",),
    "qualifiassions": ("qualifier",),
    "qualifiâtes": ("qualifier",),
    "qualifiât": ("qualifier",),
    "qualifiée": ("qualifier",),
    "qualifiées": ("qualifier",),
    "qualifié": ("qualifier",),
    "qualifient": ("qualifier",),
    "qualifie": ("qualifier",),
    "qualifiera": ("qualifier",),
    "qualifieraient": ("qualifier",),
    "qualifierai": ("qualifier",),
    "qualifierais": ("qualifier",),
    "qualifierait": ("qualifier",),
    "qualifieras": ("qualifier",),
    "qualifièrent": ("qualifier",),
    "qualifierez": ("qualifier",),
    "qualifieriez": ("qualifier",),
    "qualifierions": ("qualifier",),
    "qualifierons": ("qualifier",),
    "qualifieront": ("qualifier",),
    "qualifiés": ("qualifier",),
    "qualifies": ("qualifier",),
    "qualifiez": ("qualifier",),
    "qualifiiez": ("qualifier",),
    "qualifiions": ("qualifier",),
    "qualifions": ("qualifier",),
    "quantifiaient": ("quantifier",),
    "quantifiai": ("quantifier",),
    "quantifiais": ("quantifier",),
    "quantifiait": ("quantifier",),
    "quantifia": ("quantifier",),
    "quantifiâmes": ("quantifier",),
    "quantifiant": ("quantifier",),
    "quantifias": ("quantifier",),
    "quantifiassent": ("quantifier",),
    "quantifiasses": ("quantifier",),
    "quantifiasse": ("quantifier",),
    "quantifiassiez": ("quantifier",),
    "quantifiassions": ("quantifier",),
    "quantifiâtes": ("quantifier",),
    "quantifiât": ("quantifier",),
    "quantifiée": ("quantifier",),
    "quantifiées": ("quantifier",),
    "quantifié": ("quantifier",),
    "quantifient": ("quantifier",),
    "quantifie": ("quantifier",),
    "quantifiera": ("quantifier",),
    "quantifieraient": ("quantifier",),
    "quantifierai": ("quantifier",),
    "quantifierais": ("quantifier",),
    "quantifierait": ("quantifier",),
    "quantifieras": ("quantifier",),
    "quantifièrent": ("quantifier",),
    "quantifierez": ("quantifier",),
    "quantifieriez": ("quantifier",),
    "quantifierions": ("quantifier",),
    "quantifierons": ("quantifier",),
    "quantifieront": ("quantifier",),
    "quantifiés": ("quantifier",),
    "quantifies": ("quantifier",),
    "quantifiez": ("quantifier",),
    "quantifiiez": ("quantifier",),
    "quantifiions": ("quantifier",),
    "quantifions": ("quantifier",),
    "quartageaient": ("quartager",),
    "quartageai": ("quartager",),
    "quartageais": ("quartager",),
    "quartageait": ("quartager",),
    "quartagea": ("quartager",),
    "quartageâmes": ("quartager",),
    "quartageant": ("quartager",),
    "quartageas": ("quartager",),
    "quartageassent": ("quartager",),
    "quartageasses": ("quartager",),
    "quartageasse": ("quartager",),
    "quartageassiez": ("quartager",),
    "quartageassions": ("quartager",),
    "quartageâtes": ("quartager",),
    "quartageât": ("quartager",),
    "quartagée": ("quartager",),
    "quartagées": ("quartager",),
    "quartagé": ("quartager",),
    "quartagent": ("quartager",),
    "quartageons": ("quartager",),
    "quartage": ("quartager",),
    "quartagera": ("quartager",),
    "quartageraient": ("quartager",),
    "quartagerai": ("quartager",),
    "quartagerais": ("quartager",),
    "quartagerait": ("quartager",),
    "quartageras": ("quartager",),
    "quartagèrent": ("quartager",),
    "quartagerez": ("quartager",),
    "quartageriez": ("quartager",),
    "quartagerions": ("quartager",),
    "quartagerons": ("quartager",),
    "quartageront": ("quartager",),
    "quartagés": ("quartager",),
    "quartages": ("quartager",),
    "quartagez": ("quartager",),
    "quartagiez": ("quartager",),
    "quartagions": ("quartager",),
    "quartzifiaient": ("quartzifier",),
    "quartzifiai": ("quartzifier",),
    "quartzifiais": ("quartzifier",),
    "quartzifiait": ("quartzifier",),
    "quartzifia": ("quartzifier",),
    "quartzifiâmes": ("quartzifier",),
    "quartzifiant": ("quartzifier",),
    "quartzifias": ("quartzifier",),
    "quartzifiassent": ("quartzifier",),
    "quartzifiasses": ("quartzifier",),
    "quartzifiasse": ("quartzifier",),
    "quartzifiassiez": ("quartzifier",),
    "quartzifiassions": ("quartzifier",),
    "quartzifiâtes": ("quartzifier",),
    "quartzifiât": ("quartzifier",),
    "quartzifiée": ("quartzifier",),
    "quartzifiées": ("quartzifier",),
    "quartzifié": ("quartzifier",),
    "quartzifient": ("quartzifier",),
    "quartzifie": ("quartzifier",),
    "quartzifiera": ("quartzifier",),
    "quartzifieraient": ("quartzifier",),
    "quartzifierai": ("quartzifier",),
    "quartzifierais": ("quartzifier",),
    "quartzifierait": ("quartzifier",),
    "quartzifieras": ("quartzifier",),
    "quartzifièrent": ("quartzifier",),
    "quartzifierez": ("quartzifier",),
    "quartzifieriez": ("quartzifier",),
    "quartzifierions": ("quartzifier",),
    "quartzifierons": ("quartzifier",),
    "quartzifieront": ("quartzifier",),
    "quartzifiés": ("quartzifier",),
    "quartzifies": ("quartzifier",),
    "quartzifiez": ("quartzifier",),
    "quartzifiiez": ("quartzifier",),
    "quartzifiions": ("quartzifier",),
    "quartzifions": ("quartzifier",),
    "quintessenciaient": ("quintessencier",),
    "quintessenciai": ("quintessencier",),
    "quintessenciais": ("quintessencier",),
    "quintessenciait": ("quintessencier",),
    "quintessencia": ("quintessencier",),
    "quintessenciâmes": ("quintessencier",),
    "quintessenciant": ("quintessencier",),
    "quintessencias": ("quintessencier",),
    "quintessenciassent": ("quintessencier",),
    "quintessenciasses": ("quintessencier",),
    "quintessenciasse": ("quintessencier",),
    "quintessenciassiez": ("quintessencier",),
    "quintessenciassions": ("quintessencier",),
    "quintessenciâtes": ("quintessencier",),
    "quintessenciât": ("quintessencier",),
    "quintessenciée": ("quintessencier",),
    "quintessenciées": ("quintessencier",),
    "quintessencié": ("quintessencier",),
    "quintessencient": ("quintessencier",),
    "quintessencie": ("quintessencier",),
    "quintessenciera": ("quintessencier",),
    "quintessencieraient": ("quintessencier",),
    "quintessencierai": ("quintessencier",),
    "quintessencierais": ("quintessencier",),
    "quintessencierait": ("quintessencier",),
    "quintessencieras": ("quintessencier",),
    "quintessencièrent": ("quintessencier",),
    "quintessencierez": ("quintessencier",),
    "quintessencieriez": ("quintessencier",),
    "quintessencierions": ("quintessencier",),
    "quintessencierons": ("quintessencier",),
    "quintessencieront": ("quintessencier",),
    "quintessenciés": ("quintessencier",),
    "quintessencies": ("quintessencier",),
    "quintessenciez": ("quintessencier",),
    "quintessenciiez": ("quintessencier",),
    "quintessenciions": ("quintessencier",),
    "quintessencions": ("quintessencier",),
    "quintoient": ("quintoyer",),
    "quintoie": ("quintoyer",),
    "quintoiera": ("quintoyer",),
    "quintoieraient": ("quintoyer",),
    "quintoierai": ("quintoyer",),
    "quintoierais": ("quintoyer",),
    "quintoierait": ("quintoyer",),
    "quintoieras": ("quintoyer",),
    "quintoierez": ("quintoyer",),
    "quintoieriez": ("quintoyer",),
    "quintoierions": ("quintoyer",),
    "quintoierons": ("quintoyer",),
    "quintoieront": ("quintoyer",),
    "quintoies": ("quintoyer",),
    "quintoyaient": ("quintoyer",),
    "quintoyai": ("quintoyer",),
    "quintoyais": ("quintoyer",),
    "quintoyait": ("quintoyer",),
    "quintoya": ("quintoyer",),
    "quintoyâmes": ("quintoyer",),
    "quintoyant": ("quintoyer",),
    "quintoyas": ("quintoyer",),
    "quintoyassent": ("quintoyer",),
    "quintoyasses": ("quintoyer",),
    "quintoyasse": ("quintoyer",),
    "quintoyassiez": ("quintoyer",),
    "quintoyassions": ("quintoyer",),
    "quintoyâtes": ("quintoyer",),
    "quintoyât": ("quintoyer",),
    "quintoyé": ("quintoyer",),
    "quintoyèrent": ("quintoyer",),
    "quintoyez": ("quintoyer",),
    "quintoyiez": ("quintoyer",),
    "quintoyions": ("quintoyer",),
    "quintoyons": ("quintoyer",),
    "quittançaient": ("quittancer",),
    "quittançai": ("quittancer",),
    "quittançais": ("quittancer",),
    "quittançait": ("quittancer",),
    "quittança": ("quittancer",),
    "quittançâmes": ("quittancer",),
    "quittançant": ("quittancer",),
    "quittanças": ("quittancer",),
    "quittançassent": ("quittancer",),
    "quittançasses": ("quittancer",),
    "quittançasse": ("quittancer",),
    "quittançassiez": ("quittancer",),
    "quittançassions": ("quittancer",),
    "quittançâtes": ("quittancer",),
    "quittançât": ("quittancer",),
    "quittancée": ("quittancer",),
    "quittancées": ("quittancer",),
    "quittancé": ("quittancer",),
    "quittancent": ("quittancer",),
    "quittance": ("quittancer",),
    "quittancera": ("quittancer",),
    "quittanceraient": ("quittancer",),
    "quittancerai": ("quittancer",),
    "quittancerais": ("quittancer",),
    "quittancerait": ("quittancer",),
    "quittanceras": ("quittancer",),
    "quittancèrent": ("quittancer",),
    "quittancerez": ("quittancer",),
    "quittanceriez": ("quittancer",),
    "quittancerions": ("quittancer",),
    "quittancerons": ("quittancer",),
    "quittanceront": ("quittancer",),
    "quittancés": ("quittancer",),
    "quittances": ("quittancer",),
    "quittancez": ("quittancer",),
    "quittanciez": ("quittancer",),
    "quittancions": ("quittancer",),
    "quittançons": ("quittancer",),
    "rabassenaient": ("rabassener",),
    "rabassenai": ("rabassener",),
    "rabassenais": ("rabassener",),
    "rabassenait": ("rabassener",),
    "rabassena": ("rabassener",),
    "rabassenâmes": ("rabassener",),
    "rabassenant": ("rabassener",),
    "rabassenas": ("rabassener",),
    "rabassenassent": ("rabassener",),
    "rabassenasses": ("rabassener",),
    "rabassenasse": ("rabassener",),
    "rabassenassiez": ("rabassener",),
    "rabassenassions": ("rabassener",),
    "rabassenâtes": ("rabassener",),
    "rabassenât": ("rabassener",),
    "rabassenée": ("rabassener",),
    "rabassenées": ("rabassener",),
    "rabassené": ("rabassener",),
    "rabassènent": ("rabassener",),
    "rabassène": ("rabassener",),
    "rabassènera": ("rabassener",),
    "rabassèneraient": ("rabassener",),
    "rabassènerai": ("rabassener",),
    "rabassènerais": ("rabassener",),
    "rabassènerait": ("rabassener",),
    "rabassèneras": ("rabassener",),
    "rabassenèrent": ("rabassener",),
    "rabassènerez": ("rabassener",),
    "rabassèneriez": ("rabassener",),
    "rabassènerions": ("rabassener",),
    "rabassènerons": ("rabassener",),
    "rabassèneront": ("rabassener",),
    "rabassenés": ("rabassener",),
    "rabassènes": ("rabassener",),
    "rabassenez": ("rabassener",),
    "rabasseniez": ("rabassener",),
    "rabassenions": ("rabassener",),
    "rabassenons": ("rabassener",),
    "rabat": ("rabattre",),
    "rabats": ("rabattre",),
    "rabattaient": ("rabattre",),
    "rabattais": ("rabattre",),
    "rabattait": ("rabattre",),
    "rabattant": ("rabattre",),
    "rabattent": ("rabattre",),
    "rabatte": ("rabattre",),
    "rabattes": ("rabattre",),
    "rabattez": ("rabattre",),
    "rabattiez": ("rabattre",),
    "rabattîmes": ("rabattre",),
    "rabattions": ("rabattre",),
    "rabattirent": ("rabattre",),
    "rabattis": ("rabattre",),
    "rabattissent": ("rabattre",),
    "rabattisses": ("rabattre",),
    "rabattisse": ("rabattre",),
    "rabattissiez": ("rabattre",),
    "rabattissions": ("rabattre",),
    "rabattîtes": ("rabattre",),
    "rabattit": ("rabattre",),
    "rabattît": ("rabattre",),
    "rabattons": ("rabattre",),
    "rabattra": ("rabattre",),
    "rabattraient": ("rabattre",),
    "rabattrai": ("rabattre",),
    "rabattrais": ("rabattre",),
    "rabattrait": ("rabattre",),
    "rabattras": ("rabattre",),
    "rabattrez": ("rabattre",),
    "rabattriez": ("rabattre",),
    "rabattrions": ("rabattre",),
    "rabattrons": ("rabattre",),
    "rabattront": ("rabattre",),
    "rabattue": ("rabattre",),
    "rabattues": ("rabattre",),
    "rabattu": ("rabattre",),
    "rabattus": ("rabattre",),
    "rabêtie": ("rabêtir",),
    "rabêties": ("rabêtir",),
    "rabêti": ("rabêtir",),
    "rabêtîmes": ("rabêtir",),
    "rabêtira": ("rabêtir",),
    "rabêtiraient": ("rabêtir",),
    "rabêtirai": ("rabêtir",),
    "rabêtirais": ("rabêtir",),
    "rabêtirait": ("rabêtir",),
    "rabêtiras": ("rabêtir",),
    "rabêtirent": ("rabêtir",),
    "rabêtirez": ("rabêtir",),
    "rabêtiriez": ("rabêtir",),
    "rabêtirions": ("rabêtir",),
    "rabêtirons": ("rabêtir",),
    "rabêtiront": ("rabêtir",),
    "rabêtis": ("rabêtir",),
    "rabêtissaient": ("rabêtir",),
    "rabêtissais": ("rabêtir",),
    "rabêtissait": ("rabêtir",),
    "rabêtissant": ("rabêtir",),
    "rabêtissent": ("rabêtir",),
    "rabêtisse": ("rabêtir",),
    "rabêtisses": ("rabêtir",),
    "rabêtissez": ("rabêtir",),
    "rabêtissiez": ("rabêtir",),
    "rabêtissions": ("rabêtir",),
    "rabêtissons": ("rabêtir",),
    "rabêtîtes": ("rabêtir",),
    "rabêtit": ("rabêtir",),
    "rabêtît": ("rabêtir",),
    "rabonnie": ("rabonnir",),
    "rabonnies": ("rabonnir",),
    "rabonni": ("rabonnir",),
    "rabonnîmes": ("rabonnir",),
    "rabonnira": ("rabonnir",),
    "rabonniraient": ("rabonnir",),
    "rabonnirai": ("rabonnir",),
    "rabonnirais": ("rabonnir",),
    "rabonnirait": ("rabonnir",),
    "rabonniras": ("rabonnir",),
    "rabonnirent": ("rabonnir",),
    "rabonnirez": ("rabonnir",),
    "rabonniriez": ("rabonnir",),
    "rabonnirions": ("rabonnir",),
    "rabonnirons": ("rabonnir",),
    "rabonniront": ("rabonnir",),
    "rabonnis": ("rabonnir",),
    "rabonnissaient": ("rabonnir",),
    "rabonnissais": ("rabonnir",),
    "rabonnissait": ("rabonnir",),
    "rabonnissant": ("rabonnir",),
    "rabonnissent": ("rabonnir",),
    "rabonnisse": ("rabonnir",),
    "rabonnisses": ("rabonnir",),
    "rabonnissez": ("rabonnir",),
    "rabonnissiez": ("rabonnir",),
    "rabonnissions": ("rabonnir",),
    "rabonnissons": ("rabonnir",),
    "rabonnîtes": ("rabonnir",),
    "rabonnit": ("rabonnir",),
    "rabonnît": ("rabonnir",),
    "rabougrie": ("rabougrir",),
    "rabougries": ("rabougrir",),
    "rabougri": ("rabougrir",),
    "rabougrîmes": ("rabougrir",),
    "rabougrira": ("rabougrir",),
    "rabougriraient": ("rabougrir",),
    "rabougrirai": ("rabougrir",),
    "rabougrirais": ("rabougrir",),
    "rabougrirait": ("rabougrir",),
    "rabougriras": ("rabougrir",),
    "rabougrirent": ("rabougrir",),
    "rabougrirez": ("rabougrir",),
    "rabougririez": ("rabougrir",),
    "rabougririons": ("rabougrir",),
    "rabougrirons": ("rabougrir",),
    "rabougriront": ("rabougrir",),
    "rabougris": ("rabougrir",),
    "rabougrissaient": ("rabougrir",),
    "rabougrissais": ("rabougrir",),
    "rabougrissait": ("rabougrir",),
    "rabougrissant": ("rabougrir",),
    "rabougrissent": ("rabougrir",),
    "rabougrisse": ("rabougrir",),
    "rabougrisses": ("rabougrir",),
    "rabougrissez": ("rabougrir",),
    "rabougrissiez": ("rabougrir",),
    "rabougrissions": ("rabougrir",),
    "rabougrissons": ("rabougrir",),
    "rabougrîtes": ("rabougrir",),
    "rabougrit": ("rabougrir",),
    "rabougrît": ("rabougrir",),
    "raboutie": ("raboutir",),
    "rabouties": ("raboutir",),
    "rabouti": ("raboutir",),
    "raboutîmes": ("raboutir",),
    "raboutira": ("raboutir",),
    "raboutiraient": ("raboutir",),
    "raboutirai": ("raboutir",),
    "raboutirais": ("raboutir",),
    "raboutirait": ("raboutir",),
    "raboutiras": ("raboutir",),
    "raboutirent": ("raboutir",),
    "raboutirez": ("raboutir",),
    "raboutiriez": ("raboutir",),
    "raboutirions": ("raboutir",),
    "raboutirons": ("raboutir",),
    "raboutiront": ("raboutir",),
    "raboutis": ("raboutir",),
    "raboutissaient": ("raboutir",),
    "raboutissais": ("raboutir",),
    "raboutissait": ("raboutir",),
    "raboutissant": ("raboutir",),
    "raboutissent": ("raboutir",),
    "raboutisse": ("raboutir",),
    "raboutisses": ("raboutir",),
    "raboutissez": ("raboutir",),
    "raboutissiez": ("raboutir",),
    "raboutissions": ("raboutir",),
    "raboutissons": ("raboutir",),
    "raboutîtes": ("raboutir",),
    "raboutit": ("raboutir",),
    "raboutît": ("raboutir",),
    "raccourcie": ("raccourcir",),
    "raccourcies": ("raccourcir",),
    "raccourci": ("raccourcir",),
    "raccourcîmes": ("raccourcir",),
    "raccourcira": ("raccourcir",),
    "raccourciraient": ("raccourcir",),
    "raccourcirai": ("raccourcir",),
    "raccourcirais": ("raccourcir",),
    "raccourcirait": ("raccourcir",),
    "raccourciras": ("raccourcir",),
    "raccourcirent": ("raccourcir",),
    "raccourcirez": ("raccourcir",),
    "raccourciriez": ("raccourcir",),
    "raccourcirions": ("raccourcir",),
    "raccourcirons": ("raccourcir",),
    "raccourciront": ("raccourcir",),
    "raccourcis": ("raccourcir",),
    "raccourcissaient": ("raccourcir",),
    "raccourcissais": ("raccourcir",),
    "raccourcissait": ("raccourcir",),
    "raccourcissant": ("raccourcir",),
    "raccourcissent": ("raccourcir",),
    "raccourcisse": ("raccourcir",),
    "raccourcisses": ("raccourcir",),
    "raccourcissez": ("raccourcir",),
    "raccourcissiez": ("raccourcir",),
    "raccourcissions": ("raccourcir",),
    "raccourcissons": ("raccourcir",),
    "raccourcîtes": ("raccourcir",),
    "raccourcit": ("raccourcir",),
    "raccourcît": ("raccourcir",),
    "raccouraient": ("raccourir",),
    "raccourais": ("raccourir",),
    "raccourait": ("raccourir",),
    "raccourant": ("raccourir",),
    "raccourent": ("raccourir",),
    "raccoure": ("raccourir",),
    "raccoures": ("raccourir",),
    "raccourez": ("raccourir",),
    "raccouriez": ("raccourir",),
    "raccourions": ("raccourir",),
    "raccourons": ("raccourir",),
    "raccourra": ("raccourir",),
    "raccourraient": ("raccourir",),
    "raccourrai": ("raccourir",),
    "raccourrais": ("raccourir",),
    "raccourrait": ("raccourir",),
    "raccourras": ("raccourir",),
    "raccourrez": ("raccourir",),
    "raccourriez": ("raccourir",),
    "raccourrions": ("raccourir",),
    "raccourrons": ("raccourir",),
    "raccourront": ("raccourir",),
    "raccours": ("raccourir",),
    "raccourt": ("raccourir",),
    "raccouru": ("raccourir",),
    "raccourûmes": ("raccourir",),
    "raccoururent": ("raccourir",),
    "raccourus": ("raccourir",),
    "raccourussent": ("raccourir",),
    "raccourusses": ("raccourir",),
    "raccourusse": ("raccourir",),
    "raccourussiez": ("raccourir",),
    "raccourussions": ("raccourir",),
    "raccourûtes": ("raccourir",),
    "raccourut": ("raccourir",),
    "raccourût": ("raccourir",),
    "rachetaient": ("racheter",),
    "rachetai": ("racheter",),
    "rachetais": ("racheter",),
    "rachetait": ("racheter",),
    "racheta": ("racheter",),
    "rachetâmes": ("racheter",),
    "rachetant": ("racheter",),
    "rachetas": ("racheter",),
    "rachetassent": ("racheter",),
    "rachetasses": ("racheter",),
    "rachetasse": ("racheter",),
    "rachetassiez": ("racheter",),
    "rachetassions": ("racheter",),
    "rachetâtes": ("racheter",),
    "rachetât": ("racheter",),
    "rachetée": ("racheter",),
    "rachetées": ("racheter",),
    "racheté": ("racheter",),
    "rachetent": ("racheter",),
    "rachètent": ("racheter",),
    "rachete": ("racheter",),
    "rachète": ("racheter",),
    "rachetera": ("racheter",),
    "rachètera": ("racheter",),
    "racheteraient": ("racheter",),
    "rachèteraient": ("racheter",),
    "racheterai": ("racheter",),
    "rachèterai": ("racheter",),
    "racheterais": ("racheter",),
    "rachèterais": ("racheter",),
    "racheterait": ("racheter",),
    "rachèterait": ("racheter",),
    "racheteras": ("racheter",),
    "rachèteras": ("racheter",),
    "rachetèrent": ("racheter",),
    "racheterez": ("racheter",),
    "rachèterez": ("racheter",),
    "racheteriez": ("racheter",),
    "rachèteriez": ("racheter",),
    "racheterions": ("racheter",),
    "rachèterions": ("racheter",),
    "racheterons": ("racheter",),
    "rachèterons": ("racheter",),
    "racheteront": ("racheter",),
    "rachèteront": ("racheter",),
    "rachetés": ("racheter",),
    "rachetes": ("racheter",),
    "rachètes": ("racheter",),
    "rachetez": ("racheter",),
    "rachetiez": ("racheter",),
    "rachetions": ("racheter",),
    "rachetons": ("racheter",),
    "rachevaient": ("rachever",),
    "rachevai": ("rachever",),
    "rachevais": ("rachever",),
    "rachevait": ("rachever",),
    "racheva": ("rachever",),
    "rachevâmes": ("rachever",),
    "rachevant": ("rachever",),
    "rachevas": ("rachever",),
    "rachevassent": ("rachever",),
    "rachevasses": ("rachever",),
    "rachevasse": ("rachever",),
    "rachevassiez": ("rachever",),
    "rachevassions": ("rachever",),
    "rachevâtes": ("rachever",),
    "rachevât": ("rachever",),
    "rachevée": ("rachever",),
    "rachevées": ("rachever",),
    "rachevé": ("rachever",),
    "rachèvent": ("rachever",),
    "rachève": ("rachever",),
    "rachèvera": ("rachever",),
    "rachèveraient": ("rachever",),
    "rachèverai": ("rachever",),
    "rachèverais": ("rachever",),
    "rachèverait": ("rachever",),
    "rachèveras": ("rachever",),
    "rachevèrent": ("rachever",),
    "rachèverez": ("rachever",),
    "rachèveriez": ("rachever",),
    "rachèverions": ("rachever",),
    "rachèverons": ("rachever",),
    "rachèveront": ("rachever",),
    "rachevés": ("rachever",),
    "rachèves": ("rachever",),
    "rachevez": ("rachever",),
    "racheviez": ("rachever",),
    "rachevions": ("rachever",),
    "rachevons": ("rachever",),
    "racornie": ("racornir",),
    "racornies": ("racornir",),
    "racorni": ("racornir",),
    "racornîmes": ("racornir",),
    "racornira": ("racornir",),
    "racorniraient": ("racornir",),
    "racornirai": ("racornir",),
    "racornirais": ("racornir",),
    "racornirait": ("racornir",),
    "racorniras": ("racornir",),
    "racornirent": ("racornir",),
    "racornirez": ("racornir",),
    "racorniriez": ("racornir",),
    "racornirions": ("racornir",),
    "racornirons": ("racornir",),
    "racorniront": ("racornir",),
    "racornis": ("racornir",),
    "racornissaient": ("racornir",),
    "racornissais": ("racornir",),
    "racornissait": ("racornir",),
    "racornissant": ("racornir",),
    "racornissent": ("racornir",),
    "racornisse": ("racornir",),
    "racornisses": ("racornir",),
    "racornissez": ("racornir",),
    "racornissiez": ("racornir",),
    "racornissions": ("racornir",),
    "racornissons": ("racornir",),
    "racornîtes": ("racornir",),
    "racornit": ("racornir",),
    "racornît": ("racornir",),
    "radiaient": ("radier",),
    "radiai": ("radier",),
    "radiais": ("radier",),
    "radiait": ("radier",),
    "radia": ("radier",),
    "radiâmes": ("radier",),
    "radiant": ("radier",),
    "radias": ("radier",),
    "radiassent": ("radier",),
    "radiasses": ("radier",),
    "radiasse": ("radier",),
    "radiassiez": ("radier",),
    "radiassions": ("radier",),
    "radiâtes": ("radier",),
    "radiât": ("radier",),
    "radiée": ("radier",),
    "radiées": ("radier",),
    "radié": ("radier",),
    "radient": ("radier",),
    "radie": ("radier",),
    "radiera": ("radier",),
    "radieraient": ("radier",),
    "radierai": ("radier",),
    "radierais": ("radier",),
    "radierait": ("radier",),
    "radieras": ("radier",),
    "radièrent": ("radier",),
    "radierez": ("radier",),
    "radieriez": ("radier",),
    "radierions": ("radier",),
    "radierons": ("radier",),
    "radieront": ("radier",),
    "radiés": ("radier",),
    "radies": ("radier",),
    "radiez": ("radier",),
    "radiiez": ("radier",),
    "radiions": ("radier",),
    "radions": ("radier",),
    "radiographiaient": ("radiographier",),
    "radiographiai": ("radiographier",),
    "radiographiais": ("radiographier",),
    "radiographiait": ("radiographier",),
    "radiographia": ("radiographier",),
    "radiographiâmes": ("radiographier",),
    "radiographiant": ("radiographier",),
    "radiographias": ("radiographier",),
    "radiographiassent": ("radiographier",),
    "radiographiasses": ("radiographier",),
    "radiographiasse": ("radiographier",),
    "radiographiassiez": ("radiographier",),
    "radiographiassions": ("radiographier",),
    "radiographiâtes": ("radiographier",),
    "radiographiât": ("radiographier",),
    "radiographiée": ("radiographier",),
    "radiographiées": ("radiographier",),
    "radiographié": ("radiographier",),
    "radiographient": ("radiographier",),
    "radiographie": ("radiographier",),
    "radiographiera": ("radiographier",),
    "radiographieraient": ("radiographier",),
    "radiographierai": ("radiographier",),
    "radiographierais": ("radiographier",),
    "radiographierait": ("radiographier",),
    "radiographieras": ("radiographier",),
    "radiographièrent": ("radiographier",),
    "radiographierez": ("radiographier",),
    "radiographieriez": ("radiographier",),
    "radiographierions": ("radiographier",),
    "radiographierons": ("radiographier",),
    "radiographieront": ("radiographier",),
    "radiographiés": ("radiographier",),
    "radiographies": ("radiographier",),
    "radiographiez": ("radiographier",),
    "radiographiiez": ("radiographier",),
    "radiographiions": ("radiographier",),
    "radiographions": ("radiographier",),
    "radiorepéraient": ("radiorepérer",),
    "radiorepérai": ("radiorepérer",),
    "radiorepérais": ("radiorepérer",),
    "radiorepérait": ("radiorepérer",),
    "radiorepéra": ("radiorepérer",),
    "radiorepérâmes": ("radiorepérer",),
    "radiorepérant": ("radiorepérer",),
    "radiorepéras": ("radiorepérer",),
    "radiorepérassent": ("radiorepérer",),
    "radiorepérasses": ("radiorepérer",),
    "radiorepérasse": ("radiorepérer",),
    "radiorepérassiez": ("radiorepérer",),
    "radiorepérassions": ("radiorepérer",),
    "radiorepérâtes": ("radiorepérer",),
    "radiorepérât": ("radiorepérer",),
    "radiorepérée": ("radiorepérer",),
    "radiorepérées": ("radiorepérer",),
    "radiorepéré": ("radiorepérer",),
    "radiorepèrent": ("radiorepérer",),
    "radiorepère": ("radiorepérer",),
    "radiorepérera": ("radiorepérer",),
    "radiorepéreraient": ("radiorepérer",),
    "radiorepérerai": ("radiorepérer",),
    "radiorepérerais": ("radiorepérer",),
    "radiorepérerait": ("radiorepérer",),
    "radiorepéreras": ("radiorepérer",),
    "radiorepérèrent": ("radiorepérer",),
    "radiorepérerez": ("radiorepérer",),
    "radiorepéreriez": ("radiorepérer",),
    "radiorepérerions": ("radiorepérer",),
    "radiorepérerons": ("radiorepérer",),
    "radiorepéreront": ("radiorepérer",),
    "radiorepérés": ("radiorepérer",),
    "radiorepères": ("radiorepérer",),
    "radiorepérez": ("radiorepérer",),
    "radiorepériez": ("radiorepérer",),
    "radiorepérions": ("radiorepérer",),
    "radiorepérons": ("radiorepérer",),
    "radioscopiaient": ("radioscopier",),
    "radioscopiai": ("radioscopier",),
    "radioscopiais": ("radioscopier",),
    "radioscopiait": ("radioscopier",),
    "radioscopia": ("radioscopier",),
    "radioscopiâmes": ("radioscopier",),
    "radioscopiant": ("radioscopier",),
    "radioscopias": ("radioscopier",),
    "radioscopiassent": ("radioscopier",),
    "radioscopiasses": ("radioscopier",),
    "radioscopiasse": ("radioscopier",),
    "radioscopiassiez": ("radioscopier",),
    "radioscopiassions": ("radioscopier",),
    "radioscopiâtes": ("radioscopier",),
    "radioscopiât": ("radioscopier",),
    "radioscopiée": ("radioscopier",),
    "radioscopiées": ("radioscopier",),
    "radioscopié": ("radioscopier",),
    "radioscopient": ("radioscopier",),
    "radioscopie": ("radioscopier",),
    "radioscopiera": ("radioscopier",),
    "radioscopieraient": ("radioscopier",),
    "radioscopierai": ("radioscopier",),
    "radioscopierais": ("radioscopier",),
    "radioscopierait": ("radioscopier",),
    "radioscopieras": ("radioscopier",),
    "radioscopièrent": ("radioscopier",),
    "radioscopierez": ("radioscopier",),
    "radioscopieriez": ("radioscopier",),
    "radioscopierions": ("radioscopier",),
    "radioscopierons": ("radioscopier",),
    "radioscopieront": ("radioscopier",),
    "radioscopiés": ("radioscopier",),
    "radioscopies": ("radioscopier",),
    "radioscopiez": ("radioscopier",),
    "radioscopiiez": ("radioscopier",),
    "radioscopiions": ("radioscopier",),
    "radioscopions": ("radioscopier",),
    "radiotélégraphiaient": ("radiotélégraphier",),
    "radiotélégraphiai": ("radiotélégraphier",),
    "radiotélégraphiais": ("radiotélégraphier",),
    "radiotélégraphiait": ("radiotélégraphier",),
    "radiotélégraphia": ("radiotélégraphier",),
    "radiotélégraphiâmes": ("radiotélégraphier",),
    "radiotélégraphiant": ("radiotélégraphier",),
    "radiotélégraphias": ("radiotélégraphier",),
    "radiotélégraphiassent": ("radiotélégraphier",),
    "radiotélégraphiasses": ("radiotélégraphier",),
    "radiotélégraphiasse": ("radiotélégraphier",),
    "radiotélégraphiassiez": ("radiotélégraphier",),
    "radiotélégraphiassions": ("radiotélégraphier",),
    "radiotélégraphiâtes": ("radiotélégraphier",),
    "radiotélégraphiât": ("radiotélégraphier",),
    "radiotélégraphiée": ("radiotélégraphier",),
    "radiotélégraphiées": ("radiotélégraphier",),
    "radiotélégraphié": ("radiotélégraphier",),
    "radiotélégraphient": ("radiotélégraphier",),
    "radiotélégraphie": ("radiotélégraphier",),
    "radiotélégraphiera": ("radiotélégraphier",),
    "radiotélégraphieraient": ("radiotélégraphier",),
    "radiotélégraphierai": ("radiotélégraphier",),
    "radiotélégraphierais": ("radiotélégraphier",),
    "radiotélégraphierait": ("radiotélégraphier",),
    "radiotélégraphieras": ("radiotélégraphier",),
    "radiotélégraphièrent": ("radiotélégraphier",),
    "radiotélégraphierez": ("radiotélégraphier",),
    "radiotélégraphieriez": ("radiotélégraphier",),
    "radiotélégraphierions": ("radiotélégraphier",),
    "radiotélégraphierons": ("radiotélégraphier",),
    "radiotélégraphieront": ("radiotélégraphier",),
    "radiotélégraphiés": ("radiotélégraphier",),
    "radiotélégraphies": ("radiotélégraphier",),
    "radiotélégraphiez": ("radiotélégraphier",),
    "radiotélégraphiiez": ("radiotélégraphier",),
    "radiotélégraphiions": ("radiotélégraphier",),
    "radiotélégraphions": ("radiotélégraphier",),
    "radoucie": ("radoucir",),
    "radoucies": ("radoucir",),
    "radouci": ("radoucir",),
    "radoucîmes": ("radoucir",),
    "radoucira": ("radoucir",),
    "radouciraient": ("radoucir",),
    "radoucirai": ("radoucir",),
    "radoucirais": ("radoucir",),
    "radoucirait": ("radoucir",),
    "radouciras": ("radoucir",),
    "radoucirent": ("radoucir",),
    "radoucirez": ("radoucir",),
    "radouciriez": ("radoucir",),
    "radoucirions": ("radoucir",),
    "radoucirons": ("radoucir",),
    "radouciront": ("radoucir",),
    "radoucis": ("radoucir",),
    "radoucissaient": ("radoucir",),
    "radoucissais": ("radoucir",),
    "radoucissait": ("radoucir",),
    "radoucissant": ("radoucir",),
    "radoucissent": ("radoucir",),
    "radoucisse": ("radoucir",),
    "radoucisses": ("radoucir",),
    "radoucissez": ("radoucir",),
    "radoucissiez": ("radoucir",),
    "radoucissions": ("radoucir",),
    "radoucissons": ("radoucir",),
    "radoucîtes": ("radoucir",),
    "radoucit": ("radoucir",),
    "radoucît": ("radoucir",),
    "raffermie": ("raffermir",),
    "raffermies": ("raffermir",),
    "raffermi": ("raffermir",),
    "raffermîmes": ("raffermir",),
    "raffermira": ("raffermir",),
    "raffermiraient": ("raffermir",),
    "raffermirai": ("raffermir",),
    "raffermirais": ("raffermir",),
    "raffermirait": ("raffermir",),
    "raffermiras": ("raffermir",),
    "raffermirent": ("raffermir",),
    "raffermirez": ("raffermir",),
    "raffermiriez": ("raffermir",),
    "raffermirions": ("raffermir",),
    "raffermirons": ("raffermir",),
    "raffermiront": ("raffermir",),
    "raffermis": ("raffermir",),
    "raffermissaient": ("raffermir",),
    "raffermissais": ("raffermir",),
    "raffermissait": ("raffermir",),
    "raffermissant": ("raffermir",),
    "raffermissent": ("raffermir",),
    "raffermisse": ("raffermir",),
    "raffermisses": ("raffermir",),
    "raffermissez": ("raffermir",),
    "raffermissiez": ("raffermir",),
    "raffermissions": ("raffermir",),
    "raffermissons": ("raffermir",),
    "raffermîtes": ("raffermir",),
    "raffermit": ("raffermir",),
    "raffermît": ("raffermir",),
    "rafraîchie": ("rafraîchir",),
    "rafraîchies": ("rafraîchir",),
    "rafraîchi": ("rafraîchir",),
    "rafraîchîmes": ("rafraîchir",),
    "rafraîchira": ("rafraîchir",),
    "rafraîchiraient": ("rafraîchir",),
    "rafraîchirai": ("rafraîchir",),
    "rafraîchirais": ("rafraîchir",),
    "rafraîchirait": ("rafraîchir",),
    "rafraîchiras": ("rafraîchir",),
    "rafraîchirent": ("rafraîchir",),
    "rafraîchirez": ("rafraîchir",),
    "rafraîchiriez": ("rafraîchir",),
    "rafraîchirions": ("rafraîchir",),
    "rafraîchirons": ("rafraîchir",),
    "rafraîchiront": ("rafraîchir",),
    "rafraîchis": ("rafraîchir",),
    "rafraîchissaient": ("rafraîchir",),
    "rafraîchissais": ("rafraîchir",),
    "rafraîchissait": ("rafraîchir",),
    "rafraîchissant": ("rafraîchir",),
    "rafraîchissent": ("rafraîchir",),
    "rafraîchisse": ("rafraîchir",),
    "rafraîchisses": ("rafraîchir",),
    "rafraîchissez": ("rafraîchir",),
    "rafraîchissiez": ("rafraîchir",),
    "rafraîchissions": ("rafraîchir",),
    "rafraîchissons": ("rafraîchir",),
    "rafraîchîtes": ("rafraîchir",),
    "rafraîchit": ("rafraîchir",),
    "rafraîchît": ("rafraîchir",),
    "ragaillardie": ("ragaillardir",),
    "ragaillardies": ("ragaillardir",),
    "ragaillardi": ("ragaillardir",),
    "ragaillardîmes": ("ragaillardir",),
    "ragaillardira": ("ragaillardir",),
    "ragaillardiraient": ("ragaillardir",),
    "ragaillardirai": ("ragaillardir",),
    "ragaillardirais": ("ragaillardir",),
    "ragaillardirait": ("ragaillardir",),
    "ragaillardiras": ("ragaillardir",),
    "ragaillardirent": ("ragaillardir",),
    "ragaillardirez": ("ragaillardir",),
    "ragaillardiriez": ("ragaillardir",),
    "ragaillardirions": ("ragaillardir",),
    "ragaillardirons": ("ragaillardir",),
    "ragaillardiront": ("ragaillardir",),
    "ragaillardis": ("ragaillardir",),
    "ragaillardissaient": ("ragaillardir",),
    "ragaillardissais": ("ragaillardir",),
    "ragaillardissait": ("ragaillardir",),
    "ragaillardissant": ("ragaillardir",),
    "ragaillardissent": ("ragaillardir",),
    "ragaillardisse": ("ragaillardir",),
    "ragaillardisses": ("ragaillardir",),
    "ragaillardissez": ("ragaillardir",),
    "ragaillardissiez": ("ragaillardir",),
    "ragaillardissions": ("ragaillardir",),
    "ragaillardissons": ("ragaillardir",),
    "ragaillardîtes": ("ragaillardir",),
    "ragaillardit": ("ragaillardir",),
    "ragaillardît": ("ragaillardir",),
    "ragençaient": ("ragencer",),
    "ragençai": ("ragencer",),
    "ragençais": ("ragencer",),
    "ragençait": ("ragencer",),
    "ragença": ("ragencer",),
    "ragençâmes": ("ragencer",),
    "ragençant": ("ragencer",),
    "ragenças": ("ragencer",),
    "ragençassent": ("ragencer",),
    "ragençasses": ("ragencer",),
    "ragençasse": ("ragencer",),
    "ragençassiez": ("ragencer",),
    "ragençassions": ("ragencer",),
    "ragençâtes": ("ragencer",),
    "ragençât": ("ragencer",),
    "ragencée": ("ragencer",),
    "ragencées": ("ragencer",),
    "ragencé": ("ragencer",),
    "ragencent": ("ragencer",),
    "ragence": ("ragencer",),
    "ragencera": ("ragencer",),
    "ragenceraient": ("ragencer",),
    "ragencerai": ("ragencer",),
    "ragencerais": ("ragencer",),
    "ragencerait": ("ragencer",),
    "ragenceras": ("ragencer",),
    "ragencèrent": ("ragencer",),
    "ragencerez": ("ragencer",),
    "ragenceriez": ("ragencer",),
    "ragencerions": ("ragencer",),
    "ragencerons": ("ragencer",),
    "ragenceront": ("ragencer",),
    "ragencés": ("ragencer",),
    "ragences": ("ragencer",),
    "ragencez": ("ragencer",),
    "ragenciez": ("ragencer",),
    "ragencions": ("ragencer",),
    "ragençons": ("ragencer",),
    "rageaient": ("rager",),
    "rageai": ("rager",),
    "rageais": ("rager",),
    "rageait": ("rager",),
    "ragea": ("rager",),
    "rageâmes": ("rager",),
    "rageant": ("rager",),
    "rageas": ("rager",),
    "rageassent": ("rager",),
    "rageasses": ("rager",),
    "rageasse": ("rager",),
    "rageassiez": ("rager",),
    "rageassions": ("rager",),
    "rageâtes": ("rager",),
    "rageât": ("rager",),
    "ragé": ("rager",),
    "ragent": ("rager",),
    "rageons": ("rager",),
    "rage": ("rager",),
    "ragera": ("rager",),
    "rageraient": ("rager",),
    "ragerai": ("rager",),
    "ragerais": ("rager",),
    "ragerait": ("rager",),
    "rageras": ("rager",),
    "ragèrent": ("rager",),
    "ragerez": ("rager",),
    "rageriez": ("rager",),
    "ragerions": ("rager",),
    "ragerons": ("rager",),
    "rageront": ("rager",),
    "rages": ("rager",),
    "ragez": ("rager",),
    "ragiez": ("rager",),
    "ragions": ("rager",),
    "ragrandie": ("ragrandir",),
    "ragrandies": ("ragrandir",),
    "ragrandi": ("ragrandir",),
    "ragrandîmes": ("ragrandir",),
    "ragrandira": ("ragrandir",),
    "ragrandiraient": ("ragrandir",),
    "ragrandirai": ("ragrandir",),
    "ragrandirais": ("ragrandir",),
    "ragrandirait": ("ragrandir",),
    "ragrandiras": ("ragrandir",),
    "ragrandirent": ("ragrandir",),
    "ragrandirez": ("ragrandir",),
    "ragrandiriez": ("ragrandir",),
    "ragrandirions": ("ragrandir",),
    "ragrandirons": ("ragrandir",),
    "ragrandiront": ("ragrandir",),
    "ragrandis": ("ragrandir",),
    "ragrandissaient": ("ragrandir",),
    "ragrandissais": ("ragrandir",),
    "ragrandissait": ("ragrandir",),
    "ragrandissant": ("ragrandir",),
    "ragrandissent": ("ragrandir",),
    "ragrandisse": ("ragrandir",),
    "ragrandisses": ("ragrandir",),
    "ragrandissez": ("ragrandir",),
    "ragrandissiez": ("ragrandir",),
    "ragrandissions": ("ragrandir",),
    "ragrandissons": ("ragrandir",),
    "ragrandîtes": ("ragrandir",),
    "ragrandit": ("ragrandir",),
    "ragrandît": ("ragrandir",),
    "ragréaient": ("ragréer",),
    "ragréai": ("ragréer",),
    "ragréais": ("ragréer",),
    "ragréait": ("ragréer",),
    "ragréa": ("ragréer",),
    "ragréâmes": ("ragréer",),
    "ragréant": ("ragréer",),
    "ragréas": ("ragréer",),
    "ragréassent": ("ragréer",),
    "ragréasses": ("ragréer",),
    "ragréasse": ("ragréer",),
    "ragréassiez": ("ragréer",),
    "ragréassions": ("ragréer",),
    "ragréâtes": ("ragréer",),
    "ragréât": ("ragréer",),
    "ragréée": ("ragréer",),
    "ragréées": ("ragréer",),
    "ragréé": ("ragréer",),
    "ragréent": ("ragréer",),
    "ragrée": ("ragréer",),
    "ragréera": ("ragréer",),
    "ragréeraient": ("ragréer",),
    "ragréerai": ("ragréer",),
    "ragréerais": ("ragréer",),
    "ragréerait": ("ragréer",),
    "ragréeras": ("ragréer",),
    "ragréèrent": ("ragréer",),
    "ragréerez": ("ragréer",),
    "ragréeriez": ("ragréer",),
    "ragréerions": ("ragréer",),
    "ragréerons": ("ragréer",),
    "ragréeront": ("ragréer",),
    "ragréés": ("ragréer",),
    "ragrées": ("ragréer",),
    "ragréez": ("ragréer",),
    "ragréiez": ("ragréer",),
    "ragréions": ("ragréer",),
    "ragréons": ("ragréer",),
    "raidie": ("raidir",),
    "raidies": ("raidir",),
    "raidi": ("raidir",),
    "raidîmes": ("raidir",),
    "raidira": ("raidir",),
    "raidiraient": ("raidir",),
    "raidirai": ("raidir",),
    "raidirais": ("raidir",),
    "raidirait": ("raidir",),
    "raidiras": ("raidir",),
    "raidirent": ("raidir",),
    "raidirez": ("raidir",),
    "raidiriez": ("raidir",),
    "raidirions": ("raidir",),
    "raidirons": ("raidir",),
    "raidiront": ("raidir",),
    "raidis": ("raidir",),
    "raidissaient": ("raidir",),
    "raidissais": ("raidir",),
    "raidissait": ("raidir",),
    "raidissant": ("raidir",),
    "raidissent": ("raidir",),
    "raidisse": ("raidir",),
    "raidisses": ("raidir",),
    "raidissez": ("raidir",),
    "raidissiez": ("raidir",),
    "raidissions": ("raidir",),
    "raidissons": ("raidir",),
    "raidîtes": ("raidir",),
    "raidit": ("raidir",),
    "raidît": ("raidir",),
    "rainetaient": ("raineter",),
    "rainetai": ("raineter",),
    "rainetais": ("raineter",),
    "rainetait": ("raineter",),
    "raineta": ("raineter",),
    "rainetâmes": ("raineter",),
    "rainetant": ("raineter",),
    "rainetas": ("raineter",),
    "rainetassent": ("raineter",),
    "rainetasses": ("raineter",),
    "rainetasse": ("raineter",),
    "rainetassiez": ("raineter",),
    "rainetassions": ("raineter",),
    "rainetâtes": ("raineter",),
    "rainetât": ("raineter",),
    "rainetée": ("raineter",),
    "rainetées": ("raineter",),
    "raineté": ("raineter",),
    "rainetèrent": ("raineter",),
    "rainetés": ("raineter",),
    "rainetez": ("raineter",),
    "rainetiez": ("raineter",),
    "rainetions": ("raineter",),
    "rainetons": ("raineter",),
    "rainettent": ("raineter",),
    "rainette": ("raineter",),
    "rainettera": ("raineter",),
    "rainetteraient": ("raineter",),
    "rainetterai": ("raineter",),
    "rainetterais": ("raineter",),
    "rainetterait": ("raineter",),
    "rainetteras": ("raineter",),
    "rainetterez": ("raineter",),
    "rainetteriez": ("raineter",),
    "rainetterions": ("raineter",),
    "rainetterons": ("raineter",),
    "rainetteront": ("raineter",),
    "rainettes": ("raineter",),
    "raient": ("rayer",),
    "raie": ("rayer",),
    "raies": ("rayer",),
    "raira": ("raire",),
    "rairaient": ("raire",),
    "rairai": ("raire",),
    "rairais": ("raire",),
    "rairait": ("raire",),
    "rairas": ("raire",),
    "rairez": ("raire",),
    "rairiez": ("raire",),
    "rairions": ("raire",),
    "rairons": ("raire",),
    "rairont": ("raire",),
    "rais": ("raire",),
    "raite": ("raire",),
    "raites": ("raire",),
    "rait": ("raire",),
    "raits": ("raire",),
    "rayaient": ("rayer",),
    "rayais": ("rayer",),
    "rayait": ("rayer",),
    "rayant": ("rayer",),
    "rayez": ("rayer",),
    "rayiez": ("rayer",),
    "rayions": ("rayer",),
    "rayons": ("rayer",),
    "rajeunie": ("rajeunir",),
    "rajeunies": ("rajeunir",),
    "rajeuni": ("rajeunir",),
    "rajeunîmes": ("rajeunir",),
    "rajeunira": ("rajeunir",),
    "rajeuniraient": ("rajeunir",),
    "rajeunirai": ("rajeunir",),
    "rajeunirais": ("rajeunir",),
    "rajeunirait": ("rajeunir",),
    "rajeuniras": ("rajeunir",),
    "rajeunirent": ("rajeunir",),
    "rajeunirez": ("rajeunir",),
    "rajeuniriez": ("rajeunir",),
    "rajeunirions": ("rajeunir",),
    "rajeunirons": ("rajeunir",),
    "rajeuniront": ("rajeunir",),
    "rajeunis": ("rajeunir",),
    "rajeunissaient": ("rajeunir",),
    "rajeunissais": ("rajeunir",),
    "rajeunissait": ("rajeunir",),
    "rajeunissant": ("rajeunir",),
    "rajeunissent": ("rajeunir",),
    "rajeunisse": ("rajeunir",),
    "rajeunisses": ("rajeunir",),
    "rajeunissez": ("rajeunir",),
    "rajeunissiez": ("rajeunir",),
    "rajeunissions": ("rajeunir",),
    "rajeunissons": ("rajeunir",),
    "rajeunîtes": ("rajeunir",),
    "rajeunit": ("rajeunir",),
    "rajeunît": ("rajeunir",),
    "ralentie": ("ralentir",),
    "ralenties": ("ralentir",),
    "ralenti": ("ralentir",),
    "ralentîmes": ("ralentir",),
    "ralentira": ("ralentir",),
    "ralentiraient": ("ralentir",),
    "ralentirai": ("ralentir",),
    "ralentirais": ("ralentir",),
    "ralentirait": ("ralentir",),
    "ralentiras": ("ralentir",),
    "ralentirent": ("ralentir",),
    "ralentirez": ("ralentir",),
    "ralentiriez": ("ralentir",),
    "ralentirions": ("ralentir",),
    "ralentirons": ("ralentir",),
    "ralentiront": ("ralentir",),
    "ralentis": ("ralentir",),
    "ralentissaient": ("ralentir",),
    "ralentissais": ("ralentir",),
    "ralentissait": ("ralentir",),
    "ralentissant": ("ralentir",),
    "ralentissent": ("ralentir",),
    "ralentisse": ("ralentir",),
    "ralentisses": ("ralentir",),
    "ralentissez": ("ralentir",),
    "ralentissiez": ("ralentir",),
    "ralentissions": ("ralentir",),
    "ralentissons": ("ralentir",),
    "ralentîtes": ("ralentir",),
    "ralentit": ("ralentir",),
    "ralentît": ("ralentir",),
    "rallégeaient": ("ralléger",),
    "rallégeai": ("ralléger",),
    "rallégeais": ("ralléger",),
    "rallégeait": ("ralléger",),
    "rallégea": ("ralléger",),
    "rallégeâmes": ("ralléger",),
    "rallégeant": ("ralléger",),
    "rallégeas": ("ralléger",),
    "rallégeassent": ("ralléger",),
    "rallégeasses": ("ralléger",),
    "rallégeasse": ("ralléger",),
    "rallégeassiez": ("ralléger",),
    "rallégeassions": ("ralléger",),
    "rallégeâtes": ("ralléger",),
    "rallégeât": ("ralléger",),
    "rallégée": ("ralléger",),
    "rallégées": ("ralléger",),
    "rallégé": ("ralléger",),
    "rallègent": ("ralléger",),
    "rallégeons": ("ralléger",),
    "rallège": ("ralléger",),
    "rallégera": ("ralléger",),
    "rallégeraient": ("ralléger",),
    "rallégerai": ("ralléger",),
    "rallégerais": ("ralléger",),
    "rallégerait": ("ralléger",),
    "rallégeras": ("ralléger",),
    "rallégèrent": ("ralléger",),
    "rallégerez": ("ralléger",),
    "rallégeriez": ("ralléger",),
    "rallégerions": ("ralléger",),
    "rallégerons": ("ralléger",),
    "rallégeront": ("ralléger",),
    "rallégés": ("ralléger",),
    "rallèges": ("ralléger",),
    "rallégez": ("ralléger",),
    "rallégiez": ("ralléger",),
    "rallégions": ("ralléger",),
    "ralliaient": ("rallier",),
    "ralliai": ("rallier",),
    "ralliais": ("rallier",),
    "ralliait": ("rallier",),
    "rallia": ("rallier",),
    "ralliâmes": ("rallier",),
    "ralliant": ("rallier",),
    "rallias": ("rallier",),
    "ralliassent": ("rallier",),
    "ralliasses": ("rallier",),
    "ralliasse": ("rallier",),
    "ralliassiez": ("rallier",),
    "ralliassions": ("rallier",),
    "ralliâtes": ("rallier",),
    "ralliât": ("rallier",),
    "ralliée": ("rallier",),
    "ralliées": ("rallier",),
    "rallié": ("rallier",),
    "rallient": ("rallier",),
    "rallie": ("rallier",),
    "ralliera": ("rallier",),
    "rallieraient": ("rallier",),
    "rallierai": ("rallier",),
    "rallierais": ("rallier",),
    "rallierait": ("rallier",),
    "rallieras": ("rallier",),
    "rallièrent": ("rallier",),
    "rallierez": ("rallier",),
    "rallieriez": ("rallier",),
    "rallierions": ("rallier",),
    "rallierons": ("rallier",),
    "rallieront": ("rallier",),
    "ralliés": ("rallier",),
    "rallies": ("rallier",),
    "ralliez": ("rallier",),
    "ralliiez": ("rallier",),
    "ralliions": ("rallier",),
    "rallions": ("rallier",),
    "rallongeaient": ("rallonger",),
    "rallongeai": ("rallonger",),
    "rallongeais": ("rallonger",),
    "rallongeait": ("rallonger",),
    "rallongea": ("rallonger",),
    "rallongeâmes": ("rallonger",),
    "rallongeant": ("rallonger",),
    "rallongeas": ("rallonger",),
    "rallongeassent": ("rallonger",),
    "rallongeasses": ("rallonger",),
    "rallongeasse": ("rallonger",),
    "rallongeassiez": ("rallonger",),
    "rallongeassions": ("rallonger",),
    "rallongeâtes": ("rallonger",),
    "rallongeât": ("rallonger",),
    "rallongée": ("rallonger",),
    "rallongées": ("rallonger",),
    "rallongé": ("rallonger",),
    "rallongent": ("rallonger",),
    "rallongeons": ("rallonger",),
    "rallonge": ("rallonger",),
    "rallongera": ("rallonger",),
    "rallongeraient": ("rallonger",),
    "rallongerai": ("rallonger",),
    "rallongerais": ("rallonger",),
    "rallongerait": ("rallonger",),
    "rallongeras": ("rallonger",),
    "rallongèrent": ("rallonger",),
    "rallongerez": ("rallonger",),
    "rallongeriez": ("rallonger",),
    "rallongerions": ("rallonger",),
    "rallongerons": ("rallonger",),
    "rallongeront": ("rallonger",),
    "rallongés": ("rallonger",),
    "rallonges": ("rallonger",),
    "rallongez": ("rallonger",),
    "rallongiez": ("rallonger",),
    "rallongions": ("rallonger",),
    "ramageaient": ("ramager",),
    "ramageai": ("ramager",),
    "ramageais": ("ramager",),
    "ramageait": ("ramager",),
    "ramagea": ("ramager",),
    "ramageâmes": ("ramager",),
    "ramageant": ("ramager",),
    "ramageas": ("ramager",),
    "ramageassent": ("ramager",),
    "ramageasses": ("ramager",),
    "ramageasse": ("ramager",),
    "ramageassiez": ("ramager",),
    "ramageassions": ("ramager",),
    "ramageâtes": ("ramager",),
    "ramageât": ("ramager",),
    "ramagée": ("ramager",),
    "ramagées": ("ramager",),
    "ramagé": ("ramager",),
    "ramagent": ("ramager",),
    "ramageons": ("ramager",),
    "ramage": ("ramager",),
    "ramagera": ("ramager",),
    "ramageraient": ("ramager",),
    "ramagerai": ("ramager",),
    "ramagerais": ("ramager",),
    "ramagerait": ("ramager",),
    "ramageras": ("ramager",),
    "ramagèrent": ("ramager",),
    "ramagerez": ("ramager",),
    "ramageriez": ("ramager",),
    "ramagerions": ("ramager",),
    "ramagerons": ("ramager",),
    "ramageront": ("ramager",),
    "ramagés": ("ramager",),
    "ramages": ("ramager",),
    "ramagez": ("ramager",),
    "ramagiez": ("ramager",),
    "ramagions": ("ramager",),
    "ramaigrie": ("ramaigrir",),
    "ramaigries": ("ramaigrir",),
    "ramaigri": ("ramaigrir",),
    "ramaigrîmes": ("ramaigrir",),
    "ramaigrira": ("ramaigrir",),
    "ramaigriraient": ("ramaigrir",),
    "ramaigrirai": ("ramaigrir",),
    "ramaigrirais": ("ramaigrir",),
    "ramaigrirait": ("ramaigrir",),
    "ramaigriras": ("ramaigrir",),
    "ramaigrirent": ("ramaigrir",),
    "ramaigrirez": ("ramaigrir",),
    "ramaigririez": ("ramaigrir",),
    "ramaigririons": ("ramaigrir",),
    "ramaigrirons": ("ramaigrir",),
    "ramaigriront": ("ramaigrir",),
    "ramaigris": ("ramaigrir",),
    "ramaigrissaient": ("ramaigrir",),
    "ramaigrissais": ("ramaigrir",),
    "ramaigrissait": ("ramaigrir",),
    "ramaigrissant": ("ramaigrir",),
    "ramaigrissent": ("ramaigrir",),
    "ramaigrisse": ("ramaigrir",),
    "ramaigrisses": ("ramaigrir",),
    "ramaigrissez": ("ramaigrir",),
    "ramaigrissiez": ("ramaigrir",),
    "ramaigrissions": ("ramaigrir",),
    "ramaigrissons": ("ramaigrir",),
    "ramaigrîtes": ("ramaigrir",),
    "ramaigrit": ("ramaigrir",),
    "ramaigrît": ("ramaigrir",),
    "ramassaient": ("ramasser",),
    "ramassai": ("ramasser",),
    "ramassais": ("ramasser",),
    "ramassait": ("ramasser",),
    "ramassa": ("ramasser",),
    "ramassâmes": ("ramasser",),
    "ramassant": ("ramasser",),
    "ramassas": ("ramasser",),
    "ramassassent": ("ramasser",),
    "ramassasses": ("ramasser",),
    "ramassasse": ("ramasser",),
    "ramassassiez": ("ramasser",),
    "ramassassions": ("ramasser",),
    "ramassâtes": ("ramasser",),
    "ramassât": ("ramasser",),
    "ramassée": ("ramasser",),
    "ramassées": ("ramasser",),
    "ramassé": ("ramasser",),
    "ramassent": ("ramasser",),
    "ramasse": ("ramasser",),
    "ramassera": ("ramasser",),
    "ramasseraient": ("ramasser",),
    "ramasserai": ("ramasser",),
    "ramasserais": ("ramasser",),
    "ramasserait": ("ramasser",),
    "ramasseras": ("ramasser",),
    "ramassèrent": ("ramasser",),
    "ramasserez": ("ramasser",),
    "ramasseriez": ("ramasser",),
    "ramasserions": ("ramasser",),
    "ramasserons": ("ramasser",),
    "ramasseront": ("ramasser",),
    "ramassés": ("ramasser",),
    "ramasses": ("ramasser",),
    "ramassez": ("ramasser",),
    "ramassiez": ("ramasser",),
    "ramassions": ("ramasser",),
    "ramassons": ("ramasser",),
    "ramenaient": ("ramener",),
    "ramenai": ("ramener",),
    "ramenais": ("ramener",),
    "ramenait": ("ramener",),
    "ramena": ("ramener",),
    "ramenâmes": ("ramener",),
    "ramenant": ("ramener",),
    "ramenas": ("ramener",),
    "ramenassent": ("ramener",),
    "ramenasses": ("ramener",),
    "ramenasse": ("ramener",),
    "ramenassiez": ("ramener",),
    "ramenassions": ("ramener",),
    "ramenâtes": ("ramener",),
    "ramenât": ("ramener",),
    "ramenée": ("ramener",),
    "ramenées": ("ramener",),
    "ramené": ("ramener",),
    "ramènent": ("ramener",),
    "ramène": ("ramener",),
    "ramènera": ("ramener",),
    "ramèneraient": ("ramener",),
    "ramènerai": ("ramener",),
    "ramènerais": ("ramener",),
    "ramènerait": ("ramener",),
    "ramèneras": ("ramener",),
    "ramenèrent": ("ramener",),
    "ramènerez": ("ramener",),
    "ramèneriez": ("ramener",),
    "ramènerions": ("ramener",),
    "ramènerons": ("ramener",),
    "ramèneront": ("ramener",),
    "ramenés": ("ramener",),
    "ramènes": ("ramener",),
    "ramenez": ("ramener",),
    "rameniez": ("ramener",),
    "ramenions": ("ramener",),
    "ramenons": ("ramener",),
    "ramifiaient": ("ramifier",),
    "ramifiai": ("ramifier",),
    "ramifiais": ("ramifier",),
    "ramifiait": ("ramifier",),
    "ramifia": ("ramifier",),
    "ramifiâmes": ("ramifier",),
    "ramifiant": ("ramifier",),
    "ramifias": ("ramifier",),
    "ramifiassent": ("ramifier",),
    "ramifiasses": ("ramifier",),
    "ramifiasse": ("ramifier",),
    "ramifiassiez": ("ramifier",),
    "ramifiassions": ("ramifier",),
    "ramifiâtes": ("ramifier",),
    "ramifiât": ("ramifier",),
    "ramifiée": ("ramifier",),
    "ramifiées": ("ramifier",),
    "ramifié": ("ramifier",),
    "ramifient": ("ramifier",),
    "ramifie": ("ramifier",),
    "ramifiera": ("ramifier",),
    "ramifieraient": ("ramifier",),
    "ramifierai": ("ramifier",),
    "ramifierais": ("ramifier",),
    "ramifierait": ("ramifier",),
    "ramifieras": ("ramifier",),
    "ramifièrent": ("ramifier",),
    "ramifierez": ("ramifier",),
    "ramifieriez": ("ramifier",),
    "ramifierions": ("ramifier",),
    "ramifierons": ("ramifier",),
    "ramifieront": ("ramifier",),
    "ramifiés": ("ramifier",),
    "ramifies": ("ramifier",),
    "ramifiez": ("ramifier",),
    "ramifiiez": ("ramifier",),
    "ramifiions": ("ramifier",),
    "ramifions": ("ramifier",),
    "ramoindrie": ("ramoindrir",),
    "ramoindries": ("ramoindrir",),
    "ramoindri": ("ramoindrir",),
    "ramoindrîmes": ("ramoindrir",),
    "ramoindrira": ("ramoindrir",),
    "ramoindriraient": ("ramoindrir",),
    "ramoindrirai": ("ramoindrir",),
    "ramoindrirais": ("ramoindrir",),
    "ramoindrirait": ("ramoindrir",),
    "ramoindriras": ("ramoindrir",),
    "ramoindrirent": ("ramoindrir",),
    "ramoindrirez": ("ramoindrir",),
    "ramoindririez": ("ramoindrir",),
    "ramoindririons": ("ramoindrir",),
    "ramoindrirons": ("ramoindrir",),
    "ramoindriront": ("ramoindrir",),
    "ramoindris": ("ramoindrir",),
    "ramoindrissaient": ("ramoindrir",),
    "ramoindrissais": ("ramoindrir",),
    "ramoindrissait": ("ramoindrir",),
    "ramoindrissant": ("ramoindrir",),
    "ramoindrissent": ("ramoindrir",),
    "ramoindrisse": ("ramoindrir",),
    "ramoindrisses": ("ramoindrir",),
    "ramoindrissez": ("ramoindrir",),
    "ramoindrissiez": ("ramoindrir",),
    "ramoindrissions": ("ramoindrir",),
    "ramoindrissons": ("ramoindrir",),
    "ramoindrîtes": ("ramoindrir",),
    "ramoindrit": ("ramoindrir",),
    "ramoindrît": ("ramoindrir",),
    "ramollie": ("ramollir",),
    "ramollies": ("ramollir",),
    "ramolli": ("ramollir",),
    "ramollîmes": ("ramollir",),
    "ramollira": ("ramollir",),
    "ramolliraient": ("ramollir",),
    "ramollirai": ("ramollir",),
    "ramollirais": ("ramollir",),
    "ramollirait": ("ramollir",),
    "ramolliras": ("ramollir",),
    "ramollirent": ("ramollir",),
    "ramollirez": ("ramollir",),
    "ramolliriez": ("ramollir",),
    "ramollirions": ("ramollir",),
    "ramollirons": ("ramollir",),
    "ramolliront": ("ramollir",),
    "ramollis": ("ramollir",),
    "ramollissaient": ("ramollir",),
    "ramollissais": ("ramollir",),
    "ramollissait": ("ramollir",),
    "ramollissant": ("ramollir",),
    "ramollissent": ("ramollir",),
    "ramollisse": ("ramollir",),
    "ramollisses": ("ramollir",),
    "ramollissez": ("ramollir",),
    "ramollissiez": ("ramollir",),
    "ramollissions": ("ramollir",),
    "ramollissons": ("ramollir",),
    "ramollîtes": ("ramollir",),
    "ramollit": ("ramollir",),
    "ramollît": ("ramollir",),
    "rançaient": ("rancer",),
    "rançai": ("rancer",),
    "rançais": ("rancer",),
    "rançait": ("rancer",),
    "rança": ("rancer",),
    "rançâmes": ("rancer",),
    "rançant": ("rancer",),
    "ranças": ("rancer",),
    "rançassent": ("rancer",),
    "rançasses": ("rancer",),
    "rançasse": ("rancer",),
    "rançassiez": ("rancer",),
    "rançassions": ("rancer",),
    "rançâtes": ("rancer",),
    "rançât": ("rancer",),
    "rancée": ("rancer",),
    "rancées": ("rancer",),
    "rancé": ("rancer",),
    "rancent": ("rancer",),
    "rance": ("rancer",),
    "rancera": ("rancer",),
    "ranceraient": ("rancer",),
    "rancerai": ("rancer",),
    "rancerais": ("rancer",),
    "rancerait": ("rancer",),
    "ranceras": ("rancer",),
    "rancèrent": ("rancer",),
    "rancerez": ("rancer",),
    "ranceriez": ("rancer",),
    "rancerions": ("rancer",),
    "rancerons": ("rancer",),
    "ranceront": ("rancer",),
    "rancés": ("rancer",),
    "rances": ("rancer",),
    "rancez": ("rancer",),
    "ranciez": ("rancer",),
    "rancions": ("rancer",),
    "rançons": ("rancer",),
    "rancie": ("rancir",),
    "rancies": ("rancir",),
    "ranci": ("rancir",),
    "rancîmes": ("rancir",),
    "rancira": ("rancir",),
    "ranciraient": ("rancir",),
    "rancirai": ("rancir",),
    "rancirais": ("rancir",),
    "rancirait": ("rancir",),
    "ranciras": ("rancir",),
    "rancirent": ("rancir",),
    "rancirez": ("rancir",),
    "ranciriez": ("rancir",),
    "rancirions": ("rancir",),
    "rancirons": ("rancir",),
    "ranciront": ("rancir",),
    "rancis": ("rancir",),
    "rancissaient": ("rancir",),
    "rancissais": ("rancir",),
    "rancissait": ("rancir",),
    "rancissant": ("rancir",),
    "rancissent": ("rancir",),
    "rancisse": ("rancir",),
    "rancisses": ("rancir",),
    "rancissez": ("rancir",),
    "rancissiez": ("rancir",),
    "rancissions": ("rancir",),
    "rancissons": ("rancir",),
    "rancîtes": ("rancir",),
    "rancit": ("rancir",),
    "rancît": ("rancir",),
    "rangeaient": ("ranger",),
    "rangeai": ("ranger",),
    "rangeais": ("ranger",),
    "rangeait": ("ranger",),
    "rangea": ("ranger",),
    "rangeâmes": ("ranger",),
    "rangeant": ("ranger",),
    "rangeas": ("ranger",),
    "rangeassent": ("ranger",),
    "rangeasses": ("ranger",),
    "rangeasse": ("ranger",),
    "rangeassiez": ("ranger",),
    "rangeassions": ("ranger",),
    "rangeâtes": ("ranger",),
    "rangeât": ("ranger",),
    "rangée": ("ranger",),
    "rangées": ("ranger",),
    "rangé": ("ranger",),
    "rangent": ("ranger",),
    "rangeons": ("ranger",),
    "range": ("ranger",),
    "rangera": ("ranger",),
    "rangeraient": ("ranger",),
    "rangerai": ("ranger",),
    "rangerais": ("ranger",),
    "rangerait": ("ranger",),
    "rangeras": ("ranger",),
    "rangèrent": ("ranger",),
    "rangerez": ("ranger",),
    "rangeriez": ("ranger",),
    "rangerions": ("ranger",),
    "rangerons": ("ranger",),
    "rangeront": ("ranger",),
    "rangés": ("ranger",),
    "ranges": ("ranger",),
    "rangez": ("ranger",),
    "rangiez": ("ranger",),
    "rangions": ("ranger",),
    "rapatriaient": ("rapatrier",),
    "rapatriai": ("rapatrier",),
    "rapatriais": ("rapatrier",),
    "rapatriait": ("rapatrier",),
    "rapatria": ("rapatrier",),
    "rapatriâmes": ("rapatrier",),
    "rapatriant": ("rapatrier",),
    "rapatrias": ("rapatrier",),
    "rapatriassent": ("rapatrier",),
    "rapatriasses": ("rapatrier",),
    "rapatriasse": ("rapatrier",),
    "rapatriassiez": ("rapatrier",),
    "rapatriassions": ("rapatrier",),
    "rapatriâtes": ("rapatrier",),
    "rapatriât": ("rapatrier",),
    "rapatriée": ("rapatrier",),
    "rapatriées": ("rapatrier",),
    "rapatrié": ("rapatrier",),
    "rapatrient": ("rapatrier",),
    "rapatrie": ("rapatrier",),
    "rapatriera": ("rapatrier",),
    "rapatrieraient": ("rapatrier",),
    "rapatrierai": ("rapatrier",),
    "rapatrierais": ("rapatrier",),
    "rapatrierait": ("rapatrier",),
    "rapatrieras": ("rapatrier",),
    "rapatrièrent": ("rapatrier",),
    "rapatrierez": ("rapatrier",),
    "rapatrieriez": ("rapatrier",),
    "rapatrierions": ("rapatrier",),
    "rapatrierons": ("rapatrier",),
    "rapatrieront": ("rapatrier",),
    "rapatriés": ("rapatrier",),
    "rapatries": ("rapatrier",),
    "rapatriez": ("rapatrier",),
    "rapatriiez": ("rapatrier",),
    "rapatriions": ("rapatrier",),
    "rapatrions": ("rapatrier",),
    "rapetassaient": ("rapetasser",),
    "rapetassai": ("rapetasser",),
    "rapetassais": ("rapetasser",),
    "rapetassait": ("rapetasser",),
    "rapetassa": ("rapetasser",),
    "rapetassâmes": ("rapetasser",),
    "rapetassant": ("rapetasser",),
    "rapetassas": ("rapetasser",),
    "rapetassassent": ("rapetasser",),
    "rapetassasses": ("rapetasser",),
    "rapetassasse": ("rapetasser",),
    "rapetassassiez": ("rapetasser",),
    "rapetassassions": ("rapetasser",),
    "rapetassâtes": ("rapetasser",),
    "rapetassât": ("rapetasser",),
    "rapetassée": ("rapetasser",),
    "rapetassées": ("rapetasser",),
    "rapetassé": ("rapetasser",),
    "rapetassent": ("rapetasser",),
    "rapetasse": ("rapetasser",),
    "rapetassera": ("rapetasser",),
    "rapetasseraient": ("rapetasser",),
    "rapetasserai": ("rapetasser",),
    "rapetasserais": ("rapetasser",),
    "rapetasserait": ("rapetasser",),
    "rapetasseras": ("rapetasser",),
    "rapetassèrent": ("rapetasser",),
    "rapetasserez": ("rapetasser",),
    "rapetasseriez": ("rapetasser",),
    "rapetasserions": ("rapetasser",),
    "rapetasserons": ("rapetasser",),
    "rapetasseront": ("rapetasser",),
    "rapetassés": ("rapetasser",),
    "rapetasses": ("rapetasser",),
    "rapetassez": ("rapetasser",),
    "rapetassiez": ("rapetasser",),
    "rapetassions": ("rapetasser",),
    "rapetassons": ("rapetasser",),
    "rapiéçaient": ("rapiécer",),
    "rapiéçai": ("rapiécer",),
    "rapiéçais": ("rapiécer",),
    "rapiéçait": ("rapiécer",),
    "rapiéça": ("rapiécer",),
    "rapiéçâmes": ("rapiécer",),
    "rapiéçant": ("rapiécer",),
    "rapiéças": ("rapiécer",),
    "rapiéçassent": ("rapiécer",),
    "rapiéçasses": ("rapiécer",),
    "rapiéçasse": ("rapiécer",),
    "rapiéçassiez": ("rapiécer",),
    "rapiéçassions": ("rapiécer",),
    "rapiéçâtes": ("rapiécer",),
    "rapiéçât": ("rapiécer",),
    "rapiécée": ("rapiécer",),
    "rapiécées": ("rapiécer",),
    "rapiécé": ("rapiécer",),
    "rapiècent": ("rapiécer",),
    "rapièce": ("rapiécer",),
    "rapiécera": ("rapiécer",),
    "rapiéceraient": ("rapiécer",),
    "rapiécerai": ("rapiécer",),
    "rapiécerais": ("rapiécer",),
    "rapiécerait": ("rapiécer",),
    "rapiéceras": ("rapiécer",),
    "rapiécèrent": ("rapiécer",),
    "rapiécerez": ("rapiécer",),
    "rapiéceriez": ("rapiécer",),
    "rapiécerions": ("rapiécer",),
    "rapiécerons": ("rapiécer",),
    "rapiéceront": ("rapiécer",),
    "rapiécés": ("rapiécer",),
    "rapièces": ("rapiécer",),
    "rapiécez": ("rapiécer",),
    "rapiéciez": ("rapiécer",),
    "rapiécions": ("rapiécer",),
    "rapiéçons": ("rapiécer",),
    "rapiécetaient": ("rapiéceter",),
    "rapiécetai": ("rapiéceter",),
    "rapiécetais": ("rapiéceter",),
    "rapiécetait": ("rapiéceter",),
    "rapiéceta": ("rapiéceter",),
    "rapiécetâmes": ("rapiéceter",),
    "rapiécetant": ("rapiéceter",),
    "rapiécetas": ("rapiéceter",),
    "rapiécetassent": ("rapiéceter",),
    "rapiécetasses": ("rapiéceter",),
    "rapiécetasse": ("rapiéceter",),
    "rapiécetassiez": ("rapiéceter",),
    "rapiécetassions": ("rapiéceter",),
    "rapiécetâtes": ("rapiéceter",),
    "rapiécetât": ("rapiéceter",),
    "rapiécetée": ("rapiéceter",),
    "rapiécetées": ("rapiéceter",),
    "rapiéceté": ("rapiéceter",),
    "rapiécètent": ("rapiéceter",),
    "rapiécète": ("rapiéceter",),
    "rapiécètera": ("rapiéceter",),
    "rapiécèteraient": ("rapiéceter",),
    "rapiécèterai": ("rapiéceter",),
    "rapiécèterais": ("rapiéceter",),
    "rapiécèterait": ("rapiéceter",),
    "rapiécèteras": ("rapiéceter",),
    "rapiécetèrent": ("rapiéceter",),
    "rapiécèterez": ("rapiéceter",),
    "rapiécèteriez": ("rapiéceter",),
    "rapiécèterions": ("rapiéceter",),
    "rapiécèterons": ("rapiéceter",),
    "rapiécèteront": ("rapiéceter",),
    "rapiécetés": ("rapiéceter",),
    "rapiécètes": ("rapiéceter",),
    "rapiécetez": ("rapiéceter",),
    "rapiécetiez": ("rapiéceter",),
    "rapiécetions": ("rapiéceter",),
    "rapiécetons": ("rapiéceter",),
    "raplatie": ("raplatir",),
    "raplaties": ("raplatir",),
    "raplati": ("raplatir",),
    "raplatîmes": ("raplatir",),
    "raplatira": ("raplatir",),
    "raplatiraient": ("raplatir",),
    "raplatirai": ("raplatir",),
    "raplatirais": ("raplatir",),
    "raplatirait": ("raplatir",),
    "raplatiras": ("raplatir",),
    "raplatirent": ("raplatir",),
    "raplatirez": ("raplatir",),
    "raplatiriez": ("raplatir",),
    "raplatirions": ("raplatir",),
    "raplatirons": ("raplatir",),
    "raplatiront": ("raplatir",),
    "raplatis": ("raplatir",),
    "raplatissaient": ("raplatir",),
    "raplatissais": ("raplatir",),
    "raplatissait": ("raplatir",),
    "raplatissant": ("raplatir",),
    "raplatissent": ("raplatir",),
    "raplatisse": ("raplatir",),
    "raplatisses": ("raplatir",),
    "raplatissez": ("raplatir",),
    "raplatissiez": ("raplatir",),
    "raplatissions": ("raplatir",),
    "raplatissons": ("raplatir",),
    "raplatîtes": ("raplatir",),
    "raplatit": ("raplatir",),
    "raplatît": ("raplatir",),
    "rapointie": ("rapointir",),
    "rapointies": ("rapointir",),
    "rapointi": ("rapointir",),
    "rapointîmes": ("rapointir",),
    "rapointira": ("rapointir",),
    "rapointiraient": ("rapointir",),
    "rapointirai": ("rapointir",),
    "rapointirais": ("rapointir",),
    "rapointirait": ("rapointir",),
    "rapointiras": ("rapointir",),
    "rapointirent": ("rapointir",),
    "rapointirez": ("rapointir",),
    "rapointiriez": ("rapointir",),
    "rapointirions": ("rapointir",),
    "rapointirons": ("rapointir",),
    "rapointiront": ("rapointir",),
    "rapointis": ("rapointir",),
    "rapointissaient": ("rapointir",),
    "rapointissais": ("rapointir",),
    "rapointissait": ("rapointir",),
    "rapointissant": ("rapointir",),
    "rapointissent": ("rapointir",),
    "rapointisse": ("rapointir",),
    "rapointisses": ("rapointir",),
    "rapointissez": ("rapointir",),
    "rapointissiez": ("rapointir",),
    "rapointissions": ("rapointir",),
    "rapointissons": ("rapointir",),
    "rapointîtes": ("rapointir",),
    "rapointit": ("rapointir",),
    "rapointît": ("rapointir",),
    "rappariaient": ("rapparier",),
    "rappariai": ("rapparier",),
    "rappariais": ("rapparier",),
    "rappariait": ("rapparier",),
    "rapparia": ("rapparier",),
    "rappariâmes": ("rapparier",),
    "rappariant": ("rapparier",),
    "rapparias": ("rapparier",),
    "rappariassent": ("rapparier",),
    "rappariasses": ("rapparier",),
    "rappariasse": ("rapparier",),
    "rappariassiez": ("rapparier",),
    "rappariassions": ("rapparier",),
    "rappariâtes": ("rapparier",),
    "rappariât": ("rapparier",),
    "rappariée": ("rapparier",),
    "rappariées": ("rapparier",),
    "rapparié": ("rapparier",),
    "rapparient": ("rapparier",),
    "rapparie": ("rapparier",),
    "rappariera": ("rapparier",),
    "rapparieraient": ("rapparier",),
    "rapparierai": ("rapparier",),
    "rapparierais": ("rapparier",),
    "rapparierait": ("rapparier",),
    "rapparieras": ("rapparier",),
    "rapparièrent": ("rapparier",),
    "rapparierez": ("rapparier",),
    "rapparieriez": ("rapparier",),
    "rapparierions": ("rapparier",),
    "rapparierons": ("rapparier",),
    "rapparieront": ("rapparier",),
    "rappariés": ("rapparier",),
    "rapparies": ("rapparier",),
    "rappariez": ("rapparier",),
    "rappariiez": ("rapparier",),
    "rappariions": ("rapparier",),
    "rapparions": ("rapparier",),
    "rappelaient": ("rappeler",),
    "rappelai": ("rappeler",),
    "rappelais": ("rappeler",),
    "rappelait": ("rappeler",),
    "rappela": ("rappeler",),
    "rappelâmes": ("rappeler",),
    "rappelant": ("rappeler",),
    "rappelas": ("rappeler",),
    "rappelassent": ("rappeler",),
    "rappelasses": ("rappeler",),
    "rappelasse": ("rappeler",),
    "rappelassiez": ("rappeler",),
    "rappelassions": ("rappeler",),
    "rappelâtes": ("rappeler",),
    "rappelât": ("rappeler",),
    "rappelée": ("rappeler",),
    "rappelées": ("rappeler",),
    "rappelé": ("rappeler",),
    "rappelèrent": ("rappeler",),
    "rappelés": ("rappeler",),
    "rappelez": ("rappeler",),
    "rappeliez": ("rappeler",),
    "rappelions": ("rappeler",),
    "rappellent": ("rappeler",),
    "rappelle": ("rappeler",),
    "rappellera": ("rappeler",),
    "rappelleraient": ("rappeler",),
    "rappellerai": ("rappeler",),
    "rappellerais": ("rappeler",),
    "rappellerait": ("rappeler",),
    "rappelleras": ("rappeler",),
    "rappellerez": ("rappeler",),
    "rappelleriez": ("rappeler",),
    "rappellerions": ("rappeler",),
    "rappellerons": ("rappeler",),
    "rappelleront": ("rappeler",),
    "rappelles": ("rappeler",),
    "rappelons": ("rappeler",),
    "rappointie": ("rappointir",),
    "rappointies": ("rappointir",),
    "rappointi": ("rappointir",),
    "rappointîmes": ("rappointir",),
    "rappointira": ("rappointir",),
    "rappointiraient": ("rappointir",),
    "rappointirai": ("rappointir",),
    "rappointirais": ("rappointir",),
    "rappointirait": ("rappointir",),
    "rappointiras": ("rappointir",),
    "rappointirent": ("rappointir",),
    "rappointirez": ("rappointir",),
    "rappointiriez": ("rappointir",),
    "rappointirions": ("rappointir",),
    "rappointirons": ("rappointir",),
    "rappointiront": ("rappointir",),
    "rappointis": ("rappointir",),
    "rappointissaient": ("rappointir",),
    "rappointissais": ("rappointir",),
    "rappointissait": ("rappointir",),
    "rappointissant": ("rappointir",),
    "rappointissent": ("rappointir",),
    "rappointisse": ("rappointir",),
    "rappointisses": ("rappointir",),
    "rappointissez": ("rappointir",),
    "rappointissiez": ("rappointir",),
    "rappointissions": ("rappointir",),
    "rappointissons": ("rappointir",),
    "rappointîtes": ("rappointir",),
    "rappointit": ("rappointir",),
    "rappointît": ("rappointir",),
    "rappréciaient": ("rapprécier",),
    "rappréciai": ("rapprécier",),
    "rappréciais": ("rapprécier",),
    "rappréciait": ("rapprécier",),
    "rapprécia": ("rapprécier",),
    "rappréciâmes": ("rapprécier",),
    "rappréciant": ("rapprécier",),
    "rapprécias": ("rapprécier",),
    "rappréciassent": ("rapprécier",),
    "rappréciasses": ("rapprécier",),
    "rappréciasse": ("rapprécier",),
    "rappréciassiez": ("rapprécier",),
    "rappréciassions": ("rapprécier",),
    "rappréciâtes": ("rapprécier",),
    "rappréciât": ("rapprécier",),
    "rappréciée": ("rapprécier",),
    "rappréciées": ("rapprécier",),
    "rapprécié": ("rapprécier",),
    "rapprécient": ("rapprécier",),
    "rapprécie": ("rapprécier",),
    "rappréciera": ("rapprécier",),
    "rapprécieraient": ("rapprécier",),
    "rapprécierai": ("rapprécier",),
    "rapprécierais": ("rapprécier",),
    "rapprécierait": ("rapprécier",),
    "rapprécieras": ("rapprécier",),
    "rapprécièrent": ("rapprécier",),
    "rapprécierez": ("rapprécier",),
    "rapprécieriez": ("rapprécier",),
    "rapprécierions": ("rapprécier",),
    "rapprécierons": ("rapprécier",),
    "rapprécieront": ("rapprécier",),
    "rappréciés": ("rapprécier",),
    "rapprécies": ("rapprécier",),
    "rappréciez": ("rapprécier",),
    "rappréciiez": ("rapprécier",),
    "rappréciions": ("rapprécier",),
    "rapprécions": ("rapprécier",),
    "rapprenaient": ("rapprendre",),
    "rapprenais": ("rapprendre",),
    "rapprenait": ("rapprendre",),
    "rapprenant": ("rapprendre",),
    "rapprend": ("rapprendre",),
    "rapprendra": ("rapprendre",),
    "rapprendraient": ("rapprendre",),
    "rapprendrai": ("rapprendre",),
    "rapprendrais": ("rapprendre",),
    "rapprendrait": ("rapprendre",),
    "rapprendras": ("rapprendre",),
    "rapprendrez": ("rapprendre",),
    "rapprendriez": ("rapprendre",),
    "rapprendrions": ("rapprendre",),
    "rapprendrons": ("rapprendre",),
    "rapprendront": ("rapprendre",),
    "rapprends": ("rapprendre",),
    "rapprenez": ("rapprendre",),
    "rappreniez": ("rapprendre",),
    "rapprenions": ("rapprendre",),
    "rapprennent": ("rapprendre",),
    "rapprenne": ("rapprendre",),
    "rapprennes": ("rapprendre",),
    "rapprenons": ("rapprendre",),
    "rapprîmes": ("rapprendre",),
    "rapprirent": ("rapprendre",),
    "rapprise": ("rapprendre",),
    "rapprises": ("rapprendre",),
    "rappris": ("rapprendre",),
    "rapprissent": ("rapprendre",),
    "rapprisses": ("rapprendre",),
    "rapprisse": ("rapprendre",),
    "rapprissiez": ("rapprendre",),
    "rapprissions": ("rapprendre",),
    "rapprîtes": ("rapprendre",),
    "rapprit": ("rapprendre",),
    "rapprît": ("rapprendre",),
    "rappropriaient": ("rapproprier",),
    "rappropriai": ("rapproprier",),
    "rappropriais": ("rapproprier",),
    "rappropriait": ("rapproprier",),
    "rappropria": ("rapproprier",),
    "rappropriâmes": ("rapproprier",),
    "rappropriant": ("rapproprier",),
    "rapproprias": ("rapproprier",),
    "rappropriassent": ("rapproprier",),
    "rappropriasses": ("rapproprier",),
    "rappropriasse": ("rapproprier",),
    "rappropriassiez": ("rapproprier",),
    "rappropriassions": ("rapproprier",),
    "rappropriâtes": ("rapproprier",),
    "rappropriât": ("rapproprier",),
    "rappropriée": ("rapproprier",),
    "rappropriées": ("rapproprier",),
    "rapproprié": ("rapproprier",),
    "rapproprient": ("rapproprier",),
    "rapproprie": ("rapproprier",),
    "rappropriera": ("rapproprier",),
    "rapproprieraient": ("rapproprier",),
    "rapproprierai": ("rapproprier",),
    "rapproprierais": ("rapproprier",),
    "rapproprierait": ("rapproprier",),
    "rapproprieras": ("rapproprier",),
    "rapproprièrent": ("rapproprier",),
    "rapproprierez": ("rapproprier",),
    "rapproprieriez": ("rapproprier",),
    "rapproprierions": ("rapproprier",),
    "rapproprierons": ("rapproprier",),
    "rapproprieront": ("rapproprier",),
    "rappropriés": ("rapproprier",),
    "rappropries": ("rapproprier",),
    "rappropriez": ("rapproprier",),
    "rappropriiez": ("rapproprier",),
    "rappropriions": ("rapproprier",),
    "rapproprions": ("rapproprier",),
    "rappuient": ("rappuyer",),
    "rappuie": ("rappuyer",),
    "rappuiera": ("rappuyer",),
    "rappuieraient": ("rappuyer",),
    "rappuierai": ("rappuyer",),
    "rappuierais": ("rappuyer",),
    "rappuierait": ("rappuyer",),
    "rappuieras": ("rappuyer",),
    "rappuierez": ("rappuyer",),
    "rappuieriez": ("rappuyer",),
    "rappuierions": ("rappuyer",),
    "rappuierons": ("rappuyer",),
    "rappuieront": ("rappuyer",),
    "rappuies": ("rappuyer",),
    "rappuyaient": ("rappuyer",),
    "rappuyai": ("rappuyer",),
    "rappuyais": ("rappuyer",),
    "rappuyait": ("rappuyer",),
    "rappuya": ("rappuyer",),
    "rappuyâmes": ("rappuyer",),
    "rappuyant": ("rappuyer",),
    "rappuyas": ("rappuyer",),
    "rappuyassent": ("rappuyer",),
    "rappuyasses": ("rappuyer",),
    "rappuyasse": ("rappuyer",),
    "rappuyassiez": ("rappuyer",),
    "rappuyassions": ("rappuyer",),
    "rappuyâtes": ("rappuyer",),
    "rappuyât": ("rappuyer",),
    "rappuyée": ("rappuyer",),
    "rappuyées": ("rappuyer",),
    "rappuyé": ("rappuyer",),
    "rappuyèrent": ("rappuyer",),
    "rappuyés": ("rappuyer",),
    "rappuyez": ("rappuyer",),
    "rappuyiez": ("rappuyer",),
    "rappuyions": ("rappuyer",),
    "rappuyons": ("rappuyer",),
    "raréfiaient": ("raréfier",),
    "raréfiai": ("raréfier",),
    "raréfiais": ("raréfier",),
    "raréfiait": ("raréfier",),
    "raréfia": ("raréfier",),
    "raréfiâmes": ("raréfier",),
    "raréfiant": ("raréfier",),
    "raréfias": ("raréfier",),
    "raréfiassent": ("raréfier",),
    "raréfiasses": ("raréfier",),
    "raréfiasse": ("raréfier",),
    "raréfiassiez": ("raréfier",),
    "raréfiassions": ("raréfier",),
    "raréfiâtes": ("raréfier",),
    "raréfiât": ("raréfier",),
    "raréfiée": ("raréfier",),
    "raréfiées": ("raréfier",),
    "raréfié": ("raréfier",),
    "raréfient": ("raréfier",),
    "raréfie": ("raréfier",),
    "raréfiera": ("raréfier",),
    "raréfieraient": ("raréfier",),
    "raréfierai": ("raréfier",),
    "raréfierais": ("raréfier",),
    "raréfierait": ("raréfier",),
    "raréfieras": ("raréfier",),
    "raréfièrent": ("raréfier",),
    "raréfierez": ("raréfier",),
    "raréfieriez": ("raréfier",),
    "raréfierions": ("raréfier",),
    "raréfierons": ("raréfier",),
    "raréfieront": ("raréfier",),
    "raréfiés": ("raréfier",),
    "raréfies": ("raréfier",),
    "raréfiez": ("raréfier",),
    "raréfiiez": ("raréfier",),
    "raréfiions": ("raréfier",),
    "raréfions": ("raréfier",),
    "rarrangeaient": ("rarranger",),
    "rarrangeai": ("rarranger",),
    "rarrangeais": ("rarranger",),
    "rarrangeait": ("rarranger",),
    "rarrangea": ("rarranger",),
    "rarrangeâmes": ("rarranger",),
    "rarrangeant": ("rarranger",),
    "rarrangeas": ("rarranger",),
    "rarrangeassent": ("rarranger",),
    "rarrangeasses": ("rarranger",),
    "rarrangeasse": ("rarranger",),
    "rarrangeassiez": ("rarranger",),
    "rarrangeassions": ("rarranger",),
    "rarrangeâtes": ("rarranger",),
    "rarrangeât": ("rarranger",),
    "rarrangée": ("rarranger",),
    "rarrangées": ("rarranger",),
    "rarrangé": ("rarranger",),
    "rarrangent": ("rarranger",),
    "rarrangeons": ("rarranger",),
    "rarrange": ("rarranger",),
    "rarrangera": ("rarranger",),
    "rarrangeraient": ("rarranger",),
    "rarrangerai": ("rarranger",),
    "rarrangerais": ("rarranger",),
    "rarrangerait": ("rarranger",),
    "rarrangeras": ("rarranger",),
    "rarrangèrent": ("rarranger",),
    "rarrangerez": ("rarranger",),
    "rarrangeriez": ("rarranger",),
    "rarrangerions": ("rarranger",),
    "rarrangerons": ("rarranger",),
    "rarrangeront": ("rarranger",),
    "rarrangés": ("rarranger",),
    "rarranges": ("rarranger",),
    "rarrangez": ("rarranger",),
    "rarrangiez": ("rarranger",),
    "rarrangions": ("rarranger",),
    "rassasiaient": ("rassasier",),
    "rassasiai": ("rassasier",),
    "rassasiais": ("rassasier",),
    "rassasiait": ("rassasier",),
    "rassasia": ("rassasier",),
    "rassasiâmes": ("rassasier",),
    "rassasiant": ("rassasier",),
    "rassasias": ("rassasier",),
    "rassasiassent": ("rassasier",),
    "rassasiasses": ("rassasier",),
    "rassasiasse": ("rassasier",),
    "rassasiassiez": ("rassasier",),
    "rassasiassions": ("rassasier",),
    "rassasiâtes": ("rassasier",),
    "rassasiât": ("rassasier",),
    "rassasiée": ("rassasier",),
    "rassasiées": ("rassasier",),
    "rassasié": ("rassasier",),
    "rassasient": ("rassasier",),
    "rassasie": ("rassasier",),
    "rassasiera": ("rassasier",),
    "rassasieraient": ("rassasier",),
    "rassasierai": ("rassasier",),
    "rassasierais": ("rassasier",),
    "rassasierait": ("rassasier",),
    "rassasieras": ("rassasier",),
    "rassasièrent": ("rassasier",),
    "rassasierez": ("rassasier",),
    "rassasieriez": ("rassasier",),
    "rassasierions": ("rassasier",),
    "rassasierons": ("rassasier",),
    "rassasieront": ("rassasier",),
    "rassasiés": ("rassasier",),
    "rassasies": ("rassasier",),
    "rassasiez": ("rassasier",),
    "rassasiiez": ("rassasier",),
    "rassasiions": ("rassasier",),
    "rassasions": ("rassasier",),
    "rasseyaient": ("rasseoir",),
    "rasseyais": ("rasseoir",),
    "rasseyait": ("rasseoir",),
    "rasseyant": ("rasseoir",),
    "rasseyent": ("rasseoir",),
    "rasseye": ("rasseoir",),
    "rasseyes": ("rasseoir",),
    "rasseyez": ("rasseoir",),
    "rasseyiez": ("rasseoir",),
    "rasseyions": ("rasseoir",),
    "rasseyons": ("rasseoir",),
    "rassied": ("rasseoir",),
    "rassieds": ("rasseoir",),
    "rassiéra": ("rasseoir",),
    "rassiéraient": ("rasseoir",),
    "rassiérai": ("rasseoir",),
    "rassiérais": ("rasseoir",),
    "rassiérait": ("rasseoir",),
    "rassiéras": ("rasseoir",),
    "rassiérez": ("rasseoir",),
    "rassiériez": ("rasseoir",),
    "rassiérions": ("rasseoir",),
    "rassiérons": ("rasseoir",),
    "rassiéront": ("rasseoir",),
    "rassîmes": ("rassir",),
    "rassirent": ("rassir",),
    "rassise": ("rasseoir",),
    "rassises": ("rasseoir",),
    "rassis": ("rassir",),
    "rassissent": ("rassir",),
    "rassisses": ("rassir",),
    "rassisse": ("rassir",),
    "rassissiez": ("rassir",),
    "rassissions": ("rassir",),
    "rassîtes": ("rassir",),
    "rassit": ("rassir",),
    "rassît": ("rassir",),
    "rassoient": ("rasseoir",),
    "rassoie": ("rasseoir",),
    "rassoies": ("rasseoir",),
    "rassoira": ("rasseoir",),
    "rassoiraient": ("rasseoir",),
    "rassoirai": ("rasseoir",),
    "rassoirais": ("rasseoir",),
    "rassoirait": ("rasseoir",),
    "rassoiras": ("rasseoir",),
    "rassoirez": ("rasseoir",),
    "rassoiriez": ("rasseoir",),
    "rassoirions": ("rasseoir",),
    "rassoirons": ("rasseoir",),
    "rassoiront": ("rasseoir",),
    "rassois": ("rasseoir",),
    "rassoit": ("rasseoir",),
    "rassoyaient": ("rasseoir",),
    "rassoyais": ("rasseoir",),
    "rassoyait": ("rasseoir",),
    "rassoyant": ("rasseoir",),
    "rassoyez": ("rasseoir",),
    "rassoyiez": ("rasseoir",),
    "rassoyions": ("rasseoir",),
    "rassoyons": ("rasseoir",),
    "rassérénaient": ("rasséréner",),
    "rassérénai": ("rasséréner",),
    "rassérénais": ("rasséréner",),
    "rassérénait": ("rasséréner",),
    "rasséréna": ("rasséréner",),
    "rassérénâmes": ("rasséréner",),
    "rassérénant": ("rasséréner",),
    "rassérénas": ("rasséréner",),
    "rassérénassent": ("rasséréner",),
    "rassérénasses": ("rasséréner",),
    "rassérénasse": ("rasséréner",),
    "rassérénassiez": ("rasséréner",),
    "rassérénassions": ("rasséréner",),
    "rassérénâtes": ("rasséréner",),
    "rassérénât": ("rasséréner",),
    "rassérénée": ("rasséréner",),
    "rassérénées": ("rasséréner",),
    "rasséréné": ("rasséréner",),
    "rassérènent": ("rasséréner",),
    "rassérène": ("rasséréner",),
    "rassérénera": ("rasséréner",),
    "rasséréneraient": ("rasséréner",),
    "rassérénerai": ("rasséréner",),
    "rassérénerais": ("rasséréner",),
    "rassérénerait": ("rasséréner",),
    "rasséréneras": ("rasséréner",),
    "rassérénèrent": ("rasséréner",),
    "rassérénerez": ("rasséréner",),
    "rasséréneriez": ("rasséréner",),
    "rassérénerions": ("rasséréner",),
    "rassérénerons": ("rasséréner",),
    "rasséréneront": ("rasséréner",),
    "rassérénés": ("rasséréner",),
    "rassérènes": ("rasséréner",),
    "rassérénez": ("rasséréner",),
    "rasséréniez": ("rasséréner",),
    "rassérénions": ("rasséréner",),
    "rassérénons": ("rasséréner",),
    "rassie": ("rassir",),
    "rassies": ("rassir",),
    "rassi": ("rassir",),
    "rassira": ("rassir",),
    "rassiraient": ("rassir",),
    "rassirai": ("rassir",),
    "rassirais": ("rassir",),
    "rassirait": ("rassir",),
    "rassiras": ("rassir",),
    "rassirez": ("rassir",),
    "rassiriez": ("rassir",),
    "rassirions": ("rassir",),
    "rassirons": ("rassir",),
    "rassiront": ("rassir",),
    "rassissaient": ("rassir",),
    "rassissais": ("rassir",),
    "rassissait": ("rassir",),
    "rassissant": ("rassir",),
    "rassissez": ("rassir",),
    "rassissons": ("rassir",),
    "rassortie": ("rassortir",),
    "rassorties": ("rassortir",),
    "rassorti": ("rassortir",),
    "rassortîmes": ("rassortir",),
    "rassortira": ("rassortir",),
    "rassortiraient": ("rassortir",),
    "rassortirai": ("rassortir",),
    "rassortirais": ("rassortir",),
    "rassortirait": ("rassortir",),
    "rassortiras": ("rassortir",),
    "rassortirent": ("rassortir",),
    "rassortirez": ("rassortir",),
    "rassortiriez": ("rassortir",),
    "rassortirions": ("rassortir",),
    "rassortirons": ("rassortir",),
    "rassortiront": ("rassortir",),
    "rassortis": ("rassortir",),
    "rassortissaient": ("rassortir",),
    "rassortissais": ("rassortir",),
    "rassortissait": ("rassortir",),
    "rassortissant": ("rassortir",),
    "rassortissent": ("rassortir",),
    "rassortisse": ("rassortir",),
    "rassortisses": ("rassortir",),
    "rassortissez": ("rassortir",),
    "rassortissiez": ("rassortir",),
    "rassortissions": ("rassortir",),
    "rassortissons": ("rassortir",),
    "rassortîtes": ("rassortir",),
    "rassortit": ("rassortir",),
    "rassortît": ("rassortir",),
    "râtelaient": ("râteler",),
    "râtelai": ("râteler",),
    "râtelais": ("râteler",),
    "râtelait": ("râteler",),
    "râtela": ("râteler",),
    "râtelâmes": ("râteler",),
    "râtelant": ("râteler",),
    "râtelas": ("râteler",),
    "râtelassent": ("râteler",),
    "râtelasses": ("râteler",),
    "râtelasse": ("râteler",),
    "râtelassiez": ("râteler",),
    "râtelassions": ("râteler",),
    "râtelâtes": ("râteler",),
    "râtelât": ("râteler",),
    "râtelée": ("râteler",),
    "râtelées": ("râteler",),
    "râtelé": ("râteler",),
    "râtelèrent": ("râteler",),
    "râtelés": ("râteler",),
    "râtelez": ("râteler",),
    "râteliez": ("râteler",),
    "râtelions": ("râteler",),
    "râtellent": ("râteler",),
    "râtelle": ("râteler",),
    "râtellera": ("râteler",),
    "râtelleraient": ("râteler",),
    "râtellerai": ("râteler",),
    "râtellerais": ("râteler",),
    "râtellerait": ("râteler",),
    "râtelleras": ("râteler",),
    "râtellerez": ("râteler",),
    "râtelleriez": ("râteler",),
    "râtellerions": ("râteler",),
    "râtellerons": ("râteler",),
    "râtelleront": ("râteler",),
    "râtelles": ("râteler",),
    "râtelons": ("râteler",),
    "ratifiaient": ("ratifier",),
    "ratifiai": ("ratifier",),
    "ratifiais": ("ratifier",),
    "ratifiait": ("ratifier",),
    "ratifia": ("ratifier",),
    "ratifiâmes": ("ratifier",),
    "ratifiant": ("ratifier",),
    "ratifias": ("ratifier",),
    "ratifiassent": ("ratifier",),
    "ratifiasses": ("ratifier",),
    "ratifiasse": ("ratifier",),
    "ratifiassiez": ("ratifier",),
    "ratifiassions": ("ratifier",),
    "ratifiâtes": ("ratifier",),
    "ratifiât": ("ratifier",),
    "ratifiée": ("ratifier",),
    "ratifiées": ("ratifier",),
    "ratifié": ("ratifier",),
    "ratifient": ("ratifier",),
    "ratifie": ("ratifier",),
    "ratifiera": ("ratifier",),
    "ratifieraient": ("ratifier",),
    "ratifierai": ("ratifier",),
    "ratifierais": ("ratifier",),
    "ratifierait": ("ratifier",),
    "ratifieras": ("ratifier",),
    "ratifièrent": ("ratifier",),
    "ratifierez": ("ratifier",),
    "ratifieriez": ("ratifier",),
    "ratifierions": ("ratifier",),
    "ratifierons": ("ratifier",),
    "ratifieront": ("ratifier",),
    "ratifiés": ("ratifier",),
    "ratifies": ("ratifier",),
    "ratifiez": ("ratifier",),
    "ratifiiez": ("ratifier",),
    "ratifiions": ("ratifier",),
    "ratifions": ("ratifier",),
    "ravageaient": ("ravager",),
    "ravageai": ("ravager",),
    "ravageais": ("ravager",),
    "ravageait": ("ravager",),
    "ravagea": ("ravager",),
    "ravageâmes": ("ravager",),
    "ravageant": ("ravager",),
    "ravageas": ("ravager",),
    "ravageassent": ("ravager",),
    "ravageasses": ("ravager",),
    "ravageasse": ("ravager",),
    "ravageassiez": ("ravager",),
    "ravageassions": ("ravager",),
    "ravageâtes": ("ravager",),
    "ravageât": ("ravager",),
    "ravagée": ("ravager",),
    "ravagées": ("ravager",),
    "ravagé": ("ravager",),
    "ravagent": ("ravager",),
    "ravageons": ("ravager",),
    "ravage": ("ravager",),
    "ravagera": ("ravager",),
    "ravageraient": ("ravager",),
    "ravagerai": ("ravager",),
    "ravagerais": ("ravager",),
    "ravagerait": ("ravager",),
    "ravageras": ("ravager",),
    "ravagèrent": ("ravager",),
    "ravagerez": ("ravager",),
    "ravageriez": ("ravager",),
    "ravagerions": ("ravager",),
    "ravagerons": ("ravager",),
    "ravageront": ("ravager",),
    "ravagés": ("ravager",),
    "ravages": ("ravager",),
    "ravagez": ("ravager",),
    "ravagiez": ("ravager",),
    "ravagions": ("ravager",),
    "ravilie": ("ravilir",),
    "ravilies": ("ravilir",),
    "ravili": ("ravilir",),
    "ravilîmes": ("ravilir",),
    "ravilira": ("ravilir",),
    "raviliraient": ("ravilir",),
    "ravilirai": ("ravilir",),
    "ravilirais": ("ravilir",),
    "ravilirait": ("ravilir",),
    "raviliras": ("ravilir",),
    "ravilirent": ("ravilir",),
    "ravilirez": ("ravilir",),
    "raviliriez": ("ravilir",),
    "ravilirions": ("ravilir",),
    "ravilirons": ("ravilir",),
    "raviliront": ("ravilir",),
    "ravilis": ("ravilir",),
    "ravilissaient": ("ravilir",),
    "ravilissais": ("ravilir",),
    "ravilissait": ("ravilir",),
    "ravilissant": ("ravilir",),
    "ravilissent": ("ravilir",),
    "ravilisse": ("ravilir",),
    "ravilisses": ("ravilir",),
    "ravilissez": ("ravilir",),
    "ravilissiez": ("ravilir",),
    "ravilissions": ("ravilir",),
    "ravilissons": ("ravilir",),
    "ravilîtes": ("ravilir",),
    "ravilit": ("ravilir",),
    "ravilît": ("ravilir",),
    "ravie": ("ravir",),
    "ravies": ("ravir",),
    "ravi": ("ravir",),
    "ravîmes": ("ravir",),
    "ravira": ("ravir",),
    "raviraient": ("ravir",),
    "ravirai": ("ravir",),
    "ravirais": ("ravir",),
    "ravirait": ("ravir",),
    "raviras": ("ravir",),
    "ravirent": ("ravir",),
    "ravirez": ("ravir",),
    "raviriez": ("ravir",),
    "ravirions": ("ravir",),
    "ravirons": ("ravir",),
    "raviront": ("ravir",),
    "ravis": ("ravir",),
    "ravissaient": ("ravir",),
    "ravissais": ("ravir",),
    "ravissait": ("ravir",),
    "ravissant": ("ravir",),
    "ravissent": ("ravir",),
    "ravisse": ("ravir",),
    "ravisses": ("ravir",),
    "ravissez": ("ravir",),
    "ravissiez": ("ravir",),
    "ravissions": ("ravir",),
    "ravissons": ("ravir",),
    "ravîtes": ("ravir",),
    "ravit": ("ravir",),
    "ravît": ("ravir",),
    "raiera": ("rayer",),
    "raieraient": ("rayer",),
    "raierai": ("rayer",),
    "raierais": ("rayer",),
    "raierait": ("rayer",),
    "raieras": ("rayer",),
    "raierez": ("rayer",),
    "raieriez": ("rayer",),
    "raierions": ("rayer",),
    "raierons": ("rayer",),
    "raieront": ("rayer",),
    "rayai": ("rayer",),
    "raya": ("rayer",),
    "rayâmes": ("rayer",),
    "rayas": ("rayer",),
    "rayassent": ("rayer",),
    "rayasses": ("rayer",),
    "rayasse": ("rayer",),
    "rayassiez": ("rayer",),
    "rayassions": ("rayer",),
    "rayâtes": ("rayer",),
    "rayât": ("rayer",),
    "rayée": ("rayer",),
    "rayées": ("rayer",),
    "rayé": ("rayer",),
    "rayent": ("rayer",),
    "raye": ("rayer",),
    "rayera": ("rayer",),
    "rayeraient": ("rayer",),
    "rayerai": ("rayer",),
    "rayerais": ("rayer",),
    "rayerait": ("rayer",),
    "rayeras": ("rayer",),
    "rayèrent": ("rayer",),
    "rayerez": ("rayer",),
    "rayeriez": ("rayer",),
    "rayerions": ("rayer",),
    "rayerons": ("rayer",),
    "rayeront": ("rayer",),
    "rayés": ("rayer",),
    "rayes": ("rayer",),
    "razziaient": ("razzier",),
    "razziai": ("razzier",),
    "razziais": ("razzier",),
    "razziait": ("razzier",),
    "razzia": ("razzier",),
    "razziâmes": ("razzier",),
    "razziant": ("razzier",),
    "razzias": ("razzier",),
    "razziassent": ("razzier",),
    "razziasses": ("razzier",),
    "razziasse": ("razzier",),
    "razziassiez": ("razzier",),
    "razziassions": ("razzier",),
    "razziâtes": ("razzier",),
    "razziât": ("razzier",),
    "razziée": ("razzier",),
    "razziées": ("razzier",),
    "razzié": ("razzier",),
    "razzient": ("razzier",),
    "razzie": ("razzier",),
    "razziera": ("razzier",),
    "razzieraient": ("razzier",),
    "razzierai": ("razzier",),
    "razzierais": ("razzier",),
    "razzierait": ("razzier",),
    "razzieras": ("razzier",),
    "razzièrent": ("razzier",),
    "razzierez": ("razzier",),
    "razzieriez": ("razzier",),
    "razzierions": ("razzier",),
    "razzierons": ("razzier",),
    "razzieront": ("razzier",),
    "razziés": ("razzier",),
    "razzies": ("razzier",),
    "razziez": ("razzier",),
    "razziiez": ("razzier",),
    "razziions": ("razzier",),
    "razzions": ("razzier",),
    "réabrégeaient": ("réabréger",),
    "réabrégeai": ("réabréger",),
    "réabrégeais": ("réabréger",),
    "réabrégeait": ("réabréger",),
    "réabrégea": ("réabréger",),
    "réabrégeâmes": ("réabréger",),
    "réabrégeant": ("réabréger",),
    "réabrégeas": ("réabréger",),
    "réabrégeassent": ("réabréger",),
    "réabrégeasses": ("réabréger",),
    "réabrégeasse": ("réabréger",),
    "réabrégeassiez": ("réabréger",),
    "réabrégeassions": ("réabréger",),
    "réabrégeâtes": ("réabréger",),
    "réabrégeât": ("réabréger",),
    "réabrégée": ("réabréger",),
    "réabrégées": ("réabréger",),
    "réabrégé": ("réabréger",),
    "réabrègent": ("réabréger",),
    "réabrégeons": ("réabréger",),
    "réabrège": ("réabréger",),
    "réabrégera": ("réabréger",),
    "réabrégeraient": ("réabréger",),
    "réabrégerai": ("réabréger",),
    "réabrégerais": ("réabréger",),
    "réabrégerait": ("réabréger",),
    "réabrégeras": ("réabréger",),
    "réabrégèrent": ("réabréger",),
    "réabrégerez": ("réabréger",),
    "réabrégeriez": ("réabréger",),
    "réabrégerions": ("réabréger",),
    "réabrégerons": ("réabréger",),
    "réabrégeront": ("réabréger",),
    "réabrégés": ("réabréger",),
    "réabrèges": ("réabréger",),
    "réabrégez": ("réabréger",),
    "réabrégiez": ("réabréger",),
    "réabrégions": ("réabréger",),
    "réabrogeaient": ("réabroger",),
    "réabrogeai": ("réabroger",),
    "réabrogeais": ("réabroger",),
    "réabrogeait": ("réabroger",),
    "réabrogea": ("réabroger",),
    "réabrogeâmes": ("réabroger",),
    "réabrogeant": ("réabroger",),
    "réabrogeas": ("réabroger",),
    "réabrogeassent": ("réabroger",),
    "réabrogeasses": ("réabroger",),
    "réabrogeasse": ("réabroger",),
    "réabrogeassiez": ("réabroger",),
    "réabrogeassions": ("réabroger",),
    "réabrogeâtes": ("réabroger",),
    "réabrogeât": ("réabroger",),
    "réabrogée": ("réabroger",),
    "réabrogées": ("réabroger",),
    "réabrogé": ("réabroger",),
    "réabrogent": ("réabroger",),
    "réabrogeons": ("réabroger",),
    "réabroge": ("réabroger",),
    "réabrogera": ("réabroger",),
    "réabrogeraient": ("réabroger",),
    "réabrogerai": ("réabroger",),
    "réabrogerais": ("réabroger",),
    "réabrogerait": ("réabroger",),
    "réabrogeras": ("réabroger",),
    "réabrogèrent": ("réabroger",),
    "réabrogerez": ("réabroger",),
    "réabrogeriez": ("réabroger",),
    "réabrogerions": ("réabroger",),
    "réabrogerons": ("réabroger",),
    "réabrogeront": ("réabroger",),
    "réabrogés": ("réabroger",),
    "réabroges": ("réabroger",),
    "réabrogez": ("réabroger",),
    "réabrogiez": ("réabroger",),
    "réabrogions": ("réabroger",),
    "réaccédaient": ("réaccéder",),
    "réaccédai": ("réaccéder",),
    "réaccédais": ("réaccéder",),
    "réaccédait": ("réaccéder",),
    "réaccéda": ("réaccéder",),
    "réaccédâmes": ("réaccéder",),
    "réaccédant": ("réaccéder",),
    "réaccédas": ("réaccéder",),
    "réaccédassent": ("réaccéder",),
    "réaccédasses": ("réaccéder",),
    "réaccédasse": ("réaccéder",),
    "réaccédassiez": ("réaccéder",),
    "réaccédassions": ("réaccéder",),
    "réaccédâtes": ("réaccéder",),
    "réaccédât": ("réaccéder",),
    "réaccédée": ("réaccéder",),
    "réaccédées": ("réaccéder",),
    "réaccédé": ("réaccéder",),
    "réaccèdent": ("réaccéder",),
    "réaccède": ("réaccéder",),
    "réaccédera": ("réaccéder",),
    "réaccéderaient": ("réaccéder",),
    "réaccéderai": ("réaccéder",),
    "réaccéderais": ("réaccéder",),
    "réaccéderait": ("réaccéder",),
    "réaccéderas": ("réaccéder",),
    "réaccédèrent": ("réaccéder",),
    "réaccéderez": ("réaccéder",),
    "réaccéderiez": ("réaccéder",),
    "réaccéderions": ("réaccéder",),
    "réaccéderons": ("réaccéder",),
    "réaccéderont": ("réaccéder",),
    "réaccédés": ("réaccéder",),
    "réaccèdes": ("réaccéder",),
    "réaccédez": ("réaccéder",),
    "réaccédiez": ("réaccéder",),
    "réaccédions": ("réaccéder",),
    "réaccédons": ("réaccéder",),
    "réaccéléraient": ("réaccélérer",),
    "réaccélérai": ("réaccélérer",),
    "réaccélérais": ("réaccélérer",),
    "réaccélérait": ("réaccélérer",),
    "réaccéléra": ("réaccélérer",),
    "réaccélérâmes": ("réaccélérer",),
    "réaccélérant": ("réaccélérer",),
    "réaccéléras": ("réaccélérer",),
    "réaccélérassent": ("réaccélérer",),
    "réaccélérasses": ("réaccélérer",),
    "réaccélérasse": ("réaccélérer",),
    "réaccélérassiez": ("réaccélérer",),
    "réaccélérassions": ("réaccélérer",),
    "réaccélérâtes": ("réaccélérer",),
    "réaccélérât": ("réaccélérer",),
    "réaccélérée": ("réaccélérer",),
    "réaccélérées": ("réaccélérer",),
    "réaccéléré": ("réaccélérer",),
    "réaccélèrent": ("réaccélérer",),
    "réaccélère": ("réaccélérer",),
    "réaccélérera": ("réaccélérer",),
    "réaccéléreraient": ("réaccélérer",),
    "réaccélérerai": ("réaccélérer",),
    "réaccélérerais": ("réaccélérer",),
    "réaccélérerait": ("réaccélérer",),
    "réaccéléreras": ("réaccélérer",),
    "réaccélérèrent": ("réaccélérer",),
    "réaccélérerez": ("réaccélérer",),
    "réaccéléreriez": ("réaccélérer",),
    "réaccélérerions": ("réaccélérer",),
    "réaccélérerons": ("réaccélérer",),
    "réaccéléreront": ("réaccélérer",),
    "réaccélérés": ("réaccélérer",),
    "réaccélères": ("réaccélérer",),
    "réaccélérez": ("réaccélérer",),
    "réaccélériez": ("réaccélérer",),
    "réaccélérions": ("réaccélérer",),
    "réaccélérons": ("réaccélérer",),
    "réacquéraient": ("réacquérir",),
    "réacquérais": ("réacquérir",),
    "réacquérait": ("réacquérir",),
    "réacquérant": ("réacquérir",),
    "réacquérez": ("réacquérir",),
    "réacquériez": ("réacquérir",),
    "réacquérions": ("réacquérir",),
    "réacquérons": ("réacquérir",),
    "réacquerra": ("réacquérir",),
    "réacquerraient": ("réacquérir",),
    "réacquerrai": ("réacquérir",),
    "réacquerrais": ("réacquérir",),
    "réacquerrait": ("réacquérir",),
    "réacquerras": ("réacquérir",),
    "réacquerrez": ("réacquérir",),
    "réacquerriez": ("réacquérir",),
    "réacquerrions": ("réacquérir",),
    "réacquerrons": ("réacquérir",),
    "réacquerront": ("réacquérir",),
    "réacquièrent": ("réacquérir",),
    "réacquière": ("réacquérir",),
    "réacquières": ("réacquérir",),
    "réacquiers": ("réacquérir",),
    "réacquiert": ("réacquérir",),
    "réacquîmes": ("réacquérir",),
    "réacquirent": ("réacquérir",),
    "réacquise": ("réacquérir",),
    "réacquises": ("réacquérir",),
    "réacquis": ("réacquérir",),
    "réacquissent": ("réacquérir",),
    "réacquisses": ("réacquérir",),
    "réacquisse": ("réacquérir",),
    "réacquissiez": ("réacquérir",),
    "réacquissions": ("réacquérir",),
    "réacquîtes": ("réacquérir",),
    "réacquit": ("réacquérir",),
    "réacquît": ("réacquérir",),
    "réacquiesçaient": ("réacquiescer",),
    "réacquiesçai": ("réacquiescer",),
    "réacquiesçais": ("réacquiescer",),
    "réacquiesçait": ("réacquiescer",),
    "réacquiesça": ("réacquiescer",),
    "réacquiesçâmes": ("réacquiescer",),
    "réacquiesçant": ("réacquiescer",),
    "réacquiesças": ("réacquiescer",),
    "réacquiesçassent": ("réacquiescer",),
    "réacquiesçasses": ("réacquiescer",),
    "réacquiesçasse": ("réacquiescer",),
    "réacquiesçassiez": ("réacquiescer",),
    "réacquiesçassions": ("réacquiescer",),
    "réacquiesçâtes": ("réacquiescer",),
    "réacquiesçât": ("réacquiescer",),
    "réacquiescée": ("réacquiescer",),
    "réacquiescées": ("réacquiescer",),
    "réacquiescé": ("réacquiescer",),
    "réacquiescent": ("réacquiescer",),
    "réacquiesce": ("réacquiescer",),
    "réacquiescera": ("réacquiescer",),
    "réacquiesceraient": ("réacquiescer",),
    "réacquiescerai": ("réacquiescer",),
    "réacquiescerais": ("réacquiescer",),
    "réacquiescerait": ("réacquiescer",),
    "réacquiesceras": ("réacquiescer",),
    "réacquiescèrent": ("réacquiescer",),
    "réacquiescerez": ("réacquiescer",),
    "réacquiesceriez": ("réacquiescer",),
    "réacquiescerions": ("réacquiescer",),
    "réacquiescerons": ("réacquiescer",),
    "réacquiesceront": ("réacquiescer",),
    "réacquiescés": ("réacquiescer",),
    "réacquiesces": ("réacquiescer",),
    "réacquiescez": ("réacquiescer",),
    "réacquiesciez": ("réacquiescer",),
    "réacquiescions": ("réacquiescer",),
    "réacquiesçons": ("réacquiescer",),
    "réadjugeaient": ("réadjuger",),
    "réadjugeai": ("réadjuger",),
    "réadjugeais": ("réadjuger",),
    "réadjugeait": ("réadjuger",),
    "réadjugea": ("réadjuger",),
    "réadjugeâmes": ("réadjuger",),
    "réadjugeant": ("réadjuger",),
    "réadjugeas": ("réadjuger",),
    "réadjugeassent": ("réadjuger",),
    "réadjugeasses": ("réadjuger",),
    "réadjugeasse": ("réadjuger",),
    "réadjugeassiez": ("réadjuger",),
    "réadjugeassions": ("réadjuger",),
    "réadjugeâtes": ("réadjuger",),
    "réadjugeât": ("réadjuger",),
    "réadjugée": ("réadjuger",),
    "réadjugées": ("réadjuger",),
    "réadjugé": ("réadjuger",),
    "réadjugent": ("réadjuger",),
    "réadjugeons": ("réadjuger",),
    "réadjuge": ("réadjuger",),
    "réadjugera": ("réadjuger",),
    "réadjugeraient": ("réadjuger",),
    "réadjugerai": ("réadjuger",),
    "réadjugerais": ("réadjuger",),
    "réadjugerait": ("réadjuger",),
    "réadjugeras": ("réadjuger",),
    "réadjugèrent": ("réadjuger",),
    "réadjugerez": ("réadjuger",),
    "réadjugeriez": ("réadjuger",),
    "réadjugerions": ("réadjuger",),
    "réadjugerons": ("réadjuger",),
    "réadjugeront": ("réadjuger",),
    "réadjugés": ("réadjuger",),
    "réadjuges": ("réadjuger",),
    "réadjugez": ("réadjuger",),
    "réadjugiez": ("réadjuger",),
    "réadjugions": ("réadjuger",),
    "réadmet": ("réadmettre",),
    "réadmets": ("réadmettre",),
    "réadmettaient": ("réadmettre",),
    "réadmettais": ("réadmettre",),
    "réadmettait": ("réadmettre",),
    "réadmettant": ("réadmettre",),
    "réadmettent": ("réadmettre",),
    "réadmette": ("réadmettre",),
    "réadmettes": ("réadmettre",),
    "réadmettez": ("réadmettre",),
    "réadmettiez": ("réadmettre",),
    "réadmettions": ("réadmettre",),
    "réadmettons": ("réadmettre",),
    "réadmettra": ("réadmettre",),
    "réadmettraient": ("réadmettre",),
    "réadmettrai": ("réadmettre",),
    "réadmettrais": ("réadmettre",),
    "réadmettrait": ("réadmettre",),
    "réadmettras": ("réadmettre",),
    "réadmettrez": ("réadmettre",),
    "réadmettriez": ("réadmettre",),
    "réadmettrions": ("réadmettre",),
    "réadmettrons": ("réadmettre",),
    "réadmettront": ("réadmettre",),
    "réadmîmes": ("réadmettre",),
    "réadmirent": ("réadmettre",),
    "réadmise": ("réadmettre",),
    "réadmises": ("réadmettre",),
    "réadmis": ("réadmettre",),
    "réadmissent": ("réadmettre",),
    "réadmisses": ("réadmettre",),
    "réadmisse": ("réadmettre",),
    "réadmissiez": ("réadmettre",),
    "réadmissions": ("réadmettre",),
    "réadmîtes": ("réadmettre",),
    "réadmit": ("réadmettre",),
    "réadmît": ("réadmettre",),
    "réaffaiblie": ("réaffaiblir",),
    "réaffaiblies": ("réaffaiblir",),
    "réaffaibli": ("réaffaiblir",),
    "réaffaiblîmes": ("réaffaiblir",),
    "réaffaiblira": ("réaffaiblir",),
    "réaffaibliraient": ("réaffaiblir",),
    "réaffaiblirai": ("réaffaiblir",),
    "réaffaiblirais": ("réaffaiblir",),
    "réaffaiblirait": ("réaffaiblir",),
    "réaffaibliras": ("réaffaiblir",),
    "réaffaiblirent": ("réaffaiblir",),
    "réaffaiblirez": ("réaffaiblir",),
    "réaffaibliriez": ("réaffaiblir",),
    "réaffaiblirions": ("réaffaiblir",),
    "réaffaiblirons": ("réaffaiblir",),
    "réaffaibliront": ("réaffaiblir",),
    "réaffaiblis": ("réaffaiblir",),
    "réaffaiblissaient": ("réaffaiblir",),
    "réaffaiblissais": ("réaffaiblir",),
    "réaffaiblissait": ("réaffaiblir",),
    "réaffaiblissant": ("réaffaiblir",),
    "réaffaiblissent": ("réaffaiblir",),
    "réaffaiblisse": ("réaffaiblir",),
    "réaffaiblisses": ("réaffaiblir",),
    "réaffaiblissez": ("réaffaiblir",),
    "réaffaiblissiez": ("réaffaiblir",),
    "réaffaiblissions": ("réaffaiblir",),
    "réaffaiblissons": ("réaffaiblir",),
    "réaffaiblîtes": ("réaffaiblir",),
    "réaffaiblit": ("réaffaiblir",),
    "réaffaiblît": ("réaffaiblir",),
    "réaffiliaient": ("réaffilier",),
    "réaffiliai": ("réaffilier",),
    "réaffiliais": ("réaffilier",),
    "réaffiliait": ("réaffilier",),
    "réaffilia": ("réaffilier",),
    "réaffiliâmes": ("réaffilier",),
    "réaffiliant": ("réaffilier",),
    "réaffilias": ("réaffilier",),
    "réaffiliassent": ("réaffilier",),
    "réaffiliasses": ("réaffilier",),
    "réaffiliasse": ("réaffilier",),
    "réaffiliassiez": ("réaffilier",),
    "réaffiliassions": ("réaffilier",),
    "réaffiliâtes": ("réaffilier",),
    "réaffiliât": ("réaffilier",),
    "réaffiliée": ("réaffilier",),
    "réaffiliées": ("réaffilier",),
    "réaffilié": ("réaffilier",),
    "réaffilient": ("réaffilier",),
    "réaffilie": ("réaffilier",),
    "réaffiliera": ("réaffilier",),
    "réaffilieraient": ("réaffilier",),
    "réaffilierai": ("réaffilier",),
    "réaffilierais": ("réaffilier",),
    "réaffilierait": ("réaffilier",),
    "réaffilieras": ("réaffilier",),
    "réaffilièrent": ("réaffilier",),
    "réaffilierez": ("réaffilier",),
    "réaffilieriez": ("réaffilier",),
    "réaffilierions": ("réaffilier",),
    "réaffilierons": ("réaffilier",),
    "réaffilieront": ("réaffilier",),
    "réaffiliés": ("réaffilier",),
    "réaffilies": ("réaffilier",),
    "réaffiliez": ("réaffilier",),
    "réaffiliiez": ("réaffilier",),
    "réaffiliions": ("réaffilier",),
    "réaffilions": ("réaffilier",),
    "réaffranchie": ("réaffranchir",),
    "réaffranchies": ("réaffranchir",),
    "réaffranchi": ("réaffranchir",),
    "réaffranchîmes": ("réaffranchir",),
    "réaffranchira": ("réaffranchir",),
    "réaffranchiraient": ("réaffranchir",),
    "réaffranchirai": ("réaffranchir",),
    "réaffranchirais": ("réaffranchir",),
    "réaffranchirait": ("réaffranchir",),
    "réaffranchiras": ("réaffranchir",),
    "réaffranchirent": ("réaffranchir",),
    "réaffranchirez": ("réaffranchir",),
    "réaffranchiriez": ("réaffranchir",),
    "réaffranchirions": ("réaffranchir",),
    "réaffranchirons": ("réaffranchir",),
    "réaffranchiront": ("réaffranchir",),
    "réaffranchis": ("réaffranchir",),
    "réaffranchissaient": ("réaffranchir",),
    "réaffranchissais": ("réaffranchir",),
    "réaffranchissait": ("réaffranchir",),
    "réaffranchissant": ("réaffranchir",),
    "réaffranchissent": ("réaffranchir",),
    "réaffranchisse": ("réaffranchir",),
    "réaffranchisses": ("réaffranchir",),
    "réaffranchissez": ("réaffranchir",),
    "réaffranchissiez": ("réaffranchir",),
    "réaffranchissions": ("réaffranchir",),
    "réaffranchissons": ("réaffranchir",),
    "réaffranchîtes": ("réaffranchir",),
    "réaffranchit": ("réaffranchir",),
    "réaffranchît": ("réaffranchir",),
    "réaffrétaient": ("réaffréter",),
    "réaffrétai": ("réaffréter",),
    "réaffrétais": ("réaffréter",),
    "réaffrétait": ("réaffréter",),
    "réaffréta": ("réaffréter",),
    "réaffrétâmes": ("réaffréter",),
    "réaffrétant": ("réaffréter",),
    "réaffrétas": ("réaffréter",),
    "réaffrétassent": ("réaffréter",),
    "réaffrétasses": ("réaffréter",),
    "réaffrétasse": ("réaffréter",),
    "réaffrétassiez": ("réaffréter",),
    "réaffrétassions": ("réaffréter",),
    "réaffrétâtes": ("réaffréter",),
    "réaffrétât": ("réaffréter",),
    "réaffrétée": ("réaffréter",),
    "réaffrétées": ("réaffréter",),
    "réaffrété": ("réaffréter",),
    "réaffrètent": ("réaffréter",),
    "réaffrète": ("réaffréter",),
    "réaffrétera": ("réaffréter",),
    "réaffréteraient": ("réaffréter",),
    "réaffréterai": ("réaffréter",),
    "réaffréterais": ("réaffréter",),
    "réaffréterait": ("réaffréter",),
    "réaffréteras": ("réaffréter",),
    "réaffrétèrent": ("réaffréter",),
    "réaffréterez": ("réaffréter",),
    "réaffréteriez": ("réaffréter",),
    "réaffréterions": ("réaffréter",),
    "réaffréterons": ("réaffréter",),
    "réaffréteront": ("réaffréter",),
    "réaffrétés": ("réaffréter",),
    "réaffrètes": ("réaffréter",),
    "réaffrétez": ("réaffréter",),
    "réaffrétiez": ("réaffréter",),
    "réaffrétions": ("réaffréter",),
    "réaffrétons": ("réaffréter",),
    "réagençaient": ("réagencer",),
    "réagençai": ("réagencer",),
    "réagençais": ("réagencer",),
    "réagençait": ("réagencer",),
    "réagença": ("réagencer",),
    "réagençâmes": ("réagencer",),
    "réagençant": ("réagencer",),
    "réagenças": ("réagencer",),
    "réagençassent": ("réagencer",),
    "réagençasses": ("réagencer",),
    "réagençasse": ("réagencer",),
    "réagençassiez": ("réagencer",),
    "réagençassions": ("réagencer",),
    "réagençâtes": ("réagencer",),
    "réagençât": ("réagencer",),
    "réagencée": ("réagencer",),
    "réagencées": ("réagencer",),
    "réagencé": ("réagencer",),
    "réagencent": ("réagencer",),
    "réagence": ("réagencer",),
    "réagencera": ("réagencer",),
    "réagenceraient": ("réagencer",),
    "réagencerai": ("réagencer",),
    "réagencerais": ("réagencer",),
    "réagencerait": ("réagencer",),
    "réagenceras": ("réagencer",),
    "réagencèrent": ("réagencer",),
    "réagencerez": ("réagencer",),
    "réagenceriez": ("réagencer",),
    "réagencerions": ("réagencer",),
    "réagencerons": ("réagencer",),
    "réagenceront": ("réagencer",),
    "réagencés": ("réagencer",),
    "réagences": ("réagencer",),
    "réagencez": ("réagencer",),
    "réagenciez": ("réagencer",),
    "réagencions": ("réagencer",),
    "réagençons": ("réagencer",),
    "réagi": ("réagir",),
    "réagîmes": ("réagir",),
    "réagira": ("réagir",),
    "réagiraient": ("réagir",),
    "réagirai": ("réagir",),
    "réagirais": ("réagir",),
    "réagirait": ("réagir",),
    "réagiras": ("réagir",),
    "réagirent": ("réagir",),
    "réagirez": ("réagir",),
    "réagiriez": ("réagir",),
    "réagirions": ("réagir",),
    "réagirons": ("réagir",),
    "réagiront": ("réagir",),
    "réagis": ("réagir",),
    "réagissaient": ("réagir",),
    "réagissais": ("réagir",),
    "réagissait": ("réagir",),
    "réagissant": ("réagir",),
    "réagissent": ("réagir",),
    "réagisse": ("réagir",),
    "réagisses": ("réagir",),
    "réagissez": ("réagir",),
    "réagissiez": ("réagir",),
    "réagissions": ("réagir",),
    "réagissons": ("réagir",),
    "réagîtes": ("réagir",),
    "réagit": ("réagir",),
    "réagît": ("réagir",),
    "réagrandie": ("réagrandir",),
    "réagrandies": ("réagrandir",),
    "réagrandi": ("réagrandir",),
    "réagrandîmes": ("réagrandir",),
    "réagrandira": ("réagrandir",),
    "réagrandiraient": ("réagrandir",),
    "réagrandirai": ("réagrandir",),
    "réagrandirais": ("réagrandir",),
    "réagrandirait": ("réagrandir",),
    "réagrandiras": ("réagrandir",),
    "réagrandirent": ("réagrandir",),
    "réagrandirez": ("réagrandir",),
    "réagrandiriez": ("réagrandir",),
    "réagrandirions": ("réagrandir",),
    "réagrandirons": ("réagrandir",),
    "réagrandiront": ("réagrandir",),
    "réagrandis": ("réagrandir",),
    "réagrandissaient": ("réagrandir",),
    "réagrandissais": ("réagrandir",),
    "réagrandissait": ("réagrandir",),
    "réagrandissant": ("réagrandir",),
    "réagrandissent": ("réagrandir",),
    "réagrandisse": ("réagrandir",),
    "réagrandisses": ("réagrandir",),
    "réagrandissez": ("réagrandir",),
    "réagrandissiez": ("réagrandir",),
    "réagrandissions": ("réagrandir",),
    "réagrandissons": ("réagrandir",),
    "réagrandîtes": ("réagrandir",),
    "réagrandit": ("réagrandir",),
    "réagrandît": ("réagrandir",),
    "réagrégeaient": ("réagréger",),
    "réagrégeai": ("réagréger",),
    "réagrégeais": ("réagréger",),
    "réagrégeait": ("réagréger",),
    "réagrégea": ("réagréger",),
    "réagrégeâmes": ("réagréger",),
    "réagrégeant": ("réagréger",),
    "réagrégeas": ("réagréger",),
    "réagrégeassent": ("réagréger",),
    "réagrégeasses": ("réagréger",),
    "réagrégeasse": ("réagréger",),
    "réagrégeassiez": ("réagréger",),
    "réagrégeassions": ("réagréger",),
    "réagrégeâtes": ("réagréger",),
    "réagrégeât": ("réagréger",),
    "réagrégée": ("réagréger",),
    "réagrégées": ("réagréger",),
    "réagrégé": ("réagréger",),
    "réagrègent": ("réagréger",),
    "réagrégeons": ("réagréger",),
    "réagrège": ("réagréger",),
    "réagrégera": ("réagréger",),
    "réagrégeraient": ("réagréger",),
    "réagrégerai": ("réagréger",),
    "réagrégerais": ("réagréger",),
    "réagrégerait": ("réagréger",),
    "réagrégeras": ("réagréger",),
    "réagrégèrent": ("réagréger",),
    "réagrégerez": ("réagréger",),
    "réagrégeriez": ("réagréger",),
    "réagrégerions": ("réagréger",),
    "réagrégerons": ("réagréger",),
    "réagrégeront": ("réagréger",),
    "réagrégés": ("réagréger",),
    "réagrèges": ("réagréger",),
    "réagrégez": ("réagréger",),
    "réagrégiez": ("réagréger",),
    "réagrégions": ("réagréger",),
    "réalésaient": ("réaléser",),
    "réalésai": ("réaléser",),
    "réalésais": ("réaléser",),
    "réalésait": ("réaléser",),
    "réalésa": ("réaléser",),
    "réalésâmes": ("réaléser",),
    "réalésant": ("réaléser",),
    "réalésas": ("réaléser",),
    "réalésassent": ("réaléser",),
    "réalésasses": ("réaléser",),
    "réalésasse": ("réaléser",),
    "réalésassiez": ("réaléser",),
    "réalésassions": ("réaléser",),
    "réalésâtes": ("réaléser",),
    "réalésât": ("réaléser",),
    "réalésée": ("réaléser",),
    "réalésées": ("réaléser",),
    "réalésé": ("réaléser",),
    "réalèsent": ("réaléser",),
    "réalèse": ("réaléser",),
    "réalésera": ("réaléser",),
    "réaléseraient": ("réaléser",),
    "réaléserai": ("réaléser",),
    "réaléserais": ("réaléser",),
    "réaléserait": ("réaléser",),
    "réaléseras": ("réaléser",),
    "réalésèrent": ("réaléser",),
    "réaléserez": ("réaléser",),
    "réaléseriez": ("réaléser",),
    "réaléserions": ("réaléser",),
    "réaléserons": ("réaléser",),
    "réaléseront": ("réaléser",),
    "réalésés": ("réaléser",),
    "réalèses": ("réaléser",),
    "réalésez": ("réaléser",),
    "réalésiez": ("réaléser",),
    "réalésions": ("réaléser",),
    "réalésons": ("réaléser",),
    "réallégeaient": ("réalléger",),
    "réallégeai": ("réalléger",),
    "réallégeais": ("réalléger",),
    "réallégeait": ("réalléger",),
    "réallégea": ("réalléger",),
    "réallégeâmes": ("réalléger",),
    "réallégeant": ("réalléger",),
    "réallégeas": ("réalléger",),
    "réallégeassent": ("réalléger",),
    "réallégeasses": ("réalléger",),
    "réallégeasse": ("réalléger",),
    "réallégeassiez": ("réalléger",),
    "réallégeassions": ("réalléger",),
    "réallégeâtes": ("réalléger",),
    "réallégeât": ("réalléger",),
    "réallégée": ("réalléger",),
    "réallégées": ("réalléger",),
    "réallégé": ("réalléger",),
    "réallègent": ("réalléger",),
    "réallégeons": ("réalléger",),
    "réallège": ("réalléger",),
    "réallégera": ("réalléger",),
    "réallégeraient": ("réalléger",),
    "réallégerai": ("réalléger",),
    "réallégerais": ("réalléger",),
    "réallégerait": ("réalléger",),
    "réallégeras": ("réalléger",),
    "réallégèrent": ("réalléger",),
    "réallégerez": ("réalléger",),
    "réallégeriez": ("réalléger",),
    "réallégerions": ("réalléger",),
    "réallégerons": ("réalléger",),
    "réallégeront": ("réalléger",),
    "réallégés": ("réalléger",),
    "réallèges": ("réalléger",),
    "réallégez": ("réalléger",),
    "réallégiez": ("réalléger",),
    "réallégions": ("réalléger",),
    "réallongeaient": ("réallonger",),
    "réallongeai": ("réallonger",),
    "réallongeais": ("réallonger",),
    "réallongeait": ("réallonger",),
    "réallongea": ("réallonger",),
    "réallongeâmes": ("réallonger",),
    "réallongeant": ("réallonger",),
    "réallongeas": ("réallonger",),
    "réallongeassent": ("réallonger",),
    "réallongeasses": ("réallonger",),
    "réallongeasse": ("réallonger",),
    "réallongeassiez": ("réallonger",),
    "réallongeassions": ("réallonger",),
    "réallongeâtes": ("réallonger",),
    "réallongeât": ("réallonger",),
    "réallongée": ("réallonger",),
    "réallongées": ("réallonger",),
    "réallongé": ("réallonger",),
    "réallongent": ("réallonger",),
    "réallongeons": ("réallonger",),
    "réallonge": ("réallonger",),
    "réallongera": ("réallonger",),
    "réallongeraient": ("réallonger",),
    "réallongerai": ("réallonger",),
    "réallongerais": ("réallonger",),
    "réallongerait": ("réallonger",),
    "réallongeras": ("réallonger",),
    "réallongèrent": ("réallonger",),
    "réallongerez": ("réallonger",),
    "réallongeriez": ("réallonger",),
    "réallongerions": ("réallonger",),
    "réallongerons": ("réallonger",),
    "réallongeront": ("réallonger",),
    "réallongés": ("réallonger",),
    "réallonges": ("réallonger",),
    "réallongez": ("réallonger",),
    "réallongiez": ("réallonger",),
    "réallongions": ("réallonger",),
    "réamassaient": ("réamasser",),
    "réamassai": ("réamasser",),
    "réamassais": ("réamasser",),
    "réamassait": ("réamasser",),
    "réamassa": ("réamasser",),
    "réamassâmes": ("réamasser",),
    "réamassant": ("réamasser",),
    "réamassas": ("réamasser",),
    "réamassassent": ("réamasser",),
    "réamassasses": ("réamasser",),
    "réamassasse": ("réamasser",),
    "réamassassiez": ("réamasser",),
    "réamassassions": ("réamasser",),
    "réamassâtes": ("réamasser",),
    "réamassât": ("réamasser",),
    "réamassée": ("réamasser",),
    "réamassées": ("réamasser",),
    "réamassé": ("réamasser",),
    "réamassent": ("réamasser",),
    "réamasse": ("réamasser",),
    "réamassera": ("réamasser",),
    "réamasseraient": ("réamasser",),
    "réamasserai": ("réamasser",),
    "réamasserais": ("réamasser",),
    "réamasserait": ("réamasser",),
    "réamasseras": ("réamasser",),
    "réamassèrent": ("réamasser",),
    "réamasserez": ("réamasser",),
    "réamasseriez": ("réamasser",),
    "réamasserions": ("réamasser",),
    "réamasserons": ("réamasser",),
    "réamasseront": ("réamasser",),
    "réamassés": ("réamasser",),
    "réamasses": ("réamasser",),
    "réamassez": ("réamasser",),
    "réamassiez": ("réamasser",),
    "réamassions": ("réamasser",),
    "réamassons": ("réamasser",),
    "réaménageaient": ("réaménager",),
    "réaménageai": ("réaménager",),
    "réaménageais": ("réaménager",),
    "réaménageait": ("réaménager",),
    "réaménagea": ("réaménager",),
    "réaménageâmes": ("réaménager",),
    "réaménageant": ("réaménager",),
    "réaménageas": ("réaménager",),
    "réaménageassent": ("réaménager",),
    "réaménageasses": ("réaménager",),
    "réaménageasse": ("réaménager",),
    "réaménageassiez": ("réaménager",),
    "réaménageassions": ("réaménager",),
    "réaménageâtes": ("réaménager",),
    "réaménageât": ("réaménager",),
    "réaménagée": ("réaménager",),
    "réaménagées": ("réaménager",),
    "réaménagé": ("réaménager",),
    "réaménagent": ("réaménager",),
    "réaménageons": ("réaménager",),
    "réaménage": ("réaménager",),
    "réaménagera": ("réaménager",),
    "réaménageraient": ("réaménager",),
    "réaménagerai": ("réaménager",),
    "réaménagerais": ("réaménager",),
    "réaménagerait": ("réaménager",),
    "réaménageras": ("réaménager",),
    "réaménagèrent": ("réaménager",),
    "réaménagerez": ("réaménager",),
    "réaménageriez": ("réaménager",),
    "réaménagerions": ("réaménager",),
    "réaménagerons": ("réaménager",),
    "réaménageront": ("réaménager",),
    "réaménagés": ("réaménager",),
    "réaménages": ("réaménager",),
    "réaménagez": ("réaménager",),
    "réaménagiez": ("réaménager",),
    "réaménagions": ("réaménager",),
    "réamerrie": ("réamerrir",),
    "réamerries": ("réamerrir",),
    "réamerri": ("réamerrir",),
    "réamerrîmes": ("réamerrir",),
    "réamerrira": ("réamerrir",),
    "réamerriraient": ("réamerrir",),
    "réamerrirai": ("réamerrir",),
    "réamerrirais": ("réamerrir",),
    "réamerrirait": ("réamerrir",),
    "réamerriras": ("réamerrir",),
    "réamerrirent": ("réamerrir",),
    "réamerrirez": ("réamerrir",),
    "réamerririez": ("réamerrir",),
    "réamerririons": ("réamerrir",),
    "réamerrirons": ("réamerrir",),
    "réamerriront": ("réamerrir",),
    "réamerris": ("réamerrir",),
    "réamerrissaient": ("réamerrir",),
    "réamerrissais": ("réamerrir",),
    "réamerrissait": ("réamerrir",),
    "réamerrissant": ("réamerrir",),
    "réamerrissent": ("réamerrir",),
    "réamerrisse": ("réamerrir",),
    "réamerrisses": ("réamerrir",),
    "réamerrissez": ("réamerrir",),
    "réamerrissiez": ("réamerrir",),
    "réamerrissions": ("réamerrir",),
    "réamerrissons": ("réamerrir",),
    "réamerrîtes": ("réamerrir",),
    "réamerrit": ("réamerrir",),
    "réamerrît": ("réamerrir",),
    "réamoncelaient": ("réamonceler",),
    "réamoncelai": ("réamonceler",),
    "réamoncelais": ("réamonceler",),
    "réamoncelait": ("réamonceler",),
    "réamoncela": ("réamonceler",),
    "réamoncelâmes": ("réamonceler",),
    "réamoncelant": ("réamonceler",),
    "réamoncelas": ("réamonceler",),
    "réamoncelassent": ("réamonceler",),
    "réamoncelasses": ("réamonceler",),
    "réamoncelasse": ("réamonceler",),
    "réamoncelassiez": ("réamonceler",),
    "réamoncelassions": ("réamonceler",),
    "réamoncelâtes": ("réamonceler",),
    "réamoncelât": ("réamonceler",),
    "réamoncelée": ("réamonceler",),
    "réamoncelées": ("réamonceler",),
    "réamoncelé": ("réamonceler",),
    "réamoncelèrent": ("réamonceler",),
    "réamoncelés": ("réamonceler",),
    "réamoncelez": ("réamonceler",),
    "réamonceliez": ("réamonceler",),
    "réamoncelions": ("réamonceler",),
    "réamoncellent": ("réamonceler",),
    "réamoncelle": ("réamonceler",),
    "réamoncellera": ("réamonceler",),
    "réamoncelleraient": ("réamonceler",),
    "réamoncellerai": ("réamonceler",),
    "réamoncellerais": ("réamonceler",),
    "réamoncellerait": ("réamonceler",),
    "réamoncelleras": ("réamonceler",),
    "réamoncellerez": ("réamonceler",),
    "réamoncelleriez": ("réamonceler",),
    "réamoncellerions": ("réamonceler",),
    "réamoncellerons": ("réamonceler",),
    "réamoncelleront": ("réamonceler",),
    "réamoncelles": ("réamonceler",),
    "réamoncelons": ("réamonceler",),
    "réamorçaient": ("réamorcer",),
    "réamorçai": ("réamorcer",),
    "réamorçais": ("réamorcer",),
    "réamorçait": ("réamorcer",),
    "réamorça": ("réamorcer",),
    "réamorçâmes": ("réamorcer",),
    "réamorçant": ("réamorcer",),
    "réamorças": ("réamorcer",),
    "réamorçassent": ("réamorcer",),
    "réamorçasses": ("réamorcer",),
    "réamorçasse": ("réamorcer",),
    "réamorçassiez": ("réamorcer",),
    "réamorçassions": ("réamorcer",),
    "réamorçâtes": ("réamorcer",),
    "réamorçât": ("réamorcer",),
    "réamorcée": ("réamorcer",),
    "réamorcées": ("réamorcer",),
    "réamorcé": ("réamorcer",),
    "réamorcent": ("réamorcer",),
    "réamorce": ("réamorcer",),
    "réamorcera": ("réamorcer",),
    "réamorceraient": ("réamorcer",),
    "réamorcerai": ("réamorcer",),
    "réamorcerais": ("réamorcer",),
    "réamorcerait": ("réamorcer",),
    "réamorceras": ("réamorcer",),
    "réamorcèrent": ("réamorcer",),
    "réamorcerez": ("réamorcer",),
    "réamorceriez": ("réamorcer",),
    "réamorcerions": ("réamorcer",),
    "réamorcerons": ("réamorcer",),
    "réamorceront": ("réamorcer",),
    "réamorcés": ("réamorcer",),
    "réamorces": ("réamorcer",),
    "réamorcez": ("réamorcer",),
    "réamorciez": ("réamorcer",),
    "réamorcions": ("réamorcer",),
    "réamorçons": ("réamorcer",),
    "réannonçaient": ("réannoncer",),
    "réannonçai": ("réannoncer",),
    "réannonçais": ("réannoncer",),
    "réannonçait": ("réannoncer",),
    "réannonça": ("réannoncer",),
    "réannonçâmes": ("réannoncer",),
    "réannonçant": ("réannoncer",),
    "réannonças": ("réannoncer",),
    "réannonçassent": ("réannoncer",),
    "réannonçasses": ("réannoncer",),
    "réannonçasse": ("réannoncer",),
    "réannonçassiez": ("réannoncer",),
    "réannonçassions": ("réannoncer",),
    "réannonçâtes": ("réannoncer",),
    "réannonçât": ("réannoncer",),
    "réannoncée": ("réannoncer",),
    "réannoncées": ("réannoncer",),
    "réannoncé": ("réannoncer",),
    "réannoncent": ("réannoncer",),
    "réannonce": ("réannoncer",),
    "réannoncera": ("réannoncer",),
    "réannonceraient": ("réannoncer",),
    "réannoncerai": ("réannoncer",),
    "réannoncerais": ("réannoncer",),
    "réannoncerait": ("réannoncer",),
    "réannonceras": ("réannoncer",),
    "réannoncèrent": ("réannoncer",),
    "réannoncerez": ("réannoncer",),
    "réannonceriez": ("réannoncer",),
    "réannoncerions": ("réannoncer",),
    "réannoncerons": ("réannoncer",),
    "réannonceront": ("réannoncer",),
    "réannoncés": ("réannoncer",),
    "réannonces": ("réannoncer",),
    "réannoncez": ("réannoncer",),
    "réannonciez": ("réannoncer",),
    "réannoncions": ("réannoncer",),
    "réannonçons": ("réannoncer",),
    "réapercevaient": ("réapercevoir",),
    "réapercevais": ("réapercevoir",),
    "réapercevait": ("réapercevoir",),
    "réapercevant": ("réapercevoir",),
    "réapercevez": ("réapercevoir",),
    "réaperceviez": ("réapercevoir",),
    "réapercevions": ("réapercevoir",),
    "réapercevons": ("réapercevoir",),
    "réapercevra": ("réapercevoir",),
    "réapercevraient": ("réapercevoir",),
    "réapercevrai": ("réapercevoir",),
    "réapercevrais": ("réapercevoir",),
    "réapercevrait": ("réapercevoir",),
    "réapercevras": ("réapercevoir",),
    "réapercevrez": ("réapercevoir",),
    "réapercevriez": ("réapercevoir",),
    "réapercevrions": ("réapercevoir",),
    "réapercevrons": ("réapercevoir",),
    "réapercevront": ("réapercevoir",),
    "réaperçois": ("réapercevoir",),
    "réaperçoit": ("réapercevoir",),
    "réaperçoivent": ("réapercevoir",),
    "réaperçoive": ("réapercevoir",),
    "réaperçoives": ("réapercevoir",),
    "réaperçue": ("réapercevoir",),
    "réaperçues": ("réapercevoir",),
    "réaperçu": ("réapercevoir",),
    "réaperçûmes": ("réapercevoir",),
    "réaperçurent": ("réapercevoir",),
    "réaperçus": ("réapercevoir",),
    "réaperçussent": ("réapercevoir",),
    "réaperçusses": ("réapercevoir",),
    "réaperçusse": ("réapercevoir",),
    "réaperçussiez": ("réapercevoir",),
    "réaperçussions": ("réapercevoir",),
    "réaperçûtes": ("réapercevoir",),
    "réaperçut": ("réapercevoir",),
    "réaperçût": ("réapercevoir",),
    "réaplanie": ("réaplanir",),
    "réaplanies": ("réaplanir",),
    "réaplani": ("réaplanir",),
    "réaplanîmes": ("réaplanir",),
    "réaplanira": ("réaplanir",),
    "réaplaniraient": ("réaplanir",),
    "réaplanirai": ("réaplanir",),
    "réaplanirais": ("réaplanir",),
    "réaplanirait": ("réaplanir",),
    "réaplaniras": ("réaplanir",),
    "réaplanirent": ("réaplanir",),
    "réaplanirez": ("réaplanir",),
    "réaplaniriez": ("réaplanir",),
    "réaplanirions": ("réaplanir",),
    "réaplanirons": ("réaplanir",),
    "réaplaniront": ("réaplanir",),
    "réaplanis": ("réaplanir",),
    "réaplanissaient": ("réaplanir",),
    "réaplanissais": ("réaplanir",),
    "réaplanissait": ("réaplanir",),
    "réaplanissant": ("réaplanir",),
    "réaplanissent": ("réaplanir",),
    "réaplanisse": ("réaplanir",),
    "réaplanisses": ("réaplanir",),
    "réaplanissez": ("réaplanir",),
    "réaplanissiez": ("réaplanir",),
    "réaplanissions": ("réaplanir",),
    "réaplanissons": ("réaplanir",),
    "réaplanîtes": ("réaplanir",),
    "réaplanit": ("réaplanir",),
    "réaplanît": ("réaplanir",),
    "réapparais": ("réapparaître",),
    "réapparaissaient": ("réapparaître",),
    "réapparaissais": ("réapparaître",),
    "réapparaissait": ("réapparaître",),
    "réapparaissant": ("réapparaître",),
    "réapparaissent": ("réapparaître",),
    "réapparaisse": ("réapparaître",),
    "réapparaisses": ("réapparaître",),
    "réapparaissez": ("réapparaître",),
    "réapparaissiez": ("réapparaître",),
    "réapparaissions": ("réapparaître",),
    "réapparaissons": ("réapparaître",),
    "réapparaît": ("réapparaître",),
    "réapparaîtra": ("réapparaître",),
    "réapparaîtraient": ("réapparaître",),
    "réapparaîtrai": ("réapparaître",),
    "réapparaîtrais": ("réapparaître",),
    "réapparaîtrait": ("réapparaître",),
    "réapparaîtras": ("réapparaître",),
    "réapparaîtrez": ("réapparaître",),
    "réapparaîtriez": ("réapparaître",),
    "réapparaîtrions": ("réapparaître",),
    "réapparaîtrons": ("réapparaître",),
    "réapparaîtront": ("réapparaître",),
    "réapparue": ("réapparaître",),
    "réapparues": ("réapparaître",),
    "réapparu": ("réapparaître",),
    "réapparûmes": ("réapparaître",),
    "réapparurent": ("réapparaître",),
    "réapparus": ("réapparaître",),
    "réapparussent": ("réapparaître",),
    "réapparusses": ("réapparaître",),
    "réapparusse": ("réapparaître",),
    "réapparussiez": ("réapparaître",),
    "réapparussions": ("réapparaître",),
    "réapparûtes": ("réapparaître",),
    "réapparut": ("réapparaître",),
    "réapparût": ("réapparaître",),
    "réappariaient": ("réapparier",),
    "réappariai": ("réapparier",),
    "réappariais": ("réapparier",),
    "réappariait": ("réapparier",),
    "réapparia": ("réapparier",),
    "réappariâmes": ("réapparier",),
    "réappariant": ("réapparier",),
    "réapparias": ("réapparier",),
    "réappariassent": ("réapparier",),
    "réappariasses": ("réapparier",),
    "réappariasse": ("réapparier",),
    "réappariassiez": ("réapparier",),
    "réappariassions": ("réapparier",),
    "réappariâtes": ("réapparier",),
    "réappariât": ("réapparier",),
    "réappariée": ("réapparier",),
    "réappariées": ("réapparier",),
    "réapparié": ("réapparier",),
    "réapparient": ("réapparier",),
    "réapparie": ("réapparier",),
    "réappariera": ("réapparier",),
    "réapparieraient": ("réapparier",),
    "réapparierai": ("réapparier",),
    "réapparierais": ("réapparier",),
    "réapparierait": ("réapparier",),
    "réapparieras": ("réapparier",),
    "réapparièrent": ("réapparier",),
    "réapparierez": ("réapparier",),
    "réapparieriez": ("réapparier",),
    "réapparierions": ("réapparier",),
    "réapparierons": ("réapparier",),
    "réapparieront": ("réapparier",),
    "réappariés": ("réapparier",),
    "réapparies": ("réapparier",),
    "réappariez": ("réapparier",),
    "réappariiez": ("réapparier",),
    "réappariions": ("réapparier",),
    "réapparions": ("réapparier",),
    "réappâtaient": ("réappâter",),
    "réappâtai": ("réappâter",),
    "réappâtais": ("réappâter",),
    "réappâtait": ("réappâter",),
    "réappâta": ("réappâter",),
    "réappâtâmes": ("réappâter",),
    "réappâtant": ("réappâter",),
    "réappâtas": ("réappâter",),
    "réappâtassent": ("réappâter",),
    "réappâtasses": ("réappâter",),
    "réappâtasse": ("réappâter",),
    "réappâtassiez": ("réappâter",),
    "réappâtassions": ("réappâter",),
    "réappâtâtes": ("réappâter",),
    "réappâtât": ("réappâter",),
    "réappâtée": ("réappâter",),
    "réappâtées": ("réappâter",),
    "réappâté": ("réappâter",),
    "réappâtent": ("réappâter",),
    "réappâte": ("réappâter",),
    "réappâtera": ("réappâter",),
    "réappâteraient": ("réappâter",),
    "réappâterai": ("réappâter",),
    "réappâterais": ("réappâter",),
    "réappâterait": ("réappâter",),
    "réappâteras": ("réappâter",),
    "réappâtèrent": ("réappâter",),
    "réappâterez": ("réappâter",),
    "réappâteriez": ("réappâter",),
    "réappâterions": ("réappâter",),
    "réappâterons": ("réappâter",),
    "réappâteront": ("réappâter",),
    "réappâtés": ("réappâter",),
    "réappâtes": ("réappâter",),
    "réappâtez": ("réappâter",),
    "réappâtiez": ("réappâter",),
    "réappâtions": ("réappâter",),
    "réappâtons": ("réappâter",),
    "réappauvrie": ("réappauvrir",),
    "réappauvries": ("réappauvrir",),
    "réappauvri": ("réappauvrir",),
    "réappauvrîmes": ("réappauvrir",),
    "réappauvrira": ("réappauvrir",),
    "réappauvriraient": ("réappauvrir",),
    "réappauvrirai": ("réappauvrir",),
    "réappauvrirais": ("réappauvrir",),
    "réappauvrirait": ("réappauvrir",),
    "réappauvriras": ("réappauvrir",),
    "réappauvrirent": ("réappauvrir",),
    "réappauvrirez": ("réappauvrir",),
    "réappauvririez": ("réappauvrir",),
    "réappauvririons": ("réappauvrir",),
    "réappauvrirons": ("réappauvrir",),
    "réappauvriront": ("réappauvrir",),
    "réappauvris": ("réappauvrir",),
    "réappauvrissaient": ("réappauvrir",),
    "réappauvrissais": ("réappauvrir",),
    "réappauvrissait": ("réappauvrir",),
    "réappauvrissant": ("réappauvrir",),
    "réappauvrissent": ("réappauvrir",),
    "réappauvrisse": ("réappauvrir",),
    "réappauvrisses": ("réappauvrir",),
    "réappauvrissez": ("réappauvrir",),
    "réappauvrissiez": ("réappauvrir",),
    "réappauvrissions": ("réappauvrir",),
    "réappauvrissons": ("réappauvrir",),
    "réappauvrîtes": ("réappauvrir",),
    "réappauvrit": ("réappauvrir",),
    "réappauvrît": ("réappauvrir",),
    "réappelaient": ("réappeler",),
    "réappelai": ("réappeler",),
    "réappelais": ("réappeler",),
    "réappelait": ("réappeler",),
    "réappela": ("réappeler",),
    "réappelâmes": ("réappeler",),
    "réappelant": ("réappeler",),
    "réappelas": ("réappeler",),
    "réappelassent": ("réappeler",),
    "réappelasses": ("réappeler",),
    "réappelasse": ("réappeler",),
    "réappelassiez": ("réappeler",),
    "réappelassions": ("réappeler",),
    "réappelâtes": ("réappeler",),
    "réappelât": ("réappeler",),
    "réappelée": ("réappeler",),
    "réappelées": ("réappeler",),
    "réappelé": ("réappeler",),
    "réappelèrent": ("réappeler",),
    "réappelés": ("réappeler",),
    "réappelez": ("réappeler",),
    "réappeliez": ("réappeler",),
    "réappelions": ("réappeler",),
    "réappellent": ("réappeler",),
    "réappelle": ("réappeler",),
    "réappellera": ("réappeler",),
    "réappelleraient": ("réappeler",),
    "réappellerai": ("réappeler",),
    "réappellerais": ("réappeler",),
    "réappellerait": ("réappeler",),
    "réappelleras": ("réappeler",),
    "réappellerez": ("réappeler",),
    "réappelleriez": ("réappeler",),
    "réappellerions": ("réappeler",),
    "réappellerons": ("réappeler",),
    "réappelleront": ("réappeler",),
    "réappelles": ("réappeler",),
    "réappelons": ("réappeler",),
    "réapplaudie": ("réapplaudir",),
    "réapplaudies": ("réapplaudir",),
    "réapplaudi": ("réapplaudir",),
    "réapplaudîmes": ("réapplaudir",),
    "réapplaudira": ("réapplaudir",),
    "réapplaudiraient": ("réapplaudir",),
    "réapplaudirai": ("réapplaudir",),
    "réapplaudirais": ("réapplaudir",),
    "réapplaudirait": ("réapplaudir",),
    "réapplaudiras": ("réapplaudir",),
    "réapplaudirent": ("réapplaudir",),
    "réapplaudirez": ("réapplaudir",),
    "réapplaudiriez": ("réapplaudir",),
    "réapplaudirions": ("réapplaudir",),
    "réapplaudirons": ("réapplaudir",),
    "réapplaudiront": ("réapplaudir",),
    "réapplaudis": ("réapplaudir",),
    "réapplaudissaient": ("réapplaudir",),
    "réapplaudissais": ("réapplaudir",),
    "réapplaudissait": ("réapplaudir",),
    "réapplaudissant": ("réapplaudir",),
    "réapplaudissent": ("réapplaudir",),
    "réapplaudisse": ("réapplaudir",),
    "réapplaudisses": ("réapplaudir",),
    "réapplaudissez": ("réapplaudir",),
    "réapplaudissiez": ("réapplaudir",),
    "réapplaudissions": ("réapplaudir",),
    "réapplaudissons": ("réapplaudir",),
    "réapplaudîtes": ("réapplaudir",),
    "réapplaudit": ("réapplaudir",),
    "réapplaudît": ("réapplaudir",),
    "réapprenaient": ("réapprendre",),
    "réapprenais": ("réapprendre",),
    "réapprenait": ("réapprendre",),
    "réapprenant": ("réapprendre",),
    "réapprend": ("réapprendre",),
    "réapprendra": ("réapprendre",),
    "réapprendraient": ("réapprendre",),
    "réapprendrai": ("réapprendre",),
    "réapprendrais": ("réapprendre",),
    "réapprendrait": ("réapprendre",),
    "réapprendras": ("réapprendre",),
    "réapprendrez": ("réapprendre",),
    "réapprendriez": ("réapprendre",),
    "réapprendrions": ("réapprendre",),
    "réapprendrons": ("réapprendre",),
    "réapprendront": ("réapprendre",),
    "réapprends": ("réapprendre",),
    "réapprenez": ("réapprendre",),
    "réappreniez": ("réapprendre",),
    "réapprenions": ("réapprendre",),
    "réapprennent": ("réapprendre",),
    "réapprenne": ("réapprendre",),
    "réapprennes": ("réapprendre",),
    "réapprenons": ("réapprendre",),
    "réapprîmes": ("réapprendre",),
    "réapprirent": ("réapprendre",),
    "réapprise": ("réapprendre",),
    "réapprises": ("réapprendre",),
    "réappris": ("réapprendre",),
    "réapprissent": ("réapprendre",),
    "réapprisses": ("réapprendre",),
    "réapprisse": ("réapprendre",),
    "réapprissiez": ("réapprendre",),
    "réapprissions": ("réapprendre",),
    "réapprîtes": ("réapprendre",),
    "réapprit": ("réapprendre",),
    "réapprît": ("réapprendre",),
    "réapprofondie": ("réapprofondir",),
    "réapprofondies": ("réapprofondir",),
    "réapprofondi": ("réapprofondir",),
    "réapprofondîmes": ("réapprofondir",),
    "réapprofondira": ("réapprofondir",),
    "réapprofondiraient": ("réapprofondir",),
    "réapprofondirai": ("réapprofondir",),
    "réapprofondirais": ("réapprofondir",),
    "réapprofondirait": ("réapprofondir",),
    "réapprofondiras": ("réapprofondir",),
    "réapprofondirent": ("réapprofondir",),
    "réapprofondirez": ("réapprofondir",),
    "réapprofondiriez": ("réapprofondir",),
    "réapprofondirions": ("réapprofondir",),
    "réapprofondirons": ("réapprofondir",),
    "réapprofondiront": ("réapprofondir",),
    "réapprofondis": ("réapprofondir",),
    "réapprofondissaient": ("réapprofondir",),
    "réapprofondissais": ("réapprofondir",),
    "réapprofondissait": ("réapprofondir",),
    "réapprofondissant": ("réapprofondir",),
    "réapprofondissent": ("réapprofondir",),
    "réapprofondisse": ("réapprofondir",),
    "réapprofondisses": ("réapprofondir",),
    "réapprofondissez": ("réapprofondir",),
    "réapprofondissiez": ("réapprofondir",),
    "réapprofondissions": ("réapprofondir",),
    "réapprofondissons": ("réapprofondir",),
    "réapprofondîtes": ("réapprofondir",),
    "réapprofondit": ("réapprofondir",),
    "réapprofondît": ("réapprofondir",),
    "réappropriaient": ("réapproprier",),
    "réappropriai": ("réapproprier",),
    "réappropriais": ("réapproprier",),
    "réappropriait": ("réapproprier",),
    "réappropria": ("réapproprier",),
    "réappropriâmes": ("réapproprier",),
    "réappropriant": ("réapproprier",),
    "réapproprias": ("réapproprier",),
    "réappropriassent": ("réapproprier",),
    "réappropriasses": ("réapproprier",),
    "réappropriasse": ("réapproprier",),
    "réappropriassiez": ("réapproprier",),
    "réappropriassions": ("réapproprier",),
    "réappropriâtes": ("réapproprier",),
    "réappropriât": ("réapproprier",),
    "réappropriée": ("réapproprier",),
    "réappropriées": ("réapproprier",),
    "réapproprié": ("réapproprier",),
    "réapproprient": ("réapproprier",),
    "réapproprie": ("réapproprier",),
    "réappropriera": ("réapproprier",),
    "réapproprieraient": ("réapproprier",),
    "réapproprierai": ("réapproprier",),
    "réapproprierais": ("réapproprier",),
    "réapproprierait": ("réapproprier",),
    "réapproprieras": ("réapproprier",),
    "réapproprièrent": ("réapproprier",),
    "réapproprierez": ("réapproprier",),
    "réapproprieriez": ("réapproprier",),
    "réapproprierions": ("réapproprier",),
    "réapproprierons": ("réapproprier",),
    "réapproprieront": ("réapproprier",),
    "réappropriés": ("réapproprier",),
    "réappropries": ("réapproprier",),
    "réappropriez": ("réapproprier",),
    "réappropriiez": ("réapproprier",),
    "réappropriions": ("réapproprier",),
    "réapproprions": ("réapproprier",),
    "réappuient": ("réappuyer",),
    "réappuie": ("réappuyer",),
    "réappuiera": ("réappuyer",),
    "réappuieraient": ("réappuyer",),
    "réappuierai": ("réappuyer",),
    "réappuierais": ("réappuyer",),
    "réappuierait": ("réappuyer",),
    "réappuieras": ("réappuyer",),
    "réappuierez": ("réappuyer",),
    "réappuieriez": ("réappuyer",),
    "réappuierions": ("réappuyer",),
    "réappuierons": ("réappuyer",),
    "réappuieront": ("réappuyer",),
    "réappuies": ("réappuyer",),
    "réappuyaient": ("réappuyer",),
    "réappuyai": ("réappuyer",),
    "réappuyais": ("réappuyer",),
    "réappuyait": ("réappuyer",),
    "réappuya": ("réappuyer",),
    "réappuyâmes": ("réappuyer",),
    "réappuyant": ("réappuyer",),
    "réappuyas": ("réappuyer",),
    "réappuyassent": ("réappuyer",),
    "réappuyasses": ("réappuyer",),
    "réappuyasse": ("réappuyer",),
    "réappuyassiez": ("réappuyer",),
    "réappuyassions": ("réappuyer",),
    "réappuyâtes": ("réappuyer",),
    "réappuyât": ("réappuyer",),
    "réappuyée": ("réappuyer",),
    "réappuyées": ("réappuyer",),
    "réappuyé": ("réappuyer",),
    "réappuyèrent": ("réappuyer",),
    "réappuyés": ("réappuyer",),
    "réappuyez": ("réappuyer",),
    "réappuyiez": ("réappuyer",),
    "réappuyions": ("réappuyer",),
    "réappuyons": ("réappuyer",),
    "réarrangeaient": ("réarranger",),
    "réarrangeai": ("réarranger",),
    "réarrangeais": ("réarranger",),
    "réarrangeait": ("réarranger",),
    "réarrangea": ("réarranger",),
    "réarrangeâmes": ("réarranger",),
    "réarrangeant": ("réarranger",),
    "réarrangeas": ("réarranger",),
    "réarrangeassent": ("réarranger",),
    "réarrangeasses": ("réarranger",),
    "réarrangeasse": ("réarranger",),
    "réarrangeassiez": ("réarranger",),
    "réarrangeassions": ("réarranger",),
    "réarrangeâtes": ("réarranger",),
    "réarrangeât": ("réarranger",),
    "réarrangée": ("réarranger",),
    "réarrangées": ("réarranger",),
    "réarrangé": ("réarranger",),
    "réarrangent": ("réarranger",),
    "réarrangeons": ("réarranger",),
    "réarrange": ("réarranger",),
    "réarrangera": ("réarranger",),
    "réarrangeraient": ("réarranger",),
    "réarrangerai": ("réarranger",),
    "réarrangerais": ("réarranger",),
    "réarrangerait": ("réarranger",),
    "réarrangeras": ("réarranger",),
    "réarrangèrent": ("réarranger",),
    "réarrangerez": ("réarranger",),
    "réarrangeriez": ("réarranger",),
    "réarrangerions": ("réarranger",),
    "réarrangerons": ("réarranger",),
    "réarrangeront": ("réarranger",),
    "réarrangés": ("réarranger",),
    "réarranges": ("réarranger",),
    "réarrangez": ("réarranger",),
    "réarrangiez": ("réarranger",),
    "réarrangions": ("réarranger",),
    "réaspergeaient": ("réasperger",),
    "réaspergeai": ("réasperger",),
    "réaspergeais": ("réasperger",),
    "réaspergeait": ("réasperger",),
    "réaspergea": ("réasperger",),
    "réaspergeâmes": ("réasperger",),
    "réaspergeant": ("réasperger",),
    "réaspergeas": ("réasperger",),
    "réaspergeassent": ("réasperger",),
    "réaspergeasses": ("réasperger",),
    "réaspergeasse": ("réasperger",),
    "réaspergeassiez": ("réasperger",),
    "réaspergeassions": ("réasperger",),
    "réaspergeâtes": ("réasperger",),
    "réaspergeât": ("réasperger",),
    "réaspergée": ("réasperger",),
    "réaspergées": ("réasperger",),
    "réaspergé": ("réasperger",),
    "réaspergent": ("réasperger",),
    "réaspergeons": ("réasperger",),
    "réasperge": ("réasperger",),
    "réaspergera": ("réasperger",),
    "réaspergeraient": ("réasperger",),
    "réaspergerai": ("réasperger",),
    "réaspergerais": ("réasperger",),
    "réaspergerait": ("réasperger",),
    "réaspergeras": ("réasperger",),
    "réaspergèrent": ("réasperger",),
    "réaspergerez": ("réasperger",),
    "réaspergeriez": ("réasperger",),
    "réaspergerions": ("réasperger",),
    "réaspergerons": ("réasperger",),
    "réaspergeront": ("réasperger",),
    "réaspergés": ("réasperger",),
    "réasperges": ("réasperger",),
    "réaspergez": ("réasperger",),
    "réaspergiez": ("réasperger",),
    "réaspergions": ("réasperger",),
    "réasséchaient": ("réassécher",),
    "réasséchai": ("réassécher",),
    "réasséchais": ("réassécher",),
    "réasséchait": ("réassécher",),
    "réassécha": ("réassécher",),
    "réasséchâmes": ("réassécher",),
    "réasséchant": ("réassécher",),
    "réasséchas": ("réassécher",),
    "réasséchassent": ("réassécher",),
    "réasséchasses": ("réassécher",),
    "réasséchasse": ("réassécher",),
    "réasséchassiez": ("réassécher",),
    "réasséchassions": ("réassécher",),
    "réasséchâtes": ("réassécher",),
    "réasséchât": ("réassécher",),
    "réasséchée": ("réassécher",),
    "réasséchées": ("réassécher",),
    "réasséché": ("réassécher",),
    "réassèchent": ("réassécher",),
    "réassèche": ("réassécher",),
    "réasséchera": ("réassécher",),
    "réassécheraient": ("réassécher",),
    "réassécherai": ("réassécher",),
    "réassécherais": ("réassécher",),
    "réassécherait": ("réassécher",),
    "réassécheras": ("réassécher",),
    "réasséchèrent": ("réassécher",),
    "réassécherez": ("réassécher",),
    "réassécheriez": ("réassécher",),
    "réassécherions": ("réassécher",),
    "réassécherons": ("réassécher",),
    "réassécheront": ("réassécher",),
    "réasséchés": ("réassécher",),
    "réassèches": ("réassécher",),
    "réasséchez": ("réassécher",),
    "réasséchiez": ("réassécher",),
    "réasséchions": ("réassécher",),
    "réasséchons": ("réassécher",),
    "réasservie": ("réasservir",),
    "réasservies": ("réasservir",),
    "réasservi": ("réasservir",),
    "réasservîmes": ("réasservir",),
    "réasservira": ("réasservir",),
    "réasserviraient": ("réasservir",),
    "réasservirai": ("réasservir",),
    "réasservirais": ("réasservir",),
    "réasservirait": ("réasservir",),
    "réasserviras": ("réasservir",),
    "réasservirent": ("réasservir",),
    "réasservirez": ("réasservir",),
    "réasserviriez": ("réasservir",),
    "réasservirions": ("réasservir",),
    "réasservirons": ("réasservir",),
    "réasserviront": ("réasservir",),
    "réasservis": ("réasservir",),
    "réasservissaient": ("réasservir",),
    "réasservissais": ("réasservir",),
    "réasservissait": ("réasservir",),
    "réasservissant": ("réasservir",),
    "réasservissent": ("réasservir",),
    "réasservisse": ("réasservir",),
    "réasservisses": ("réasservir",),
    "réasservissez": ("réasservir",),
    "réasservissiez": ("réasservir",),
    "réasservissions": ("réasservir",),
    "réasservissons": ("réasservir",),
    "réasservîtes": ("réasservir",),
    "réasservit": ("réasservir",),
    "réasservît": ("réasservir",),
    "réassiégeaient": ("réassiéger",),
    "réassiégeai": ("réassiéger",),
    "réassiégeais": ("réassiéger",),
    "réassiégeait": ("réassiéger",),
    "réassiégea": ("réassiéger",),
    "réassiégeâmes": ("réassiéger",),
    "réassiégeant": ("réassiéger",),
    "réassiégeas": ("réassiéger",),
    "réassiégeassent": ("réassiéger",),
    "réassiégeasses": ("réassiéger",),
    "réassiégeasse": ("réassiéger",),
    "réassiégeassiez": ("réassiéger",),
    "réassiégeassions": ("réassiéger",),
    "réassiégeâtes": ("réassiéger",),
    "réassiégeât": ("réassiéger",),
    "réassiégée": ("réassiéger",),
    "réassiégées": ("réassiéger",),
    "réassiégé": ("réassiéger",),
    "réassiègent": ("réassiéger",),
    "réassiégeons": ("réassiéger",),
    "réassiège": ("réassiéger",),
    "réassiégera": ("réassiéger",),
    "réassiégeraient": ("réassiéger",),
    "réassiégerai": ("réassiéger",),
    "réassiégerais": ("réassiéger",),
    "réassiégerait": ("réassiéger",),
    "réassiégeras": ("réassiéger",),
    "réassiégèrent": ("réassiéger",),
    "réassiégerez": ("réassiéger",),
    "réassiégeriez": ("réassiéger",),
    "réassiégerions": ("réassiéger",),
    "réassiégerons": ("réassiéger",),
    "réassiégeront": ("réassiéger",),
    "réassiégés": ("réassiéger",),
    "réassièges": ("réassiéger",),
    "réassiégez": ("réassiéger",),
    "réassiégiez": ("réassiéger",),
    "réassiégions": ("réassiéger",),
    "réassociaient": ("réassocier",),
    "réassociai": ("réassocier",),
    "réassociais": ("réassocier",),
    "réassociait": ("réassocier",),
    "réassocia": ("réassocier",),
    "réassociâmes": ("réassocier",),
    "réassociant": ("réassocier",),
    "réassocias": ("réassocier",),
    "réassociassent": ("réassocier",),
    "réassociasses": ("réassocier",),
    "réassociasse": ("réassocier",),
    "réassociassiez": ("réassocier",),
    "réassociassions": ("réassocier",),
    "réassociâtes": ("réassocier",),
    "réassociât": ("réassocier",),
    "réassociée": ("réassocier",),
    "réassociées": ("réassocier",),
    "réassocié": ("réassocier",),
    "réassocient": ("réassocier",),
    "réassocie": ("réassocier",),
    "réassociera": ("réassocier",),
    "réassocieraient": ("réassocier",),
    "réassocierai": ("réassocier",),
    "réassocierais": ("réassocier",),
    "réassocierait": ("réassocier",),
    "réassocieras": ("réassocier",),
    "réassocièrent": ("réassocier",),
    "réassocierez": ("réassocier",),
    "réassocieriez": ("réassocier",),
    "réassocierions": ("réassocier",),
    "réassocierons": ("réassocier",),
    "réassocieront": ("réassocier",),
    "réassociés": ("réassocier",),
    "réassocies": ("réassocier",),
    "réassociez": ("réassocier",),
    "réassociiez": ("réassocier",),
    "réassociions": ("réassocier",),
    "réassocions": ("réassocier",),
    "réassortie": ("réassortir",),
    "réassorties": ("réassortir",),
    "réassorti": ("réassortir",),
    "réassortîmes": ("réassortir",),
    "réassortira": ("réassortir",),
    "réassortiraient": ("réassortir",),
    "réassortirai": ("réassortir",),
    "réassortirais": ("réassortir",),
    "réassortirait": ("réassortir",),
    "réassortiras": ("réassortir",),
    "réassortirent": ("réassortir",),
    "réassortirez": ("réassortir",),
    "réassortiriez": ("réassortir",),
    "réassortirions": ("réassortir",),
    "réassortirons": ("réassortir",),
    "réassortiront": ("réassortir",),
    "réassortis": ("réassortir",),
    "réassortissaient": ("réassortir",),
    "réassortissais": ("réassortir",),
    "réassortissait": ("réassortir",),
    "réassortissant": ("réassortir",),
    "réassortissent": ("réassortir",),
    "réassortisse": ("réassortir",),
    "réassortisses": ("réassortir",),
    "réassortissez": ("réassortir",),
    "réassortissiez": ("réassortir",),
    "réassortissions": ("réassortir",),
    "réassortissons": ("réassortir",),
    "réassortîtes": ("réassortir",),
    "réassortit": ("réassortir",),
    "réassortît": ("réassortir",),
    "réassujettie": ("réassujettir",),
    "réassujetties": ("réassujettir",),
    "réassujetti": ("réassujettir",),
    "réassujettîmes": ("réassujettir",),
    "réassujettira": ("réassujettir",),
    "réassujettiraient": ("réassujettir",),
    "réassujettirai": ("réassujettir",),
    "réassujettirais": ("réassujettir",),
    "réassujettirait": ("réassujettir",),
    "réassujettiras": ("réassujettir",),
    "réassujettirent": ("réassujettir",),
    "réassujettirez": ("réassujettir",),
    "réassujettiriez": ("réassujettir",),
    "réassujettirions": ("réassujettir",),
    "réassujettirons": ("réassujettir",),
    "réassujettiront": ("réassujettir",),
    "réassujettis": ("réassujettir",),
    "réassujettissaient": ("réassujettir",),
    "réassujettissais": ("réassujettir",),
    "réassujettissait": ("réassujettir",),
    "réassujettissant": ("réassujettir",),
    "réassujettissent": ("réassujettir",),
    "réassujettisse": ("réassujettir",),
    "réassujettisses": ("réassujettir",),
    "réassujettissez": ("réassujettir",),
    "réassujettissiez": ("réassujettir",),
    "réassujettissions": ("réassujettir",),
    "réassujettissons": ("réassujettir",),
    "réassujettîtes": ("réassujettir",),
    "réassujettit": ("réassujettir",),
    "réassujettît": ("réassujettir",),
    "réattelaient": ("réatteler",),
    "réattelai": ("réatteler",),
    "réattelais": ("réatteler",),
    "réattelait": ("réatteler",),
    "réattela": ("réatteler",),
    "réattelâmes": ("réatteler",),
    "réattelant": ("réatteler",),
    "réattelas": ("réatteler",),
    "réattelassent": ("réatteler",),
    "réattelasses": ("réatteler",),
    "réattelasse": ("réatteler",),
    "réattelassiez": ("réatteler",),
    "réattelassions": ("réatteler",),
    "réattelâtes": ("réatteler",),
    "réattelât": ("réatteler",),
    "réattelée": ("réatteler",),
    "réattelées": ("réatteler",),
    "réattelé": ("réatteler",),
    "réattelèrent": ("réatteler",),
    "réattelés": ("réatteler",),
    "réattelez": ("réatteler",),
    "réatteliez": ("réatteler",),
    "réattelions": ("réatteler",),
    "réattellent": ("réatteler",),
    "réattelle": ("réatteler",),
    "réattellera": ("réatteler",),
    "réattelleraient": ("réatteler",),
    "réattellerai": ("réatteler",),
    "réattellerais": ("réatteler",),
    "réattellerait": ("réatteler",),
    "réattelleras": ("réatteler",),
    "réattellerez": ("réatteler",),
    "réattelleriez": ("réatteler",),
    "réattellerions": ("réatteler",),
    "réattellerons": ("réatteler",),
    "réattelleront": ("réatteler",),
    "réattelles": ("réatteler",),
    "réattelons": ("réatteler",),
    "réatterrie": ("réatterrir",),
    "réatterries": ("réatterrir",),
    "réatterri": ("réatterrir",),
    "réatterrîmes": ("réatterrir",),
    "réatterrira": ("réatterrir",),
    "réatterriraient": ("réatterrir",),
    "réatterrirai": ("réatterrir",),
    "réatterrirais": ("réatterrir",),
    "réatterrirait": ("réatterrir",),
    "réatterriras": ("réatterrir",),
    "réatterrirent": ("réatterrir",),
    "réatterrirez": ("réatterrir",),
    "réatterririez": ("réatterrir",),
    "réatterririons": ("réatterrir",),
    "réatterrirons": ("réatterrir",),
    "réatterriront": ("réatterrir",),
    "réatterris": ("réatterrir",),
    "réatterrissaient": ("réatterrir",),
    "réatterrissais": ("réatterrir",),
    "réatterrissait": ("réatterrir",),
    "réatterrissant": ("réatterrir",),
    "réatterrissent": ("réatterrir",),
    "réatterrisse": ("réatterrir",),
    "réatterrisses": ("réatterrir",),
    "réatterrissez": ("réatterrir",),
    "réatterrissiez": ("réatterrir",),
    "réatterrissions": ("réatterrir",),
    "réatterrissons": ("réatterrir",),
    "réatterrîtes": ("réatterrir",),
    "réatterrit": ("réatterrir",),
    "réatterrît": ("réatterrir",),
    "réavançaient": ("réavancer",),
    "réavançai": ("réavancer",),
    "réavançais": ("réavancer",),
    "réavançait": ("réavancer",),
    "réavança": ("réavancer",),
    "réavançâmes": ("réavancer",),
    "réavançant": ("réavancer",),
    "réavanças": ("réavancer",),
    "réavançassent": ("réavancer",),
    "réavançasses": ("réavancer",),
    "réavançasse": ("réavancer",),
    "réavançassiez": ("réavancer",),
    "réavançassions": ("réavancer",),
    "réavançâtes": ("réavancer",),
    "réavançât": ("réavancer",),
    "réavancée": ("réavancer",),
    "réavancées": ("réavancer",),
    "réavancé": ("réavancer",),
    "réavancent": ("réavancer",),
    "réavance": ("réavancer",),
    "réavancera": ("réavancer",),
    "réavanceraient": ("réavancer",),
    "réavancerai": ("réavancer",),
    "réavancerais": ("réavancer",),
    "réavancerait": ("réavancer",),
    "réavanceras": ("réavancer",),
    "réavancèrent": ("réavancer",),
    "réavancerez": ("réavancer",),
    "réavanceriez": ("réavancer",),
    "réavancerions": ("réavancer",),
    "réavancerons": ("réavancer",),
    "réavanceront": ("réavancer",),
    "réavancés": ("réavancer",),
    "réavances": ("réavancer",),
    "réavancez": ("réavancer",),
    "réavanciez": ("réavancer",),
    "réavancions": ("réavancer",),
    "réavançons": ("réavancer",),
    "réavantageaient": ("réavantager",),
    "réavantageai": ("réavantager",),
    "réavantageais": ("réavantager",),
    "réavantageait": ("réavantager",),
    "réavantagea": ("réavantager",),
    "réavantageâmes": ("réavantager",),
    "réavantageant": ("réavantager",),
    "réavantageas": ("réavantager",),
    "réavantageassent": ("réavantager",),
    "réavantageasses": ("réavantager",),
    "réavantageasse": ("réavantager",),
    "réavantageassiez": ("réavantager",),
    "réavantageassions": ("réavantager",),
    "réavantageâtes": ("réavantager",),
    "réavantageât": ("réavantager",),
    "réavantagée": ("réavantager",),
    "réavantagées": ("réavantager",),
    "réavantagé": ("réavantager",),
    "réavantagent": ("réavantager",),
    "réavantageons": ("réavantager",),
    "réavantage": ("réavantager",),
    "réavantagera": ("réavantager",),
    "réavantageraient": ("réavantager",),
    "réavantagerai": ("réavantager",),
    "réavantagerais": ("réavantager",),
    "réavantagerait": ("réavantager",),
    "réavantageras": ("réavantager",),
    "réavantagèrent": ("réavantager",),
    "réavantagerez": ("réavantager",),
    "réavantageriez": ("réavantager",),
    "réavantagerions": ("réavantager",),
    "réavantagerons": ("réavantager",),
    "réavantageront": ("réavantager",),
    "réavantagés": ("réavantager",),
    "réavantages": ("réavantager",),
    "réavantagez": ("réavantager",),
    "réavantagiez": ("réavantager",),
    "réavantagions": ("réavantager",),
    "réavertie": ("réavertir",),
    "réaverties": ("réavertir",),
    "réaverti": ("réavertir",),
    "réavertîmes": ("réavertir",),
    "réavertira": ("réavertir",),
    "réavertiraient": ("réavertir",),
    "réavertirai": ("réavertir",),
    "réavertirais": ("réavertir",),
    "réavertirait": ("réavertir",),
    "réavertiras": ("réavertir",),
    "réavertirent": ("réavertir",),
    "réavertirez": ("réavertir",),
    "réavertiriez": ("réavertir",),
    "réavertirions": ("réavertir",),
    "réavertirons": ("réavertir",),
    "réavertiront": ("réavertir",),
    "réavertis": ("réavertir",),
    "réavertissaient": ("réavertir",),
    "réavertissais": ("réavertir",),
    "réavertissait": ("réavertir",),
    "réavertissant": ("réavertir",),
    "réavertissent": ("réavertir",),
    "réavertisse": ("réavertir",),
    "réavertisses": ("réavertir",),
    "réavertissez": ("réavertir",),
    "réavertissiez": ("réavertir",),
    "réavertissions": ("réavertir",),
    "réavertissons": ("réavertir",),
    "réavertîtes": ("réavertir",),
    "réavertit": ("réavertir",),
    "réavertît": ("réavertir",),
    "rebalançaient": ("rebalancer",),
    "rebalançai": ("rebalancer",),
    "rebalançais": ("rebalancer",),
    "rebalançait": ("rebalancer",),
    "rebalança": ("rebalancer",),
    "rebalançâmes": ("rebalancer",),
    "rebalançant": ("rebalancer",),
    "rebalanças": ("rebalancer",),
    "rebalançassent": ("rebalancer",),
    "rebalançasses": ("rebalancer",),
    "rebalançasse": ("rebalancer",),
    "rebalançassiez": ("rebalancer",),
    "rebalançassions": ("rebalancer",),
    "rebalançâtes": ("rebalancer",),
    "rebalançât": ("rebalancer",),
    "rebalancée": ("rebalancer",),
    "rebalancées": ("rebalancer",),
    "rebalancé": ("rebalancer",),
    "rebalancent": ("rebalancer",),
    "rebalance": ("rebalancer",),
    "rebalancera": ("rebalancer",),
    "rebalanceraient": ("rebalancer",),
    "rebalancerai": ("rebalancer",),
    "rebalancerais": ("rebalancer",),
    "rebalancerait": ("rebalancer",),
    "rebalanceras": ("rebalancer",),
    "rebalancèrent": ("rebalancer",),
    "rebalancerez": ("rebalancer",),
    "rebalanceriez": ("rebalancer",),
    "rebalancerions": ("rebalancer",),
    "rebalancerons": ("rebalancer",),
    "rebalanceront": ("rebalancer",),
    "rebalancés": ("rebalancer",),
    "rebalances": ("rebalancer",),
    "rebalancez": ("rebalancer",),
    "rebalanciez": ("rebalancer",),
    "rebalancions": ("rebalancer",),
    "rebalançons": ("rebalancer",),
    "rebalaient": ("rebalayer",),
    "rebalaie": ("rebalayer",),
    "rebalaiera": ("rebalayer",),
    "rebalaieraient": ("rebalayer",),
    "rebalaierai": ("rebalayer",),
    "rebalaierais": ("rebalayer",),
    "rebalaierait": ("rebalayer",),
    "rebalaieras": ("rebalayer",),
    "rebalaierez": ("rebalayer",),
    "rebalaieriez": ("rebalayer",),
    "rebalaierions": ("rebalayer",),
    "rebalaierons": ("rebalayer",),
    "rebalaieront": ("rebalayer",),
    "rebalaies": ("rebalayer",),
    "rebalayaient": ("rebalayer",),
    "rebalayai": ("rebalayer",),
    "rebalayais": ("rebalayer",),
    "rebalayait": ("rebalayer",),
    "rebalaya": ("rebalayer",),
    "rebalayâmes": ("rebalayer",),
    "rebalayant": ("rebalayer",),
    "rebalayas": ("rebalayer",),
    "rebalayassent": ("rebalayer",),
    "rebalayasses": ("rebalayer",),
    "rebalayasse": ("rebalayer",),
    "rebalayassiez": ("rebalayer",),
    "rebalayassions": ("rebalayer",),
    "rebalayâtes": ("rebalayer",),
    "rebalayât": ("rebalayer",),
    "rebalayée": ("rebalayer",),
    "rebalayées": ("rebalayer",),
    "rebalayé": ("rebalayer",),
    "rebalayent": ("rebalayer",),
    "rebalaye": ("rebalayer",),
    "rebalayera": ("rebalayer",),
    "rebalayeraient": ("rebalayer",),
    "rebalayerai": ("rebalayer",),
    "rebalayerais": ("rebalayer",),
    "rebalayerait": ("rebalayer",),
    "rebalayeras": ("rebalayer",),
    "rebalayèrent": ("rebalayer",),
    "rebalayerez": ("rebalayer",),
    "rebalayeriez": ("rebalayer",),
    "rebalayerions": ("rebalayer",),
    "rebalayerons": ("rebalayer",),
    "rebalayeront": ("rebalayer",),
    "rebalayés": ("rebalayer",),
    "rebalayes": ("rebalayer",),
    "rebalayez": ("rebalayer",),
    "rebalayiez": ("rebalayer",),
    "rebalayions": ("rebalayer",),
    "rebalayons": ("rebalayer",),
    "rebâtaient": ("rebâter",),
    "rebâtai": ("rebâter",),
    "rebâtais": ("rebâter",),
    "rebâtait": ("rebâter",),
    "rebâta": ("rebâter",),
    "rebâtâmes": ("rebâter",),
    "rebâtant": ("rebâter",),
    "rebâtas": ("rebâter",),
    "rebâtassent": ("rebâter",),
    "rebâtasses": ("rebâter",),
    "rebâtasse": ("rebâter",),
    "rebâtassiez": ("rebâter",),
    "rebâtassions": ("rebâter",),
    "rebâtâtes": ("rebâter",),
    "rebâtât": ("rebâter",),
    "rebâtée": ("rebâter",),
    "rebâtées": ("rebâter",),
    "rebâté": ("rebâter",),
    "rebâtent": ("rebâter",),
    "rebâte": ("rebâter",),
    "rebâtera": ("rebâter",),
    "rebâteraient": ("rebâter",),
    "rebâterai": ("rebâter",),
    "rebâterais": ("rebâter",),
    "rebâterait": ("rebâter",),
    "rebâteras": ("rebâter",),
    "rebâtèrent": ("rebâter",),
    "rebâterez": ("rebâter",),
    "rebâteriez": ("rebâter",),
    "rebâterions": ("rebâter",),
    "rebâterons": ("rebâter",),
    "rebâteront": ("rebâter",),
    "rebâtés": ("rebâter",),
    "rebâtes": ("rebâter",),
    "rebâtez": ("rebâter",),
    "rebâtiez": ("rebâter",),
    "rebâtions": ("rebâter",),
    "rebâtons": ("rebâter",),
    "rebâtie": ("rebâtir",),
    "rebâties": ("rebâtir",),
    "rebâti": ("rebâtir",),
    "rebâtîmes": ("rebâtir",),
    "rebâtira": ("rebâtir",),
    "rebâtiraient": ("rebâtir",),
    "rebâtirai": ("rebâtir",),
    "rebâtirais": ("rebâtir",),
    "rebâtirait": ("rebâtir",),
    "rebâtiras": ("rebâtir",),
    "rebâtirent": ("rebâtir",),
    "rebâtirez": ("rebâtir",),
    "rebâtiriez": ("rebâtir",),
    "rebâtirions": ("rebâtir",),
    "rebâtirons": ("rebâtir",),
    "rebâtiront": ("rebâtir",),
    "rebâtis": ("rebâtir",),
    "rebâtissaient": ("rebâtir",),
    "rebâtissais": ("rebâtir",),
    "rebâtissait": ("rebâtir",),
    "rebâtissant": ("rebâtir",),
    "rebâtissent": ("rebâtir",),
    "rebâtisse": ("rebâtir",),
    "rebâtisses": ("rebâtir",),
    "rebâtissez": ("rebâtir",),
    "rebâtissiez": ("rebâtir",),
    "rebâtissions": ("rebâtir",),
    "rebâtissons": ("rebâtir",),
    "rebâtîtes": ("rebâtir",),
    "rebâtit": ("rebâtir",),
    "rebâtît": ("rebâtir",),
    "rebat": ("rebattre",),
    "rebats": ("rebattre",),
    "rebattaient": ("rebattre",),
    "rebattais": ("rebattre",),
    "rebattait": ("rebattre",),
    "rebattant": ("rebattre",),
    "rebattent": ("rebattre",),
    "rebatte": ("rebattre",),
    "rebattes": ("rebattre",),
    "rebattez": ("rebattre",),
    "rebattiez": ("rebattre",),
    "rebattîmes": ("rebattre",),
    "rebattions": ("rebattre",),
    "rebattirent": ("rebattre",),
    "rebattis": ("rebattre",),
    "rebattissent": ("rebattre",),
    "rebattisses": ("rebattre",),
    "rebattisse": ("rebattre",),
    "rebattissiez": ("rebattre",),
    "rebattissions": ("rebattre",),
    "rebattîtes": ("rebattre",),
    "rebattit": ("rebattre",),
    "rebattît": ("rebattre",),
    "rebattons": ("rebattre",),
    "rebattra": ("rebattre",),
    "rebattraient": ("rebattre",),
    "rebattrai": ("rebattre",),
    "rebattrais": ("rebattre",),
    "rebattrait": ("rebattre",),
    "rebattras": ("rebattre",),
    "rebattrez": ("rebattre",),
    "rebattriez": ("rebattre",),
    "rebattrions": ("rebattre",),
    "rebattrons": ("rebattre",),
    "rebattront": ("rebattre",),
    "rebattue": ("rebattre",),
    "rebattues": ("rebattre",),
    "rebattu": ("rebattre",),
    "rebattus": ("rebattre",),
    "rebaudie": ("rebaudir",),
    "rebaudies": ("rebaudir",),
    "rebaudi": ("rebaudir",),
    "rebaudîmes": ("rebaudir",),
    "rebaudira": ("rebaudir",),
    "rebaudiraient": ("rebaudir",),
    "rebaudirai": ("rebaudir",),
    "rebaudirais": ("rebaudir",),
    "rebaudirait": ("rebaudir",),
    "rebaudiras": ("rebaudir",),
    "rebaudirent": ("rebaudir",),
    "rebaudirez": ("rebaudir",),
    "rebaudiriez": ("rebaudir",),
    "rebaudirions": ("rebaudir",),
    "rebaudirons": ("rebaudir",),
    "rebaudiront": ("rebaudir",),
    "rebaudis": ("rebaudir",),
    "rebaudissaient": ("rebaudir",),
    "rebaudissais": ("rebaudir",),
    "rebaudissait": ("rebaudir",),
    "rebaudissant": ("rebaudir",),
    "rebaudissent": ("rebaudir",),
    "rebaudisse": ("rebaudir",),
    "rebaudisses": ("rebaudir",),
    "rebaudissez": ("rebaudir",),
    "rebaudissiez": ("rebaudir",),
    "rebaudissions": ("rebaudir",),
    "rebaudissons": ("rebaudir",),
    "rebaudîtes": ("rebaudir",),
    "rebaudit": ("rebaudir",),
    "rebaudît": ("rebaudir",),
    "rebecquetaient": ("rebecqueter",),
    "rebecquetai": ("rebecqueter",),
    "rebecquetais": ("rebecqueter",),
    "rebecquetait": ("rebecqueter",),
    "rebecqueta": ("rebecqueter",),
    "rebecquetâmes": ("rebecqueter",),
    "rebecquetant": ("rebecqueter",),
    "rebecquetas": ("rebecqueter",),
    "rebecquetassent": ("rebecqueter",),
    "rebecquetasses": ("rebecqueter",),
    "rebecquetasse": ("rebecqueter",),
    "rebecquetassiez": ("rebecqueter",),
    "rebecquetassions": ("rebecqueter",),
    "rebecquetâtes": ("rebecqueter",),
    "rebecquetât": ("rebecqueter",),
    "rebecquetée": ("rebecqueter",),
    "rebecquetées": ("rebecqueter",),
    "rebecqueté": ("rebecqueter",),
    "rebecquetèrent": ("rebecqueter",),
    "rebecquetés": ("rebecqueter",),
    "rebecquetez": ("rebecqueter",),
    "rebecquetiez": ("rebecqueter",),
    "rebecquetions": ("rebecqueter",),
    "rebecquetons": ("rebecqueter",),
    "rebecquettent": ("rebecqueter",),
    "rebecquette": ("rebecqueter",),
    "rebecquettera": ("rebecqueter",),
    "rebecquetteraient": ("rebecqueter",),
    "rebecquetterai": ("rebecqueter",),
    "rebecquetterais": ("rebecqueter",),
    "rebecquetterait": ("rebecqueter",),
    "rebecquetteras": ("rebecqueter",),
    "rebecquetterez": ("rebecqueter",),
    "rebecquetteriez": ("rebecqueter",),
    "rebecquetterions": ("rebecqueter",),
    "rebecquetterons": ("rebecqueter",),
    "rebecquetteront": ("rebecqueter",),
    "rebecquettes": ("rebecqueter",),
    "rebénéficiaient": ("rebénéficier",),
    "rebénéficiai": ("rebénéficier",),
    "rebénéficiais": ("rebénéficier",),
    "rebénéficiait": ("rebénéficier",),
    "rebénéficia": ("rebénéficier",),
    "rebénéficiâmes": ("rebénéficier",),
    "rebénéficiant": ("rebénéficier",),
    "rebénéficias": ("rebénéficier",),
    "rebénéficiassent": ("rebénéficier",),
    "rebénéficiasses": ("rebénéficier",),
    "rebénéficiasse": ("rebénéficier",),
    "rebénéficiassiez": ("rebénéficier",),
    "rebénéficiassions": ("rebénéficier",),
    "rebénéficiâtes": ("rebénéficier",),
    "rebénéficiât": ("rebénéficier",),
    "rebénéficiée": ("rebénéficier",),
    "rebénéficiées": ("rebénéficier",),
    "rebénéficié": ("rebénéficier",),
    "rebénéficient": ("rebénéficier",),
    "rebénéficie": ("rebénéficier",),
    "rebénéficiera": ("rebénéficier",),
    "rebénéficieraient": ("rebénéficier",),
    "rebénéficierai": ("rebénéficier",),
    "rebénéficierais": ("rebénéficier",),
    "rebénéficierait": ("rebénéficier",),
    "rebénéficieras": ("rebénéficier",),
    "rebénéficièrent": ("rebénéficier",),
    "rebénéficierez": ("rebénéficier",),
    "rebénéficieriez": ("rebénéficier",),
    "rebénéficierions": ("rebénéficier",),
    "rebénéficierons": ("rebénéficier",),
    "rebénéficieront": ("rebénéficier",),
    "rebénéficiés": ("rebénéficier",),
    "rebénéficies": ("rebénéficier",),
    "rebénéficiez": ("rebénéficier",),
    "rebénéficiiez": ("rebénéficier",),
    "rebénéficiions": ("rebénéficier",),
    "rebénéficions": ("rebénéficier",),
    "rebénie": ("rebénir",),
    "rebénies": ("rebénir",),
    "rebéni": ("rebénir",),
    "rebénîmes": ("rebénir",),
    "rebénira": ("rebénir",),
    "rebéniraient": ("rebénir",),
    "rebénirai": ("rebénir",),
    "rebénirais": ("rebénir",),
    "rebénirait": ("rebénir",),
    "rebéniras": ("rebénir",),
    "rebénirent": ("rebénir",),
    "rebénirez": ("rebénir",),
    "rebéniriez": ("rebénir",),
    "rebénirions": ("rebénir",),
    "rebénirons": ("rebénir",),
    "rebéniront": ("rebénir",),
    "rebénis": ("rebénir",),
    "rebénissaient": ("rebénir",),
    "rebénissais": ("rebénir",),
    "rebénissait": ("rebénir",),
    "rebénissant": ("rebénir",),
    "rebénissent": ("rebénir",),
    "rebénisse": ("rebénir",),
    "rebénisses": ("rebénir",),
    "rebénissez": ("rebénir",),
    "rebénissiez": ("rebénir",),
    "rebénissions": ("rebénir",),
    "rebénissons": ("rebénir",),
    "rebénîtes": ("rebénir",),
    "rebénit": ("rebénir",),
    "rebénît": ("rebénir",),
    "rebéquaient": ("rebéquer",),
    "rebéquai": ("rebéquer",),
    "rebéquais": ("rebéquer",),
    "rebéquait": ("rebéquer",),
    "rebéqua": ("rebéquer",),
    "rebéquâmes": ("rebéquer",),
    "rebéquant": ("rebéquer",),
    "rebéquas": ("rebéquer",),
    "rebéquassent": ("rebéquer",),
    "rebéquasses": ("rebéquer",),
    "rebéquasse": ("rebéquer",),
    "rebéquassiez": ("rebéquer",),
    "rebéquassions": ("rebéquer",),
    "rebéquâtes": ("rebéquer",),
    "rebéquât": ("rebéquer",),
    "rebéquée": ("rebéquer",),
    "rebéquées": ("rebéquer",),
    "rebéqué": ("rebéquer",),
    "rebèquent": ("rebéquer",),
    "rebèque": ("rebéquer",),
    "rebéquera": ("rebéquer",),
    "rebéqueraient": ("rebéquer",),
    "rebéquerai": ("rebéquer",),
    "rebéquerais": ("rebéquer",),
    "rebéquerait": ("rebéquer",),
    "rebéqueras": ("rebéquer",),
    "rebéquèrent": ("rebéquer",),
    "rebéquerez": ("rebéquer",),
    "rebéqueriez": ("rebéquer",),
    "rebéquerions": ("rebéquer",),
    "rebéquerons": ("rebéquer",),
    "rebéqueront": ("rebéquer",),
    "rebéqués": ("rebéquer",),
    "rebèques": ("rebéquer",),
    "rebéquez": ("rebéquer",),
    "rebéquiez": ("rebéquer",),
    "rebéquions": ("rebéquer",),
    "rebéquons": ("rebéquer",),
    "rebéquetaient": ("rebéqueter",),
    "rebéquetai": ("rebéqueter",),
    "rebéquetais": ("rebéqueter",),
    "rebéquetait": ("rebéqueter",),
    "rebéqueta": ("rebéqueter",),
    "rebéquetâmes": ("rebéqueter",),
    "rebéquetant": ("rebéqueter",),
    "rebéquetas": ("rebéqueter",),
    "rebéquetassent": ("rebéqueter",),
    "rebéquetasses": ("rebéqueter",),
    "rebéquetasse": ("rebéqueter",),
    "rebéquetassiez": ("rebéqueter",),
    "rebéquetassions": ("rebéqueter",),
    "rebéquetâtes": ("rebéqueter",),
    "rebéquetât": ("rebéqueter",),
    "rebéquetée": ("rebéqueter",),
    "rebéquetées": ("rebéqueter",),
    "rebéqueté": ("rebéqueter",),
    "rebéquetèrent": ("rebéqueter",),
    "rebéquetés": ("rebéqueter",),
    "rebéquetez": ("rebéqueter",),
    "rebéquetiez": ("rebéqueter",),
    "rebéquetions": ("rebéqueter",),
    "rebéquetons": ("rebéqueter",),
    "rebéquettent": ("rebéqueter",),
    "rebéquette": ("rebéqueter",),
    "rebéquettera": ("rebéqueter",),
    "rebéquetteraient": ("rebéqueter",),
    "rebéquetterai": ("rebéqueter",),
    "rebéquetterais": ("rebéqueter",),
    "rebéquetterait": ("rebéqueter",),
    "rebéquetteras": ("rebéqueter",),
    "rebéquetterez": ("rebéqueter",),
    "rebéquetteriez": ("rebéqueter",),
    "rebéquetterions": ("rebéqueter",),
    "rebéquetterons": ("rebéqueter",),
    "rebéquetteront": ("rebéqueter",),
    "rebéquettes": ("rebéqueter",),
    "reberçaient": ("rebercer",),
    "reberçai": ("rebercer",),
    "reberçais": ("rebercer",),
    "reberçait": ("rebercer",),
    "reberça": ("rebercer",),
    "reberçâmes": ("rebercer",),
    "reberçant": ("rebercer",),
    "reberças": ("rebercer",),
    "reberçassent": ("rebercer",),
    "reberçasses": ("rebercer",),
    "reberçasse": ("rebercer",),
    "reberçassiez": ("rebercer",),
    "reberçassions": ("rebercer",),
    "reberçâtes": ("rebercer",),
    "reberçât": ("rebercer",),
    "rebercée": ("rebercer",),
    "rebercées": ("rebercer",),
    "rebercé": ("rebercer",),
    "rebercent": ("rebercer",),
    "reberce": ("rebercer",),
    "rebercera": ("rebercer",),
    "reberceraient": ("rebercer",),
    "rebercerai": ("rebercer",),
    "rebercerais": ("rebercer",),
    "rebercerait": ("rebercer",),
    "reberceras": ("rebercer",),
    "rebercèrent": ("rebercer",),
    "rebercerez": ("rebercer",),
    "reberceriez": ("rebercer",),
    "rebercerions": ("rebercer",),
    "rebercerons": ("rebercer",),
    "reberceront": ("rebercer",),
    "rebercés": ("rebercer",),
    "reberces": ("rebercer",),
    "rebercez": ("rebercer",),
    "reberciez": ("rebercer",),
    "rebercions": ("rebercer",),
    "reberçons": ("rebercer",),
    "reblanchie": ("reblanchir",),
    "reblanchies": ("reblanchir",),
    "reblanchi": ("reblanchir",),
    "reblanchîmes": ("reblanchir",),
    "reblanchira": ("reblanchir",),
    "reblanchiraient": ("reblanchir",),
    "reblanchirai": ("reblanchir",),
    "reblanchirais": ("reblanchir",),
    "reblanchirait": ("reblanchir",),
    "reblanchiras": ("reblanchir",),
    "reblanchirent": ("reblanchir",),
    "reblanchirez": ("reblanchir",),
    "reblanchiriez": ("reblanchir",),
    "reblanchirions": ("reblanchir",),
    "reblanchirons": ("reblanchir",),
    "reblanchiront": ("reblanchir",),
    "reblanchis": ("reblanchir",),
    "reblanchissaient": ("reblanchir",),
    "reblanchissais": ("reblanchir",),
    "reblanchissait": ("reblanchir",),
    "reblanchissant": ("reblanchir",),
    "reblanchissent": ("reblanchir",),
    "reblanchisse": ("reblanchir",),
    "reblanchisses": ("reblanchir",),
    "reblanchissez": ("reblanchir",),
    "reblanchissiez": ("reblanchir",),
    "reblanchissions": ("reblanchir",),
    "reblanchissons": ("reblanchir",),
    "reblanchîtes": ("reblanchir",),
    "reblanchit": ("reblanchir",),
    "reblanchît": ("reblanchir",),
    "reblandie": ("reblandir",),
    "reblandies": ("reblandir",),
    "reblandi": ("reblandir",),
    "reblandîmes": ("reblandir",),
    "reblandira": ("reblandir",),
    "reblandiraient": ("reblandir",),
    "reblandirai": ("reblandir",),
    "reblandirais": ("reblandir",),
    "reblandirait": ("reblandir",),
    "reblandiras": ("reblandir",),
    "reblandirent": ("reblandir",),
    "reblandirez": ("reblandir",),
    "reblandiriez": ("reblandir",),
    "reblandirions": ("reblandir",),
    "reblandirons": ("reblandir",),
    "reblandiront": ("reblandir",),
    "reblandis": ("reblandir",),
    "reblandissaient": ("reblandir",),
    "reblandissais": ("reblandir",),
    "reblandissait": ("reblandir",),
    "reblandissant": ("reblandir",),
    "reblandissent": ("reblandir",),
    "reblandisse": ("reblandir",),
    "reblandisses": ("reblandir",),
    "reblandissez": ("reblandir",),
    "reblandissiez": ("reblandir",),
    "reblandissions": ("reblandir",),
    "reblandissons": ("reblandir",),
    "reblandîtes": ("reblandir",),
    "reblandit": ("reblandir",),
    "reblandît": ("reblandir",),
    "reblottie": ("reblottir",),
    "reblotties": ("reblottir",),
    "reblotti": ("reblottir",),
    "reblottîmes": ("reblottir",),
    "reblottira": ("reblottir",),
    "reblottiraient": ("reblottir",),
    "reblottirai": ("reblottir",),
    "reblottirais": ("reblottir",),
    "reblottirait": ("reblottir",),
    "reblottiras": ("reblottir",),
    "reblottirent": ("reblottir",),
    "reblottirez": ("reblottir",),
    "reblottiriez": ("reblottir",),
    "reblottirions": ("reblottir",),
    "reblottirons": ("reblottir",),
    "reblottiront": ("reblottir",),
    "reblottis": ("reblottir",),
    "reblottissaient": ("reblottir",),
    "reblottissais": ("reblottir",),
    "reblottissait": ("reblottir",),
    "reblottissant": ("reblottir",),
    "reblottissent": ("reblottir",),
    "reblottisse": ("reblottir",),
    "reblottisses": ("reblottir",),
    "reblottissez": ("reblottir",),
    "reblottissiez": ("reblottir",),
    "reblottissions": ("reblottir",),
    "reblottissons": ("reblottir",),
    "reblottîtes": ("reblottir",),
    "reblottit": ("reblottir",),
    "reblottît": ("reblottir",),
    "reboira": ("reboire",),
    "reboiraient": ("reboire",),
    "reboirai": ("reboire",),
    "reboirais": ("reboire",),
    "reboirait": ("reboire",),
    "reboiras": ("reboire",),
    "reboirez": ("reboire",),
    "reboiriez": ("reboire",),
    "reboirions": ("reboire",),
    "reboirons": ("reboire",),
    "reboiront": ("reboire",),
    "rebois": ("reboire",),
    "reboit": ("reboire",),
    "reboivent": ("reboire",),
    "reboive": ("reboire",),
    "reboives": ("reboire",),
    "rebue": ("reboire",),
    "rebues": ("reboire",),
    "rebu": ("reboire",),
    "rebûmes": ("reboire",),
    "reburent": ("reboire",),
    "rebus": ("reboire",),
    "rebussent": ("reboire",),
    "rebusses": ("reboire",),
    "rebusse": ("reboire",),
    "rebussiez": ("reboire",),
    "rebussions": ("reboire",),
    "rebûtes": ("reboire",),
    "rebut": ("reboire",),
    "rebût": ("reboire",),
    "rebuvaient": ("reboire",),
    "rebuvais": ("reboire",),
    "rebuvait": ("reboire",),
    "rebuvant": ("reboire",),
    "rebuvez": ("reboire",),
    "rebuviez": ("reboire",),
    "rebuvions": ("reboire",),
    "rebuvons": ("reboire",),
    "rebondie": ("rebondir",),
    "rebondies": ("rebondir",),
    "rebondi": ("rebondir",),
    "rebondîmes": ("rebondir",),
    "rebondira": ("rebondir",),
    "rebondiraient": ("rebondir",),
    "rebondirai": ("rebondir",),
    "rebondirais": ("rebondir",),
    "rebondirait": ("rebondir",),
    "rebondiras": ("rebondir",),
    "rebondirent": ("rebondir",),
    "rebondirez": ("rebondir",),
    "rebondiriez": ("rebondir",),
    "rebondirions": ("rebondir",),
    "rebondirons": ("rebondir",),
    "rebondiront": ("rebondir",),
    "rebondis": ("rebondir",),
    "rebondissaient": ("rebondir",),
    "rebondissais": ("rebondir",),
    "rebondissait": ("rebondir",),
    "rebondissant": ("rebondir",),
    "rebondissent": ("rebondir",),
    "rebondisse": ("rebondir",),
    "rebondisses": ("rebondir",),
    "rebondissez": ("rebondir",),
    "rebondissiez": ("rebondir",),
    "rebondissions": ("rebondir",),
    "rebondissons": ("rebondir",),
    "rebondîtes": ("rebondir",),
    "rebondit": ("rebondir",),
    "rebondît": ("rebondir",),
    "rebouillaient": ("rebouillir",),
    "rebouillais": ("rebouillir",),
    "rebouillait": ("rebouillir",),
    "rebouillant": ("rebouillir",),
    "rebouillent": ("rebouillir",),
    "rebouille": ("rebouillir",),
    "rebouilles": ("rebouillir",),
    "rebouillez": ("rebouillir",),
    "rebouillie": ("rebouillir",),
    "rebouillies": ("rebouillir",),
    "rebouilliez": ("rebouillir",),
    "rebouilli": ("rebouillir",),
    "rebouillîmes": ("rebouillir",),
    "rebouillions": ("rebouillir",),
    "rebouillira": ("rebouillir",),
    "rebouilliraient": ("rebouillir",),
    "rebouillirai": ("rebouillir",),
    "rebouillirais": ("rebouillir",),
    "rebouillirait": ("rebouillir",),
    "rebouilliras": ("rebouillir",),
    "rebouillirent": ("rebouillir",),
    "rebouillirez": ("rebouillir",),
    "rebouilliriez": ("rebouillir",),
    "rebouillirions": ("rebouillir",),
    "rebouillirons": ("rebouillir",),
    "rebouilliront": ("rebouillir",),
    "rebouillis": ("rebouillir",),
    "rebouillissent": ("rebouillir",),
    "rebouillisses": ("rebouillir",),
    "rebouillisse": ("rebouillir",),
    "rebouillissiez": ("rebouillir",),
    "rebouillissions": ("rebouillir",),
    "rebouillîtes": ("rebouillir",),
    "rebouillit": ("rebouillir",),
    "rebouillît": ("rebouillir",),
    "rebouillons": ("rebouillir",),
    "rebous": ("rebouillir",),
    "rebout": ("rebouillir",),
    "rebrandie": ("rebrandir",),
    "rebrandies": ("rebrandir",),
    "rebrandi": ("rebrandir",),
    "rebrandîmes": ("rebrandir",),
    "rebrandira": ("rebrandir",),
    "rebrandiraient": ("rebrandir",),
    "rebrandirai": ("rebrandir",),
    "rebrandirais": ("rebrandir",),
    "rebrandirait": ("rebrandir",),
    "rebrandiras": ("rebrandir",),
    "rebrandirent": ("rebrandir",),
    "rebrandirez": ("rebrandir",),
    "rebrandiriez": ("rebrandir",),
    "rebrandirions": ("rebrandir",),
    "rebrandirons": ("rebrandir",),
    "rebrandiront": ("rebrandir",),
    "rebrandis": ("rebrandir",),
    "rebrandissaient": ("rebrandir",),
    "rebrandissais": ("rebrandir",),
    "rebrandissait": ("rebrandir",),
    "rebrandissant": ("rebrandir",),
    "rebrandissent": ("rebrandir",),
    "rebrandisse": ("rebrandir",),
    "rebrandisses": ("rebrandir",),
    "rebrandissez": ("rebrandir",),
    "rebrandissiez": ("rebrandir",),
    "rebrandissions": ("rebrandir",),
    "rebrandissons": ("rebrandir",),
    "rebrandîtes": ("rebrandir",),
    "rebrandit": ("rebrandir",),
    "rebrandît": ("rebrandir",),
    "rebrassaient": ("rebrasser",),
    "rebrassai": ("rebrasser",),
    "rebrassais": ("rebrasser",),
    "rebrassait": ("rebrasser",),
    "rebrassa": ("rebrasser",),
    "rebrassâmes": ("rebrasser",),
    "rebrassant": ("rebrasser",),
    "rebrassas": ("rebrasser",),
    "rebrassassent": ("rebrasser",),
    "rebrassasses": ("rebrasser",),
    "rebrassasse": ("rebrasser",),
    "rebrassassiez": ("rebrasser",),
    "rebrassassions": ("rebrasser",),
    "rebrassâtes": ("rebrasser",),
    "rebrassât": ("rebrasser",),
    "rebrassée": ("rebrasser",),
    "rebrassées": ("rebrasser",),
    "rebrassé": ("rebrasser",),
    "rebrassent": ("rebrasser",),
    "rebrasse": ("rebrasser",),
    "rebrassera": ("rebrasser",),
    "rebrasseraient": ("rebrasser",),
    "rebrasserai": ("rebrasser",),
    "rebrasserais": ("rebrasser",),
    "rebrasserait": ("rebrasser",),
    "rebrasseras": ("rebrasser",),
    "rebrassèrent": ("rebrasser",),
    "rebrasserez": ("rebrasser",),
    "rebrasseriez": ("rebrasser",),
    "rebrasserions": ("rebrasser",),
    "rebrasserons": ("rebrasser",),
    "rebrasseront": ("rebrasser",),
    "rebrassés": ("rebrasser",),
    "rebrasses": ("rebrasser",),
    "rebrassez": ("rebrasser",),
    "rebrassiez": ("rebrasser",),
    "rebrassions": ("rebrasser",),
    "rebrassons": ("rebrasser",),
    "rebridgeaient": ("rebridger",),
    "rebridgeai": ("rebridger",),
    "rebridgeais": ("rebridger",),
    "rebridgeait": ("rebridger",),
    "rebridgea": ("rebridger",),
    "rebridgeâmes": ("rebridger",),
    "rebridgeant": ("rebridger",),
    "rebridgeas": ("rebridger",),
    "rebridgeassent": ("rebridger",),
    "rebridgeasses": ("rebridger",),
    "rebridgeasse": ("rebridger",),
    "rebridgeassiez": ("rebridger",),
    "rebridgeassions": ("rebridger",),
    "rebridgeâtes": ("rebridger",),
    "rebridgeât": ("rebridger",),
    "rebridgée": ("rebridger",),
    "rebridgées": ("rebridger",),
    "rebridgé": ("rebridger",),
    "rebridgent": ("rebridger",),
    "rebridgeons": ("rebridger",),
    "rebridge": ("rebridger",),
    "rebridgera": ("rebridger",),
    "rebridgeraient": ("rebridger",),
    "rebridgerai": ("rebridger",),
    "rebridgerais": ("rebridger",),
    "rebridgerait": ("rebridger",),
    "rebridgeras": ("rebridger",),
    "rebridgèrent": ("rebridger",),
    "rebridgerez": ("rebridger",),
    "rebridgeriez": ("rebridger",),
    "rebridgerions": ("rebridger",),
    "rebridgerons": ("rebridger",),
    "rebridgeront": ("rebridger",),
    "rebridgés": ("rebridger",),
    "rebridges": ("rebridger",),
    "rebridgez": ("rebridger",),
    "rebridgiez": ("rebridger",),
    "rebridgions": ("rebridger",),
    "rebrunie": ("rebrunir",),
    "rebrunies": ("rebrunir",),
    "rebruni": ("rebrunir",),
    "rebrunîmes": ("rebrunir",),
    "rebrunira": ("rebrunir",),
    "rebruniraient": ("rebrunir",),
    "rebrunirai": ("rebrunir",),
    "rebrunirais": ("rebrunir",),
    "rebrunirait": ("rebrunir",),
    "rebruniras": ("rebrunir",),
    "rebrunirent": ("rebrunir",),
    "rebrunirez": ("rebrunir",),
    "rebruniriez": ("rebrunir",),
    "rebrunirions": ("rebrunir",),
    "rebrunirons": ("rebrunir",),
    "rebruniront": ("rebrunir",),
    "rebrunis": ("rebrunir",),
    "rebrunissaient": ("rebrunir",),
    "rebrunissais": ("rebrunir",),
    "rebrunissait": ("rebrunir",),
    "rebrunissant": ("rebrunir",),
    "rebrunissent": ("rebrunir",),
    "rebrunisse": ("rebrunir",),
    "rebrunisses": ("rebrunir",),
    "rebrunissez": ("rebrunir",),
    "rebrunissiez": ("rebrunir",),
    "rebrunissions": ("rebrunir",),
    "rebrunissons": ("rebrunir",),
    "rebrunîtes": ("rebrunir",),
    "rebrunit": ("rebrunir",),
    "rebrunît": ("rebrunir",),
    "recachetaient": ("recacheter",),
    "recachetai": ("recacheter",),
    "recachetais": ("recacheter",),
    "recachetait": ("recacheter",),
    "recacheta": ("recacheter",),
    "recachetâmes": ("recacheter",),
    "recachetant": ("recacheter",),
    "recachetas": ("recacheter",),
    "recachetassent": ("recacheter",),
    "recachetasses": ("recacheter",),
    "recachetasse": ("recacheter",),
    "recachetassiez": ("recacheter",),
    "recachetassions": ("recacheter",),
    "recachetâtes": ("recacheter",),
    "recachetât": ("recacheter",),
    "recachetée": ("recacheter",),
    "recachetées": ("recacheter",),
    "recacheté": ("recacheter",),
    "recachetèrent": ("recacheter",),
    "recachetés": ("recacheter",),
    "recachetez": ("recacheter",),
    "recachetiez": ("recacheter",),
    "recachetions": ("recacheter",),
    "recachetons": ("recacheter",),
    "recachettent": ("recacheter",),
    "recachette": ("recacheter",),
    "recachettera": ("recacheter",),
    "recachetteraient": ("recacheter",),
    "recachetterai": ("recacheter",),
    "recachetterais": ("recacheter",),
    "recachetterait": ("recacheter",),
    "recachetteras": ("recacheter",),
    "recachetterez": ("recacheter",),
    "recachetteriez": ("recacheter",),
    "recachetterions": ("recacheter",),
    "recachetterons": ("recacheter",),
    "recachetteront": ("recacheter",),
    "recachettes": ("recacheter",),
    "recadenassaient": ("recadenasser",),
    "recadenassai": ("recadenasser",),
    "recadenassais": ("recadenasser",),
    "recadenassait": ("recadenasser",),
    "recadenassa": ("recadenasser",),
    "recadenassâmes": ("recadenasser",),
    "recadenassant": ("recadenasser",),
    "recadenassas": ("recadenasser",),
    "recadenassassent": ("recadenasser",),
    "recadenassasses": ("recadenasser",),
    "recadenassasse": ("recadenasser",),
    "recadenassassiez": ("recadenasser",),
    "recadenassassions": ("recadenasser",),
    "recadenassâtes": ("recadenasser",),
    "recadenassât": ("recadenasser",),
    "recadenassée": ("recadenasser",),
    "recadenassées": ("recadenasser",),
    "recadenassé": ("recadenasser",),
    "recadenassent": ("recadenasser",),
    "recadenasse": ("recadenasser",),
    "recadenassera": ("recadenasser",),
    "recadenasseraient": ("recadenasser",),
    "recadenasserai": ("recadenasser",),
    "recadenasserais": ("recadenasser",),
    "recadenasserait": ("recadenasser",),
    "recadenasseras": ("recadenasser",),
    "recadenassèrent": ("recadenasser",),
    "recadenasserez": ("recadenasser",),
    "recadenasseriez": ("recadenasser",),
    "recadenasserions": ("recadenasser",),
    "recadenasserons": ("recadenasser",),
    "recadenasseront": ("recadenasser",),
    "recadenassés": ("recadenasser",),
    "recadenasses": ("recadenasser",),
    "recadenassez": ("recadenasser",),
    "recadenassiez": ("recadenasser",),
    "recadenassions": ("recadenasser",),
    "recadenassons": ("recadenasser",),
    "recadençaient": ("recadencer",),
    "recadençai": ("recadencer",),
    "recadençais": ("recadencer",),
    "recadençait": ("recadencer",),
    "recadença": ("recadencer",),
    "recadençâmes": ("recadencer",),
    "recadençant": ("recadencer",),
    "recadenças": ("recadencer",),
    "recadençassent": ("recadencer",),
    "recadençasses": ("recadencer",),
    "recadençasse": ("recadencer",),
    "recadençassiez": ("recadencer",),
    "recadençassions": ("recadencer",),
    "recadençâtes": ("recadencer",),
    "recadençât": ("recadencer",),
    "recadencée": ("recadencer",),
    "recadencées": ("recadencer",),
    "recadencé": ("recadencer",),
    "recadencent": ("recadencer",),
    "recadence": ("recadencer",),
    "recadencera": ("recadencer",),
    "recadenceraient": ("recadencer",),
    "recadencerai": ("recadencer",),
    "recadencerais": ("recadencer",),
    "recadencerait": ("recadencer",),
    "recadenceras": ("recadencer",),
    "recadencèrent": ("recadencer",),
    "recadencerez": ("recadencer",),
    "recadenceriez": ("recadencer",),
    "recadencerions": ("recadencer",),
    "recadencerons": ("recadencer",),
    "recadenceront": ("recadencer",),
    "recadencés": ("recadencer",),
    "recadences": ("recadencer",),
    "recadencez": ("recadencer",),
    "recadenciez": ("recadencer",),
    "recadencions": ("recadencer",),
    "recadençons": ("recadencer",),
    "recalcifiaient": ("recalcifier",),
    "recalcifiai": ("recalcifier",),
    "recalcifiais": ("recalcifier",),
    "recalcifiait": ("recalcifier",),
    "recalcifia": ("recalcifier",),
    "recalcifiâmes": ("recalcifier",),
    "recalcifiant": ("recalcifier",),
    "recalcifias": ("recalcifier",),
    "recalcifiassent": ("recalcifier",),
    "recalcifiasses": ("recalcifier",),
    "recalcifiasse": ("recalcifier",),
    "recalcifiassiez": ("recalcifier",),
    "recalcifiassions": ("recalcifier",),
    "recalcifiâtes": ("recalcifier",),
    "recalcifiât": ("recalcifier",),
    "recalcifiée": ("recalcifier",),
    "recalcifiées": ("recalcifier",),
    "recalcifié": ("recalcifier",),
    "recalcifient": ("recalcifier",),
    "recalcifie": ("recalcifier",),
    "recalcifiera": ("recalcifier",),
    "recalcifieraient": ("recalcifier",),
    "recalcifierai": ("recalcifier",),
    "recalcifierais": ("recalcifier",),
    "recalcifierait": ("recalcifier",),
    "recalcifieras": ("recalcifier",),
    "recalcifièrent": ("recalcifier",),
    "recalcifierez": ("recalcifier",),
    "recalcifieriez": ("recalcifier",),
    "recalcifierions": ("recalcifier",),
    "recalcifierons": ("recalcifier",),
    "recalcifieront": ("recalcifier",),
    "recalcifiés": ("recalcifier",),
    "recalcifies": ("recalcifier",),
    "recalcifiez": ("recalcifier",),
    "recalcifiiez": ("recalcifier",),
    "recalcifiions": ("recalcifier",),
    "recalcifions": ("recalcifier",),
    "recalorifugeaient": ("recalorifuger",),
    "recalorifugeai": ("recalorifuger",),
    "recalorifugeais": ("recalorifuger",),
    "recalorifugeait": ("recalorifuger",),
    "recalorifugea": ("recalorifuger",),
    "recalorifugeâmes": ("recalorifuger",),
    "recalorifugeant": ("recalorifuger",),
    "recalorifugeas": ("recalorifuger",),
    "recalorifugeassent": ("recalorifuger",),
    "recalorifugeasses": ("recalorifuger",),
    "recalorifugeasse": ("recalorifuger",),
    "recalorifugeassiez": ("recalorifuger",),
    "recalorifugeassions": ("recalorifuger",),
    "recalorifugeâtes": ("recalorifuger",),
    "recalorifugeât": ("recalorifuger",),
    "recalorifugée": ("recalorifuger",),
    "recalorifugées": ("recalorifuger",),
    "recalorifugé": ("recalorifuger",),
    "recalorifugent": ("recalorifuger",),
    "recalorifugeons": ("recalorifuger",),
    "recalorifuge": ("recalorifuger",),
    "recalorifugera": ("recalorifuger",),
    "recalorifugeraient": ("recalorifuger",),
    "recalorifugerai": ("recalorifuger",),
    "recalorifugerais": ("recalorifuger",),
    "recalorifugerait": ("recalorifuger",),
    "recalorifugeras": ("recalorifuger",),
    "recalorifugèrent": ("recalorifuger",),
    "recalorifugerez": ("recalorifuger",),
    "recalorifugeriez": ("recalorifuger",),
    "recalorifugerions": ("recalorifuger",),
    "recalorifugerons": ("recalorifuger",),
    "recalorifugeront": ("recalorifuger",),
    "recalorifugés": ("recalorifuger",),
    "recalorifuges": ("recalorifuger",),
    "recalorifugez": ("recalorifuger",),
    "recalorifugiez": ("recalorifuger",),
    "recalorifugions": ("recalorifuger",),
    "recarénaient": ("recaréner",),
    "recarénai": ("recaréner",),
    "recarénais": ("recaréner",),
    "recarénait": ("recaréner",),
    "recaréna": ("recaréner",),
    "recarénâmes": ("recaréner",),
    "recarénant": ("recaréner",),
    "recarénas": ("recaréner",),
    "recarénassent": ("recaréner",),
    "recarénasses": ("recaréner",),
    "recarénasse": ("recaréner",),
    "recarénassiez": ("recaréner",),
    "recarénassions": ("recaréner",),
    "recarénâtes": ("recaréner",),
    "recarénât": ("recaréner",),
    "recarénée": ("recaréner",),
    "recarénées": ("recaréner",),
    "recaréné": ("recaréner",),
    "recarènent": ("recaréner",),
    "recarène": ("recaréner",),
    "recarénera": ("recaréner",),
    "recaréneraient": ("recaréner",),
    "recarénerai": ("recaréner",),
    "recarénerais": ("recaréner",),
    "recarénerait": ("recaréner",),
    "recaréneras": ("recaréner",),
    "recarénèrent": ("recaréner",),
    "recarénerez": ("recaréner",),
    "recaréneriez": ("recaréner",),
    "recarénerions": ("recaréner",),
    "recarénerons": ("recaréner",),
    "recaréneront": ("recaréner",),
    "recarénés": ("recaréner",),
    "recarènes": ("recaréner",),
    "recarénez": ("recaréner",),
    "recaréniez": ("recaréner",),
    "recarénions": ("recaréner",),
    "recarénons": ("recaréner",),
    "recarrelaient": ("recarreler",),
    "recarrelai": ("recarreler",),
    "recarrelais": ("recarreler",),
    "recarrelait": ("recarreler",),
    "recarrela": ("recarreler",),
    "recarrelâmes": ("recarreler",),
    "recarrelant": ("recarreler",),
    "recarrelas": ("recarreler",),
    "recarrelassent": ("recarreler",),
    "recarrelasses": ("recarreler",),
    "recarrelasse": ("recarreler",),
    "recarrelassiez": ("recarreler",),
    "recarrelassions": ("recarreler",),
    "recarrelâtes": ("recarreler",),
    "recarrelât": ("recarreler",),
    "recarrelée": ("recarreler",),
    "recarrelées": ("recarreler",),
    "recarrelé": ("recarreler",),
    "recarrelèrent": ("recarreler",),
    "recarrelés": ("recarreler",),
    "recarrelez": ("recarreler",),
    "recarreliez": ("recarreler",),
    "recarrelions": ("recarreler",),
    "recarrellent": ("recarreler",),
    "recarrelle": ("recarreler",),
    "recarrellera": ("recarreler",),
    "recarrelleraient": ("recarreler",),
    "recarrellerai": ("recarreler",),
    "recarrellerais": ("recarreler",),
    "recarrellerait": ("recarreler",),
    "recarrelleras": ("recarreler",),
    "recarrellerez": ("recarreler",),
    "recarrelleriez": ("recarreler",),
    "recarrellerions": ("recarreler",),
    "recarrellerons": ("recarreler",),
    "recarrelleront": ("recarreler",),
    "recarrelles": ("recarreler",),
    "recarrelons": ("recarreler",),
    "recassaient": ("recasser",),
    "recassai": ("recasser",),
    "recassais": ("recasser",),
    "recassait": ("recasser",),
    "recassa": ("recasser",),
    "recassâmes": ("recasser",),
    "recassant": ("recasser",),
    "recassas": ("recasser",),
    "recassassent": ("recasser",),
    "recassasses": ("recasser",),
    "recassasse": ("recasser",),
    "recassassiez": ("recasser",),
    "recassassions": ("recasser",),
    "recassâtes": ("recasser",),
    "recassât": ("recasser",),
    "recassée": ("recasser",),
    "recassées": ("recasser",),
    "recassé": ("recasser",),
    "recassent": ("recasser",),
    "recasse": ("recasser",),
    "recassera": ("recasser",),
    "recasseraient": ("recasser",),
    "recasserai": ("recasser",),
    "recasserais": ("recasser",),
    "recasserait": ("recasser",),
    "recasseras": ("recasser",),
    "recassèrent": ("recasser",),
    "recasserez": ("recasser",),
    "recasseriez": ("recasser",),
    "recasserions": ("recasser",),
    "recasserons": ("recasser",),
    "recasseront": ("recasser",),
    "recassés": ("recasser",),
    "recasses": ("recasser",),
    "recassez": ("recasser",),
    "recassiez": ("recasser",),
    "recassions": ("recasser",),
    "recassons": ("recasser",),
    "recédaient": ("recéder",),
    "recédai": ("recéder",),
    "recédais": ("recéder",),
    "recédait": ("recéder",),
    "recéda": ("recéder",),
    "recédâmes": ("recéder",),
    "recédant": ("recéder",),
    "recédas": ("recéder",),
    "recédassent": ("recéder",),
    "recédasses": ("recéder",),
    "recédasse": ("recéder",),
    "recédassiez": ("recéder",),
    "recédassions": ("recéder",),
    "recédâtes": ("recéder",),
    "recédât": ("recéder",),
    "recédée": ("recéder",),
    "recédées": ("recéder",),
    "recédé": ("recéder",),
    "recèdent": ("recéder",),
    "recède": ("recéder",),
    "recédera": ("recéder",),
    "recéderaient": ("recéder",),
    "recéderai": ("recéder",),
    "recéderais": ("recéder",),
    "recéderait": ("recéder",),
    "recéderas": ("recéder",),
    "recédèrent": ("recéder",),
    "recéderez": ("recéder",),
    "recéderiez": ("recéder",),
    "recéderions": ("recéder",),
    "recéderons": ("recéder",),
    "recéderont": ("recéder",),
    "recédés": ("recéder",),
    "recèdes": ("recéder",),
    "recédez": ("recéder",),
    "recédiez": ("recéder",),
    "recédions": ("recéder",),
    "recédons": ("recéder",),
    "recélébraient": ("recélébrer",),
    "recélébrai": ("recélébrer",),
    "recélébrais": ("recélébrer",),
    "recélébrait": ("recélébrer",),
    "recélébra": ("recélébrer",),
    "recélébrâmes": ("recélébrer",),
    "recélébrant": ("recélébrer",),
    "recélébras": ("recélébrer",),
    "recélébrassent": ("recélébrer",),
    "recélébrasses": ("recélébrer",),
    "recélébrasse": ("recélébrer",),
    "recélébrassiez": ("recélébrer",),
    "recélébrassions": ("recélébrer",),
    "recélébrâtes": ("recélébrer",),
    "recélébrât": ("recélébrer",),
    "recélébrée": ("recélébrer",),
    "recélébrées": ("recélébrer",),
    "recélébré": ("recélébrer",),
    "recélèbrent": ("recélébrer",),
    "recélèbre": ("recélébrer",),
    "recélébrera": ("recélébrer",),
    "recélébreraient": ("recélébrer",),
    "recélébrerai": ("recélébrer",),
    "recélébrerais": ("recélébrer",),
    "recélébrerait": ("recélébrer",),
    "recélébreras": ("recélébrer",),
    "recélébrèrent": ("recélébrer",),
    "recélébrerez": ("recélébrer",),
    "recélébreriez": ("recélébrer",),
    "recélébrerions": ("recélébrer",),
    "recélébrerons": ("recélébrer",),
    "recélébreront": ("recélébrer",),
    "recélébrés": ("recélébrer",),
    "recélèbres": ("recélébrer",),
    "recélébrez": ("recélébrer",),
    "recélébriez": ("recélébrer",),
    "recélébrions": ("recélébrer",),
    "recélébrons": ("recélébrer",),
    "recertifiaient": ("recertifier",),
    "recertifiai": ("recertifier",),
    "recertifiais": ("recertifier",),
    "recertifiait": ("recertifier",),
    "recertifia": ("recertifier",),
    "recertifiâmes": ("recertifier",),
    "recertifiant": ("recertifier",),
    "recertifias": ("recertifier",),
    "recertifiassent": ("recertifier",),
    "recertifiasses": ("recertifier",),
    "recertifiasse": ("recertifier",),
    "recertifiassiez": ("recertifier",),
    "recertifiassions": ("recertifier",),
    "recertifiâtes": ("recertifier",),
    "recertifiât": ("recertifier",),
    "recertifiée": ("recertifier",),
    "recertifiées": ("recertifier",),
    "recertifié": ("recertifier",),
    "recertifient": ("recertifier",),
    "recertifie": ("recertifier",),
    "recertifiera": ("recertifier",),
    "recertifieraient": ("recertifier",),
    "recertifierai": ("recertifier",),
    "recertifierais": ("recertifier",),
    "recertifierait": ("recertifier",),
    "recertifieras": ("recertifier",),
    "recertifièrent": ("recertifier",),
    "recertifierez": ("recertifier",),
    "recertifieriez": ("recertifier",),
    "recertifierions": ("recertifier",),
    "recertifierons": ("recertifier",),
    "recertifieront": ("recertifier",),
    "recertifiés": ("recertifier",),
    "recertifies": ("recertifier",),
    "recertifiez": ("recertifier",),
    "recertifiiez": ("recertifier",),
    "recertifiions": ("recertifier",),
    "recertifions": ("recertifier",),
    "recevaient": ("recevoir",),
    "recevais": ("recevoir",),
    "recevait": ("recevoir",),
    "recevant": ("recevoir",),
    "recevez": ("recevoir",),
    "receviez": ("recevoir",),
    "recevions": ("recevoir",),
    "recevons": ("recevoir",),
    "recevra": ("recevoir",),
    "recevraient": ("recevoir",),
    "recevrai": ("recevoir",),
    "recevrais": ("recevoir",),
    "recevrait": ("recevoir",),
    "recevras": ("recevoir",),
    "recevrez": ("recevoir",),
    "recevriez": ("recevoir",),
    "recevrions": ("recevoir",),
    "recevrons": ("recevoir",),
    "recevront": ("recevoir",),
    "reçois": ("recevoir",),
    "reçoit": ("recevoir",),
    "reçoivent": ("recevoir",),
    "reçoive": ("recevoir",),
    "reçoives": ("recevoir",),
    "reçue": ("recevoir",),
    "reçues": ("recevoir",),
    "reçu": ("recevoir",),
    "reçûmes": ("recevoir",),
    "reçurent": ("recevoir",),
    "reçus": ("recevoir",),
    "reçussent": ("recevoir",),
    "reçusses": ("recevoir",),
    "reçusse": ("recevoir",),
    "reçussiez": ("recevoir",),
    "reçussions": ("recevoir",),
    "reçûtes": ("recevoir",),
    "reçut": ("recevoir",),
    "reçût": ("recevoir",),
    "rechampie": ("rechampir",),
    "réchampie": ("réchampir",),
    "rechampies": ("rechampir",),
    "réchampies": ("réchampir",),
    "rechampi": ("rechampir",),
    "réchampi": ("réchampir",),
    "rechampîmes": ("rechampir",),
    "réchampîmes": ("réchampir",),
    "rechampira": ("rechampir",),
    "réchampira": ("réchampir",),
    "rechampiraient": ("rechampir",),
    "réchampiraient": ("réchampir",),
    "rechampirai": ("rechampir",),
    "réchampirai": ("réchampir",),
    "rechampirais": ("rechampir",),
    "réchampirais": ("réchampir",),
    "rechampirait": ("rechampir",),
    "réchampirait": ("réchampir",),
    "rechampiras": ("rechampir",),
    "réchampiras": ("réchampir",),
    "rechampirent": ("rechampir",),
    "réchampirent": ("réchampir",),
    "rechampirez": ("rechampir",),
    "réchampirez": ("réchampir",),
    "rechampiriez": ("rechampir",),
    "réchampiriez": ("réchampir",),
    "rechampirions": ("rechampir",),
    "réchampirions": ("réchampir",),
    "rechampirons": ("rechampir",),
    "réchampirons": ("réchampir",),
    "rechampiront": ("rechampir",),
    "réchampiront": ("réchampir",),
    "rechampis": ("rechampir",),
    "réchampis": ("réchampir",),
    "rechampissaient": ("rechampir",),
    "réchampissaient": ("réchampir",),
    "rechampissais": ("rechampir",),
    "réchampissais": ("réchampir",),
    "rechampissait": ("rechampir",),
    "réchampissait": ("réchampir",),
    "rechampissant": ("rechampir",),
    "réchampissant": ("réchampir",),
    "rechampissent": ("rechampir",),
    "réchampissent": ("réchampir",),
    "rechampisse": ("rechampir",),
    "réchampisse": ("réchampir",),
    "rechampisses": ("rechampir",),
    "réchampisses": ("réchampir",),
    "rechampissez": ("rechampir",),
    "réchampissez": ("réchampir",),
    "rechampissiez": ("rechampir",),
    "réchampissiez": ("réchampir",),
    "rechampissions": ("rechampir",),
    "réchampissions": ("réchampir",),
    "rechampissons": ("rechampir",),
    "réchampissons": ("réchampir",),
    "rechampîtes": ("rechampir",),
    "réchampîtes": ("réchampir",),
    "rechampit": ("rechampir",),
    "réchampit": ("réchampir",),
    "rechampît": ("rechampir",),
    "réchampît": ("réchampir",),
    "rechangeaient": ("rechanger",),
    "rechangeai": ("rechanger",),
    "rechangeais": ("rechanger",),
    "rechangeait": ("rechanger",),
    "rechangea": ("rechanger",),
    "rechangeâmes": ("rechanger",),
    "rechangeant": ("rechanger",),
    "rechangeas": ("rechanger",),
    "rechangeassent": ("rechanger",),
    "rechangeasses": ("rechanger",),
    "rechangeasse": ("rechanger",),
    "rechangeassiez": ("rechanger",),
    "rechangeassions": ("rechanger",),
    "rechangeâtes": ("rechanger",),
    "rechangeât": ("rechanger",),
    "rechangée": ("rechanger",),
    "rechangées": ("rechanger",),
    "rechangé": ("rechanger",),
    "rechangent": ("rechanger",),
    "rechangeons": ("rechanger",),
    "rechange": ("rechanger",),
    "rechangera": ("rechanger",),
    "rechangeraient": ("rechanger",),
    "rechangerai": ("rechanger",),
    "rechangerais": ("rechanger",),
    "rechangerait": ("rechanger",),
    "rechangeras": ("rechanger",),
    "rechangèrent": ("rechanger",),
    "rechangerez": ("rechanger",),
    "rechangeriez": ("rechanger",),
    "rechangerions": ("rechanger",),
    "rechangerons": ("rechanger",),
    "rechangeront": ("rechanger",),
    "rechangés": ("rechanger",),
    "rechanges": ("rechanger",),
    "rechangez": ("rechanger",),
    "rechangiez": ("rechanger",),
    "rechangions": ("rechanger",),
    "rechargeaient": ("recharger",),
    "rechargeai": ("recharger",),
    "rechargeais": ("recharger",),
    "rechargeait": ("recharger",),
    "rechargea": ("recharger",),
    "rechargeâmes": ("recharger",),
    "rechargeant": ("recharger",),
    "rechargeas": ("recharger",),
    "rechargeassent": ("recharger",),
    "rechargeasses": ("recharger",),
    "rechargeasse": ("recharger",),
    "rechargeassiez": ("recharger",),
    "rechargeassions": ("recharger",),
    "rechargeâtes": ("recharger",),
    "rechargeât": ("recharger",),
    "rechargée": ("recharger",),
    "rechargées": ("recharger",),
    "rechargé": ("recharger",),
    "rechargent": ("recharger",),
    "rechargeons": ("recharger",),
    "recharge": ("recharger",),
    "rechargera": ("recharger",),
    "rechargeraient": ("recharger",),
    "rechargerai": ("recharger",),
    "rechargerais": ("recharger",),
    "rechargerait": ("recharger",),
    "rechargeras": ("recharger",),
    "rechargèrent": ("recharger",),
    "rechargerez": ("recharger",),
    "rechargeriez": ("recharger",),
    "rechargerions": ("recharger",),
    "rechargerons": ("recharger",),
    "rechargeront": ("recharger",),
    "rechargés": ("recharger",),
    "recharges": ("recharger",),
    "rechargez": ("recharger",),
    "rechargiez": ("recharger",),
    "rechargions": ("recharger",),
    "rechassaient": ("rechasser",),
    "rechassai": ("rechasser",),
    "rechassais": ("rechasser",),
    "rechassait": ("rechasser",),
    "rechassa": ("rechasser",),
    "rechassâmes": ("rechasser",),
    "rechassant": ("rechasser",),
    "rechassas": ("rechasser",),
    "rechassassent": ("rechasser",),
    "rechassasses": ("rechasser",),
    "rechassasse": ("rechasser",),
    "rechassassiez": ("rechasser",),
    "rechassassions": ("rechasser",),
    "rechassâtes": ("rechasser",),
    "rechassât": ("rechasser",),
    "rechassée": ("rechasser",),
    "rechassées": ("rechasser",),
    "rechassé": ("rechasser",),
    "rechassent": ("rechasser",),
    "rechasse": ("rechasser",),
    "rechassera": ("rechasser",),
    "rechasseraient": ("rechasser",),
    "rechasserai": ("rechasser",),
    "rechasserais": ("rechasser",),
    "rechasserait": ("rechasser",),
    "rechasseras": ("rechasser",),
    "rechassèrent": ("rechasser",),
    "rechasserez": ("rechasser",),
    "rechasseriez": ("rechasser",),
    "rechasserions": ("rechasser",),
    "rechasserons": ("rechasser",),
    "rechasseront": ("rechasser",),
    "rechassés": ("rechasser",),
    "rechasses": ("rechasser",),
    "rechassez": ("rechasser",),
    "rechassiez": ("rechasser",),
    "rechassions": ("rechasser",),
    "rechassons": ("rechasser",),
    "rechâtiaient": ("rechâtier",),
    "rechâtiai": ("rechâtier",),
    "rechâtiais": ("rechâtier",),
    "rechâtiait": ("rechâtier",),
    "rechâtia": ("rechâtier",),
    "rechâtiâmes": ("rechâtier",),
    "rechâtiant": ("rechâtier",),
    "rechâtias": ("rechâtier",),
    "rechâtiassent": ("rechâtier",),
    "rechâtiasses": ("rechâtier",),
    "rechâtiasse": ("rechâtier",),
    "rechâtiassiez": ("rechâtier",),
    "rechâtiassions": ("rechâtier",),
    "rechâtiâtes": ("rechâtier",),
    "rechâtiât": ("rechâtier",),
    "rechâtiée": ("rechâtier",),
    "rechâtiées": ("rechâtier",),
    "rechâtié": ("rechâtier",),
    "rechâtient": ("rechâtier",),
    "rechâtie": ("rechâtier",),
    "rechâtiera": ("rechâtier",),
    "rechâtieraient": ("rechâtier",),
    "rechâtierai": ("rechâtier",),
    "rechâtierais": ("rechâtier",),
    "rechâtierait": ("rechâtier",),
    "rechâtieras": ("rechâtier",),
    "rechâtièrent": ("rechâtier",),
    "rechâtierez": ("rechâtier",),
    "rechâtieriez": ("rechâtier",),
    "rechâtierions": ("rechâtier",),
    "rechâtierons": ("rechâtier",),
    "rechâtieront": ("rechâtier",),
    "rechâtiés": ("rechâtier",),
    "rechâties": ("rechâtier",),
    "rechâtiez": ("rechâtier",),
    "rechâtiiez": ("rechâtier",),
    "rechâtiions": ("rechâtier",),
    "rechâtions": ("rechâtier",),
    "rechoisie": ("rechoisir",),
    "rechoisies": ("rechoisir",),
    "rechoisi": ("rechoisir",),
    "rechoisîmes": ("rechoisir",),
    "rechoisira": ("rechoisir",),
    "rechoisiraient": ("rechoisir",),
    "rechoisirai": ("rechoisir",),
    "rechoisirais": ("rechoisir",),
    "rechoisirait": ("rechoisir",),
    "rechoisiras": ("rechoisir",),
    "rechoisirent": ("rechoisir",),
    "rechoisirez": ("rechoisir",),
    "rechoisiriez": ("rechoisir",),
    "rechoisirions": ("rechoisir",),
    "rechoisirons": ("rechoisir",),
    "rechoisiront": ("rechoisir",),
    "rechoisis": ("rechoisir",),
    "rechoisissaient": ("rechoisir",),
    "rechoisissais": ("rechoisir",),
    "rechoisissait": ("rechoisir",),
    "rechoisissant": ("rechoisir",),
    "rechoisissent": ("rechoisir",),
    "rechoisisse": ("rechoisir",),
    "rechoisisses": ("rechoisir",),
    "rechoisissez": ("rechoisir",),
    "rechoisissiez": ("rechoisir",),
    "rechoisissions": ("rechoisir",),
    "rechoisissons": ("rechoisir",),
    "rechoisîtes": ("rechoisir",),
    "rechoisit": ("rechoisir",),
    "rechoisît": ("rechoisir",),
    "rechronométraient": ("rechronométrer",),
    "rechronométrai": ("rechronométrer",),
    "rechronométrais": ("rechronométrer",),
    "rechronométrait": ("rechronométrer",),
    "rechronométra": ("rechronométrer",),
    "rechronométrâmes": ("rechronométrer",),
    "rechronométrant": ("rechronométrer",),
    "rechronométras": ("rechronométrer",),
    "rechronométrassent": ("rechronométrer",),
    "rechronométrasses": ("rechronométrer",),
    "rechronométrasse": ("rechronométrer",),
    "rechronométrassiez": ("rechronométrer",),
    "rechronométrassions": ("rechronométrer",),
    "rechronométrâtes": ("rechronométrer",),
    "rechronométrât": ("rechronométrer",),
    "rechronométrée": ("rechronométrer",),
    "rechronométrées": ("rechronométrer",),
    "rechronométré": ("rechronométrer",),
    "rechronomètrent": ("rechronométrer",),
    "rechronomètre": ("rechronométrer",),
    "rechronométrera": ("rechronométrer",),
    "rechronométreraient": ("rechronométrer",),
    "rechronométrerai": ("rechronométrer",),
    "rechronométrerais": ("rechronométrer",),
    "rechronométrerait": ("rechronométrer",),
    "rechronométreras": ("rechronométrer",),
    "rechronométrèrent": ("rechronométrer",),
    "rechronométrerez": ("rechronométrer",),
    "rechronométreriez": ("rechronométrer",),
    "rechronométrerions": ("rechronométrer",),
    "rechronométrerons": ("rechronométrer",),
    "rechronométreront": ("rechronométrer",),
    "rechronométrés": ("rechronométrer",),
    "rechronomètres": ("rechronométrer",),
    "rechronométrez": ("rechronométrer",),
    "rechronométriez": ("rechronométrer",),
    "rechronométrions": ("rechronométrer",),
    "rechronométrons": ("rechronométrer",),
    "reclassaient": ("reclasser",),
    "reclassai": ("reclasser",),
    "reclassais": ("reclasser",),
    "reclassait": ("reclasser",),
    "reclassa": ("reclasser",),
    "reclassâmes": ("reclasser",),
    "reclassant": ("reclasser",),
    "reclassas": ("reclasser",),
    "reclassassent": ("reclasser",),
    "reclassasses": ("reclasser",),
    "reclassasse": ("reclasser",),
    "reclassassiez": ("reclasser",),
    "reclassassions": ("reclasser",),
    "reclassâtes": ("reclasser",),
    "reclassât": ("reclasser",),
    "reclassée": ("reclasser",),
    "reclassées": ("reclasser",),
    "reclassé": ("reclasser",),
    "reclassent": ("reclasser",),
    "reclasse": ("reclasser",),
    "reclassera": ("reclasser",),
    "reclasseraient": ("reclasser",),
    "reclasserai": ("reclasser",),
    "reclasserais": ("reclasser",),
    "reclasserait": ("reclasser",),
    "reclasseras": ("reclasser",),
    "reclassèrent": ("reclasser",),
    "reclasserez": ("reclasser",),
    "reclasseriez": ("reclasser",),
    "reclasserions": ("reclasser",),
    "reclasserons": ("reclasser",),
    "reclasseront": ("reclasser",),
    "reclassés": ("reclasser",),
    "reclasses": ("reclasser",),
    "reclassez": ("reclasser",),
    "reclassiez": ("reclasser",),
    "reclassions": ("reclasser",),
    "reclassons": ("reclasser",),
    "reclassifiaient": ("reclassifier",),
    "reclassifiai": ("reclassifier",),
    "reclassifiais": ("reclassifier",),
    "reclassifiait": ("reclassifier",),
    "reclassifia": ("reclassifier",),
    "reclassifiâmes": ("reclassifier",),
    "reclassifiant": ("reclassifier",),
    "reclassifias": ("reclassifier",),
    "reclassifiassent": ("reclassifier",),
    "reclassifiasses": ("reclassifier",),
    "reclassifiasse": ("reclassifier",),
    "reclassifiassiez": ("reclassifier",),
    "reclassifiassions": ("reclassifier",),
    "reclassifiâtes": ("reclassifier",),
    "reclassifiât": ("reclassifier",),
    "reclassifiée": ("reclassifier",),
    "reclassifiées": ("reclassifier",),
    "reclassifié": ("reclassifier",),
    "reclassifient": ("reclassifier",),
    "reclassifie": ("reclassifier",),
    "reclassifiera": ("reclassifier",),
    "reclassifieraient": ("reclassifier",),
    "reclassifierai": ("reclassifier",),
    "reclassifierais": ("reclassifier",),
    "reclassifierait": ("reclassifier",),
    "reclassifieras": ("reclassifier",),
    "reclassifièrent": ("reclassifier",),
    "reclassifierez": ("reclassifier",),
    "reclassifieriez": ("reclassifier",),
    "reclassifierions": ("reclassifier",),
    "reclassifierons": ("reclassifier",),
    "reclassifieront": ("reclassifier",),
    "reclassifiés": ("reclassifier",),
    "reclassifies": ("reclassifier",),
    "reclassifiez": ("reclassifier",),
    "reclassifiiez": ("reclassifier",),
    "reclassifiions": ("reclassifier",),
    "reclassifions": ("reclassifier",),
    "reclora": ("reclore",),
    "recloraient": ("reclore",),
    "reclorai": ("reclore",),
    "reclorais": ("reclore",),
    "reclorait": ("reclore",),
    "recloras": ("reclore",),
    "reclorez": ("reclore",),
    "recloriez": ("reclore",),
    "reclorions": ("reclore",),
    "reclorons": ("reclore",),
    "recloront": ("reclore",),
    "reclosant": ("reclore",),
    "reclose": ("reclore",),
    "reclosent": ("reclore",),
    "recloses": ("reclore",),
    "reclosez": ("reclore",),
    "reclosiez": ("reclore",),
    "reclosions": ("reclore",),
    "reclos": ("reclore",),
    "reclosons": ("reclore",),
    "reclôt": ("reclore",),
    "recluse": ("reclure",),
    "recluses": ("reclure",),
    "reclus": ("reclure",),
    "recodifiaient": ("recodifier",),
    "recodifiai": ("recodifier",),
    "recodifiais": ("recodifier",),
    "recodifiait": ("recodifier",),
    "recodifia": ("recodifier",),
    "recodifiâmes": ("recodifier",),
    "recodifiant": ("recodifier",),
    "recodifias": ("recodifier",),
    "recodifiassent": ("recodifier",),
    "recodifiasses": ("recodifier",),
    "recodifiasse": ("recodifier",),
    "recodifiassiez": ("recodifier",),
    "recodifiassions": ("recodifier",),
    "recodifiâtes": ("recodifier",),
    "recodifiât": ("recodifier",),
    "recodifiée": ("recodifier",),
    "recodifiées": ("recodifier",),
    "recodifié": ("recodifier",),
    "recodifient": ("recodifier",),
    "recodifie": ("recodifier",),
    "recodifiera": ("recodifier",),
    "recodifieraient": ("recodifier",),
    "recodifierai": ("recodifier",),
    "recodifierais": ("recodifier",),
    "recodifierait": ("recodifier",),
    "recodifieras": ("recodifier",),
    "recodifièrent": ("recodifier",),
    "recodifierez": ("recodifier",),
    "recodifieriez": ("recodifier",),
    "recodifierions": ("recodifier",),
    "recodifierons": ("recodifier",),
    "recodifieront": ("recodifier",),
    "recodifiés": ("recodifier",),
    "recodifies": ("recodifier",),
    "recodifiez": ("recodifier",),
    "recodifiiez": ("recodifier",),
    "recodifiions": ("recodifier",),
    "recodifions": ("recodifier",),
    "recoinçaient": ("recoincer",),
    "recoinçai": ("recoincer",),
    "recoinçais": ("recoincer",),
    "recoinçait": ("recoincer",),
    "recoinça": ("recoincer",),
    "recoinçâmes": ("recoincer",),
    "recoinçant": ("recoincer",),
    "recoinças": ("recoincer",),
    "recoinçassent": ("recoincer",),
    "recoinçasses": ("recoincer",),
    "recoinçasse": ("recoincer",),
    "recoinçassiez": ("recoincer",),
    "recoinçassions": ("recoincer",),
    "recoinçâtes": ("recoincer",),
    "recoinçât": ("recoincer",),
    "recoincée": ("recoincer",),
    "recoincées": ("recoincer",),
    "recoincé": ("recoincer",),
    "recoincent": ("recoincer",),
    "recoince": ("recoincer",),
    "recoincera": ("recoincer",),
    "recoinceraient": ("recoincer",),
    "recoincerai": ("recoincer",),
    "recoincerais": ("recoincer",),
    "recoincerait": ("recoincer",),
    "recoinceras": ("recoincer",),
    "recoincèrent": ("recoincer",),
    "recoincerez": ("recoincer",),
    "recoinceriez": ("recoincer",),
    "recoincerions": ("recoincer",),
    "recoincerons": ("recoincer",),
    "recoinceront": ("recoincer",),
    "recoincés": ("recoincer",),
    "recoinces": ("recoincer",),
    "recoincez": ("recoincer",),
    "recoinciez": ("recoincer",),
    "recoincions": ("recoincer",),
    "recoinçons": ("recoincer",),
    "recoloriaient": ("recolorier",),
    "recoloriai": ("recolorier",),
    "recoloriais": ("recolorier",),
    "recoloriait": ("recolorier",),
    "recoloria": ("recolorier",),
    "recoloriâmes": ("recolorier",),
    "recoloriant": ("recolorier",),
    "recolorias": ("recolorier",),
    "recoloriassent": ("recolorier",),
    "recoloriasses": ("recolorier",),
    "recoloriasse": ("recolorier",),
    "recoloriassiez": ("recolorier",),
    "recoloriassions": ("recolorier",),
    "recoloriâtes": ("recolorier",),
    "recoloriât": ("recolorier",),
    "recoloriée": ("recolorier",),
    "recoloriées": ("recolorier",),
    "recolorié": ("recolorier",),
    "recolorient": ("recolorier",),
    "recolorie": ("recolorier",),
    "recoloriera": ("recolorier",),
    "recolorieraient": ("recolorier",),
    "recolorierai": ("recolorier",),
    "recolorierais": ("recolorier",),
    "recolorierait": ("recolorier",),
    "recolorieras": ("recolorier",),
    "recolorièrent": ("recolorier",),
    "recolorierez": ("recolorier",),
    "recolorieriez": ("recolorier",),
    "recolorierions": ("recolorier",),
    "recolorierons": ("recolorier",),
    "recolorieront": ("recolorier",),
    "recoloriés": ("recolorier",),
    "recolories": ("recolorier",),
    "recoloriez": ("recolorier",),
    "recoloriiez": ("recolorier",),
    "recoloriions": ("recolorier",),
    "recolorions": ("recolorier",),
    "recombat": ("recombattre",),
    "recombats": ("recombattre",),
    "recombattaient": ("recombattre",),
    "recombattais": ("recombattre",),
    "recombattait": ("recombattre",),
    "recombattant": ("recombattre",),
    "recombattent": ("recombattre",),
    "recombatte": ("recombattre",),
    "recombattes": ("recombattre",),
    "recombattez": ("recombattre",),
    "recombattiez": ("recombattre",),
    "recombattîmes": ("recombattre",),
    "recombattions": ("recombattre",),
    "recombattirent": ("recombattre",),
    "recombattis": ("recombattre",),
    "recombattissent": ("recombattre",),
    "recombattisses": ("recombattre",),
    "recombattisse": ("recombattre",),
    "recombattissiez": ("recombattre",),
    "recombattissions": ("recombattre",),
    "recombattîtes": ("recombattre",),
    "recombattit": ("recombattre",),
    "recombattît": ("recombattre",),
    "recombattons": ("recombattre",),
    "recombattra": ("recombattre",),
    "recombattraient": ("recombattre",),
    "recombattrai": ("recombattre",),
    "recombattrais": ("recombattre",),
    "recombattrait": ("recombattre",),
    "recombattras": ("recombattre",),
    "recombattrez": ("recombattre",),
    "recombattriez": ("recombattre",),
    "recombattrions": ("recombattre",),
    "recombattrons": ("recombattre",),
    "recombattront": ("recombattre",),
    "recombattue": ("recombattre",),
    "recombattues": ("recombattre",),
    "recombattu": ("recombattre",),
    "recombattus": ("recombattre",),
    "recommençaient": ("recommencer",),
    "recommençai": ("recommencer",),
    "recommençais": ("recommencer",),
    "recommençait": ("recommencer",),
    "recommença": ("recommencer",),
    "recommençâmes": ("recommencer",),
    "recommençant": ("recommencer",),
    "recommenças": ("recommencer",),
    "recommençassent": ("recommencer",),
    "recommençasses": ("recommencer",),
    "recommençasse": ("recommencer",),
    "recommençassiez": ("recommencer",),
    "recommençassions": ("recommencer",),
    "recommençâtes": ("recommencer",),
    "recommençât": ("recommencer",),
    "recommencée": ("recommencer",),
    "recommencées": ("recommencer",),
    "recommencé": ("recommencer",),
    "recommencent": ("recommencer",),
    "recommence": ("recommencer",),
    "recommencera": ("recommencer",),
    "recommenceraient": ("recommencer",),
    "recommencerai": ("recommencer",),
    "recommencerais": ("recommencer",),
    "recommencerait": ("recommencer",),
    "recommenceras": ("recommencer",),
    "recommencèrent": ("recommencer",),
    "recommencerez": ("recommencer",),
    "recommenceriez": ("recommencer",),
    "recommencerions": ("recommencer",),
    "recommencerons": ("recommencer",),
    "recommenceront": ("recommencer",),
    "recommencés": ("recommencer",),
    "recommences": ("recommencer",),
    "recommencez": ("recommencer",),
    "recommenciez": ("recommencer",),
    "recommencions": ("recommencer",),
    "recommençons": ("recommencer",),
    "recommerçaient": ("recommercer",),
    "recommerçai": ("recommercer",),
    "recommerçais": ("recommercer",),
    "recommerçait": ("recommercer",),
    "recommerça": ("recommercer",),
    "recommerçâmes": ("recommercer",),
    "recommerçant": ("recommercer",),
    "recommerças": ("recommercer",),
    "recommerçassent": ("recommercer",),
    "recommerçasses": ("recommercer",),
    "recommerçasse": ("recommercer",),
    "recommerçassiez": ("recommercer",),
    "recommerçassions": ("recommercer",),
    "recommerçâtes": ("recommercer",),
    "recommerçât": ("recommercer",),
    "recommercée": ("recommercer",),
    "recommercées": ("recommercer",),
    "recommercé": ("recommercer",),
    "recommercent": ("recommercer",),
    "recommerce": ("recommercer",),
    "recommercera": ("recommercer",),
    "recommerceraient": ("recommercer",),
    "recommercerai": ("recommercer",),
    "recommercerais": ("recommercer",),
    "recommercerait": ("recommercer",),
    "recommerceras": ("recommercer",),
    "recommercèrent": ("recommercer",),
    "recommercerez": ("recommercer",),
    "recommerceriez": ("recommercer",),
    "recommercerions": ("recommercer",),
    "recommercerons": ("recommercer",),
    "recommerceront": ("recommercer",),
    "recommercés": ("recommercer",),
    "recommerces": ("recommercer",),
    "recommercez": ("recommercer",),
    "recommerciez": ("recommercer",),
    "recommercions": ("recommercer",),
    "recommerçons": ("recommercer",),
    "recommet": ("recommettre",),
    "recommets": ("recommettre",),
    "recommettaient": ("recommettre",),
    "recommettais": ("recommettre",),
    "recommettait": ("recommettre",),
    "recommettant": ("recommettre",),
    "recommettent": ("recommettre",),
    "recommette": ("recommettre",),
    "recommettes": ("recommettre",),
    "recommettez": ("recommettre",),
    "recommettiez": ("recommettre",),
    "recommettions": ("recommettre",),
    "recommettons": ("recommettre",),
    "recommettra": ("recommettre",),
    "recommettraient": ("recommettre",),
    "recommettrai": ("recommettre",),
    "recommettrais": ("recommettre",),
    "recommettrait": ("recommettre",),
    "recommettras": ("recommettre",),
    "recommettrez": ("recommettre",),
    "recommettriez": ("recommettre",),
    "recommettrions": ("recommettre",),
    "recommettrons": ("recommettre",),
    "recommettront": ("recommettre",),
    "recommîmes": ("recommettre",),
    "recommirent": ("recommettre",),
    "recommise": ("recommettre",),
    "recommises": ("recommettre",),
    "recommis": ("recommettre",),
    "recommissent": ("recommettre",),
    "recommisses": ("recommettre",),
    "recommisse": ("recommettre",),
    "recommissiez": ("recommettre",),
    "recommissions": ("recommettre",),
    "recommîtes": ("recommettre",),
    "recommit": ("recommettre",),
    "recommît": ("recommettre",),
    "recomparais": ("recomparaître",),
    "recomparaissaient": ("recomparaître",),
    "recomparaissais": ("recomparaître",),
    "recomparaissait": ("recomparaître",),
    "recomparaissant": ("recomparaître",),
    "recomparaissent": ("recomparaître",),
    "recomparaisse": ("recomparaître",),
    "recomparaisses": ("recomparaître",),
    "recomparaissez": ("recomparaître",),
    "recomparaissiez": ("recomparaître",),
    "recomparaissions": ("recomparaître",),
    "recomparaissons": ("recomparaître",),
    "recomparaît": ("recomparaître",),
    "recomparaîtra": ("recomparaître",),
    "recomparaîtraient": ("recomparaître",),
    "recomparaîtrai": ("recomparaître",),
    "recomparaîtrais": ("recomparaître",),
    "recomparaîtrait": ("recomparaître",),
    "recomparaîtras": ("recomparaître",),
    "recomparaîtrez": ("recomparaître",),
    "recomparaîtriez": ("recomparaître",),
    "recomparaîtrions": ("recomparaître",),
    "recomparaîtrons": ("recomparaître",),
    "recomparaîtront": ("recomparaître",),
    "recomparu": ("recomparaître",),
    "recomparûmes": ("recomparaître",),
    "recomparurent": ("recomparaître",),
    "recomparus": ("recomparaître",),
    "recomparussent": ("recomparaître",),
    "recomparusses": ("recomparaître",),
    "recomparusse": ("recomparaître",),
    "recomparussiez": ("recomparaître",),
    "recomparussions": ("recomparaître",),
    "recomparûtes": ("recomparaître",),
    "recomparut": ("recomparaître",),
    "recomparût": ("recomparaître",),
    "recomplétaient": ("recompléter",),
    "recomplétai": ("recompléter",),
    "recomplétais": ("recompléter",),
    "recomplétait": ("recompléter",),
    "recompléta": ("recompléter",),
    "recomplétâmes": ("recompléter",),
    "recomplétant": ("recompléter",),
    "recomplétas": ("recompléter",),
    "recomplétassent": ("recompléter",),
    "recomplétasses": ("recompléter",),
    "recomplétasse": ("recompléter",),
    "recomplétassiez": ("recompléter",),
    "recomplétassions": ("recompléter",),
    "recomplétâtes": ("recompléter",),
    "recomplétât": ("recompléter",),
    "recomplétée": ("recompléter",),
    "recomplétées": ("recompléter",),
    "recomplété": ("recompléter",),
    "recomplètent": ("recompléter",),
    "recomplète": ("recompléter",),
    "recomplétera": ("recompléter",),
    "recompléteraient": ("recompléter",),
    "recompléterai": ("recompléter",),
    "recompléterais": ("recompléter",),
    "recompléterait": ("recompléter",),
    "recompléteras": ("recompléter",),
    "recomplétèrent": ("recompléter",),
    "recompléterez": ("recompléter",),
    "recompléteriez": ("recompléter",),
    "recompléterions": ("recompléter",),
    "recompléterons": ("recompléter",),
    "recompléteront": ("recompléter",),
    "recomplétés": ("recompléter",),
    "recomplètes": ("recompléter",),
    "recomplétez": ("recompléter",),
    "recomplétiez": ("recompléter",),
    "recomplétions": ("recompléter",),
    "recomplétons": ("recompléter",),
    "recompromet": ("recompromettre",),
    "recompromets": ("recompromettre",),
    "recompromettaient": ("recompromettre",),
    "recompromettais": ("recompromettre",),
    "recompromettait": ("recompromettre",),
    "recompromettant": ("recompromettre",),
    "recompromettent": ("recompromettre",),
    "recompromette": ("recompromettre",),
    "recompromettes": ("recompromettre",),
    "recompromettez": ("recompromettre",),
    "recompromettiez": ("recompromettre",),
    "recompromettions": ("recompromettre",),
    "recompromettons": ("recompromettre",),
    "recompromettra": ("recompromettre",),
    "recompromettraient": ("recompromettre",),
    "recompromettrai": ("recompromettre",),
    "recompromettrais": ("recompromettre",),
    "recompromettrait": ("recompromettre",),
    "recompromettras": ("recompromettre",),
    "recompromettrez": ("recompromettre",),
    "recompromettriez": ("recompromettre",),
    "recompromettrions": ("recompromettre",),
    "recompromettrons": ("recompromettre",),
    "recompromettront": ("recompromettre",),
    "recompromîmes": ("recompromettre",),
    "recompromirent": ("recompromettre",),
    "recompromise": ("recompromettre",),
    "recompromises": ("recompromettre",),
    "recompromis": ("recompromettre",),
    "recompromissent": ("recompromettre",),
    "recompromisses": ("recompromettre",),
    "recompromisse": ("recompromettre",),
    "recompromissiez": ("recompromettre",),
    "recompromissions": ("recompromettre",),
    "recompromîtes": ("recompromettre",),
    "recompromit": ("recompromettre",),
    "recompromît": ("recompromettre",),
    "reconcédaient": ("reconcéder",),
    "reconcédai": ("reconcéder",),
    "reconcédais": ("reconcéder",),
    "reconcédait": ("reconcéder",),
    "reconcéda": ("reconcéder",),
    "reconcédâmes": ("reconcéder",),
    "reconcédant": ("reconcéder",),
    "reconcédas": ("reconcéder",),
    "reconcédassent": ("reconcéder",),
    "reconcédasses": ("reconcéder",),
    "reconcédasse": ("reconcéder",),
    "reconcédassiez": ("reconcéder",),
    "reconcédassions": ("reconcéder",),
    "reconcédâtes": ("reconcéder",),
    "reconcédât": ("reconcéder",),
    "reconcédée": ("reconcéder",),
    "reconcédées": ("reconcéder",),
    "reconcédé": ("reconcéder",),
    "reconcèdent": ("reconcéder",),
    "reconcède": ("reconcéder",),
    "reconcédera": ("reconcéder",),
    "reconcéderaient": ("reconcéder",),
    "reconcéderai": ("reconcéder",),
    "reconcéderais": ("reconcéder",),
    "reconcéderait": ("reconcéder",),
    "reconcéderas": ("reconcéder",),
    "reconcédèrent": ("reconcéder",),
    "reconcéderez": ("reconcéder",),
    "reconcéderiez": ("reconcéder",),
    "reconcéderions": ("reconcéder",),
    "reconcéderons": ("reconcéder",),
    "reconcéderont": ("reconcéder",),
    "reconcédés": ("reconcéder",),
    "reconcèdes": ("reconcéder",),
    "reconcédez": ("reconcéder",),
    "reconcédiez": ("reconcéder",),
    "reconcédions": ("reconcéder",),
    "reconcédons": ("reconcéder",),
    "réconciliaient": ("réconcilier",),
    "réconciliai": ("réconcilier",),
    "réconciliais": ("réconcilier",),
    "réconciliait": ("réconcilier",),
    "réconcilia": ("réconcilier",),
    "réconciliâmes": ("réconcilier",),
    "réconciliant": ("réconcilier",),
    "réconcilias": ("réconcilier",),
    "réconciliassent": ("réconcilier",),
    "réconciliasses": ("réconcilier",),
    "réconciliasse": ("réconcilier",),
    "réconciliassiez": ("réconcilier",),
    "réconciliassions": ("réconcilier",),
    "réconciliâtes": ("réconcilier",),
    "réconciliât": ("réconcilier",),
    "réconciliée": ("réconcilier",),
    "réconciliées": ("réconcilier",),
    "réconcilié": ("réconcilier",),
    "réconcilient": ("réconcilier",),
    "réconcilie": ("réconcilier",),
    "réconciliera": ("réconcilier",),
    "réconcilieraient": ("réconcilier",),
    "réconcilierai": ("réconcilier",),
    "réconcilierais": ("réconcilier",),
    "réconcilierait": ("réconcilier",),
    "réconcilieras": ("réconcilier",),
    "réconcilièrent": ("réconcilier",),
    "réconcilierez": ("réconcilier",),
    "réconcilieriez": ("réconcilier",),
    "réconcilierions": ("réconcilier",),
    "réconcilierons": ("réconcilier",),
    "réconcilieront": ("réconcilier",),
    "réconciliés": ("réconcilier",),
    "réconcilies": ("réconcilier",),
    "réconciliez": ("réconcilier",),
    "réconciliiez": ("réconcilier",),
    "réconciliions": ("réconcilier",),
    "réconcilions": ("réconcilier",),
    "reconcouraient": ("reconcourir",),
    "reconcourais": ("reconcourir",),
    "reconcourait": ("reconcourir",),
    "reconcourant": ("reconcourir",),
    "reconcourent": ("reconcourir",),
    "reconcoure": ("reconcourir",),
    "reconcoures": ("reconcourir",),
    "reconcourez": ("reconcourir",),
    "reconcouriez": ("reconcourir",),
    "reconcourions": ("reconcourir",),
    "reconcourons": ("reconcourir",),
    "reconcourra": ("reconcourir",),
    "reconcourraient": ("reconcourir",),
    "reconcourrai": ("reconcourir",),
    "reconcourrais": ("reconcourir",),
    "reconcourrait": ("reconcourir",),
    "reconcourras": ("reconcourir",),
    "reconcourrez": ("reconcourir",),
    "reconcourriez": ("reconcourir",),
    "reconcourrions": ("reconcourir",),
    "reconcourrons": ("reconcourir",),
    "reconcourront": ("reconcourir",),
    "reconcours": ("reconcourir",),
    "reconcourt": ("reconcourir",),
    "reconcourue": ("reconcourir",),
    "reconcourues": ("reconcourir",),
    "reconcouru": ("reconcourir",),
    "reconcourûmes": ("reconcourir",),
    "reconcoururent": ("reconcourir",),
    "reconcourus": ("reconcourir",),
    "reconcourussent": ("reconcourir",),
    "reconcourusses": ("reconcourir",),
    "reconcourusse": ("reconcourir",),
    "reconcourussiez": ("reconcourir",),
    "reconcourussions": ("reconcourir",),
    "reconcourûtes": ("reconcourir",),
    "reconcourut": ("reconcourir",),
    "reconcourût": ("reconcourir",),
    "reconcurrençaient": ("reconcurrencer",),
    "reconcurrençai": ("reconcurrencer",),
    "reconcurrençais": ("reconcurrencer",),
    "reconcurrençait": ("reconcurrencer",),
    "reconcurrença": ("reconcurrencer",),
    "reconcurrençâmes": ("reconcurrencer",),
    "reconcurrençant": ("reconcurrencer",),
    "reconcurrenças": ("reconcurrencer",),
    "reconcurrençassent": ("reconcurrencer",),
    "reconcurrençasses": ("reconcurrencer",),
    "reconcurrençasse": ("reconcurrencer",),
    "reconcurrençassiez": ("reconcurrencer",),
    "reconcurrençassions": ("reconcurrencer",),
    "reconcurrençâtes": ("reconcurrencer",),
    "reconcurrençât": ("reconcurrencer",),
    "reconcurrencée": ("reconcurrencer",),
    "reconcurrencées": ("reconcurrencer",),
    "reconcurrencé": ("reconcurrencer",),
    "reconcurrencent": ("reconcurrencer",),
    "reconcurrence": ("reconcurrencer",),
    "reconcurrencera": ("reconcurrencer",),
    "reconcurrenceraient": ("reconcurrencer",),
    "reconcurrencerai": ("reconcurrencer",),
    "reconcurrencerais": ("reconcurrencer",),
    "reconcurrencerait": ("reconcurrencer",),
    "reconcurrenceras": ("reconcurrencer",),
    "reconcurrencèrent": ("reconcurrencer",),
    "reconcurrencerez": ("reconcurrencer",),
    "reconcurrenceriez": ("reconcurrencer",),
    "reconcurrencerions": ("reconcurrencer",),
    "reconcurrencerons": ("reconcurrencer",),
    "reconcurrenceront": ("reconcurrencer",),
    "reconcurrencés": ("reconcurrencer",),
    "reconcurrences": ("reconcurrencer",),
    "reconcurrencez": ("reconcurrencer",),
    "reconcurrenciez": ("reconcurrencer",),
    "reconcurrencions": ("reconcurrencer",),
    "reconcurrençons": ("reconcurrencer",),
    "reconduira": ("reconduire",),
    "reconduiraient": ("reconduire",),
    "reconduirai": ("reconduire",),
    "reconduirais": ("reconduire",),
    "reconduirait": ("reconduire",),
    "reconduiras": ("reconduire",),
    "reconduirez": ("reconduire",),
    "reconduiriez": ("reconduire",),
    "reconduirions": ("reconduire",),
    "reconduirons": ("reconduire",),
    "reconduiront": ("reconduire",),
    "reconduisaient": ("reconduire",),
    "reconduisais": ("reconduire",),
    "reconduisait": ("reconduire",),
    "reconduisant": ("reconduire",),
    "reconduisent": ("reconduire",),
    "reconduise": ("reconduire",),
    "reconduises": ("reconduire",),
    "reconduisez": ("reconduire",),
    "reconduisiez": ("reconduire",),
    "reconduisîmes": ("reconduire",),
    "reconduisions": ("reconduire",),
    "reconduisirent": ("reconduire",),
    "reconduisis": ("reconduire",),
    "reconduisissent": ("reconduire",),
    "reconduisisses": ("reconduire",),
    "reconduisisse": ("reconduire",),
    "reconduisissiez": ("reconduire",),
    "reconduisissions": ("reconduire",),
    "reconduisîtes": ("reconduire",),
    "reconduisit": ("reconduire",),
    "reconduisît": ("reconduire",),
    "reconduisons": ("reconduire",),
    "reconduis": ("reconduire",),
    "reconduite": ("reconduire",),
    "reconduites": ("reconduire",),
    "reconduit": ("reconduire",),
    "reconduits": ("reconduire",),
    "reconfiaient": ("reconfier",),
    "reconfiai": ("reconfier",),
    "reconfiais": ("reconfier",),
    "reconfiait": ("reconfier",),
    "reconfia": ("reconfier",),
    "reconfiâmes": ("reconfier",),
    "reconfiant": ("reconfier",),
    "reconfias": ("reconfier",),
    "reconfiassent": ("reconfier",),
    "reconfiasses": ("reconfier",),
    "reconfiasse": ("reconfier",),
    "reconfiassiez": ("reconfier",),
    "reconfiassions": ("reconfier",),
    "reconfiâtes": ("reconfier",),
    "reconfiât": ("reconfier",),
    "reconfiée": ("reconfier",),
    "reconfiées": ("reconfier",),
    "reconfié": ("reconfier",),
    "reconfient": ("reconfier",),
    "reconfie": ("reconfier",),
    "reconfiera": ("reconfier",),
    "reconfieraient": ("reconfier",),
    "reconfierai": ("reconfier",),
    "reconfierais": ("reconfier",),
    "reconfierait": ("reconfier",),
    "reconfieras": ("reconfier",),
    "reconfièrent": ("reconfier",),
    "reconfierez": ("reconfier",),
    "reconfieriez": ("reconfier",),
    "reconfierions": ("reconfier",),
    "reconfierons": ("reconfier",),
    "reconfieront": ("reconfier",),
    "reconfiés": ("reconfier",),
    "reconfies": ("reconfier",),
    "reconfiez": ("reconfier",),
    "reconfiiez": ("reconfier",),
    "reconfiions": ("reconfier",),
    "reconfions": ("reconfier",),
    "reconfondaient": ("reconfondre",),
    "reconfondais": ("reconfondre",),
    "reconfondait": ("reconfondre",),
    "reconfondant": ("reconfondre",),
    "reconfondent": ("reconfondre",),
    "reconfonde": ("reconfondre",),
    "reconfondes": ("reconfondre",),
    "reconfondez": ("reconfondre",),
    "reconfondiez": ("reconfondre",),
    "reconfondîmes": ("reconfondre",),
    "reconfondions": ("reconfondre",),
    "reconfondirent": ("reconfondre",),
    "reconfondis": ("reconfondre",),
    "reconfondissent": ("reconfondre",),
    "reconfondisses": ("reconfondre",),
    "reconfondisse": ("reconfondre",),
    "reconfondissiez": ("reconfondre",),
    "reconfondissions": ("reconfondre",),
    "reconfondîtes": ("reconfondre",),
    "reconfondit": ("reconfondre",),
    "reconfondît": ("reconfondre",),
    "reconfondons": ("reconfondre",),
    "reconfond": ("reconfondre",),
    "reconfondra": ("reconfondre",),
    "reconfondraient": ("reconfondre",),
    "reconfondrai": ("reconfondre",),
    "reconfondrais": ("reconfondre",),
    "reconfondrait": ("reconfondre",),
    "reconfondras": ("reconfondre",),
    "reconfondrez": ("reconfondre",),
    "reconfondriez": ("reconfondre",),
    "reconfondrions": ("reconfondre",),
    "reconfondrons": ("reconfondre",),
    "reconfondront": ("reconfondre",),
    "reconfonds": ("reconfondre",),
    "reconfondue": ("reconfondre",),
    "reconfondues": ("reconfondre",),
    "reconfondu": ("reconfondre",),
    "reconfondus": ("reconfondre",),
    "recongédiaient": ("recongédier",),
    "recongédiai": ("recongédier",),
    "recongédiais": ("recongédier",),
    "recongédiait": ("recongédier",),
    "recongédia": ("recongédier",),
    "recongédiâmes": ("recongédier",),
    "recongédiant": ("recongédier",),
    "recongédias": ("recongédier",),
    "recongédiassent": ("recongédier",),
    "recongédiasses": ("recongédier",),
    "recongédiasse": ("recongédier",),
    "recongédiassiez": ("recongédier",),
    "recongédiassions": ("recongédier",),
    "recongédiâtes": ("recongédier",),
    "recongédiât": ("recongédier",),
    "recongédiée": ("recongédier",),
    "recongédiées": ("recongédier",),
    "recongédié": ("recongédier",),
    "recongédient": ("recongédier",),
    "recongédie": ("recongédier",),
    "recongédiera": ("recongédier",),
    "recongédieraient": ("recongédier",),
    "recongédierai": ("recongédier",),
    "recongédierais": ("recongédier",),
    "recongédierait": ("recongédier",),
    "recongédieras": ("recongédier",),
    "recongédièrent": ("recongédier",),
    "recongédierez": ("recongédier",),
    "recongédieriez": ("recongédier",),
    "recongédierions": ("recongédier",),
    "recongédierons": ("recongédier",),
    "recongédieront": ("recongédier",),
    "recongédiés": ("recongédier",),
    "recongédies": ("recongédier",),
    "recongédiez": ("recongédier",),
    "recongédiiez": ("recongédier",),
    "recongédiions": ("recongédier",),
    "recongédions": ("recongédier",),
    "recongelaient": ("recongeler",),
    "recongelai": ("recongeler",),
    "recongelais": ("recongeler",),
    "recongelait": ("recongeler",),
    "recongela": ("recongeler",),
    "recongelâmes": ("recongeler",),
    "recongelant": ("recongeler",),
    "recongelas": ("recongeler",),
    "recongelassent": ("recongeler",),
    "recongelasses": ("recongeler",),
    "recongelasse": ("recongeler",),
    "recongelassiez": ("recongeler",),
    "recongelassions": ("recongeler",),
    "recongelâtes": ("recongeler",),
    "recongelât": ("recongeler",),
    "recongelée": ("recongeler",),
    "recongelées": ("recongeler",),
    "recongelé": ("recongeler",),
    "recongèlent": ("recongeler",),
    "recongèle": ("recongeler",),
    "recongèlera": ("recongeler",),
    "recongèleraient": ("recongeler",),
    "recongèlerai": ("recongeler",),
    "recongèlerais": ("recongeler",),
    "recongèlerait": ("recongeler",),
    "recongèleras": ("recongeler",),
    "recongelèrent": ("recongeler",),
    "recongèlerez": ("recongeler",),
    "recongèleriez": ("recongeler",),
    "recongèlerions": ("recongeler",),
    "recongèlerons": ("recongeler",),
    "recongèleront": ("recongeler",),
    "recongelés": ("recongeler",),
    "recongèles": ("recongeler",),
    "recongelez": ("recongeler",),
    "recongeliez": ("recongeler",),
    "recongelions": ("recongeler",),
    "recongelons": ("recongeler",),
    "reconnais": ("reconnaître",),
    "reconnaissaient": ("reconnaître",),
    "reconnaissais": ("reconnaître",),
    "reconnaissait": ("reconnaître",),
    "reconnaissant": ("reconnaître",),
    "reconnaissent": ("reconnaître",),
    "reconnaisse": ("reconnaître",),
    "reconnaisses": ("reconnaître",),
    "reconnaissez": ("reconnaître",),
    "reconnaissiez": ("reconnaître",),
    "reconnaissions": ("reconnaître",),
    "reconnaissons": ("reconnaître",),
    "reconnaît": ("reconnaître",),
    "reconnaîtra": ("reconnaître",),
    "reconnaîtraient": ("reconnaître",),
    "reconnaîtrai": ("reconnaître",),
    "reconnaîtrais": ("reconnaître",),
    "reconnaîtrait": ("reconnaître",),
    "reconnaîtras": ("reconnaître",),
    "reconnaîtrez": ("reconnaître",),
    "reconnaîtriez": ("reconnaître",),
    "reconnaîtrions": ("reconnaître",),
    "reconnaîtrons": ("reconnaître",),
    "reconnaîtront": ("reconnaître",),
    "reconnue": ("reconnaître",),
    "reconnues": ("reconnaître",),
    "reconnu": ("reconnaître",),
    "reconnûmes": ("reconnaître",),
    "reconnurent": ("reconnaître",),
    "reconnus": ("reconnaître",),
    "reconnussent": ("reconnaître",),
    "reconnusses": ("reconnaître",),
    "reconnusse": ("reconnaître",),
    "reconnussiez": ("reconnaître",),
    "reconnussions": ("reconnaître",),
    "reconnûtes": ("reconnaître",),
    "reconnut": ("reconnaître",),
    "reconnût": ("reconnaître",),
    "reconquéraient": ("reconquérir",),
    "reconquérais": ("reconquérir",),
    "reconquérait": ("reconquérir",),
    "reconquérant": ("reconquérir",),
    "reconquérez": ("reconquérir",),
    "reconquériez": ("reconquérir",),
    "reconquérions": ("reconquérir",),
    "reconquérons": ("reconquérir",),
    "reconquerra": ("reconquérir",),
    "reconquerraient": ("reconquérir",),
    "reconquerrai": ("reconquérir",),
    "reconquerrais": ("reconquérir",),
    "reconquerrait": ("reconquérir",),
    "reconquerras": ("reconquérir",),
    "reconquerrez": ("reconquérir",),
    "reconquerriez": ("reconquérir",),
    "reconquerrions": ("reconquérir",),
    "reconquerrons": ("reconquérir",),
    "reconquerront": ("reconquérir",),
    "reconquièrent": ("reconquérir",),
    "reconquière": ("reconquérir",),
    "reconquières": ("reconquérir",),
    "reconquiers": ("reconquérir",),
    "reconquiert": ("reconquérir",),
    "reconquîmes": ("reconquérir",),
    "reconquirent": ("reconquérir",),
    "reconquise": ("reconquérir",),
    "reconquises": ("reconquérir",),
    "reconquis": ("reconquérir",),
    "reconquissent": ("reconquérir",),
    "reconquisses": ("reconquérir",),
    "reconquisse": ("reconquérir",),
    "reconquissiez": ("reconquérir",),
    "reconquissions": ("reconquérir",),
    "reconquîtes": ("reconquérir",),
    "reconquit": ("reconquérir",),
    "reconquît": ("reconquérir",),
    "reconsens": ("reconsentir",),
    "reconsentaient": ("reconsentir",),
    "reconsentais": ("reconsentir",),
    "reconsentait": ("reconsentir",),
    "reconsentant": ("reconsentir",),
    "reconsentent": ("reconsentir",),
    "reconsente": ("reconsentir",),
    "reconsentes": ("reconsentir",),
    "reconsentez": ("reconsentir",),
    "reconsentie": ("reconsentir",),
    "reconsenties": ("reconsentir",),
    "reconsentiez": ("reconsentir",),
    "reconsenti": ("reconsentir",),
    "reconsentîmes": ("reconsentir",),
    "reconsentions": ("reconsentir",),
    "reconsentira": ("reconsentir",),
    "reconsentiraient": ("reconsentir",),
    "reconsentirai": ("reconsentir",),
    "reconsentirais": ("reconsentir",),
    "reconsentirait": ("reconsentir",),
    "reconsentiras": ("reconsentir",),
    "reconsentirent": ("reconsentir",),
    "reconsentirez": ("reconsentir",),
    "reconsentiriez": ("reconsentir",),
    "reconsentirions": ("reconsentir",),
    "reconsentirons": ("reconsentir",),
    "reconsentiront": ("reconsentir",),
    "reconsentis": ("reconsentir",),
    "reconsentissent": ("reconsentir",),
    "reconsentisses": ("reconsentir",),
    "reconsentisse": ("reconsentir",),
    "reconsentissiez": ("reconsentir",),
    "reconsentissions": ("reconsentir",),
    "reconsentîtes": ("reconsentir",),
    "reconsentit": ("reconsentir",),
    "reconsentît": ("reconsentir",),
    "reconsentons": ("reconsentir",),
    "reconsent": ("reconsentir",),
    "reconsidéraient": ("reconsidérer",),
    "reconsidérai": ("reconsidérer",),
    "reconsidérais": ("reconsidérer",),
    "reconsidérait": ("reconsidérer",),
    "reconsidéra": ("reconsidérer",),
    "reconsidérâmes": ("reconsidérer",),
    "reconsidérant": ("reconsidérer",),
    "reconsidéras": ("reconsidérer",),
    "reconsidérassent": ("reconsidérer",),
    "reconsidérasses": ("reconsidérer",),
    "reconsidérasse": ("reconsidérer",),
    "reconsidérassiez": ("reconsidérer",),
    "reconsidérassions": ("reconsidérer",),
    "reconsidérâtes": ("reconsidérer",),
    "reconsidérât": ("reconsidérer",),
    "reconsidérée": ("reconsidérer",),
    "reconsidérées": ("reconsidérer",),
    "reconsidéré": ("reconsidérer",),
    "reconsidèrent": ("reconsidérer",),
    "reconsidère": ("reconsidérer",),
    "reconsidérera": ("reconsidérer",),
    "reconsidéreraient": ("reconsidérer",),
    "reconsidérerai": ("reconsidérer",),
    "reconsidérerais": ("reconsidérer",),
    "reconsidérerait": ("reconsidérer",),
    "reconsidéreras": ("reconsidérer",),
    "reconsidérèrent": ("reconsidérer",),
    "reconsidérerez": ("reconsidérer",),
    "reconsidéreriez": ("reconsidérer",),
    "reconsidérerions": ("reconsidérer",),
    "reconsidérerons": ("reconsidérer",),
    "reconsidéreront": ("reconsidérer",),
    "reconsidérés": ("reconsidérer",),
    "reconsidères": ("reconsidérer",),
    "reconsidérez": ("reconsidérer",),
    "reconsidériez": ("reconsidérer",),
    "reconsidérions": ("reconsidérer",),
    "reconsidérons": ("reconsidérer",),
    "reconstruira": ("reconstruire",),
    "reconstruiraient": ("reconstruire",),
    "reconstruirai": ("reconstruire",),
    "reconstruirais": ("reconstruire",),
    "reconstruirait": ("reconstruire",),
    "reconstruiras": ("reconstruire",),
    "reconstruirez": ("reconstruire",),
    "reconstruiriez": ("reconstruire",),
    "reconstruirions": ("reconstruire",),
    "reconstruirons": ("reconstruire",),
    "reconstruiront": ("reconstruire",),
    "reconstruisaient": ("reconstruire",),
    "reconstruisais": ("reconstruire",),
    "reconstruisait": ("reconstruire",),
    "reconstruisant": ("reconstruire",),
    "reconstruisent": ("reconstruire",),
    "reconstruise": ("reconstruire",),
    "reconstruises": ("reconstruire",),
    "reconstruisez": ("reconstruire",),
    "reconstruisiez": ("reconstruire",),
    "reconstruisîmes": ("reconstruire",),
    "reconstruisions": ("reconstruire",),
    "reconstruisirent": ("reconstruire",),
    "reconstruisis": ("reconstruire",),
    "reconstruisissent": ("reconstruire",),
    "reconstruisisses": ("reconstruire",),
    "reconstruisisse": ("reconstruire",),
    "reconstruisissiez": ("reconstruire",),
    "reconstruisissions": ("reconstruire",),
    "reconstruisîtes": ("reconstruire",),
    "reconstruisit": ("reconstruire",),
    "reconstruisît": ("reconstruire",),
    "reconstruisons": ("reconstruire",),
    "reconstruis": ("reconstruire",),
    "reconstruite": ("reconstruire",),
    "reconstruites": ("reconstruire",),
    "reconstruit": ("reconstruire",),
    "reconstruits": ("reconstruire",),
    "recontrariaient": ("recontrarier",),
    "recontrariai": ("recontrarier",),
    "recontrariais": ("recontrarier",),
    "recontrariait": ("recontrarier",),
    "recontraria": ("recontrarier",),
    "recontrariâmes": ("recontrarier",),
    "recontrariant": ("recontrarier",),
    "recontrarias": ("recontrarier",),
    "recontrariassent": ("recontrarier",),
    "recontrariasses": ("recontrarier",),
    "recontrariasse": ("recontrarier",),
    "recontrariassiez": ("recontrarier",),
    "recontrariassions": ("recontrarier",),
    "recontrariâtes": ("recontrarier",),
    "recontrariât": ("recontrarier",),
    "recontrariée": ("recontrarier",),
    "recontrariées": ("recontrarier",),
    "recontrarié": ("recontrarier",),
    "recontrarient": ("recontrarier",),
    "recontrarie": ("recontrarier",),
    "recontrariera": ("recontrarier",),
    "recontrarieraient": ("recontrarier",),
    "recontrarierai": ("recontrarier",),
    "recontrarierais": ("recontrarier",),
    "recontrarierait": ("recontrarier",),
    "recontrarieras": ("recontrarier",),
    "recontrarièrent": ("recontrarier",),
    "recontrarierez": ("recontrarier",),
    "recontrarieriez": ("recontrarier",),
    "recontrarierions": ("recontrarier",),
    "recontrarierons": ("recontrarier",),
    "recontrarieront": ("recontrarier",),
    "recontrariés": ("recontrarier",),
    "recontraries": ("recontrarier",),
    "recontrariez": ("recontrarier",),
    "recontrariiez": ("recontrarier",),
    "recontrariions": ("recontrarier",),
    "recontrarions": ("recontrarier",),
    "reconvertie": ("reconvertir",),
    "reconverties": ("reconvertir",),
    "reconverti": ("reconvertir",),
    "reconvertîmes": ("reconvertir",),
    "reconvertira": ("reconvertir",),
    "reconvertiraient": ("reconvertir",),
    "reconvertirai": ("reconvertir",),
    "reconvertirais": ("reconvertir",),
    "reconvertirait": ("reconvertir",),
    "reconvertiras": ("reconvertir",),
    "reconvertirent": ("reconvertir",),
    "reconvertirez": ("reconvertir",),
    "reconvertiriez": ("reconvertir",),
    "reconvertirions": ("reconvertir",),
    "reconvertirons": ("reconvertir",),
    "reconvertiront": ("reconvertir",),
    "reconvertis": ("reconvertir",),
    "reconvertissaient": ("reconvertir",),
    "reconvertissais": ("reconvertir",),
    "reconvertissait": ("reconvertir",),
    "reconvertissant": ("reconvertir",),
    "reconvertissent": ("reconvertir",),
    "reconvertisse": ("reconvertir",),
    "reconvertisses": ("reconvertir",),
    "reconvertissez": ("reconvertir",),
    "reconvertissiez": ("reconvertir",),
    "reconvertissions": ("reconvertir",),
    "reconvertissons": ("reconvertir",),
    "reconvertîtes": ("reconvertir",),
    "reconvertit": ("reconvertir",),
    "reconvertît": ("reconvertir",),
    "recopiaient": ("recopier",),
    "recopiai": ("recopier",),
    "recopiais": ("recopier",),
    "recopiait": ("recopier",),
    "recopia": ("recopier",),
    "recopiâmes": ("recopier",),
    "recopiant": ("recopier",),
    "recopias": ("recopier",),
    "recopiassent": ("recopier",),
    "recopiasses": ("recopier",),
    "recopiasse": ("recopier",),
    "recopiassiez": ("recopier",),
    "recopiassions": ("recopier",),
    "recopiâtes": ("recopier",),
    "recopiât": ("recopier",),
    "recopiée": ("recopier",),
    "recopiées": ("recopier",),
    "recopié": ("recopier",),
    "recopient": ("recopier",),
    "recopie": ("recopier",),
    "recopiera": ("recopier",),
    "recopieraient": ("recopier",),
    "recopierai": ("recopier",),
    "recopierais": ("recopier",),
    "recopierait": ("recopier",),
    "recopieras": ("recopier",),
    "recopièrent": ("recopier",),
    "recopierez": ("recopier",),
    "recopieriez": ("recopier",),
    "recopierions": ("recopier",),
    "recopierons": ("recopier",),
    "recopieront": ("recopier",),
    "recopiés": ("recopier",),
    "recopies": ("recopier",),
    "recopiez": ("recopier",),
    "recopiiez": ("recopier",),
    "recopiions": ("recopier",),
    "recopions": ("recopier",),
    "recoquetaient": ("recoqueter",),
    "recoquetai": ("recoqueter",),
    "recoquetais": ("recoqueter",),
    "recoquetait": ("recoqueter",),
    "recoqueta": ("recoqueter",),
    "recoquetâmes": ("recoqueter",),
    "recoquetant": ("recoqueter",),
    "recoquetas": ("recoqueter",),
    "recoquetassent": ("recoqueter",),
    "recoquetasses": ("recoqueter",),
    "recoquetasse": ("recoqueter",),
    "recoquetassiez": ("recoqueter",),
    "recoquetassions": ("recoqueter",),
    "recoquetâtes": ("recoqueter",),
    "recoquetât": ("recoqueter",),
    "recoquetée": ("recoqueter",),
    "recoquetées": ("recoqueter",),
    "recoqueté": ("recoqueter",),
    "recoquetèrent": ("recoqueter",),
    "recoquetés": ("recoqueter",),
    "recoquetez": ("recoqueter",),
    "recoquetiez": ("recoqueter",),
    "recoquetions": ("recoqueter",),
    "recoquetons": ("recoqueter",),
    "recoquettent": ("recoqueter",),
    "recoquette": ("recoqueter",),
    "recoquettera": ("recoqueter",),
    "recoquetteraient": ("recoqueter",),
    "recoquetterai": ("recoqueter",),
    "recoquetterais": ("recoqueter",),
    "recoquetterait": ("recoqueter",),
    "recoquetteras": ("recoqueter",),
    "recoquetterez": ("recoqueter",),
    "recoquetteriez": ("recoqueter",),
    "recoquetterions": ("recoqueter",),
    "recoquetterons": ("recoqueter",),
    "recoquetteront": ("recoqueter",),
    "recoquettes": ("recoqueter",),
    "recorrespondaient": ("recorrespondre",),
    "recorrespondais": ("recorrespondre",),
    "recorrespondait": ("recorrespondre",),
    "recorrespondant": ("recorrespondre",),
    "recorrespondent": ("recorrespondre",),
    "recorresponde": ("recorrespondre",),
    "recorrespondes": ("recorrespondre",),
    "recorrespondez": ("recorrespondre",),
    "recorrespondiez": ("recorrespondre",),
    "recorrespondîmes": ("recorrespondre",),
    "recorrespondions": ("recorrespondre",),
    "recorrespondirent": ("recorrespondre",),
    "recorrespondis": ("recorrespondre",),
    "recorrespondissent": ("recorrespondre",),
    "recorrespondisses": ("recorrespondre",),
    "recorrespondisse": ("recorrespondre",),
    "recorrespondissiez": ("recorrespondre",),
    "recorrespondissions": ("recorrespondre",),
    "recorrespondîtes": ("recorrespondre",),
    "recorrespondit": ("recorrespondre",),
    "recorrespondît": ("recorrespondre",),
    "recorrespondons": ("recorrespondre",),
    "recorrespond": ("recorrespondre",),
    "recorrespondra": ("recorrespondre",),
    "recorrespondraient": ("recorrespondre",),
    "recorrespondrai": ("recorrespondre",),
    "recorrespondrais": ("recorrespondre",),
    "recorrespondrait": ("recorrespondre",),
    "recorrespondras": ("recorrespondre",),
    "recorrespondrez": ("recorrespondre",),
    "recorrespondriez": ("recorrespondre",),
    "recorrespondrions": ("recorrespondre",),
    "recorrespondrons": ("recorrespondre",),
    "recorrespondront": ("recorrespondre",),
    "recorresponds": ("recorrespondre",),
    "recorrespondue": ("recorrespondre",),
    "recorrespondues": ("recorrespondre",),
    "recorrespondu": ("recorrespondre",),
    "recorrespondus": ("recorrespondre",),
    "recorrigeaient": ("recorriger",),
    "recorrigeai": ("recorriger",),
    "recorrigeais": ("recorriger",),
    "recorrigeait": ("recorriger",),
    "recorrigea": ("recorriger",),
    "recorrigeâmes": ("recorriger",),
    "recorrigeant": ("recorriger",),
    "recorrigeas": ("recorriger",),
    "recorrigeassent": ("recorriger",),
    "recorrigeasses": ("recorriger",),
    "recorrigeasse": ("recorriger",),
    "recorrigeassiez": ("recorriger",),
    "recorrigeassions": ("recorriger",),
    "recorrigeâtes": ("recorriger",),
    "recorrigeât": ("recorriger",),
    "recorrigée": ("recorriger",),
    "recorrigées": ("recorriger",),
    "recorrigé": ("recorriger",),
    "recorrigent": ("recorriger",),
    "recorrigeons": ("recorriger",),
    "recorrige": ("recorriger",),
    "recorrigera": ("recorriger",),
    "recorrigeraient": ("recorriger",),
    "recorrigerai": ("recorriger",),
    "recorrigerais": ("recorriger",),
    "recorrigerait": ("recorriger",),
    "recorrigeras": ("recorriger",),
    "recorrigèrent": ("recorriger",),
    "recorrigerez": ("recorriger",),
    "recorrigeriez": ("recorriger",),
    "recorrigerions": ("recorriger",),
    "recorrigerons": ("recorriger",),
    "recorrigeront": ("recorriger",),
    "recorrigés": ("recorriger",),
    "recorriges": ("recorriger",),
    "recorrigez": ("recorriger",),
    "recorrigiez": ("recorriger",),
    "recorrigions": ("recorriger",),
    "recoud": ("recoudre",),
    "recoudra": ("recoudre",),
    "recoudraient": ("recoudre",),
    "recoudrai": ("recoudre",),
    "recoudrais": ("recoudre",),
    "recoudrait": ("recoudre",),
    "recoudras": ("recoudre",),
    "recoudrez": ("recoudre",),
    "recoudriez": ("recoudre",),
    "recoudrions": ("recoudre",),
    "recoudrons": ("recoudre",),
    "recoudront": ("recoudre",),
    "recouds": ("recoudre",),
    "recousaient": ("recoudre",),
    "recousais": ("recoudre",),
    "recousait": ("recoudre",),
    "recousant": ("recoudre",),
    "recousent": ("recoudre",),
    "recouse": ("recoudre",),
    "recouses": ("recoudre",),
    "recousez": ("recoudre",),
    "recousiez": ("recoudre",),
    "recousîmes": ("recoudre",),
    "recousions": ("recoudre",),
    "recousirent": ("recoudre",),
    "recousis": ("recoudre",),
    "recousissent": ("recoudre",),
    "recousisses": ("recoudre",),
    "recousisse": ("recoudre",),
    "recousissiez": ("recoudre",),
    "recousissions": ("recoudre",),
    "recousîtes": ("recoudre",),
    "recousit": ("recoudre",),
    "recousît": ("recoudre",),
    "recousons": ("recoudre",),
    "recousue": ("recoudre",),
    "recousues": ("recoudre",),
    "recousu": ("recoudre",),
    "recousus": ("recoudre",),
    "recouraient": ("recourir",),
    "recourais": ("recourir",),
    "recourait": ("recourir",),
    "recourant": ("recourir",),
    "recourent": ("recourir",),
    "recoure": ("recourir",),
    "recoures": ("recourir",),
    "recourez": ("recourir",),
    "recouriez": ("recourir",),
    "recourions": ("recourir",),
    "recourons": ("recourir",),
    "recourra": ("recourir",),
    "recourraient": ("recourir",),
    "recourrai": ("recourir",),
    "recourrais": ("recourir",),
    "recourrait": ("recourir",),
    "recourras": ("recourir",),
    "recourrez": ("recourir",),
    "recourriez": ("recourir",),
    "recourrions": ("recourir",),
    "recourrons": ("recourir",),
    "recourront": ("recourir",),
    "recours": ("recourir",),
    "recourt": ("recourir",),
    "recourue": ("recourir",),
    "recourues": ("recourir",),
    "recouru": ("recourir",),
    "recourûmes": ("recourir",),
    "recoururent": ("recourir",),
    "recourus": ("recourir",),
    "recourussent": ("recourir",),
    "recourusses": ("recourir",),
    "recourusse": ("recourir",),
    "recourussiez": ("recourir",),
    "recourussions": ("recourir",),
    "recourûtes": ("recourir",),
    "recourut": ("recourir",),
    "recourût": ("recourir",),
    "recourrouçaient": ("recourroucer",),
    "recourrouçai": ("recourroucer",),
    "recourrouçais": ("recourroucer",),
    "recourrouçait": ("recourroucer",),
    "recourrouça": ("recourroucer",),
    "recourrouçâmes": ("recourroucer",),
    "recourrouçant": ("recourroucer",),
    "recourrouças": ("recourroucer",),
    "recourrouçassent": ("recourroucer",),
    "recourrouçasses": ("recourroucer",),
    "recourrouçasse": ("recourroucer",),
    "recourrouçassiez": ("recourroucer",),
    "recourrouçassions": ("recourroucer",),
    "recourrouçâtes": ("recourroucer",),
    "recourrouçât": ("recourroucer",),
    "recourroucée": ("recourroucer",),
    "recourroucées": ("recourroucer",),
    "recourroucé": ("recourroucer",),
    "recourroucent": ("recourroucer",),
    "recourrouce": ("recourroucer",),
    "recourroucera": ("recourroucer",),
    "recourrouceraient": ("recourroucer",),
    "recourroucerai": ("recourroucer",),
    "recourroucerais": ("recourroucer",),
    "recourroucerait": ("recourroucer",),
    "recourrouceras": ("recourroucer",),
    "recourroucèrent": ("recourroucer",),
    "recourroucerez": ("recourroucer",),
    "recourrouceriez": ("recourroucer",),
    "recourroucerions": ("recourroucer",),
    "recourroucerons": ("recourroucer",),
    "recourrouceront": ("recourroucer",),
    "recourroucés": ("recourroucer",),
    "recourrouces": ("recourroucer",),
    "recourroucez": ("recourroucer",),
    "recourrouciez": ("recourroucer",),
    "recourroucions": ("recourroucer",),
    "recourrouçons": ("recourroucer",),
    "recouverte": ("recouvrir",),
    "recouvertes": ("recouvrir",),
    "recouvert": ("recouvrir",),
    "recouverts": ("recouvrir",),
    "recouvraient": ("recouvrir",),
    "recouvrais": ("recouvrir",),
    "recouvrait": ("recouvrir",),
    "recouvrant": ("recouvrir",),
    "recouvrent": ("recouvrir",),
    "recouvre": ("recouvrir",),
    "recouvres": ("recouvrir",),
    "recouvrez": ("recouvrir",),
    "recouvriez": ("recouvrir",),
    "recouvrîmes": ("recouvrir",),
    "recouvrions": ("recouvrir",),
    "recouvrira": ("recouvrir",),
    "recouvriraient": ("recouvrir",),
    "recouvrirai": ("recouvrir",),
    "recouvrirais": ("recouvrir",),
    "recouvrirait": ("recouvrir",),
    "recouvriras": ("recouvrir",),
    "recouvrirent": ("recouvrir",),
    "recouvrirez": ("recouvrir",),
    "recouvririez": ("recouvrir",),
    "recouvririons": ("recouvrir",),
    "recouvrirons": ("recouvrir",),
    "recouvriront": ("recouvrir",),
    "recouvris": ("recouvrir",),
    "recouvrissent": ("recouvrir",),
    "recouvrisses": ("recouvrir",),
    "recouvrisse": ("recouvrir",),
    "recouvrissiez": ("recouvrir",),
    "recouvrissions": ("recouvrir",),
    "recouvrîtes": ("recouvrir",),
    "recouvrit": ("recouvrir",),
    "recouvrît": ("recouvrir",),
    "recouvrons": ("recouvrir",),
    "recrépie": ("recrépir",),
    "recrépies": ("recrépir",),
    "recrépi": ("recrépir",),
    "recrépîmes": ("recrépir",),
    "recrépira": ("recrépir",),
    "recrépiraient": ("recrépir",),
    "recrépirai": ("recrépir",),
    "recrépirais": ("recrépir",),
    "recrépirait": ("recrépir",),
    "recrépiras": ("recrépir",),
    "recrépirent": ("recrépir",),
    "recrépirez": ("recrépir",),
    "recrépiriez": ("recrépir",),
    "recrépirions": ("recrépir",),
    "recrépirons": ("recrépir",),
    "recrépiront": ("recrépir",),
    "recrépis": ("recrépir",),
    "recrépissaient": ("recrépir",),
    "recrépissais": ("recrépir",),
    "recrépissait": ("recrépir",),
    "recrépissant": ("recrépir",),
    "recrépissent": ("recrépir",),
    "recrépisse": ("recrépir",),
    "recrépisses": ("recrépir",),
    "recrépissez": ("recrépir",),
    "recrépissiez": ("recrépir",),
    "recrépissions": ("recrépir",),
    "recrépissons": ("recrépir",),
    "recrépîtes": ("recrépir",),
    "recrépit": ("recrépir",),
    "recrépît": ("recrépir",),
    "récrira": ("récrire",),
    "récriraient": ("récrire",),
    "récrirai": ("récrire",),
    "récrirais": ("récrire",),
    "récrirait": ("récrire",),
    "récriras": ("récrire",),
    "récrirez": ("récrire",),
    "récririez": ("récrire",),
    "récririons": ("récrire",),
    "récrirons": ("récrire",),
    "récriront": ("récrire",),
    "récris": ("récrire",),
    "récrite": ("récrire",),
    "récrites": ("récrire",),
    "récrit": ("récrire",),
    "récrits": ("récrire",),
    "récrivaient": ("récrire",),
    "récrivais": ("récrire",),
    "récrivait": ("récrire",),
    "récrivant": ("récrire",),
    "récrivent": ("récrire",),
    "récrive": ("récrire",),
    "récrives": ("récrire",),
    "récrivez": ("récrire",),
    "récriviez": ("récrire",),
    "récrivîmes": ("récrire",),
    "récrivions": ("récrire",),
    "récrivirent": ("récrire",),
    "récrivis": ("récrire",),
    "récrivissent": ("récrire",),
    "récrivisses": ("récrire",),
    "récrivisse": ("récrire",),
    "récrivissiez": ("récrire",),
    "récrivissions": ("récrire",),
    "récrivîtes": ("récrire",),
    "récrivit": ("récrire",),
    "récrivît": ("récrire",),
    "récrivons": ("récrire",),
    "recroient": ("recroire",),
    "recroie": ("recroire",),
    "recroies": ("recroire",),
    "recroira": ("recroire",),
    "recroiraient": ("recroire",),
    "recroirai": ("recroire",),
    "recroirais": ("recroire",),
    "recroirait": ("recroire",),
    "recroiras": ("recroire",),
    "recroirez": ("recroire",),
    "recroiriez": ("recroire",),
    "recroirions": ("recroire",),
    "recroirons": ("recroire",),
    "recroiront": ("recroire",),
    "recrois": ("recroître",),
    "recroit": ("recroire",),
    "recroyaient": ("recroire",),
    "recroyais": ("recroire",),
    "recroyait": ("recroire",),
    "recroyant": ("recroire",),
    "recroyez": ("recroire",),
    "recroyiez": ("recroire",),
    "recroyions": ("recroire",),
    "recroyons": ("recroire",),
    "recrue": ("recroître",),
    "recrues": ("recroître",),
    "recru": ("recroire",),
    "recrûmes": ("recroître",),
    "recrurent": ("recroître",),
    "recrus": ("recroître",),
    "recrussent": ("recroître",),
    "recrusses": ("recroître",),
    "recrusse": ("recroître",),
    "recrussiez": ("recroître",),
    "recrussions": ("recroître",),
    "recrûtes": ("recroître",),
    "recrut": ("recroître",),
    "recrût": ("recroître",),
    "recroissaient": ("recroître",),
    "recroissais": ("recroître",),
    "recroissait": ("recroître",),
    "recroissant": ("recroître",),
    "recroissent": ("recroître",),
    "recroisse": ("recroître",),
    "recroisses": ("recroître",),
    "recroissez": ("recroître",),
    "recroissiez": ("recroître",),
    "recroissions": ("recroître",),
    "recroissons": ("recroître",),
    "recroît": ("recroître",),
    "recroîtra": ("recroître",),
    "recroîtraient": ("recroître",),
    "recroîtrai": ("recroître",),
    "recroîtrais": ("recroître",),
    "recroîtrait": ("recroître",),
    "recroîtras": ("recroître",),
    "recroîtrez": ("recroître",),
    "recroîtriez": ("recroître",),
    "recroîtrions": ("recroître",),
    "recroîtrons": ("recroître",),
    "recroîtront": ("recroître",),
    "recrû": ("recroître",),
    "rectifiaient": ("rectifier",),
    "rectifiai": ("rectifier",),
    "rectifiais": ("rectifier",),
    "rectifiait": ("rectifier",),
    "rectifia": ("rectifier",),
    "rectifiâmes": ("rectifier",),
    "rectifiant": ("rectifier",),
    "rectifias": ("rectifier",),
    "rectifiassent": ("rectifier",),
    "rectifiasses": ("rectifier",),
    "rectifiasse": ("rectifier",),
    "rectifiassiez": ("rectifier",),
    "rectifiassions": ("rectifier",),
    "rectifiâtes": ("rectifier",),
    "rectifiât": ("rectifier",),
    "rectifiée": ("rectifier",),
    "rectifiées": ("rectifier",),
    "rectifié": ("rectifier",),
    "rectifient": ("rectifier",),
    "rectifie": ("rectifier",),
    "rectifiera": ("rectifier",),
    "rectifieraient": ("rectifier",),
    "rectifierai": ("rectifier",),
    "rectifierais": ("rectifier",),
    "rectifierait": ("rectifier",),
    "rectifieras": ("rectifier",),
    "rectifièrent": ("rectifier",),
    "rectifierez": ("rectifier",),
    "rectifieriez": ("rectifier",),
    "rectifierions": ("rectifier",),
    "rectifierons": ("rectifier",),
    "rectifieront": ("rectifier",),
    "rectifiés": ("rectifier",),
    "rectifies": ("rectifier",),
    "rectifiez": ("rectifier",),
    "rectifiiez": ("rectifier",),
    "rectifiions": ("rectifier",),
    "rectifions": ("rectifier",),
    "recueillaient": ("recueillir",),
    "recueillais": ("recueillir",),
    "recueillait": ("recueillir",),
    "recueillant": ("recueillir",),
    "recueillent": ("recueillir",),
    "recueille": ("recueillir",),
    "recueillera": ("recueillir",),
    "recueilleraient": ("recueillir",),
    "recueillerai": ("recueillir",),
    "recueillerais": ("recueillir",),
    "recueillerait": ("recueillir",),
    "recueilleras": ("recueillir",),
    "recueillerez": ("recueillir",),
    "recueilleriez": ("recueillir",),
    "recueillerions": ("recueillir",),
    "recueillerons": ("recueillir",),
    "recueilleront": ("recueillir",),
    "recueilles": ("recueillir",),
    "recueillez": ("recueillir",),
    "recueillie": ("recueillir",),
    "recueillies": ("recueillir",),
    "recueilliez": ("recueillir",),
    "recueilli": ("recueillir",),
    "recueillîmes": ("recueillir",),
    "recueillions": ("recueillir",),
    "recueillirent": ("recueillir",),
    "recueillis": ("recueillir",),
    "recueillissent": ("recueillir",),
    "recueillisses": ("recueillir",),
    "recueillisse": ("recueillir",),
    "recueillissiez": ("recueillir",),
    "recueillissions": ("recueillir",),
    "recueillîtes": ("recueillir",),
    "recueillit": ("recueillir",),
    "recueillît": ("recueillir",),
    "recueillons": ("recueillir",),
    "recuira": ("recuire",),
    "recuiraient": ("recuire",),
    "recuirai": ("recuire",),
    "recuirais": ("recuire",),
    "recuirait": ("recuire",),
    "recuiras": ("recuire",),
    "recuirez": ("recuire",),
    "recuiriez": ("recuire",),
    "recuirions": ("recuire",),
    "recuirons": ("recuire",),
    "recuiront": ("recuire",),
    "recuisaient": ("recuire",),
    "recuisais": ("recuire",),
    "recuisait": ("recuire",),
    "recuisant": ("recuire",),
    "recuisent": ("recuire",),
    "recuise": ("recuire",),
    "recuises": ("recuire",),
    "recuisez": ("recuire",),
    "recuisiez": ("recuire",),
    "recuisîmes": ("recuire",),
    "recuisions": ("recuire",),
    "recuisirent": ("recuire",),
    "recuisis": ("recuire",),
    "recuisissent": ("recuire",),
    "recuisisses": ("recuire",),
    "recuisisse": ("recuire",),
    "recuisissiez": ("recuire",),
    "recuisissions": ("recuire",),
    "recuisîtes": ("recuire",),
    "recuisit": ("recuire",),
    "recuisît": ("recuire",),
    "recuisons": ("recuire",),
    "recuis": ("recuire",),
    "recuite": ("recuire",),
    "recuites": ("recuire",),
    "recuit": ("recuire",),
    "recuits": ("recuire",),
    "récupéraient": ("récupérer",),
    "récupérai": ("récupérer",),
    "récupérais": ("récupérer",),
    "récupérait": ("récupérer",),
    "récupéra": ("récupérer",),
    "récupérâmes": ("récupérer",),
    "récupérant": ("récupérer",),
    "récupéras": ("récupérer",),
    "récupérassent": ("récupérer",),
    "récupérasses": ("récupérer",),
    "récupérasse": ("récupérer",),
    "récupérassiez": ("récupérer",),
    "récupérassions": ("récupérer",),
    "récupérâtes": ("récupérer",),
    "récupérât": ("récupérer",),
    "récupérée": ("récupérer",),
    "récupérées": ("récupérer",),
    "récupéré": ("récupérer",),
    "récupèrent": ("récupérer",),
    "récupère": ("récupérer",),
    "récupérera": ("récupérer",),
    "récupéreraient": ("récupérer",),
    "récupérerai": ("récupérer",),
    "récupérerais": ("récupérer",),
    "récupérerait": ("récupérer",),
    "récupéreras": ("récupérer",),
    "récupérèrent": ("récupérer",),
    "récupérerez": ("récupérer",),
    "récupéreriez": ("récupérer",),
    "récupérerions": ("récupérer",),
    "récupérerons": ("récupérer",),
    "récupéreront": ("récupérer",),
    "récupérés": ("récupérer",),
    "récupères": ("récupérer",),
    "récupérez": ("récupérer",),
    "récupériez": ("récupérer",),
    "récupérions": ("récupérer",),
    "récupérons": ("récupérer",),
    "redactylographiaient": ("redactylographier",),
    "redactylographiai": ("redactylographier",),
    "redactylographiais": ("redactylographier",),
    "redactylographiait": ("redactylographier",),
    "redactylographia": ("redactylographier",),
    "redactylographiâmes": ("redactylographier",),
    "redactylographiant": ("redactylographier",),
    "redactylographias": ("redactylographier",),
    "redactylographiassent": ("redactylographier",),
    "redactylographiasses": ("redactylographier",),
    "redactylographiasse": ("redactylographier",),
    "redactylographiassiez": ("redactylographier",),
    "redactylographiassions": ("redactylographier",),
    "redactylographiâtes": ("redactylographier",),
    "redactylographiât": ("redactylographier",),
    "redactylographiée": ("redactylographier",),
    "redactylographiées": ("redactylographier",),
    "redactylographié": ("redactylographier",),
    "redactylographient": ("redactylographier",),
    "redactylographie": ("redactylographier",),
    "redactylographiera": ("redactylographier",),
    "redactylographieraient": ("redactylographier",),
    "redactylographierai": ("redactylographier",),
    "redactylographierais": ("redactylographier",),
    "redactylographierait": ("redactylographier",),
    "redactylographieras": ("redactylographier",),
    "redactylographièrent": ("redactylographier",),
    "redactylographierez": ("redactylographier",),
    "redactylographieriez": ("redactylographier",),
    "redactylographierions": ("redactylographier",),
    "redactylographierons": ("redactylographier",),
    "redactylographieront": ("redactylographier",),
    "redactylographiés": ("redactylographier",),
    "redactylographies": ("redactylographier",),
    "redactylographiez": ("redactylographier",),
    "redactylographiiez": ("redactylographier",),
    "redactylographiions": ("redactylographier",),
    "redactylographions": ("redactylographier",),
    "redébarrassaient": ("redébarrasser",),
    "redébarrassai": ("redébarrasser",),
    "redébarrassais": ("redébarrasser",),
    "redébarrassait": ("redébarrasser",),
    "redébarrassa": ("redébarrasser",),
    "redébarrassâmes": ("redébarrasser",),
    "redébarrassant": ("redébarrasser",),
    "redébarrassas": ("redébarrasser",),
    "redébarrassassent": ("redébarrasser",),
    "redébarrassasses": ("redébarrasser",),
    "redébarrassasse": ("redébarrasser",),
    "redébarrassassiez": ("redébarrasser",),
    "redébarrassassions": ("redébarrasser",),
    "redébarrassâtes": ("redébarrasser",),
    "redébarrassât": ("redébarrasser",),
    "redébarrassée": ("redébarrasser",),
    "redébarrassées": ("redébarrasser",),
    "redébarrassé": ("redébarrasser",),
    "redébarrassent": ("redébarrasser",),
    "redébarrasse": ("redébarrasser",),
    "redébarrassera": ("redébarrasser",),
    "redébarrasseraient": ("redébarrasser",),
    "redébarrasserai": ("redébarrasser",),
    "redébarrasserais": ("redébarrasser",),
    "redébarrasserait": ("redébarrasser",),
    "redébarrasseras": ("redébarrasser",),
    "redébarrassèrent": ("redébarrasser",),
    "redébarrasserez": ("redébarrasser",),
    "redébarrasseriez": ("redébarrasser",),
    "redébarrasserions": ("redébarrasser",),
    "redébarrasserons": ("redébarrasser",),
    "redébarrasseront": ("redébarrasser",),
    "redébarrassés": ("redébarrasser",),
    "redébarrasses": ("redébarrasser",),
    "redébarrassez": ("redébarrasser",),
    "redébarrassiez": ("redébarrasser",),
    "redébarrassions": ("redébarrasser",),
    "redébarrassons": ("redébarrasser",),
    "redébat": ("redébattre",),
    "redébats": ("redébattre",),
    "redébattaient": ("redébattre",),
    "redébattais": ("redébattre",),
    "redébattait": ("redébattre",),
    "redébattant": ("redébattre",),
    "redébattent": ("redébattre",),
    "redébatte": ("redébattre",),
    "redébattes": ("redébattre",),
    "redébattez": ("redébattre",),
    "redébattiez": ("redébattre",),
    "redébattîmes": ("redébattre",),
    "redébattions": ("redébattre",),
    "redébattirent": ("redébattre",),
    "redébattis": ("redébattre",),
    "redébattissent": ("redébattre",),
    "redébattisses": ("redébattre",),
    "redébattisse": ("redébattre",),
    "redébattissiez": ("redébattre",),
    "redébattissions": ("redébattre",),
    "redébattîtes": ("redébattre",),
    "redébattit": ("redébattre",),
    "redébattît": ("redébattre",),
    "redébattons": ("redébattre",),
    "redébattra": ("redébattre",),
    "redébattraient": ("redébattre",),
    "redébattrai": ("redébattre",),
    "redébattrais": ("redébattre",),
    "redébattrait": ("redébattre",),
    "redébattras": ("redébattre",),
    "redébattrez": ("redébattre",),
    "redébattriez": ("redébattre",),
    "redébattrions": ("redébattre",),
    "redébattrons": ("redébattre",),
    "redébattront": ("redébattre",),
    "redébattue": ("redébattre",),
    "redébattues": ("redébattre",),
    "redébattu": ("redébattre",),
    "redébattus": ("redébattre",),
    "redéblaient": ("redéblayer",),
    "redéblaie": ("redéblayer",),
    "redéblaiera": ("redéblayer",),
    "redéblaieraient": ("redéblayer",),
    "redéblaierai": ("redéblayer",),
    "redéblaierais": ("redéblayer",),
    "redéblaierait": ("redéblayer",),
    "redéblaieras": ("redéblayer",),
    "redéblaierez": ("redéblayer",),
    "redéblaieriez": ("redéblayer",),
    "redéblaierions": ("redéblayer",),
    "redéblaierons": ("redéblayer",),
    "redéblaieront": ("redéblayer",),
    "redéblaies": ("redéblayer",),
    "redéblayaient": ("redéblayer",),
    "redéblayai": ("redéblayer",),
    "redéblayais": ("redéblayer",),
    "redéblayait": ("redéblayer",),
    "redéblaya": ("redéblayer",),
    "redéblayâmes": ("redéblayer",),
    "redéblayant": ("redéblayer",),
    "redéblayas": ("redéblayer",),
    "redéblayassent": ("redéblayer",),
    "redéblayasses": ("redéblayer",),
    "redéblayasse": ("redéblayer",),
    "redéblayassiez": ("redéblayer",),
    "redéblayassions": ("redéblayer",),
    "redéblayâtes": ("redéblayer",),
    "redéblayât": ("redéblayer",),
    "redéblayée": ("redéblayer",),
    "redéblayées": ("redéblayer",),
    "redéblayé": ("redéblayer",),
    "redéblayent": ("redéblayer",),
    "redéblaye": ("redéblayer",),
    "redéblayera": ("redéblayer",),
    "redéblayeraient": ("redéblayer",),
    "redéblayerai": ("redéblayer",),
    "redéblayerais": ("redéblayer",),
    "redéblayerait": ("redéblayer",),
    "redéblayeras": ("redéblayer",),
    "redéblayèrent": ("redéblayer",),
    "redéblayerez": ("redéblayer",),
    "redéblayeriez": ("redéblayer",),
    "redéblayerions": ("redéblayer",),
    "redéblayerons": ("redéblayer",),
    "redéblayeront": ("redéblayer",),
    "redéblayés": ("redéblayer",),
    "redéblayes": ("redéblayer",),
    "redéblayez": ("redéblayer",),
    "redéblayiez": ("redéblayer",),
    "redéblayions": ("redéblayer",),
    "redéblayons": ("redéblayer",),
    "redébraient": ("redébrayer",),
    "redébraie": ("redébrayer",),
    "redébraiera": ("redébrayer",),
    "redébraieraient": ("redébrayer",),
    "redébraierai": ("redébrayer",),
    "redébraierais": ("redébrayer",),
    "redébraierait": ("redébrayer",),
    "redébraieras": ("redébrayer",),
    "redébraierez": ("redébrayer",),
    "redébraieriez": ("redébrayer",),
    "redébraierions": ("redébrayer",),
    "redébraierons": ("redébrayer",),
    "redébraieront": ("redébrayer",),
    "redébraies": ("redébrayer",),
    "redébrayaient": ("redébrayer",),
    "redébrayai": ("redébrayer",),
    "redébrayais": ("redébrayer",),
    "redébrayait": ("redébrayer",),
    "redébraya": ("redébrayer",),
    "redébrayâmes": ("redébrayer",),
    "redébrayant": ("redébrayer",),
    "redébrayas": ("redébrayer",),
    "redébrayassent": ("redébrayer",),
    "redébrayasses": ("redébrayer",),
    "redébrayasse": ("redébrayer",),
    "redébrayassiez": ("redébrayer",),
    "redébrayassions": ("redébrayer",),
    "redébrayâtes": ("redébrayer",),
    "redébrayât": ("redébrayer",),
    "redébrayée": ("redébrayer",),
    "redébrayées": ("redébrayer",),
    "redébrayé": ("redébrayer",),
    "redébrayent": ("redébrayer",),
    "redébraye": ("redébrayer",),
    "redébrayera": ("redébrayer",),
    "redébrayeraient": ("redébrayer",),
    "redébrayerai": ("redébrayer",),
    "redébrayerais": ("redébrayer",),
    "redébrayerait": ("redébrayer",),
    "redébrayeras": ("redébrayer",),
    "redébrayèrent": ("redébrayer",),
    "redébrayerez": ("redébrayer",),
    "redébrayeriez": ("redébrayer",),
    "redébrayerions": ("redébrayer",),
    "redébrayerons": ("redébrayer",),
    "redébrayeront": ("redébrayer",),
    "redébrayés": ("redébrayer",),
    "redébrayes": ("redébrayer",),
    "redébrayez": ("redébrayer",),
    "redébrayiez": ("redébrayer",),
    "redébrayions": ("redébrayer",),
    "redébrayons": ("redébrayer",),
    "redécachetaient": ("redécacheter",),
    "redécachetai": ("redécacheter",),
    "redécachetais": ("redécacheter",),
    "redécachetait": ("redécacheter",),
    "redécacheta": ("redécacheter",),
    "redécachetâmes": ("redécacheter",),
    "redécachetant": ("redécacheter",),
    "redécachetas": ("redécacheter",),
    "redécachetassent": ("redécacheter",),
    "redécachetasses": ("redécacheter",),
    "redécachetasse": ("redécacheter",),
    "redécachetassiez": ("redécacheter",),
    "redécachetassions": ("redécacheter",),
    "redécachetâtes": ("redécacheter",),
    "redécachetât": ("redécacheter",),
    "redécachetée": ("redécacheter",),
    "redécachetées": ("redécacheter",),
    "redécacheté": ("redécacheter",),
    "redécachetèrent": ("redécacheter",),
    "redécachetés": ("redécacheter",),
    "redécachetez": ("redécacheter",),
    "redécachetiez": ("redécacheter",),
    "redécachetions": ("redécacheter",),
    "redécachetons": ("redécacheter",),
    "redécachettent": ("redécacheter",),
    "redécachette": ("redécacheter",),
    "redécachettera": ("redécacheter",),
    "redécachetteraient": ("redécacheter",),
    "redécachetterai": ("redécacheter",),
    "redécachetterais": ("redécacheter",),
    "redécachetterait": ("redécacheter",),
    "redécachetteras": ("redécacheter",),
    "redécachetterez": ("redécacheter",),
    "redécachetteriez": ("redécacheter",),
    "redécachetterions": ("redécacheter",),
    "redécachetterons": ("redécacheter",),
    "redécachetteront": ("redécacheter",),
    "redécachettes": ("redécacheter",),
    "redécadenassaient": ("redécadenasser",),
    "redécadenassai": ("redécadenasser",),
    "redécadenassais": ("redécadenasser",),
    "redécadenassait": ("redécadenasser",),
    "redécadenassa": ("redécadenasser",),
    "redécadenassâmes": ("redécadenasser",),
    "redécadenassant": ("redécadenasser",),
    "redécadenassas": ("redécadenasser",),
    "redécadenassassent": ("redécadenasser",),
    "redécadenassasses": ("redécadenasser",),
    "redécadenassasse": ("redécadenasser",),
    "redécadenassassiez": ("redécadenasser",),
    "redécadenassassions": ("redécadenasser",),
    "redécadenassâtes": ("redécadenasser",),
    "redécadenassât": ("redécadenasser",),
    "redécadenassée": ("redécadenasser",),
    "redécadenassées": ("redécadenasser",),
    "redécadenassé": ("redécadenasser",),
    "redécadenassent": ("redécadenasser",),
    "redécadenasse": ("redécadenasser",),
    "redécadenassera": ("redécadenasser",),
    "redécadenasseraient": ("redécadenasser",),
    "redécadenasserai": ("redécadenasser",),
    "redécadenasserais": ("redécadenasser",),
    "redécadenasserait": ("redécadenasser",),
    "redécadenasseras": ("redécadenasser",),
    "redécadenassèrent": ("redécadenasser",),
    "redécadenasserez": ("redécadenasser",),
    "redécadenasseriez": ("redécadenasser",),
    "redécadenasserions": ("redécadenasser",),
    "redécadenasserons": ("redécadenasser",),
    "redécadenasseront": ("redécadenasser",),
    "redécadenassés": ("redécadenasser",),
    "redécadenasses": ("redécadenasser",),
    "redécadenassez": ("redécadenasser",),
    "redécadenassiez": ("redécadenasser",),
    "redécadenassions": ("redécadenasser",),
    "redécadenassons": ("redécadenasser",),
    "redécalcifiaient": ("redécalcifier",),
    "redécalcifiai": ("redécalcifier",),
    "redécalcifiais": ("redécalcifier",),
    "redécalcifiait": ("redécalcifier",),
    "redécalcifia": ("redécalcifier",),
    "redécalcifiâmes": ("redécalcifier",),
    "redécalcifiant": ("redécalcifier",),
    "redécalcifias": ("redécalcifier",),
    "redécalcifiassent": ("redécalcifier",),
    "redécalcifiasses": ("redécalcifier",),
    "redécalcifiasse": ("redécalcifier",),
    "redécalcifiassiez": ("redécalcifier",),
    "redécalcifiassions": ("redécalcifier",),
    "redécalcifiâtes": ("redécalcifier",),
    "redécalcifiât": ("redécalcifier",),
    "redécalcifiée": ("redécalcifier",),
    "redécalcifiées": ("redécalcifier",),
    "redécalcifié": ("redécalcifier",),
    "redécalcifient": ("redécalcifier",),
    "redécalcifie": ("redécalcifier",),
    "redécalcifiera": ("redécalcifier",),
    "redécalcifieraient": ("redécalcifier",),
    "redécalcifierai": ("redécalcifier",),
    "redécalcifierais": ("redécalcifier",),
    "redécalcifierait": ("redécalcifier",),
    "redécalcifieras": ("redécalcifier",),
    "redécalcifièrent": ("redécalcifier",),
    "redécalcifierez": ("redécalcifier",),
    "redécalcifieriez": ("redécalcifier",),
    "redécalcifierions": ("redécalcifier",),
    "redécalcifierons": ("redécalcifier",),
    "redécalcifieront": ("redécalcifier",),
    "redécalcifiés": ("redécalcifier",),
    "redécalcifies": ("redécalcifier",),
    "redécalcifiez": ("redécalcifier",),
    "redécalcifiiez": ("redécalcifier",),
    "redécalcifiions": ("redécalcifier",),
    "redécalcifions": ("redécalcifier",),
    "redécéléraient": ("redécélérer",),
    "redécélérai": ("redécélérer",),
    "redécélérais": ("redécélérer",),
    "redécélérait": ("redécélérer",),
    "redécéléra": ("redécélérer",),
    "redécélérâmes": ("redécélérer",),
    "redécélérant": ("redécélérer",),
    "redécéléras": ("redécélérer",),
    "redécélérassent": ("redécélérer",),
    "redécélérasses": ("redécélérer",),
    "redécélérasse": ("redécélérer",),
    "redécélérassiez": ("redécélérer",),
    "redécélérassions": ("redécélérer",),
    "redécélérâtes": ("redécélérer",),
    "redécélérât": ("redécélérer",),
    "redécélérée": ("redécélérer",),
    "redécélérées": ("redécélérer",),
    "redécéléré": ("redécélérer",),
    "redécélèrent": ("redécélérer",),
    "redécélère": ("redécélérer",),
    "redécélérera": ("redécélérer",),
    "redécéléreraient": ("redécélérer",),
    "redécélérerai": ("redécélérer",),
    "redécélérerais": ("redécélérer",),
    "redécélérerait": ("redécélérer",),
    "redécéléreras": ("redécélérer",),
    "redécélérèrent": ("redécélérer",),
    "redécélérerez": ("redécélérer",),
    "redécéléreriez": ("redécélérer",),
    "redécélérerions": ("redécélérer",),
    "redécélérerons": ("redécélérer",),
    "redécéléreront": ("redécélérer",),
    "redécélérés": ("redécélérer",),
    "redécélères": ("redécélérer",),
    "redécélérez": ("redécélérer",),
    "redécélériez": ("redécélérer",),
    "redécélérions": ("redécélérer",),
    "redécélérons": ("redécélérer",),
    "redécelaient": ("redéceler",),
    "redécelai": ("redéceler",),
    "redécelais": ("redéceler",),
    "redécelait": ("redéceler",),
    "redécela": ("redéceler",),
    "redécelâmes": ("redéceler",),
    "redécelant": ("redéceler",),
    "redécelas": ("redéceler",),
    "redécelassent": ("redéceler",),
    "redécelasses": ("redéceler",),
    "redécelasse": ("redéceler",),
    "redécelassiez": ("redéceler",),
    "redécelassions": ("redéceler",),
    "redécelâtes": ("redéceler",),
    "redécelât": ("redéceler",),
    "redécelée": ("redéceler",),
    "redécelées": ("redéceler",),
    "redécelé": ("redéceler",),
    "redécèlent": ("redéceler",),
    "redécèle": ("redéceler",),
    "redécèlera": ("redéceler",),
    "redécèleraient": ("redéceler",),
    "redécèlerai": ("redéceler",),
    "redécèlerais": ("redéceler",),
    "redécèlerait": ("redéceler",),
    "redécèleras": ("redéceler",),
    "redécelèrent": ("redéceler",),
    "redécèlerez": ("redéceler",),
    "redécèleriez": ("redéceler",),
    "redécèlerions": ("redéceler",),
    "redécèlerons": ("redéceler",),
    "redécèleront": ("redéceler",),
    "redécelés": ("redéceler",),
    "redécèles": ("redéceler",),
    "redécelez": ("redéceler",),
    "redéceliez": ("redéceler",),
    "redécelions": ("redéceler",),
    "redécelons": ("redéceler",),
    "redéchargeaient": ("redécharger",),
    "redéchargeai": ("redécharger",),
    "redéchargeais": ("redécharger",),
    "redéchargeait": ("redécharger",),
    "redéchargea": ("redécharger",),
    "redéchargeâmes": ("redécharger",),
    "redéchargeant": ("redécharger",),
    "redéchargeas": ("redécharger",),
    "redéchargeassent": ("redécharger",),
    "redéchargeasses": ("redécharger",),
    "redéchargeasse": ("redécharger",),
    "redéchargeassiez": ("redécharger",),
    "redéchargeassions": ("redécharger",),
    "redéchargeâtes": ("redécharger",),
    "redéchargeât": ("redécharger",),
    "redéchargée": ("redécharger",),
    "redéchargées": ("redécharger",),
    "redéchargé": ("redécharger",),
    "redéchargent": ("redécharger",),
    "redéchargeons": ("redécharger",),
    "redécharge": ("redécharger",),
    "redéchargera": ("redécharger",),
    "redéchargeraient": ("redécharger",),
    "redéchargerai": ("redécharger",),
    "redéchargerais": ("redécharger",),
    "redéchargerait": ("redécharger",),
    "redéchargeras": ("redécharger",),
    "redéchargèrent": ("redécharger",),
    "redéchargerez": ("redécharger",),
    "redéchargeriez": ("redécharger",),
    "redéchargerions": ("redécharger",),
    "redéchargerons": ("redécharger",),
    "redéchargeront": ("redécharger",),
    "redéchargés": ("redécharger",),
    "redécharges": ("redécharger",),
    "redéchargez": ("redécharger",),
    "redéchargiez": ("redécharger",),
    "redéchargions": ("redécharger",),
    "redéclassaient": ("redéclasser",),
    "redéclassai": ("redéclasser",),
    "redéclassais": ("redéclasser",),
    "redéclassait": ("redéclasser",),
    "redéclassa": ("redéclasser",),
    "redéclassâmes": ("redéclasser",),
    "redéclassant": ("redéclasser",),
    "redéclassas": ("redéclasser",),
    "redéclassassent": ("redéclasser",),
    "redéclassasses": ("redéclasser",),
    "redéclassasse": ("redéclasser",),
    "redéclassassiez": ("redéclasser",),
    "redéclassassions": ("redéclasser",),
    "redéclassâtes": ("redéclasser",),
    "redéclassât": ("redéclasser",),
    "redéclassée": ("redéclasser",),
    "redéclassées": ("redéclasser",),
    "redéclassé": ("redéclasser",),
    "redéclassent": ("redéclasser",),
    "redéclasse": ("redéclasser",),
    "redéclassera": ("redéclasser",),
    "redéclasseraient": ("redéclasser",),
    "redéclasserai": ("redéclasser",),
    "redéclasserais": ("redéclasser",),
    "redéclasserait": ("redéclasser",),
    "redéclasseras": ("redéclasser",),
    "redéclassèrent": ("redéclasser",),
    "redéclasserez": ("redéclasser",),
    "redéclasseriez": ("redéclasser",),
    "redéclasserions": ("redéclasser",),
    "redéclasserons": ("redéclasser",),
    "redéclasseront": ("redéclasser",),
    "redéclassés": ("redéclasser",),
    "redéclasses": ("redéclasser",),
    "redéclassez": ("redéclasser",),
    "redéclassiez": ("redéclasser",),
    "redéclassions": ("redéclasser",),
    "redéclassons": ("redéclasser",),
    "redéconsidéraient": ("redéconsidérer",),
    "redéconsidérai": ("redéconsidérer",),
    "redéconsidérais": ("redéconsidérer",),
    "redéconsidérait": ("redéconsidérer",),
    "redéconsidéra": ("redéconsidérer",),
    "redéconsidérâmes": ("redéconsidérer",),
    "redéconsidérant": ("redéconsidérer",),
    "redéconsidéras": ("redéconsidérer",),
    "redéconsidérassent": ("redéconsidérer",),
    "redéconsidérasses": ("redéconsidérer",),
    "redéconsidérasse": ("redéconsidérer",),
    "redéconsidérassiez": ("redéconsidérer",),
    "redéconsidérassions": ("redéconsidérer",),
    "redéconsidérâtes": ("redéconsidérer",),
    "redéconsidérât": ("redéconsidérer",),
    "redéconsidérée": ("redéconsidérer",),
    "redéconsidérées": ("redéconsidérer",),
    "redéconsidéré": ("redéconsidérer",),
    "redéconsidèrent": ("redéconsidérer",),
    "redéconsidère": ("redéconsidérer",),
    "redéconsidérera": ("redéconsidérer",),
    "redéconsidéreraient": ("redéconsidérer",),
    "redéconsidérerai": ("redéconsidérer",),
    "redéconsidérerais": ("redéconsidérer",),
    "redéconsidérerait": ("redéconsidérer",),
    "redéconsidéreras": ("redéconsidérer",),
    "redéconsidérèrent": ("redéconsidérer",),
    "redéconsidérerez": ("redéconsidérer",),
    "redéconsidéreriez": ("redéconsidérer",),
    "redéconsidérerions": ("redéconsidérer",),
    "redéconsidérerons": ("redéconsidérer",),
    "redéconsidéreront": ("redéconsidérer",),
    "redéconsidérés": ("redéconsidérer",),
    "redéconsidères": ("redéconsidérer",),
    "redéconsidérez": ("redéconsidérer",),
    "redéconsidériez": ("redéconsidérer",),
    "redéconsidérions": ("redéconsidérer",),
    "redéconsidérons": ("redéconsidérer",),
    "redécontenançaient": ("redécontenancer",),
    "redécontenançai": ("redécontenancer",),
    "redécontenançais": ("redécontenancer",),
    "redécontenançait": ("redécontenancer",),
    "redécontenança": ("redécontenancer",),
    "redécontenançâmes": ("redécontenancer",),
    "redécontenançant": ("redécontenancer",),
    "redécontenanças": ("redécontenancer",),
    "redécontenançassent": ("redécontenancer",),
    "redécontenançasses": ("redécontenancer",),
    "redécontenançasse": ("redécontenancer",),
    "redécontenançassiez": ("redécontenancer",),
    "redécontenançassions": ("redécontenancer",),
    "redécontenançâtes": ("redécontenancer",),
    "redécontenançât": ("redécontenancer",),
    "redécontenancée": ("redécontenancer",),
    "redécontenancées": ("redécontenancer",),
    "redécontenancé": ("redécontenancer",),
    "redécontenancent": ("redécontenancer",),
    "redécontenance": ("redécontenancer",),
    "redécontenancera": ("redécontenancer",),
    "redécontenanceraient": ("redécontenancer",),
    "redécontenancerai": ("redécontenancer",),
    "redécontenancerais": ("redécontenancer",),
    "redécontenancerait": ("redécontenancer",),
    "redécontenanceras": ("redécontenancer",),
    "redécontenancèrent": ("redécontenancer",),
    "redécontenancerez": ("redécontenancer",),
    "redécontenanceriez": ("redécontenancer",),
    "redécontenancerions": ("redécontenancer",),
    "redécontenancerons": ("redécontenancer",),
    "redécontenanceront": ("redécontenancer",),
    "redécontenancés": ("redécontenancer",),
    "redécontenances": ("redécontenancer",),
    "redécontenancez": ("redécontenancer",),
    "redécontenanciez": ("redécontenancer",),
    "redécontenancions": ("redécontenancer",),
    "redécontenançons": ("redécontenancer",),
    "redécoud": ("redécoudre",),
    "redécoudra": ("redécoudre",),
    "redécoudraient": ("redécoudre",),
    "redécoudrai": ("redécoudre",),
    "redécoudrais": ("redécoudre",),
    "redécoudrait": ("redécoudre",),
    "redécoudras": ("redécoudre",),
    "redécoudrez": ("redécoudre",),
    "redécoudriez": ("redécoudre",),
    "redécoudrions": ("redécoudre",),
    "redécoudrons": ("redécoudre",),
    "redécoudront": ("redécoudre",),
    "redécouds": ("redécoudre",),
    "redécousaient": ("redécoudre",),
    "redécousais": ("redécoudre",),
    "redécousait": ("redécoudre",),
    "redécousant": ("redécoudre",),
    "redécousent": ("redécoudre",),
    "redécouse": ("redécoudre",),
    "redécouses": ("redécoudre",),
    "redécousez": ("redécoudre",),
    "redécousiez": ("redécoudre",),
    "redécousîmes": ("redécoudre",),
    "redécousions": ("redécoudre",),
    "redécousirent": ("redécoudre",),
    "redécousis": ("redécoudre",),
    "redécousissent": ("redécoudre",),
    "redécousisses": ("redécoudre",),
    "redécousisse": ("redécoudre",),
    "redécousissiez": ("redécoudre",),
    "redécousissions": ("redécoudre",),
    "redécousîtes": ("redécoudre",),
    "redécousit": ("redécoudre",),
    "redécousît": ("redécoudre",),
    "redécousons": ("redécoudre",),
    "redécousue": ("redécoudre",),
    "redécousues": ("redécoudre",),
    "redécousu": ("redécoudre",),
    "redécousus": ("redécoudre",),
    "redécouverte": ("redécouvrir",),
    "redécouvertes": ("redécouvrir",),
    "redécouvert": ("redécouvrir",),
    "redécouverts": ("redécouvrir",),
    "redécouvraient": ("redécouvrir",),
    "redécouvrais": ("redécouvrir",),
    "redécouvrait": ("redécouvrir",),
    "redécouvrant": ("redécouvrir",),
    "redécouvrent": ("redécouvrir",),
    "redécouvre": ("redécouvrir",),
    "redécouvres": ("redécouvrir",),
    "redécouvrez": ("redécouvrir",),
    "redécouvriez": ("redécouvrir",),
    "redécouvrîmes": ("redécouvrir",),
    "redécouvrions": ("redécouvrir",),
    "redécouvrira": ("redécouvrir",),
    "redécouvriraient": ("redécouvrir",),
    "redécouvrirai": ("redécouvrir",),
    "redécouvrirais": ("redécouvrir",),
    "redécouvrirait": ("redécouvrir",),
    "redécouvriras": ("redécouvrir",),
    "redécouvrirent": ("redécouvrir",),
    "redécouvrirez": ("redécouvrir",),
    "redécouvririez": ("redécouvrir",),
    "redécouvririons": ("redécouvrir",),
    "redécouvrirons": ("redécouvrir",),
    "redécouvriront": ("redécouvrir",),
    "redécouvris": ("redécouvrir",),
    "redécouvrissent": ("redécouvrir",),
    "redécouvrisses": ("redécouvrir",),
    "redécouvrisse": ("redécouvrir",),
    "redécouvrissiez": ("redécouvrir",),
    "redécouvrissions": ("redécouvrir",),
    "redécouvrîtes": ("redécouvrir",),
    "redécouvrit": ("redécouvrir",),
    "redécouvrît": ("redécouvrir",),
    "redécouvrons": ("redécouvrir",),
    "redécrétaient": ("redécréter",),
    "redécrétai": ("redécréter",),
    "redécrétais": ("redécréter",),
    "redécrétait": ("redécréter",),
    "redécréta": ("redécréter",),
    "redécrétâmes": ("redécréter",),
    "redécrétant": ("redécréter",),
    "redécrétas": ("redécréter",),
    "redécrétassent": ("redécréter",),
    "redécrétasses": ("redécréter",),
    "redécrétasse": ("redécréter",),
    "redécrétassiez": ("redécréter",),
    "redécrétassions": ("redécréter",),
    "redécrétâtes": ("redécréter",),
    "redécrétât": ("redécréter",),
    "redécrétée": ("redécréter",),
    "redécrétées": ("redécréter",),
    "redécrété": ("redécréter",),
    "redécrètent": ("redécréter",),
    "redécrète": ("redécréter",),
    "redécrétera": ("redécréter",),
    "redécréteraient": ("redécréter",),
    "redécréterai": ("redécréter",),
    "redécréterais": ("redécréter",),
    "redécréterait": ("redécréter",),
    "redécréteras": ("redécréter",),
    "redécrétèrent": ("redécréter",),
    "redécréterez": ("redécréter",),
    "redécréteriez": ("redécréter",),
    "redécréterions": ("redécréter",),
    "redécréterons": ("redécréter",),
    "redécréteront": ("redécréter",),
    "redécrétés": ("redécréter",),
    "redécrètes": ("redécréter",),
    "redécrétez": ("redécréter",),
    "redécrétiez": ("redécréter",),
    "redécrétions": ("redécréter",),
    "redécrétons": ("redécréter",),
    "redécrira": ("redécrire",),
    "redécriraient": ("redécrire",),
    "redécrirai": ("redécrire",),
    "redécrirais": ("redécrire",),
    "redécrirait": ("redécrire",),
    "redécriras": ("redécrire",),
    "redécrirez": ("redécrire",),
    "redécririez": ("redécrire",),
    "redécririons": ("redécrire",),
    "redécrirons": ("redécrire",),
    "redécriront": ("redécrire",),
    "redécris": ("redécrire",),
    "redécrite": ("redécrire",),
    "redécrites": ("redécrire",),
    "redécrit": ("redécrire",),
    "redécrits": ("redécrire",),
    "redécrivaient": ("redécrire",),
    "redécrivais": ("redécrire",),
    "redécrivait": ("redécrire",),
    "redécrivant": ("redécrire",),
    "redécrivent": ("redécrire",),
    "redécrive": ("redécrire",),
    "redécrives": ("redécrire",),
    "redécrivez": ("redécrire",),
    "redécriviez": ("redécrire",),
    "redécrivîmes": ("redécrire",),
    "redécrivions": ("redécrire",),
    "redécrivirent": ("redécrire",),
    "redécrivis": ("redécrire",),
    "redécrivissent": ("redécrire",),
    "redécrivisses": ("redécrire",),
    "redécrivisse": ("redécrire",),
    "redécrivissiez": ("redécrire",),
    "redécrivissions": ("redécrire",),
    "redécrivîtes": ("redécrire",),
    "redécrivit": ("redécrire",),
    "redécrivît": ("redécrire",),
    "redécrivons": ("redécrire",),
    "redécrois": ("redécroître",),
    "redécroissaient": ("redécroître",),
    "redécroissais": ("redécroître",),
    "redécroissait": ("redécroître",),
    "redécroissant": ("redécroître",),
    "redécroissent": ("redécroître",),
    "redécroisse": ("redécroître",),
    "redécroisses": ("redécroître",),
    "redécroissez": ("redécroître",),
    "redécroissiez": ("redécroître",),
    "redécroissions": ("redécroître",),
    "redécroissons": ("redécroître",),
    "redécroît": ("redécroître",),
    "redécroîtra": ("redécroître",),
    "redécroîtraient": ("redécroître",),
    "redécroîtrai": ("redécroître",),
    "redécroîtrais": ("redécroître",),
    "redécroîtrait": ("redécroître",),
    "redécroîtras": ("redécroître",),
    "redécroîtrez": ("redécroître",),
    "redécroîtriez": ("redécroître",),
    "redécroîtrions": ("redécroître",),
    "redécroîtrons": ("redécroître",),
    "redécroîtront": ("redécroître",),
    "redécrue": ("redécroître",),
    "redécrues": ("redécroître",),
    "redécru": ("redécroître",),
    "redécrûmes": ("redécroître",),
    "redécrurent": ("redécroître",),
    "redécrus": ("redécroître",),
    "redécrussent": ("redécroître",),
    "redécrusses": ("redécroître",),
    "redécrusse": ("redécroître",),
    "redécrussiez": ("redécroître",),
    "redécrussions": ("redécroître",),
    "redécrûtes": ("redécroître",),
    "redécrut": ("redécroître",),
    "redécrût": ("redécroître",),
    "redédicaçaient": ("redédicacer",),
    "redédicaçai": ("redédicacer",),
    "redédicaçais": ("redédicacer",),
    "redédicaçait": ("redédicacer",),
    "redédicaça": ("redédicacer",),
    "redédicaçâmes": ("redédicacer",),
    "redédicaçant": ("redédicacer",),
    "redédicaças": ("redédicacer",),
    "redédicaçassent": ("redédicacer",),
    "redédicaçasses": ("redédicacer",),
    "redédicaçasse": ("redédicacer",),
    "redédicaçassiez": ("redédicacer",),
    "redédicaçassions": ("redédicacer",),
    "redédicaçâtes": ("redédicacer",),
    "redédicaçât": ("redédicacer",),
    "redédicacée": ("redédicacer",),
    "redédicacées": ("redédicacer",),
    "redédicacé": ("redédicacer",),
    "redédicacent": ("redédicacer",),
    "redédicace": ("redédicacer",),
    "redédicacera": ("redédicacer",),
    "redédicaceraient": ("redédicacer",),
    "redédicacerai": ("redédicacer",),
    "redédicacerais": ("redédicacer",),
    "redédicacerait": ("redédicacer",),
    "redédicaceras": ("redédicacer",),
    "redédicacèrent": ("redédicacer",),
    "redédicacerez": ("redédicacer",),
    "redédicaceriez": ("redédicacer",),
    "redédicacerions": ("redédicacer",),
    "redédicacerons": ("redédicacer",),
    "redédicaceront": ("redédicacer",),
    "redédicacés": ("redédicacer",),
    "redédicaces": ("redédicacer",),
    "redédicacez": ("redédicacer",),
    "redédicaciez": ("redédicacer",),
    "redédicacions": ("redédicacer",),
    "redédicaçons": ("redédicacer",),
    "redédiaient": ("redédier",),
    "redédiai": ("redédier",),
    "redédiais": ("redédier",),
    "redédiait": ("redédier",),
    "redédia": ("redédier",),
    "redédiâmes": ("redédier",),
    "redédiant": ("redédier",),
    "redédias": ("redédier",),
    "redédiassent": ("redédier",),
    "redédiasses": ("redédier",),
    "redédiasse": ("redédier",),
    "redédiassiez": ("redédier",),
    "redédiassions": ("redédier",),
    "redédiâtes": ("redédier",),
    "redédiât": ("redédier",),
    "redédiée": ("redédier",),
    "redédiées": ("redédier",),
    "redédié": ("redédier",),
    "redédient": ("redédier",),
    "redédie": ("redédier",),
    "redédiera": ("redédier",),
    "redédieraient": ("redédier",),
    "redédierai": ("redédier",),
    "redédierais": ("redédier",),
    "redédierait": ("redédier",),
    "redédieras": ("redédier",),
    "redédièrent": ("redédier",),
    "redédierez": ("redédier",),
    "redédieriez": ("redédier",),
    "redédierions": ("redédier",),
    "redédierons": ("redédier",),
    "redédieront": ("redédier",),
    "redédiés": ("redédier",),
    "redédies": ("redédier",),
    "redédiez": ("redédier",),
    "redédiiez": ("redédier",),
    "redédiions": ("redédier",),
    "redédions": ("redédier",),
    "redéduira": ("redéduire",),
    "redéduiraient": ("redéduire",),
    "redéduirai": ("redéduire",),
    "redéduirais": ("redéduire",),
    "redéduirait": ("redéduire",),
    "redéduiras": ("redéduire",),
    "redéduirez": ("redéduire",),
    "redéduiriez": ("redéduire",),
    "redéduirions": ("redéduire",),
    "redéduirons": ("redéduire",),
    "redéduiront": ("redéduire",),
    "redéduisaient": ("redéduire",),
    "redéduisais": ("redéduire",),
    "redéduisait": ("redéduire",),
    "redéduisant": ("redéduire",),
    "redéduisent": ("redéduire",),
    "redéduise": ("redéduire",),
    "redéduises": ("redéduire",),
    "redéduisez": ("redéduire",),
    "redéduisiez": ("redéduire",),
    "redéduisîmes": ("redéduire",),
    "redéduisions": ("redéduire",),
    "redéduisirent": ("redéduire",),
    "redéduisis": ("redéduire",),
    "redéduisissent": ("redéduire",),
    "redéduisisses": ("redéduire",),
    "redéduisisse": ("redéduire",),
    "redéduisissiez": ("redéduire",),
    "redéduisissions": ("redéduire",),
    "redéduisîtes": ("redéduire",),
    "redéduisit": ("redéduire",),
    "redéduisît": ("redéduire",),
    "redéduisons": ("redéduire",),
    "redéduis": ("redéduire",),
    "redéduite": ("redéduire",),
    "redéduites": ("redéduire",),
    "redéduit": ("redéduire",),
    "redéduits": ("redéduire",),
    "redéfaisaient": ("redéfaire",),
    "redéfaisais": ("redéfaire",),
    "redéfaisait": ("redéfaire",),
    "redéfaisant": ("redéfaire",),
    "redéfaisiez": ("redéfaire",),
    "redéfaisions": ("redéfaire",),
    "redéfaisons": ("redéfaire",),
    "redéfais": ("redéfaire",),
    "redéfaite": ("redéfaire",),
    "redéfaites": ("redéfaire",),
    "redéfait": ("redéfaire",),
    "redéfaits": ("redéfaire",),
    "redéfassent": ("redéfaire",),
    "redéfasse": ("redéfaire",),
    "redéfasses": ("redéfaire",),
    "redéfassiez": ("redéfaire",),
    "redéfassions": ("redéfaire",),
    "redéfera": ("redéfaire",),
    "redéferaient": ("redéfaire",),
    "redéferai": ("redéfaire",),
    "redéferais": ("redéfaire",),
    "redéferait": ("redéfaire",),
    "redéferas": ("redéfaire",),
    "redéferez": ("redéfaire",),
    "redéferiez": ("redéfaire",),
    "redéferions": ("redéfaire",),
    "redéferons": ("redéfaire",),
    "redéferont": ("redéfaire",),
    "redéfîmes": ("redéfaire",),
    "redéfirent": ("redéfaire",),
    "redéfis": ("redéfaire",),
    "redéfissent": ("redéfaire",),
    "redéfisses": ("redéfaire",),
    "redéfisse": ("redéfaire",),
    "redéfissiez": ("redéfaire",),
    "redéfissions": ("redéfaire",),
    "redéfîtes": ("redéfaire",),
    "redéfit": ("redéfaire",),
    "redéfît": ("redéfaire",),
    "redéfont": ("redéfaire",),
    "redéfendaient": ("redéfendre",),
    "redéfendais": ("redéfendre",),
    "redéfendait": ("redéfendre",),
    "redéfendant": ("redéfendre",),
    "redéfendent": ("redéfendre",),
    "redéfende": ("redéfendre",),
    "redéfendes": ("redéfendre",),
    "redéfendez": ("redéfendre",),
    "redéfendiez": ("redéfendre",),
    "redéfendîmes": ("redéfendre",),
    "redéfendions": ("redéfendre",),
    "redéfendirent": ("redéfendre",),
    "redéfendis": ("redéfendre",),
    "redéfendissent": ("redéfendre",),
    "redéfendisses": ("redéfendre",),
    "redéfendisse": ("redéfendre",),
    "redéfendissiez": ("redéfendre",),
    "redéfendissions": ("redéfendre",),
    "redéfendîtes": ("redéfendre",),
    "redéfendit": ("redéfendre",),
    "redéfendît": ("redéfendre",),
    "redéfendons": ("redéfendre",),
    "redéfend": ("redéfendre",),
    "redéfendra": ("redéfendre",),
    "redéfendraient": ("redéfendre",),
    "redéfendrai": ("redéfendre",),
    "redéfendrais": ("redéfendre",),
    "redéfendrait": ("redéfendre",),
    "redéfendras": ("redéfendre",),
    "redéfendrez": ("redéfendre",),
    "redéfendriez": ("redéfendre",),
    "redéfendrions": ("redéfendre",),
    "redéfendrons": ("redéfendre",),
    "redéfendront": ("redéfendre",),
    "redéfends": ("redéfendre",),
    "redéfendue": ("redéfendre",),
    "redéfendues": ("redéfendre",),
    "redéfendu": ("redéfendre",),
    "redéfendus": ("redéfendre",),
    "redéféraient": ("redéférer",),
    "redéférai": ("redéférer",),
    "redéférais": ("redéférer",),
    "redéférait": ("redéférer",),
    "redéféra": ("redéférer",),
    "redéférâmes": ("redéférer",),
    "redéférant": ("redéférer",),
    "redéféras": ("redéférer",),
    "redéférassent": ("redéférer",),
    "redéférasses": ("redéférer",),
    "redéférasse": ("redéférer",),
    "redéférassiez": ("redéférer",),
    "redéférassions": ("redéférer",),
    "redéférâtes": ("redéférer",),
    "redéférât": ("redéférer",),
    "redéférée": ("redéférer",),
    "redéférées": ("redéférer",),
    "redéféré": ("redéférer",),
    "redéfèrent": ("redéférer",),
    "redéfère": ("redéférer",),
    "redéférera": ("redéférer",),
    "redéféreraient": ("redéférer",),
    "redéférerai": ("redéférer",),
    "redéférerais": ("redéférer",),
    "redéférerait": ("redéférer",),
    "redéféreras": ("redéférer",),
    "redéférèrent": ("redéférer",),
    "redéférerez": ("redéférer",),
    "redéféreriez": ("redéférer",),
    "redéférerions": ("redéférer",),
    "redéférerons": ("redéférer",),
    "redéféreront": ("redéférer",),
    "redéférés": ("redéférer",),
    "redéfères": ("redéférer",),
    "redéférez": ("redéférer",),
    "redéfériez": ("redéférer",),
    "redéférions": ("redéférer",),
    "redéférons": ("redéférer",),
    "redéfiaient": ("redéfier",),
    "redéfiai": ("redéfier",),
    "redéfiais": ("redéfier",),
    "redéfiait": ("redéfier",),
    "redéfia": ("redéfier",),
    "redéfiâmes": ("redéfier",),
    "redéfiant": ("redéfier",),
    "redéfias": ("redéfier",),
    "redéfiassent": ("redéfier",),
    "redéfiasses": ("redéfier",),
    "redéfiasse": ("redéfier",),
    "redéfiassiez": ("redéfier",),
    "redéfiassions": ("redéfier",),
    "redéfiâtes": ("redéfier",),
    "redéfiât": ("redéfier",),
    "redéfiée": ("redéfier",),
    "redéfiées": ("redéfier",),
    "redéfié": ("redéfier",),
    "redéfient": ("redéfier",),
    "redéfie": ("redéfier",),
    "redéfiera": ("redéfier",),
    "redéfieraient": ("redéfier",),
    "redéfierai": ("redéfier",),
    "redéfierais": ("redéfier",),
    "redéfierait": ("redéfier",),
    "redéfieras": ("redéfier",),
    "redéfièrent": ("redéfier",),
    "redéfierez": ("redéfier",),
    "redéfieriez": ("redéfier",),
    "redéfierions": ("redéfier",),
    "redéfierons": ("redéfier",),
    "redéfieront": ("redéfier",),
    "redéfiés": ("redéfier",),
    "redéfies": ("redéfier",),
    "redéfiez": ("redéfier",),
    "redéfiiez": ("redéfier",),
    "redéfiions": ("redéfier",),
    "redéfions": ("redéfier",),
    "redéfinie": ("redéfinir",),
    "redéfinies": ("redéfinir",),
    "redéfini": ("redéfinir",),
    "redéfinîmes": ("redéfinir",),
    "redéfinira": ("redéfinir",),
    "redéfiniraient": ("redéfinir",),
    "redéfinirai": ("redéfinir",),
    "redéfinirais": ("redéfinir",),
    "redéfinirait": ("redéfinir",),
    "redéfiniras": ("redéfinir",),
    "redéfinirent": ("redéfinir",),
    "redéfinirez": ("redéfinir",),
    "redéfiniriez": ("redéfinir",),
    "redéfinirions": ("redéfinir",),
    "redéfinirons": ("redéfinir",),
    "redéfiniront": ("redéfinir",),
    "redéfinis": ("redéfinir",),
    "redéfinissaient": ("redéfinir",),
    "redéfinissais": ("redéfinir",),
    "redéfinissait": ("redéfinir",),
    "redéfinissant": ("redéfinir",),
    "redéfinissent": ("redéfinir",),
    "redéfinisse": ("redéfinir",),
    "redéfinisses": ("redéfinir",),
    "redéfinissez": ("redéfinir",),
    "redéfinissiez": ("redéfinir",),
    "redéfinissions": ("redéfinir",),
    "redéfinissons": ("redéfinir",),
    "redéfinîtes": ("redéfinir",),
    "redéfinit": ("redéfinir",),
    "redéfinît": ("redéfinir",),
    "redéfonçaient": ("redéfoncer",),
    "redéfonçai": ("redéfoncer",),
    "redéfonçais": ("redéfoncer",),
    "redéfonçait": ("redéfoncer",),
    "redéfonça": ("redéfoncer",),
    "redéfonçâmes": ("redéfoncer",),
    "redéfonçant": ("redéfoncer",),
    "redéfonças": ("redéfoncer",),
    "redéfonçassent": ("redéfoncer",),
    "redéfonçasses": ("redéfoncer",),
    "redéfonçasse": ("redéfoncer",),
    "redéfonçassiez": ("redéfoncer",),
    "redéfonçassions": ("redéfoncer",),
    "redéfonçâtes": ("redéfoncer",),
    "redéfonçât": ("redéfoncer",),
    "redéfoncée": ("redéfoncer",),
    "redéfoncées": ("redéfoncer",),
    "redéfoncé": ("redéfoncer",),
    "redéfoncent": ("redéfoncer",),
    "redéfonce": ("redéfoncer",),
    "redéfoncera": ("redéfoncer",),
    "redéfonceraient": ("redéfoncer",),
    "redéfoncerai": ("redéfoncer",),
    "redéfoncerais": ("redéfoncer",),
    "redéfoncerait": ("redéfoncer",),
    "redéfonceras": ("redéfoncer",),
    "redéfoncèrent": ("redéfoncer",),
    "redéfoncerez": ("redéfoncer",),
    "redéfonceriez": ("redéfoncer",),
    "redéfoncerions": ("redéfoncer",),
    "redéfoncerons": ("redéfoncer",),
    "redéfonceront": ("redéfoncer",),
    "redéfoncés": ("redéfoncer",),
    "redéfonces": ("redéfoncer",),
    "redéfoncez": ("redéfoncer",),
    "redéfonciez": ("redéfoncer",),
    "redéfoncions": ("redéfoncer",),
    "redéfonçons": ("redéfoncer",),
    "redégageaient": ("redégager",),
    "redégageai": ("redégager",),
    "redégageais": ("redégager",),
    "redégageait": ("redégager",),
    "redégagea": ("redégager",),
    "redégageâmes": ("redégager",),
    "redégageant": ("redégager",),
    "redégageas": ("redégager",),
    "redégageassent": ("redégager",),
    "redégageasses": ("redégager",),
    "redégageasse": ("redégager",),
    "redégageassiez": ("redégager",),
    "redégageassions": ("redégager",),
    "redégageâtes": ("redégager",),
    "redégageât": ("redégager",),
    "redégagée": ("redégager",),
    "redégagées": ("redégager",),
    "redégagé": ("redégager",),
    "redégagent": ("redégager",),
    "redégageons": ("redégager",),
    "redégage": ("redégager",),
    "redégagera": ("redégager",),
    "redégageraient": ("redégager",),
    "redégagerai": ("redégager",),
    "redégagerais": ("redégager",),
    "redégagerait": ("redégager",),
    "redégageras": ("redégager",),
    "redégagèrent": ("redégager",),
    "redégagerez": ("redégager",),
    "redégageriez": ("redégager",),
    "redégagerions": ("redégager",),
    "redégagerons": ("redégager",),
    "redégageront": ("redégager",),
    "redégagés": ("redégager",),
    "redégages": ("redégager",),
    "redégagez": ("redégager",),
    "redégagiez": ("redégager",),
    "redégagions": ("redégager",),
    "redégarnie": ("redégarnir",),
    "redégarnies": ("redégarnir",),
    "redégarni": ("redégarnir",),
    "redégarnîmes": ("redégarnir",),
    "redégarnira": ("redégarnir",),
    "redégarniraient": ("redégarnir",),
    "redégarnirai": ("redégarnir",),
    "redégarnirais": ("redégarnir",),
    "redégarnirait": ("redégarnir",),
    "redégarniras": ("redégarnir",),
    "redégarnirent": ("redégarnir",),
    "redégarnirez": ("redégarnir",),
    "redégarniriez": ("redégarnir",),
    "redégarnirions": ("redégarnir",),
    "redégarnirons": ("redégarnir",),
    "redégarniront": ("redégarnir",),
    "redégarnis": ("redégarnir",),
    "redégarnissaient": ("redégarnir",),
    "redégarnissais": ("redégarnir",),
    "redégarnissait": ("redégarnir",),
    "redégarnissant": ("redégarnir",),
    "redégarnissent": ("redégarnir",),
    "redégarnisse": ("redégarnir",),
    "redégarnisses": ("redégarnir",),
    "redégarnissez": ("redégarnir",),
    "redégarnissiez": ("redégarnir",),
    "redégarnissions": ("redégarnir",),
    "redégarnissons": ("redégarnir",),
    "redégarnîtes": ("redégarnir",),
    "redégarnit": ("redégarnir",),
    "redégarnît": ("redégarnir",),
    "redégelaient": ("redégeler",),
    "redégelai": ("redégeler",),
    "redégelais": ("redégeler",),
    "redégelait": ("redégeler",),
    "redégela": ("redégeler",),
    "redégelâmes": ("redégeler",),
    "redégelant": ("redégeler",),
    "redégelas": ("redégeler",),
    "redégelassent": ("redégeler",),
    "redégelasses": ("redégeler",),
    "redégelasse": ("redégeler",),
    "redégelassiez": ("redégeler",),
    "redégelassions": ("redégeler",),
    "redégelâtes": ("redégeler",),
    "redégelât": ("redégeler",),
    "redégelée": ("redégeler",),
    "redégelées": ("redégeler",),
    "redégelé": ("redégeler",),
    "redégèlent": ("redégeler",),
    "redégèle": ("redégeler",),
    "redégèlera": ("redégeler",),
    "redégèleraient": ("redégeler",),
    "redégèlerai": ("redégeler",),
    "redégèlerais": ("redégeler",),
    "redégèlerait": ("redégeler",),
    "redégèleras": ("redégeler",),
    "redégelèrent": ("redégeler",),
    "redégèlerez": ("redégeler",),
    "redégèleriez": ("redégeler",),
    "redégèlerions": ("redégeler",),
    "redégèlerons": ("redégeler",),
    "redégèleront": ("redégeler",),
    "redégelés": ("redégeler",),
    "redégèles": ("redégeler",),
    "redégelez": ("redégeler",),
    "redégeliez": ("redégeler",),
    "redégelions": ("redégeler",),
    "redégelons": ("redégeler",),
    "redéléguaient": ("redéléguer",),
    "redéléguai": ("redéléguer",),
    "redéléguais": ("redéléguer",),
    "redéléguait": ("redéléguer",),
    "redélégua": ("redéléguer",),
    "redéléguâmes": ("redéléguer",),
    "redéléguant": ("redéléguer",),
    "redéléguas": ("redéléguer",),
    "redéléguassent": ("redéléguer",),
    "redéléguasses": ("redéléguer",),
    "redéléguasse": ("redéléguer",),
    "redéléguassiez": ("redéléguer",),
    "redéléguassions": ("redéléguer",),
    "redéléguâtes": ("redéléguer",),
    "redéléguât": ("redéléguer",),
    "redéléguée": ("redéléguer",),
    "redéléguées": ("redéléguer",),
    "redélégué": ("redéléguer",),
    "redélèguent": ("redéléguer",),
    "redélègue": ("redéléguer",),
    "redéléguera": ("redéléguer",),
    "redélégueraient": ("redéléguer",),
    "redéléguerai": ("redéléguer",),
    "redéléguerais": ("redéléguer",),
    "redéléguerait": ("redéléguer",),
    "redélégueras": ("redéléguer",),
    "redéléguèrent": ("redéléguer",),
    "redéléguerez": ("redéléguer",),
    "redélégueriez": ("redéléguer",),
    "redéléguerions": ("redéléguer",),
    "redéléguerons": ("redéléguer",),
    "redélégueront": ("redéléguer",),
    "redélégués": ("redéléguer",),
    "redélègues": ("redéléguer",),
    "redéléguez": ("redéléguer",),
    "redéléguiez": ("redéléguer",),
    "redéléguions": ("redéléguer",),
    "redéléguons": ("redéléguer",),
    "redélibéraient": ("redélibérer",),
    "redélibérai": ("redélibérer",),
    "redélibérais": ("redélibérer",),
    "redélibérait": ("redélibérer",),
    "redélibéra": ("redélibérer",),
    "redélibérâmes": ("redélibérer",),
    "redélibérant": ("redélibérer",),
    "redélibéras": ("redélibérer",),
    "redélibérassent": ("redélibérer",),
    "redélibérasses": ("redélibérer",),
    "redélibérasse": ("redélibérer",),
    "redélibérassiez": ("redélibérer",),
    "redélibérassions": ("redélibérer",),
    "redélibérâtes": ("redélibérer",),
    "redélibérât": ("redélibérer",),
    "redélibéré": ("redélibérer",),
    "redélibèrent": ("redélibérer",),
    "redélibère": ("redélibérer",),
    "redélibérera": ("redélibérer",),
    "redélibéreraient": ("redélibérer",),
    "redélibérerai": ("redélibérer",),
    "redélibérerais": ("redélibérer",),
    "redélibérerait": ("redélibérer",),
    "redélibéreras": ("redélibérer",),
    "redélibérèrent": ("redélibérer",),
    "redélibérerez": ("redélibérer",),
    "redélibéreriez": ("redélibérer",),
    "redélibérerions": ("redélibérer",),
    "redélibérerons": ("redélibérer",),
    "redélibéreront": ("redélibérer",),
    "redélibères": ("redélibérer",),
    "redélibérez": ("redélibérer",),
    "redélibériez": ("redélibérer",),
    "redélibérions": ("redélibérer",),
    "redélibérons": ("redélibérer",),
    "redélogeaient": ("redéloger",),
    "redélogeai": ("redéloger",),
    "redélogeais": ("redéloger",),
    "redélogeait": ("redéloger",),
    "redélogea": ("redéloger",),
    "redélogeâmes": ("redéloger",),
    "redélogeant": ("redéloger",),
    "redélogeas": ("redéloger",),
    "redélogeassent": ("redéloger",),
    "redélogeasses": ("redéloger",),
    "redélogeasse": ("redéloger",),
    "redélogeassiez": ("redéloger",),
    "redélogeassions": ("redéloger",),
    "redélogeâtes": ("redéloger",),
    "redélogeât": ("redéloger",),
    "redélogée": ("redéloger",),
    "redélogées": ("redéloger",),
    "redélogé": ("redéloger",),
    "redélogent": ("redéloger",),
    "redélogeons": ("redéloger",),
    "redéloge": ("redéloger",),
    "redélogera": ("redéloger",),
    "redélogeraient": ("redéloger",),
    "redélogerai": ("redéloger",),
    "redélogerais": ("redéloger",),
    "redélogerait": ("redéloger",),
    "redélogeras": ("redéloger",),
    "redélogèrent": ("redéloger",),
    "redélogerez": ("redéloger",),
    "redélogeriez": ("redéloger",),
    "redélogerions": ("redéloger",),
    "redélogerons": ("redéloger",),
    "redélogeront": ("redéloger",),
    "redélogés": ("redéloger",),
    "redéloges": ("redéloger",),
    "redélogez": ("redéloger",),
    "redélogiez": ("redéloger",),
    "redélogions": ("redéloger",),
    "redémangeaient": ("redémanger",),
    "redémangeai": ("redémanger",),
    "redémangeais": ("redémanger",),
    "redémangeait": ("redémanger",),
    "redémangea": ("redémanger",),
    "redémangeâmes": ("redémanger",),
    "redémangeant": ("redémanger",),
    "redémangeas": ("redémanger",),
    "redémangeassent": ("redémanger",),
    "redémangeasses": ("redémanger",),
    "redémangeasse": ("redémanger",),
    "redémangeassiez": ("redémanger",),
    "redémangeassions": ("redémanger",),
    "redémangeâtes": ("redémanger",),
    "redémangeât": ("redémanger",),
    "redémangée": ("redémanger",),
    "redémangées": ("redémanger",),
    "redémangé": ("redémanger",),
    "redémangent": ("redémanger",),
    "redémangeons": ("redémanger",),
    "redémange": ("redémanger",),
    "redémangera": ("redémanger",),
    "redémangeraient": ("redémanger",),
    "redémangerai": ("redémanger",),
    "redémangerais": ("redémanger",),
    "redémangerait": ("redémanger",),
    "redémangeras": ("redémanger",),
    "redémangèrent": ("redémanger",),
    "redémangerez": ("redémanger",),
    "redémangeriez": ("redémanger",),
    "redémangerions": ("redémanger",),
    "redémangerons": ("redémanger",),
    "redémangeront": ("redémanger",),
    "redémangés": ("redémanger",),
    "redémanges": ("redémanger",),
    "redémangez": ("redémanger",),
    "redémangiez": ("redémanger",),
    "redémangions": ("redémanger",),
    "redéménageaient": ("redéménager",),
    "redéménageai": ("redéménager",),
    "redéménageais": ("redéménager",),
    "redéménageait": ("redéménager",),
    "redéménagea": ("redéménager",),
    "redéménageâmes": ("redéménager",),
    "redéménageant": ("redéménager",),
    "redéménageas": ("redéménager",),
    "redéménageassent": ("redéménager",),
    "redéménageasses": ("redéménager",),
    "redéménageasse": ("redéménager",),
    "redéménageassiez": ("redéménager",),
    "redéménageassions": ("redéménager",),
    "redéménageâtes": ("redéménager",),
    "redéménageât": ("redéménager",),
    "redéménagée": ("redéménager",),
    "redéménagées": ("redéménager",),
    "redéménagé": ("redéménager",),
    "redéménagent": ("redéménager",),
    "redéménageons": ("redéménager",),
    "redéménage": ("redéménager",),
    "redéménagera": ("redéménager",),
    "redéménageraient": ("redéménager",),
    "redéménagerai": ("redéménager",),
    "redéménagerais": ("redéménager",),
    "redéménagerait": ("redéménager",),
    "redéménageras": ("redéménager",),
    "redéménagèrent": ("redéménager",),
    "redéménagerez": ("redéménager",),
    "redéménageriez": ("redéménager",),
    "redéménagerions": ("redéménager",),
    "redéménagerons": ("redéménager",),
    "redéménageront": ("redéménager",),
    "redéménagés": ("redéménager",),
    "redéménages": ("redéménager",),
    "redéménagez": ("redéménager",),
    "redéménagiez": ("redéménager",),
    "redéménagions": ("redéménager",),
    "redémolie": ("redémolir",),
    "redémolies": ("redémolir",),
    "redémoli": ("redémolir",),
    "redémolîmes": ("redémolir",),
    "redémolira": ("redémolir",),
    "redémoliraient": ("redémolir",),
    "redémolirai": ("redémolir",),
    "redémolirais": ("redémolir",),
    "redémolirait": ("redémolir",),
    "redémoliras": ("redémolir",),
    "redémolirent": ("redémolir",),
    "redémolirez": ("redémolir",),
    "redémoliriez": ("redémolir",),
    "redémolirions": ("redémolir",),
    "redémolirons": ("redémolir",),
    "redémoliront": ("redémolir",),
    "redémolis": ("redémolir",),
    "redémolissaient": ("redémolir",),
    "redémolissais": ("redémolir",),
    "redémolissait": ("redémolir",),
    "redémolissant": ("redémolir",),
    "redémolissent": ("redémolir",),
    "redémolisse": ("redémolir",),
    "redémolisses": ("redémolir",),
    "redémolissez": ("redémolir",),
    "redémolissiez": ("redémolir",),
    "redémolissions": ("redémolir",),
    "redémolissons": ("redémolir",),
    "redémolîtes": ("redémolir",),
    "redémolit": ("redémolir",),
    "redémolît": ("redémolir",),
    "redénonçaient": ("redénoncer",),
    "redénonçai": ("redénoncer",),
    "redénonçais": ("redénoncer",),
    "redénonçait": ("redénoncer",),
    "redénonça": ("redénoncer",),
    "redénonçâmes": ("redénoncer",),
    "redénonçant": ("redénoncer",),
    "redénonças": ("redénoncer",),
    "redénonçassent": ("redénoncer",),
    "redénonçasses": ("redénoncer",),
    "redénonçasse": ("redénoncer",),
    "redénonçassiez": ("redénoncer",),
    "redénonçassions": ("redénoncer",),
    "redénonçâtes": ("redénoncer",),
    "redénonçât": ("redénoncer",),
    "redénoncée": ("redénoncer",),
    "redénoncées": ("redénoncer",),
    "redénoncé": ("redénoncer",),
    "redénoncent": ("redénoncer",),
    "redénonce": ("redénoncer",),
    "redénoncera": ("redénoncer",),
    "redénonceraient": ("redénoncer",),
    "redénoncerai": ("redénoncer",),
    "redénoncerais": ("redénoncer",),
    "redénoncerait": ("redénoncer",),
    "redénonceras": ("redénoncer",),
    "redénoncèrent": ("redénoncer",),
    "redénoncerez": ("redénoncer",),
    "redénonceriez": ("redénoncer",),
    "redénoncerions": ("redénoncer",),
    "redénoncerons": ("redénoncer",),
    "redénonceront": ("redénoncer",),
    "redénoncés": ("redénoncer",),
    "redénonces": ("redénoncer",),
    "redénoncez": ("redénoncer",),
    "redénonciez": ("redénoncer",),
    "redénoncions": ("redénoncer",),
    "redénonçons": ("redénoncer",),
    "redépaquetaient": ("redépaqueter",),
    "redépaquetai": ("redépaqueter",),
    "redépaquetais": ("redépaqueter",),
    "redépaquetait": ("redépaqueter",),
    "redépaqueta": ("redépaqueter",),
    "redépaquetâmes": ("redépaqueter",),
    "redépaquetant": ("redépaqueter",),
    "redépaquetas": ("redépaqueter",),
    "redépaquetassent": ("redépaqueter",),
    "redépaquetasses": ("redépaqueter",),
    "redépaquetasse": ("redépaqueter",),
    "redépaquetassiez": ("redépaqueter",),
    "redépaquetassions": ("redépaqueter",),
    "redépaquetâtes": ("redépaqueter",),
    "redépaquetât": ("redépaqueter",),
    "redépaquetée": ("redépaqueter",),
    "redépaquetées": ("redépaqueter",),
    "redépaqueté": ("redépaqueter",),
    "redépaquetèrent": ("redépaqueter",),
    "redépaquetés": ("redépaqueter",),
    "redépaquetez": ("redépaqueter",),
    "redépaquetiez": ("redépaqueter",),
    "redépaquetions": ("redépaqueter",),
    "redépaquetons": ("redépaqueter",),
    "redépaquettent": ("redépaqueter",),
    "redépaquette": ("redépaqueter",),
    "redépaquettera": ("redépaqueter",),
    "redépaquetteraient": ("redépaqueter",),
    "redépaquetterai": ("redépaqueter",),
    "redépaquetterais": ("redépaqueter",),
    "redépaquetterait": ("redépaqueter",),
    "redépaquetteras": ("redépaqueter",),
    "redépaquetterez": ("redépaqueter",),
    "redépaquetteriez": ("redépaqueter",),
    "redépaquetterions": ("redépaqueter",),
    "redépaquetterons": ("redépaqueter",),
    "redépaquetteront": ("redépaqueter",),
    "redépaquettes": ("redépaqueter",),
    "redépeignaient": ("redépeindre",),
    "redépeignais": ("redépeindre",),
    "redépeignait": ("redépeindre",),
    "redépeignant": ("redépeindre",),
    "redépeignent": ("redépeindre",),
    "redépeigne": ("redépeindre",),
    "redépeignes": ("redépeindre",),
    "redépeignez": ("redépeindre",),
    "redépeigniez": ("redépeindre",),
    "redépeignîmes": ("redépeindre",),
    "redépeignions": ("redépeindre",),
    "redépeignirent": ("redépeindre",),
    "redépeignis": ("redépeindre",),
    "redépeignissent": ("redépeindre",),
    "redépeignisses": ("redépeindre",),
    "redépeignisse": ("redépeindre",),
    "redépeignissiez": ("redépeindre",),
    "redépeignissions": ("redépeindre",),
    "redépeignîtes": ("redépeindre",),
    "redépeignit": ("redépeindre",),
    "redépeignît": ("redépeindre",),
    "redépeignons": ("redépeindre",),
    "redépeindra": ("redépeindre",),
    "redépeindraient": ("redépeindre",),
    "redépeindrai": ("redépeindre",),
    "redépeindrais": ("redépeindre",),
    "redépeindrait": ("redépeindre",),
    "redépeindras": ("redépeindre",),
    "redépeindrez": ("redépeindre",),
    "redépeindriez": ("redépeindre",),
    "redépeindrions": ("redépeindre",),
    "redépeindrons": ("redépeindre",),
    "redépeindront": ("redépeindre",),
    "redépeins": ("redépeindre",),
    "redépeinte": ("redépeindre",),
    "redépeintes": ("redépeindre",),
    "redépeint": ("redépeindre",),
    "redépeints": ("redépeindre",),
    "redépendaient": ("redépendre",),
    "redépendais": ("redépendre",),
    "redépendait": ("redépendre",),
    "redépendant": ("redépendre",),
    "redépendent": ("redépendre",),
    "redépende": ("redépendre",),
    "redépendes": ("redépendre",),
    "redépendez": ("redépendre",),
    "redépendiez": ("redépendre",),
    "redépendîmes": ("redépendre",),
    "redépendions": ("redépendre",),
    "redépendirent": ("redépendre",),
    "redépendis": ("redépendre",),
    "redépendissent": ("redépendre",),
    "redépendisses": ("redépendre",),
    "redépendisse": ("redépendre",),
    "redépendissiez": ("redépendre",),
    "redépendissions": ("redépendre",),
    "redépendîtes": ("redépendre",),
    "redépendit": ("redépendre",),
    "redépendît": ("redépendre",),
    "redépendons": ("redépendre",),
    "redépend": ("redépendre",),
    "redépendra": ("redépendre",),
    "redépendraient": ("redépendre",),
    "redépendrai": ("redépendre",),
    "redépendrais": ("redépendre",),
    "redépendrait": ("redépendre",),
    "redépendras": ("redépendre",),
    "redépendrez": ("redépendre",),
    "redépendriez": ("redépendre",),
    "redépendrions": ("redépendre",),
    "redépendrons": ("redépendre",),
    "redépendront": ("redépendre",),
    "redépends": ("redépendre",),
    "redépendue": ("redépendre",),
    "redépendues": ("redépendre",),
    "redépendu": ("redépendre",),
    "redépendus": ("redépendre",),
    "redéplaçaient": ("redéplacer",),
    "redéplaçai": ("redéplacer",),
    "redéplaçais": ("redéplacer",),
    "redéplaçait": ("redéplacer",),
    "redéplaça": ("redéplacer",),
    "redéplaçâmes": ("redéplacer",),
    "redéplaçant": ("redéplacer",),
    "redéplaças": ("redéplacer",),
    "redéplaçassent": ("redéplacer",),
    "redéplaçasses": ("redéplacer",),
    "redéplaçasse": ("redéplacer",),
    "redéplaçassiez": ("redéplacer",),
    "redéplaçassions": ("redéplacer",),
    "redéplaçâtes": ("redéplacer",),
    "redéplaçât": ("redéplacer",),
    "redéplacée": ("redéplacer",),
    "redéplacées": ("redéplacer",),
    "redéplacé": ("redéplacer",),
    "redéplacent": ("redéplacer",),
    "redéplace": ("redéplacer",),
    "redéplacera": ("redéplacer",),
    "redéplaceraient": ("redéplacer",),
    "redéplacerai": ("redéplacer",),
    "redéplacerais": ("redéplacer",),
    "redéplacerait": ("redéplacer",),
    "redéplaceras": ("redéplacer",),
    "redéplacèrent": ("redéplacer",),
    "redéplacerez": ("redéplacer",),
    "redéplaceriez": ("redéplacer",),
    "redéplacerions": ("redéplacer",),
    "redéplacerons": ("redéplacer",),
    "redéplaceront": ("redéplacer",),
    "redéplacés": ("redéplacer",),
    "redéplaces": ("redéplacer",),
    "redéplacez": ("redéplacer",),
    "redéplaciez": ("redéplacer",),
    "redéplacions": ("redéplacer",),
    "redéplaçons": ("redéplacer",),
    "redépliaient": ("redéplier",),
    "redépliai": ("redéplier",),
    "redépliais": ("redéplier",),
    "redépliait": ("redéplier",),
    "redéplia": ("redéplier",),
    "redépliâmes": ("redéplier",),
    "redépliant": ("redéplier",),
    "redéplias": ("redéplier",),
    "redépliassent": ("redéplier",),
    "redépliasses": ("redéplier",),
    "redépliasse": ("redéplier",),
    "redépliassiez": ("redéplier",),
    "redépliassions": ("redéplier",),
    "redépliâtes": ("redéplier",),
    "redépliât": ("redéplier",),
    "redépliée": ("redéplier",),
    "redépliées": ("redéplier",),
    "redéplié": ("redéplier",),
    "redéplient": ("redéplier",),
    "redéplie": ("redéplier",),
    "redépliera": ("redéplier",),
    "redéplieraient": ("redéplier",),
    "redéplierai": ("redéplier",),
    "redéplierais": ("redéplier",),
    "redéplierait": ("redéplier",),
    "redéplieras": ("redéplier",),
    "redéplièrent": ("redéplier",),
    "redéplierez": ("redéplier",),
    "redéplieriez": ("redéplier",),
    "redéplierions": ("redéplier",),
    "redéplierons": ("redéplier",),
    "redéplieront": ("redéplier",),
    "redépliés": ("redéplier",),
    "redéplies": ("redéplier",),
    "redépliez": ("redéplier",),
    "redépliiez": ("redéplier",),
    "redépliions": ("redéplier",),
    "redéplions": ("redéplier",),
    "redéploient": ("redéployer",),
    "redéploie": ("redéployer",),
    "redéploiera": ("redéployer",),
    "redéploieraient": ("redéployer",),
    "redéploierai": ("redéployer",),
    "redéploierais": ("redéployer",),
    "redéploierait": ("redéployer",),
    "redéploieras": ("redéployer",),
    "redéploierez": ("redéployer",),
    "redéploieriez": ("redéployer",),
    "redéploierions": ("redéployer",),
    "redéploierons": ("redéployer",),
    "redéploieront": ("redéployer",),
    "redéploies": ("redéployer",),
    "redéployaient": ("redéployer",),
    "redéployai": ("redéployer",),
    "redéployais": ("redéployer",),
    "redéployait": ("redéployer",),
    "redéploya": ("redéployer",),
    "redéployâmes": ("redéployer",),
    "redéployant": ("redéployer",),
    "redéployas": ("redéployer",),
    "redéployassent": ("redéployer",),
    "redéployasses": ("redéployer",),
    "redéployasse": ("redéployer",),
    "redéployassiez": ("redéployer",),
    "redéployassions": ("redéployer",),
    "redéployâtes": ("redéployer",),
    "redéployât": ("redéployer",),
    "redéployée": ("redéployer",),
    "redéployées": ("redéployer",),
    "redéployé": ("redéployer",),
    "redéployèrent": ("redéployer",),
    "redéployés": ("redéployer",),
    "redéployez": ("redéployer",),
    "redéployiez": ("redéployer",),
    "redéployions": ("redéployer",),
    "redéployons": ("redéployer",),
    "redépossédaient": ("redéposséder",),
    "redépossédai": ("redéposséder",),
    "redépossédais": ("redéposséder",),
    "redépossédait": ("redéposséder",),
    "redéposséda": ("redéposséder",),
    "redépossédâmes": ("redéposséder",),
    "redépossédant": ("redéposséder",),
    "redépossédas": ("redéposséder",),
    "redépossédassent": ("redéposséder",),
    "redépossédasses": ("redéposséder",),
    "redépossédasse": ("redéposséder",),
    "redépossédassiez": ("redéposséder",),
    "redépossédassions": ("redéposséder",),
    "redépossédâtes": ("redéposséder",),
    "redépossédât": ("redéposséder",),
    "redépossédée": ("redéposséder",),
    "redépossédées": ("redéposséder",),
    "redépossédé": ("redéposséder",),
    "redépossèdent": ("redéposséder",),
    "redépossède": ("redéposséder",),
    "redépossédera": ("redéposséder",),
    "redéposséderaient": ("redéposséder",),
    "redéposséderai": ("redéposséder",),
    "redéposséderais": ("redéposséder",),
    "redéposséderait": ("redéposséder",),
    "redéposséderas": ("redéposséder",),
    "redépossédèrent": ("redéposséder",),
    "redéposséderez": ("redéposséder",),
    "redéposséderiez": ("redéposséder",),
    "redéposséderions": ("redéposséder",),
    "redéposséderons": ("redéposséder",),
    "redéposséderont": ("redéposséder",),
    "redépossédés": ("redéposséder",),
    "redépossèdes": ("redéposséder",),
    "redépossédez": ("redéposséder",),
    "redépossédiez": ("redéposséder",),
    "redépossédions": ("redéposséder",),
    "redépossédons": ("redéposséder",),
    "redérangeaient": ("redéranger",),
    "redérangeai": ("redéranger",),
    "redérangeais": ("redéranger",),
    "redérangeait": ("redéranger",),
    "redérangea": ("redéranger",),
    "redérangeâmes": ("redéranger",),
    "redérangeant": ("redéranger",),
    "redérangeas": ("redéranger",),
    "redérangeassent": ("redéranger",),
    "redérangeasses": ("redéranger",),
    "redérangeasse": ("redéranger",),
    "redérangeassiez": ("redéranger",),
    "redérangeassions": ("redéranger",),
    "redérangeâtes": ("redéranger",),
    "redérangeât": ("redéranger",),
    "redérangée": ("redéranger",),
    "redérangées": ("redéranger",),
    "redérangé": ("redéranger",),
    "redérangent": ("redéranger",),
    "redérangeons": ("redéranger",),
    "redérange": ("redéranger",),
    "redérangera": ("redéranger",),
    "redérangeraient": ("redéranger",),
    "redérangerai": ("redéranger",),
    "redérangerais": ("redéranger",),
    "redérangerait": ("redéranger",),
    "redérangeras": ("redéranger",),
    "redérangèrent": ("redéranger",),
    "redérangerez": ("redéranger",),
    "redérangeriez": ("redéranger",),
    "redérangerions": ("redéranger",),
    "redérangerons": ("redéranger",),
    "redérangeront": ("redéranger",),
    "redérangés": ("redéranger",),
    "redéranges": ("redéranger",),
    "redérangez": ("redéranger",),
    "redérangiez": ("redéranger",),
    "redérangions": ("redéranger",),
    "redéréglaient": ("redérégler",),
    "redéréglai": ("redérégler",),
    "redéréglais": ("redérégler",),
    "redéréglait": ("redérégler",),
    "redérégla": ("redérégler",),
    "redéréglâmes": ("redérégler",),
    "redéréglant": ("redérégler",),
    "redéréglas": ("redérégler",),
    "redéréglassent": ("redérégler",),
    "redéréglasses": ("redérégler",),
    "redéréglasse": ("redérégler",),
    "redéréglassiez": ("redérégler",),
    "redéréglassions": ("redérégler",),
    "redéréglâtes": ("redérégler",),
    "redéréglât": ("redérégler",),
    "redéréglée": ("redérégler",),
    "redéréglées": ("redérégler",),
    "redéréglé": ("redérégler",),
    "redérèglent": ("redérégler",),
    "redérègle": ("redérégler",),
    "redéréglera": ("redérégler",),
    "redérégleraient": ("redérégler",),
    "redéréglerai": ("redérégler",),
    "redéréglerais": ("redérégler",),
    "redéréglerait": ("redérégler",),
    "redérégleras": ("redérégler",),
    "redéréglèrent": ("redérégler",),
    "redéréglerez": ("redérégler",),
    "redérégleriez": ("redérégler",),
    "redéréglerions": ("redérégler",),
    "redéréglerons": ("redérégler",),
    "redérégleront": ("redérégler",),
    "redéréglés": ("redérégler",),
    "redérègles": ("redérégler",),
    "redéréglez": ("redérégler",),
    "redérégliez": ("redérégler",),
    "redéréglions": ("redérégler",),
    "redéréglons": ("redérégler",),
    "redésavantageaient": ("redésavantager",),
    "redésavantageai": ("redésavantager",),
    "redésavantageais": ("redésavantager",),
    "redésavantageait": ("redésavantager",),
    "redésavantagea": ("redésavantager",),
    "redésavantageâmes": ("redésavantager",),
    "redésavantageant": ("redésavantager",),
    "redésavantageas": ("redésavantager",),
    "redésavantageassent": ("redésavantager",),
    "redésavantageasses": ("redésavantager",),
    "redésavantageasse": ("redésavantager",),
    "redésavantageassiez": ("redésavantager",),
    "redésavantageassions": ("redésavantager",),
    "redésavantageâtes": ("redésavantager",),
    "redésavantageât": ("redésavantager",),
    "redésavantagée": ("redésavantager",),
    "redésavantagées": ("redésavantager",),
    "redésavantagé": ("redésavantager",),
    "redésavantagent": ("redésavantager",),
    "redésavantageons": ("redésavantager",),
    "redésavantage": ("redésavantager",),
    "redésavantagera": ("redésavantager",),
    "redésavantageraient": ("redésavantager",),
    "redésavantagerai": ("redésavantager",),
    "redésavantagerais": ("redésavantager",),
    "redésavantagerait": ("redésavantager",),
    "redésavantageras": ("redésavantager",),
    "redésavantagèrent": ("redésavantager",),
    "redésavantagerez": ("redésavantager",),
    "redésavantageriez": ("redésavantager",),
    "redésavantagerions": ("redésavantager",),
    "redésavantagerons": ("redésavantager",),
    "redésavantageront": ("redésavantager",),
    "redésavantagés": ("redésavantager",),
    "redésavantages": ("redésavantager",),
    "redésavantagez": ("redésavantager",),
    "redésavantagiez": ("redésavantager",),
    "redésavantagions": ("redésavantager",),
    "redescendaient": ("redescendre",),
    "redescendais": ("redescendre",),
    "redescendait": ("redescendre",),
    "redescendant": ("redescendre",),
    "redescendent": ("redescendre",),
    "redescende": ("redescendre",),
    "redescendes": ("redescendre",),
    "redescendez": ("redescendre",),
    "redescendiez": ("redescendre",),
    "redescendîmes": ("redescendre",),
    "redescendions": ("redescendre",),
    "redescendirent": ("redescendre",),
    "redescendis": ("redescendre",),
    "redescendissent": ("redescendre",),
    "redescendisses": ("redescendre",),
    "redescendisse": ("redescendre",),
    "redescendissiez": ("redescendre",),
    "redescendissions": ("redescendre",),
    "redescendîtes": ("redescendre",),
    "redescendit": ("redescendre",),
    "redescendît": ("redescendre",),
    "redescendons": ("redescendre",),
    "redescend": ("redescendre",),
    "redescendra": ("redescendre",),
    "redescendraient": ("redescendre",),
    "redescendrai": ("redescendre",),
    "redescendrais": ("redescendre",),
    "redescendrait": ("redescendre",),
    "redescendras": ("redescendre",),
    "redescendrez": ("redescendre",),
    "redescendriez": ("redescendre",),
    "redescendrions": ("redescendre",),
    "redescendrons": ("redescendre",),
    "redescendront": ("redescendre",),
    "redescends": ("redescendre",),
    "redescendue": ("redescendre",),
    "redescendues": ("redescendre",),
    "redescendu": ("redescendre",),
    "redescendus": ("redescendre",),
    "redésobéie": ("redésobéir",),
    "redésobéies": ("redésobéir",),
    "redésobéi": ("redésobéir",),
    "redésobéîmes": ("redésobéir",),
    "redésobéira": ("redésobéir",),
    "redésobéiraient": ("redésobéir",),
    "redésobéirai": ("redésobéir",),
    "redésobéirais": ("redésobéir",),
    "redésobéirait": ("redésobéir",),
    "redésobéiras": ("redésobéir",),
    "redésobéirent": ("redésobéir",),
    "redésobéirez": ("redésobéir",),
    "redésobéiriez": ("redésobéir",),
    "redésobéirions": ("redésobéir",),
    "redésobéirons": ("redésobéir",),
    "redésobéiront": ("redésobéir",),
    "redésobéis": ("redésobéir",),
    "redésobéissaient": ("redésobéir",),
    "redésobéissais": ("redésobéir",),
    "redésobéissait": ("redésobéir",),
    "redésobéissant": ("redésobéir",),
    "redésobéissent": ("redésobéir",),
    "redésobéisse": ("redésobéir",),
    "redésobéisses": ("redésobéir",),
    "redésobéissez": ("redésobéir",),
    "redésobéissiez": ("redésobéir",),
    "redésobéissions": ("redésobéir",),
    "redésobéissons": ("redésobéir",),
    "redésobéîtes": ("redésobéir",),
    "redésobéit": ("redésobéir",),
    "redésobéît": ("redésobéir",),
    "redessers": ("redesservir",),
    "redessert": ("redesservir",),
    "redesservaient": ("redesservir",),
    "redesservais": ("redesservir",),
    "redesservait": ("redesservir",),
    "redesservant": ("redesservir",),
    "redesservent": ("redesservir",),
    "redesserve": ("redesservir",),
    "redesserves": ("redesservir",),
    "redesservez": ("redesservir",),
    "redesservie": ("redesservir",),
    "redesservies": ("redesservir",),
    "redesserviez": ("redesservir",),
    "redesservi": ("redesservir",),
    "redesservîmes": ("redesservir",),
    "redesservions": ("redesservir",),
    "redesservira": ("redesservir",),
    "redesserviraient": ("redesservir",),
    "redesservirai": ("redesservir",),
    "redesservirais": ("redesservir",),
    "redesservirait": ("redesservir",),
    "redesserviras": ("redesservir",),
    "redesservirent": ("redesservir",),
    "redesservirez": ("redesservir",),
    "redesserviriez": ("redesservir",),
    "redesservirions": ("redesservir",),
    "redesservirons": ("redesservir",),
    "redesserviront": ("redesservir",),
    "redesservis": ("redesservir",),
    "redesservissent": ("redesservir",),
    "redesservisses": ("redesservir",),
    "redesservisse": ("redesservir",),
    "redesservissiez": ("redesservir",),
    "redesservissions": ("redesservir",),
    "redesservîtes": ("redesservir",),
    "redesservit": ("redesservir",),
    "redesservît": ("redesservir",),
    "redesservons": ("redesservir",),
    "redéteignaient": ("redéteindre",),
    "redéteignais": ("redéteindre",),
    "redéteignait": ("redéteindre",),
    "redéteignant": ("redéteindre",),
    "redéteignent": ("redéteindre",),
    "redéteigne": ("redéteindre",),
    "redéteignes": ("redéteindre",),
    "redéteignez": ("redéteindre",),
    "redéteigniez": ("redéteindre",),
    "redéteignîmes": ("redéteindre",),
    "redéteignions": ("redéteindre",),
    "redéteignirent": ("redéteindre",),
    "redéteignis": ("redéteindre",),
    "redéteignissent": ("redéteindre",),
    "redéteignisses": ("redéteindre",),
    "redéteignisse": ("redéteindre",),
    "redéteignissiez": ("redéteindre",),
    "redéteignissions": ("redéteindre",),
    "redéteignîtes": ("redéteindre",),
    "redéteignit": ("redéteindre",),
    "redéteignît": ("redéteindre",),
    "redéteignons": ("redéteindre",),
    "redéteindra": ("redéteindre",),
    "redéteindraient": ("redéteindre",),
    "redéteindrai": ("redéteindre",),
    "redéteindrais": ("redéteindre",),
    "redéteindrait": ("redéteindre",),
    "redéteindras": ("redéteindre",),
    "redéteindrez": ("redéteindre",),
    "redéteindriez": ("redéteindre",),
    "redéteindrions": ("redéteindre",),
    "redéteindrons": ("redéteindre",),
    "redéteindront": ("redéteindre",),
    "redéteins": ("redéteindre",),
    "redéteinte": ("redéteindre",),
    "redéteintes": ("redéteindre",),
    "redéteint": ("redéteindre",),
    "redéteints": ("redéteindre",),
    "redétendaient": ("redétendre",),
    "redétendais": ("redétendre",),
    "redétendait": ("redétendre",),
    "redétendant": ("redétendre",),
    "redétendent": ("redétendre",),
    "redétende": ("redétendre",),
    "redétendes": ("redétendre",),
    "redétendez": ("redétendre",),
    "redétendiez": ("redétendre",),
    "redétendîmes": ("redétendre",),
    "redétendions": ("redétendre",),
    "redétendirent": ("redétendre",),
    "redétendis": ("redétendre",),
    "redétendissent": ("redétendre",),
    "redétendisses": ("redétendre",),
    "redétendisse": ("redétendre",),
    "redétendissiez": ("redétendre",),
    "redétendissions": ("redétendre",),
    "redétendîtes": ("redétendre",),
    "redétendit": ("redétendre",),
    "redétendît": ("redétendre",),
    "redétendons": ("redétendre",),
    "redétend": ("redétendre",),
    "redétendra": ("redétendre",),
    "redétendraient": ("redétendre",),
    "redétendrai": ("redétendre",),
    "redétendrais": ("redétendre",),
    "redétendrait": ("redétendre",),
    "redétendras": ("redétendre",),
    "redétendrez": ("redétendre",),
    "redétendriez": ("redétendre",),
    "redétendrions": ("redétendre",),
    "redétendrons": ("redétendre",),
    "redétendront": ("redétendre",),
    "redétends": ("redétendre",),
    "redétendue": ("redétendre",),
    "redétendues": ("redétendre",),
    "redétendu": ("redétendre",),
    "redétendus": ("redétendre",),
    "redétruira": ("redétruire",),
    "redétruiraient": ("redétruire",),
    "redétruirai": ("redétruire",),
    "redétruirais": ("redétruire",),
    "redétruirait": ("redétruire",),
    "redétruiras": ("redétruire",),
    "redétruirez": ("redétruire",),
    "redétruiriez": ("redétruire",),
    "redétruirions": ("redétruire",),
    "redétruirons": ("redétruire",),
    "redétruiront": ("redétruire",),
    "redétruisaient": ("redétruire",),
    "redétruisais": ("redétruire",),
    "redétruisait": ("redétruire",),
    "redétruisant": ("redétruire",),
    "redétruisent": ("redétruire",),
    "redétruise": ("redétruire",),
    "redétruises": ("redétruire",),
    "redétruisez": ("redétruire",),
    "redétruisiez": ("redétruire",),
    "redétruisîmes": ("redétruire",),
    "redétruisions": ("redétruire",),
    "redétruisirent": ("redétruire",),
    "redétruisis": ("redétruire",),
    "redétruisissent": ("redétruire",),
    "redétruisisses": ("redétruire",),
    "redétruisisse": ("redétruire",),
    "redétruisissiez": ("redétruire",),
    "redétruisissions": ("redétruire",),
    "redétruisîtes": ("redétruire",),
    "redétruisit": ("redétruire",),
    "redétruisît": ("redétruire",),
    "redétruisons": ("redétruire",),
    "redétruis": ("redétruire",),
    "redétruite": ("redétruire",),
    "redétruites": ("redétruire",),
    "redétruit": ("redétruire",),
    "redétruits": ("redétruire",),
    "redevançaient": ("redevancer",),
    "redevançai": ("redevancer",),
    "redevançais": ("redevancer",),
    "redevançait": ("redevancer",),
    "redevança": ("redevancer",),
    "redevançâmes": ("redevancer",),
    "redevançant": ("redevancer",),
    "redevanças": ("redevancer",),
    "redevançassent": ("redevancer",),
    "redevançasses": ("redevancer",),
    "redevançasse": ("redevancer",),
    "redevançassiez": ("redevancer",),
    "redevançassions": ("redevancer",),
    "redevançâtes": ("redevancer",),
    "redevançât": ("redevancer",),
    "redevancée": ("redevancer",),
    "redevancées": ("redevancer",),
    "redevancé": ("redevancer",),
    "redevancent": ("redevancer",),
    "redevance": ("redevancer",),
    "redevancera": ("redevancer",),
    "redevanceraient": ("redevancer",),
    "redevancerai": ("redevancer",),
    "redevancerais": ("redevancer",),
    "redevancerait": ("redevancer",),
    "redevanceras": ("redevancer",),
    "redevancèrent": ("redevancer",),
    "redevancerez": ("redevancer",),
    "redevanceriez": ("redevancer",),
    "redevancerions": ("redevancer",),
    "redevancerons": ("redevancer",),
    "redevanceront": ("redevancer",),
    "redevancés": ("redevancer",),
    "redevances": ("redevancer",),
    "redevancez": ("redevancer",),
    "redevanciez": ("redevancer",),
    "redevancions": ("redevancer",),
    "redevançons": ("redevancer",),
    "redevenaient": ("redevenir",),
    "redevenais": ("redevenir",),
    "redevenait": ("redevenir",),
    "redevenant": ("redevenir",),
    "redevenez": ("redevenir",),
    "redeveniez": ("redevenir",),
    "redevenions": ("redevenir",),
    "redevenons": ("redevenir",),
    "redevenue": ("redevenir",),
    "redevenues": ("redevenir",),
    "redevenu": ("redevenir",),
    "redevenus": ("redevenir",),
    "redeviendra": ("redevenir",),
    "redeviendraient": ("redevenir",),
    "redeviendrai": ("redevenir",),
    "redeviendrais": ("redevenir",),
    "redeviendrait": ("redevenir",),
    "redeviendras": ("redevenir",),
    "redeviendrez": ("redevenir",),
    "redeviendriez": ("redevenir",),
    "redeviendrions": ("redevenir",),
    "redeviendrons": ("redevenir",),
    "redeviendront": ("redevenir",),
    "redeviennent": ("redevenir",),
    "redevienne": ("redevenir",),
    "redeviennes": ("redevenir",),
    "redeviens": ("redevenir",),
    "redevient": ("redevenir",),
    "redevînmes": ("redevenir",),
    "redevinrent": ("redevenir",),
    "redevins": ("redevenir",),
    "redevinssent": ("redevenir",),
    "redevinsses": ("redevenir",),
    "redevinsse": ("redevenir",),
    "redevinssiez": ("redevenir",),
    "redevinssions": ("redevenir",),
    "redevîntes": ("redevenir",),
    "redevint": ("redevenir",),
    "redevînt": ("redevenir",),
    "redévisageaient": ("redévisager",),
    "redévisageai": ("redévisager",),
    "redévisageais": ("redévisager",),
    "redévisageait": ("redévisager",),
    "redévisagea": ("redévisager",),
    "redévisageâmes": ("redévisager",),
    "redévisageant": ("redévisager",),
    "redévisageas": ("redévisager",),
    "redévisageassent": ("redévisager",),
    "redévisageasses": ("redévisager",),
    "redévisageasse": ("redévisager",),
    "redévisageassiez": ("redévisager",),
    "redévisageassions": ("redévisager",),
    "redévisageâtes": ("redévisager",),
    "redévisageât": ("redévisager",),
    "redévisagée": ("redévisager",),
    "redévisagées": ("redévisager",),
    "redévisagé": ("redévisager",),
    "redévisagent": ("redévisager",),
    "redévisageons": ("redévisager",),
    "redévisage": ("redévisager",),
    "redévisagera": ("redévisager",),
    "redévisageraient": ("redévisager",),
    "redévisagerai": ("redévisager",),
    "redévisagerais": ("redévisager",),
    "redévisagerait": ("redévisager",),
    "redévisageras": ("redévisager",),
    "redévisagèrent": ("redévisager",),
    "redévisagerez": ("redévisager",),
    "redévisageriez": ("redévisager",),
    "redévisagerions": ("redévisager",),
    "redévisagerons": ("redévisager",),
    "redévisageront": ("redévisager",),
    "redévisagés": ("redévisager",),
    "redévisages": ("redévisager",),
    "redévisagez": ("redévisager",),
    "redévisagiez": ("redévisager",),
    "redévisagions": ("redévisager",),
    "redevaient": ("redevoir",),
    "redevais": ("redevoir",),
    "redevait": ("redevoir",),
    "redevant": ("redevoir",),
    "redevez": ("redevoir",),
    "redeviez": ("redevoir",),
    "redevions": ("redevoir",),
    "redevons": ("redevoir",),
    "redevra": ("redevoir",),
    "redevraient": ("redevoir",),
    "redevrai": ("redevoir",),
    "redevrais": ("redevoir",),
    "redevrait": ("redevoir",),
    "redevras": ("redevoir",),
    "redevrez": ("redevoir",),
    "redevriez": ("redevoir",),
    "redevrions": ("redevoir",),
    "redevrons": ("redevoir",),
    "redevront": ("redevoir",),
    "redois": ("redevoir",),
    "redoit": ("redevoir",),
    "redoivent": ("redevoir",),
    "redoive": ("redevoir",),
    "redoives": ("redevoir",),
    "redue": ("redevoir",),
    "redues": ("redevoir",),
    "redû": ("redevoir",),
    "redûmes": ("redevoir",),
    "redurent": ("redevoir",),
    "redus": ("redevoir",),
    "redussent": ("redevoir",),
    "redusses": ("redevoir",),
    "redusse": ("redevoir",),
    "redussiez": ("redevoir",),
    "redussions": ("redevoir",),
    "redûtes": ("redevoir",),
    "redut": ("redevoir",),
    "redût": ("redevoir",),
    "redifférenciaient": ("redifférencier",),
    "redifférenciai": ("redifférencier",),
    "redifférenciais": ("redifférencier",),
    "redifférenciait": ("redifférencier",),
    "redifférencia": ("redifférencier",),
    "redifférenciâmes": ("redifférencier",),
    "redifférenciant": ("redifférencier",),
    "redifférencias": ("redifférencier",),
    "redifférenciassent": ("redifférencier",),
    "redifférenciasses": ("redifférencier",),
    "redifférenciasse": ("redifférencier",),
    "redifférenciassiez": ("redifférencier",),
    "redifférenciassions": ("redifférencier",),
    "redifférenciâtes": ("redifférencier",),
    "redifférenciât": ("redifférencier",),
    "redifférenciée": ("redifférencier",),
    "redifférenciées": ("redifférencier",),
    "redifférencié": ("redifférencier",),
    "redifférencient": ("redifférencier",),
    "redifférencie": ("redifférencier",),
    "redifférenciera": ("redifférencier",),
    "redifférencieraient": ("redifférencier",),
    "redifférencierai": ("redifférencier",),
    "redifférencierais": ("redifférencier",),
    "redifférencierait": ("redifférencier",),
    "redifférencieras": ("redifférencier",),
    "redifférencièrent": ("redifférencier",),
    "redifférencierez": ("redifférencier",),
    "redifférencieriez": ("redifférencier",),
    "redifférencierions": ("redifférencier",),
    "redifférencierons": ("redifférencier",),
    "redifférencieront": ("redifférencier",),
    "redifférenciés": ("redifférencier",),
    "redifférencies": ("redifférencier",),
    "redifférenciez": ("redifférencier",),
    "redifférenciiez": ("redifférencier",),
    "redifférenciions": ("redifférencier",),
    "redifférencions": ("redifférencier",),
    "rédigeaient": ("rédiger",),
    "rédigeai": ("rédiger",),
    "rédigeais": ("rédiger",),
    "rédigeait": ("rédiger",),
    "rédigea": ("rédiger",),
    "rédigeâmes": ("rédiger",),
    "rédigeant": ("rédiger",),
    "rédigeas": ("rédiger",),
    "rédigeassent": ("rédiger",),
    "rédigeasses": ("rédiger",),
    "rédigeasse": ("rédiger",),
    "rédigeassiez": ("rédiger",),
    "rédigeassions": ("rédiger",),
    "rédigeâtes": ("rédiger",),
    "rédigeât": ("rédiger",),
    "rédigée": ("rédiger",),
    "rédigées": ("rédiger",),
    "rédigé": ("rédiger",),
    "rédigent": ("rédiger",),
    "rédigeons": ("rédiger",),
    "rédige": ("rédiger",),
    "rédigera": ("rédiger",),
    "rédigeraient": ("rédiger",),
    "rédigerai": ("rédiger",),
    "rédigerais": ("rédiger",),
    "rédigerait": ("rédiger",),
    "rédigeras": ("rédiger",),
    "rédigèrent": ("rédiger",),
    "rédigerez": ("rédiger",),
    "rédigeriez": ("rédiger",),
    "rédigerions": ("rédiger",),
    "rédigerons": ("rédiger",),
    "rédigeront": ("rédiger",),
    "rédigés": ("rédiger",),
    "rédiges": ("rédiger",),
    "rédigez": ("rédiger",),
    "rédigiez": ("rédiger",),
    "rédigions": ("rédiger",),
    "redîmes": ("redire",),
    "redira": ("redire",),
    "rediraient": ("redire",),
    "redirai": ("redire",),
    "redirais": ("redire",),
    "redirait": ("redire",),
    "rediras": ("redire",),
    "redirent": ("redire",),
    "redirez": ("redire",),
    "rediriez": ("redire",),
    "redirions": ("redire",),
    "redirons": ("redire",),
    "rediront": ("redire",),
    "redisaient": ("redire",),
    "redisais": ("redire",),
    "redisait": ("redire",),
    "redisant": ("redire",),
    "redisent": ("redire",),
    "redise": ("redire",),
    "redises": ("redire",),
    "redisiez": ("redire",),
    "redisions": ("redire",),
    "redisons": ("redire",),
    "redis": ("redire",),
    "redissent": ("redire",),
    "redisses": ("redire",),
    "redisse": ("redire",),
    "redissiez": ("redire",),
    "redissions": ("redire",),
    "redite": ("redire",),
    "redîtes": ("redire",),
    "redites": ("redire",),
    "redit": ("redire",),
    "redits": ("redire",),
    "redît": ("redire",),
    "redirigeaient": ("rediriger",),
    "redirigeai": ("rediriger",),
    "redirigeais": ("rediriger",),
    "redirigeait": ("rediriger",),
    "redirigea": ("rediriger",),
    "redirigeâmes": ("rediriger",),
    "redirigeant": ("rediriger",),
    "redirigeas": ("rediriger",),
    "redirigeassent": ("rediriger",),
    "redirigeasses": ("rediriger",),
    "redirigeasse": ("rediriger",),
    "redirigeassiez": ("rediriger",),
    "redirigeassions": ("rediriger",),
    "redirigeâtes": ("rediriger",),
    "redirigeât": ("rediriger",),
    "redirigée": ("rediriger",),
    "redirigées": ("rediriger",),
    "redirigé": ("rediriger",),
    "redirigent": ("rediriger",),
    "redirigeons": ("rediriger",),
    "redirige": ("rediriger",),
    "redirigera": ("rediriger",),
    "redirigeraient": ("rediriger",),
    "redirigerai": ("rediriger",),
    "redirigerais": ("rediriger",),
    "redirigerait": ("rediriger",),
    "redirigeras": ("rediriger",),
    "redirigèrent": ("rediriger",),
    "redirigerez": ("rediriger",),
    "redirigeriez": ("rediriger",),
    "redirigerions": ("rediriger",),
    "redirigerons": ("rediriger",),
    "redirigeront": ("rediriger",),
    "redirigés": ("rediriger",),
    "rediriges": ("rediriger",),
    "redirigez": ("rediriger",),
    "redirigiez": ("rediriger",),
    "redirigions": ("rediriger",),
    "rediscouraient": ("rediscourir",),
    "rediscourais": ("rediscourir",),
    "rediscourait": ("rediscourir",),
    "rediscourant": ("rediscourir",),
    "rediscourent": ("rediscourir",),
    "rediscoure": ("rediscourir",),
    "rediscoures": ("rediscourir",),
    "rediscourez": ("rediscourir",),
    "rediscouriez": ("rediscourir",),
    "rediscourions": ("rediscourir",),
    "rediscourons": ("rediscourir",),
    "rediscourra": ("rediscourir",),
    "rediscourraient": ("rediscourir",),
    "rediscourrai": ("rediscourir",),
    "rediscourrais": ("rediscourir",),
    "rediscourrait": ("rediscourir",),
    "rediscourras": ("rediscourir",),
    "rediscourrez": ("rediscourir",),
    "rediscourriez": ("rediscourir",),
    "rediscourrions": ("rediscourir",),
    "rediscourrons": ("rediscourir",),
    "rediscourront": ("rediscourir",),
    "rediscours": ("rediscourir",),
    "rediscourt": ("rediscourir",),
    "rediscouru": ("rediscourir",),
    "rediscourûmes": ("rediscourir",),
    "rediscoururent": ("rediscourir",),
    "rediscourus": ("rediscourir",),
    "rediscourussent": ("rediscourir",),
    "rediscourusses": ("rediscourir",),
    "rediscourusse": ("rediscourir",),
    "rediscourussiez": ("rediscourir",),
    "rediscourussions": ("rediscourir",),
    "rediscourûtes": ("rediscourir",),
    "rediscourut": ("rediscourir",),
    "rediscourût": ("rediscourir",),
    "redisparais": ("redisparaître",),
    "redisparaissaient": ("redisparaître",),
    "redisparaissais": ("redisparaître",),
    "redisparaissait": ("redisparaître",),
    "redisparaissant": ("redisparaître",),
    "redisparaissent": ("redisparaître",),
    "redisparaisse": ("redisparaître",),
    "redisparaisses": ("redisparaître",),
    "redisparaissez": ("redisparaître",),
    "redisparaissiez": ("redisparaître",),
    "redisparaissions": ("redisparaître",),
    "redisparaissons": ("redisparaître",),
    "redisparaît": ("redisparaître",),
    "redisparaîtra": ("redisparaître",),
    "redisparaîtraient": ("redisparaître",),
    "redisparaîtrai": ("redisparaître",),
    "redisparaîtrais": ("redisparaître",),
    "redisparaîtrait": ("redisparaître",),
    "redisparaîtras": ("redisparaître",),
    "redisparaîtrez": ("redisparaître",),
    "redisparaîtriez": ("redisparaître",),
    "redisparaîtrions": ("redisparaître",),
    "redisparaîtrons": ("redisparaître",),
    "redisparaîtront": ("redisparaître",),
    "redisparue": ("redisparaître",),
    "redisparues": ("redisparaître",),
    "redisparu": ("redisparaître",),
    "redisparûmes": ("redisparaître",),
    "redisparurent": ("redisparaître",),
    "redisparus": ("redisparaître",),
    "redisparussent": ("redisparaître",),
    "redisparusses": ("redisparaître",),
    "redisparusse": ("redisparaître",),
    "redisparussiez": ("redisparaître",),
    "redisparussions": ("redisparaître",),
    "redisparûtes": ("redisparaître",),
    "redisparut": ("redisparaître",),
    "redisparût": ("redisparaître",),
    "redisséquaient": ("redisséquer",),
    "redisséquai": ("redisséquer",),
    "redisséquais": ("redisséquer",),
    "redisséquait": ("redisséquer",),
    "redisséqua": ("redisséquer",),
    "redisséquâmes": ("redisséquer",),
    "redisséquant": ("redisséquer",),
    "redisséquas": ("redisséquer",),
    "redisséquassent": ("redisséquer",),
    "redisséquasses": ("redisséquer",),
    "redisséquasse": ("redisséquer",),
    "redisséquassiez": ("redisséquer",),
    "redisséquassions": ("redisséquer",),
    "redisséquâtes": ("redisséquer",),
    "redisséquât": ("redisséquer",),
    "redisséquée": ("redisséquer",),
    "redisséquées": ("redisséquer",),
    "redisséqué": ("redisséquer",),
    "redissèquent": ("redisséquer",),
    "redissèque": ("redisséquer",),
    "redisséquera": ("redisséquer",),
    "redisséqueraient": ("redisséquer",),
    "redisséquerai": ("redisséquer",),
    "redisséquerais": ("redisséquer",),
    "redisséquerait": ("redisséquer",),
    "redisséqueras": ("redisséquer",),
    "redisséquèrent": ("redisséquer",),
    "redisséquerez": ("redisséquer",),
    "redisséqueriez": ("redisséquer",),
    "redisséquerions": ("redisséquer",),
    "redisséquerons": ("redisséquer",),
    "redisséqueront": ("redisséquer",),
    "redisséqués": ("redisséquer",),
    "redissèques": ("redisséquer",),
    "redisséquez": ("redisséquer",),
    "redisséquiez": ("redisséquer",),
    "redisséquions": ("redisséquer",),
    "redisséquons": ("redisséquer",),
    "redissolûmes": ("redissoudre",),
    "redissolurent": ("redissoudre",),
    "redissolus": ("redissoudre",),
    "redissolussent": ("redissoudre",),
    "redissolusses": ("redissoudre",),
    "redissolusse": ("redissoudre",),
    "redissolussiez": ("redissoudre",),
    "redissolussions": ("redissoudre",),
    "redissolûtes": ("redissoudre",),
    "redissolut": ("redissoudre",),
    "redissolût": ("redissoudre",),
    "redissolvaient": ("redissoudre",),
    "redissolvais": ("redissoudre",),
    "redissolvait": ("redissoudre",),
    "redissolvant": ("redissoudre",),
    "redissolvent": ("redissoudre",),
    "redissolve": ("redissoudre",),
    "redissolves": ("redissoudre",),
    "redissolvez": ("redissoudre",),
    "redissolviez": ("redissoudre",),
    "redissolvions": ("redissoudre",),
    "redissolvons": ("redissoudre",),
    "redissoudra": ("redissoudre",),
    "redissoudraient": ("redissoudre",),
    "redissoudrai": ("redissoudre",),
    "redissoudrais": ("redissoudre",),
    "redissoudrait": ("redissoudre",),
    "redissoudras": ("redissoudre",),
    "redissoudrez": ("redissoudre",),
    "redissoudriez": ("redissoudre",),
    "redissoudrions": ("redissoudre",),
    "redissoudrons": ("redissoudre",),
    "redissoudront": ("redissoudre",),
    "redissous": ("redissoudre",),
    "redissoute": ("redissoudre",),
    "redissoutes": ("redissoudre",),
    "redissout": ("redissoudre",),
    "redistançaient": ("redistancer",),
    "redistançai": ("redistancer",),
    "redistançais": ("redistancer",),
    "redistançait": ("redistancer",),
    "redistança": ("redistancer",),
    "redistançâmes": ("redistancer",),
    "redistançant": ("redistancer",),
    "redistanças": ("redistancer",),
    "redistançassent": ("redistancer",),
    "redistançasses": ("redistancer",),
    "redistançasse": ("redistancer",),
    "redistançassiez": ("redistancer",),
    "redistançassions": ("redistancer",),
    "redistançâtes": ("redistancer",),
    "redistançât": ("redistancer",),
    "redistancée": ("redistancer",),
    "redistancées": ("redistancer",),
    "redistancé": ("redistancer",),
    "redistancent": ("redistancer",),
    "redistance": ("redistancer",),
    "redistancera": ("redistancer",),
    "redistanceraient": ("redistancer",),
    "redistancerai": ("redistancer",),
    "redistancerais": ("redistancer",),
    "redistancerait": ("redistancer",),
    "redistanceras": ("redistancer",),
    "redistancèrent": ("redistancer",),
    "redistancerez": ("redistancer",),
    "redistanceriez": ("redistancer",),
    "redistancerions": ("redistancer",),
    "redistancerons": ("redistancer",),
    "redistanceront": ("redistancer",),
    "redistancés": ("redistancer",),
    "redistances": ("redistancer",),
    "redistancez": ("redistancer",),
    "redistanciez": ("redistancer",),
    "redistancions": ("redistancer",),
    "redistançons": ("redistancer",),
    "redivorçaient": ("redivorcer",),
    "redivorçai": ("redivorcer",),
    "redivorçais": ("redivorcer",),
    "redivorçait": ("redivorcer",),
    "redivorça": ("redivorcer",),
    "redivorçâmes": ("redivorcer",),
    "redivorçant": ("redivorcer",),
    "redivorças": ("redivorcer",),
    "redivorçassent": ("redivorcer",),
    "redivorçasses": ("redivorcer",),
    "redivorçasse": ("redivorcer",),
    "redivorçassiez": ("redivorcer",),
    "redivorçassions": ("redivorcer",),
    "redivorçâtes": ("redivorcer",),
    "redivorçât": ("redivorcer",),
    "redivorcée": ("redivorcer",),
    "redivorcées": ("redivorcer",),
    "redivorcé": ("redivorcer",),
    "redivorcent": ("redivorcer",),
    "redivorce": ("redivorcer",),
    "redivorcera": ("redivorcer",),
    "redivorceraient": ("redivorcer",),
    "redivorcerai": ("redivorcer",),
    "redivorcerais": ("redivorcer",),
    "redivorcerait": ("redivorcer",),
    "redivorceras": ("redivorcer",),
    "redivorcèrent": ("redivorcer",),
    "redivorcerez": ("redivorcer",),
    "redivorceriez": ("redivorcer",),
    "redivorcerions": ("redivorcer",),
    "redivorcerons": ("redivorcer",),
    "redivorceront": ("redivorcer",),
    "redivorcés": ("redivorcer",),
    "redivorces": ("redivorcer",),
    "redivorcez": ("redivorcer",),
    "redivorciez": ("redivorcer",),
    "redivorcions": ("redivorcer",),
    "redivorçons": ("redivorcer",),
    "redomiciliaient": ("redomicilier",),
    "redomiciliai": ("redomicilier",),
    "redomiciliais": ("redomicilier",),
    "redomiciliait": ("redomicilier",),
    "redomicilia": ("redomicilier",),
    "redomiciliâmes": ("redomicilier",),
    "redomiciliant": ("redomicilier",),
    "redomicilias": ("redomicilier",),
    "redomiciliassent": ("redomicilier",),
    "redomiciliasses": ("redomicilier",),
    "redomiciliasse": ("redomicilier",),
    "redomiciliassiez": ("redomicilier",),
    "redomiciliassions": ("redomicilier",),
    "redomiciliâtes": ("redomicilier",),
    "redomiciliât": ("redomicilier",),
    "redomiciliée": ("redomicilier",),
    "redomiciliées": ("redomicilier",),
    "redomicilié": ("redomicilier",),
    "redomicilient": ("redomicilier",),
    "redomicilie": ("redomicilier",),
    "redomiciliera": ("redomicilier",),
    "redomicilieraient": ("redomicilier",),
    "redomicilierai": ("redomicilier",),
    "redomicilierais": ("redomicilier",),
    "redomicilierait": ("redomicilier",),
    "redomicilieras": ("redomicilier",),
    "redomicilièrent": ("redomicilier",),
    "redomicilierez": ("redomicilier",),
    "redomicilieriez": ("redomicilier",),
    "redomicilierions": ("redomicilier",),
    "redomicilierons": ("redomicilier",),
    "redomicilieront": ("redomicilier",),
    "redomiciliés": ("redomicilier",),
    "redomicilies": ("redomicilier",),
    "redomiciliez": ("redomicilier",),
    "redomiciliiez": ("redomicilier",),
    "redomiciliions": ("redomicilier",),
    "redomicilions": ("redomicilier",),
    "redormaient": ("redormir",),
    "redormais": ("redormir",),
    "redormait": ("redormir",),
    "redormant": ("redormir",),
    "redorment": ("redormir",),
    "redorme": ("redormir",),
    "redormes": ("redormir",),
    "redormez": ("redormir",),
    "redormie": ("redormir",),
    "redormies": ("redormir",),
    "redormiez": ("redormir",),
    "redormi": ("redormir",),
    "redormîmes": ("redormir",),
    "redormions": ("redormir",),
    "redormira": ("redormir",),
    "redormiraient": ("redormir",),
    "redormirai": ("redormir",),
    "redormirais": ("redormir",),
    "redormirait": ("redormir",),
    "redormiras": ("redormir",),
    "redormirent": ("redormir",),
    "redormirez": ("redormir",),
    "redormiriez": ("redormir",),
    "redormirions": ("redormir",),
    "redormirons": ("redormir",),
    "redormiront": ("redormir",),
    "redormis": ("redormir",),
    "redormissent": ("redormir",),
    "redormisses": ("redormir",),
    "redormisse": ("redormir",),
    "redormissiez": ("redormir",),
    "redormissions": ("redormir",),
    "redormîtes": ("redormir",),
    "redormit": ("redormir",),
    "redormît": ("redormir",),
    "redormons": ("redormir",),
    "redors": ("redormir",),
    "redort": ("redormir",),
    "réduira": ("réduire",),
    "réduiraient": ("réduire",),
    "réduirai": ("réduire",),
    "réduirais": ("réduire",),
    "réduirait": ("réduire",),
    "réduiras": ("réduire",),
    "réduirez": ("réduire",),
    "réduiriez": ("réduire",),
    "réduirions": ("réduire",),
    "réduirons": ("réduire",),
    "réduiront": ("réduire",),
    "réduisaient": ("réduire",),
    "réduisais": ("réduire",),
    "réduisait": ("réduire",),
    "réduisant": ("réduire",),
    "réduisent": ("réduire",),
    "réduise": ("réduire",),
    "réduises": ("réduire",),
    "réduisez": ("réduire",),
    "réduisiez": ("réduire",),
    "réduisîmes": ("réduire",),
    "réduisions": ("réduire",),
    "réduisirent": ("réduire",),
    "réduisis": ("réduire",),
    "réduisissent": ("réduire",),
    "réduisisses": ("réduire",),
    "réduisisse": ("réduire",),
    "réduisissiez": ("réduire",),
    "réduisissions": ("réduire",),
    "réduisîtes": ("réduire",),
    "réduisit": ("réduire",),
    "réduisît": ("réduire",),
    "réduisons": ("réduire",),
    "réduis": ("réduire",),
    "réduite": ("réduire",),
    "réduites": ("réduire",),
    "réduit": ("réduire",),
    "réduits": ("réduire",),
    "réécartelaient": ("réécarteler",),
    "réécartelai": ("réécarteler",),
    "réécartelais": ("réécarteler",),
    "réécartelait": ("réécarteler",),
    "réécartela": ("réécarteler",),
    "réécartelâmes": ("réécarteler",),
    "réécartelant": ("réécarteler",),
    "réécartelas": ("réécarteler",),
    "réécartelassent": ("réécarteler",),
    "réécartelasses": ("réécarteler",),
    "réécartelasse": ("réécarteler",),
    "réécartelassiez": ("réécarteler",),
    "réécartelassions": ("réécarteler",),
    "réécartelâtes": ("réécarteler",),
    "réécartelât": ("réécarteler",),
    "réécartelée": ("réécarteler",),
    "réécartelées": ("réécarteler",),
    "réécartelé": ("réécarteler",),
    "réécartèlent": ("réécarteler",),
    "réécartèle": ("réécarteler",),
    "réécartèlera": ("réécarteler",),
    "réécartèleraient": ("réécarteler",),
    "réécartèlerai": ("réécarteler",),
    "réécartèlerais": ("réécarteler",),
    "réécartèlerait": ("réécarteler",),
    "réécartèleras": ("réécarteler",),
    "réécartelèrent": ("réécarteler",),
    "réécartèlerez": ("réécarteler",),
    "réécartèleriez": ("réécarteler",),
    "réécartèlerions": ("réécarteler",),
    "réécartèlerons": ("réécarteler",),
    "réécartèleront": ("réécarteler",),
    "réécartelés": ("réécarteler",),
    "réécartèles": ("réécarteler",),
    "réécartelez": ("réécarteler",),
    "réécarteliez": ("réécarteler",),
    "réécartelions": ("réécarteler",),
    "réécartelons": ("réécarteler",),
    "rééchangeaient": ("rééchanger",),
    "rééchangeai": ("rééchanger",),
    "rééchangeais": ("rééchanger",),
    "rééchangeait": ("rééchanger",),
    "rééchangea": ("rééchanger",),
    "rééchangeâmes": ("rééchanger",),
    "rééchangeant": ("rééchanger",),
    "rééchangeas": ("rééchanger",),
    "rééchangeassent": ("rééchanger",),
    "rééchangeasses": ("rééchanger",),
    "rééchangeasse": ("rééchanger",),
    "rééchangeassiez": ("rééchanger",),
    "rééchangeassions": ("rééchanger",),
    "rééchangeâtes": ("rééchanger",),
    "rééchangeât": ("rééchanger",),
    "rééchangée": ("rééchanger",),
    "rééchangées": ("rééchanger",),
    "rééchangé": ("rééchanger",),
    "rééchangent": ("rééchanger",),
    "rééchangeons": ("rééchanger",),
    "rééchange": ("rééchanger",),
    "rééchangera": ("rééchanger",),
    "rééchangeraient": ("rééchanger",),
    "rééchangerai": ("rééchanger",),
    "rééchangerais": ("rééchanger",),
    "rééchangerait": ("rééchanger",),
    "rééchangeras": ("rééchanger",),
    "rééchangèrent": ("rééchanger",),
    "rééchangerez": ("rééchanger",),
    "rééchangeriez": ("rééchanger",),
    "rééchangerions": ("rééchanger",),
    "rééchangerons": ("rééchanger",),
    "rééchangeront": ("rééchanger",),
    "rééchangés": ("rééchanger",),
    "rééchanges": ("rééchanger",),
    "rééchangez": ("rééchanger",),
    "rééchangiez": ("rééchanger",),
    "rééchangions": ("rééchanger",),
    "réécrira": ("réécrire",),
    "réécriraient": ("réécrire",),
    "réécrirai": ("réécrire",),
    "réécrirais": ("réécrire",),
    "réécrirait": ("réécrire",),
    "réécriras": ("réécrire",),
    "réécrirez": ("réécrire",),
    "réécririez": ("réécrire",),
    "réécririons": ("réécrire",),
    "réécrirons": ("réécrire",),
    "réécriront": ("réécrire",),
    "réécris": ("réécrire",),
    "réécrite": ("réécrire",),
    "réécrites": ("réécrire",),
    "réécrit": ("réécrire",),
    "réécrits": ("réécrire",),
    "réécrivaient": ("réécrire",),
    "réécrivais": ("réécrire",),
    "réécrivait": ("réécrire",),
    "réécrivant": ("réécrire",),
    "réécrivent": ("réécrire",),
    "réécrive": ("réécrire",),
    "réécrives": ("réécrire",),
    "réécrivez": ("réécrire",),
    "réécriviez": ("réécrire",),
    "réécrivîmes": ("réécrire",),
    "réécrivions": ("réécrire",),
    "réécrivirent": ("réécrire",),
    "réécrivis": ("réécrire",),
    "réécrivissent": ("réécrire",),
    "réécrivisses": ("réécrire",),
    "réécrivisse": ("réécrire",),
    "réécrivissiez": ("réécrire",),
    "réécrivissions": ("réécrire",),
    "réécrivîtes": ("réécrire",),
    "réécrivit": ("réécrire",),
    "réécrivît": ("réécrire",),
    "réécrivons": ("réécrire",),
    "réédifiaient": ("réédifier",),
    "réédifiai": ("réédifier",),
    "réédifiais": ("réédifier",),
    "réédifiait": ("réédifier",),
    "réédifia": ("réédifier",),
    "réédifiâmes": ("réédifier",),
    "réédifiant": ("réédifier",),
    "réédifias": ("réédifier",),
    "réédifiassent": ("réédifier",),
    "réédifiasses": ("réédifier",),
    "réédifiasse": ("réédifier",),
    "réédifiassiez": ("réédifier",),
    "réédifiassions": ("réédifier",),
    "réédifiâtes": ("réédifier",),
    "réédifiât": ("réédifier",),
    "réédifiée": ("réédifier",),
    "réédifiées": ("réédifier",),
    "réédifié": ("réédifier",),
    "réédifient": ("réédifier",),
    "réédifie": ("réédifier",),
    "réédifiera": ("réédifier",),
    "réédifieraient": ("réédifier",),
    "réédifierai": ("réédifier",),
    "réédifierais": ("réédifier",),
    "réédifierait": ("réédifier",),
    "réédifieras": ("réédifier",),
    "réédifièrent": ("réédifier",),
    "réédifierez": ("réédifier",),
    "réédifieriez": ("réédifier",),
    "réédifierions": ("réédifier",),
    "réédifierons": ("réédifier",),
    "réédifieront": ("réédifier",),
    "réédifiés": ("réédifier",),
    "réédifies": ("réédifier",),
    "réédifiez": ("réédifier",),
    "réédifiiez": ("réédifier",),
    "réédifiions": ("réédifier",),
    "réédifions": ("réédifier",),
    "réeffaçaient": ("réeffacer",),
    "réeffaçai": ("réeffacer",),
    "réeffaçais": ("réeffacer",),
    "réeffaçait": ("réeffacer",),
    "réeffaça": ("réeffacer",),
    "réeffaçâmes": ("réeffacer",),
    "réeffaçant": ("réeffacer",),
    "réeffaças": ("réeffacer",),
    "réeffaçassent": ("réeffacer",),
    "réeffaçasses": ("réeffacer",),
    "réeffaçasse": ("réeffacer",),
    "réeffaçassiez": ("réeffacer",),
    "réeffaçassions": ("réeffacer",),
    "réeffaçâtes": ("réeffacer",),
    "réeffaçât": ("réeffacer",),
    "réeffacée": ("réeffacer",),
    "réeffacées": ("réeffacer",),
    "réeffacé": ("réeffacer",),
    "réeffacent": ("réeffacer",),
    "réefface": ("réeffacer",),
    "réeffacera": ("réeffacer",),
    "réeffaceraient": ("réeffacer",),
    "réeffacerai": ("réeffacer",),
    "réeffacerais": ("réeffacer",),
    "réeffacerait": ("réeffacer",),
    "réeffaceras": ("réeffacer",),
    "réeffacèrent": ("réeffacer",),
    "réeffacerez": ("réeffacer",),
    "réeffaceriez": ("réeffacer",),
    "réeffacerions": ("réeffacer",),
    "réeffacerons": ("réeffacer",),
    "réeffaceront": ("réeffacer",),
    "réeffacés": ("réeffacer",),
    "réeffaces": ("réeffacer",),
    "réeffacez": ("réeffacer",),
    "réeffaciez": ("réeffacer",),
    "réeffacions": ("réeffacer",),
    "réeffaçons": ("réeffacer",),
    "réélargie": ("réélargir",),
    "réélargies": ("réélargir",),
    "réélargi": ("réélargir",),
    "réélargîmes": ("réélargir",),
    "réélargira": ("réélargir",),
    "réélargiraient": ("réélargir",),
    "réélargirai": ("réélargir",),
    "réélargirais": ("réélargir",),
    "réélargirait": ("réélargir",),
    "réélargiras": ("réélargir",),
    "réélargirent": ("réélargir",),
    "réélargirez": ("réélargir",),
    "réélargiriez": ("réélargir",),
    "réélargirions": ("réélargir",),
    "réélargirons": ("réélargir",),
    "réélargiront": ("réélargir",),
    "réélargis": ("réélargir",),
    "réélargissaient": ("réélargir",),
    "réélargissais": ("réélargir",),
    "réélargissait": ("réélargir",),
    "réélargissant": ("réélargir",),
    "réélargissent": ("réélargir",),
    "réélargisse": ("réélargir",),
    "réélargisses": ("réélargir",),
    "réélargissez": ("réélargir",),
    "réélargissiez": ("réélargir",),
    "réélargissions": ("réélargir",),
    "réélargissons": ("réélargir",),
    "réélargîtes": ("réélargir",),
    "réélargit": ("réélargir",),
    "réélargît": ("réélargir",),
    "réélira": ("réélire",),
    "rééliraient": ("réélire",),
    "réélirai": ("réélire",),
    "réélirais": ("réélire",),
    "réélirait": ("réélire",),
    "rééliras": ("réélire",),
    "réélirez": ("réélire",),
    "rééliriez": ("réélire",),
    "réélirions": ("réélire",),
    "réélirons": ("réélire",),
    "rééliront": ("réélire",),
    "réélisaient": ("réélire",),
    "réélisais": ("réélire",),
    "réélisait": ("réélire",),
    "réélisant": ("réélire",),
    "réélisent": ("réélire",),
    "réélise": ("réélire",),
    "réélises": ("réélire",),
    "réélisez": ("réélire",),
    "réélisiez": ("réélire",),
    "réélisions": ("réélire",),
    "réélisons": ("réélire",),
    "réélis": ("réélire",),
    "réélit": ("réélire",),
    "réélue": ("réélire",),
    "réélues": ("réélire",),
    "réélu": ("réélire",),
    "réélûmes": ("réélire",),
    "réélurent": ("réélire",),
    "réélus": ("réélire",),
    "réélussent": ("réélire",),
    "réélusses": ("réélire",),
    "réélusse": ("réélire",),
    "réélussiez": ("réélire",),
    "réélussions": ("réélire",),
    "réélûtes": ("réélire",),
    "réélut": ("réélire",),
    "réélût": ("réélire",),
    "réemboutie": ("réemboutir",),
    "réembouties": ("réemboutir",),
    "réembouti": ("réemboutir",),
    "réemboutîmes": ("réemboutir",),
    "réemboutira": ("réemboutir",),
    "réemboutiraient": ("réemboutir",),
    "réemboutirai": ("réemboutir",),
    "réemboutirais": ("réemboutir",),
    "réemboutirait": ("réemboutir",),
    "réemboutiras": ("réemboutir",),
    "réemboutirent": ("réemboutir",),
    "réemboutirez": ("réemboutir",),
    "réemboutiriez": ("réemboutir",),
    "réemboutirions": ("réemboutir",),
    "réemboutirons": ("réemboutir",),
    "réemboutiront": ("réemboutir",),
    "réemboutis": ("réemboutir",),
    "réemboutissaient": ("réemboutir",),
    "réemboutissais": ("réemboutir",),
    "réemboutissait": ("réemboutir",),
    "réemboutissant": ("réemboutir",),
    "réemboutissent": ("réemboutir",),
    "réemboutisse": ("réemboutir",),
    "réemboutisses": ("réemboutir",),
    "réemboutissez": ("réemboutir",),
    "réemboutissiez": ("réemboutir",),
    "réemboutissions": ("réemboutir",),
    "réemboutissons": ("réemboutir",),
    "réemboutîtes": ("réemboutir",),
    "réemboutit": ("réemboutir",),
    "réemboutît": ("réemboutir",),
    "réembrassaient": ("réembrasser",),
    "réembrassai": ("réembrasser",),
    "réembrassais": ("réembrasser",),
    "réembrassait": ("réembrasser",),
    "réembrassa": ("réembrasser",),
    "réembrassâmes": ("réembrasser",),
    "réembrassant": ("réembrasser",),
    "réembrassas": ("réembrasser",),
    "réembrassassent": ("réembrasser",),
    "réembrassasses": ("réembrasser",),
    "réembrassasse": ("réembrasser",),
    "réembrassassiez": ("réembrasser",),
    "réembrassassions": ("réembrasser",),
    "réembrassâtes": ("réembrasser",),
    "réembrassât": ("réembrasser",),
    "réembrassée": ("réembrasser",),
    "réembrassées": ("réembrasser",),
    "réembrassé": ("réembrasser",),
    "réembrassent": ("réembrasser",),
    "réembrasse": ("réembrasser",),
    "réembrassera": ("réembrasser",),
    "réembrasseraient": ("réembrasser",),
    "réembrasserai": ("réembrasser",),
    "réembrasserais": ("réembrasser",),
    "réembrasserait": ("réembrasser",),
    "réembrasseras": ("réembrasser",),
    "réembrassèrent": ("réembrasser",),
    "réembrasserez": ("réembrasser",),
    "réembrasseriez": ("réembrasser",),
    "réembrasserions": ("réembrasser",),
    "réembrasserons": ("réembrasser",),
    "réembrasseront": ("réembrasser",),
    "réembrassés": ("réembrasser",),
    "réembrasses": ("réembrasser",),
    "réembrassez": ("réembrasser",),
    "réembrassiez": ("réembrasser",),
    "réembrassions": ("réembrasser",),
    "réembrassons": ("réembrasser",),
    "réembraient": ("réembrayer",),
    "réembraie": ("réembrayer",),
    "réembraiera": ("réembrayer",),
    "réembraieraient": ("réembrayer",),
    "réembraierai": ("réembrayer",),
    "réembraierais": ("réembrayer",),
    "réembraierait": ("réembrayer",),
    "réembraieras": ("réembrayer",),
    "réembraierez": ("réembrayer",),
    "réembraieriez": ("réembrayer",),
    "réembraierions": ("réembrayer",),
    "réembraierons": ("réembrayer",),
    "réembraieront": ("réembrayer",),
    "réembraies": ("réembrayer",),
    "réembrayaient": ("réembrayer",),
    "réembrayai": ("réembrayer",),
    "réembrayais": ("réembrayer",),
    "réembrayait": ("réembrayer",),
    "réembraya": ("réembrayer",),
    "réembrayâmes": ("réembrayer",),
    "réembrayant": ("réembrayer",),
    "réembrayas": ("réembrayer",),
    "réembrayassent": ("réembrayer",),
    "réembrayasses": ("réembrayer",),
    "réembrayasse": ("réembrayer",),
    "réembrayassiez": ("réembrayer",),
    "réembrayassions": ("réembrayer",),
    "réembrayâtes": ("réembrayer",),
    "réembrayât": ("réembrayer",),
    "réembrayée": ("réembrayer",),
    "réembrayées": ("réembrayer",),
    "réembrayé": ("réembrayer",),
    "réembrayent": ("réembrayer",),
    "réembraye": ("réembrayer",),
    "réembrayera": ("réembrayer",),
    "réembrayeraient": ("réembrayer",),
    "réembrayerai": ("réembrayer",),
    "réembrayerais": ("réembrayer",),
    "réembrayerait": ("réembrayer",),
    "réembrayeras": ("réembrayer",),
    "réembrayèrent": ("réembrayer",),
    "réembrayerez": ("réembrayer",),
    "réembrayeriez": ("réembrayer",),
    "réembrayerions": ("réembrayer",),
    "réembrayerons": ("réembrayer",),
    "réembrayeront": ("réembrayer",),
    "réembrayés": ("réembrayer",),
    "réembrayes": ("réembrayer",),
    "réembrayez": ("réembrayer",),
    "réembrayiez": ("réembrayer",),
    "réembrayions": ("réembrayer",),
    "réembrayons": ("réembrayer",),
    "réémet": ("réémettre",),
    "réémets": ("réémettre",),
    "réémettaient": ("réémettre",),
    "réémettais": ("réémettre",),
    "réémettait": ("réémettre",),
    "réémettant": ("réémettre",),
    "réémettent": ("réémettre",),
    "réémette": ("réémettre",),
    "réémettes": ("réémettre",),
    "réémettez": ("réémettre",),
    "réémettiez": ("réémettre",),
    "réémettions": ("réémettre",),
    "réémettons": ("réémettre",),
    "réémettra": ("réémettre",),
    "réémettraient": ("réémettre",),
    "réémettrai": ("réémettre",),
    "réémettrais": ("réémettre",),
    "réémettrait": ("réémettre",),
    "réémettras": ("réémettre",),
    "réémettrez": ("réémettre",),
    "réémettriez": ("réémettre",),
    "réémettrions": ("réémettre",),
    "réémettrons": ("réémettre",),
    "réémettront": ("réémettre",),
    "réémîmes": ("réémettre",),
    "réémirent": ("réémettre",),
    "réémise": ("réémettre",),
    "réémises": ("réémettre",),
    "réémis": ("réémettre",),
    "réémissent": ("réémettre",),
    "réémisses": ("réémettre",),
    "réémisse": ("réémettre",),
    "réémissiez": ("réémettre",),
    "réémissions": ("réémettre",),
    "réémîtes": ("réémettre",),
    "réémit": ("réémettre",),
    "réémît": ("réémettre",),
    "réemménageaient": ("réemménager",),
    "réemménageai": ("réemménager",),
    "réemménageais": ("réemménager",),
    "réemménageait": ("réemménager",),
    "réemménagea": ("réemménager",),
    "réemménageâmes": ("réemménager",),
    "réemménageant": ("réemménager",),
    "réemménageas": ("réemménager",),
    "réemménageassent": ("réemménager",),
    "réemménageasses": ("réemménager",),
    "réemménageasse": ("réemménager",),
    "réemménageassiez": ("réemménager",),
    "réemménageassions": ("réemménager",),
    "réemménageâtes": ("réemménager",),
    "réemménageât": ("réemménager",),
    "réemménagée": ("réemménager",),
    "réemménagées": ("réemménager",),
    "réemménagé": ("réemménager",),
    "réemménagent": ("réemménager",),
    "réemménageons": ("réemménager",),
    "réemménage": ("réemménager",),
    "réemménagera": ("réemménager",),
    "réemménageraient": ("réemménager",),
    "réemménagerai": ("réemménager",),
    "réemménagerais": ("réemménager",),
    "réemménagerait": ("réemménager",),
    "réemménageras": ("réemménager",),
    "réemménagèrent": ("réemménager",),
    "réemménagerez": ("réemménager",),
    "réemménageriez": ("réemménager",),
    "réemménagerions": ("réemménager",),
    "réemménagerons": ("réemménager",),
    "réemménageront": ("réemménager",),
    "réemménagés": ("réemménager",),
    "réemménages": ("réemménager",),
    "réemménagez": ("réemménager",),
    "réemménagiez": ("réemménager",),
    "réemménagions": ("réemménager",),
    "réempaquetaient": ("réempaqueter",),
    "réempaquetai": ("réempaqueter",),
    "réempaquetais": ("réempaqueter",),
    "réempaquetait": ("réempaqueter",),
    "réempaqueta": ("réempaqueter",),
    "réempaquetâmes": ("réempaqueter",),
    "réempaquetant": ("réempaqueter",),
    "réempaquetas": ("réempaqueter",),
    "réempaquetassent": ("réempaqueter",),
    "réempaquetasses": ("réempaqueter",),
    "réempaquetasse": ("réempaqueter",),
    "réempaquetassiez": ("réempaqueter",),
    "réempaquetassions": ("réempaqueter",),
    "réempaquetâtes": ("réempaqueter",),
    "réempaquetât": ("réempaqueter",),
    "réempaquetée": ("réempaqueter",),
    "réempaquetées": ("réempaqueter",),
    "réempaqueté": ("réempaqueter",),
    "réempaquetèrent": ("réempaqueter",),
    "réempaquetés": ("réempaqueter",),
    "réempaquetez": ("réempaqueter",),
    "réempaquetiez": ("réempaqueter",),
    "réempaquetions": ("réempaqueter",),
    "réempaquetons": ("réempaqueter",),
    "réempaquettent": ("réempaqueter",),
    "réempaquette": ("réempaqueter",),
    "réempaquettera": ("réempaqueter",),
    "réempaquetteraient": ("réempaqueter",),
    "réempaquetterai": ("réempaqueter",),
    "réempaquetterais": ("réempaqueter",),
    "réempaquetterait": ("réempaqueter",),
    "réempaquetteras": ("réempaqueter",),
    "réempaquetterez": ("réempaqueter",),
    "réempaquetteriez": ("réempaqueter",),
    "réempaquetterions": ("réempaqueter",),
    "réempaquetterons": ("réempaqueter",),
    "réempaquetteront": ("réempaqueter",),
    "réempaquettes": ("réempaqueter",),
    "réempesaient": ("réempeser",),
    "réempesai": ("réempeser",),
    "réempesais": ("réempeser",),
    "réempesait": ("réempeser",),
    "réempesa": ("réempeser",),
    "réempesâmes": ("réempeser",),
    "réempesant": ("réempeser",),
    "réempesas": ("réempeser",),
    "réempesassent": ("réempeser",),
    "réempesasses": ("réempeser",),
    "réempesasse": ("réempeser",),
    "réempesassiez": ("réempeser",),
    "réempesassions": ("réempeser",),
    "réempesâtes": ("réempeser",),
    "réempesât": ("réempeser",),
    "réempesée": ("réempeser",),
    "réempesées": ("réempeser",),
    "réempesé": ("réempeser",),
    "réempèsent": ("réempeser",),
    "réempèse": ("réempeser",),
    "réempèsera": ("réempeser",),
    "réempèseraient": ("réempeser",),
    "réempèserai": ("réempeser",),
    "réempèserais": ("réempeser",),
    "réempèserait": ("réempeser",),
    "réempèseras": ("réempeser",),
    "réempesèrent": ("réempeser",),
    "réempèserez": ("réempeser",),
    "réempèseriez": ("réempeser",),
    "réempèserions": ("réempeser",),
    "réempèserons": ("réempeser",),
    "réempèseront": ("réempeser",),
    "réempesés": ("réempeser",),
    "réempèses": ("réempeser",),
    "réempesez": ("réempeser",),
    "réempesiez": ("réempeser",),
    "réempesions": ("réempeser",),
    "réempesons": ("réempeser",),
    "réempiétaient": ("réempiéter",),
    "réempiétai": ("réempiéter",),
    "réempiétais": ("réempiéter",),
    "réempiétait": ("réempiéter",),
    "réempiéta": ("réempiéter",),
    "réempiétâmes": ("réempiéter",),
    "réempiétant": ("réempiéter",),
    "réempiétas": ("réempiéter",),
    "réempiétassent": ("réempiéter",),
    "réempiétasses": ("réempiéter",),
    "réempiétasse": ("réempiéter",),
    "réempiétassiez": ("réempiéter",),
    "réempiétassions": ("réempiéter",),
    "réempiétâtes": ("réempiéter",),
    "réempiétât": ("réempiéter",),
    "réempiétée": ("réempiéter",),
    "réempiétées": ("réempiéter",),
    "réempiété": ("réempiéter",),
    "réempiètent": ("réempiéter",),
    "réempiète": ("réempiéter",),
    "réempiétera": ("réempiéter",),
    "réempiéteraient": ("réempiéter",),
    "réempiéterai": ("réempiéter",),
    "réempiéterais": ("réempiéter",),
    "réempiéterait": ("réempiéter",),
    "réempiéteras": ("réempiéter",),
    "réempiétèrent": ("réempiéter",),
    "réempiéterez": ("réempiéter",),
    "réempiéteriez": ("réempiéter",),
    "réempiéterions": ("réempiéter",),
    "réempiéterons": ("réempiéter",),
    "réempiéteront": ("réempiéter",),
    "réempiétés": ("réempiéter",),
    "réempiètes": ("réempiéter",),
    "réempiétez": ("réempiéter",),
    "réempiétiez": ("réempiéter",),
    "réempiétions": ("réempiéter",),
    "réempiétons": ("réempiéter",),
    "réemploient": ("réemployer",),
    "réemploie": ("réemployer",),
    "réemploiera": ("réemployer",),
    "réemploieraient": ("réemployer",),
    "réemploierai": ("réemployer",),
    "réemploierais": ("réemployer",),
    "réemploierait": ("réemployer",),
    "réemploieras": ("réemployer",),
    "réemploierez": ("réemployer",),
    "réemploieriez": ("réemployer",),
    "réemploierions": ("réemployer",),
    "réemploierons": ("réemployer",),
    "réemploieront": ("réemployer",),
    "réemploies": ("réemployer",),
    "réemployaient": ("réemployer",),
    "réemployai": ("réemployer",),
    "réemployais": ("réemployer",),
    "réemployait": ("réemployer",),
    "réemploya": ("réemployer",),
    "réemployâmes": ("réemployer",),
    "réemployant": ("réemployer",),
    "réemployas": ("réemployer",),
    "réemployassent": ("réemployer",),
    "réemployasses": ("réemployer",),
    "réemployasse": ("réemployer",),
    "réemployassiez": ("réemployer",),
    "réemployassions": ("réemployer",),
    "réemployâtes": ("réemployer",),
    "réemployât": ("réemployer",),
    "réemployée": ("réemployer",),
    "réemployées": ("réemployer",),
    "réemployé": ("réemployer",),
    "réemployèrent": ("réemployer",),
    "réemployés": ("réemployer",),
    "réemployez": ("réemployer",),
    "réemployiez": ("réemployer",),
    "réemployions": ("réemployer",),
    "réemployons": ("réemployer",),
    "réencourageaient": ("réencourager",),
    "réencourageai": ("réencourager",),
    "réencourageais": ("réencourager",),
    "réencourageait": ("réencourager",),
    "réencouragea": ("réencourager",),
    "réencourageâmes": ("réencourager",),
    "réencourageant": ("réencourager",),
    "réencourageas": ("réencourager",),
    "réencourageassent": ("réencourager",),
    "réencourageasses": ("réencourager",),
    "réencourageasse": ("réencourager",),
    "réencourageassiez": ("réencourager",),
    "réencourageassions": ("réencourager",),
    "réencourageâtes": ("réencourager",),
    "réencourageât": ("réencourager",),
    "réencouragée": ("réencourager",),
    "réencouragées": ("réencourager",),
    "réencouragé": ("réencourager",),
    "réencouragent": ("réencourager",),
    "réencourageons": ("réencourager",),
    "réencourage": ("réencourager",),
    "réencouragera": ("réencourager",),
    "réencourageraient": ("réencourager",),
    "réencouragerai": ("réencourager",),
    "réencouragerais": ("réencourager",),
    "réencouragerait": ("réencourager",),
    "réencourageras": ("réencourager",),
    "réencouragèrent": ("réencourager",),
    "réencouragerez": ("réencourager",),
    "réencourageriez": ("réencourager",),
    "réencouragerions": ("réencourager",),
    "réencouragerons": ("réencourager",),
    "réencourageront": ("réencourager",),
    "réencouragés": ("réencourager",),
    "réencourages": ("réencourager",),
    "réencouragez": ("réencourager",),
    "réencouragiez": ("réencourager",),
    "réencouragions": ("réencourager",),
    "réencrassaient": ("réencrasser",),
    "réencrassai": ("réencrasser",),
    "réencrassais": ("réencrasser",),
    "réencrassait": ("réencrasser",),
    "réencrassa": ("réencrasser",),
    "réencrassâmes": ("réencrasser",),
    "réencrassant": ("réencrasser",),
    "réencrassas": ("réencrasser",),
    "réencrassassent": ("réencrasser",),
    "réencrassasses": ("réencrasser",),
    "réencrassasse": ("réencrasser",),
    "réencrassassiez": ("réencrasser",),
    "réencrassassions": ("réencrasser",),
    "réencrassâtes": ("réencrasser",),
    "réencrassât": ("réencrasser",),
    "réencrassée": ("réencrasser",),
    "réencrassées": ("réencrasser",),
    "réencrassé": ("réencrasser",),
    "réencrassent": ("réencrasser",),
    "réencrasse": ("réencrasser",),
    "réencrassera": ("réencrasser",),
    "réencrasseraient": ("réencrasser",),
    "réencrasserai": ("réencrasser",),
    "réencrasserais": ("réencrasser",),
    "réencrasserait": ("réencrasser",),
    "réencrasseras": ("réencrasser",),
    "réencrassèrent": ("réencrasser",),
    "réencrasserez": ("réencrasser",),
    "réencrasseriez": ("réencrasser",),
    "réencrasserions": ("réencrasser",),
    "réencrasserons": ("réencrasser",),
    "réencrasseront": ("réencrasser",),
    "réencrassés": ("réencrasser",),
    "réencrasses": ("réencrasser",),
    "réencrassez": ("réencrasser",),
    "réencrassiez": ("réencrasser",),
    "réencrassions": ("réencrasser",),
    "réencrassons": ("réencrasser",),
    "réenduira": ("réenduire",),
    "réenduiraient": ("réenduire",),
    "réenduirai": ("réenduire",),
    "réenduirais": ("réenduire",),
    "réenduirait": ("réenduire",),
    "réenduiras": ("réenduire",),
    "réenduirez": ("réenduire",),
    "réenduiriez": ("réenduire",),
    "réenduirions": ("réenduire",),
    "réenduirons": ("réenduire",),
    "réenduiront": ("réenduire",),
    "réenduisaient": ("réenduire",),
    "réenduisais": ("réenduire",),
    "réenduisait": ("réenduire",),
    "réenduisant": ("réenduire",),
    "réenduisent": ("réenduire",),
    "réenduise": ("réenduire",),
    "réenduises": ("réenduire",),
    "réenduisez": ("réenduire",),
    "réenduisiez": ("réenduire",),
    "réenduisîmes": ("réenduire",),
    "réenduisions": ("réenduire",),
    "réenduisirent": ("réenduire",),
    "réenduisis": ("réenduire",),
    "réenduisissent": ("réenduire",),
    "réenduisisses": ("réenduire",),
    "réenduisisse": ("réenduire",),
    "réenduisissiez": ("réenduire",),
    "réenduisissions": ("réenduire",),
    "réenduisîtes": ("réenduire",),
    "réenduisit": ("réenduire",),
    "réenduisît": ("réenduire",),
    "réenduisons": ("réenduire",),
    "réenduis": ("réenduire",),
    "réenduite": ("réenduire",),
    "réenduites": ("réenduire",),
    "réenduit": ("réenduire",),
    "réenduits": ("réenduire",),
    "réenfonçaient": ("réenfoncer",),
    "réenfonçai": ("réenfoncer",),
    "réenfonçais": ("réenfoncer",),
    "réenfonçait": ("réenfoncer",),
    "réenfonça": ("réenfoncer",),
    "réenfonçâmes": ("réenfoncer",),
    "réenfonçant": ("réenfoncer",),
    "réenfonças": ("réenfoncer",),
    "réenfonçassent": ("réenfoncer",),
    "réenfonçasses": ("réenfoncer",),
    "réenfonçasse": ("réenfoncer",),
    "réenfonçassiez": ("réenfoncer",),
    "réenfonçassions": ("réenfoncer",),
    "réenfonçâtes": ("réenfoncer",),
    "réenfonçât": ("réenfoncer",),
    "réenfoncée": ("réenfoncer",),
    "réenfoncées": ("réenfoncer",),
    "réenfoncé": ("réenfoncer",),
    "réenfoncent": ("réenfoncer",),
    "réenfonce": ("réenfoncer",),
    "réenfoncera": ("réenfoncer",),
    "réenfonceraient": ("réenfoncer",),
    "réenfoncerai": ("réenfoncer",),
    "réenfoncerais": ("réenfoncer",),
    "réenfoncerait": ("réenfoncer",),
    "réenfonceras": ("réenfoncer",),
    "réenfoncèrent": ("réenfoncer",),
    "réenfoncerez": ("réenfoncer",),
    "réenfonceriez": ("réenfoncer",),
    "réenfoncerions": ("réenfoncer",),
    "réenfoncerons": ("réenfoncer",),
    "réenfonceront": ("réenfoncer",),
    "réenfoncés": ("réenfoncer",),
    "réenfonces": ("réenfoncer",),
    "réenfoncez": ("réenfoncer",),
    "réenfonciez": ("réenfoncer",),
    "réenfoncions": ("réenfoncer",),
    "réenfonçons": ("réenfoncer",),
    "réengageaient": ("réengager",),
    "réengageai": ("réengager",),
    "réengageais": ("réengager",),
    "réengageait": ("réengager",),
    "réengagea": ("réengager",),
    "réengageâmes": ("réengager",),
    "réengageant": ("réengager",),
    "réengageas": ("réengager",),
    "réengageassent": ("réengager",),
    "réengageasses": ("réengager",),
    "réengageasse": ("réengager",),
    "réengageassiez": ("réengager",),
    "réengageassions": ("réengager",),
    "réengageâtes": ("réengager",),
    "réengageât": ("réengager",),
    "réengagée": ("réengager",),
    "réengagées": ("réengager",),
    "réengagé": ("réengager",),
    "réengagent": ("réengager",),
    "réengageons": ("réengager",),
    "réengage": ("réengager",),
    "réengagera": ("réengager",),
    "réengageraient": ("réengager",),
    "réengagerai": ("réengager",),
    "réengagerais": ("réengager",),
    "réengagerait": ("réengager",),
    "réengageras": ("réengager",),
    "réengagèrent": ("réengager",),
    "réengagerez": ("réengager",),
    "réengageriez": ("réengager",),
    "réengagerions": ("réengager",),
    "réengagerons": ("réengager",),
    "réengageront": ("réengager",),
    "réengagés": ("réengager",),
    "réengages": ("réengager",),
    "réengagez": ("réengager",),
    "réengagiez": ("réengager",),
    "réengagions": ("réengager",),
    "réenglaçaient": ("réenglacer",),
    "réenglaçai": ("réenglacer",),
    "réenglaçais": ("réenglacer",),
    "réenglaçait": ("réenglacer",),
    "réenglaça": ("réenglacer",),
    "réenglaçâmes": ("réenglacer",),
    "réenglaçant": ("réenglacer",),
    "réenglaças": ("réenglacer",),
    "réenglaçassent": ("réenglacer",),
    "réenglaçasses": ("réenglacer",),
    "réenglaçasse": ("réenglacer",),
    "réenglaçassiez": ("réenglacer",),
    "réenglaçassions": ("réenglacer",),
    "réenglaçâtes": ("réenglacer",),
    "réenglaçât": ("réenglacer",),
    "réenglacée": ("réenglacer",),
    "réenglacées": ("réenglacer",),
    "réenglacé": ("réenglacer",),
    "réenglacent": ("réenglacer",),
    "réenglace": ("réenglacer",),
    "réenglacera": ("réenglacer",),
    "réenglaceraient": ("réenglacer",),
    "réenglacerai": ("réenglacer",),
    "réenglacerais": ("réenglacer",),
    "réenglacerait": ("réenglacer",),
    "réenglaceras": ("réenglacer",),
    "réenglacèrent": ("réenglacer",),
    "réenglacerez": ("réenglacer",),
    "réenglaceriez": ("réenglacer",),
    "réenglacerions": ("réenglacer",),
    "réenglacerons": ("réenglacer",),
    "réenglaceront": ("réenglacer",),
    "réenglacés": ("réenglacer",),
    "réenglaces": ("réenglacer",),
    "réenglacez": ("réenglacer",),
    "réenglaciez": ("réenglacer",),
    "réenglacions": ("réenglacer",),
    "réenglaçons": ("réenglacer",),
    "réengorgeaient": ("réengorger",),
    "réengorgeai": ("réengorger",),
    "réengorgeais": ("réengorger",),
    "réengorgeait": ("réengorger",),
    "réengorgea": ("réengorger",),
    "réengorgeâmes": ("réengorger",),
    "réengorgeant": ("réengorger",),
    "réengorgeas": ("réengorger",),
    "réengorgeassent": ("réengorger",),
    "réengorgeasses": ("réengorger",),
    "réengorgeasse": ("réengorger",),
    "réengorgeassiez": ("réengorger",),
    "réengorgeassions": ("réengorger",),
    "réengorgeâtes": ("réengorger",),
    "réengorgeât": ("réengorger",),
    "réengorgée": ("réengorger",),
    "réengorgées": ("réengorger",),
    "réengorgé": ("réengorger",),
    "réengorgent": ("réengorger",),
    "réengorgeons": ("réengorger",),
    "réengorge": ("réengorger",),
    "réengorgera": ("réengorger",),
    "réengorgeraient": ("réengorger",),
    "réengorgerai": ("réengorger",),
    "réengorgerais": ("réengorger",),
    "réengorgerait": ("réengorger",),
    "réengorgeras": ("réengorger",),
    "réengorgèrent": ("réengorger",),
    "réengorgerez": ("réengorger",),
    "réengorgeriez": ("réengorger",),
    "réengorgerions": ("réengorger",),
    "réengorgerons": ("réengorger",),
    "réengorgeront": ("réengorger",),
    "réengorgés": ("réengorger",),
    "réengorges": ("réengorger",),
    "réengorgez": ("réengorger",),
    "réengorgiez": ("réengorger",),
    "réengorgions": ("réengorger",),
    "réenlaçaient": ("réenlacer",),
    "réenlaçai": ("réenlacer",),
    "réenlaçais": ("réenlacer",),
    "réenlaçait": ("réenlacer",),
    "réenlaça": ("réenlacer",),
    "réenlaçâmes": ("réenlacer",),
    "réenlaçant": ("réenlacer",),
    "réenlaças": ("réenlacer",),
    "réenlaçassent": ("réenlacer",),
    "réenlaçasses": ("réenlacer",),
    "réenlaçasse": ("réenlacer",),
    "réenlaçassiez": ("réenlacer",),
    "réenlaçassions": ("réenlacer",),
    "réenlaçâtes": ("réenlacer",),
    "réenlaçât": ("réenlacer",),
    "réenlacée": ("réenlacer",),
    "réenlacées": ("réenlacer",),
    "réenlacé": ("réenlacer",),
    "réenlacent": ("réenlacer",),
    "réenlace": ("réenlacer",),
    "réenlacera": ("réenlacer",),
    "réenlaceraient": ("réenlacer",),
    "réenlacerai": ("réenlacer",),
    "réenlacerais": ("réenlacer",),
    "réenlacerait": ("réenlacer",),
    "réenlaceras": ("réenlacer",),
    "réenlacèrent": ("réenlacer",),
    "réenlacerez": ("réenlacer",),
    "réenlaceriez": ("réenlacer",),
    "réenlacerions": ("réenlacer",),
    "réenlacerons": ("réenlacer",),
    "réenlaceront": ("réenlacer",),
    "réenlacés": ("réenlacer",),
    "réenlaces": ("réenlacer",),
    "réenlacez": ("réenlacer",),
    "réenlaciez": ("réenlacer",),
    "réenlacions": ("réenlacer",),
    "réenlaçons": ("réenlacer",),
    "réenneigeaient": ("réenneiger",),
    "réenneigeai": ("réenneiger",),
    "réenneigeais": ("réenneiger",),
    "réenneigeait": ("réenneiger",),
    "réenneigea": ("réenneiger",),
    "réenneigeâmes": ("réenneiger",),
    "réenneigeant": ("réenneiger",),
    "réenneigeas": ("réenneiger",),
    "réenneigeassent": ("réenneiger",),
    "réenneigeasses": ("réenneiger",),
    "réenneigeasse": ("réenneiger",),
    "réenneigeassiez": ("réenneiger",),
    "réenneigeassions": ("réenneiger",),
    "réenneigeâtes": ("réenneiger",),
    "réenneigeât": ("réenneiger",),
    "réenneigée": ("réenneiger",),
    "réenneigées": ("réenneiger",),
    "réenneigé": ("réenneiger",),
    "réenneigent": ("réenneiger",),
    "réenneigeons": ("réenneiger",),
    "réenneige": ("réenneiger",),
    "réenneigera": ("réenneiger",),
    "réenneigeraient": ("réenneiger",),
    "réenneigerai": ("réenneiger",),
    "réenneigerais": ("réenneiger",),
    "réenneigerait": ("réenneiger",),
    "réenneigeras": ("réenneiger",),
    "réenneigèrent": ("réenneiger",),
    "réenneigerez": ("réenneiger",),
    "réenneigeriez": ("réenneiger",),
    "réenneigerions": ("réenneiger",),
    "réenneigerons": ("réenneiger",),
    "réenneigeront": ("réenneiger",),
    "réenneigés": ("réenneiger",),
    "réenneiges": ("réenneiger",),
    "réenneigez": ("réenneiger",),
    "réenneigiez": ("réenneiger",),
    "réenneigions": ("réenneiger",),
    "réénonçaient": ("réénoncer",),
    "réénonçai": ("réénoncer",),
    "réénonçais": ("réénoncer",),
    "réénonçait": ("réénoncer",),
    "réénonça": ("réénoncer",),
    "réénonçâmes": ("réénoncer",),
    "réénonçant": ("réénoncer",),
    "réénonças": ("réénoncer",),
    "réénonçassent": ("réénoncer",),
    "réénonçasses": ("réénoncer",),
    "réénonçasse": ("réénoncer",),
    "réénonçassiez": ("réénoncer",),
    "réénonçassions": ("réénoncer",),
    "réénonçâtes": ("réénoncer",),
    "réénonçât": ("réénoncer",),
    "réénoncée": ("réénoncer",),
    "réénoncées": ("réénoncer",),
    "réénoncé": ("réénoncer",),
    "réénoncent": ("réénoncer",),
    "réénonce": ("réénoncer",),
    "réénoncera": ("réénoncer",),
    "réénonceraient": ("réénoncer",),
    "réénoncerai": ("réénoncer",),
    "réénoncerais": ("réénoncer",),
    "réénoncerait": ("réénoncer",),
    "réénonceras": ("réénoncer",),
    "réénoncèrent": ("réénoncer",),
    "réénoncerez": ("réénoncer",),
    "réénonceriez": ("réénoncer",),
    "réénoncerions": ("réénoncer",),
    "réénoncerons": ("réénoncer",),
    "réénonceront": ("réénoncer",),
    "réénoncés": ("réénoncer",),
    "réénonces": ("réénoncer",),
    "réénoncez": ("réénoncer",),
    "réénonciez": ("réénoncer",),
    "réénoncions": ("réénoncer",),
    "réénonçons": ("réénoncer",),
    "réensemençaient": ("réensemencer",),
    "réensemençai": ("réensemencer",),
    "réensemençais": ("réensemencer",),
    "réensemençait": ("réensemencer",),
    "réensemença": ("réensemencer",),
    "réensemençâmes": ("réensemencer",),
    "réensemençant": ("réensemencer",),
    "réensemenças": ("réensemencer",),
    "réensemençassent": ("réensemencer",),
    "réensemençasses": ("réensemencer",),
    "réensemençasse": ("réensemencer",),
    "réensemençassiez": ("réensemencer",),
    "réensemençassions": ("réensemencer",),
    "réensemençâtes": ("réensemencer",),
    "réensemençât": ("réensemencer",),
    "réensemencée": ("réensemencer",),
    "réensemencées": ("réensemencer",),
    "réensemencé": ("réensemencer",),
    "réensemencent": ("réensemencer",),
    "réensemence": ("réensemencer",),
    "réensemencera": ("réensemencer",),
    "réensemenceraient": ("réensemencer",),
    "réensemencerai": ("réensemencer",),
    "réensemencerais": ("réensemencer",),
    "réensemencerait": ("réensemencer",),
    "réensemenceras": ("réensemencer",),
    "réensemencèrent": ("réensemencer",),
    "réensemencerez": ("réensemencer",),
    "réensemenceriez": ("réensemencer",),
    "réensemencerions": ("réensemencer",),
    "réensemencerons": ("réensemencer",),
    "réensemenceront": ("réensemencer",),
    "réensemencés": ("réensemencer",),
    "réensemences": ("réensemencer",),
    "réensemencez": ("réensemencer",),
    "réensemenciez": ("réensemencer",),
    "réensemencions": ("réensemencer",),
    "réensemençons": ("réensemencer",),
    "réentassaient": ("réentasser",),
    "réentassai": ("réentasser",),
    "réentassais": ("réentasser",),
    "réentassait": ("réentasser",),
    "réentassa": ("réentasser",),
    "réentassâmes": ("réentasser",),
    "réentassant": ("réentasser",),
    "réentassas": ("réentasser",),
    "réentassassent": ("réentasser",),
    "réentassasses": ("réentasser",),
    "réentassasse": ("réentasser",),
    "réentassassiez": ("réentasser",),
    "réentassassions": ("réentasser",),
    "réentassâtes": ("réentasser",),
    "réentassât": ("réentasser",),
    "réentassée": ("réentasser",),
    "réentassées": ("réentasser",),
    "réentassé": ("réentasser",),
    "réentassent": ("réentasser",),
    "réentasse": ("réentasser",),
    "réentassera": ("réentasser",),
    "réentasseraient": ("réentasser",),
    "réentasserai": ("réentasser",),
    "réentasserais": ("réentasser",),
    "réentasserait": ("réentasser",),
    "réentasseras": ("réentasser",),
    "réentassèrent": ("réentasser",),
    "réentasserez": ("réentasser",),
    "réentasseriez": ("réentasser",),
    "réentasserions": ("réentasser",),
    "réentasserons": ("réentasser",),
    "réentasseront": ("réentasser",),
    "réentassés": ("réentasser",),
    "réentasses": ("réentasser",),
    "réentassez": ("réentasser",),
    "réentassiez": ("réentasser",),
    "réentassions": ("réentasser",),
    "réentassons": ("réentasser",),
    "réentendaient": ("réentendre",),
    "réentendais": ("réentendre",),
    "réentendait": ("réentendre",),
    "réentendant": ("réentendre",),
    "réentendent": ("réentendre",),
    "réentende": ("réentendre",),
    "réentendes": ("réentendre",),
    "réentendez": ("réentendre",),
    "réentendiez": ("réentendre",),
    "réentendîmes": ("réentendre",),
    "réentendions": ("réentendre",),
    "réentendirent": ("réentendre",),
    "réentendis": ("réentendre",),
    "réentendissent": ("réentendre",),
    "réentendisses": ("réentendre",),
    "réentendisse": ("réentendre",),
    "réentendissiez": ("réentendre",),
    "réentendissions": ("réentendre",),
    "réentendîtes": ("réentendre",),
    "réentendit": ("réentendre",),
    "réentendît": ("réentendre",),
    "réentendons": ("réentendre",),
    "réentend": ("réentendre",),
    "réentendra": ("réentendre",),
    "réentendraient": ("réentendre",),
    "réentendrai": ("réentendre",),
    "réentendrais": ("réentendre",),
    "réentendrait": ("réentendre",),
    "réentendras": ("réentendre",),
    "réentendrez": ("réentendre",),
    "réentendriez": ("réentendre",),
    "réentendrions": ("réentendre",),
    "réentendrons": ("réentendre",),
    "réentendront": ("réentendre",),
    "réentends": ("réentendre",),
    "réentendue": ("réentendre",),
    "réentendues": ("réentendre",),
    "réentendu": ("réentendre",),
    "réentendus": ("réentendre",),
    "réénuméraient": ("réénumérer",),
    "réénumérai": ("réénumérer",),
    "réénumérais": ("réénumérer",),
    "réénumérait": ("réénumérer",),
    "réénuméra": ("réénumérer",),
    "réénumérâmes": ("réénumérer",),
    "réénumérant": ("réénumérer",),
    "réénuméras": ("réénumérer",),
    "réénumérassent": ("réénumérer",),
    "réénumérasses": ("réénumérer",),
    "réénumérasse": ("réénumérer",),
    "réénumérassiez": ("réénumérer",),
    "réénumérassions": ("réénumérer",),
    "réénumérâtes": ("réénumérer",),
    "réénumérât": ("réénumérer",),
    "réénumérée": ("réénumérer",),
    "réénumérées": ("réénumérer",),
    "réénuméré": ("réénumérer",),
    "réénumèrent": ("réénumérer",),
    "réénumère": ("réénumérer",),
    "réénumérera": ("réénumérer",),
    "réénuméreraient": ("réénumérer",),
    "réénumérerai": ("réénumérer",),
    "réénumérerais": ("réénumérer",),
    "réénumérerait": ("réénumérer",),
    "réénuméreras": ("réénumérer",),
    "réénumérèrent": ("réénumérer",),
    "réénumérerez": ("réénumérer",),
    "réénuméreriez": ("réénumérer",),
    "réénumérerions": ("réénumérer",),
    "réénumérerons": ("réénumérer",),
    "réénuméreront": ("réénumérer",),
    "réénumérés": ("réénumérer",),
    "réénumères": ("réénumérer",),
    "réénumérez": ("réénumérer",),
    "réénumériez": ("réénumérer",),
    "réénumérions": ("réénumérer",),
    "réénumérons": ("réénumérer",),
    "réenvahie": ("réenvahir",),
    "réenvahies": ("réenvahir",),
    "réenvahi": ("réenvahir",),
    "réenvahîmes": ("réenvahir",),
    "réenvahira": ("réenvahir",),
    "réenvahiraient": ("réenvahir",),
    "réenvahirai": ("réenvahir",),
    "réenvahirais": ("réenvahir",),
    "réenvahirait": ("réenvahir",),
    "réenvahiras": ("réenvahir",),
    "réenvahirent": ("réenvahir",),
    "réenvahirez": ("réenvahir",),
    "réenvahiriez": ("réenvahir",),
    "réenvahirions": ("réenvahir",),
    "réenvahirons": ("réenvahir",),
    "réenvahiront": ("réenvahir",),
    "réenvahis": ("réenvahir",),
    "réenvahissaient": ("réenvahir",),
    "réenvahissais": ("réenvahir",),
    "réenvahissait": ("réenvahir",),
    "réenvahissant": ("réenvahir",),
    "réenvahissent": ("réenvahir",),
    "réenvahisse": ("réenvahir",),
    "réenvahisses": ("réenvahir",),
    "réenvahissez": ("réenvahir",),
    "réenvahissiez": ("réenvahir",),
    "réenvahissions": ("réenvahir",),
    "réenvahissons": ("réenvahir",),
    "réenvahîtes": ("réenvahir",),
    "réenvahit": ("réenvahir",),
    "réenvahît": ("réenvahir",),
    "réenvisageaient": ("réenvisager",),
    "réenvisageai": ("réenvisager",),
    "réenvisageais": ("réenvisager",),
    "réenvisageait": ("réenvisager",),
    "réenvisagea": ("réenvisager",),
    "réenvisageâmes": ("réenvisager",),
    "réenvisageant": ("réenvisager",),
    "réenvisageas": ("réenvisager",),
    "réenvisageassent": ("réenvisager",),
    "réenvisageasses": ("réenvisager",),
    "réenvisageasse": ("réenvisager",),
    "réenvisageassiez": ("réenvisager",),
    "réenvisageassions": ("réenvisager",),
    "réenvisageâtes": ("réenvisager",),
    "réenvisageât": ("réenvisager",),
    "réenvisagée": ("réenvisager",),
    "réenvisagées": ("réenvisager",),
    "réenvisagé": ("réenvisager",),
    "réenvisagent": ("réenvisager",),
    "réenvisageons": ("réenvisager",),
    "réenvisage": ("réenvisager",),
    "réenvisagera": ("réenvisager",),
    "réenvisageraient": ("réenvisager",),
    "réenvisagerai": ("réenvisager",),
    "réenvisagerais": ("réenvisager",),
    "réenvisagerait": ("réenvisager",),
    "réenvisageras": ("réenvisager",),
    "réenvisagèrent": ("réenvisager",),
    "réenvisagerez": ("réenvisager",),
    "réenvisageriez": ("réenvisager",),
    "réenvisagerions": ("réenvisager",),
    "réenvisagerons": ("réenvisager",),
    "réenvisageront": ("réenvisager",),
    "réenvisagés": ("réenvisager",),
    "réenvisages": ("réenvisager",),
    "réenvisagez": ("réenvisager",),
    "réenvisagiez": ("réenvisager",),
    "réenvisagions": ("réenvisager",),
    "réenverra": ("réenvoyer",),
    "réenverraient": ("réenvoyer",),
    "réenverrai": ("réenvoyer",),
    "réenverrais": ("réenvoyer",),
    "réenverrait": ("réenvoyer",),
    "réenverras": ("réenvoyer",),
    "réenverrez": ("réenvoyer",),
    "réenverriez": ("réenvoyer",),
    "réenverrions": ("réenvoyer",),
    "réenverrons": ("réenvoyer",),
    "réenverront": ("réenvoyer",),
    "réenvoient": ("réenvoyer",),
    "réenvoie": ("réenvoyer",),
    "réenvoies": ("réenvoyer",),
    "réenvoyaient": ("réenvoyer",),
    "réenvoyai": ("réenvoyer",),
    "réenvoyais": ("réenvoyer",),
    "réenvoyait": ("réenvoyer",),
    "réenvoya": ("réenvoyer",),
    "réenvoyâmes": ("réenvoyer",),
    "réenvoyant": ("réenvoyer",),
    "réenvoyas": ("réenvoyer",),
    "réenvoyassent": ("réenvoyer",),
    "réenvoyasses": ("réenvoyer",),
    "réenvoyasse": ("réenvoyer",),
    "réenvoyassiez": ("réenvoyer",),
    "réenvoyassions": ("réenvoyer",),
    "réenvoyâtes": ("réenvoyer",),
    "réenvoyât": ("réenvoyer",),
    "réenvoyée": ("réenvoyer",),
    "réenvoyées": ("réenvoyer",),
    "réenvoyé": ("réenvoyer",),
    "réenvoyèrent": ("réenvoyer",),
    "réenvoyés": ("réenvoyer",),
    "réenvoyez": ("réenvoyer",),
    "réenvoyiez": ("réenvoyer",),
    "réenvoyions": ("réenvoyer",),
    "réenvoyons": ("réenvoyer",),
    "réépelaient": ("réépeler",),
    "réépelai": ("réépeler",),
    "réépelais": ("réépeler",),
    "réépelait": ("réépeler",),
    "réépela": ("réépeler",),
    "réépelâmes": ("réépeler",),
    "réépelant": ("réépeler",),
    "réépelas": ("réépeler",),
    "réépelassent": ("réépeler",),
    "réépelasses": ("réépeler",),
    "réépelasse": ("réépeler",),
    "réépelassiez": ("réépeler",),
    "réépelassions": ("réépeler",),
    "réépelâtes": ("réépeler",),
    "réépelât": ("réépeler",),
    "réépelée": ("réépeler",),
    "réépelées": ("réépeler",),
    "réépelé": ("réépeler",),
    "réépelèrent": ("réépeler",),
    "réépelés": ("réépeler",),
    "réépelez": ("réépeler",),
    "réépeliez": ("réépeler",),
    "réépelions": ("réépeler",),
    "réépellent": ("réépeler",),
    "réépelle": ("réépeler",),
    "réépellera": ("réépeler",),
    "réépelleraient": ("réépeler",),
    "réépellerai": ("réépeler",),
    "réépellerais": ("réépeler",),
    "réépellerait": ("réépeler",),
    "réépelleras": ("réépeler",),
    "réépellerez": ("réépeler",),
    "réépelleriez": ("réépeler",),
    "réépellerions": ("réépeler",),
    "réépellerons": ("réépeler",),
    "réépelleront": ("réépeler",),
    "réépelles": ("réépeler",),
    "réépelons": ("réépeler",),
    "réépiçaient": ("réépicer",),
    "réépiçai": ("réépicer",),
    "réépiçais": ("réépicer",),
    "réépiçait": ("réépicer",),
    "réépiça": ("réépicer",),
    "réépiçâmes": ("réépicer",),
    "réépiçant": ("réépicer",),
    "réépiças": ("réépicer",),
    "réépiçassent": ("réépicer",),
    "réépiçasses": ("réépicer",),
    "réépiçasse": ("réépicer",),
    "réépiçassiez": ("réépicer",),
    "réépiçassions": ("réépicer",),
    "réépiçâtes": ("réépicer",),
    "réépiçât": ("réépicer",),
    "réépicée": ("réépicer",),
    "réépicées": ("réépicer",),
    "réépicé": ("réépicer",),
    "réépicent": ("réépicer",),
    "réépice": ("réépicer",),
    "réépicera": ("réépicer",),
    "réépiceraient": ("réépicer",),
    "réépicerai": ("réépicer",),
    "réépicerais": ("réépicer",),
    "réépicerait": ("réépicer",),
    "réépiceras": ("réépicer",),
    "réépicèrent": ("réépicer",),
    "réépicerez": ("réépicer",),
    "réépiceriez": ("réépicer",),
    "réépicerions": ("réépicer",),
    "réépicerons": ("réépicer",),
    "réépiceront": ("réépicer",),
    "réépicés": ("réépicer",),
    "réépices": ("réépicer",),
    "réépicez": ("réépicer",),
    "réépiciez": ("réépicer",),
    "réépicions": ("réépicer",),
    "réépiçons": ("réépicer",),
    "réépongeaient": ("rééponger",),
    "réépongeai": ("rééponger",),
    "réépongeais": ("rééponger",),
    "réépongeait": ("rééponger",),
    "réépongea": ("rééponger",),
    "réépongeâmes": ("rééponger",),
    "réépongeant": ("rééponger",),
    "réépongeas": ("rééponger",),
    "réépongeassent": ("rééponger",),
    "réépongeasses": ("rééponger",),
    "réépongeasse": ("rééponger",),
    "réépongeassiez": ("rééponger",),
    "réépongeassions": ("rééponger",),
    "réépongeâtes": ("rééponger",),
    "réépongeât": ("rééponger",),
    "réépongée": ("rééponger",),
    "réépongées": ("rééponger",),
    "réépongé": ("rééponger",),
    "réépongent": ("rééponger",),
    "réépongeons": ("rééponger",),
    "rééponge": ("rééponger",),
    "réépongera": ("rééponger",),
    "réépongeraient": ("rééponger",),
    "réépongerai": ("rééponger",),
    "réépongerais": ("rééponger",),
    "réépongerait": ("rééponger",),
    "réépongeras": ("rééponger",),
    "réépongèrent": ("rééponger",),
    "réépongerez": ("rééponger",),
    "réépongeriez": ("rééponger",),
    "réépongerions": ("rééponger",),
    "réépongerons": ("rééponger",),
    "réépongeront": ("rééponger",),
    "réépongés": ("rééponger",),
    "rééponges": ("rééponger",),
    "réépongez": ("rééponger",),
    "réépongiez": ("rééponger",),
    "réépongions": ("rééponger",),
    "réépuçaient": ("réépucer",),
    "réépuçai": ("réépucer",),
    "réépuçais": ("réépucer",),
    "réépuçait": ("réépucer",),
    "réépuça": ("réépucer",),
    "réépuçâmes": ("réépucer",),
    "réépuçant": ("réépucer",),
    "réépuças": ("réépucer",),
    "réépuçassent": ("réépucer",),
    "réépuçasses": ("réépucer",),
    "réépuçasse": ("réépucer",),
    "réépuçassiez": ("réépucer",),
    "réépuçassions": ("réépucer",),
    "réépuçâtes": ("réépucer",),
    "réépuçât": ("réépucer",),
    "réépucée": ("réépucer",),
    "réépucées": ("réépucer",),
    "réépucé": ("réépucer",),
    "réépucent": ("réépucer",),
    "réépuce": ("réépucer",),
    "réépucera": ("réépucer",),
    "réépuceraient": ("réépucer",),
    "réépucerai": ("réépucer",),
    "réépucerais": ("réépucer",),
    "réépucerait": ("réépucer",),
    "réépuceras": ("réépucer",),
    "réépucèrent": ("réépucer",),
    "réépucerez": ("réépucer",),
    "réépuceriez": ("réépucer",),
    "réépucerions": ("réépucer",),
    "réépucerons": ("réépucer",),
    "réépuceront": ("réépucer",),
    "réépucés": ("réépucer",),
    "réépuces": ("réépucer",),
    "réépucez": ("réépucer",),
    "réépuciez": ("réépucer",),
    "réépucions": ("réépucer",),
    "réépuçons": ("réépucer",),
    "réaient": ("réer",),
    "réai": ("réer",),
    "réais": ("réer",),
    "réait": ("réer",),
    "réa": ("réer",),
    "réâmes": ("réer",),
    "réant": ("réer",),
    "réas": ("réer",),
    "réassent": ("réer",),
    "réasses": ("réer",),
    "réasse": ("réer",),
    "réassiez": ("réer",),
    "réassions": ("réer",),
    "réâtes": ("réer",),
    "réât": ("réer",),
    "réée": ("réer",),
    "réées": ("réer",),
    "réé": ("réer",),
    "réent": ("réer",),
    "rée": ("réer",),
    "réera": ("réer",),
    "réeraient": ("réer",),
    "réerai": ("réer",),
    "réerais": ("réer",),
    "réerait": ("réer",),
    "réeras": ("réer",),
    "réèrent": ("réer",),
    "réerez": ("réer",),
    "réeriez": ("réer",),
    "réerions": ("réer",),
    "réerons": ("réer",),
    "réeront": ("réer",),
    "réés": ("réer",),
    "rées": ("réer",),
    "réez": ("réer",),
    "réiez": ("réer",),
    "réions": ("réer",),
    "réons": ("réer",),
    "réespaçaient": ("réespacer",),
    "réespaçai": ("réespacer",),
    "réespaçais": ("réespacer",),
    "réespaçait": ("réespacer",),
    "réespaça": ("réespacer",),
    "réespaçâmes": ("réespacer",),
    "réespaçant": ("réespacer",),
    "réespaças": ("réespacer",),
    "réespaçassent": ("réespacer",),
    "réespaçasses": ("réespacer",),
    "réespaçasse": ("réespacer",),
    "réespaçassiez": ("réespacer",),
    "réespaçassions": ("réespacer",),
    "réespaçâtes": ("réespacer",),
    "réespaçât": ("réespacer",),
    "réespacée": ("réespacer",),
    "réespacées": ("réespacer",),
    "réespacé": ("réespacer",),
    "réespacent": ("réespacer",),
    "réespace": ("réespacer",),
    "réespacera": ("réespacer",),
    "réespaceraient": ("réespacer",),
    "réespacerai": ("réespacer",),
    "réespacerais": ("réespacer",),
    "réespacerait": ("réespacer",),
    "réespaceras": ("réespacer",),
    "réespacèrent": ("réespacer",),
    "réespacerez": ("réespacer",),
    "réespaceriez": ("réespacer",),
    "réespacerions": ("réespacer",),
    "réespacerons": ("réespacer",),
    "réespaceront": ("réespacer",),
    "réespacés": ("réespacer",),
    "réespaces": ("réespacer",),
    "réespacez": ("réespacer",),
    "réespaciez": ("réespacer",),
    "réespacions": ("réespacer",),
    "réespaçons": ("réespacer",),
    "réessaient": ("réessayer",),
    "réessaie": ("réessayer",),
    "réessaiera": ("réessayer",),
    "réessaieraient": ("réessayer",),
    "réessaierai": ("réessayer",),
    "réessaierais": ("réessayer",),
    "réessaierait": ("réessayer",),
    "réessaieras": ("réessayer",),
    "réessaierez": ("réessayer",),
    "réessaieriez": ("réessayer",),
    "réessaierions": ("réessayer",),
    "réessaierons": ("réessayer",),
    "réessaieront": ("réessayer",),
    "réessaies": ("réessayer",),
    "réessayaient": ("réessayer",),
    "réessayai": ("réessayer",),
    "réessayais": ("réessayer",),
    "réessayait": ("réessayer",),
    "réessaya": ("réessayer",),
    "réessayâmes": ("réessayer",),
    "réessayant": ("réessayer",),
    "réessayas": ("réessayer",),
    "réessayassent": ("réessayer",),
    "réessayasses": ("réessayer",),
    "réessayasse": ("réessayer",),
    "réessayassiez": ("réessayer",),
    "réessayassions": ("réessayer",),
    "réessayâtes": ("réessayer",),
    "réessayât": ("réessayer",),
    "réessayée": ("réessayer",),
    "réessayées": ("réessayer",),
    "réessayé": ("réessayer",),
    "réessayent": ("réessayer",),
    "réessaye": ("réessayer",),
    "réessayera": ("réessayer",),
    "réessayeraient": ("réessayer",),
    "réessayerai": ("réessayer",),
    "réessayerais": ("réessayer",),
    "réessayerait": ("réessayer",),
    "réessayeras": ("réessayer",),
    "réessayèrent": ("réessayer",),
    "réessayerez": ("réessayer",),
    "réessayeriez": ("réessayer",),
    "réessayerions": ("réessayer",),
    "réessayerons": ("réessayer",),
    "réessayeront": ("réessayer",),
    "réessayés": ("réessayer",),
    "réessayes": ("réessayer",),
    "réessayez": ("réessayer",),
    "réessayiez": ("réessayer",),
    "réessayions": ("réessayer",),
    "réessayons": ("réessayer",),
    "réessuient": ("réessuyer",),
    "réessuie": ("réessuyer",),
    "réessuiera": ("réessuyer",),
    "réessuieraient": ("réessuyer",),
    "réessuierai": ("réessuyer",),
    "réessuierais": ("réessuyer",),
    "réessuierait": ("réessuyer",),
    "réessuieras": ("réessuyer",),
    "réessuierez": ("réessuyer",),
    "réessuieriez": ("réessuyer",),
    "réessuierions": ("réessuyer",),
    "réessuierons": ("réessuyer",),
    "réessuieront": ("réessuyer",),
    "réessuies": ("réessuyer",),
    "réessuyaient": ("réessuyer",),
    "réessuyai": ("réessuyer",),
    "réessuyais": ("réessuyer",),
    "réessuyait": ("réessuyer",),
    "réessuya": ("réessuyer",),
    "réessuyâmes": ("réessuyer",),
    "réessuyant": ("réessuyer",),
    "réessuyas": ("réessuyer",),
    "réessuyassent": ("réessuyer",),
    "réessuyasses": ("réessuyer",),
    "réessuyasse": ("réessuyer",),
    "réessuyassiez": ("réessuyer",),
    "réessuyassions": ("réessuyer",),
    "réessuyâtes": ("réessuyer",),
    "réessuyât": ("réessuyer",),
    "réessuyée": ("réessuyer",),
    "réessuyées": ("réessuyer",),
    "réessuyé": ("réessuyer",),
    "réessuyèrent": ("réessuyer",),
    "réessuyés": ("réessuyer",),
    "réessuyez": ("réessuyer",),
    "réessuyiez": ("réessuyer",),
    "réessuyions": ("réessuyer",),
    "réessuyons": ("réessuyer",),
    "réestérifiaient": ("réestérifier",),
    "réestérifiai": ("réestérifier",),
    "réestérifiais": ("réestérifier",),
    "réestérifiait": ("réestérifier",),
    "réestérifia": ("réestérifier",),
    "réestérifiâmes": ("réestérifier",),
    "réestérifiant": ("réestérifier",),
    "réestérifias": ("réestérifier",),
    "réestérifiassent": ("réestérifier",),
    "réestérifiasses": ("réestérifier",),
    "réestérifiasse": ("réestérifier",),
    "réestérifiassiez": ("réestérifier",),
    "réestérifiassions": ("réestérifier",),
    "réestérifiâtes": ("réestérifier",),
    "réestérifiât": ("réestérifier",),
    "réestérifiée": ("réestérifier",),
    "réestérifiées": ("réestérifier",),
    "réestérifié": ("réestérifier",),
    "réestérifient": ("réestérifier",),
    "réestérifie": ("réestérifier",),
    "réestérifiera": ("réestérifier",),
    "réestérifieraient": ("réestérifier",),
    "réestérifierai": ("réestérifier",),
    "réestérifierais": ("réestérifier",),
    "réestérifierait": ("réestérifier",),
    "réestérifieras": ("réestérifier",),
    "réestérifièrent": ("réestérifier",),
    "réestérifierez": ("réestérifier",),
    "réestérifieriez": ("réestérifier",),
    "réestérifierions": ("réestérifier",),
    "réestérifierons": ("réestérifier",),
    "réestérifieront": ("réestérifier",),
    "réestérifiés": ("réestérifier",),
    "réestérifies": ("réestérifier",),
    "réestérifiez": ("réestérifier",),
    "réestérifiiez": ("réestérifier",),
    "réestérifiions": ("réestérifier",),
    "réestérifions": ("réestérifier",),
    "réétablie": ("réétablir",),
    "réétablies": ("réétablir",),
    "réétabli": ("réétablir",),
    "réétablîmes": ("réétablir",),
    "réétablira": ("réétablir",),
    "réétabliraient": ("réétablir",),
    "réétablirai": ("réétablir",),
    "réétablirais": ("réétablir",),
    "réétablirait": ("réétablir",),
    "réétabliras": ("réétablir",),
    "réétablirent": ("réétablir",),
    "réétablirez": ("réétablir",),
    "réétabliriez": ("réétablir",),
    "réétablirions": ("réétablir",),
    "réétablirons": ("réétablir",),
    "réétabliront": ("réétablir",),
    "réétablis": ("réétablir",),
    "réétablissaient": ("réétablir",),
    "réétablissais": ("réétablir",),
    "réétablissait": ("réétablir",),
    "réétablissant": ("réétablir",),
    "réétablissent": ("réétablir",),
    "réétablisse": ("réétablir",),
    "réétablisses": ("réétablir",),
    "réétablissez": ("réétablir",),
    "réétablissiez": ("réétablir",),
    "réétablissions": ("réétablir",),
    "réétablissons": ("réétablir",),
    "réétablîtes": ("réétablir",),
    "réétablit": ("réétablir",),
    "réétablît": ("réétablir",),
    "réétageaient": ("réétager",),
    "réétageai": ("réétager",),
    "réétageais": ("réétager",),
    "réétageait": ("réétager",),
    "réétagea": ("réétager",),
    "réétageâmes": ("réétager",),
    "réétageant": ("réétager",),
    "réétageas": ("réétager",),
    "réétageassent": ("réétager",),
    "réétageasses": ("réétager",),
    "réétageasse": ("réétager",),
    "réétageassiez": ("réétager",),
    "réétageassions": ("réétager",),
    "réétageâtes": ("réétager",),
    "réétageât": ("réétager",),
    "réétagée": ("réétager",),
    "réétagées": ("réétager",),
    "réétagé": ("réétager",),
    "réétagent": ("réétager",),
    "réétageons": ("réétager",),
    "réétage": ("réétager",),
    "réétagera": ("réétager",),
    "réétageraient": ("réétager",),
    "réétagerai": ("réétager",),
    "réétagerais": ("réétager",),
    "réétagerait": ("réétager",),
    "réétageras": ("réétager",),
    "réétagèrent": ("réétager",),
    "réétagerez": ("réétager",),
    "réétageriez": ("réétager",),
    "réétagerions": ("réétager",),
    "réétagerons": ("réétager",),
    "réétageront": ("réétager",),
    "réétagés": ("réétager",),
    "réétages": ("réétager",),
    "réétagez": ("réétager",),
    "réétagiez": ("réétager",),
    "réétagions": ("réétager",),
    "réétiquetaient": ("réétiqueter",),
    "réétiquetai": ("réétiqueter",),
    "réétiquetais": ("réétiqueter",),
    "réétiquetait": ("réétiqueter",),
    "réétiqueta": ("réétiqueter",),
    "réétiquetâmes": ("réétiqueter",),
    "réétiquetant": ("réétiqueter",),
    "réétiquetas": ("réétiqueter",),
    "réétiquetassent": ("réétiqueter",),
    "réétiquetasses": ("réétiqueter",),
    "réétiquetasse": ("réétiqueter",),
    "réétiquetassiez": ("réétiqueter",),
    "réétiquetassions": ("réétiqueter",),
    "réétiquetâtes": ("réétiqueter",),
    "réétiquetât": ("réétiqueter",),
    "réétiquetée": ("réétiqueter",),
    "réétiquetées": ("réétiqueter",),
    "réétiqueté": ("réétiqueter",),
    "réétiquetèrent": ("réétiqueter",),
    "réétiquetés": ("réétiqueter",),
    "réétiquetez": ("réétiqueter",),
    "réétiquetiez": ("réétiqueter",),
    "réétiquetions": ("réétiqueter",),
    "réétiquetons": ("réétiqueter",),
    "réétiquettent": ("réétiqueter",),
    "réétiquette": ("réétiqueter",),
    "réétiquettera": ("réétiqueter",),
    "réétiquetteraient": ("réétiqueter",),
    "réétiquetterai": ("réétiqueter",),
    "réétiquetterais": ("réétiqueter",),
    "réétiquetterait": ("réétiqueter",),
    "réétiquetteras": ("réétiqueter",),
    "réétiquetterez": ("réétiqueter",),
    "réétiquetteriez": ("réétiqueter",),
    "réétiquetterions": ("réétiqueter",),
    "réétiquetterons": ("réétiqueter",),
    "réétiquetteront": ("réétiqueter",),
    "réétiquettes": ("réétiqueter",),
    "réétudiaient": ("réétudier",),
    "réétudiai": ("réétudier",),
    "réétudiais": ("réétudier",),
    "réétudiait": ("réétudier",),
    "réétudia": ("réétudier",),
    "réétudiâmes": ("réétudier",),
    "réétudiant": ("réétudier",),
    "réétudias": ("réétudier",),
    "réétudiassent": ("réétudier",),
    "réétudiasses": ("réétudier",),
    "réétudiasse": ("réétudier",),
    "réétudiassiez": ("réétudier",),
    "réétudiassions": ("réétudier",),
    "réétudiâtes": ("réétudier",),
    "réétudiât": ("réétudier",),
    "réétudiée": ("réétudier",),
    "réétudiées": ("réétudier",),
    "réétudié": ("réétudier",),
    "réétudient": ("réétudier",),
    "réétudie": ("réétudier",),
    "réétudiera": ("réétudier",),
    "réétudieraient": ("réétudier",),
    "réétudierai": ("réétudier",),
    "réétudierais": ("réétudier",),
    "réétudierait": ("réétudier",),
    "réétudieras": ("réétudier",),
    "réétudièrent": ("réétudier",),
    "réétudierez": ("réétudier",),
    "réétudieriez": ("réétudier",),
    "réétudierions": ("réétudier",),
    "réétudierons": ("réétudier",),
    "réétudieront": ("réétudier",),
    "réétudiés": ("réétudier",),
    "réétudies": ("réétudier",),
    "réétudiez": ("réétudier",),
    "réétudiiez": ("réétudier",),
    "réétudiions": ("réétudier",),
    "réétudions": ("réétudier",),
    "réévinçaient": ("réévincer",),
    "réévinçai": ("réévincer",),
    "réévinçais": ("réévincer",),
    "réévinçait": ("réévincer",),
    "réévinça": ("réévincer",),
    "réévinçâmes": ("réévincer",),
    "réévinçant": ("réévincer",),
    "réévinças": ("réévincer",),
    "réévinçassent": ("réévincer",),
    "réévinçasses": ("réévincer",),
    "réévinçasse": ("réévincer",),
    "réévinçassiez": ("réévincer",),
    "réévinçassions": ("réévincer",),
    "réévinçâtes": ("réévincer",),
    "réévinçât": ("réévincer",),
    "réévincée": ("réévincer",),
    "réévincées": ("réévincer",),
    "réévincé": ("réévincer",),
    "réévincent": ("réévincer",),
    "réévince": ("réévincer",),
    "réévincera": ("réévincer",),
    "réévinceraient": ("réévincer",),
    "réévincerai": ("réévincer",),
    "réévincerais": ("réévincer",),
    "réévincerait": ("réévincer",),
    "réévinceras": ("réévincer",),
    "réévincèrent": ("réévincer",),
    "réévincerez": ("réévincer",),
    "réévinceriez": ("réévincer",),
    "réévincerions": ("réévincer",),
    "réévincerons": ("réévincer",),
    "réévinceront": ("réévincer",),
    "réévincés": ("réévincer",),
    "réévinces": ("réévincer",),
    "réévincez": ("réévincer",),
    "réévinciez": ("réévincer",),
    "réévincions": ("réévincer",),
    "réévinçons": ("réévincer",),
    "réexerçaient": ("réexercer",),
    "réexerçai": ("réexercer",),
    "réexerçais": ("réexercer",),
    "réexerçait": ("réexercer",),
    "réexerça": ("réexercer",),
    "réexerçâmes": ("réexercer",),
    "réexerçant": ("réexercer",),
    "réexerças": ("réexercer",),
    "réexerçassent": ("réexercer",),
    "réexerçasses": ("réexercer",),
    "réexerçasse": ("réexercer",),
    "réexerçassiez": ("réexercer",),
    "réexerçassions": ("réexercer",),
    "réexerçâtes": ("réexercer",),
    "réexerçât": ("réexercer",),
    "réexercée": ("réexercer",),
    "réexercées": ("réexercer",),
    "réexercé": ("réexercer",),
    "réexercent": ("réexercer",),
    "réexerce": ("réexercer",),
    "réexercera": ("réexercer",),
    "réexerceraient": ("réexercer",),
    "réexercerai": ("réexercer",),
    "réexercerais": ("réexercer",),
    "réexercerait": ("réexercer",),
    "réexerceras": ("réexercer",),
    "réexercèrent": ("réexercer",),
    "réexercerez": ("réexercer",),
    "réexerceriez": ("réexercer",),
    "réexercerions": ("réexercer",),
    "réexercerons": ("réexercer",),
    "réexerceront": ("réexercer",),
    "réexercés": ("réexercer",),
    "réexerces": ("réexercer",),
    "réexercez": ("réexercer",),
    "réexerciez": ("réexercer",),
    "réexercions": ("réexercer",),
    "réexerçons": ("réexercer",),
    "réexpédiaient": ("réexpédier",),
    "réexpédiai": ("réexpédier",),
    "réexpédiais": ("réexpédier",),
    "réexpédiait": ("réexpédier",),
    "réexpédia": ("réexpédier",),
    "réexpédiâmes": ("réexpédier",),
    "réexpédiant": ("réexpédier",),
    "réexpédias": ("réexpédier",),
    "réexpédiassent": ("réexpédier",),
    "réexpédiasses": ("réexpédier",),
    "réexpédiasse": ("réexpédier",),
    "réexpédiassiez": ("réexpédier",),
    "réexpédiassions": ("réexpédier",),
    "réexpédiâtes": ("réexpédier",),
    "réexpédiât": ("réexpédier",),
    "réexpédiée": ("réexpédier",),
    "réexpédiées": ("réexpédier",),
    "réexpédié": ("réexpédier",),
    "réexpédient": ("réexpédier",),
    "réexpédie": ("réexpédier",),
    "réexpédiera": ("réexpédier",),
    "réexpédieraient": ("réexpédier",),
    "réexpédierai": ("réexpédier",),
    "réexpédierais": ("réexpédier",),
    "réexpédierait": ("réexpédier",),
    "réexpédieras": ("réexpédier",),
    "réexpédièrent": ("réexpédier",),
    "réexpédierez": ("réexpédier",),
    "réexpédieriez": ("réexpédier",),
    "réexpédierions": ("réexpédier",),
    "réexpédierons": ("réexpédier",),
    "réexpédieront": ("réexpédier",),
    "réexpédiés": ("réexpédier",),
    "réexpédies": ("réexpédier",),
    "réexpédiez": ("réexpédier",),
    "réexpédiiez": ("réexpédier",),
    "réexpédiions": ("réexpédier",),
    "réexpédions": ("réexpédier",),
    "refaisaient": ("refaire",),
    "refaisais": ("refaire",),
    "refaisait": ("refaire",),
    "refaisant": ("refaire",),
    "refaisiez": ("refaire",),
    "refaisions": ("refaire",),
    "refaisons": ("refaire",),
    "refais": ("refaire",),
    "refaite": ("refaire",),
    "refaites": ("refaire",),
    "refait": ("refaire",),
    "refaits": ("refaire",),
    "refassent": ("refaire",),
    "refasse": ("refaire",),
    "refasses": ("refaire",),
    "refassiez": ("refaire",),
    "refassions": ("refaire",),
    "refera": ("refaire",),
    "referaient": ("refaire",),
    "referai": ("refaire",),
    "referais": ("refaire",),
    "referait": ("refaire",),
    "referas": ("refaire",),
    "referez": ("refaire",),
    "referiez": ("refaire",),
    "referions": ("refaire",),
    "referons": ("refaire",),
    "referont": ("refaire",),
    "refîmes": ("refaire",),
    "refirent": ("refaire",),
    "refis": ("refaire",),
    "refissent": ("refaire",),
    "refisses": ("refaire",),
    "refisse": ("refaire",),
    "refissiez": ("refaire",),
    "refissions": ("refaire",),
    "refîtes": ("refaire",),
    "refit": ("refaire",),
    "refît": ("refaire",),
    "refont": ("refaire",),
    "refaille": ("refalloir",),
    "refallait": ("refalloir",),
    "refallu": ("refalloir",),
    "refallut": ("refalloir",),
    "refallût": ("refalloir",),
    "refaudra": ("refalloir",),
    "refaudrait": ("refalloir",),
    "refaut": ("refalloir",),
    "reféaient": ("reféer",),
    "reféai": ("reféer",),
    "reféais": ("reféer",),
    "reféait": ("reféer",),
    "reféa": ("reféer",),
    "reféâmes": ("reféer",),
    "reféant": ("reféer",),
    "reféas": ("reféer",),
    "reféassent": ("reféer",),
    "reféasses": ("reféer",),
    "reféasse": ("reféer",),
    "reféassiez": ("reféer",),
    "reféassions": ("reféer",),
    "reféâtes": ("reféer",),
    "reféât": ("reféer",),
    "reféée": ("reféer",),
    "reféées": ("reféer",),
    "reféé": ("reféer",),
    "reféent": ("reféer",),
    "refée": ("reféer",),
    "reféera": ("reféer",),
    "reféeraient": ("reféer",),
    "reféerai": ("reféer",),
    "reféerais": ("reféer",),
    "reféerait": ("reféer",),
    "reféeras": ("reféer",),
    "reféèrent": ("reféer",),
    "reféerez": ("reféer",),
    "reféeriez": ("reféer",),
    "reféerions": ("reféer",),
    "reféerons": ("reféer",),
    "reféeront": ("reféer",),
    "reféés": ("reféer",),
    "refées": ("reféer",),
    "reféez": ("reféer",),
    "reféiez": ("reféer",),
    "reféions": ("reféer",),
    "reféons": ("reféer",),
    "refendaient": ("refendre",),
    "refendais": ("refendre",),
    "refendait": ("refendre",),
    "refendant": ("refendre",),
    "refendent": ("refendre",),
    "refende": ("refendre",),
    "refendes": ("refendre",),
    "refendez": ("refendre",),
    "refendiez": ("refendre",),
    "refendîmes": ("refendre",),
    "refendions": ("refendre",),
    "refendirent": ("refendre",),
    "refendis": ("refendre",),
    "refendissent": ("refendre",),
    "refendisses": ("refendre",),
    "refendisse": ("refendre",),
    "refendissiez": ("refendre",),
    "refendissions": ("refendre",),
    "refendîtes": ("refendre",),
    "refendit": ("refendre",),
    "refendît": ("refendre",),
    "refendons": ("refendre",),
    "refend": ("refendre",),
    "refendra": ("refendre",),
    "refendraient": ("refendre",),
    "refendrai": ("refendre",),
    "refendrais": ("refendre",),
    "refendrait": ("refendre",),
    "refendras": ("refendre",),
    "refendrez": ("refendre",),
    "refendriez": ("refendre",),
    "refendrions": ("refendre",),
    "refendrons": ("refendre",),
    "refendront": ("refendre",),
    "refends": ("refendre",),
    "refendue": ("refendre",),
    "refendues": ("refendre",),
    "refendu": ("refendre",),
    "refendus": ("refendre",),
    "référençaient": ("référencer",),
    "référençai": ("référencer",),
    "référençais": ("référencer",),
    "référençait": ("référencer",),
    "référença": ("référencer",),
    "référençâmes": ("référencer",),
    "référençant": ("référencer",),
    "référenças": ("référencer",),
    "référençassent": ("référencer",),
    "référençasses": ("référencer",),
    "référençasse": ("référencer",),
    "référençassiez": ("référencer",),
    "référençassions": ("référencer",),
    "référençâtes": ("référencer",),
    "référençât": ("référencer",),
    "référencée": ("référencer",),
    "référencées": ("référencer",),
    "référencé": ("référencer",),
    "référencent": ("référencer",),
    "référence": ("référencer",),
    "référencera": ("référencer",),
    "référenceraient": ("référencer",),
    "référencerai": ("référencer",),
    "référencerais": ("référencer",),
    "référencerait": ("référencer",),
    "référenceras": ("référencer",),
    "référencèrent": ("référencer",),
    "référencerez": ("référencer",),
    "référenceriez": ("référencer",),
    "référencerions": ("référencer",),
    "référencerons": ("référencer",),
    "référenceront": ("référencer",),
    "référencés": ("référencer",),
    "références": ("référencer",),
    "référencez": ("référencer",),
    "référenciez": ("référencier",),
    "référencions": ("référencier",),
    "référençons": ("référencer",),
    "référenciaient": ("référencier",),
    "référenciai": ("référencier",),
    "référenciais": ("référencier",),
    "référenciait": ("référencier",),
    "référencia": ("référencier",),
    "référenciâmes": ("référencier",),
    "référenciant": ("référencier",),
    "référencias": ("référencier",),
    "référenciassent": ("référencier",),
    "référenciasses": ("référencier",),
    "référenciasse": ("référencier",),
    "référenciassiez": ("référencier",),
    "référenciassions": ("référencier",),
    "référenciâtes": ("référencier",),
    "référenciât": ("référencier",),
    "référenciée": ("référencier",),
    "référenciées": ("référencier",),
    "référencié": ("référencier",),
    "référencient": ("référencier",),
    "référencie": ("référencier",),
    "référenciera": ("référencier",),
    "référencieraient": ("référencier",),
    "référencierai": ("référencier",),
    "référencierais": ("référencier",),
    "référencierait": ("référencier",),
    "référencieras": ("référencier",),
    "référencièrent": ("référencier",),
    "référencierez": ("référencier",),
    "référencieriez": ("référencier",),
    "référencierions": ("référencier",),
    "référencierons": ("référencier",),
    "référencieront": ("référencier",),
    "référenciés": ("référencier",),
    "référencies": ("référencier",),
    "référenciiez": ("référencier",),
    "référenciions": ("référencier",),
    "référaient": ("référer",),
    "référai": ("référer",),
    "référais": ("référer",),
    "référait": ("référer",),
    "référa": ("référer",),
    "référâmes": ("référer",),
    "référant": ("référer",),
    "référas": ("référer",),
    "référassent": ("référer",),
    "référasses": ("référer",),
    "référasse": ("référer",),
    "référassiez": ("référer",),
    "référassions": ("référer",),
    "référâtes": ("référer",),
    "référât": ("référer",),
    "référée": ("référer",),
    "référées": ("référer",),
    "référé": ("référer",),
    "réfèrent": ("référer",),
    "réfère": ("référer",),
    "référera": ("référer",),
    "référeraient": ("référer",),
    "référerai": ("référer",),
    "référerais": ("référer",),
    "référerait": ("référer",),
    "référeras": ("référer",),
    "référèrent": ("référer",),
    "référerez": ("référer",),
    "référeriez": ("référer",),
    "référerions": ("référer",),
    "référerons": ("référer",),
    "référeront": ("référer",),
    "référés": ("référer",),
    "réfères": ("référer",),
    "référez": ("référer",),
    "référiez": ("référer",),
    "référions": ("référer",),
    "référons": ("référer",),
    "refestoient": ("refestoyer",),
    "refestoie": ("refestoyer",),
    "refestoiera": ("refestoyer",),
    "refestoieraient": ("refestoyer",),
    "refestoierai": ("refestoyer",),
    "refestoierais": ("refestoyer",),
    "refestoierait": ("refestoyer",),
    "refestoieras": ("refestoyer",),
    "refestoierez": ("refestoyer",),
    "refestoieriez": ("refestoyer",),
    "refestoierions": ("refestoyer",),
    "refestoierons": ("refestoyer",),
    "refestoieront": ("refestoyer",),
    "refestoies": ("refestoyer",),
    "refestoyaient": ("refestoyer",),
    "refestoyai": ("refestoyer",),
    "refestoyais": ("refestoyer",),
    "refestoyait": ("refestoyer",),
    "refestoya": ("refestoyer",),
    "refestoyâmes": ("refestoyer",),
    "refestoyant": ("refestoyer",),
    "refestoyas": ("refestoyer",),
    "refestoyassent": ("refestoyer",),
    "refestoyasses": ("refestoyer",),
    "refestoyasse": ("refestoyer",),
    "refestoyassiez": ("refestoyer",),
    "refestoyassions": ("refestoyer",),
    "refestoyâtes": ("refestoyer",),
    "refestoyât": ("refestoyer",),
    "refestoyée": ("refestoyer",),
    "refestoyées": ("refestoyer",),
    "refestoyé": ("refestoyer",),
    "refestoyèrent": ("refestoyer",),
    "refestoyés": ("refestoyer",),
    "refestoyez": ("refestoyer",),
    "refestoyiez": ("refestoyer",),
    "refestoyions": ("refestoyer",),
    "refestoyons": ("refestoyer",),
    "refeuilletaient": ("refeuilleter",),
    "refeuilletai": ("refeuilleter",),
    "refeuilletais": ("refeuilleter",),
    "refeuilletait": ("refeuilleter",),
    "refeuilleta": ("refeuilleter",),
    "refeuilletâmes": ("refeuilleter",),
    "refeuilletant": ("refeuilleter",),
    "refeuilletas": ("refeuilleter",),
    "refeuilletassent": ("refeuilleter",),
    "refeuilletasses": ("refeuilleter",),
    "refeuilletasse": ("refeuilleter",),
    "refeuilletassiez": ("refeuilleter",),
    "refeuilletassions": ("refeuilleter",),
    "refeuilletâtes": ("refeuilleter",),
    "refeuilletât": ("refeuilleter",),
    "refeuilletée": ("refeuilleter",),
    "refeuilletées": ("refeuilleter",),
    "refeuilleté": ("refeuilleter",),
    "refeuilletèrent": ("refeuilleter",),
    "refeuilletés": ("refeuilleter",),
    "refeuilletez": ("refeuilleter",),
    "refeuilletiez": ("refeuilleter",),
    "refeuilletions": ("refeuilleter",),
    "refeuilletons": ("refeuilleter",),
    "refeuillettent": ("refeuilleter",),
    "refeuillette": ("refeuilleter",),
    "refeuillettera": ("refeuilleter",),
    "refeuilletteraient": ("refeuilleter",),
    "refeuilletterai": ("refeuilleter",),
    "refeuilletterais": ("refeuilleter",),
    "refeuilletterait": ("refeuilleter",),
    "refeuilletteras": ("refeuilleter",),
    "refeuilletterez": ("refeuilleter",),
    "refeuilletteriez": ("refeuilleter",),
    "refeuilletterions": ("refeuilleter",),
    "refeuilletterons": ("refeuilleter",),
    "refeuilletteront": ("refeuilleter",),
    "refeuillettes": ("refeuilleter",),
    "refiançaient": ("refiancer",),
    "refiançai": ("refiancer",),
    "refiançais": ("refiancer",),
    "refiançait": ("refiancer",),
    "refiança": ("refiancer",),
    "refiançâmes": ("refiancer",),
    "refiançant": ("refiancer",),
    "refianças": ("refiancer",),
    "refiançassent": ("refiancer",),
    "refiançasses": ("refiancer",),
    "refiançasse": ("refiancer",),
    "refiançassiez": ("refiancer",),
    "refiançassions": ("refiancer",),
    "refiançâtes": ("refiancer",),
    "refiançât": ("refiancer",),
    "refiancée": ("refiancer",),
    "refiancées": ("refiancer",),
    "refiancé": ("refiancer",),
    "refiancent": ("refiancer",),
    "refiance": ("refiancer",),
    "refiancera": ("refiancer",),
    "refianceraient": ("refiancer",),
    "refiancerai": ("refiancer",),
    "refiancerais": ("refiancer",),
    "refiancerait": ("refiancer",),
    "refianceras": ("refiancer",),
    "refiancèrent": ("refiancer",),
    "refiancerez": ("refiancer",),
    "refianceriez": ("refiancer",),
    "refiancerions": ("refiancer",),
    "refiancerons": ("refiancer",),
    "refianceront": ("refiancer",),
    "refiancés": ("refiancer",),
    "refiances": ("refiancer",),
    "refiancez": ("refiancer",),
    "refianciez": ("refiancer",),
    "refiancions": ("refiancer",),
    "refiançons": ("refiancer",),
    "reficelaient": ("reficeler",),
    "reficelai": ("reficeler",),
    "reficelais": ("reficeler",),
    "reficelait": ("reficeler",),
    "reficela": ("reficeler",),
    "reficelâmes": ("reficeler",),
    "reficelant": ("reficeler",),
    "reficelas": ("reficeler",),
    "reficelassent": ("reficeler",),
    "reficelasses": ("reficeler",),
    "reficelasse": ("reficeler",),
    "reficelassiez": ("reficeler",),
    "reficelassions": ("reficeler",),
    "reficelâtes": ("reficeler",),
    "reficelât": ("reficeler",),
    "reficelée": ("reficeler",),
    "reficelées": ("reficeler",),
    "reficelé": ("reficeler",),
    "reficelèrent": ("reficeler",),
    "reficelés": ("reficeler",),
    "reficelez": ("reficeler",),
    "reficeliez": ("reficeler",),
    "reficelions": ("reficeler",),
    "reficellent": ("reficeler",),
    "reficelle": ("reficeler",),
    "reficellera": ("reficeler",),
    "reficelleraient": ("reficeler",),
    "reficellerai": ("reficeler",),
    "reficellerais": ("reficeler",),
    "reficellerait": ("reficeler",),
    "reficelleras": ("reficeler",),
    "reficellerez": ("reficeler",),
    "reficelleriez": ("reficeler",),
    "reficellerions": ("reficeler",),
    "reficellerons": ("reficeler",),
    "reficelleront": ("reficeler",),
    "reficelles": ("reficeler",),
    "reficelons": ("reficeler",),
    "refinançaient": ("refinancer",),
    "refinançai": ("refinancer",),
    "refinançais": ("refinancer",),
    "refinançait": ("refinancer",),
    "refinança": ("refinancer",),
    "refinançâmes": ("refinancer",),
    "refinançant": ("refinancer",),
    "refinanças": ("refinancer",),
    "refinançassent": ("refinancer",),
    "refinançasses": ("refinancer",),
    "refinançasse": ("refinancer",),
    "refinançassiez": ("refinancer",),
    "refinançassions": ("refinancer",),
    "refinançâtes": ("refinancer",),
    "refinançât": ("refinancer",),
    "refinancée": ("refinancer",),
    "refinancées": ("refinancer",),
    "refinancé": ("refinancer",),
    "refinancent": ("refinancer",),
    "refinance": ("refinancer",),
    "refinancera": ("refinancer",),
    "refinanceraient": ("refinancer",),
    "refinancerai": ("refinancer",),
    "refinancerais": ("refinancer",),
    "refinancerait": ("refinancer",),
    "refinanceras": ("refinancer",),
    "refinancèrent": ("refinancer",),
    "refinancerez": ("refinancer",),
    "refinanceriez": ("refinancer",),
    "refinancerions": ("refinancer",),
    "refinancerons": ("refinancer",),
    "refinanceront": ("refinancer",),
    "refinancés": ("refinancer",),
    "refinances": ("refinancer",),
    "refinancez": ("refinancer",),
    "refinanciez": ("refinancer",),
    "refinancions": ("refinancer",),
    "refinançons": ("refinancer",),
    "reflambloient": ("reflambloyer",),
    "reflambloie": ("reflambloyer",),
    "reflambloiera": ("reflambloyer",),
    "reflambloieraient": ("reflambloyer",),
    "reflambloierai": ("reflambloyer",),
    "reflambloierais": ("reflambloyer",),
    "reflambloierait": ("reflambloyer",),
    "reflambloieras": ("reflambloyer",),
    "reflambloierez": ("reflambloyer",),
    "reflambloieriez": ("reflambloyer",),
    "reflambloierions": ("reflambloyer",),
    "reflambloierons": ("reflambloyer",),
    "reflambloieront": ("reflambloyer",),
    "reflambloies": ("reflambloyer",),
    "reflambloyaient": ("reflambloyer",),
    "reflambloyai": ("reflambloyer",),
    "reflambloyais": ("reflambloyer",),
    "reflambloyait": ("reflambloyer",),
    "reflambloya": ("reflambloyer",),
    "reflambloyâmes": ("reflambloyer",),
    "reflambloyant": ("reflambloyer",),
    "reflambloyas": ("reflambloyer",),
    "reflambloyassent": ("reflambloyer",),
    "reflambloyasses": ("reflambloyer",),
    "reflambloyasse": ("reflambloyer",),
    "reflambloyassiez": ("reflambloyer",),
    "reflambloyassions": ("reflambloyer",),
    "reflambloyâtes": ("reflambloyer",),
    "reflambloyât": ("reflambloyer",),
    "reflambloyé": ("reflambloyer",),
    "reflambloyèrent": ("reflambloyer",),
    "reflambloyez": ("reflambloyer",),
    "reflambloyiez": ("reflambloyer",),
    "reflambloyions": ("reflambloyer",),
    "reflambloyons": ("reflambloyer",),
    "réfléchie": ("réfléchir",),
    "réfléchies": ("réfléchir",),
    "réfléchi": ("réfléchir",),
    "réfléchîmes": ("réfléchir",),
    "réfléchira": ("réfléchir",),
    "réfléchiraient": ("réfléchir",),
    "réfléchirai": ("réfléchir",),
    "réfléchirais": ("réfléchir",),
    "réfléchirait": ("réfléchir",),
    "réfléchiras": ("réfléchir",),
    "réfléchirent": ("réfléchir",),
    "réfléchirez": ("réfléchir",),
    "réfléchiriez": ("réfléchir",),
    "réfléchirions": ("réfléchir",),
    "réfléchirons": ("réfléchir",),
    "réfléchiront": ("réfléchir",),
    "réfléchis": ("réfléchir",),
    "réfléchissaient": ("réfléchir",),
    "réfléchissais": ("réfléchir",),
    "réfléchissait": ("réfléchir",),
    "réfléchissant": ("réfléchir",),
    "réfléchissent": ("réfléchir",),
    "réfléchisse": ("réfléchir",),
    "réfléchisses": ("réfléchir",),
    "réfléchissez": ("réfléchir",),
    "réfléchissiez": ("réfléchir",),
    "réfléchissions": ("réfléchir",),
    "réfléchissons": ("réfléchir",),
    "réfléchîtes": ("réfléchir",),
    "réfléchit": ("réfléchir",),
    "réfléchît": ("réfléchir",),
    "reflétaient": ("refléter",),
    "reflétai": ("refléter",),
    "reflétais": ("refléter",),
    "reflétait": ("refléter",),
    "refléta": ("refléter",),
    "reflétâmes": ("refléter",),
    "reflétant": ("refléter",),
    "reflétas": ("refléter",),
    "reflétassent": ("refléter",),
    "reflétasses": ("refléter",),
    "reflétasse": ("refléter",),
    "reflétassiez": ("refléter",),
    "reflétassions": ("refléter",),
    "reflétâtes": ("refléter",),
    "reflétât": ("refléter",),
    "reflétée": ("refléter",),
    "reflétées": ("refléter",),
    "reflété": ("refléter",),
    "reflètent": ("refléter",),
    "reflète": ("refléter",),
    "reflétera": ("refléter",),
    "refléteraient": ("refléter",),
    "refléterai": ("refléter",),
    "refléterais": ("refléter",),
    "refléterait": ("refléter",),
    "refléteras": ("refléter",),
    "reflétèrent": ("refléter",),
    "refléterez": ("refléter",),
    "refléteriez": ("refléter",),
    "refléterions": ("refléter",),
    "refléterons": ("refléter",),
    "refléteront": ("refléter",),
    "reflétés": ("refléter",),
    "reflètes": ("refléter",),
    "reflétez": ("refléter",),
    "reflétiez": ("refléter",),
    "reflétions": ("refléter",),
    "reflétons": ("refléter",),
    "refleurie": ("refleurir",),
    "refleuries": ("refleurir",),
    "refleuri": ("refleurir",),
    "refleurîmes": ("refleurir",),
    "refleurira": ("refleurir",),
    "refleuriraient": ("refleurir",),
    "refleurirai": ("refleurir",),
    "refleurirais": ("refleurir",),
    "refleurirait": ("refleurir",),
    "refleuriras": ("refleurir",),
    "refleurirent": ("refleurir",),
    "refleurirez": ("refleurir",),
    "refleuririez": ("refleurir",),
    "refleuririons": ("refleurir",),
    "refleurirons": ("refleurir",),
    "refleuriront": ("refleurir",),
    "refleuris": ("refleurir",),
    "refleurissaient": ("refleurir",),
    "refleurissais": ("refleurir",),
    "refleurissait": ("refleurir",),
    "refleurissant": ("refleurir",),
    "refleurissent": ("refleurir",),
    "refleurisse": ("refleurir",),
    "refleurisses": ("refleurir",),
    "refleurissez": ("refleurir",),
    "refleurissiez": ("refleurir",),
    "refleurissions": ("refleurir",),
    "refleurissons": ("refleurir",),
    "refleurîtes": ("refleurir",),
    "refleurit": ("refleurir",),
    "refleurît": ("refleurir",),
    "refonçaient": ("refoncer",),
    "refonçai": ("refoncer",),
    "refonçais": ("refoncer",),
    "refonçait": ("refoncer",),
    "refonça": ("refoncer",),
    "refonçâmes": ("refoncer",),
    "refonçant": ("refoncer",),
    "refonças": ("refoncer",),
    "refonçassent": ("refoncer",),
    "refonçasses": ("refoncer",),
    "refonçasse": ("refoncer",),
    "refonçassiez": ("refoncer",),
    "refonçassions": ("refoncer",),
    "refonçâtes": ("refoncer",),
    "refonçât": ("refoncer",),
    "refoncée": ("refoncer",),
    "refoncées": ("refoncer",),
    "refoncé": ("refoncer",),
    "refoncent": ("refoncer",),
    "refonce": ("refoncer",),
    "refoncera": ("refoncer",),
    "refonceraient": ("refoncer",),
    "refoncerai": ("refoncer",),
    "refoncerais": ("refoncer",),
    "refoncerait": ("refoncer",),
    "refonceras": ("refoncer",),
    "refoncèrent": ("refoncer",),
    "refoncerez": ("refoncer",),
    "refonceriez": ("refoncer",),
    "refoncerions": ("refoncer",),
    "refoncerons": ("refoncer",),
    "refonceront": ("refoncer",),
    "refoncés": ("refoncer",),
    "refonces": ("refoncer",),
    "refoncez": ("refoncer",),
    "refonciez": ("refoncer",),
    "refoncions": ("refoncer",),
    "refonçons": ("refoncer",),
    "refondaient": ("refondre",),
    "refondais": ("refondre",),
    "refondait": ("refondre",),
    "refondant": ("refondre",),
    "refondent": ("refondre",),
    "refonde": ("refondre",),
    "refondes": ("refondre",),
    "refondez": ("refondre",),
    "refondiez": ("refondre",),
    "refondîmes": ("refondre",),
    "refondions": ("refondre",),
    "refondirent": ("refondre",),
    "refondis": ("refondre",),
    "refondissent": ("refondre",),
    "refondisses": ("refondre",),
    "refondisse": ("refondre",),
    "refondissiez": ("refondre",),
    "refondissions": ("refondre",),
    "refondîtes": ("refondre",),
    "refondit": ("refondre",),
    "refondît": ("refondre",),
    "refondons": ("refondre",),
    "refond": ("refondre",),
    "refondra": ("refondre",),
    "refondraient": ("refondre",),
    "refondrai": ("refondre",),
    "refondrais": ("refondre",),
    "refondrait": ("refondre",),
    "refondras": ("refondre",),
    "refondrez": ("refondre",),
    "refondriez": ("refondre",),
    "refondrions": ("refondre",),
    "refondrons": ("refondre",),
    "refondront": ("refondre",),
    "refonds": ("refondre",),
    "refondue": ("refondre",),
    "refondues": ("refondre",),
    "refondu": ("refondre",),
    "refondus": ("refondre",),
    "reforçaient": ("reforcer",),
    "reforçai": ("reforcer",),
    "reforçais": ("reforcer",),
    "reforçait": ("reforcer",),
    "reforça": ("reforcer",),
    "reforçâmes": ("reforcer",),
    "reforçant": ("reforcer",),
    "reforças": ("reforcer",),
    "reforçassent": ("reforcer",),
    "reforçasses": ("reforcer",),
    "reforçasse": ("reforcer",),
    "reforçassiez": ("reforcer",),
    "reforçassions": ("reforcer",),
    "reforçâtes": ("reforcer",),
    "reforçât": ("reforcer",),
    "reforcée": ("reforcer",),
    "reforcées": ("reforcer",),
    "reforcé": ("reforcer",),
    "reforcent": ("reforcer",),
    "reforce": ("reforcer",),
    "reforcera": ("reforcer",),
    "reforceraient": ("reforcer",),
    "reforcerai": ("reforcer",),
    "reforcerais": ("reforcer",),
    "reforcerait": ("reforcer",),
    "reforceras": ("reforcer",),
    "reforcèrent": ("reforcer",),
    "reforcerez": ("reforcer",),
    "reforceriez": ("reforcer",),
    "reforcerions": ("reforcer",),
    "reforcerons": ("reforcer",),
    "reforceront": ("reforcer",),
    "reforcés": ("reforcer",),
    "reforces": ("reforcer",),
    "reforcez": ("reforcer",),
    "reforciez": ("reforcer",),
    "reforcions": ("reforcer",),
    "reforçons": ("reforcer",),
    "reforgeaient": ("reforger",),
    "reforgeai": ("reforger",),
    "reforgeais": ("reforger",),
    "reforgeait": ("reforger",),
    "reforgea": ("reforger",),
    "reforgeâmes": ("reforger",),
    "reforgeant": ("reforger",),
    "reforgeas": ("reforger",),
    "reforgeassent": ("reforger",),
    "reforgeasses": ("reforger",),
    "reforgeasse": ("reforger",),
    "reforgeassiez": ("reforger",),
    "reforgeassions": ("reforger",),
    "reforgeâtes": ("reforger",),
    "reforgeât": ("reforger",),
    "reforgée": ("reforger",),
    "reforgées": ("reforger",),
    "reforgé": ("reforger",),
    "reforgent": ("reforger",),
    "reforgeons": ("reforger",),
    "reforge": ("reforger",),
    "reforgera": ("reforger",),
    "reforgeraient": ("reforger",),
    "reforgerai": ("reforger",),
    "reforgerais": ("reforger",),
    "reforgerait": ("reforger",),
    "reforgeras": ("reforger",),
    "reforgèrent": ("reforger",),
    "reforgerez": ("reforger",),
    "reforgeriez": ("reforger",),
    "reforgerions": ("reforger",),
    "reforgerons": ("reforger",),
    "reforgeront": ("reforger",),
    "reforgés": ("reforger",),
    "reforges": ("reforger",),
    "reforgez": ("reforger",),
    "reforgiez": ("reforger",),
    "reforgions": ("reforger",),
    "refortifiaient": ("refortifier",),
    "refortifiai": ("refortifier",),
    "refortifiais": ("refortifier",),
    "refortifiait": ("refortifier",),
    "refortifia": ("refortifier",),
    "refortifiâmes": ("refortifier",),
    "refortifiant": ("refortifier",),
    "refortifias": ("refortifier",),
    "refortifiassent": ("refortifier",),
    "refortifiasses": ("refortifier",),
    "refortifiasse": ("refortifier",),
    "refortifiassiez": ("refortifier",),
    "refortifiassions": ("refortifier",),
    "refortifiâtes": ("refortifier",),
    "refortifiât": ("refortifier",),
    "refortifiée": ("refortifier",),
    "refortifiées": ("refortifier",),
    "refortifié": ("refortifier",),
    "refortifient": ("refortifier",),
    "refortifie": ("refortifier",),
    "refortifiera": ("refortifier",),
    "refortifieraient": ("refortifier",),
    "refortifierai": ("refortifier",),
    "refortifierais": ("refortifier",),
    "refortifierait": ("refortifier",),
    "refortifieras": ("refortifier",),
    "refortifièrent": ("refortifier",),
    "refortifierez": ("refortifier",),
    "refortifieriez": ("refortifier",),
    "refortifierions": ("refortifier",),
    "refortifierons": ("refortifier",),
    "refortifieront": ("refortifier",),
    "refortifiés": ("refortifier",),
    "refortifies": ("refortifier",),
    "refortifiez": ("refortifier",),
    "refortifiiez": ("refortifier",),
    "refortifiions": ("refortifier",),
    "refortifions": ("refortifier",),
    "refourbie": ("refourbir",),
    "refourbies": ("refourbir",),
    "refourbi": ("refourbir",),
    "refourbîmes": ("refourbir",),
    "refourbira": ("refourbir",),
    "refourbiraient": ("refourbir",),
    "refourbirai": ("refourbir",),
    "refourbirais": ("refourbir",),
    "refourbirait": ("refourbir",),
    "refourbiras": ("refourbir",),
    "refourbirent": ("refourbir",),
    "refourbirez": ("refourbir",),
    "refourbiriez": ("refourbir",),
    "refourbirions": ("refourbir",),
    "refourbirons": ("refourbir",),
    "refourbiront": ("refourbir",),
    "refourbis": ("refourbir",),
    "refourbissaient": ("refourbir",),
    "refourbissais": ("refourbir",),
    "refourbissait": ("refourbir",),
    "refourbissant": ("refourbir",),
    "refourbissent": ("refourbir",),
    "refourbisse": ("refourbir",),
    "refourbisses": ("refourbir",),
    "refourbissez": ("refourbir",),
    "refourbissiez": ("refourbir",),
    "refourbissions": ("refourbir",),
    "refourbissons": ("refourbir",),
    "refourbîtes": ("refourbir",),
    "refourbit": ("refourbir",),
    "refourbît": ("refourbir",),
    "refournie": ("refournir",),
    "refournies": ("refournir",),
    "refourni": ("refournir",),
    "refournîmes": ("refournir",),
    "refournira": ("refournir",),
    "refourniraient": ("refournir",),
    "refournirai": ("refournir",),
    "refournirais": ("refournir",),
    "refournirait": ("refournir",),
    "refourniras": ("refournir",),
    "refournirent": ("refournir",),
    "refournirez": ("refournir",),
    "refourniriez": ("refournir",),
    "refournirions": ("refournir",),
    "refournirons": ("refournir",),
    "refourniront": ("refournir",),
    "refournis": ("refournir",),
    "refournissaient": ("refournir",),
    "refournissais": ("refournir",),
    "refournissait": ("refournir",),
    "refournissant": ("refournir",),
    "refournissent": ("refournir",),
    "refournisse": ("refournir",),
    "refournisses": ("refournir",),
    "refournissez": ("refournir",),
    "refournissiez": ("refournir",),
    "refournissions": ("refournir",),
    "refournissons": ("refournir",),
    "refournîtes": ("refournir",),
    "refournit": ("refournir",),
    "refournît": ("refournir",),
    "refous": ("refoutre",),
    "refoutaient": ("refoutre",),
    "refoutais": ("refoutre",),
    "refoutait": ("refoutre",),
    "refoutant": ("refoutre",),
    "refoutent": ("refoutre",),
    "refoute": ("refoutre",),
    "refoutes": ("refoutre",),
    "refoutez": ("refoutre",),
    "refoutiez": ("refoutre",),
    "refoutions": ("refoutre",),
    "refoutissent": ("refoutre",),
    "refoutisses": ("refoutre",),
    "refoutisse": ("refoutre",),
    "refoutissiez": ("refoutre",),
    "refoutissions": ("refoutre",),
    "refoutît": ("refoutre",),
    "refoutons": ("refoutre",),
    "refout": ("refoutre",),
    "refoutra": ("refoutre",),
    "refoutraient": ("refoutre",),
    "refoutrai": ("refoutre",),
    "refoutrais": ("refoutre",),
    "refoutrait": ("refoutre",),
    "refoutras": ("refoutre",),
    "refoutrez": ("refoutre",),
    "refoutriez": ("refoutre",),
    "refoutrions": ("refoutre",),
    "refoutrons": ("refoutre",),
    "refoutront": ("refoutre",),
    "refoutue": ("refoutre",),
    "refoutues": ("refoutre",),
    "refoutu": ("refoutre",),
    "refoutus": ("refoutre",),
    "refraintie": ("refraintir",),
    "refrainties": ("refraintir",),
    "refrainti": ("refraintir",),
    "refraintîmes": ("refraintir",),
    "refraintira": ("refraintir",),
    "refraintiraient": ("refraintir",),
    "refraintirai": ("refraintir",),
    "refraintirais": ("refraintir",),
    "refraintirait": ("refraintir",),
    "refraintiras": ("refraintir",),
    "refraintirent": ("refraintir",),
    "refraintirez": ("refraintir",),
    "refraintiriez": ("refraintir",),
    "refraintirions": ("refraintir",),
    "refraintirons": ("refraintir",),
    "refraintiront": ("refraintir",),
    "refraintis": ("refraintir",),
    "refraintissaient": ("refraintir",),
    "refraintissais": ("refraintir",),
    "refraintissait": ("refraintir",),
    "refraintissant": ("refraintir",),
    "refraintissent": ("refraintir",),
    "refraintisse": ("refraintir",),
    "refraintisses": ("refraintir",),
    "refraintissez": ("refraintir",),
    "refraintissiez": ("refraintir",),
    "refraintissions": ("refraintir",),
    "refraintissons": ("refraintir",),
    "refraintîtes": ("refraintir",),
    "refraintit": ("refraintir",),
    "refraintît": ("refraintir",),
    "refranchie": ("refranchir",),
    "refranchies": ("refranchir",),
    "refranchi": ("refranchir",),
    "refranchîmes": ("refranchir",),
    "refranchira": ("refranchir",),
    "refranchiraient": ("refranchir",),
    "refranchirai": ("refranchir",),
    "refranchirais": ("refranchir",),
    "refranchirait": ("refranchir",),
    "refranchiras": ("refranchir",),
    "refranchirent": ("refranchir",),
    "refranchirez": ("refranchir",),
    "refranchiriez": ("refranchir",),
    "refranchirions": ("refranchir",),
    "refranchirons": ("refranchir",),
    "refranchiront": ("refranchir",),
    "refranchis": ("refranchir",),
    "refranchissaient": ("refranchir",),
    "refranchissais": ("refranchir",),
    "refranchissait": ("refranchir",),
    "refranchissant": ("refranchir",),
    "refranchissent": ("refranchir",),
    "refranchisse": ("refranchir",),
    "refranchisses": ("refranchir",),
    "refranchissez": ("refranchir",),
    "refranchissiez": ("refranchir",),
    "refranchissions": ("refranchir",),
    "refranchissons": ("refranchir",),
    "refranchîtes": ("refranchir",),
    "refranchit": ("refranchir",),
    "refranchît": ("refranchir",),
    "refraient": ("refrayer",),
    "refraie": ("refrayer",),
    "refraiera": ("refrayer",),
    "refraieraient": ("refrayer",),
    "refraierai": ("refrayer",),
    "refraierais": ("refrayer",),
    "refraierait": ("refrayer",),
    "refraieras": ("refrayer",),
    "refraierez": ("refrayer",),
    "refraieriez": ("refrayer",),
    "refraierions": ("refrayer",),
    "refraierons": ("refrayer",),
    "refraieront": ("refrayer",),
    "refraies": ("refrayer",),
    "refrayaient": ("refrayer",),
    "refrayai": ("refrayer",),
    "refrayais": ("refrayer",),
    "refrayait": ("refrayer",),
    "refraya": ("refrayer",),
    "refrayâmes": ("refrayer",),
    "refrayant": ("refrayer",),
    "refrayas": ("refrayer",),
    "refrayassent": ("refrayer",),
    "refrayasses": ("refrayer",),
    "refrayasse": ("refrayer",),
    "refrayassiez": ("refrayer",),
    "refrayassions": ("refrayer",),
    "refrayâtes": ("refrayer",),
    "refrayât": ("refrayer",),
    "refrayée": ("refrayer",),
    "refrayées": ("refrayer",),
    "refrayé": ("refrayer",),
    "refrayent": ("refrayer",),
    "refraye": ("refrayer",),
    "refrayera": ("refrayer",),
    "refrayeraient": ("refrayer",),
    "refrayerai": ("refrayer",),
    "refrayerais": ("refrayer",),
    "refrayerait": ("refrayer",),
    "refrayeras": ("refrayer",),
    "refrayèrent": ("refrayer",),
    "refrayerez": ("refrayer",),
    "refrayeriez": ("refrayer",),
    "refrayerions": ("refrayer",),
    "refrayerons": ("refrayer",),
    "refrayeront": ("refrayer",),
    "refrayés": ("refrayer",),
    "refrayes": ("refrayer",),
    "refrayez": ("refrayer",),
    "refrayiez": ("refrayer",),
    "refrayions": ("refrayer",),
    "refrayons": ("refrayer",),
    "réfrigéraient": ("réfrigérer",),
    "réfrigérai": ("réfrigérer",),
    "réfrigérais": ("réfrigérer",),
    "réfrigérait": ("réfrigérer",),
    "réfrigéra": ("réfrigérer",),
    "réfrigérâmes": ("réfrigérer",),
    "réfrigérant": ("réfrigérer",),
    "réfrigéras": ("réfrigérer",),
    "réfrigérassent": ("réfrigérer",),
    "réfrigérasses": ("réfrigérer",),
    "réfrigérasse": ("réfrigérer",),
    "réfrigérassiez": ("réfrigérer",),
    "réfrigérassions": ("réfrigérer",),
    "réfrigérâtes": ("réfrigérer",),
    "réfrigérât": ("réfrigérer",),
    "réfrigérée": ("réfrigérer",),
    "réfrigérées": ("réfrigérer",),
    "réfrigéré": ("réfrigérer",),
    "réfrigèrent": ("réfrigérer",),
    "réfrigère": ("réfrigérer",),
    "réfrigérera": ("réfrigérer",),
    "réfrigéreraient": ("réfrigérer",),
    "réfrigérerai": ("réfrigérer",),
    "réfrigérerais": ("réfrigérer",),
    "réfrigérerait": ("réfrigérer",),
    "réfrigéreras": ("réfrigérer",),
    "réfrigérèrent": ("réfrigérer",),
    "réfrigérerez": ("réfrigérer",),
    "réfrigéreriez": ("réfrigérer",),
    "réfrigérerions": ("réfrigérer",),
    "réfrigérerons": ("réfrigérer",),
    "réfrigéreront": ("réfrigérer",),
    "réfrigérés": ("réfrigérer",),
    "réfrigères": ("réfrigérer",),
    "réfrigérez": ("réfrigérer",),
    "réfrigériez": ("réfrigérer",),
    "réfrigérions": ("réfrigérer",),
    "réfrigérons": ("réfrigérer",),
    "refroidie": ("refroidir",),
    "refroidies": ("refroidir",),
    "refroidi": ("refroidir",),
    "refroidîmes": ("refroidir",),
    "refroidira": ("refroidir",),
    "refroidiraient": ("refroidir",),
    "refroidirai": ("refroidir",),
    "refroidirais": ("refroidir",),
    "refroidirait": ("refroidir",),
    "refroidiras": ("refroidir",),
    "refroidirent": ("refroidir",),
    "refroidirez": ("refroidir",),
    "refroidiriez": ("refroidir",),
    "refroidirions": ("refroidir",),
    "refroidirons": ("refroidir",),
    "refroidiront": ("refroidir",),
    "refroidis": ("refroidir",),
    "refroidissaient": ("refroidir",),
    "refroidissais": ("refroidir",),
    "refroidissait": ("refroidir",),
    "refroidissant": ("refroidir",),
    "refroidissent": ("refroidir",),
    "refroidisse": ("refroidir",),
    "refroidisses": ("refroidir",),
    "refroidissez": ("refroidir",),
    "refroidissiez": ("refroidir",),
    "refroidissions": ("refroidir",),
    "refroidissons": ("refroidir",),
    "refroidîtes": ("refroidir",),
    "refroidit": ("refroidir",),
    "refroidît": ("refroidir",),
    "refronçaient": ("refroncer",),
    "refronçai": ("refroncer",),
    "refronçais": ("refroncer",),
    "refronçait": ("refroncer",),
    "refronça": ("refroncer",),
    "refronçâmes": ("refroncer",),
    "refronçant": ("refroncer",),
    "refronças": ("refroncer",),
    "refronçassent": ("refroncer",),
    "refronçasses": ("refroncer",),
    "refronçasse": ("refroncer",),
    "refronçassiez": ("refroncer",),
    "refronçassions": ("refroncer",),
    "refronçâtes": ("refroncer",),
    "refronçât": ("refroncer",),
    "refroncée": ("refroncer",),
    "refroncées": ("refroncer",),
    "refroncé": ("refroncer",),
    "refroncent": ("refroncer",),
    "refronce": ("refroncer",),
    "refroncera": ("refroncer",),
    "refronceraient": ("refroncer",),
    "refroncerai": ("refroncer",),
    "refroncerais": ("refroncer",),
    "refroncerait": ("refroncer",),
    "refronceras": ("refroncer",),
    "refroncèrent": ("refroncer",),
    "refroncerez": ("refroncer",),
    "refronceriez": ("refroncer",),
    "refroncerions": ("refroncer",),
    "refroncerons": ("refroncer",),
    "refronceront": ("refroncer",),
    "refroncés": ("refroncer",),
    "refronces": ("refroncer",),
    "refroncez": ("refroncer",),
    "refronciez": ("refroncer",),
    "refroncions": ("refroncer",),
    "refronçons": ("refroncer",),
    "réfugiaient": ("réfugier",),
    "réfugiai": ("réfugier",),
    "réfugiais": ("réfugier",),
    "réfugiait": ("réfugier",),
    "réfugia": ("réfugier",),
    "réfugiâmes": ("réfugier",),
    "réfugiant": ("réfugier",),
    "réfugias": ("réfugier",),
    "réfugiassent": ("réfugier",),
    "réfugiasses": ("réfugier",),
    "réfugiasse": ("réfugier",),
    "réfugiassiez": ("réfugier",),
    "réfugiassions": ("réfugier",),
    "réfugiâtes": ("réfugier",),
    "réfugiât": ("réfugier",),
    "réfugiée": ("réfugier",),
    "réfugiées": ("réfugier",),
    "réfugié": ("réfugier",),
    "réfugient": ("réfugier",),
    "réfugie": ("réfugier",),
    "réfugiera": ("réfugier",),
    "réfugieraient": ("réfugier",),
    "réfugierai": ("réfugier",),
    "réfugierais": ("réfugier",),
    "réfugierait": ("réfugier",),
    "réfugieras": ("réfugier",),
    "réfugièrent": ("réfugier",),
    "réfugierez": ("réfugier",),
    "réfugieriez": ("réfugier",),
    "réfugierions": ("réfugier",),
    "réfugierons": ("réfugier",),
    "réfugieront": ("réfugier",),
    "réfugiés": ("réfugier",),
    "réfugies": ("réfugier",),
    "réfugiez": ("réfugier",),
    "réfugiiez": ("réfugier",),
    "réfugiions": ("réfugier",),
    "réfugions": ("réfugier",),
    "refuient": ("refuir",),
    "refuie": ("refuir",),
    "refuies": ("refuir",),
    "refui": ("refuir",),
    "refuîmes": ("refuir",),
    "refuira": ("refuir",),
    "refuiraient": ("refuir",),
    "refuirai": ("refuir",),
    "refuirais": ("refuir",),
    "refuirait": ("refuir",),
    "refuiras": ("refuir",),
    "refuirent": ("refuir",),
    "refuirez": ("refuir",),
    "refuiriez": ("refuir",),
    "refuirions": ("refuir",),
    "refuirons": ("refuir",),
    "refuiront": ("refuir",),
    "refuis": ("refuir",),
    "refuissent": ("refuir",),
    "refuisses": ("refuir",),
    "refuisse": ("refuir",),
    "refuissiez": ("refuir",),
    "refuissions": ("refuir",),
    "refuîtes": ("refuir",),
    "refuit": ("refuir",),
    "refuît": ("refuir",),
    "refuyaient": ("refuir",),
    "refuyais": ("refuir",),
    "refuyait": ("refuir",),
    "refuyant": ("refuir",),
    "refuyez": ("refuir",),
    "refuyiez": ("refuir",),
    "refuyions": ("refuir",),
    "refuyons": ("refuir",),
    "refuretaient": ("refureter",),
    "refuretai": ("refureter",),
    "refuretais": ("refureter",),
    "refuretait": ("refureter",),
    "refureta": ("refureter",),
    "refuretâmes": ("refureter",),
    "refuretant": ("refureter",),
    "refuretas": ("refureter",),
    "refuretassent": ("refureter",),
    "refuretasses": ("refureter",),
    "refuretasse": ("refureter",),
    "refuretassiez": ("refureter",),
    "refuretassions": ("refureter",),
    "refuretâtes": ("refureter",),
    "refuretât": ("refureter",),
    "refureté": ("refureter",),
    "refurètent": ("refureter",),
    "refurète": ("refureter",),
    "refurètera": ("refureter",),
    "refurèteraient": ("refureter",),
    "refurèterai": ("refureter",),
    "refurèterais": ("refureter",),
    "refurèterait": ("refureter",),
    "refurèteras": ("refureter",),
    "refuretèrent": ("refureter",),
    "refurèterez": ("refureter",),
    "refurèteriez": ("refureter",),
    "refurèterions": ("refureter",),
    "refurèterons": ("refureter",),
    "refurèteront": ("refureter",),
    "refurètes": ("refureter",),
    "refuretez": ("refureter",),
    "refuretiez": ("refureter",),
    "refuretions": ("refureter",),
    "refuretons": ("refureter",),
    "regageaient": ("regager",),
    "regageai": ("regager",),
    "regageais": ("regager",),
    "regageait": ("regager",),
    "regagea": ("regager",),
    "regageâmes": ("regager",),
    "regageant": ("regager",),
    "regageas": ("regager",),
    "regageassent": ("regager",),
    "regageasses": ("regager",),
    "regageasse": ("regager",),
    "regageassiez": ("regager",),
    "regageassions": ("regager",),
    "regageâtes": ("regager",),
    "regageât": ("regager",),
    "regagée": ("regager",),
    "regagées": ("regager",),
    "regagé": ("regager",),
    "regagent": ("regager",),
    "regageons": ("regager",),
    "regage": ("regager",),
    "regagera": ("regager",),
    "regageraient": ("regager",),
    "regagerai": ("regager",),
    "regagerais": ("regager",),
    "regagerait": ("regager",),
    "regageras": ("regager",),
    "regagèrent": ("regager",),
    "regagerez": ("regager",),
    "regageriez": ("regager",),
    "regagerions": ("regager",),
    "regagerons": ("regager",),
    "regageront": ("regager",),
    "regagés": ("regager",),
    "regages": ("regager",),
    "regagez": ("regager",),
    "regagiez": ("regager",),
    "regagions": ("regager",),
    "regaillardie": ("regaillardir",),
    "regaillardies": ("regaillardir",),
    "regaillardi": ("regaillardir",),
    "regaillardîmes": ("regaillardir",),
    "regaillardira": ("regaillardir",),
    "regaillardiraient": ("regaillardir",),
    "regaillardirai": ("regaillardir",),
    "regaillardirais": ("regaillardir",),
    "regaillardirait": ("regaillardir",),
    "regaillardiras": ("regaillardir",),
    "regaillardirent": ("regaillardir",),
    "regaillardirez": ("regaillardir",),
    "regaillardiriez": ("regaillardir",),
    "regaillardirions": ("regaillardir",),
    "regaillardirons": ("regaillardir",),
    "regaillardiront": ("regaillardir",),
    "regaillardis": ("regaillardir",),
    "regaillardissaient": ("regaillardir",),
    "regaillardissais": ("regaillardir",),
    "regaillardissait": ("regaillardir",),
    "regaillardissant": ("regaillardir",),
    "regaillardissent": ("regaillardir",),
    "regaillardisse": ("regaillardir",),
    "regaillardisses": ("regaillardir",),
    "regaillardissez": ("regaillardir",),
    "regaillardissiez": ("regaillardir",),
    "regaillardissions": ("regaillardir",),
    "regaillardissons": ("regaillardir",),
    "regaillardîtes": ("regaillardir",),
    "regaillardit": ("regaillardir",),
    "regaillardît": ("regaillardir",),
    "regarantie": ("regarantir",),
    "regaranties": ("regarantir",),
    "regaranti": ("regarantir",),
    "regarantîmes": ("regarantir",),
    "regarantira": ("regarantir",),
    "regarantiraient": ("regarantir",),
    "regarantirai": ("regarantir",),
    "regarantirais": ("regarantir",),
    "regarantirait": ("regarantir",),
    "regarantiras": ("regarantir",),
    "regarantirent": ("regarantir",),
    "regarantirez": ("regarantir",),
    "regarantiriez": ("regarantir",),
    "regarantirions": ("regarantir",),
    "regarantirons": ("regarantir",),
    "regarantiront": ("regarantir",),
    "regarantis": ("regarantir",),
    "regarantissaient": ("regarantir",),
    "regarantissais": ("regarantir",),
    "regarantissait": ("regarantir",),
    "regarantissant": ("regarantir",),
    "regarantissent": ("regarantir",),
    "regarantisse": ("regarantir",),
    "regarantisses": ("regarantir",),
    "regarantissez": ("regarantir",),
    "regarantissiez": ("regarantir",),
    "regarantissions": ("regarantir",),
    "regarantissons": ("regarantir",),
    "regarantîtes": ("regarantir",),
    "regarantit": ("regarantir",),
    "regarantît": ("regarantir",),
    "regarnie": ("regarnir",),
    "regarnies": ("regarnir",),
    "regarni": ("regarnir",),
    "regarnîmes": ("regarnir",),
    "regarnira": ("regarnir",),
    "regarniraient": ("regarnir",),
    "regarnirai": ("regarnir",),
    "regarnirais": ("regarnir",),
    "regarnirait": ("regarnir",),
    "regarniras": ("regarnir",),
    "regarnirent": ("regarnir",),
    "regarnirez": ("regarnir",),
    "regarniriez": ("regarnir",),
    "regarnirions": ("regarnir",),
    "regarnirons": ("regarnir",),
    "regarniront": ("regarnir",),
    "regarnis": ("regarnir",),
    "regarnissaient": ("regarnir",),
    "regarnissais": ("regarnir",),
    "regarnissait": ("regarnir",),
    "regarnissant": ("regarnir",),
    "regarnissent": ("regarnir",),
    "regarnisse": ("regarnir",),
    "regarnisses": ("regarnir",),
    "regarnissez": ("regarnir",),
    "regarnissiez": ("regarnir",),
    "regarnissions": ("regarnir",),
    "regarnissons": ("regarnir",),
    "regarnîtes": ("regarnir",),
    "regarnit": ("regarnir",),
    "regarnît": ("regarnir",),
    "regaient": ("regayer",),
    "regaie": ("regayer",),
    "regaiera": ("regayer",),
    "regaieraient": ("regayer",),
    "regaierai": ("regayer",),
    "regaierais": ("regayer",),
    "regaierait": ("regayer",),
    "regaieras": ("regayer",),
    "regaierez": ("regayer",),
    "regaieriez": ("regayer",),
    "regaierions": ("regayer",),
    "regaierons": ("regayer",),
    "regaieront": ("regayer",),
    "regaies": ("regayer",),
    "regayaient": ("regayer",),
    "regayai": ("regayer",),
    "regayais": ("regayer",),
    "regayait": ("regayer",),
    "regaya": ("regayer",),
    "regayâmes": ("regayer",),
    "regayant": ("regayer",),
    "regayas": ("regayer",),
    "regayassent": ("regayer",),
    "regayasses": ("regayer",),
    "regayasse": ("regayer",),
    "regayassiez": ("regayer",),
    "regayassions": ("regayer",),
    "regayâtes": ("regayer",),
    "regayât": ("regayer",),
    "regayée": ("regayer",),
    "regayées": ("regayer",),
    "regayé": ("regayer",),
    "regayent": ("regayer",),
    "regaye": ("regayer",),
    "regayera": ("regayer",),
    "regayeraient": ("regayer",),
    "regayerai": ("regayer",),
    "regayerais": ("regayer",),
    "regayerait": ("regayer",),
    "regayeras": ("regayer",),
    "regayèrent": ("regayer",),
    "regayerez": ("regayer",),
    "regayeriez": ("regayer",),
    "regayerions": ("regayer",),
    "regayerons": ("regayer",),
    "regayeront": ("regayer",),
    "regayés": ("regayer",),
    "regayes": ("regayer",),
    "regayez": ("regayer",),
    "regayiez": ("regayer",),
    "regayions": ("regayer",),
    "regayons": ("regayer",),
    "regazéifiaient": ("regazéifier",),
    "regazéifiai": ("regazéifier",),
    "regazéifiais": ("regazéifier",),
    "regazéifiait": ("regazéifier",),
    "regazéifia": ("regazéifier",),
    "regazéifiâmes": ("regazéifier",),
    "regazéifiant": ("regazéifier",),
    "regazéifias": ("regazéifier",),
    "regazéifiassent": ("regazéifier",),
    "regazéifiasses": ("regazéifier",),
    "regazéifiasse": ("regazéifier",),
    "regazéifiassiez": ("regazéifier",),
    "regazéifiassions": ("regazéifier",),
    "regazéifiâtes": ("regazéifier",),
    "regazéifiât": ("regazéifier",),
    "regazéifiée": ("regazéifier",),
    "regazéifiées": ("regazéifier",),
    "regazéifié": ("regazéifier",),
    "regazéifient": ("regazéifier",),
    "regazéifie": ("regazéifier",),
    "regazéifiera": ("regazéifier",),
    "regazéifieraient": ("regazéifier",),
    "regazéifierai": ("regazéifier",),
    "regazéifierais": ("regazéifier",),
    "regazéifierait": ("regazéifier",),
    "regazéifieras": ("regazéifier",),
    "regazéifièrent": ("regazéifier",),
    "regazéifierez": ("regazéifier",),
    "regazéifieriez": ("regazéifier",),
    "regazéifierions": ("regazéifier",),
    "regazéifierons": ("regazéifier",),
    "regazéifieront": ("regazéifier",),
    "regazéifiés": ("regazéifier",),
    "regazéifies": ("regazéifier",),
    "regazéifiez": ("regazéifier",),
    "regazéifiiez": ("regazéifier",),
    "regazéifiions": ("regazéifier",),
    "regazéifions": ("regazéifier",),
    "regelaient": ("regeler",),
    "regelai": ("regeler",),
    "regelais": ("regeler",),
    "regelait": ("regeler",),
    "regela": ("regeler",),
    "regelâmes": ("regeler",),
    "regelant": ("regeler",),
    "regelas": ("regeler",),
    "regelassent": ("regeler",),
    "regelasses": ("regeler",),
    "regelasse": ("regeler",),
    "regelassiez": ("regeler",),
    "regelassions": ("regeler",),
    "regelâtes": ("regeler",),
    "regelât": ("regeler",),
    "regelé": ("regeler",),
    "regèlent": ("regeler",),
    "regèle": ("regeler",),
    "regèlera": ("regeler",),
    "regèleraient": ("regeler",),
    "regèlerai": ("regeler",),
    "regèlerais": ("regeler",),
    "regèlerait": ("regeler",),
    "regèleras": ("regeler",),
    "regelèrent": ("regeler",),
    "regèlerez": ("regeler",),
    "regèleriez": ("regeler",),
    "regèlerions": ("regeler",),
    "regèlerons": ("regeler",),
    "regèleront": ("regeler",),
    "regèles": ("regeler",),
    "regelez": ("regeler",),
    "regeliez": ("regeler",),
    "regelions": ("regeler",),
    "regelons": ("regeler",),
    "régénéraient": ("régénérer",),
    "régénérai": ("régénérer",),
    "régénérais": ("régénérer",),
    "régénérait": ("régénérer",),
    "régénéra": ("régénérer",),
    "régénérâmes": ("régénérer",),
    "régénérant": ("régénérer",),
    "régénéras": ("régénérer",),
    "régénérassent": ("régénérer",),
    "régénérasses": ("régénérer",),
    "régénérasse": ("régénérer",),
    "régénérassiez": ("régénérer",),
    "régénérassions": ("régénérer",),
    "régénérâtes": ("régénérer",),
    "régénérât": ("régénérer",),
    "régénérée": ("régénérer",),
    "régénérées": ("régénérer",),
    "régénéré": ("régénérer",),
    "régénèrent": ("régénérer",),
    "régénère": ("régénérer",),
    "régénérera": ("régénérer",),
    "régénéreraient": ("régénérer",),
    "régénérerai": ("régénérer",),
    "régénérerais": ("régénérer",),
    "régénérerait": ("régénérer",),
    "régénéreras": ("régénérer",),
    "régénérèrent": ("régénérer",),
    "régénérerez": ("régénérer",),
    "régénéreriez": ("régénérer",),
    "régénérerions": ("régénérer",),
    "régénérerons": ("régénérer",),
    "régénéreront": ("régénérer",),
    "régénérés": ("régénérer",),
    "régénères": ("régénérer",),
    "régénérez": ("régénérer",),
    "régénériez": ("régénérer",),
    "régénérions": ("régénérer",),
    "régénérons": ("régénérer",),
    "regerçaient": ("regercer",),
    "regerçai": ("regercer",),
    "regerçais": ("regercer",),
    "regerçait": ("regercer",),
    "regerça": ("regercer",),
    "regerçâmes": ("regercer",),
    "regerçant": ("regercer",),
    "regerças": ("regercer",),
    "regerçassent": ("regercer",),
    "regerçasses": ("regercer",),
    "regerçasse": ("regercer",),
    "regerçassiez": ("regercer",),
    "regerçassions": ("regercer",),
    "regerçâtes": ("regercer",),
    "regerçât": ("regercer",),
    "regercée": ("regercer",),
    "regercées": ("regercer",),
    "regercé": ("regercer",),
    "regercent": ("regercer",),
    "regerce": ("regercer",),
    "regercera": ("regercer",),
    "regerceraient": ("regercer",),
    "regercerai": ("regercer",),
    "regercerais": ("regercer",),
    "regercerait": ("regercer",),
    "regerceras": ("regercer",),
    "regercèrent": ("regercer",),
    "regercerez": ("regercer",),
    "regerceriez": ("regercer",),
    "regercerions": ("regercer",),
    "regercerons": ("regercer",),
    "regerceront": ("regercer",),
    "regercés": ("regercer",),
    "regerces": ("regercer",),
    "regercez": ("regercer",),
    "regerciez": ("regercer",),
    "regercions": ("regercer",),
    "regerçons": ("regercer",),
    "régie": ("régir",),
    "régies": ("régir",),
    "régi": ("régir",),
    "régîmes": ("régir",),
    "régira": ("régir",),
    "régiraient": ("régir",),
    "régirai": ("régir",),
    "régirais": ("régir",),
    "régirait": ("régir",),
    "régiras": ("régir",),
    "régirent": ("régir",),
    "régirez": ("régir",),
    "régiriez": ("régir",),
    "régirions": ("régir",),
    "régirons": ("régir",),
    "régiront": ("régir",),
    "régis": ("régir",),
    "régissaient": ("régir",),
    "régissais": ("régir",),
    "régissait": ("régir",),
    "régissant": ("régir",),
    "régissent": ("régir",),
    "régisse": ("régir",),
    "régisses": ("régir",),
    "régissez": ("régir",),
    "régissiez": ("régir",),
    "régissions": ("régir",),
    "régissons": ("régir",),
    "régîtes": ("régir",),
    "régit": ("régir",),
    "régît": ("régir",),
    "reglaçaient": ("reglacer",),
    "reglaçai": ("reglacer",),
    "reglaçais": ("reglacer",),
    "reglaçait": ("reglacer",),
    "reglaça": ("reglacer",),
    "reglaçâmes": ("reglacer",),
    "reglaçant": ("reglacer",),
    "reglaças": ("reglacer",),
    "reglaçassent": ("reglacer",),
    "reglaçasses": ("reglacer",),
    "reglaçasse": ("reglacer",),
    "reglaçassiez": ("reglacer",),
    "reglaçassions": ("reglacer",),
    "reglaçâtes": ("reglacer",),
    "reglaçât": ("reglacer",),
    "reglacée": ("reglacer",),
    "reglacées": ("reglacer",),
    "reglacé": ("reglacer",),
    "reglacent": ("reglacer",),
    "reglace": ("reglacer",),
    "reglacera": ("reglacer",),
    "reglaceraient": ("reglacer",),
    "reglacerai": ("reglacer",),
    "reglacerais": ("reglacer",),
    "reglacerait": ("reglacer",),
    "reglaceras": ("reglacer",),
    "reglacèrent": ("reglacer",),
    "reglacerez": ("reglacer",),
    "reglaceriez": ("reglacer",),
    "reglacerions": ("reglacer",),
    "reglacerons": ("reglacer",),
    "reglaceront": ("reglacer",),
    "reglacés": ("reglacer",),
    "reglaces": ("reglacer",),
    "reglacez": ("reglacer",),
    "reglaciez": ("reglacer",),
    "reglacions": ("reglacer",),
    "reglaçons": ("reglacer",),
    "réglaient": ("régler",),
    "réglai": ("régler",),
    "réglais": ("régler",),
    "réglait": ("régler",),
    "régla": ("régler",),
    "réglâmes": ("régler",),
    "réglant": ("régler",),
    "réglas": ("régler",),
    "réglassent": ("régler",),
    "réglasses": ("régler",),
    "réglasse": ("régler",),
    "réglassiez": ("régler",),
    "réglassions": ("régler",),
    "réglâtes": ("régler",),
    "réglât": ("régler",),
    "réglée": ("régler",),
    "réglées": ("régler",),
    "réglé": ("régler",),
    "règlent": ("régler",),
    "règle": ("régler",),
    "réglera": ("régler",),
    "régleraient": ("régler",),
    "réglerai": ("régler",),
    "réglerais": ("régler",),
    "réglerait": ("régler",),
    "régleras": ("régler",),
    "réglèrent": ("régler",),
    "réglerez": ("régler",),
    "régleriez": ("régler",),
    "réglerions": ("régler",),
    "réglerons": ("régler",),
    "régleront": ("régler",),
    "réglés": ("régler",),
    "règles": ("régler",),
    "réglez": ("régler",),
    "régliez": ("régler",),
    "réglions": ("régler",),
    "réglons": ("régler",),
    "reglorifiaient": ("reglorifier",),
    "reglorifiai": ("reglorifier",),
    "reglorifiais": ("reglorifier",),
    "reglorifiait": ("reglorifier",),
    "reglorifia": ("reglorifier",),
    "reglorifiâmes": ("reglorifier",),
    "reglorifiant": ("reglorifier",),
    "reglorifias": ("reglorifier",),
    "reglorifiassent": ("reglorifier",),
    "reglorifiasses": ("reglorifier",),
    "reglorifiasse": ("reglorifier",),
    "reglorifiassiez": ("reglorifier",),
    "reglorifiassions": ("reglorifier",),
    "reglorifiâtes": ("reglorifier",),
    "reglorifiât": ("reglorifier",),
    "reglorifiée": ("reglorifier",),
    "reglorifiées": ("reglorifier",),
    "reglorifié": ("reglorifier",),
    "reglorifient": ("reglorifier",),
    "reglorifie": ("reglorifier",),
    "reglorifiera": ("reglorifier",),
    "reglorifieraient": ("reglorifier",),
    "reglorifierai": ("reglorifier",),
    "reglorifierais": ("reglorifier",),
    "reglorifierait": ("reglorifier",),
    "reglorifieras": ("reglorifier",),
    "reglorifièrent": ("reglorifier",),
    "reglorifierez": ("reglorifier",),
    "reglorifieriez": ("reglorifier",),
    "reglorifierions": ("reglorifier",),
    "reglorifierons": ("reglorifier",),
    "reglorifieront": ("reglorifier",),
    "reglorifiés": ("reglorifier",),
    "reglorifies": ("reglorifier",),
    "reglorifiez": ("reglorifier",),
    "reglorifiiez": ("reglorifier",),
    "reglorifiions": ("reglorifier",),
    "reglorifions": ("reglorifier",),
    "régnaient": ("régner",),
    "régnai": ("régner",),
    "régnais": ("régner",),
    "régnait": ("régner",),
    "régna": ("régner",),
    "régnâmes": ("régner",),
    "régnant": ("régner",),
    "régnas": ("régner",),
    "régnassent": ("régner",),
    "régnasses": ("régner",),
    "régnasse": ("régner",),
    "régnassiez": ("régner",),
    "régnassions": ("régner",),
    "régnâtes": ("régner",),
    "régnât": ("régner",),
    "régné": ("régner",),
    "règnent": ("régner",),
    "règne": ("régner",),
    "régnera": ("régner",),
    "régneraient": ("régner",),
    "régnerai": ("régner",),
    "régnerais": ("régner",),
    "régnerait": ("régner",),
    "régneras": ("régner",),
    "régnèrent": ("régner",),
    "régnerez": ("régner",),
    "régneriez": ("régner",),
    "régnerions": ("régner",),
    "régnerons": ("régner",),
    "régneront": ("régner",),
    "règnes": ("régner",),
    "régnez": ("régner",),
    "régniez": ("régner",),
    "régnions": ("régner",),
    "régnons": ("régner",),
    "regorgeaient": ("regorger",),
    "regorgeai": ("regorger",),
    "regorgeais": ("regorger",),
    "regorgeait": ("regorger",),
    "regorgea": ("regorger",),
    "regorgeâmes": ("regorger",),
    "regorgeant": ("regorger",),
    "regorgeas": ("regorger",),
    "regorgeassent": ("regorger",),
    "regorgeasses": ("regorger",),
    "regorgeasse": ("regorger",),
    "regorgeassiez": ("regorger",),
    "regorgeassions": ("regorger",),
    "regorgeâtes": ("regorger",),
    "regorgeât": ("regorger",),
    "regorgé": ("regorger",),
    "regorgent": ("regorger",),
    "regorgeons": ("regorger",),
    "regorge": ("regorger",),
    "regorgera": ("regorger",),
    "regorgeraient": ("regorger",),
    "regorgerai": ("regorger",),
    "regorgerais": ("regorger",),
    "regorgerait": ("regorger",),
    "regorgeras": ("regorger",),
    "regorgèrent": ("regorger",),
    "regorgerez": ("regorger",),
    "regorgeriez": ("regorger",),
    "regorgerions": ("regorger",),
    "regorgerons": ("regorger",),
    "regorgeront": ("regorger",),
    "regorges": ("regorger",),
    "regorgez": ("regorger",),
    "regorgiez": ("regorger",),
    "regorgions": ("regorger",),
    "regrandie": ("regrandir",),
    "regrandies": ("regrandir",),
    "regrandi": ("regrandir",),
    "regrandîmes": ("regrandir",),
    "regrandira": ("regrandir",),
    "regrandiraient": ("regrandir",),
    "regrandirai": ("regrandir",),
    "regrandirais": ("regrandir",),
    "regrandirait": ("regrandir",),
    "regrandiras": ("regrandir",),
    "regrandirent": ("regrandir",),
    "regrandirez": ("regrandir",),
    "regrandiriez": ("regrandir",),
    "regrandirions": ("regrandir",),
    "regrandirons": ("regrandir",),
    "regrandiront": ("regrandir",),
    "regrandis": ("regrandir",),
    "regrandissaient": ("regrandir",),
    "regrandissais": ("regrandir",),
    "regrandissait": ("regrandir",),
    "regrandissant": ("regrandir",),
    "regrandissent": ("regrandir",),
    "regrandisse": ("regrandir",),
    "regrandisses": ("regrandir",),
    "regrandissez": ("regrandir",),
    "regrandissiez": ("regrandir",),
    "regrandissions": ("regrandir",),
    "regrandissons": ("regrandir",),
    "regrandîtes": ("regrandir",),
    "regrandit": ("regrandir",),
    "regrandît": ("regrandir",),
    "regravie": ("regravir",),
    "regravies": ("regravir",),
    "regravi": ("regravir",),
    "regravîmes": ("regravir",),
    "regravira": ("regravir",),
    "regraviraient": ("regravir",),
    "regravirai": ("regravir",),
    "regravirais": ("regravir",),
    "regravirait": ("regravir",),
    "regraviras": ("regravir",),
    "regravirent": ("regravir",),
    "regravirez": ("regravir",),
    "regraviriez": ("regravir",),
    "regravirions": ("regravir",),
    "regravirons": ("regravir",),
    "regraviront": ("regravir",),
    "regravis": ("regravir",),
    "regravissaient": ("regravir",),
    "regravissais": ("regravir",),
    "regravissait": ("regravir",),
    "regravissant": ("regravir",),
    "regravissent": ("regravir",),
    "regravisse": ("regravir",),
    "regravisses": ("regravir",),
    "regravissez": ("regravir",),
    "regravissiez": ("regravir",),
    "regravissions": ("regravir",),
    "regravissons": ("regravir",),
    "regravîtes": ("regravir",),
    "regravit": ("regravir",),
    "regravît": ("regravir",),
    "regréaient": ("regréer",),
    "regréai": ("regréer",),
    "regréais": ("regréer",),
    "regréait": ("regréer",),
    "regréa": ("regréer",),
    "regréâmes": ("regréer",),
    "regréant": ("regréer",),
    "regréas": ("regréer",),
    "regréassent": ("regréer",),
    "regréasses": ("regréer",),
    "regréasse": ("regréer",),
    "regréassiez": ("regréer",),
    "regréassions": ("regréer",),
    "regréâtes": ("regréer",),
    "regréât": ("regréer",),
    "regréée": ("regréer",),
    "regréées": ("regréer",),
    "regréé": ("regréer",),
    "regréent": ("regréer",),
    "regrée": ("regréer",),
    "regréera": ("regréer",),
    "regréeraient": ("regréer",),
    "regréerai": ("regréer",),
    "regréerais": ("regréer",),
    "regréerait": ("regréer",),
    "regréeras": ("regréer",),
    "regréèrent": ("regréer",),
    "regréerez": ("regréer",),
    "regréeriez": ("regréer",),
    "regréerions": ("regréer",),
    "regréerons": ("regréer",),
    "regréeront": ("regréer",),
    "regréés": ("regréer",),
    "regrées": ("regréer",),
    "regréez": ("regréer",),
    "regréiez": ("regréer",),
    "regréions": ("regréer",),
    "regréons": ("regréer",),
    "regrevaient": ("regrever",),
    "regrevai": ("regrever",),
    "regrevais": ("regrever",),
    "regrevait": ("regrever",),
    "regreva": ("regrever",),
    "regrevâmes": ("regrever",),
    "regrevant": ("regrever",),
    "regrevas": ("regrever",),
    "regrevassent": ("regrever",),
    "regrevasses": ("regrever",),
    "regrevasse": ("regrever",),
    "regrevassiez": ("regrever",),
    "regrevassions": ("regrever",),
    "regrevâtes": ("regrever",),
    "regrevât": ("regrever",),
    "regrevée": ("regrever",),
    "regrevées": ("regrever",),
    "regrevé": ("regrever",),
    "regrèvent": ("regrever",),
    "regrève": ("regrever",),
    "regrèvera": ("regrever",),
    "regrèveraient": ("regrever",),
    "regrèverai": ("regrever",),
    "regrèverais": ("regrever",),
    "regrèverait": ("regrever",),
    "regrèveras": ("regrever",),
    "regrevèrent": ("regrever",),
    "regrèverez": ("regrever",),
    "regrèveriez": ("regrever",),
    "regrèverions": ("regrever",),
    "regrèverons": ("regrever",),
    "regrèveront": ("regrever",),
    "regrevés": ("regrever",),
    "regrèves": ("regrever",),
    "regrevez": ("regrever",),
    "regreviez": ("regrever",),
    "regrevions": ("regrever",),
    "regrevons": ("regrever",),
    "regrimaçaient": ("regrimacer",),
    "regrimaçai": ("regrimacer",),
    "regrimaçais": ("regrimacer",),
    "regrimaçait": ("regrimacer",),
    "regrimaça": ("regrimacer",),
    "regrimaçâmes": ("regrimacer",),
    "regrimaçant": ("regrimacer",),
    "regrimaças": ("regrimacer",),
    "regrimaçassent": ("regrimacer",),
    "regrimaçasses": ("regrimacer",),
    "regrimaçasse": ("regrimacer",),
    "regrimaçassiez": ("regrimacer",),
    "regrimaçassions": ("regrimacer",),
    "regrimaçâtes": ("regrimacer",),
    "regrimaçât": ("regrimacer",),
    "regrimacée": ("regrimacer",),
    "regrimacées": ("regrimacer",),
    "regrimacé": ("regrimacer",),
    "regrimacent": ("regrimacer",),
    "regrimace": ("regrimacer",),
    "regrimacera": ("regrimacer",),
    "regrimaceraient": ("regrimacer",),
    "regrimacerai": ("regrimacer",),
    "regrimacerais": ("regrimacer",),
    "regrimacerait": ("regrimacer",),
    "regrimaceras": ("regrimacer",),
    "regrimacèrent": ("regrimacer",),
    "regrimacerez": ("regrimacer",),
    "regrimaceriez": ("regrimacer",),
    "regrimacerions": ("regrimacer",),
    "regrimacerons": ("regrimacer",),
    "regrimaceront": ("regrimacer",),
    "regrimacés": ("regrimacer",),
    "regrimaces": ("regrimacer",),
    "regrimacez": ("regrimacer",),
    "regrimaciez": ("regrimacer",),
    "regrimacions": ("regrimacer",),
    "regrimaçons": ("regrimacer",),
    "regrossi": ("regrossir",),
    "regrossîmes": ("regrossir",),
    "regrossira": ("regrossir",),
    "regrossiraient": ("regrossir",),
    "regrossirai": ("regrossir",),
    "regrossirais": ("regrossir",),
    "regrossirait": ("regrossir",),
    "regrossiras": ("regrossir",),
    "regrossirent": ("regrossir",),
    "regrossirez": ("regrossir",),
    "regrossiriez": ("regrossir",),
    "regrossirions": ("regrossir",),
    "regrossirons": ("regrossir",),
    "regrossiront": ("regrossir",),
    "regrossis": ("regrossir",),
    "regrossissaient": ("regrossir",),
    "regrossissais": ("regrossir",),
    "regrossissait": ("regrossir",),
    "regrossissant": ("regrossir",),
    "regrossissent": ("regrossir",),
    "regrossisse": ("regrossir",),
    "regrossisses": ("regrossir",),
    "regrossissez": ("regrossir",),
    "regrossissiez": ("regrossir",),
    "regrossissions": ("regrossir",),
    "regrossissons": ("regrossir",),
    "regrossîtes": ("regrossir",),
    "regrossit": ("regrossir",),
    "regrossît": ("regrossir",),
    "rehypothéquaient": ("rehypothéquer",),
    "rehypothéquai": ("rehypothéquer",),
    "rehypothéquais": ("rehypothéquer",),
    "rehypothéquait": ("rehypothéquer",),
    "rehypothéqua": ("rehypothéquer",),
    "rehypothéquâmes": ("rehypothéquer",),
    "rehypothéquant": ("rehypothéquer",),
    "rehypothéquas": ("rehypothéquer",),
    "rehypothéquassent": ("rehypothéquer",),
    "rehypothéquasses": ("rehypothéquer",),
    "rehypothéquasse": ("rehypothéquer",),
    "rehypothéquassiez": ("rehypothéquer",),
    "rehypothéquassions": ("rehypothéquer",),
    "rehypothéquâtes": ("rehypothéquer",),
    "rehypothéquât": ("rehypothéquer",),
    "rehypothéquée": ("rehypothéquer",),
    "rehypothéquées": ("rehypothéquer",),
    "rehypothéqué": ("rehypothéquer",),
    "rehypothèquent": ("rehypothéquer",),
    "rehypothèque": ("rehypothéquer",),
    "rehypothéquera": ("rehypothéquer",),
    "rehypothéqueraient": ("rehypothéquer",),
    "rehypothéquerai": ("rehypothéquer",),
    "rehypothéquerais": ("rehypothéquer",),
    "rehypothéquerait": ("rehypothéquer",),
    "rehypothéqueras": ("rehypothéquer",),
    "rehypothéquèrent": ("rehypothéquer",),
    "rehypothéquerez": ("rehypothéquer",),
    "rehypothéqueriez": ("rehypothéquer",),
    "rehypothéquerions": ("rehypothéquer",),
    "rehypothéquerons": ("rehypothéquer",),
    "rehypothéqueront": ("rehypothéquer",),
    "rehypothéqués": ("rehypothéquer",),
    "rehypothèques": ("rehypothéquer",),
    "rehypothéquez": ("rehypothéquer",),
    "rehypothéquiez": ("rehypothéquer",),
    "rehypothéquions": ("rehypothéquer",),
    "rehypothéquons": ("rehypothéquer",),
    "réifiaient": ("réifier",),
    "réifiai": ("réifier",),
    "réifiais": ("réifier",),
    "réifiait": ("réifier",),
    "réifia": ("réifier",),
    "réifiâmes": ("réifier",),
    "réifiant": ("réifier",),
    "réifias": ("réifier",),
    "réifiassent": ("réifier",),
    "réifiasses": ("réifier",),
    "réifiasse": ("réifier",),
    "réifiassiez": ("réifier",),
    "réifiassions": ("réifier",),
    "réifiâtes": ("réifier",),
    "réifiât": ("réifier",),
    "réifiée": ("réifier",),
    "réifiées": ("réifier",),
    "réifié": ("réifier",),
    "réifient": ("réifier",),
    "réifie": ("réifier",),
    "réifiera": ("réifier",),
    "réifieraient": ("réifier",),
    "réifierai": ("réifier",),
    "réifierais": ("réifier",),
    "réifierait": ("réifier",),
    "réifieras": ("réifier",),
    "réifièrent": ("réifier",),
    "réifierez": ("réifier",),
    "réifieriez": ("réifier",),
    "réifierions": ("réifier",),
    "réifierons": ("réifier",),
    "réifieront": ("réifier",),
    "réifiés": ("réifier",),
    "réifies": ("réifier",),
    "réifiez": ("réifier",),
    "réifiiez": ("réifier",),
    "réifiions": ("réifier",),
    "réifions": ("réifier",),
    "réimmergeaient": ("réimmerger",),
    "réimmergeai": ("réimmerger",),
    "réimmergeais": ("réimmerger",),
    "réimmergeait": ("réimmerger",),
    "réimmergea": ("réimmerger",),
    "réimmergeâmes": ("réimmerger",),
    "réimmergeant": ("réimmerger",),
    "réimmergeas": ("réimmerger",),
    "réimmergeassent": ("réimmerger",),
    "réimmergeasses": ("réimmerger",),
    "réimmergeasse": ("réimmerger",),
    "réimmergeassiez": ("réimmerger",),
    "réimmergeassions": ("réimmerger",),
    "réimmergeâtes": ("réimmerger",),
    "réimmergeât": ("réimmerger",),
    "réimmergée": ("réimmerger",),
    "réimmergées": ("réimmerger",),
    "réimmergé": ("réimmerger",),
    "réimmergent": ("réimmerger",),
    "réimmergeons": ("réimmerger",),
    "réimmerge": ("réimmerger",),
    "réimmergera": ("réimmerger",),
    "réimmergeraient": ("réimmerger",),
    "réimmergerai": ("réimmerger",),
    "réimmergerais": ("réimmerger",),
    "réimmergerait": ("réimmerger",),
    "réimmergeras": ("réimmerger",),
    "réimmergèrent": ("réimmerger",),
    "réimmergerez": ("réimmerger",),
    "réimmergeriez": ("réimmerger",),
    "réimmergerions": ("réimmerger",),
    "réimmergerons": ("réimmerger",),
    "réimmergeront": ("réimmerger",),
    "réimmergés": ("réimmerger",),
    "réimmerges": ("réimmerger",),
    "réimmergez": ("réimmerger",),
    "réimmergiez": ("réimmerger",),
    "réimmergions": ("réimmerger",),
    "réimmisçaient": ("réimmiscer",),
    "réimmisçai": ("réimmiscer",),
    "réimmisçais": ("réimmiscer",),
    "réimmisçait": ("réimmiscer",),
    "réimmisça": ("réimmiscer",),
    "réimmisçâmes": ("réimmiscer",),
    "réimmisçant": ("réimmiscer",),
    "réimmisças": ("réimmiscer",),
    "réimmisçassent": ("réimmiscer",),
    "réimmisçasses": ("réimmiscer",),
    "réimmisçasse": ("réimmiscer",),
    "réimmisçassiez": ("réimmiscer",),
    "réimmisçassions": ("réimmiscer",),
    "réimmisçâtes": ("réimmiscer",),
    "réimmisçât": ("réimmiscer",),
    "réimmiscée": ("réimmiscer",),
    "réimmiscées": ("réimmiscer",),
    "réimmiscé": ("réimmiscer",),
    "réimmiscent": ("réimmiscer",),
    "réimmisce": ("réimmiscer",),
    "réimmiscera": ("réimmiscer",),
    "réimmisceraient": ("réimmiscer",),
    "réimmiscerai": ("réimmiscer",),
    "réimmiscerais": ("réimmiscer",),
    "réimmiscerait": ("réimmiscer",),
    "réimmisceras": ("réimmiscer",),
    "réimmiscèrent": ("réimmiscer",),
    "réimmiscerez": ("réimmiscer",),
    "réimmisceriez": ("réimmiscer",),
    "réimmiscerions": ("réimmiscer",),
    "réimmiscerons": ("réimmiscer",),
    "réimmisceront": ("réimmiscer",),
    "réimmiscés": ("réimmiscer",),
    "réimmisces": ("réimmiscer",),
    "réimmiscez": ("réimmiscer",),
    "réimmisciez": ("réimmiscer",),
    "réimmiscions": ("réimmiscer",),
    "réimmisçons": ("réimmiscer",),
    "réimprégnaient": ("réimprégner",),
    "réimprégnai": ("réimprégner",),
    "réimprégnais": ("réimprégner",),
    "réimprégnait": ("réimprégner",),
    "réimprégna": ("réimprégner",),
    "réimprégnâmes": ("réimprégner",),
    "réimprégnant": ("réimprégner",),
    "réimprégnas": ("réimprégner",),
    "réimprégnassent": ("réimprégner",),
    "réimprégnasses": ("réimprégner",),
    "réimprégnasse": ("réimprégner",),
    "réimprégnassiez": ("réimprégner",),
    "réimprégnassions": ("réimprégner",),
    "réimprégnâtes": ("réimprégner",),
    "réimprégnât": ("réimprégner",),
    "réimprégnée": ("réimprégner",),
    "réimprégnées": ("réimprégner",),
    "réimprégné": ("réimprégner",),
    "réimprègnent": ("réimprégner",),
    "réimprègne": ("réimprégner",),
    "réimprégnera": ("réimprégner",),
    "réimprégneraient": ("réimprégner",),
    "réimprégnerai": ("réimprégner",),
    "réimprégnerais": ("réimprégner",),
    "réimprégnerait": ("réimprégner",),
    "réimprégneras": ("réimprégner",),
    "réimprégnèrent": ("réimprégner",),
    "réimprégnerez": ("réimprégner",),
    "réimprégneriez": ("réimprégner",),
    "réimprégnerions": ("réimprégner",),
    "réimprégnerons": ("réimprégner",),
    "réimprégneront": ("réimprégner",),
    "réimprégnés": ("réimprégner",),
    "réimprègnes": ("réimprégner",),
    "réimprégnez": ("réimprégner",),
    "réimprégniez": ("réimprégner",),
    "réimprégnions": ("réimprégner",),
    "réimprégnons": ("réimprégner",),
    "réincarcéraient": ("réincarcérer",),
    "réincarcérai": ("réincarcérer",),
    "réincarcérais": ("réincarcérer",),
    "réincarcérait": ("réincarcérer",),
    "réincarcéra": ("réincarcérer",),
    "réincarcérâmes": ("réincarcérer",),
    "réincarcérant": ("réincarcérer",),
    "réincarcéras": ("réincarcérer",),
    "réincarcérassent": ("réincarcérer",),
    "réincarcérasses": ("réincarcérer",),
    "réincarcérasse": ("réincarcérer",),
    "réincarcérassiez": ("réincarcérer",),
    "réincarcérassions": ("réincarcérer",),
    "réincarcérâtes": ("réincarcérer",),
    "réincarcérât": ("réincarcérer",),
    "réincarcérée": ("réincarcérer",),
    "réincarcérées": ("réincarcérer",),
    "réincarcéré": ("réincarcérer",),
    "réincarcèrent": ("réincarcérer",),
    "réincarcère": ("réincarcérer",),
    "réincarcérera": ("réincarcérer",),
    "réincarcéreraient": ("réincarcérer",),
    "réincarcérerai": ("réincarcérer",),
    "réincarcérerais": ("réincarcérer",),
    "réincarcérerait": ("réincarcérer",),
    "réincarcéreras": ("réincarcérer",),
    "réincarcérèrent": ("réincarcérer",),
    "réincarcérerez": ("réincarcérer",),
    "réincarcéreriez": ("réincarcérer",),
    "réincarcérerions": ("réincarcérer",),
    "réincarcérerons": ("réincarcérer",),
    "réincarcéreront": ("réincarcérer",),
    "réincarcérés": ("réincarcérer",),
    "réincarcères": ("réincarcérer",),
    "réincarcérez": ("réincarcérer",),
    "réincarcériez": ("réincarcérer",),
    "réincarcérions": ("réincarcérer",),
    "réincarcérons": ("réincarcérer",),
    "réindiçaient": ("réindicer",),
    "réindiçai": ("réindicer",),
    "réindiçais": ("réindicer",),
    "réindiçait": ("réindicer",),
    "réindiça": ("réindicer",),
    "réindiçâmes": ("réindicer",),
    "réindiçant": ("réindicer",),
    "réindiças": ("réindicer",),
    "réindiçassent": ("réindicer",),
    "réindiçasses": ("réindicer",),
    "réindiçasse": ("réindicer",),
    "réindiçassiez": ("réindicer",),
    "réindiçassions": ("réindicer",),
    "réindiçâtes": ("réindicer",),
    "réindiçât": ("réindicer",),
    "réindicée": ("réindicer",),
    "réindicées": ("réindicer",),
    "réindicé": ("réindicer",),
    "réindicent": ("réindicer",),
    "réindice": ("réindicer",),
    "réindicera": ("réindicer",),
    "réindiceraient": ("réindicer",),
    "réindicerai": ("réindicer",),
    "réindicerais": ("réindicer",),
    "réindicerait": ("réindicer",),
    "réindiceras": ("réindicer",),
    "réindicèrent": ("réindicer",),
    "réindicerez": ("réindicer",),
    "réindiceriez": ("réindicer",),
    "réindicerions": ("réindicer",),
    "réindicerons": ("réindicer",),
    "réindiceront": ("réindicer",),
    "réindicés": ("réindicer",),
    "réindices": ("réindicer",),
    "réindicez": ("réindicer",),
    "réindiciez": ("réindicer",),
    "réindicions": ("réindicer",),
    "réindiçons": ("réindicer",),
    "réinfluençaient": ("réinfluencer",),
    "réinfluençai": ("réinfluencer",),
    "réinfluençais": ("réinfluencer",),
    "réinfluençait": ("réinfluencer",),
    "réinfluença": ("réinfluencer",),
    "réinfluençâmes": ("réinfluencer",),
    "réinfluençant": ("réinfluencer",),
    "réinfluenças": ("réinfluencer",),
    "réinfluençassent": ("réinfluencer",),
    "réinfluençasses": ("réinfluencer",),
    "réinfluençasse": ("réinfluencer",),
    "réinfluençassiez": ("réinfluencer",),
    "réinfluençassions": ("réinfluencer",),
    "réinfluençâtes": ("réinfluencer",),
    "réinfluençât": ("réinfluencer",),
    "réinfluencée": ("réinfluencer",),
    "réinfluencées": ("réinfluencer",),
    "réinfluencé": ("réinfluencer",),
    "réinfluencent": ("réinfluencer",),
    "réinfluence": ("réinfluencer",),
    "réinfluencera": ("réinfluencer",),
    "réinfluenceraient": ("réinfluencer",),
    "réinfluencerai": ("réinfluencer",),
    "réinfluencerais": ("réinfluencer",),
    "réinfluencerait": ("réinfluencer",),
    "réinfluenceras": ("réinfluencer",),
    "réinfluencèrent": ("réinfluencer",),
    "réinfluencerez": ("réinfluencer",),
    "réinfluenceriez": ("réinfluencer",),
    "réinfluencerions": ("réinfluencer",),
    "réinfluencerons": ("réinfluencer",),
    "réinfluenceront": ("réinfluencer",),
    "réinfluencés": ("réinfluencer",),
    "réinfluences": ("réinfluencer",),
    "réinfluencez": ("réinfluencer",),
    "réinfluenciez": ("réinfluencer",),
    "réinfluencions": ("réinfluencer",),
    "réinfluençons": ("réinfluencer",),
    "réingéraient": ("réingérer",),
    "réingérai": ("réingérer",),
    "réingérais": ("réingérer",),
    "réingérait": ("réingérer",),
    "réingéra": ("réingérer",),
    "réingérâmes": ("réingérer",),
    "réingérant": ("réingérer",),
    "réingéras": ("réingérer",),
    "réingérassent": ("réingérer",),
    "réingérasses": ("réingérer",),
    "réingérasse": ("réingérer",),
    "réingérassiez": ("réingérer",),
    "réingérassions": ("réingérer",),
    "réingérâtes": ("réingérer",),
    "réingérât": ("réingérer",),
    "réingérée": ("réingérer",),
    "réingérées": ("réingérer",),
    "réingéré": ("réingérer",),
    "réingèrent": ("réingérer",),
    "réingère": ("réingérer",),
    "réingérera": ("réingérer",),
    "réingéreraient": ("réingérer",),
    "réingérerai": ("réingérer",),
    "réingérerais": ("réingérer",),
    "réingérerait": ("réingérer",),
    "réingéreras": ("réingérer",),
    "réingérèrent": ("réingérer",),
    "réingérerez": ("réingérer",),
    "réingéreriez": ("réingérer",),
    "réingérerions": ("réingérer",),
    "réingérerons": ("réingérer",),
    "réingéreront": ("réingérer",),
    "réingérés": ("réingérer",),
    "réingères": ("réingérer",),
    "réingérez": ("réingérer",),
    "réingériez": ("réingérer",),
    "réingérions": ("réingérer",),
    "réingérons": ("réingérer",),
    "réinscrira": ("réinscrire",),
    "réinscriraient": ("réinscrire",),
    "réinscrirai": ("réinscrire",),
    "réinscrirais": ("réinscrire",),
    "réinscrirait": ("réinscrire",),
    "réinscriras": ("réinscrire",),
    "réinscrirez": ("réinscrire",),
    "réinscririez": ("réinscrire",),
    "réinscririons": ("réinscrire",),
    "réinscrirons": ("réinscrire",),
    "réinscriront": ("réinscrire",),
    "réinscris": ("réinscrire",),
    "réinscrite": ("réinscrire",),
    "réinscrites": ("réinscrire",),
    "réinscrit": ("réinscrire",),
    "réinscrits": ("réinscrire",),
    "réinscrivaient": ("réinscrire",),
    "réinscrivais": ("réinscrire",),
    "réinscrivait": ("réinscrire",),
    "réinscrivant": ("réinscrire",),
    "réinscrivent": ("réinscrire",),
    "réinscrive": ("réinscrire",),
    "réinscrives": ("réinscrire",),
    "réinscrivez": ("réinscrire",),
    "réinscriviez": ("réinscrire",),
    "réinscrivîmes": ("réinscrire",),
    "réinscrivions": ("réinscrire",),
    "réinscrivirent": ("réinscrire",),
    "réinscrivis": ("réinscrire",),
    "réinscrivissent": ("réinscrire",),
    "réinscrivisses": ("réinscrire",),
    "réinscrivisse": ("réinscrire",),
    "réinscrivissiez": ("réinscrire",),
    "réinscrivissions": ("réinscrire",),
    "réinscrivîtes": ("réinscrire",),
    "réinscrivit": ("réinscrire",),
    "réinscrivît": ("réinscrire",),
    "réinscrivons": ("réinscrire",),
    "réinséraient": ("réinsérer",),
    "réinsérai": ("réinsérer",),
    "réinsérais": ("réinsérer",),
    "réinsérait": ("réinsérer",),
    "réinséra": ("réinsérer",),
    "réinsérâmes": ("réinsérer",),
    "réinsérant": ("réinsérer",),
    "réinséras": ("réinsérer",),
    "réinsérassent": ("réinsérer",),
    "réinsérasses": ("réinsérer",),
    "réinsérasse": ("réinsérer",),
    "réinsérassiez": ("réinsérer",),
    "réinsérassions": ("réinsérer",),
    "réinsérâtes": ("réinsérer",),
    "réinsérât": ("réinsérer",),
    "réinsérée": ("réinsérer",),
    "réinsérées": ("réinsérer",),
    "réinséré": ("réinsérer",),
    "réinsèrent": ("réinsérer",),
    "réinsère": ("réinsérer",),
    "réinsérera": ("réinsérer",),
    "réinséreraient": ("réinsérer",),
    "réinsérerai": ("réinsérer",),
    "réinsérerais": ("réinsérer",),
    "réinsérerait": ("réinsérer",),
    "réinséreras": ("réinsérer",),
    "réinsérèrent": ("réinsérer",),
    "réinsérerez": ("réinsérer",),
    "réinséreriez": ("réinsérer",),
    "réinsérerions": ("réinsérer",),
    "réinsérerons": ("réinsérer",),
    "réinséreront": ("réinsérer",),
    "réinsérés": ("réinsérer",),
    "réinsères": ("réinsérer",),
    "réinsérez": ("réinsérer",),
    "réinsériez": ("réinsérer",),
    "réinsérions": ("réinsérer",),
    "réinsérons": ("réinsérer",),
    "réintégraient": ("réintégrer",),
    "réintégrai": ("réintégrer",),
    "réintégrais": ("réintégrer",),
    "réintégrait": ("réintégrer",),
    "réintégra": ("réintégrer",),
    "réintégrâmes": ("réintégrer",),
    "réintégrant": ("réintégrer",),
    "réintégras": ("réintégrer",),
    "réintégrassent": ("réintégrer",),
    "réintégrasses": ("réintégrer",),
    "réintégrasse": ("réintégrer",),
    "réintégrassiez": ("réintégrer",),
    "réintégrassions": ("réintégrer",),
    "réintégrâtes": ("réintégrer",),
    "réintégrât": ("réintégrer",),
    "réintégrée": ("réintégrer",),
    "réintégrées": ("réintégrer",),
    "réintégré": ("réintégrer",),
    "réintègrent": ("réintégrer",),
    "réintègre": ("réintégrer",),
    "réintégrera": ("réintégrer",),
    "réintégreraient": ("réintégrer",),
    "réintégrerai": ("réintégrer",),
    "réintégrerais": ("réintégrer",),
    "réintégrerait": ("réintégrer",),
    "réintégreras": ("réintégrer",),
    "réintégrèrent": ("réintégrer",),
    "réintégrerez": ("réintégrer",),
    "réintégreriez": ("réintégrer",),
    "réintégrerions": ("réintégrer",),
    "réintégrerons": ("réintégrer",),
    "réintégreront": ("réintégrer",),
    "réintégrés": ("réintégrer",),
    "réintègres": ("réintégrer",),
    "réintégrez": ("réintégrer",),
    "réintégriez": ("réintégrer",),
    "réintégrions": ("réintégrer",),
    "réintégrons": ("réintégrer",),
    "réinterprétaient": ("réinterpréter",),
    "réinterprétai": ("réinterpréter",),
    "réinterprétais": ("réinterpréter",),
    "réinterprétait": ("réinterpréter",),
    "réinterpréta": ("réinterpréter",),
    "réinterprétâmes": ("réinterpréter",),
    "réinterprétant": ("réinterpréter",),
    "réinterprétas": ("réinterpréter",),
    "réinterprétassent": ("réinterpréter",),
    "réinterprétasses": ("réinterpréter",),
    "réinterprétasse": ("réinterpréter",),
    "réinterprétassiez": ("réinterpréter",),
    "réinterprétassions": ("réinterpréter",),
    "réinterprétâtes": ("réinterpréter",),
    "réinterprétât": ("réinterpréter",),
    "réinterprétée": ("réinterpréter",),
    "réinterprétées": ("réinterpréter",),
    "réinterprété": ("réinterpréter",),
    "réinterprètent": ("réinterpréter",),
    "réinterprète": ("réinterpréter",),
    "réinterprétera": ("réinterpréter",),
    "réinterpréteraient": ("réinterpréter",),
    "réinterpréterai": ("réinterpréter",),
    "réinterpréterais": ("réinterpréter",),
    "réinterpréterait": ("réinterpréter",),
    "réinterpréteras": ("réinterpréter",),
    "réinterprétèrent": ("réinterpréter",),
    "réinterpréterez": ("réinterpréter",),
    "réinterpréteriez": ("réinterpréter",),
    "réinterpréterions": ("réinterpréter",),
    "réinterpréterons": ("réinterpréter",),
    "réinterpréteront": ("réinterpréter",),
    "réinterprétés": ("réinterpréter",),
    "réinterprètes": ("réinterpréter",),
    "réinterprétez": ("réinterpréter",),
    "réinterprétiez": ("réinterpréter",),
    "réinterprétions": ("réinterpréter",),
    "réinterprétons": ("réinterpréter",),
    "réinterrogeaient": ("réinterroger",),
    "réinterrogeai": ("réinterroger",),
    "réinterrogeais": ("réinterroger",),
    "réinterrogeait": ("réinterroger",),
    "réinterrogea": ("réinterroger",),
    "réinterrogeâmes": ("réinterroger",),
    "réinterrogeant": ("réinterroger",),
    "réinterrogeas": ("réinterroger",),
    "réinterrogeassent": ("réinterroger",),
    "réinterrogeasses": ("réinterroger",),
    "réinterrogeasse": ("réinterroger",),
    "réinterrogeassiez": ("réinterroger",),
    "réinterrogeassions": ("réinterroger",),
    "réinterrogeâtes": ("réinterroger",),
    "réinterrogeât": ("réinterroger",),
    "réinterrogée": ("réinterroger",),
    "réinterrogées": ("réinterroger",),
    "réinterrogé": ("réinterroger",),
    "réinterrogent": ("réinterroger",),
    "réinterrogeons": ("réinterroger",),
    "réinterroge": ("réinterroger",),
    "réinterrogera": ("réinterroger",),
    "réinterrogeraient": ("réinterroger",),
    "réinterrogerai": ("réinterroger",),
    "réinterrogerais": ("réinterroger",),
    "réinterrogerait": ("réinterroger",),
    "réinterrogeras": ("réinterroger",),
    "réinterrogèrent": ("réinterroger",),
    "réinterrogerez": ("réinterroger",),
    "réinterrogeriez": ("réinterroger",),
    "réinterrogerions": ("réinterroger",),
    "réinterrogerons": ("réinterroger",),
    "réinterrogeront": ("réinterroger",),
    "réinterrogés": ("réinterroger",),
    "réinterroges": ("réinterroger",),
    "réinterrogez": ("réinterroger",),
    "réinterrogiez": ("réinterroger",),
    "réinterrogions": ("réinterroger",),
    "réintervenaient": ("réintervenir",),
    "réintervenais": ("réintervenir",),
    "réintervenait": ("réintervenir",),
    "réintervenant": ("réintervenir",),
    "réintervenez": ("réintervenir",),
    "réinterveniez": ("réintervenir",),
    "réintervenions": ("réintervenir",),
    "réintervenons": ("réintervenir",),
    "réintervenue": ("réintervenir",),
    "réintervenues": ("réintervenir",),
    "réintervenu": ("réintervenir",),
    "réintervenus": ("réintervenir",),
    "réinterviendra": ("réintervenir",),
    "réinterviendraient": ("réintervenir",),
    "réinterviendrai": ("réintervenir",),
    "réinterviendrais": ("réintervenir",),
    "réinterviendrait": ("réintervenir",),
    "réinterviendras": ("réintervenir",),
    "réinterviendrez": ("réintervenir",),
    "réinterviendriez": ("réintervenir",),
    "réinterviendrions": ("réintervenir",),
    "réinterviendrons": ("réintervenir",),
    "réinterviendront": ("réintervenir",),
    "réinterviennent": ("réintervenir",),
    "réintervienne": ("réintervenir",),
    "réinterviennes": ("réintervenir",),
    "réinterviens": ("réintervenir",),
    "réintervient": ("réintervenir",),
    "réintervînmes": ("réintervenir",),
    "réintervinrent": ("réintervenir",),
    "réintervins": ("réintervenir",),
    "réintervinssent": ("réintervenir",),
    "réintervinsses": ("réintervenir",),
    "réintervinsse": ("réintervenir",),
    "réintervinssiez": ("réintervenir",),
    "réintervinssions": ("réintervenir",),
    "réintervîntes": ("réintervenir",),
    "réintervint": ("réintervenir",),
    "réintervînt": ("réintervenir",),
    "réintroduira": ("réintroduire",),
    "réintroduiraient": ("réintroduire",),
    "réintroduirai": ("réintroduire",),
    "réintroduirais": ("réintroduire",),
    "réintroduirait": ("réintroduire",),
    "réintroduiras": ("réintroduire",),
    "réintroduirez": ("réintroduire",),
    "réintroduiriez": ("réintroduire",),
    "réintroduirions": ("réintroduire",),
    "réintroduirons": ("réintroduire",),
    "réintroduiront": ("réintroduire",),
    "réintroduisaient": ("réintroduire",),
    "réintroduisais": ("réintroduire",),
    "réintroduisait": ("réintroduire",),
    "réintroduisant": ("réintroduire",),
    "réintroduisent": ("réintroduire",),
    "réintroduise": ("réintroduire",),
    "réintroduises": ("réintroduire",),
    "réintroduisez": ("réintroduire",),
    "réintroduisiez": ("réintroduire",),
    "réintroduisîmes": ("réintroduire",),
    "réintroduisions": ("réintroduire",),
    "réintroduisirent": ("réintroduire",),
    "réintroduisis": ("réintroduire",),
    "réintroduisissent": ("réintroduire",),
    "réintroduisisses": ("réintroduire",),
    "réintroduisisse": ("réintroduire",),
    "réintroduisissiez": ("réintroduire",),
    "réintroduisissions": ("réintroduire",),
    "réintroduisîtes": ("réintroduire",),
    "réintroduisit": ("réintroduire",),
    "réintroduisît": ("réintroduire",),
    "réintroduisons": ("réintroduire",),
    "réintroduis": ("réintroduire",),
    "réintroduite": ("réintroduire",),
    "réintroduites": ("réintroduire",),
    "réintroduit": ("réintroduire",),
    "réintroduits": ("réintroduire",),
    "réinvestie": ("réinvestir",),
    "réinvesties": ("réinvestir",),
    "réinvesti": ("réinvestir",),
    "réinvestîmes": ("réinvestir",),
    "réinvestira": ("réinvestir",),
    "réinvestiraient": ("réinvestir",),
    "réinvestirai": ("réinvestir",),
    "réinvestirais": ("réinvestir",),
    "réinvestirait": ("réinvestir",),
    "réinvestiras": ("réinvestir",),
    "réinvestirent": ("réinvestir",),
    "réinvestirez": ("réinvestir",),
    "réinvestiriez": ("réinvestir",),
    "réinvestirions": ("réinvestir",),
    "réinvestirons": ("réinvestir",),
    "réinvestiront": ("réinvestir",),
    "réinvestis": ("réinvestir",),
    "réinvestissaient": ("réinvestir",),
    "réinvestissais": ("réinvestir",),
    "réinvestissait": ("réinvestir",),
    "réinvestissant": ("réinvestir",),
    "réinvestissent": ("réinvestir",),
    "réinvestisse": ("réinvestir",),
    "réinvestisses": ("réinvestir",),
    "réinvestissez": ("réinvestir",),
    "réinvestissiez": ("réinvestir",),
    "réinvestissions": ("réinvestir",),
    "réinvestissons": ("réinvestir",),
    "réinvestîtes": ("réinvestir",),
    "réinvestit": ("réinvestir",),
    "réinvestît": ("réinvestir",),
    "réitéraient": ("réitérer",),
    "réitérai": ("réitérer",),
    "réitérais": ("réitérer",),
    "réitérait": ("réitérer",),
    "réitéra": ("réitérer",),
    "réitérâmes": ("réitérer",),
    "réitérant": ("réitérer",),
    "réitéras": ("réitérer",),
    "réitérassent": ("réitérer",),
    "réitérasses": ("réitérer",),
    "réitérasse": ("réitérer",),
    "réitérassiez": ("réitérer",),
    "réitérassions": ("réitérer",),
    "réitérâtes": ("réitérer",),
    "réitérât": ("réitérer",),
    "réitérée": ("réitérer",),
    "réitérées": ("réitérer",),
    "réitéré": ("réitérer",),
    "réitèrent": ("réitérer",),
    "réitère": ("réitérer",),
    "réitérera": ("réitérer",),
    "réitéreraient": ("réitérer",),
    "réitérerai": ("réitérer",),
    "réitérerais": ("réitérer",),
    "réitérerait": ("réitérer",),
    "réitéreras": ("réitérer",),
    "réitérèrent": ("réitérer",),
    "réitérerez": ("réitérer",),
    "réitéreriez": ("réitérer",),
    "réitérerions": ("réitérer",),
    "réitérerons": ("réitérer",),
    "réitéreront": ("réitérer",),
    "réitérés": ("réitérer",),
    "réitères": ("réitérer",),
    "réitérez": ("réitérer",),
    "réitériez": ("réitérer",),
    "réitérions": ("réitérer",),
    "réitérons": ("réitérer",),
    "rejailli": ("rejaillir",),
    "rejaillîmes": ("rejaillir",),
    "rejaillira": ("rejaillir",),
    "rejailliraient": ("rejaillir",),
    "rejaillirai": ("rejaillir",),
    "rejaillirais": ("rejaillir",),
    "rejaillirait": ("rejaillir",),
    "rejailliras": ("rejaillir",),
    "rejaillirent": ("rejaillir",),
    "rejaillirez": ("rejaillir",),
    "rejailliriez": ("rejaillir",),
    "rejaillirions": ("rejaillir",),
    "rejaillirons": ("rejaillir",),
    "rejailliront": ("rejaillir",),
    "rejaillis": ("rejaillir",),
    "rejaillissaient": ("rejaillir",),
    "rejaillissais": ("rejaillir",),
    "rejaillissait": ("rejaillir",),
    "rejaillissant": ("rejaillir",),
    "rejaillissent": ("rejaillir",),
    "rejaillisse": ("rejaillir",),
    "rejaillisses": ("rejaillir",),
    "rejaillissez": ("rejaillir",),
    "rejaillissiez": ("rejaillir",),
    "rejaillissions": ("rejaillir",),
    "rejaillissons": ("rejaillir",),
    "rejaillîtes": ("rejaillir",),
    "rejaillit": ("rejaillir",),
    "rejaillît": ("rejaillir",),
    "rejaugeaient": ("rejauger",),
    "rejaugeai": ("rejauger",),
    "rejaugeais": ("rejauger",),
    "rejaugeait": ("rejauger",),
    "rejaugea": ("rejauger",),
    "rejaugeâmes": ("rejauger",),
    "rejaugeant": ("rejauger",),
    "rejaugeas": ("rejauger",),
    "rejaugeassent": ("rejauger",),
    "rejaugeasses": ("rejauger",),
    "rejaugeasse": ("rejauger",),
    "rejaugeassiez": ("rejauger",),
    "rejaugeassions": ("rejauger",),
    "rejaugeâtes": ("rejauger",),
    "rejaugeât": ("rejauger",),
    "rejaugée": ("rejauger",),
    "rejaugées": ("rejauger",),
    "rejaugé": ("rejauger",),
    "rejaugent": ("rejauger",),
    "rejaugeons": ("rejauger",),
    "rejauge": ("rejauger",),
    "rejaugera": ("rejauger",),
    "rejaugeraient": ("rejauger",),
    "rejaugerai": ("rejauger",),
    "rejaugerais": ("rejauger",),
    "rejaugerait": ("rejauger",),
    "rejaugeras": ("rejauger",),
    "rejaugèrent": ("rejauger",),
    "rejaugerez": ("rejauger",),
    "rejaugeriez": ("rejauger",),
    "rejaugerions": ("rejauger",),
    "rejaugerons": ("rejauger",),
    "rejaugeront": ("rejauger",),
    "rejaugés": ("rejauger",),
    "rejauges": ("rejauger",),
    "rejaugez": ("rejauger",),
    "rejaugiez": ("rejauger",),
    "rejaugions": ("rejauger",),
    "rejetaient": ("rejeter",),
    "rejetai": ("rejeter",),
    "rejetais": ("rejeter",),
    "rejetait": ("rejeter",),
    "rejeta": ("rejeter",),
    "rejetâmes": ("rejeter",),
    "rejetant": ("rejeter",),
    "rejetas": ("rejeter",),
    "rejetassent": ("rejeter",),
    "rejetasses": ("rejeter",),
    "rejetasse": ("rejeter",),
    "rejetassiez": ("rejeter",),
    "rejetassions": ("rejeter",),
    "rejetâtes": ("rejeter",),
    "rejetât": ("rejeter",),
    "rejetée": ("rejeter",),
    "rejetées": ("rejeter",),
    "rejeté": ("rejeter",),
    "rejetèrent": ("rejeter",),
    "rejetés": ("rejeter",),
    "rejetez": ("rejeter",),
    "rejetiez": ("rejeter",),
    "rejetions": ("rejeter",),
    "rejetons": ("rejeter",),
    "rejettent": ("rejeter",),
    "rejette": ("rejeter",),
    "rejettera": ("rejeter",),
    "rejetteraient": ("rejeter",),
    "rejetterai": ("rejeter",),
    "rejetterais": ("rejeter",),
    "rejetterait": ("rejeter",),
    "rejetteras": ("rejeter",),
    "rejetterez": ("rejeter",),
    "rejetteriez": ("rejeter",),
    "rejetterions": ("rejeter",),
    "rejetterons": ("rejeter",),
    "rejetteront": ("rejeter",),
    "rejettes": ("rejeter",),
    "rejoignaient": ("rejoindre",),
    "rejoignais": ("rejoindre",),
    "rejoignait": ("rejoindre",),
    "rejoignant": ("rejoindre",),
    "rejoignent": ("rejoindre",),
    "rejoigne": ("rejoindre",),
    "rejoignes": ("rejoindre",),
    "rejoignez": ("rejoindre",),
    "rejoigniez": ("rejoindre",),
    "rejoignîmes": ("rejoindre",),
    "rejoignions": ("rejoindre",),
    "rejoignirent": ("rejoindre",),
    "rejoignis": ("rejoindre",),
    "rejoignissent": ("rejoindre",),
    "rejoignisses": ("rejoindre",),
    "rejoignisse": ("rejoindre",),
    "rejoignissiez": ("rejoindre",),
    "rejoignissions": ("rejoindre",),
    "rejoignîtes": ("rejoindre",),
    "rejoignit": ("rejoindre",),
    "rejoignît": ("rejoindre",),
    "rejoignons": ("rejoindre",),
    "rejoindra": ("rejoindre",),
    "rejoindraient": ("rejoindre",),
    "rejoindrai": ("rejoindre",),
    "rejoindrais": ("rejoindre",),
    "rejoindrait": ("rejoindre",),
    "rejoindras": ("rejoindre",),
    "rejoindrez": ("rejoindre",),
    "rejoindriez": ("rejoindre",),
    "rejoindrions": ("rejoindre",),
    "rejoindrons": ("rejoindre",),
    "rejoindront": ("rejoindre",),
    "rejoins": ("rejoindre",),
    "rejointe": ("rejoindre",),
    "rejointes": ("rejoindre",),
    "rejoint": ("rejoindre",),
    "rejoints": ("rejoindre",),
    "rejointoient": ("rejointoyer",),
    "rejointoie": ("rejointoyer",),
    "rejointoiera": ("rejointoyer",),
    "rejointoieraient": ("rejointoyer",),
    "rejointoierai": ("rejointoyer",),
    "rejointoierais": ("rejointoyer",),
    "rejointoierait": ("rejointoyer",),
    "rejointoieras": ("rejointoyer",),
    "rejointoierez": ("rejointoyer",),
    "rejointoieriez": ("rejointoyer",),
    "rejointoierions": ("rejointoyer",),
    "rejointoierons": ("rejointoyer",),
    "rejointoieront": ("rejointoyer",),
    "rejointoies": ("rejointoyer",),
    "rejointoyaient": ("rejointoyer",),
    "rejointoyai": ("rejointoyer",),
    "rejointoyais": ("rejointoyer",),
    "rejointoyait": ("rejointoyer",),
    "rejointoya": ("rejointoyer",),
    "rejointoyâmes": ("rejointoyer",),
    "rejointoyant": ("rejointoyer",),
    "rejointoyas": ("rejointoyer",),
    "rejointoyassent": ("rejointoyer",),
    "rejointoyasses": ("rejointoyer",),
    "rejointoyasse": ("rejointoyer",),
    "rejointoyassiez": ("rejointoyer",),
    "rejointoyassions": ("rejointoyer",),
    "rejointoyâtes": ("rejointoyer",),
    "rejointoyât": ("rejointoyer",),
    "rejointoyée": ("rejointoyer",),
    "rejointoyées": ("rejointoyer",),
    "rejointoyé": ("rejointoyer",),
    "rejointoyèrent": ("rejointoyer",),
    "rejointoyés": ("rejointoyer",),
    "rejointoyez": ("rejointoyer",),
    "rejointoyiez": ("rejointoyer",),
    "rejointoyions": ("rejointoyer",),
    "rejointoyons": ("rejointoyer",),
    "réjouie": ("réjouir",),
    "réjouies": ("réjouir",),
    "réjoui": ("réjouir",),
    "réjouîmes": ("réjouir",),
    "réjouira": ("réjouir",),
    "réjouiraient": ("réjouir",),
    "réjouirai": ("réjouir",),
    "réjouirais": ("réjouir",),
    "réjouirait": ("réjouir",),
    "réjouiras": ("réjouir",),
    "réjouirent": ("réjouir",),
    "réjouirez": ("réjouir",),
    "réjouiriez": ("réjouir",),
    "réjouirions": ("réjouir",),
    "réjouirons": ("réjouir",),
    "réjouiront": ("réjouir",),
    "réjouis": ("réjouir",),
    "réjouissaient": ("réjouir",),
    "réjouissais": ("réjouir",),
    "réjouissait": ("réjouir",),
    "réjouissant": ("réjouir",),
    "réjouissent": ("réjouir",),
    "réjouisse": ("réjouir",),
    "réjouisses": ("réjouir",),
    "réjouissez": ("réjouir",),
    "réjouissiez": ("réjouir",),
    "réjouissions": ("réjouir",),
    "réjouissons": ("réjouir",),
    "réjouîtes": ("réjouir",),
    "réjouit": ("réjouir",),
    "réjouît": ("réjouir",),
    "rejugeaient": ("rejuger",),
    "rejugeai": ("rejuger",),
    "rejugeais": ("rejuger",),
    "rejugeait": ("rejuger",),
    "rejugea": ("rejuger",),
    "rejugeâmes": ("rejuger",),
    "rejugeant": ("rejuger",),
    "rejugeas": ("rejuger",),
    "rejugeassent": ("rejuger",),
    "rejugeasses": ("rejuger",),
    "rejugeasse": ("rejuger",),
    "rejugeassiez": ("rejuger",),
    "rejugeassions": ("rejuger",),
    "rejugeâtes": ("rejuger",),
    "rejugeât": ("rejuger",),
    "rejugée": ("rejuger",),
    "rejugées": ("rejuger",),
    "rejugé": ("rejuger",),
    "rejugent": ("rejuger",),
    "rejugeons": ("rejuger",),
    "rejuge": ("rejuger",),
    "rejugera": ("rejuger",),
    "rejugeraient": ("rejuger",),
    "rejugerai": ("rejuger",),
    "rejugerais": ("rejuger",),
    "rejugerait": ("rejuger",),
    "rejugeras": ("rejuger",),
    "rejugèrent": ("rejuger",),
    "rejugerez": ("rejuger",),
    "rejugeriez": ("rejuger",),
    "rejugerions": ("rejuger",),
    "rejugerons": ("rejuger",),
    "rejugeront": ("rejuger",),
    "rejugés": ("rejuger",),
    "rejuges": ("rejuger",),
    "rejugez": ("rejuger",),
    "rejugiez": ("rejuger",),
    "rejugions": ("rejuger",),
    "relaçaient": ("relacer",),
    "relaçai": ("relacer",),
    "relaçais": ("relacer",),
    "relaçait": ("relacer",),
    "relaça": ("relacer",),
    "relaçâmes": ("relacer",),
    "relaçant": ("relacer",),
    "relaças": ("relacer",),
    "relaçassent": ("relacer",),
    "relaçasses": ("relacer",),
    "relaçasse": ("relacer",),
    "relaçassiez": ("relacer",),
    "relaçassions": ("relacer",),
    "relaçâtes": ("relacer",),
    "relaçât": ("relacer",),
    "relacée": ("relacer",),
    "relacées": ("relacer",),
    "relacé": ("relacer",),
    "relacent": ("relacer",),
    "relace": ("relacer",),
    "relacera": ("relacer",),
    "relaceraient": ("relacer",),
    "relacerai": ("relacer",),
    "relacerais": ("relacer",),
    "relacerait": ("relacer",),
    "relaceras": ("relacer",),
    "relacèrent": ("relacer",),
    "relacerez": ("relacer",),
    "relaceriez": ("relacer",),
    "relacerions": ("relacer",),
    "relacerons": ("relacer",),
    "relaceront": ("relacer",),
    "relacés": ("relacer",),
    "relaces": ("relacer",),
    "relacez": ("relacer",),
    "relaciez": ("relacer",),
    "relacions": ("relacer",),
    "relaçons": ("relacer",),
    "relançaient": ("relancer",),
    "relançai": ("relancer",),
    "relançais": ("relancer",),
    "relançait": ("relancer",),
    "relança": ("relancer",),
    "relançâmes": ("relancer",),
    "relançant": ("relancer",),
    "relanças": ("relancer",),
    "relançassent": ("relancer",),
    "relançasses": ("relancer",),
    "relançasse": ("relancer",),
    "relançassiez": ("relancer",),
    "relançassions": ("relancer",),
    "relançâtes": ("relancer",),
    "relançât": ("relancer",),
    "relancée": ("relancer",),
    "relancées": ("relancer",),
    "relancé": ("relancer",),
    "relancent": ("relancer",),
    "relance": ("relancer",),
    "relancera": ("relancer",),
    "relanceraient": ("relancer",),
    "relancerai": ("relancer",),
    "relancerais": ("relancer",),
    "relancerait": ("relancer",),
    "relanceras": ("relancer",),
    "relancèrent": ("relancer",),
    "relancerez": ("relancer",),
    "relanceriez": ("relancer",),
    "relancerions": ("relancer",),
    "relancerons": ("relancer",),
    "relanceront": ("relancer",),
    "relancés": ("relancer",),
    "relances": ("relancer",),
    "relancez": ("relancer",),
    "relanciez": ("relancer",),
    "relancions": ("relancer",),
    "relançons": ("relancer",),
    "rélargie": ("rélargir",),
    "rélargies": ("rélargir",),
    "rélargi": ("rélargir",),
    "rélargîmes": ("rélargir",),
    "rélargira": ("rélargir",),
    "rélargiraient": ("rélargir",),
    "rélargirai": ("rélargir",),
    "rélargirais": ("rélargir",),
    "rélargirait": ("rélargir",),
    "rélargiras": ("rélargir",),
    "rélargirent": ("rélargir",),
    "rélargirez": ("rélargir",),
    "rélargiriez": ("rélargir",),
    "rélargirions": ("rélargir",),
    "rélargirons": ("rélargir",),
    "rélargiront": ("rélargir",),
    "rélargis": ("rélargir",),
    "rélargissaient": ("rélargir",),
    "rélargissais": ("rélargir",),
    "rélargissait": ("rélargir",),
    "rélargissant": ("rélargir",),
    "rélargissent": ("rélargir",),
    "rélargisse": ("rélargir",),
    "rélargisses": ("rélargir",),
    "rélargissez": ("rélargir",),
    "rélargissiez": ("rélargir",),
    "rélargissions": ("rélargir",),
    "rélargissons": ("rélargir",),
    "rélargîtes": ("rélargir",),
    "rélargit": ("rélargir",),
    "rélargît": ("rélargir",),
    "relaient": ("relayer",),
    "relaie": ("relayer",),
    "relaiera": ("relayer",),
    "relaieraient": ("relayer",),
    "relaierai": ("relayer",),
    "relaierais": ("relayer",),
    "relaierait": ("relayer",),
    "relaieras": ("relayer",),
    "relaierez": ("relayer",),
    "relaieriez": ("relayer",),
    "relaierions": ("relayer",),
    "relaierons": ("relayer",),
    "relaieront": ("relayer",),
    "relaies": ("relayer",),
    "relayaient": ("relayer",),
    "relayai": ("relayer",),
    "relayais": ("relayer",),
    "relayait": ("relayer",),
    "relaya": ("relayer",),
    "relayâmes": ("relayer",),
    "relayant": ("relayer",),
    "relayas": ("relayer",),
    "relayassent": ("relayer",),
    "relayasses": ("relayer",),
    "relayasse": ("relayer",),
    "relayassiez": ("relayer",),
    "relayassions": ("relayer",),
    "relayâtes": ("relayer",),
    "relayât": ("relayer",),
    "relayée": ("relayer",),
    "relayées": ("relayer",),
    "relayé": ("relayer",),
    "relayent": ("relayer",),
    "relaye": ("relayer",),
    "relayera": ("relayer",),
    "relayeraient": ("relayer",),
    "relayerai": ("relayer",),
    "relayerais": ("relayer",),
    "relayerait": ("relayer",),
    "relayeras": ("relayer",),
    "relayèrent": ("relayer",),
    "relayerez": ("relayer",),
    "relayeriez": ("relayer",),
    "relayerions": ("relayer",),
    "relayerons": ("relayer",),
    "relayeront": ("relayer",),
    "relayés": ("relayer",),
    "relayes": ("relayer",),
    "relayez": ("relayer",),
    "relayiez": ("relayer",),
    "relayions": ("relayer",),
    "relayons": ("relayer",),
    "reléguaient": ("reléguer",),
    "reléguai": ("reléguer",),
    "reléguais": ("reléguer",),
    "reléguait": ("reléguer",),
    "relégua": ("reléguer",),
    "reléguâmes": ("reléguer",),
    "reléguant": ("reléguer",),
    "reléguas": ("reléguer",),
    "reléguassent": ("reléguer",),
    "reléguasses": ("reléguer",),
    "reléguasse": ("reléguer",),
    "reléguassiez": ("reléguer",),
    "reléguassions": ("reléguer",),
    "reléguâtes": ("reléguer",),
    "reléguât": ("reléguer",),
    "reléguée": ("reléguer",),
    "reléguées": ("reléguer",),
    "relégué": ("reléguer",),
    "relèguent": ("reléguer",),
    "relègue": ("reléguer",),
    "reléguera": ("reléguer",),
    "relégueraient": ("reléguer",),
    "reléguerai": ("reléguer",),
    "reléguerais": ("reléguer",),
    "reléguerait": ("reléguer",),
    "relégueras": ("reléguer",),
    "reléguèrent": ("reléguer",),
    "reléguerez": ("reléguer",),
    "relégueriez": ("reléguer",),
    "reléguerions": ("reléguer",),
    "reléguerons": ("reléguer",),
    "relégueront": ("reléguer",),
    "relégués": ("reléguer",),
    "relègues": ("reléguer",),
    "reléguez": ("reléguer",),
    "reléguiez": ("reléguer",),
    "reléguions": ("reléguer",),
    "reléguons": ("reléguer",),
    "relevaient": ("relever",),
    "relevai": ("relever",),
    "relevais": ("relever",),
    "relevait": ("relever",),
    "releva": ("relever",),
    "relevâmes": ("relever",),
    "relevant": ("relever",),
    "relevas": ("relever",),
    "relevassent": ("relever",),
    "relevasses": ("relever",),
    "relevasse": ("relever",),
    "relevassiez": ("relever",),
    "relevassions": ("relever",),
    "relevâtes": ("relever",),
    "relevât": ("relever",),
    "relevée": ("relever",),
    "relevées": ("relever",),
    "relevé": ("relever",),
    "relèvent": ("relever",),
    "relève": ("relever",),
    "relèvera": ("relever",),
    "relèveraient": ("relever",),
    "relèverai": ("relever",),
    "relèverais": ("relever",),
    "relèverait": ("relever",),
    "relèveras": ("relever",),
    "relevèrent": ("relever",),
    "relèverez": ("relever",),
    "relèveriez": ("relever",),
    "relèverions": ("relever",),
    "relèverons": ("relever",),
    "relèveront": ("relever",),
    "relevés": ("relever",),
    "relèves": ("relever",),
    "relevez": ("relever",),
    "releviez": ("relever",),
    "relevions": ("relever",),
    "relevons": ("relever",),
    "relibéraient": ("relibérer",),
    "relibérai": ("relibérer",),
    "relibérais": ("relibérer",),
    "relibérait": ("relibérer",),
    "relibéra": ("relibérer",),
    "relibérâmes": ("relibérer",),
    "relibérant": ("relibérer",),
    "relibéras": ("relibérer",),
    "relibérassent": ("relibérer",),
    "relibérasses": ("relibérer",),
    "relibérasse": ("relibérer",),
    "relibérassiez": ("relibérer",),
    "relibérassions": ("relibérer",),
    "relibérâtes": ("relibérer",),
    "relibérât": ("relibérer",),
    "relibérée": ("relibérer",),
    "relibérées": ("relibérer",),
    "relibéré": ("relibérer",),
    "relibèrent": ("relibérer",),
    "relibère": ("relibérer",),
    "relibérera": ("relibérer",),
    "relibéreraient": ("relibérer",),
    "relibérerai": ("relibérer",),
    "relibérerais": ("relibérer",),
    "relibérerait": ("relibérer",),
    "relibéreras": ("relibérer",),
    "relibérèrent": ("relibérer",),
    "relibérerez": ("relibérer",),
    "relibéreriez": ("relibérer",),
    "relibérerions": ("relibérer",),
    "relibérerons": ("relibérer",),
    "relibéreront": ("relibérer",),
    "relibérés": ("relibérer",),
    "relibères": ("relibérer",),
    "relibérez": ("relibérer",),
    "relibériez": ("relibérer",),
    "relibérions": ("relibérer",),
    "relibérons": ("relibérer",),
    "relicenciaient": ("relicencier",),
    "relicenciai": ("relicencier",),
    "relicenciais": ("relicencier",),
    "relicenciait": ("relicencier",),
    "relicencia": ("relicencier",),
    "relicenciâmes": ("relicencier",),
    "relicenciant": ("relicencier",),
    "relicencias": ("relicencier",),
    "relicenciassent": ("relicencier",),
    "relicenciasses": ("relicencier",),
    "relicenciasse": ("relicencier",),
    "relicenciassiez": ("relicencier",),
    "relicenciassions": ("relicencier",),
    "relicenciâtes": ("relicencier",),
    "relicenciât": ("relicencier",),
    "relicenciée": ("relicencier",),
    "relicenciées": ("relicencier",),
    "relicencié": ("relicencier",),
    "relicencient": ("relicencier",),
    "relicencie": ("relicencier",),
    "relicenciera": ("relicencier",),
    "relicencieraient": ("relicencier",),
    "relicencierai": ("relicencier",),
    "relicencierais": ("relicencier",),
    "relicencierait": ("relicencier",),
    "relicencieras": ("relicencier",),
    "relicencièrent": ("relicencier",),
    "relicencierez": ("relicencier",),
    "relicencieriez": ("relicencier",),
    "relicencierions": ("relicencier",),
    "relicencierons": ("relicencier",),
    "relicencieront": ("relicencier",),
    "relicenciés": ("relicencier",),
    "relicencies": ("relicencier",),
    "relicenciez": ("relicencier",),
    "relicenciiez": ("relicencier",),
    "relicenciions": ("relicencier",),
    "relicencions": ("relicencier",),
    "reliaient": ("relier",),
    "reliai": ("relier",),
    "reliais": ("relier",),
    "reliait": ("relier",),
    "relia": ("relier",),
    "reliâmes": ("relier",),
    "reliant": ("relier",),
    "relias": ("relier",),
    "reliassent": ("relier",),
    "reliasses": ("relier",),
    "reliasse": ("relier",),
    "reliassiez": ("relier",),
    "reliassions": ("relier",),
    "reliâtes": ("relier",),
    "reliât": ("relier",),
    "reliée": ("relier",),
    "reliées": ("relier",),
    "relié": ("relier",),
    "relient": ("relier",),
    "relie": ("relier",),
    "reliera": ("relier",),
    "relieraient": ("relier",),
    "relierai": ("relier",),
    "relierais": ("relier",),
    "relierait": ("relier",),
    "relieras": ("relier",),
    "relièrent": ("relier",),
    "relierez": ("relier",),
    "relieriez": ("relier",),
    "relierions": ("relier",),
    "relierons": ("relier",),
    "relieront": ("relier",),
    "reliés": ("relier",),
    "relies": ("relier",),
    "reliez": ("relier",),
    "reliiez": ("relier",),
    "reliions": ("relier",),
    "relions": ("relier",),
    "relira": ("relire",),
    "reliraient": ("relire",),
    "relirai": ("relire",),
    "relirais": ("relire",),
    "relirait": ("relire",),
    "reliras": ("relire",),
    "relirez": ("relire",),
    "reliriez": ("relire",),
    "relirions": ("relire",),
    "relirons": ("relire",),
    "reliront": ("relire",),
    "relisaient": ("relire",),
    "relisais": ("relire",),
    "relisait": ("relire",),
    "relisant": ("relire",),
    "relisent": ("relire",),
    "relise": ("relire",),
    "relises": ("relire",),
    "relisez": ("relire",),
    "relisiez": ("relire",),
    "relisions": ("relire",),
    "relisons": ("relire",),
    "relis": ("relire",),
    "relit": ("relire",),
    "relue": ("relire",),
    "relues": ("relire",),
    "relu": ("relire",),
    "relûmes": ("relire",),
    "relurent": ("relire",),
    "relus": ("relire",),
    "relussent": ("relire",),
    "relusses": ("relire",),
    "relusse": ("relire",),
    "relussiez": ("relire",),
    "relussions": ("relire",),
    "relûtes": ("relire",),
    "relut": ("relire",),
    "relût": ("relire",),
    "relogeaient": ("reloger",),
    "relogeai": ("reloger",),
    "relogeais": ("reloger",),
    "relogeait": ("reloger",),
    "relogea": ("reloger",),
    "relogeâmes": ("reloger",),
    "relogeant": ("reloger",),
    "relogeas": ("reloger",),
    "relogeassent": ("reloger",),
    "relogeasses": ("reloger",),
    "relogeasse": ("reloger",),
    "relogeassiez": ("reloger",),
    "relogeassions": ("reloger",),
    "relogeâtes": ("reloger",),
    "relogeât": ("reloger",),
    "relogée": ("reloger",),
    "relogées": ("reloger",),
    "relogé": ("reloger",),
    "relogent": ("reloger",),
    "relogeons": ("reloger",),
    "reloge": ("reloger",),
    "relogera": ("reloger",),
    "relogeraient": ("reloger",),
    "relogerai": ("reloger",),
    "relogerais": ("reloger",),
    "relogerait": ("reloger",),
    "relogeras": ("reloger",),
    "relogèrent": ("reloger",),
    "relogerez": ("reloger",),
    "relogeriez": ("reloger",),
    "relogerions": ("reloger",),
    "relogerons": ("reloger",),
    "relogeront": ("reloger",),
    "relogés": ("reloger",),
    "reloges": ("reloger",),
    "relogez": ("reloger",),
    "relogiez": ("reloger",),
    "relogions": ("reloger",),
    "reloquetaient": ("reloqueter",),
    "reloquetai": ("reloqueter",),
    "reloquetais": ("reloqueter",),
    "reloquetait": ("reloqueter",),
    "reloqueta": ("reloqueter",),
    "reloquetâmes": ("reloqueter",),
    "reloquetant": ("reloqueter",),
    "reloquetas": ("reloqueter",),
    "reloquetassent": ("reloqueter",),
    "reloquetasses": ("reloqueter",),
    "reloquetasse": ("reloqueter",),
    "reloquetassiez": ("reloqueter",),
    "reloquetassions": ("reloqueter",),
    "reloquetâtes": ("reloqueter",),
    "reloquetât": ("reloqueter",),
    "reloquetée": ("reloqueter",),
    "reloquetées": ("reloqueter",),
    "reloqueté": ("reloqueter",),
    "reloquetèrent": ("reloqueter",),
    "reloquetés": ("reloqueter",),
    "reloquetez": ("reloqueter",),
    "reloquetiez": ("reloqueter",),
    "reloquetions": ("reloqueter",),
    "reloquetons": ("reloqueter",),
    "reloquettent": ("reloqueter",),
    "reloquette": ("reloqueter",),
    "reloquettera": ("reloqueter",),
    "reloquetteraient": ("reloqueter",),
    "reloquetterai": ("reloqueter",),
    "reloquetterais": ("reloqueter",),
    "reloquetterait": ("reloqueter",),
    "reloquetteras": ("reloqueter",),
    "reloquetterez": ("reloqueter",),
    "reloquetteriez": ("reloqueter",),
    "reloquetterions": ("reloqueter",),
    "reloquetterons": ("reloqueter",),
    "reloquetteront": ("reloqueter",),
    "reloquettes": ("reloqueter",),
    "relubrifiaient": ("relubrifier",),
    "relubrifiai": ("relubrifier",),
    "relubrifiais": ("relubrifier",),
    "relubrifiait": ("relubrifier",),
    "relubrifia": ("relubrifier",),
    "relubrifiâmes": ("relubrifier",),
    "relubrifiant": ("relubrifier",),
    "relubrifias": ("relubrifier",),
    "relubrifiassent": ("relubrifier",),
    "relubrifiasses": ("relubrifier",),
    "relubrifiasse": ("relubrifier",),
    "relubrifiassiez": ("relubrifier",),
    "relubrifiassions": ("relubrifier",),
    "relubrifiâtes": ("relubrifier",),
    "relubrifiât": ("relubrifier",),
    "relubrifiée": ("relubrifier",),
    "relubrifiées": ("relubrifier",),
    "relubrifié": ("relubrifier",),
    "relubrifient": ("relubrifier",),
    "relubrifie": ("relubrifier",),
    "relubrifiera": ("relubrifier",),
    "relubrifieraient": ("relubrifier",),
    "relubrifierai": ("relubrifier",),
    "relubrifierais": ("relubrifier",),
    "relubrifierait": ("relubrifier",),
    "relubrifieras": ("relubrifier",),
    "relubrifièrent": ("relubrifier",),
    "relubrifierez": ("relubrifier",),
    "relubrifieriez": ("relubrifier",),
    "relubrifierions": ("relubrifier",),
    "relubrifierons": ("relubrifier",),
    "relubrifieront": ("relubrifier",),
    "relubrifiés": ("relubrifier",),
    "relubrifies": ("relubrifier",),
    "relubrifiez": ("relubrifier",),
    "relubrifiiez": ("relubrifier",),
    "relubrifiions": ("relubrifier",),
    "relubrifions": ("relubrifier",),
    "relui": ("reluire",),
    "reluîmes": ("reluire",),
    "reluira": ("reluire",),
    "reluiraient": ("reluire",),
    "reluirai": ("reluire",),
    "reluirais": ("reluire",),
    "reluirait": ("reluire",),
    "reluiras": ("reluire",),
    "reluirent": ("reluire",),
    "reluirez": ("reluire",),
    "reluiriez": ("reluire",),
    "reluirions": ("reluire",),
    "reluirons": ("reluire",),
    "reluiront": ("reluire",),
    "reluisaient": ("reluire",),
    "reluisais": ("reluire",),
    "reluisait": ("reluire",),
    "reluisant": ("reluire",),
    "reluisent": ("reluire",),
    "reluise": ("reluire",),
    "reluises": ("reluire",),
    "reluisez": ("reluire",),
    "reluisiez": ("reluire",),
    "reluisîmes": ("reluire",),
    "reluisions": ("reluire",),
    "reluisirent": ("reluire",),
    "reluisis": ("reluire",),
    "reluisissent": ("reluire",),
    "reluisisses": ("reluire",),
    "reluisisse": ("reluire",),
    "reluisissiez": ("reluire",),
    "reluisissions": ("reluire",),
    "reluisîtes": ("reluire",),
    "reluisit": ("reluire",),
    "reluisît": ("reluire",),
    "reluisons": ("reluire",),
    "reluis": ("reluire",),
    "reluîtes": ("reluire",),
    "reluit": ("reluire",),
    "remacéraient": ("remacérer",),
    "remacérai": ("remacérer",),
    "remacérais": ("remacérer",),
    "remacérait": ("remacérer",),
    "remacéra": ("remacérer",),
    "remacérâmes": ("remacérer",),
    "remacérant": ("remacérer",),
    "remacéras": ("remacérer",),
    "remacérassent": ("remacérer",),
    "remacérasses": ("remacérer",),
    "remacérasse": ("remacérer",),
    "remacérassiez": ("remacérer",),
    "remacérassions": ("remacérer",),
    "remacérâtes": ("remacérer",),
    "remacérât": ("remacérer",),
    "remacérée": ("remacérer",),
    "remacérées": ("remacérer",),
    "remacéré": ("remacérer",),
    "remacèrent": ("remacérer",),
    "remacère": ("remacérer",),
    "remacérera": ("remacérer",),
    "remacéreraient": ("remacérer",),
    "remacérerai": ("remacérer",),
    "remacérerais": ("remacérer",),
    "remacérerait": ("remacérer",),
    "remacéreras": ("remacérer",),
    "remacérèrent": ("remacérer",),
    "remacérerez": ("remacérer",),
    "remacéreriez": ("remacérer",),
    "remacérerions": ("remacérer",),
    "remacérerons": ("remacérer",),
    "remacéreront": ("remacérer",),
    "remacérés": ("remacérer",),
    "remacères": ("remacérer",),
    "remacérez": ("remacérer",),
    "remacériez": ("remacérer",),
    "remacérions": ("remacérer",),
    "remacérons": ("remacérer",),
    "remaigrie": ("remaigrir",),
    "remaigries": ("remaigrir",),
    "remaigri": ("remaigrir",),
    "remaigrîmes": ("remaigrir",),
    "remaigrira": ("remaigrir",),
    "remaigriraient": ("remaigrir",),
    "remaigrirai": ("remaigrir",),
    "remaigrirais": ("remaigrir",),
    "remaigrirait": ("remaigrir",),
    "remaigriras": ("remaigrir",),
    "remaigrirent": ("remaigrir",),
    "remaigrirez": ("remaigrir",),
    "remaigririez": ("remaigrir",),
    "remaigririons": ("remaigrir",),
    "remaigrirons": ("remaigrir",),
    "remaigriront": ("remaigrir",),
    "remaigris": ("remaigrir",),
    "remaigrissaient": ("remaigrir",),
    "remaigrissais": ("remaigrir",),
    "remaigrissait": ("remaigrir",),
    "remaigrissant": ("remaigrir",),
    "remaigrissent": ("remaigrir",),
    "remaigrisse": ("remaigrir",),
    "remaigrisses": ("remaigrir",),
    "remaigrissez": ("remaigrir",),
    "remaigrissiez": ("remaigrir",),
    "remaigrissions": ("remaigrir",),
    "remaigrissons": ("remaigrir",),
    "remaigrîtes": ("remaigrir",),
    "remaigrit": ("remaigrir",),
    "remaigrît": ("remaigrir",),
    "remangeaient": ("remanger",),
    "remangeai": ("remanger",),
    "remangeais": ("remanger",),
    "remangeait": ("remanger",),
    "remangea": ("remanger",),
    "remangeâmes": ("remanger",),
    "remangeant": ("remanger",),
    "remangeas": ("remanger",),
    "remangeassent": ("remanger",),
    "remangeasses": ("remanger",),
    "remangeasse": ("remanger",),
    "remangeassiez": ("remanger",),
    "remangeassions": ("remanger",),
    "remangeâtes": ("remanger",),
    "remangeât": ("remanger",),
    "remangée": ("remanger",),
    "remangées": ("remanger",),
    "remangé": ("remanger",),
    "remangent": ("remanger",),
    "remangeons": ("remanger",),
    "remange": ("remanger",),
    "remangera": ("remanger",),
    "remangeraient": ("remanger",),
    "remangerai": ("remanger",),
    "remangerais": ("remanger",),
    "remangerait": ("remanger",),
    "remangeras": ("remanger",),
    "remangèrent": ("remanger",),
    "remangerez": ("remanger",),
    "remangeriez": ("remanger",),
    "remangerions": ("remanger",),
    "remangerons": ("remanger",),
    "remangeront": ("remanger",),
    "remangés": ("remanger",),
    "remanges": ("remanger",),
    "remangez": ("remanger",),
    "remangiez": ("remanger",),
    "remangions": ("remanger",),
    "remaniaient": ("remanier",),
    "remaniai": ("remanier",),
    "remaniais": ("remanier",),
    "remaniait": ("remanier",),
    "remania": ("remanier",),
    "remaniâmes": ("remanier",),
    "remaniant": ("remanier",),
    "remanias": ("remanier",),
    "remaniassent": ("remanier",),
    "remaniasses": ("remanier",),
    "remaniasse": ("remanier",),
    "remaniassiez": ("remanier",),
    "remaniassions": ("remanier",),
    "remaniâtes": ("remanier",),
    "remaniât": ("remanier",),
    "remaniée": ("remanier",),
    "remaniées": ("remanier",),
    "remanié": ("remanier",),
    "remanient": ("remanier",),
    "remanie": ("remanier",),
    "remaniera": ("remanier",),
    "remanieraient": ("remanier",),
    "remanierai": ("remanier",),
    "remanierais": ("remanier",),
    "remanierait": ("remanier",),
    "remanieras": ("remanier",),
    "remanièrent": ("remanier",),
    "remanierez": ("remanier",),
    "remanieriez": ("remanier",),
    "remanierions": ("remanier",),
    "remanierons": ("remanier",),
    "remanieront": ("remanier",),
    "remaniés": ("remanier",),
    "remanies": ("remanier",),
    "remaniez": ("remanier",),
    "remaniiez": ("remanier",),
    "remaniions": ("remanier",),
    "remanions": ("remanier",),
    "remanigançaient": ("remanigancer",),
    "remanigançai": ("remanigancer",),
    "remanigançais": ("remanigancer",),
    "remanigançait": ("remanigancer",),
    "remanigança": ("remanigancer",),
    "remanigançâmes": ("remanigancer",),
    "remanigançant": ("remanigancer",),
    "remaniganças": ("remanigancer",),
    "remanigançassent": ("remanigancer",),
    "remanigançasses": ("remanigancer",),
    "remanigançasse": ("remanigancer",),
    "remanigançassiez": ("remanigancer",),
    "remanigançassions": ("remanigancer",),
    "remanigançâtes": ("remanigancer",),
    "remanigançât": ("remanigancer",),
    "remanigancée": ("remanigancer",),
    "remanigancées": ("remanigancer",),
    "remanigancé": ("remanigancer",),
    "remanigancent": ("remanigancer",),
    "remanigance": ("remanigancer",),
    "remanigancera": ("remanigancer",),
    "remaniganceraient": ("remanigancer",),
    "remanigancerai": ("remanigancer",),
    "remanigancerais": ("remanigancer",),
    "remanigancerait": ("remanigancer",),
    "remaniganceras": ("remanigancer",),
    "remanigancèrent": ("remanigancer",),
    "remanigancerez": ("remanigancer",),
    "remaniganceriez": ("remanigancer",),
    "remanigancerions": ("remanigancer",),
    "remanigancerons": ("remanigancer",),
    "remaniganceront": ("remanigancer",),
    "remanigancés": ("remanigancer",),
    "remanigances": ("remanigancer",),
    "remanigancez": ("remanigancer",),
    "remaniganciez": ("remanigancer",),
    "remanigancions": ("remanigancer",),
    "remanigançons": ("remanigancer",),
    "remariaient": ("remarier",),
    "remariai": ("remarier",),
    "remariais": ("remarier",),
    "remariait": ("remarier",),
    "remaria": ("remarier",),
    "remariâmes": ("remarier",),
    "remariant": ("remarier",),
    "remarias": ("remarier",),
    "remariassent": ("remarier",),
    "remariasses": ("remarier",),
    "remariasse": ("remarier",),
    "remariassiez": ("remarier",),
    "remariassions": ("remarier",),
    "remariâtes": ("remarier",),
    "remariât": ("remarier",),
    "remariée": ("remarier",),
    "remariées": ("remarier",),
    "remarié": ("remarier",),
    "remarient": ("remarier",),
    "remarie": ("remarier",),
    "remariera": ("remarier",),
    "remarieraient": ("remarier",),
    "remarierai": ("remarier",),
    "remarierais": ("remarier",),
    "remarierait": ("remarier",),
    "remarieras": ("remarier",),
    "remarièrent": ("remarier",),
    "remarierez": ("remarier",),
    "remarieriez": ("remarier",),
    "remarierions": ("remarier",),
    "remarierons": ("remarier",),
    "remarieront": ("remarier",),
    "remariés": ("remarier",),
    "remaries": ("remarier",),
    "remariez": ("remarier",),
    "remariiez": ("remarier",),
    "remariions": ("remarier",),
    "remarions": ("remarier",),
    "remâtaient": ("remâter",),
    "remâtai": ("remâter",),
    "remâtais": ("remâter",),
    "remâtait": ("remâter",),
    "remâta": ("remâter",),
    "remâtâmes": ("remâter",),
    "remâtant": ("remâter",),
    "remâtas": ("remâter",),
    "remâtassent": ("remâter",),
    "remâtasses": ("remâter",),
    "remâtasse": ("remâter",),
    "remâtassiez": ("remâter",),
    "remâtassions": ("remâter",),
    "remâtâtes": ("remâter",),
    "remâtât": ("remâter",),
    "remâtée": ("remâter",),
    "remâtées": ("remâter",),
    "remâté": ("remâter",),
    "remâtent": ("remâter",),
    "remâte": ("remâter",),
    "remâtera": ("remâter",),
    "remâteraient": ("remâter",),
    "remâterai": ("remâter",),
    "remâterais": ("remâter",),
    "remâterait": ("remâter",),
    "remâteras": ("remâter",),
    "remâtèrent": ("remâter",),
    "remâterez": ("remâter",),
    "remâteriez": ("remâter",),
    "remâterions": ("remâter",),
    "remâterons": ("remâter",),
    "remâteront": ("remâter",),
    "remâtés": ("remâter",),
    "remâtes": ("remâter",),
    "remâtez": ("remâter",),
    "remâtiez": ("remâter",),
    "remâtions": ("remâter",),
    "remâtons": ("remâter",),
    "rematriçaient": ("rematricer",),
    "rematriçai": ("rematricer",),
    "rematriçais": ("rematricer",),
    "rematriçait": ("rematricer",),
    "rematriça": ("rematricer",),
    "rematriçâmes": ("rematricer",),
    "rematriçant": ("rematricer",),
    "rematriças": ("rematricer",),
    "rematriçassent": ("rematricer",),
    "rematriçasses": ("rematricer",),
    "rematriçasse": ("rematricer",),
    "rematriçassiez": ("rematricer",),
    "rematriçassions": ("rematricer",),
    "rematriçâtes": ("rematricer",),
    "rematriçât": ("rematricer",),
    "rematricée": ("rematricer",),
    "rematricées": ("rematricer",),
    "rematricé": ("rematricer",),
    "rematricent": ("rematricer",),
    "rematrice": ("rematricer",),
    "rematricera": ("rematricer",),
    "rematriceraient": ("rematricer",),
    "rematricerai": ("rematricer",),
    "rematricerais": ("rematricer",),
    "rematricerait": ("rematricer",),
    "rematriceras": ("rematricer",),
    "rematricèrent": ("rematricer",),
    "rematricerez": ("rematricer",),
    "rematriceriez": ("rematricer",),
    "rematricerions": ("rematricer",),
    "rematricerons": ("rematricer",),
    "rematriceront": ("rematricer",),
    "rematricés": ("rematricer",),
    "rematrices": ("rematricer",),
    "rematricez": ("rematricer",),
    "rematriciez": ("rematricer",),
    "rematricions": ("rematricer",),
    "rematriçons": ("rematricer",),
    "rembellie": ("rembellir",),
    "rembellies": ("rembellir",),
    "rembelli": ("rembellir",),
    "rembellîmes": ("rembellir",),
    "rembellira": ("rembellir",),
    "rembelliraient": ("rembellir",),
    "rembellirai": ("rembellir",),
    "rembellirais": ("rembellir",),
    "rembellirait": ("rembellir",),
    "rembelliras": ("rembellir",),
    "rembellirent": ("rembellir",),
    "rembellirez": ("rembellir",),
    "rembelliriez": ("rembellir",),
    "rembellirions": ("rembellir",),
    "rembellirons": ("rembellir",),
    "rembelliront": ("rembellir",),
    "rembellis": ("rembellir",),
    "rembellissaient": ("rembellir",),
    "rembellissais": ("rembellir",),
    "rembellissait": ("rembellir",),
    "rembellissant": ("rembellir",),
    "rembellissent": ("rembellir",),
    "rembellisse": ("rembellir",),
    "rembellisses": ("rembellir",),
    "rembellissez": ("rembellir",),
    "rembellissiez": ("rembellir",),
    "rembellissions": ("rembellir",),
    "rembellissons": ("rembellir",),
    "rembellîtes": ("rembellir",),
    "rembellit": ("rembellir",),
    "rembellît": ("rembellir",),
    "remblaient": ("remblayer",),
    "remblaie": ("remblayer",),
    "remblaiera": ("remblayer",),
    "remblaieraient": ("remblayer",),
    "remblaierai": ("remblayer",),
    "remblaierais": ("remblayer",),
    "remblaierait": ("remblayer",),
    "remblaieras": ("remblayer",),
    "remblaierez": ("remblayer",),
    "remblaieriez": ("remblayer",),
    "remblaierions": ("remblayer",),
    "remblaierons": ("remblayer",),
    "remblaieront": ("remblayer",),
    "remblaies": ("remblayer",),
    "remblayaient": ("remblayer",),
    "remblayai": ("remblayer",),
    "remblayais": ("remblayer",),
    "remblayait": ("remblayer",),
    "remblaya": ("remblayer",),
    "remblayâmes": ("remblayer",),
    "remblayant": ("remblayer",),
    "remblayas": ("remblayer",),
    "remblayassent": ("remblayer",),
    "remblayasses": ("remblayer",),
    "remblayasse": ("remblayer",),
    "remblayassiez": ("remblayer",),
    "remblayassions": ("remblayer",),
    "remblayâtes": ("remblayer",),
    "remblayât": ("remblayer",),
    "remblayée": ("remblayer",),
    "remblayées": ("remblayer",),
    "remblayé": ("remblayer",),
    "remblayent": ("remblayer",),
    "remblaye": ("remblayer",),
    "remblayera": ("remblayer",),
    "remblayeraient": ("remblayer",),
    "remblayerai": ("remblayer",),
    "remblayerais": ("remblayer",),
    "remblayerait": ("remblayer",),
    "remblayeras": ("remblayer",),
    "remblayèrent": ("remblayer",),
    "remblayerez": ("remblayer",),
    "remblayeriez": ("remblayer",),
    "remblayerions": ("remblayer",),
    "remblayerons": ("remblayer",),
    "remblayeront": ("remblayer",),
    "remblayés": ("remblayer",),
    "remblayes": ("remblayer",),
    "remblayez": ("remblayer",),
    "remblayiez": ("remblayer",),
    "remblayions": ("remblayer",),
    "remblayons": ("remblayer",),
    "rembougeaient": ("rembouger",),
    "rembougeai": ("rembouger",),
    "rembougeais": ("rembouger",),
    "rembougeait": ("rembouger",),
    "rembougea": ("rembouger",),
    "rembougeâmes": ("rembouger",),
    "rembougeant": ("rembouger",),
    "rembougeas": ("rembouger",),
    "rembougeassent": ("rembouger",),
    "rembougeasses": ("rembouger",),
    "rembougeasse": ("rembouger",),
    "rembougeassiez": ("rembouger",),
    "rembougeassions": ("rembouger",),
    "rembougeâtes": ("rembouger",),
    "rembougeât": ("rembouger",),
    "rembougée": ("rembouger",),
    "rembougées": ("rembouger",),
    "rembougé": ("rembouger",),
    "rembougent": ("rembouger",),
    "rembougeons": ("rembouger",),
    "rembouge": ("rembouger",),
    "rembougera": ("rembouger",),
    "rembougeraient": ("rembouger",),
    "rembougerai": ("rembouger",),
    "rembougerais": ("rembouger",),
    "rembougerait": ("rembouger",),
    "rembougeras": ("rembouger",),
    "rembougèrent": ("rembouger",),
    "rembougerez": ("rembouger",),
    "rembougeriez": ("rembouger",),
    "rembougerions": ("rembouger",),
    "rembougerons": ("rembouger",),
    "rembougeront": ("rembouger",),
    "rembougés": ("rembouger",),
    "rembouges": ("rembouger",),
    "rembougez": ("rembouger",),
    "rembougiez": ("rembouger",),
    "rembougions": ("rembouger",),
    "rembrassaient": ("rembrasser",),
    "rembrassai": ("rembrasser",),
    "rembrassais": ("rembrasser",),
    "rembrassait": ("rembrasser",),
    "rembrassa": ("rembrasser",),
    "rembrassâmes": ("rembrasser",),
    "rembrassant": ("rembrasser",),
    "rembrassas": ("rembrasser",),
    "rembrassassent": ("rembrasser",),
    "rembrassasses": ("rembrasser",),
    "rembrassasse": ("rembrasser",),
    "rembrassassiez": ("rembrasser",),
    "rembrassassions": ("rembrasser",),
    "rembrassâtes": ("rembrasser",),
    "rembrassât": ("rembrasser",),
    "rembrassée": ("rembrasser",),
    "rembrassées": ("rembrasser",),
    "rembrassé": ("rembrasser",),
    "rembrassent": ("rembrasser",),
    "rembrasse": ("rembrasser",),
    "rembrassera": ("rembrasser",),
    "rembrasseraient": ("rembrasser",),
    "rembrasserai": ("rembrasser",),
    "rembrasserais": ("rembrasser",),
    "rembrasserait": ("rembrasser",),
    "rembrasseras": ("rembrasser",),
    "rembrassèrent": ("rembrasser",),
    "rembrasserez": ("rembrasser",),
    "rembrasseriez": ("rembrasser",),
    "rembrasserions": ("rembrasser",),
    "rembrasserons": ("rembrasser",),
    "rembrasseront": ("rembrasser",),
    "rembrassés": ("rembrasser",),
    "rembrasses": ("rembrasser",),
    "rembrassez": ("rembrasser",),
    "rembrassiez": ("rembrasser",),
    "rembrassions": ("rembrasser",),
    "rembrassons": ("rembrasser",),
    "rembraient": ("rembrayer",),
    "rembraie": ("rembrayer",),
    "rembraiera": ("rembrayer",),
    "rembraieraient": ("rembrayer",),
    "rembraierai": ("rembrayer",),
    "rembraierais": ("rembrayer",),
    "rembraierait": ("rembrayer",),
    "rembraieras": ("rembrayer",),
    "rembraierez": ("rembrayer",),
    "rembraieriez": ("rembrayer",),
    "rembraierions": ("rembrayer",),
    "rembraierons": ("rembrayer",),
    "rembraieront": ("rembrayer",),
    "rembraies": ("rembrayer",),
    "rembrayaient": ("rembrayer",),
    "rembrayai": ("rembrayer",),
    "rembrayais": ("rembrayer",),
    "rembrayait": ("rembrayer",),
    "rembraya": ("rembrayer",),
    "rembrayâmes": ("rembrayer",),
    "rembrayant": ("rembrayer",),
    "rembrayas": ("rembrayer",),
    "rembrayassent": ("rembrayer",),
    "rembrayasses": ("rembrayer",),
    "rembrayasse": ("rembrayer",),
    "rembrayassiez": ("rembrayer",),
    "rembrayassions": ("rembrayer",),
    "rembrayâtes": ("rembrayer",),
    "rembrayât": ("rembrayer",),
    "rembrayée": ("rembrayer",),
    "rembrayées": ("rembrayer",),
    "rembrayé": ("rembrayer",),
    "rembrayent": ("rembrayer",),
    "rembraye": ("rembrayer",),
    "rembrayera": ("rembrayer",),
    "rembrayeraient": ("rembrayer",),
    "rembrayerai": ("rembrayer",),
    "rembrayerais": ("rembrayer",),
    "rembrayerait": ("rembrayer",),
    "rembrayeras": ("rembrayer",),
    "rembrayèrent": ("rembrayer",),
    "rembrayerez": ("rembrayer",),
    "rembrayeriez": ("rembrayer",),
    "rembrayerions": ("rembrayer",),
    "rembrayerons": ("rembrayer",),
    "rembrayeront": ("rembrayer",),
    "rembrayés": ("rembrayer",),
    "rembrayes": ("rembrayer",),
    "rembrayez": ("rembrayer",),
    "rembrayiez": ("rembrayer",),
    "rembrayions": ("rembrayer",),
    "rembrayons": ("rembrayer",),
    "rembrunie": ("rembrunir",),
    "rembrunies": ("rembrunir",),
    "rembruni": ("rembrunir",),
    "rembrunîmes": ("rembrunir",),
    "rembrunira": ("rembrunir",),
    "rembruniraient": ("rembrunir",),
    "rembrunirai": ("rembrunir",),
    "rembrunirais": ("rembrunir",),
    "rembrunirait": ("rembrunir",),
    "rembruniras": ("rembrunir",),
    "rembrunirent": ("rembrunir",),
    "rembrunirez": ("rembrunir",),
    "rembruniriez": ("rembrunir",),
    "rembrunirions": ("rembrunir",),
    "rembrunirons": ("rembrunir",),
    "rembruniront": ("rembrunir",),
    "rembrunis": ("rembrunir",),
    "rembrunissaient": ("rembrunir",),
    "rembrunissais": ("rembrunir",),
    "rembrunissait": ("rembrunir",),
    "rembrunissant": ("rembrunir",),
    "rembrunissent": ("rembrunir",),
    "rembrunisse": ("rembrunir",),
    "rembrunisses": ("rembrunir",),
    "rembrunissez": ("rembrunir",),
    "rembrunissiez": ("rembrunir",),
    "rembrunissions": ("rembrunir",),
    "rembrunissons": ("rembrunir",),
    "rembrunîtes": ("rembrunir",),
    "rembrunit": ("rembrunir",),
    "rembrunît": ("rembrunir",),
    "remédiaient": ("remédier",),
    "remédiai": ("remédier",),
    "remédiais": ("remédier",),
    "remédiait": ("remédier",),
    "remédia": ("remédier",),
    "remédiâmes": ("remédier",),
    "remédiant": ("remédier",),
    "remédias": ("remédier",),
    "remédiassent": ("remédier",),
    "remédiasses": ("remédier",),
    "remédiasse": ("remédier",),
    "remédiassiez": ("remédier",),
    "remédiassions": ("remédier",),
    "remédiâtes": ("remédier",),
    "remédiât": ("remédier",),
    "remédié": ("remédier",),
    "remédient": ("remédier",),
    "remédie": ("remédier",),
    "remédiera": ("remédier",),
    "remédieraient": ("remédier",),
    "remédierai": ("remédier",),
    "remédierais": ("remédier",),
    "remédierait": ("remédier",),
    "remédieras": ("remédier",),
    "remédièrent": ("remédier",),
    "remédierez": ("remédier",),
    "remédieriez": ("remédier",),
    "remédierions": ("remédier",),
    "remédierons": ("remédier",),
    "remédieront": ("remédier",),
    "remédies": ("remédier",),
    "remédiez": ("remédier",),
    "remédiiez": ("remédier",),
    "remédiions": ("remédier",),
    "remédions": ("remédier",),
    "remélangeaient": ("remélanger",),
    "remélangeai": ("remélanger",),
    "remélangeais": ("remélanger",),
    "remélangeait": ("remélanger",),
    "remélangea": ("remélanger",),
    "remélangeâmes": ("remélanger",),
    "remélangeant": ("remélanger",),
    "remélangeas": ("remélanger",),
    "remélangeassent": ("remélanger",),
    "remélangeasses": ("remélanger",),
    "remélangeasse": ("remélanger",),
    "remélangeassiez": ("remélanger",),
    "remélangeassions": ("remélanger",),
    "remélangeâtes": ("remélanger",),
    "remélangeât": ("remélanger",),
    "remélangée": ("remélanger",),
    "remélangées": ("remélanger",),
    "remélangé": ("remélanger",),
    "remélangent": ("remélanger",),
    "remélangeons": ("remélanger",),
    "remélange": ("remélanger",),
    "remélangera": ("remélanger",),
    "remélangeraient": ("remélanger",),
    "remélangerai": ("remélanger",),
    "remélangerais": ("remélanger",),
    "remélangerait": ("remélanger",),
    "remélangeras": ("remélanger",),
    "remélangèrent": ("remélanger",),
    "remélangerez": ("remélanger",),
    "remélangeriez": ("remélanger",),
    "remélangerions": ("remélanger",),
    "remélangerons": ("remélanger",),
    "remélangeront": ("remélanger",),
    "remélangés": ("remélanger",),
    "remélanges": ("remélanger",),
    "remélangez": ("remélanger",),
    "remélangiez": ("remélanger",),
    "remélangions": ("remélanger",),
    "remenaçaient": ("remenacer",),
    "remenaçai": ("remenacer",),
    "remenaçais": ("remenacer",),
    "remenaçait": ("remenacer",),
    "remenaça": ("remenacer",),
    "remenaçâmes": ("remenacer",),
    "remenaçant": ("remenacer",),
    "remenaças": ("remenacer",),
    "remenaçassent": ("remenacer",),
    "remenaçasses": ("remenacer",),
    "remenaçasse": ("remenacer",),
    "remenaçassiez": ("remenacer",),
    "remenaçassions": ("remenacer",),
    "remenaçâtes": ("remenacer",),
    "remenaçât": ("remenacer",),
    "remenacée": ("remenacer",),
    "remenacées": ("remenacer",),
    "remenacé": ("remenacer",),
    "remenacent": ("remenacer",),
    "remenace": ("remenacer",),
    "remenacera": ("remenacer",),
    "remenaceraient": ("remenacer",),
    "remenacerai": ("remenacer",),
    "remenacerais": ("remenacer",),
    "remenacerait": ("remenacer",),
    "remenaceras": ("remenacer",),
    "remenacèrent": ("remenacer",),
    "remenacerez": ("remenacer",),
    "remenaceriez": ("remenacer",),
    "remenacerions": ("remenacer",),
    "remenacerons": ("remenacer",),
    "remenaceront": ("remenacer",),
    "remenacés": ("remenacer",),
    "remenaces": ("remenacer",),
    "remenacez": ("remenacer",),
    "remenaciez": ("remenacer",),
    "remenacions": ("remenacer",),
    "remenaçons": ("remenacer",),
    "remenaient": ("remener",),
    "remenai": ("remener",),
    "remenais": ("remener",),
    "remenait": ("remener",),
    "remena": ("remener",),
    "remenâmes": ("remener",),
    "remenant": ("remener",),
    "remenas": ("remener",),
    "remenassent": ("remener",),
    "remenasses": ("remener",),
    "remenasse": ("remener",),
    "remenassiez": ("remener",),
    "remenassions": ("remener",),
    "remenâtes": ("remener",),
    "remenât": ("remener",),
    "remenée": ("remener",),
    "remenées": ("remener",),
    "remené": ("remener",),
    "remènent": ("remener",),
    "remène": ("remener",),
    "remènera": ("remener",),
    "remèneraient": ("remener",),
    "remènerai": ("remener",),
    "remènerais": ("remener",),
    "remènerait": ("remener",),
    "remèneras": ("remener",),
    "remenèrent": ("remener",),
    "remènerez": ("remener",),
    "remèneriez": ("remener",),
    "remènerions": ("remener",),
    "remènerons": ("remener",),
    "remèneront": ("remener",),
    "remenés": ("remener",),
    "remènes": ("remener",),
    "remenez": ("remener",),
    "remeniez": ("remener",),
    "remenions": ("remener",),
    "remenons": ("remener",),
    "remerciaient": ("remercier",),
    "remerciai": ("remercier",),
    "remerciais": ("remercier",),
    "remerciait": ("remercier",),
    "remercia": ("remercier",),
    "remerciâmes": ("remercier",),
    "remerciant": ("remercier",),
    "remercias": ("remercier",),
    "remerciassent": ("remercier",),
    "remerciasses": ("remercier",),
    "remerciasse": ("remercier",),
    "remerciassiez": ("remercier",),
    "remerciassions": ("remercier",),
    "remerciâtes": ("remercier",),
    "remerciât": ("remercier",),
    "remerciée": ("remercier",),
    "remerciées": ("remercier",),
    "remercié": ("remercier",),
    "remercient": ("remercier",),
    "remercie": ("remercier",),
    "remerciera": ("remercier",),
    "remercieraient": ("remercier",),
    "remercierai": ("remercier",),
    "remercierais": ("remercier",),
    "remercierait": ("remercier",),
    "remercieras": ("remercier",),
    "remercièrent": ("remercier",),
    "remercierez": ("remercier",),
    "remercieriez": ("remercier",),
    "remercierions": ("remercier",),
    "remercierons": ("remercier",),
    "remercieront": ("remercier",),
    "remerciés": ("remercier",),
    "remercies": ("remercier",),
    "remerciez": ("remercier",),
    "remerciiez": ("remercier",),
    "remerciions": ("remercier",),
    "remercions": ("remercier",),
    "réméraient": ("rémérer",),
    "rémérai": ("rémérer",),
    "rémérais": ("rémérer",),
    "rémérait": ("rémérer",),
    "réméra": ("rémérer",),
    "rémérâmes": ("rémérer",),
    "rémérant": ("rémérer",),
    "réméras": ("rémérer",),
    "rémérassent": ("rémérer",),
    "rémérasses": ("rémérer",),
    "rémérasse": ("rémérer",),
    "rémérassiez": ("rémérer",),
    "rémérassions": ("rémérer",),
    "rémérâtes": ("rémérer",),
    "rémérât": ("rémérer",),
    "rémérée": ("rémérer",),
    "rémérées": ("rémérer",),
    "réméré": ("rémérer",),
    "rémèrent": ("rémérer",),
    "rémère": ("rémérer",),
    "rémérera": ("rémérer",),
    "réméreraient": ("rémérer",),
    "rémérerai": ("rémérer",),
    "rémérerais": ("rémérer",),
    "rémérerait": ("rémérer",),
    "réméreras": ("rémérer",),
    "rémérèrent": ("rémérer",),
    "rémérerez": ("rémérer",),
    "réméreriez": ("rémérer",),
    "rémérerions": ("rémérer",),
    "rémérerons": ("rémérer",),
    "réméreront": ("rémérer",),
    "rémérés": ("rémérer",),
    "rémères": ("rémérer",),
    "rémérez": ("rémérer",),
    "rémériez": ("rémérer",),
    "rémérions": ("rémérer",),
    "rémérons": ("rémérer",),
    "remétraient": ("remétrer",),
    "remétrai": ("remétrer",),
    "remétrais": ("remétrer",),
    "remétrait": ("remétrer",),
    "remétra": ("remétrer",),
    "remétrâmes": ("remétrer",),
    "remétrant": ("remétrer",),
    "remétras": ("remétrer",),
    "remétrassent": ("remétrer",),
    "remétrasses": ("remétrer",),
    "remétrasse": ("remétrer",),
    "remétrassiez": ("remétrer",),
    "remétrassions": ("remétrer",),
    "remétrâtes": ("remétrer",),
    "remétrât": ("remétrer",),
    "remétrée": ("remétrer",),
    "remétrées": ("remétrer",),
    "remétré": ("remétrer",),
    "remètrent": ("remétrer",),
    "remètre": ("remétrer",),
    "remétrera": ("remétrer",),
    "remétreraient": ("remétrer",),
    "remétrerai": ("remétrer",),
    "remétrerais": ("remétrer",),
    "remétrerait": ("remétrer",),
    "remétreras": ("remétrer",),
    "remétrèrent": ("remétrer",),
    "remétrerez": ("remétrer",),
    "remétreriez": ("remétrer",),
    "remétrerions": ("remétrer",),
    "remétrerons": ("remétrer",),
    "remétreront": ("remétrer",),
    "remétrés": ("remétrer",),
    "remètres": ("remétrer",),
    "remétrez": ("remétrer",),
    "remétriez": ("remétrer",),
    "remétrions": ("remétrer",),
    "remétrons": ("remétrer",),
    "remet": ("remettre",),
    "remets": ("remettre",),
    "remettaient": ("remettre",),
    "remettais": ("remettre",),
    "remettait": ("remettre",),
    "remettant": ("remettre",),
    "remettent": ("remettre",),
    "remette": ("remettre",),
    "remettes": ("remettre",),
    "remettez": ("remettre",),
    "remettiez": ("remettre",),
    "remettions": ("remettre",),
    "remettons": ("remettre",),
    "remettra": ("remettre",),
    "remettraient": ("remettre",),
    "remettrai": ("remettre",),
    "remettrais": ("remettre",),
    "remettrait": ("remettre",),
    "remettras": ("remettre",),
    "remettrez": ("remettre",),
    "remettriez": ("remettre",),
    "remettrions": ("remettre",),
    "remettrons": ("remettre",),
    "remettront": ("remettre",),
    "remîmes": ("remettre",),
    "remirent": ("remettre",),
    "remise": ("remettre",),
    "remises": ("remettre",),
    "remis": ("remettre",),
    "remissent": ("remettre",),
    "remisses": ("remettre",),
    "remisse": ("remettre",),
    "remissiez": ("remettre",),
    "remissions": ("remettre",),
    "remîtes": ("remettre",),
    "remit": ("remettre",),
    "remît": ("remettre",),
    "remmenaient": ("remmener",),
    "remmenai": ("remmener",),
    "remmenais": ("remmener",),
    "remmenait": ("remmener",),
    "remmena": ("remmener",),
    "remmenâmes": ("remmener",),
    "remmenant": ("remmener",),
    "remmenas": ("remmener",),
    "remmenassent": ("remmener",),
    "remmenasses": ("remmener",),
    "remmenasse": ("remmener",),
    "remmenassiez": ("remmener",),
    "remmenassions": ("remmener",),
    "remmenâtes": ("remmener",),
    "remmenât": ("remmener",),
    "remmenée": ("remmener",),
    "remmenées": ("remmener",),
    "remmené": ("remmener",),
    "remmènent": ("remmener",),
    "remmène": ("remmener",),
    "remmènera": ("remmener",),
    "remmèneraient": ("remmener",),
    "remmènerai": ("remmener",),
    "remmènerais": ("remmener",),
    "remmènerait": ("remmener",),
    "remmèneras": ("remmener",),
    "remmenèrent": ("remmener",),
    "remmènerez": ("remmener",),
    "remmèneriez": ("remmener",),
    "remmènerions": ("remmener",),
    "remmènerons": ("remmener",),
    "remmèneront": ("remmener",),
    "remmenés": ("remmener",),
    "remmènes": ("remmener",),
    "remmenez": ("remmener",),
    "remmeniez": ("remmener",),
    "remmenions": ("remmener",),
    "remmenons": ("remmener",),
    "remodelaient": ("remodeler",),
    "remodelai": ("remodeler",),
    "remodelais": ("remodeler",),
    "remodelait": ("remodeler",),
    "remodela": ("remodeler",),
    "remodelâmes": ("remodeler",),
    "remodelant": ("remodeler",),
    "remodelas": ("remodeler",),
    "remodelassent": ("remodeler",),
    "remodelasses": ("remodeler",),
    "remodelasse": ("remodeler",),
    "remodelassiez": ("remodeler",),
    "remodelassions": ("remodeler",),
    "remodelâtes": ("remodeler",),
    "remodelât": ("remodeler",),
    "remodelée": ("remodeler",),
    "remodelées": ("remodeler",),
    "remodelé": ("remodeler",),
    "remodèlent": ("remodeler",),
    "remodèle": ("remodeler",),
    "remodèlera": ("remodeler",),
    "remodèleraient": ("remodeler",),
    "remodèlerai": ("remodeler",),
    "remodèlerais": ("remodeler",),
    "remodèlerait": ("remodeler",),
    "remodèleras": ("remodeler",),
    "remodelèrent": ("remodeler",),
    "remodèlerez": ("remodeler",),
    "remodèleriez": ("remodeler",),
    "remodèlerions": ("remodeler",),
    "remodèlerons": ("remodeler",),
    "remodèleront": ("remodeler",),
    "remodelés": ("remodeler",),
    "remodèles": ("remodeler",),
    "remodelez": ("remodeler",),
    "remodeliez": ("remodeler",),
    "remodelions": ("remodeler",),
    "remodelons": ("remodeler",),
    "remodifiaient": ("remodifier",),
    "remodifiai": ("remodifier",),
    "remodifiais": ("remodifier",),
    "remodifiait": ("remodifier",),
    "remodifia": ("remodifier",),
    "remodifiâmes": ("remodifier",),
    "remodifiant": ("remodifier",),
    "remodifias": ("remodifier",),
    "remodifiassent": ("remodifier",),
    "remodifiasses": ("remodifier",),
    "remodifiasse": ("remodifier",),
    "remodifiassiez": ("remodifier",),
    "remodifiassions": ("remodifier",),
    "remodifiâtes": ("remodifier",),
    "remodifiât": ("remodifier",),
    "remodifiée": ("remodifier",),
    "remodifiées": ("remodifier",),
    "remodifié": ("remodifier",),
    "remodifient": ("remodifier",),
    "remodifie": ("remodifier",),
    "remodifiera": ("remodifier",),
    "remodifieraient": ("remodifier",),
    "remodifierai": ("remodifier",),
    "remodifierais": ("remodifier",),
    "remodifierait": ("remodifier",),
    "remodifieras": ("remodifier",),
    "remodifièrent": ("remodifier",),
    "remodifierez": ("remodifier",),
    "remodifieriez": ("remodifier",),
    "remodifierions": ("remodifier",),
    "remodifierons": ("remodifier",),
    "remodifieront": ("remodifier",),
    "remodifiés": ("remodifier",),
    "remodifies": ("remodifier",),
    "remodifiez": ("remodifier",),
    "remodifiiez": ("remodifier",),
    "remodifiions": ("remodifier",),
    "remodifions": ("remodifier",),
    "remordançaient": ("remordancer",),
    "remordançai": ("remordancer",),
    "remordançais": ("remordancer",),
    "remordançait": ("remordancer",),
    "remordança": ("remordancer",),
    "remordançâmes": ("remordancer",),
    "remordançant": ("remordancer",),
    "remordanças": ("remordancer",),
    "remordançassent": ("remordancer",),
    "remordançasses": ("remordancer",),
    "remordançasse": ("remordancer",),
    "remordançassiez": ("remordancer",),
    "remordançassions": ("remordancer",),
    "remordançâtes": ("remordancer",),
    "remordançât": ("remordancer",),
    "remordancée": ("remordancer",),
    "remordancées": ("remordancer",),
    "remordancé": ("remordancer",),
    "remordancent": ("remordancer",),
    "remordance": ("remordancer",),
    "remordancera": ("remordancer",),
    "remordanceraient": ("remordancer",),
    "remordancerai": ("remordancer",),
    "remordancerais": ("remordancer",),
    "remordancerait": ("remordancer",),
    "remordanceras": ("remordancer",),
    "remordancèrent": ("remordancer",),
    "remordancerez": ("remordancer",),
    "remordanceriez": ("remordancer",),
    "remordancerions": ("remordancer",),
    "remordancerons": ("remordancer",),
    "remordanceront": ("remordancer",),
    "remordancés": ("remordancer",),
    "remordances": ("remordancer",),
    "remordancez": ("remordancer",),
    "remordanciez": ("remordancer",),
    "remordancions": ("remordancer",),
    "remordançons": ("remordancer",),
    "remordaient": ("remordre",),
    "remordais": ("remordre",),
    "remordait": ("remordre",),
    "remordant": ("remordre",),
    "remordent": ("remordre",),
    "remorde": ("remordre",),
    "remordes": ("remordre",),
    "remordez": ("remordre",),
    "remordiez": ("remordre",),
    "remordîmes": ("remordre",),
    "remordions": ("remordre",),
    "remordirent": ("remordre",),
    "remordis": ("remordre",),
    "remordissent": ("remordre",),
    "remordisses": ("remordre",),
    "remordisse": ("remordre",),
    "remordissiez": ("remordre",),
    "remordissions": ("remordre",),
    "remordîtes": ("remordre",),
    "remordit": ("remordre",),
    "remordît": ("remordre",),
    "remordons": ("remordre",),
    "remord": ("remordre",),
    "remordra": ("remordre",),
    "remordraient": ("remordre",),
    "remordrai": ("remordre",),
    "remordrais": ("remordre",),
    "remordrait": ("remordre",),
    "remordras": ("remordre",),
    "remordrez": ("remordre",),
    "remordriez": ("remordre",),
    "remordrions": ("remordre",),
    "remordrons": ("remordre",),
    "remordront": ("remordre",),
    "remords": ("remordre",),
    "remordue": ("remordre",),
    "remordues": ("remordre",),
    "remordu": ("remordre",),
    "remordus": ("remordre",),
    "remoud": ("remoudre",),
    "remoudra": ("remoudre",),
    "remoudraient": ("remoudre",),
    "remoudrai": ("remoudre",),
    "remoudrais": ("remoudre",),
    "remoudrait": ("remoudre",),
    "remoudras": ("remoudre",),
    "remoudrez": ("remoudre",),
    "remoudriez": ("remoudre",),
    "remoudrions": ("remoudre",),
    "remoudrons": ("remoudre",),
    "remoudront": ("remoudre",),
    "remouds": ("remoudre",),
    "remoulaient": ("remoudre",),
    "remoulais": ("remoudre",),
    "remoulait": ("remoudre",),
    "remoulant": ("remoudre",),
    "remoulent": ("remoudre",),
    "remoule": ("remoudre",),
    "remoules": ("remoudre",),
    "remoulez": ("remoudre",),
    "remouliez": ("remoudre",),
    "remoulions": ("remoudre",),
    "remoulons": ("remoudre",),
    "remoulue": ("remoudre",),
    "remoulues": ("remoudre",),
    "remoulu": ("remoudre",),
    "remoulûmes": ("remoudre",),
    "remoulurent": ("remoudre",),
    "remoulus": ("remoudre",),
    "remoulussent": ("remoudre",),
    "remoulusses": ("remoudre",),
    "remoulusse": ("remoudre",),
    "remoulussiez": ("remoudre",),
    "remoulussions": ("remoudre",),
    "remoulûtes": ("remoudre",),
    "remoulut": ("remoudre",),
    "remoulût": ("remoudre",),
    "remeurent": ("remourir",),
    "remeure": ("remourir",),
    "remeures": ("remourir",),
    "remeurs": ("remourir",),
    "remeurt": ("remourir",),
    "remorte": ("remourir",),
    "remortes": ("remourir",),
    "remort": ("remourir",),
    "remorts": ("remourir",),
    "remouraient": ("remourir",),
    "remourais": ("remourir",),
    "remourait": ("remourir",),
    "remourant": ("remourir",),
    "remourez": ("remourir",),
    "remouriez": ("remourir",),
    "remourions": ("remourir",),
    "remourons": ("remourir",),
    "remourra": ("remourir",),
    "remourraient": ("remourir",),
    "remourrai": ("remourir",),
    "remourrais": ("remourir",),
    "remourrait": ("remourir",),
    "remourras": ("remourir",),
    "remourrez": ("remourir",),
    "remourriez": ("remourir",),
    "remourrions": ("remourir",),
    "remourrons": ("remourir",),
    "remourront": ("remourir",),
    "remourûmes": ("remourir",),
    "remoururent": ("remourir",),
    "remourus": ("remourir",),
    "remourussent": ("remourir",),
    "remourusses": ("remourir",),
    "remourusse": ("remourir",),
    "remourussiez": ("remourir",),
    "remourussions": ("remourir",),
    "remourûtes": ("remourir",),
    "remourut": ("remourir",),
    "remourût": ("remourir",),
    "rempaquetaient": ("rempaqueter",),
    "rempaquetai": ("rempaqueter",),
    "rempaquetais": ("rempaqueter",),
    "rempaquetait": ("rempaqueter",),
    "rempaqueta": ("rempaqueter",),
    "rempaquetâmes": ("rempaqueter",),
    "rempaquetant": ("rempaqueter",),
    "rempaquetas": ("rempaqueter",),
    "rempaquetassent": ("rempaqueter",),
    "rempaquetasses": ("rempaqueter",),
    "rempaquetasse": ("rempaqueter",),
    "rempaquetassiez": ("rempaqueter",),
    "rempaquetassions": ("rempaqueter",),
    "rempaquetâtes": ("rempaqueter",),
    "rempaquetât": ("rempaqueter",),
    "rempaquetée": ("rempaqueter",),
    "rempaquetées": ("rempaqueter",),
    "rempaqueté": ("rempaqueter",),
    "rempaquetèrent": ("rempaqueter",),
    "rempaquetés": ("rempaqueter",),
    "rempaquetez": ("rempaqueter",),
    "rempaquetiez": ("rempaqueter",),
    "rempaquetions": ("rempaqueter",),
    "rempaquetons": ("rempaqueter",),
    "rempaquettent": ("rempaqueter",),
    "rempaquette": ("rempaqueter",),
    "rempaquettera": ("rempaqueter",),
    "rempaquetteraient": ("rempaqueter",),
    "rempaquetterai": ("rempaqueter",),
    "rempaquetterais": ("rempaqueter",),
    "rempaquetterait": ("rempaqueter",),
    "rempaquetteras": ("rempaqueter",),
    "rempaquetterez": ("rempaqueter",),
    "rempaquetteriez": ("rempaqueter",),
    "rempaquetterions": ("rempaqueter",),
    "rempaquetterons": ("rempaqueter",),
    "rempaquetteront": ("rempaqueter",),
    "rempaquettes": ("rempaqueter",),
    "rempiétaient": ("rempiéter",),
    "rempiétai": ("rempiéter",),
    "rempiétais": ("rempiéter",),
    "rempiétait": ("rempiéter",),
    "rempiéta": ("rempiéter",),
    "rempiétâmes": ("rempiéter",),
    "rempiétant": ("rempiéter",),
    "rempiétas": ("rempiéter",),
    "rempiétassent": ("rempiéter",),
    "rempiétasses": ("rempiéter",),
    "rempiétasse": ("rempiéter",),
    "rempiétassiez": ("rempiéter",),
    "rempiétassions": ("rempiéter",),
    "rempiétâtes": ("rempiéter",),
    "rempiétât": ("rempiéter",),
    "rempiétée": ("rempiéter",),
    "rempiétées": ("rempiéter",),
    "rempiété": ("rempiéter",),
    "rempiètent": ("rempiéter",),
    "rempiète": ("rempiéter",),
    "rempiétera": ("rempiéter",),
    "rempiéteraient": ("rempiéter",),
    "rempiéterai": ("rempiéter",),
    "rempiéterais": ("rempiéter",),
    "rempiéterait": ("rempiéter",),
    "rempiéteras": ("rempiéter",),
    "rempiétèrent": ("rempiéter",),
    "rempiéterez": ("rempiéter",),
    "rempiéteriez": ("rempiéter",),
    "rempiéterions": ("rempiéter",),
    "rempiéterons": ("rempiéter",),
    "rempiéteront": ("rempiéter",),
    "rempiétés": ("rempiéter",),
    "rempiètes": ("rempiéter",),
    "rempiétez": ("rempiéter",),
    "rempiétiez": ("rempiéter",),
    "rempiétions": ("rempiéter",),
    "rempiétons": ("rempiéter",),
    "remplaçaient": ("remplacer",),
    "remplaçai": ("remplacer",),
    "remplaçais": ("remplacer",),
    "remplaçait": ("remplacer",),
    "remplaça": ("remplacer",),
    "remplaçâmes": ("remplacer",),
    "remplaçant": ("remplacer",),
    "remplaças": ("remplacer",),
    "remplaçassent": ("remplacer",),
    "remplaçasses": ("remplacer",),
    "remplaçasse": ("remplacer",),
    "remplaçassiez": ("remplacer",),
    "remplaçassions": ("remplacer",),
    "remplaçâtes": ("remplacer",),
    "remplaçât": ("remplacer",),
    "remplacée": ("remplacer",),
    "remplacées": ("remplacer",),
    "remplacé": ("remplacer",),
    "remplacent": ("remplacer",),
    "remplace": ("remplacer",),
    "remplacera": ("remplacer",),
    "remplaceraient": ("remplacer",),
    "remplacerai": ("remplacer",),
    "remplacerais": ("remplacer",),
    "remplacerait": ("remplacer",),
    "remplaceras": ("remplacer",),
    "remplacèrent": ("remplacer",),
    "remplacerez": ("remplacer",),
    "remplaceriez": ("remplacer",),
    "remplacerions": ("remplacer",),
    "remplacerons": ("remplacer",),
    "remplaceront": ("remplacer",),
    "remplacés": ("remplacer",),
    "remplaces": ("remplacer",),
    "remplacez": ("remplacer",),
    "remplaciez": ("remplacer",),
    "remplacions": ("remplacer",),
    "remplaçons": ("remplacer",),
    "rempliaient": ("remplier",),
    "rempliai": ("remplier",),
    "rempliais": ("remplier",),
    "rempliait": ("remplier",),
    "remplia": ("remplier",),
    "rempliâmes": ("remplier",),
    "rempliant": ("remplier",),
    "remplias": ("remplier",),
    "rempliassent": ("remplier",),
    "rempliasses": ("remplier",),
    "rempliasse": ("remplier",),
    "rempliassiez": ("remplier",),
    "rempliassions": ("remplier",),
    "rempliâtes": ("remplier",),
    "rempliât": ("remplier",),
    "rempliée": ("remplier",),
    "rempliées": ("remplier",),
    "remplié": ("remplier",),
    "remplient": ("remplier",),
    "remplie": ("remplir",),
    "rempliera": ("remplier",),
    "remplieraient": ("remplier",),
    "remplierai": ("remplier",),
    "remplierais": ("remplier",),
    "remplierait": ("remplier",),
    "remplieras": ("remplier",),
    "remplièrent": ("remplier",),
    "remplierez": ("remplier",),
    "remplieriez": ("remplier",),
    "remplierions": ("remplier",),
    "remplierons": ("remplier",),
    "remplieront": ("remplier",),
    "rempliés": ("remplier",),
    "remplies": ("remplir",),
    "rempliez": ("remplier",),
    "rempliiez": ("remplier",),
    "rempliions": ("remplier",),
    "remplions": ("remplier",),
    "rempli": ("remplir",),
    "remplîmes": ("remplir",),
    "remplira": ("remplir",),
    "rempliraient": ("remplir",),
    "remplirai": ("remplir",),
    "remplirais": ("remplir",),
    "remplirait": ("remplir",),
    "rempliras": ("remplir",),
    "remplirent": ("remplir",),
    "remplirez": ("remplir",),
    "rempliriez": ("remplir",),
    "remplirions": ("remplir",),
    "remplirons": ("remplir",),
    "rempliront": ("remplir",),
    "remplis": ("remplir",),
    "remplissaient": ("remplir",),
    "remplissais": ("remplir",),
    "remplissait": ("remplir",),
    "remplissant": ("remplir",),
    "remplissent": ("remplir",),
    "remplisse": ("remplir",),
    "remplisses": ("remplir",),
    "remplissez": ("remplir",),
    "remplissiez": ("remplir",),
    "remplissions": ("remplir",),
    "remplissons": ("remplir",),
    "remplîtes": ("remplir",),
    "remplit": ("remplir",),
    "remplît": ("remplir",),
    "remploient": ("remployer",),
    "remploie": ("remployer",),
    "remploiera": ("remployer",),
    "remploieraient": ("remployer",),
    "remploierai": ("remployer",),
    "remploierais": ("remployer",),
    "remploierait": ("remployer",),
    "remploieras": ("remployer",),
    "remploierez": ("remployer",),
    "remploieriez": ("remployer",),
    "remploierions": ("remployer",),
    "remploierons": ("remployer",),
    "remploieront": ("remployer",),
    "remploies": ("remployer",),
    "remployaient": ("remployer",),
    "remployai": ("remployer",),
    "remployais": ("remployer",),
    "remployait": ("remployer",),
    "remploya": ("remployer",),
    "remployâmes": ("remployer",),
    "remployant": ("remployer",),
    "remployas": ("remployer",),
    "remployassent": ("remployer",),
    "remployasses": ("remployer",),
    "remployasse": ("remployer",),
    "remployassiez": ("remployer",),
    "remployassions": ("remployer",),
    "remployâtes": ("remployer",),
    "remployât": ("remployer",),
    "remployée": ("remployer",),
    "remployées": ("remployer",),
    "remployé": ("remployer",),
    "remployèrent": ("remployer",),
    "remployés": ("remployer",),
    "remployez": ("remployer",),
    "remployiez": ("remployer",),
    "remployions": ("remployer",),
    "remployons": ("remployer",),
    "rémunéraient": ("rémunérer",),
    "rémunérai": ("rémunérer",),
    "rémunérais": ("rémunérer",),
    "rémunérait": ("rémunérer",),
    "rémunéra": ("rémunérer",),
    "rémunérâmes": ("rémunérer",),
    "rémunérant": ("rémunérer",),
    "rémunéras": ("rémunérer",),
    "rémunérassent": ("rémunérer",),
    "rémunérasses": ("rémunérer",),
    "rémunérasse": ("rémunérer",),
    "rémunérassiez": ("rémunérer",),
    "rémunérassions": ("rémunérer",),
    "rémunérâtes": ("rémunérer",),
    "rémunérât": ("rémunérer",),
    "rémunérée": ("rémunérer",),
    "rémunérées": ("rémunérer",),
    "rémunéré": ("rémunérer",),
    "rémunèrent": ("rémunérer",),
    "rémunère": ("rémunérer",),
    "rémunérera": ("rémunérer",),
    "rémunéreraient": ("rémunérer",),
    "rémunérerai": ("rémunérer",),
    "rémunérerais": ("rémunérer",),
    "rémunérerait": ("rémunérer",),
    "rémunéreras": ("rémunérer",),
    "rémunérèrent": ("rémunérer",),
    "rémunérerez": ("rémunérer",),
    "rémunéreriez": ("rémunérer",),
    "rémunérerions": ("rémunérer",),
    "rémunérerons": ("rémunérer",),
    "rémunéreront": ("rémunérer",),
    "rémunérés": ("rémunérer",),
    "rémunères": ("rémunérer",),
    "rémunérez": ("rémunérer",),
    "rémunériez": ("rémunérer",),
    "rémunérions": ("rémunérer",),
    "rémunérons": ("rémunérer",),
    "remunie": ("remunir",),
    "remunies": ("remunir",),
    "remuni": ("remunir",),
    "remunîmes": ("remunir",),
    "remunira": ("remunir",),
    "remuniraient": ("remunir",),
    "remunirai": ("remunir",),
    "remunirais": ("remunir",),
    "remunirait": ("remunir",),
    "remuniras": ("remunir",),
    "remunirent": ("remunir",),
    "remunirez": ("remunir",),
    "remuniriez": ("remunir",),
    "remunirions": ("remunir",),
    "remunirons": ("remunir",),
    "remuniront": ("remunir",),
    "remunis": ("remunir",),
    "remunissaient": ("remunir",),
    "remunissais": ("remunir",),
    "remunissait": ("remunir",),
    "remunissant": ("remunir",),
    "remunissent": ("remunir",),
    "remunisse": ("remunir",),
    "remunisses": ("remunir",),
    "remunissez": ("remunir",),
    "remunissiez": ("remunir",),
    "remunissions": ("remunir",),
    "remunissons": ("remunir",),
    "remunîtes": ("remunir",),
    "remunit": ("remunir",),
    "remunît": ("remunir",),
    "renageaient": ("renager",),
    "renageai": ("renager",),
    "renageais": ("renager",),
    "renageait": ("renager",),
    "renagea": ("renager",),
    "renageâmes": ("renager",),
    "renageant": ("renager",),
    "renageas": ("renager",),
    "renageassent": ("renager",),
    "renageasses": ("renager",),
    "renageasse": ("renager",),
    "renageassiez": ("renager",),
    "renageassions": ("renager",),
    "renageâtes": ("renager",),
    "renageât": ("renager",),
    "renagée": ("renager",),
    "renagées": ("renager",),
    "renagé": ("renager",),
    "renagent": ("renager",),
    "renageons": ("renager",),
    "renage": ("renager",),
    "renagera": ("renager",),
    "renageraient": ("renager",),
    "renagerai": ("renager",),
    "renagerais": ("renager",),
    "renagerait": ("renager",),
    "renageras": ("renager",),
    "renagèrent": ("renager",),
    "renagerez": ("renager",),
    "renageriez": ("renager",),
    "renagerions": ("renager",),
    "renagerons": ("renager",),
    "renageront": ("renager",),
    "renagés": ("renager",),
    "renages": ("renager",),
    "renagez": ("renager",),
    "renagiez": ("renager",),
    "renagions": ("renager",),
    "renais": ("renaître",),
    "renaissaient": ("renaître",),
    "renaissais": ("renaître",),
    "renaissait": ("renaître",),
    "renaissant": ("renaître",),
    "renaissent": ("renaître",),
    "renaisse": ("renaître",),
    "renaisses": ("renaître",),
    "renaissez": ("renaître",),
    "renaissiez": ("renaître",),
    "renaissions": ("renaître",),
    "renaissons": ("renaître",),
    "renaît": ("renaître",),
    "renaîtra": ("renaître",),
    "renaîtraient": ("renaître",),
    "renaîtrai": ("renaître",),
    "renaîtrais": ("renaître",),
    "renaîtrait": ("renaître",),
    "renaîtras": ("renaître",),
    "renaîtrez": ("renaître",),
    "renaîtriez": ("renaître",),
    "renaîtrions": ("renaître",),
    "renaîtrons": ("renaître",),
    "renaîtront": ("renaître",),
    "renaquîmes": ("renaître",),
    "renaquirent": ("renaître",),
    "renaquis": ("renaître",),
    "renaquissent": ("renaître",),
    "renaquisses": ("renaître",),
    "renaquisse": ("renaître",),
    "renaquissiez": ("renaître",),
    "renaquissions": ("renaître",),
    "renaquîtes": ("renaître",),
    "renaquit": ("renaître",),
    "renaquît": ("renaître",),
    "renée": ("renaître",),
    "renées": ("renaître",),
    "rené": ("renaître",),
    "renés": ("renaître",),
    "renchérie": ("renchérir",),
    "renchéries": ("renchérir",),
    "renchéri": ("renchérir",),
    "renchérîmes": ("renchérir",),
    "renchérira": ("renchérir",),
    "renchériraient": ("renchérir",),
    "renchérirai": ("renchérir",),
    "renchérirais": ("renchérir",),
    "renchérirait": ("renchérir",),
    "renchériras": ("renchérir",),
    "renchérirent": ("renchérir",),
    "renchérirez": ("renchérir",),
    "renchéririez": ("renchérir",),
    "renchéririons": ("renchérir",),
    "renchérirons": ("renchérir",),
    "renchériront": ("renchérir",),
    "renchéris": ("renchérir",),
    "renchérissaient": ("renchérir",),
    "renchérissais": ("renchérir",),
    "renchérissait": ("renchérir",),
    "renchérissant": ("renchérir",),
    "renchérissent": ("renchérir",),
    "renchérisse": ("renchérir",),
    "renchérisses": ("renchérir",),
    "renchérissez": ("renchérir",),
    "renchérissiez": ("renchérir",),
    "renchérissions": ("renchérir",),
    "renchérissons": ("renchérir",),
    "renchérîtes": ("renchérir",),
    "renchérit": ("renchérir",),
    "renchérît": ("renchérir",),
    "rendormaient": ("rendormir",),
    "rendormais": ("rendormir",),
    "rendormait": ("rendormir",),
    "rendormant": ("rendormir",),
    "rendorment": ("rendormir",),
    "rendorme": ("rendormir",),
    "rendormes": ("rendormir",),
    "rendormez": ("rendormir",),
    "rendormie": ("rendormir",),
    "rendormies": ("rendormir",),
    "rendormiez": ("rendormir",),
    "rendormi": ("rendormir",),
    "rendormîmes": ("rendormir",),
    "rendormions": ("rendormir",),
    "rendormira": ("rendormir",),
    "rendormiraient": ("rendormir",),
    "rendormirai": ("rendormir",),
    "rendormirais": ("rendormir",),
    "rendormirait": ("rendormir",),
    "rendormiras": ("rendormir",),
    "rendormirent": ("rendormir",),
    "rendormirez": ("rendormir",),
    "rendormiriez": ("rendormir",),
    "rendormirions": ("rendormir",),
    "rendormirons": ("rendormir",),
    "rendormiront": ("rendormir",),
    "rendormis": ("rendormir",),
    "rendormissent": ("rendormir",),
    "rendormisses": ("rendormir",),
    "rendormisse": ("rendormir",),
    "rendormissiez": ("rendormir",),
    "rendormissions": ("rendormir",),
    "rendormîtes": ("rendormir",),
    "rendormit": ("rendormir",),
    "rendormît": ("rendormir",),
    "rendormons": ("rendormir",),
    "rendors": ("rendormir",),
    "rendort": ("rendormir",),
    "rendaient": ("rendre",),
    "rendais": ("rendre",),
    "rendait": ("rendre",),
    "rendant": ("rendre",),
    "rendent": ("rendre",),
    "rende": ("rendre",),
    "rendes": ("rendre",),
    "rendez": ("rendre",),
    "rendiez": ("rendre",),
    "rendîmes": ("rendre",),
    "rendions": ("rendre",),
    "rendirent": ("rendre",),
    "rendis": ("rendre",),
    "rendissent": ("rendre",),
    "rendisses": ("rendre",),
    "rendisse": ("rendre",),
    "rendissiez": ("rendre",),
    "rendissions": ("rendre",),
    "rendîtes": ("rendre",),
    "rendit": ("rendre",),
    "rendît": ("rendre",),
    "rendons": ("rendre",),
    "rend": ("rendre",),
    "rendra": ("rendre",),
    "rendraient": ("rendre",),
    "rendrai": ("rendre",),
    "rendrais": ("rendre",),
    "rendrait": ("rendre",),
    "rendras": ("rendre",),
    "rendrez": ("rendre",),
    "rendriez": ("rendre",),
    "rendrions": ("rendre",),
    "rendrons": ("rendre",),
    "rendront": ("rendre",),
    "rends": ("rendre",),
    "rendue": ("rendre",),
    "rendues": ("rendre",),
    "rendu": ("rendre",),
    "rendus": ("rendre",),
    "renduira": ("renduire",),
    "renduiraient": ("renduire",),
    "renduirai": ("renduire",),
    "renduirais": ("renduire",),
    "renduirait": ("renduire",),
    "renduiras": ("renduire",),
    "renduirez": ("renduire",),
    "renduiriez": ("renduire",),
    "renduirions": ("renduire",),
    "renduirons": ("renduire",),
    "renduiront": ("renduire",),
    "renduisaient": ("renduire",),
    "renduisais": ("renduire",),
    "renduisait": ("renduire",),
    "renduisant": ("renduire",),
    "renduisent": ("renduire",),
    "renduise": ("renduire",),
    "renduises": ("renduire",),
    "renduisez": ("renduire",),
    "renduisiez": ("renduire",),
    "renduisîmes": ("renduire",),
    "renduisions": ("renduire",),
    "renduisirent": ("renduire",),
    "renduisis": ("renduire",),
    "renduisissent": ("renduire",),
    "renduisisses": ("renduire",),
    "renduisisse": ("renduire",),
    "renduisissiez": ("renduire",),
    "renduisissions": ("renduire",),
    "renduisîtes": ("renduire",),
    "renduisit": ("renduire",),
    "renduisît": ("renduire",),
    "renduisons": ("renduire",),
    "renduis": ("renduire",),
    "renduite": ("renduire",),
    "renduites": ("renduire",),
    "renduit": ("renduire",),
    "renduits": ("renduire",),
    "rendurcie": ("rendurcir",),
    "rendurcies": ("rendurcir",),
    "rendurci": ("rendurcir",),
    "rendurcîmes": ("rendurcir",),
    "rendurcira": ("rendurcir",),
    "rendurciraient": ("rendurcir",),
    "rendurcirai": ("rendurcir",),
    "rendurcirais": ("rendurcir",),
    "rendurcirait": ("rendurcir",),
    "rendurciras": ("rendurcir",),
    "rendurcirent": ("rendurcir",),
    "rendurcirez": ("rendurcir",),
    "rendurciriez": ("rendurcir",),
    "rendurcirions": ("rendurcir",),
    "rendurcirons": ("rendurcir",),
    "rendurciront": ("rendurcir",),
    "rendurcis": ("rendurcir",),
    "rendurcissaient": ("rendurcir",),
    "rendurcissais": ("rendurcir",),
    "rendurcissait": ("rendurcir",),
    "rendurcissant": ("rendurcir",),
    "rendurcissent": ("rendurcir",),
    "rendurcisse": ("rendurcir",),
    "rendurcisses": ("rendurcir",),
    "rendurcissez": ("rendurcir",),
    "rendurcissiez": ("rendurcir",),
    "rendurcissions": ("rendurcir",),
    "rendurcissons": ("rendurcir",),
    "rendurcîtes": ("rendurcir",),
    "rendurcit": ("rendurcir",),
    "rendurcît": ("rendurcir",),
    "renégociaient": ("renégocier",),
    "renégociai": ("renégocier",),
    "renégociais": ("renégocier",),
    "renégociait": ("renégocier",),
    "renégocia": ("renégocier",),
    "renégociâmes": ("renégocier",),
    "renégociant": ("renégocier",),
    "renégocias": ("renégocier",),
    "renégociassent": ("renégocier",),
    "renégociasses": ("renégocier",),
    "renégociasse": ("renégocier",),
    "renégociassiez": ("renégocier",),
    "renégociassions": ("renégocier",),
    "renégociâtes": ("renégocier",),
    "renégociât": ("renégocier",),
    "renégociée": ("renégocier",),
    "renégociées": ("renégocier",),
    "renégocié": ("renégocier",),
    "renégocient": ("renégocier",),
    "renégocie": ("renégocier",),
    "renégociera": ("renégocier",),
    "renégocieraient": ("renégocier",),
    "renégocierai": ("renégocier",),
    "renégocierais": ("renégocier",),
    "renégocierait": ("renégocier",),
    "renégocieras": ("renégocier",),
    "renégocièrent": ("renégocier",),
    "renégocierez": ("renégocier",),
    "renégocieriez": ("renégocier",),
    "renégocierions": ("renégocier",),
    "renégocierons": ("renégocier",),
    "renégocieront": ("renégocier",),
    "renégociés": ("renégocier",),
    "renégocies": ("renégocier",),
    "renégociez": ("renégocier",),
    "renégociiez": ("renégocier",),
    "renégociions": ("renégocier",),
    "renégocions": ("renégocier",),
    "reneigeaient": ("reneiger",),
    "reneigeait": ("reneiger",),
    "reneigea": ("reneiger",),
    "reneigeant": ("reneiger",),
    "reneigeassent": ("reneiger",),
    "reneigeât": ("reneiger",),
    "reneigé": ("reneiger",),
    "reneigent": ("reneiger",),
    "reneige": ("reneiger",),
    "reneigera": ("reneiger",),
    "reneigeraient": ("reneiger",),
    "reneigerait": ("reneiger",),
    "reneigèrent": ("reneiger",),
    "reneigeront": ("reneiger",),
    "renettoient": ("renettoyer",),
    "renettoie": ("renettoyer",),
    "renettoiera": ("renettoyer",),
    "renettoieraient": ("renettoyer",),
    "renettoierai": ("renettoyer",),
    "renettoierais": ("renettoyer",),
    "renettoierait": ("renettoyer",),
    "renettoieras": ("renettoyer",),
    "renettoierez": ("renettoyer",),
    "renettoieriez": ("renettoyer",),
    "renettoierions": ("renettoyer",),
    "renettoierons": ("renettoyer",),
    "renettoieront": ("renettoyer",),
    "renettoies": ("renettoyer",),
    "renettoyaient": ("renettoyer",),
    "renettoyai": ("renettoyer",),
    "renettoyais": ("renettoyer",),
    "renettoyait": ("renettoyer",),
    "renettoya": ("renettoyer",),
    "renettoyâmes": ("renettoyer",),
    "renettoyant": ("renettoyer",),
    "renettoyas": ("renettoyer",),
    "renettoyassent": ("renettoyer",),
    "renettoyasses": ("renettoyer",),
    "renettoyasse": ("renettoyer",),
    "renettoyassiez": ("renettoyer",),
    "renettoyassions": ("renettoyer",),
    "renettoyâtes": ("renettoyer",),
    "renettoyât": ("renettoyer",),
    "renettoyée": ("renettoyer",),
    "renettoyées": ("renettoyer",),
    "renettoyé": ("renettoyer",),
    "renettoyèrent": ("renettoyer",),
    "renettoyés": ("renettoyer",),
    "renettoyez": ("renettoyer",),
    "renettoyiez": ("renettoyer",),
    "renettoyions": ("renettoyer",),
    "renettoyons": ("renettoyer",),
    "renfonçaient": ("renfoncer",),
    "renfonçai": ("renfoncer",),
    "renfonçais": ("renfoncer",),
    "renfonçait": ("renfoncer",),
    "renfonça": ("renfoncer",),
    "renfonçâmes": ("renfoncer",),
    "renfonçant": ("renfoncer",),
    "renfonças": ("renfoncer",),
    "renfonçassent": ("renfoncer",),
    "renfonçasses": ("renfoncer",),
    "renfonçasse": ("renfoncer",),
    "renfonçassiez": ("renfoncer",),
    "renfonçassions": ("renfoncer",),
    "renfonçâtes": ("renfoncer",),
    "renfonçât": ("renfoncer",),
    "renfoncée": ("renfoncer",),
    "renfoncées": ("renfoncer",),
    "renfoncé": ("renfoncer",),
    "renfoncent": ("renfoncer",),
    "renfonce": ("renfoncer",),
    "renfoncera": ("renfoncer",),
    "renfonceraient": ("renfoncer",),
    "renfoncerai": ("renfoncer",),
    "renfoncerais": ("renfoncer",),
    "renfoncerait": ("renfoncer",),
    "renfonceras": ("renfoncer",),
    "renfoncèrent": ("renfoncer",),
    "renfoncerez": ("renfoncer",),
    "renfonceriez": ("renfoncer",),
    "renfoncerions": ("renfoncer",),
    "renfoncerons": ("renfoncer",),
    "renfonceront": ("renfoncer",),
    "renfoncés": ("renfoncer",),
    "renfonces": ("renfoncer",),
    "renfoncez": ("renfoncer",),
    "renfonciez": ("renfoncer",),
    "renfoncions": ("renfoncer",),
    "renfonçons": ("renfoncer",),
    "renforçaient": ("renforcer",),
    "renforçai": ("renforcer",),
    "renforçais": ("renforcer",),
    "renforçait": ("renforcer",),
    "renforça": ("renforcer",),
    "renforçâmes": ("renforcer",),
    "renforçant": ("renforcer",),
    "renforças": ("renforcer",),
    "renforçassent": ("renforcer",),
    "renforçasses": ("renforcer",),
    "renforçasse": ("renforcer",),
    "renforçassiez": ("renforcer",),
    "renforçassions": ("renforcer",),
    "renforçâtes": ("renforcer",),
    "renforçât": ("renforcer",),
    "renforcée": ("renforcer",),
    "renforcées": ("renforcer",),
    "renforcé": ("renforcer",),
    "renforcent": ("renforcer",),
    "renforce": ("renforcer",),
    "renforcera": ("renforcer",),
    "renforceraient": ("renforcer",),
    "renforcerai": ("renforcer",),
    "renforcerais": ("renforcer",),
    "renforcerait": ("renforcer",),
    "renforceras": ("renforcer",),
    "renforcèrent": ("renforcer",),
    "renforcerez": ("renforcer",),
    "renforceriez": ("renforcer",),
    "renforcerions": ("renforcer",),
    "renforcerons": ("renforcer",),
    "renforceront": ("renforcer",),
    "renforcés": ("renforcer",),
    "renforces": ("renforcer",),
    "renforcez": ("renforcer",),
    "renforciez": ("renforcer",),
    "renforcions": ("renforcer",),
    "renforçons": ("renforcer",),
    "renforcie": ("renforcir",),
    "renforcies": ("renforcir",),
    "renforci": ("renforcir",),
    "renforcîmes": ("renforcir",),
    "renforcira": ("renforcir",),
    "renforciraient": ("renforcir",),
    "renforcirai": ("renforcir",),
    "renforcirais": ("renforcir",),
    "renforcirait": ("renforcir",),
    "renforciras": ("renforcir",),
    "renforcirent": ("renforcir",),
    "renforcirez": ("renforcir",),
    "renforciriez": ("renforcir",),
    "renforcirions": ("renforcir",),
    "renforcirons": ("renforcir",),
    "renforciront": ("renforcir",),
    "renforcis": ("renforcir",),
    "renforcissaient": ("renforcir",),
    "renforcissais": ("renforcir",),
    "renforcissait": ("renforcir",),
    "renforcissant": ("renforcir",),
    "renforcissent": ("renforcir",),
    "renforcisse": ("renforcir",),
    "renforcisses": ("renforcir",),
    "renforcissez": ("renforcir",),
    "renforcissiez": ("renforcir",),
    "renforcissions": ("renforcir",),
    "renforcissons": ("renforcir",),
    "renforcîtes": ("renforcir",),
    "renforcit": ("renforcir",),
    "renforcît": ("renforcir",),
    "renformie": ("renformir",),
    "renformies": ("renformir",),
    "renformi": ("renformir",),
    "renformîmes": ("renformir",),
    "renformira": ("renformir",),
    "renformiraient": ("renformir",),
    "renformirai": ("renformir",),
    "renformirais": ("renformir",),
    "renformirait": ("renformir",),
    "renformiras": ("renformir",),
    "renformirent": ("renformir",),
    "renformirez": ("renformir",),
    "renformiriez": ("renformir",),
    "renformirions": ("renformir",),
    "renformirons": ("renformir",),
    "renformiront": ("renformir",),
    "renformis": ("renformir",),
    "renformissaient": ("renformir",),
    "renformissais": ("renformir",),
    "renformissait": ("renformir",),
    "renformissant": ("renformir",),
    "renformissent": ("renformir",),
    "renformisse": ("renformir",),
    "renformisses": ("renformir",),
    "renformissez": ("renformir",),
    "renformissiez": ("renformir",),
    "renformissions": ("renformir",),
    "renformissons": ("renformir",),
    "renformîtes": ("renformir",),
    "renformit": ("renformir",),
    "renformît": ("renformir",),
    "renfouie": ("renfouir",),
    "renfouies": ("renfouir",),
    "renfoui": ("renfouir",),
    "renfouîmes": ("renfouir",),
    "renfouira": ("renfouir",),
    "renfouiraient": ("renfouir",),
    "renfouirai": ("renfouir",),
    "renfouirais": ("renfouir",),
    "renfouirait": ("renfouir",),
    "renfouiras": ("renfouir",),
    "renfouirent": ("renfouir",),
    "renfouirez": ("renfouir",),
    "renfouiriez": ("renfouir",),
    "renfouirions": ("renfouir",),
    "renfouirons": ("renfouir",),
    "renfouiront": ("renfouir",),
    "renfouis": ("renfouir",),
    "renfouissaient": ("renfouir",),
    "renfouissais": ("renfouir",),
    "renfouissait": ("renfouir",),
    "renfouissant": ("renfouir",),
    "renfouissent": ("renfouir",),
    "renfouisse": ("renfouir",),
    "renfouisses": ("renfouir",),
    "renfouissez": ("renfouir",),
    "renfouissiez": ("renfouir",),
    "renfouissions": ("renfouir",),
    "renfouissons": ("renfouir",),
    "renfouîtes": ("renfouir",),
    "renfouit": ("renfouir",),
    "renfouît": ("renfouir",),
    "rengageaient": ("rengager",),
    "rengageai": ("rengager",),
    "rengageais": ("rengager",),
    "rengageait": ("rengager",),
    "rengagea": ("rengager",),
    "rengageâmes": ("rengager",),
    "rengageant": ("rengager",),
    "rengageas": ("rengager",),
    "rengageassent": ("rengager",),
    "rengageasses": ("rengager",),
    "rengageasse": ("rengager",),
    "rengageassiez": ("rengager",),
    "rengageassions": ("rengager",),
    "rengageâtes": ("rengager",),
    "rengageât": ("rengager",),
    "rengagée": ("rengager",),
    "rengagées": ("rengager",),
    "rengagé": ("rengager",),
    "rengagent": ("rengager",),
    "rengageons": ("rengager",),
    "rengage": ("rengager",),
    "rengagera": ("rengager",),
    "rengageraient": ("rengager",),
    "rengagerai": ("rengager",),
    "rengagerais": ("rengager",),
    "rengagerait": ("rengager",),
    "rengageras": ("rengager",),
    "rengagèrent": ("rengager",),
    "rengagerez": ("rengager",),
    "rengageriez": ("rengager",),
    "rengagerions": ("rengager",),
    "rengagerons": ("rengager",),
    "rengageront": ("rengager",),
    "rengagés": ("rengager",),
    "rengages": ("rengager",),
    "rengagez": ("rengager",),
    "rengagiez": ("rengager",),
    "rengagions": ("rengager",),
    "rengonçaient": ("rengoncer",),
    "rengonçai": ("rengoncer",),
    "rengonçais": ("rengoncer",),
    "rengonçait": ("rengoncer",),
    "rengonça": ("rengoncer",),
    "rengonçâmes": ("rengoncer",),
    "rengonçant": ("rengoncer",),
    "rengonças": ("rengoncer",),
    "rengonçassent": ("rengoncer",),
    "rengonçasses": ("rengoncer",),
    "rengonçasse": ("rengoncer",),
    "rengonçassiez": ("rengoncer",),
    "rengonçassions": ("rengoncer",),
    "rengonçâtes": ("rengoncer",),
    "rengonçât": ("rengoncer",),
    "rengoncée": ("rengoncer",),
    "rengoncées": ("rengoncer",),
    "rengoncé": ("rengoncer",),
    "rengoncent": ("rengoncer",),
    "rengonce": ("rengoncer",),
    "rengoncera": ("rengoncer",),
    "rengonceraient": ("rengoncer",),
    "rengoncerai": ("rengoncer",),
    "rengoncerais": ("rengoncer",),
    "rengoncerait": ("rengoncer",),
    "rengonceras": ("rengoncer",),
    "rengoncèrent": ("rengoncer",),
    "rengoncerez": ("rengoncer",),
    "rengonceriez": ("rengoncer",),
    "rengoncerions": ("rengoncer",),
    "rengoncerons": ("rengoncer",),
    "rengonceront": ("rengoncer",),
    "rengoncés": ("rengoncer",),
    "rengonces": ("rengoncer",),
    "rengoncez": ("rengoncer",),
    "rengonciez": ("rengoncer",),
    "rengoncions": ("rengoncer",),
    "rengonçons": ("rengoncer",),
    "rengorgeaient": ("rengorger",),
    "rengorgeai": ("rengorger",),
    "rengorgeais": ("rengorger",),
    "rengorgeait": ("rengorger",),
    "rengorgea": ("rengorger",),
    "rengorgeâmes": ("rengorger",),
    "rengorgeant": ("rengorger",),
    "rengorgeas": ("rengorger",),
    "rengorgeassent": ("rengorger",),
    "rengorgeasses": ("rengorger",),
    "rengorgeasse": ("rengorger",),
    "rengorgeassiez": ("rengorger",),
    "rengorgeassions": ("rengorger",),
    "rengorgeâtes": ("rengorger",),
    "rengorgeât": ("rengorger",),
    "rengorgée": ("rengorger",),
    "rengorgées": ("rengorger",),
    "rengorgé": ("rengorger",),
    "rengorgent": ("rengorger",),
    "rengorgeons": ("rengorger",),
    "rengorge": ("rengorger",),
    "rengorgera": ("rengorger",),
    "rengorgeraient": ("rengorger",),
    "rengorgerai": ("rengorger",),
    "rengorgerais": ("rengorger",),
    "rengorgerait": ("rengorger",),
    "rengorgeras": ("rengorger",),
    "rengorgèrent": ("rengorger",),
    "rengorgerez": ("rengorger",),
    "rengorgeriez": ("rengorger",),
    "rengorgerions": ("rengorger",),
    "rengorgerons": ("rengorger",),
    "rengorgeront": ("rengorger",),
    "rengorgés": ("rengorger",),
    "rengorges": ("rengorger",),
    "rengorgez": ("rengorger",),
    "rengorgiez": ("rengorger",),
    "rengorgions": ("rengorger",),
    "rengraciaient": ("rengracier",),
    "rengraciai": ("rengracier",),
    "rengraciais": ("rengracier",),
    "rengraciait": ("rengracier",),
    "rengracia": ("rengracier",),
    "rengraciâmes": ("rengracier",),
    "rengraciant": ("rengracier",),
    "rengracias": ("rengracier",),
    "rengraciassent": ("rengracier",),
    "rengraciasses": ("rengracier",),
    "rengraciasse": ("rengracier",),
    "rengraciassiez": ("rengracier",),
    "rengraciassions": ("rengracier",),
    "rengraciâtes": ("rengracier",),
    "rengraciât": ("rengracier",),
    "rengracié": ("rengracier",),
    "rengracient": ("rengracier",),
    "rengracie": ("rengracier",),
    "rengraciera": ("rengracier",),
    "rengracieraient": ("rengracier",),
    "rengracierai": ("rengracier",),
    "rengracierais": ("rengracier",),
    "rengracierait": ("rengracier",),
    "rengracieras": ("rengracier",),
    "rengracièrent": ("rengracier",),
    "rengracierez": ("rengracier",),
    "rengracieriez": ("rengracier",),
    "rengracierions": ("rengracier",),
    "rengracierons": ("rengracier",),
    "rengracieront": ("rengracier",),
    "rengracies": ("rengracier",),
    "rengraciez": ("rengracier",),
    "rengraciiez": ("rengracier",),
    "rengraciions": ("rengracier",),
    "rengracions": ("rengracier",),
    "rengraci": ("rengracir",),
    "rengracîmes": ("rengracir",),
    "rengracira": ("rengracir",),
    "rengraciraient": ("rengracir",),
    "rengracirai": ("rengracir",),
    "rengracirais": ("rengracir",),
    "rengracirait": ("rengracir",),
    "rengraciras": ("rengracir",),
    "rengracirent": ("rengracir",),
    "rengracirez": ("rengracir",),
    "rengraciriez": ("rengracir",),
    "rengracirions": ("rengracir",),
    "rengracirons": ("rengracir",),
    "rengraciront": ("rengracir",),
    "rengracis": ("rengracir",),
    "rengracissaient": ("rengracir",),
    "rengracissais": ("rengracir",),
    "rengracissait": ("rengracir",),
    "rengracissant": ("rengracir",),
    "rengracissent": ("rengracir",),
    "rengracisse": ("rengracir",),
    "rengracisses": ("rengracir",),
    "rengracissez": ("rengracir",),
    "rengracissiez": ("rengracir",),
    "rengracissions": ("rengracir",),
    "rengracissons": ("rengracir",),
    "rengracîtes": ("rengracir",),
    "rengracit": ("rengracir",),
    "rengracît": ("rengracir",),
    "rengrégeaient": ("rengréger",),
    "rengrégeai": ("rengréger",),
    "rengrégeais": ("rengréger",),
    "rengrégeait": ("rengréger",),
    "rengrégea": ("rengréger",),
    "rengrégeâmes": ("rengréger",),
    "rengrégeant": ("rengréger",),
    "rengrégeas": ("rengréger",),
    "rengrégeassent": ("rengréger",),
    "rengrégeasses": ("rengréger",),
    "rengrégeasse": ("rengréger",),
    "rengrégeassiez": ("rengréger",),
    "rengrégeassions": ("rengréger",),
    "rengrégeâtes": ("rengréger",),
    "rengrégeât": ("rengréger",),
    "rengrégée": ("rengréger",),
    "rengrégées": ("rengréger",),
    "rengrégé": ("rengréger",),
    "rengrègent": ("rengréger",),
    "rengrégeons": ("rengréger",),
    "rengrège": ("rengréger",),
    "rengrégera": ("rengréger",),
    "rengrégeraient": ("rengréger",),
    "rengrégerai": ("rengréger",),
    "rengrégerais": ("rengréger",),
    "rengrégerait": ("rengréger",),
    "rengrégeras": ("rengréger",),
    "rengrégèrent": ("rengréger",),
    "rengrégerez": ("rengréger",),
    "rengrégeriez": ("rengréger",),
    "rengrégerions": ("rengréger",),
    "rengrégerons": ("rengréger",),
    "rengrégeront": ("rengréger",),
    "rengrégés": ("rengréger",),
    "rengrèges": ("rengréger",),
    "rengrégez": ("rengréger",),
    "rengrégiez": ("rengréger",),
    "rengrégions": ("rengréger",),
    "renhardie": ("renhardir",),
    "renhardies": ("renhardir",),
    "renhardi": ("renhardir",),
    "renhardîmes": ("renhardir",),
    "renhardira": ("renhardir",),
    "renhardiraient": ("renhardir",),
    "renhardirai": ("renhardir",),
    "renhardirais": ("renhardir",),
    "renhardirait": ("renhardir",),
    "renhardiras": ("renhardir",),
    "renhardirent": ("renhardir",),
    "renhardirez": ("renhardir",),
    "renhardiriez": ("renhardir",),
    "renhardirions": ("renhardir",),
    "renhardirons": ("renhardir",),
    "renhardiront": ("renhardir",),
    "renhardis": ("renhardir",),
    "renhardissaient": ("renhardir",),
    "renhardissais": ("renhardir",),
    "renhardissait": ("renhardir",),
    "renhardissant": ("renhardir",),
    "renhardissent": ("renhardir",),
    "renhardisse": ("renhardir",),
    "renhardisses": ("renhardir",),
    "renhardissez": ("renhardir",),
    "renhardissiez": ("renhardir",),
    "renhardissions": ("renhardir",),
    "renhardissons": ("renhardir",),
    "renhardîtes": ("renhardir",),
    "renhardit": ("renhardir",),
    "renhardît": ("renhardir",),
    "reniaient": ("renier",),
    "reniai": ("renier",),
    "reniais": ("renier",),
    "reniait": ("renier",),
    "renia": ("renier",),
    "reniâmes": ("renier",),
    "reniant": ("renier",),
    "renias": ("renier",),
    "reniassent": ("renier",),
    "reniasses": ("renier",),
    "reniasse": ("renier",),
    "reniassiez": ("renier",),
    "reniassions": ("renier",),
    "reniâtes": ("renier",),
    "reniât": ("renier",),
    "reniée": ("renier",),
    "reniées": ("renier",),
    "renié": ("renier",),
    "renient": ("renier",),
    "renie": ("renier",),
    "reniera": ("renier",),
    "renieraient": ("renier",),
    "renierai": ("renier",),
    "renierais": ("renier",),
    "renierait": ("renier",),
    "renieras": ("renier",),
    "renièrent": ("renier",),
    "renierez": ("renier",),
    "renieriez": ("renier",),
    "renierions": ("renier",),
    "renierons": ("renier",),
    "renieront": ("renier",),
    "reniés": ("renier",),
    "renies": ("renier",),
    "reniez": ("renier",),
    "reniiez": ("renier",),
    "reniions": ("renier",),
    "renions": ("renier",),
    "renoircie": ("renoircir",),
    "renoircies": ("renoircir",),
    "renoirci": ("renoircir",),
    "renoircîmes": ("renoircir",),
    "renoircira": ("renoircir",),
    "renoirciraient": ("renoircir",),
    "renoircirai": ("renoircir",),
    "renoircirais": ("renoircir",),
    "renoircirait": ("renoircir",),
    "renoirciras": ("renoircir",),
    "renoircirent": ("renoircir",),
    "renoircirez": ("renoircir",),
    "renoirciriez": ("renoircir",),
    "renoircirions": ("renoircir",),
    "renoircirons": ("renoircir",),
    "renoirciront": ("renoircir",),
    "renoircis": ("renoircir",),
    "renoircissaient": ("renoircir",),
    "renoircissais": ("renoircir",),
    "renoircissait": ("renoircir",),
    "renoircissant": ("renoircir",),
    "renoircissent": ("renoircir",),
    "renoircisse": ("renoircir",),
    "renoircisses": ("renoircir",),
    "renoircissez": ("renoircir",),
    "renoircissiez": ("renoircir",),
    "renoircissions": ("renoircir",),
    "renoircissons": ("renoircir",),
    "renoircîtes": ("renoircir",),
    "renoircit": ("renoircir",),
    "renoircît": ("renoircir",),
    "renonçaient": ("renoncer",),
    "renonçai": ("renoncer",),
    "renonçais": ("renoncer",),
    "renonçait": ("renoncer",),
    "renonça": ("renoncer",),
    "renonçâmes": ("renoncer",),
    "renonçant": ("renoncer",),
    "renonças": ("renoncer",),
    "renonçassent": ("renoncer",),
    "renonçasses": ("renoncer",),
    "renonçasse": ("renoncer",),
    "renonçassiez": ("renoncer",),
    "renonçassions": ("renoncer",),
    "renonçâtes": ("renoncer",),
    "renonçât": ("renoncer",),
    "renoncé": ("renoncer",),
    "renoncent": ("renoncer",),
    "renonce": ("renoncer",),
    "renoncera": ("renoncer",),
    "renonceraient": ("renoncer",),
    "renoncerai": ("renoncer",),
    "renoncerais": ("renoncer",),
    "renoncerait": ("renoncer",),
    "renonceras": ("renoncer",),
    "renoncèrent": ("renoncer",),
    "renoncerez": ("renoncer",),
    "renonceriez": ("renoncer",),
    "renoncerions": ("renoncer",),
    "renoncerons": ("renoncer",),
    "renonceront": ("renoncer",),
    "renonces": ("renoncer",),
    "renoncez": ("renoncer",),
    "renonciez": ("renoncer",),
    "renoncions": ("renoncer",),
    "renonçons": ("renoncer",),
    "renotifiaient": ("renotifier",),
    "renotifiai": ("renotifier",),
    "renotifiais": ("renotifier",),
    "renotifiait": ("renotifier",),
    "renotifia": ("renotifier",),
    "renotifiâmes": ("renotifier",),
    "renotifiant": ("renotifier",),
    "renotifias": ("renotifier",),
    "renotifiassent": ("renotifier",),
    "renotifiasses": ("renotifier",),
    "renotifiasse": ("renotifier",),
    "renotifiassiez": ("renotifier",),
    "renotifiassions": ("renotifier",),
    "renotifiâtes": ("renotifier",),
    "renotifiât": ("renotifier",),
    "renotifiée": ("renotifier",),
    "renotifiées": ("renotifier",),
    "renotifié": ("renotifier",),
    "renotifient": ("renotifier",),
    "renotifie": ("renotifier",),
    "renotifiera": ("renotifier",),
    "renotifieraient": ("renotifier",),
    "renotifierai": ("renotifier",),
    "renotifierais": ("renotifier",),
    "renotifierait": ("renotifier",),
    "renotifieras": ("renotifier",),
    "renotifièrent": ("renotifier",),
    "renotifierez": ("renotifier",),
    "renotifieriez": ("renotifier",),
    "renotifierions": ("renotifier",),
    "renotifierons": ("renotifier",),
    "renotifieront": ("renotifier",),
    "renotifiés": ("renotifier",),
    "renotifies": ("renotifier",),
    "renotifiez": ("renotifier",),
    "renotifiiez": ("renotifier",),
    "renotifiions": ("renotifier",),
    "renotifions": ("renotifier",),
    "renourrie": ("renourrir",),
    "renourries": ("renourrir",),
    "renourri": ("renourrir",),
    "renourrîmes": ("renourrir",),
    "renourrira": ("renourrir",),
    "renourriraient": ("renourrir",),
    "renourrirai": ("renourrir",),
    "renourrirais": ("renourrir",),
    "renourrirait": ("renourrir",),
    "renourriras": ("renourrir",),
    "renourrirent": ("renourrir",),
    "renourrirez": ("renourrir",),
    "renourririez": ("renourrir",),
    "renourririons": ("renourrir",),
    "renourrirons": ("renourrir",),
    "renourriront": ("renourrir",),
    "renourris": ("renourrir",),
    "renourrissaient": ("renourrir",),
    "renourrissais": ("renourrir",),
    "renourrissait": ("renourrir",),
    "renourrissant": ("renourrir",),
    "renourrissent": ("renourrir",),
    "renourrisse": ("renourrir",),
    "renourrisses": ("renourrir",),
    "renourrissez": ("renourrir",),
    "renourrissiez": ("renourrir",),
    "renourrissions": ("renourrir",),
    "renourrissons": ("renourrir",),
    "renourrîtes": ("renourrir",),
    "renourrit": ("renourrir",),
    "renourrît": ("renourrir",),
    "renouvelaient": ("renouveler",),
    "renouvelai": ("renouveler",),
    "renouvelais": ("renouveler",),
    "renouvelait": ("renouveler",),
    "renouvela": ("renouveler",),
    "renouvelâmes": ("renouveler",),
    "renouvelant": ("renouveler",),
    "renouvelas": ("renouveler",),
    "renouvelassent": ("renouveler",),
    "renouvelasses": ("renouveler",),
    "renouvelasse": ("renouveler",),
    "renouvelassiez": ("renouveler",),
    "renouvelassions": ("renouveler",),
    "renouvelâtes": ("renouveler",),
    "renouvelât": ("renouveler",),
    "renouvelée": ("renouveler",),
    "renouvelées": ("renouveler",),
    "renouvelé": ("renouveler",),
    "renouvelèrent": ("renouveler",),
    "renouvelés": ("renouveler",),
    "renouvelez": ("renouveler",),
    "renouveliez": ("renouveler",),
    "renouvelions": ("renouveler",),
    "renouvellent": ("renouveler",),
    "renouvelle": ("renouveler",),
    "renouvellera": ("renouveler",),
    "renouvelleraient": ("renouveler",),
    "renouvellerai": ("renouveler",),
    "renouvellerais": ("renouveler",),
    "renouvellerait": ("renouveler",),
    "renouvelleras": ("renouveler",),
    "renouvellerez": ("renouveler",),
    "renouvelleriez": ("renouveler",),
    "renouvellerions": ("renouveler",),
    "renouvellerons": ("renouveler",),
    "renouvelleront": ("renouveler",),
    "renouvelles": ("renouveler",),
    "renouvelons": ("renouveler",),
    "rensemençaient": ("rensemencer",),
    "rensemençai": ("rensemencer",),
    "rensemençais": ("rensemencer",),
    "rensemençait": ("rensemencer",),
    "rensemença": ("rensemencer",),
    "rensemençâmes": ("rensemencer",),
    "rensemençant": ("rensemencer",),
    "rensemenças": ("rensemencer",),
    "rensemençassent": ("rensemencer",),
    "rensemençasses": ("rensemencer",),
    "rensemençasse": ("rensemencer",),
    "rensemençassiez": ("rensemencer",),
    "rensemençassions": ("rensemencer",),
    "rensemençâtes": ("rensemencer",),
    "rensemençât": ("rensemencer",),
    "rensemencée": ("rensemencer",),
    "rensemencées": ("rensemencer",),
    "rensemencé": ("rensemencer",),
    "rensemencent": ("rensemencer",),
    "rensemence": ("rensemencer",),
    "rensemencera": ("rensemencer",),
    "rensemenceraient": ("rensemencer",),
    "rensemencerai": ("rensemencer",),
    "rensemencerais": ("rensemencer",),
    "rensemencerait": ("rensemencer",),
    "rensemenceras": ("rensemencer",),
    "rensemencèrent": ("rensemencer",),
    "rensemencerez": ("rensemencer",),
    "rensemenceriez": ("rensemencer",),
    "rensemencerions": ("rensemencer",),
    "rensemencerons": ("rensemencer",),
    "rensemenceront": ("rensemencer",),
    "rensemencés": ("rensemencer",),
    "rensemences": ("rensemencer",),
    "rensemencez": ("rensemencer",),
    "rensemenciez": ("rensemencer",),
    "rensemencions": ("rensemencer",),
    "rensemençons": ("rensemencer",),
    "rentraient": ("rentrayer",),
    "rentraie": ("rentrayer",),
    "rentraies": ("rentrayer",),
    "rentraira": ("rentraire",),
    "rentrairaient": ("rentraire",),
    "rentrairai": ("rentraire",),
    "rentrairais": ("rentraire",),
    "rentrairait": ("rentraire",),
    "rentrairas": ("rentraire",),
    "rentrairez": ("rentraire",),
    "rentrairiez": ("rentraire",),
    "rentrairions": ("rentraire",),
    "rentrairons": ("rentraire",),
    "rentrairont": ("rentraire",),
    "rentrais": ("rentraire",),
    "rentraite": ("rentraire",),
    "rentraites": ("rentraire",),
    "rentrait": ("rentraire",),
    "rentraits": ("rentraire",),
    "rentrayaient": ("rentrayer",),
    "rentrayais": ("rentrayer",),
    "rentrayait": ("rentrayer",),
    "rentrayant": ("rentrayer",),
    "rentrayez": ("rentrayer",),
    "rentrayiez": ("rentrayer",),
    "rentrayions": ("rentrayer",),
    "rentrayons": ("rentrayer",),
    "rentraiera": ("rentrayer",),
    "rentraieraient": ("rentrayer",),
    "rentraierai": ("rentrayer",),
    "rentraierais": ("rentrayer",),
    "rentraierait": ("rentrayer",),
    "rentraieras": ("rentrayer",),
    "rentraierez": ("rentrayer",),
    "rentraieriez": ("rentrayer",),
    "rentraierions": ("rentrayer",),
    "rentraierons": ("rentrayer",),
    "rentraieront": ("rentrayer",),
    "rentrayai": ("rentrayer",),
    "rentraya": ("rentrayer",),
    "rentrayâmes": ("rentrayer",),
    "rentrayas": ("rentrayer",),
    "rentrayassent": ("rentrayer",),
    "rentrayasses": ("rentrayer",),
    "rentrayasse": ("rentrayer",),
    "rentrayassiez": ("rentrayer",),
    "rentrayassions": ("rentrayer",),
    "rentrayâtes": ("rentrayer",),
    "rentrayât": ("rentrayer",),
    "rentrayée": ("rentrayer",),
    "rentrayées": ("rentrayer",),
    "rentrayé": ("rentrayer",),
    "rentrayent": ("rentrayer",),
    "rentraye": ("rentrayer",),
    "rentrayera": ("rentrayer",),
    "rentrayeraient": ("rentrayer",),
    "rentrayerai": ("rentrayer",),
    "rentrayerais": ("rentrayer",),
    "rentrayerait": ("rentrayer",),
    "rentrayeras": ("rentrayer",),
    "rentrayèrent": ("rentrayer",),
    "rentrayerez": ("rentrayer",),
    "rentrayeriez": ("rentrayer",),
    "rentrayerions": ("rentrayer",),
    "rentrayerons": ("rentrayer",),
    "rentrayeront": ("rentrayer",),
    "rentrayés": ("rentrayer",),
    "rentrayes": ("rentrayer",),
    "rentrouverte": ("rentrouvrir",),
    "rentrouvertes": ("rentrouvrir",),
    "rentrouvert": ("rentrouvrir",),
    "rentrouverts": ("rentrouvrir",),
    "rentrouvraient": ("rentrouvrir",),
    "rentrouvrais": ("rentrouvrir",),
    "rentrouvrait": ("rentrouvrir",),
    "rentrouvrant": ("rentrouvrir",),
    "rentrouvrent": ("rentrouvrir",),
    "rentrouvre": ("rentrouvrir",),
    "rentrouvres": ("rentrouvrir",),
    "rentrouvrez": ("rentrouvrir",),
    "rentrouvriez": ("rentrouvrir",),
    "rentrouvrîmes": ("rentrouvrir",),
    "rentrouvrions": ("rentrouvrir",),
    "rentrouvrira": ("rentrouvrir",),
    "rentrouvriraient": ("rentrouvrir",),
    "rentrouvrirai": ("rentrouvrir",),
    "rentrouvrirais": ("rentrouvrir",),
    "rentrouvrirait": ("rentrouvrir",),
    "rentrouvriras": ("rentrouvrir",),
    "rentrouvrirent": ("rentrouvrir",),
    "rentrouvrirez": ("rentrouvrir",),
    "rentrouvririez": ("rentrouvrir",),
    "rentrouvririons": ("rentrouvrir",),
    "rentrouvrirons": ("rentrouvrir",),
    "rentrouvriront": ("rentrouvrir",),
    "rentrouvris": ("rentrouvrir",),
    "rentrouvrissent": ("rentrouvrir",),
    "rentrouvrisses": ("rentrouvrir",),
    "rentrouvrisse": ("rentrouvrir",),
    "rentrouvrissiez": ("rentrouvrir",),
    "rentrouvrissions": ("rentrouvrir",),
    "rentrouvrîtes": ("rentrouvrir",),
    "rentrouvrit": ("rentrouvrir",),
    "rentrouvrît": ("rentrouvrir",),
    "rentrouvrons": ("rentrouvrir",),
    "renuançaient": ("renuancer",),
    "renuançai": ("renuancer",),
    "renuançais": ("renuancer",),
    "renuançait": ("renuancer",),
    "renuança": ("renuancer",),
    "renuançâmes": ("renuancer",),
    "renuançant": ("renuancer",),
    "renuanças": ("renuancer",),
    "renuançassent": ("renuancer",),
    "renuançasses": ("renuancer",),
    "renuançasse": ("renuancer",),
    "renuançassiez": ("renuancer",),
    "renuançassions": ("renuancer",),
    "renuançâtes": ("renuancer",),
    "renuançât": ("renuancer",),
    "renuancée": ("renuancer",),
    "renuancées": ("renuancer",),
    "renuancé": ("renuancer",),
    "renuancent": ("renuancer",),
    "renuance": ("renuancer",),
    "renuancera": ("renuancer",),
    "renuanceraient": ("renuancer",),
    "renuancerai": ("renuancer",),
    "renuancerais": ("renuancer",),
    "renuancerait": ("renuancer",),
    "renuanceras": ("renuancer",),
    "renuancèrent": ("renuancer",),
    "renuancerez": ("renuancer",),
    "renuanceriez": ("renuancer",),
    "renuancerions": ("renuancer",),
    "renuancerons": ("renuancer",),
    "renuanceront": ("renuancer",),
    "renuancés": ("renuancer",),
    "renuances": ("renuancer",),
    "renuancez": ("renuancer",),
    "renuanciez": ("renuancer",),
    "renuancions": ("renuancer",),
    "renuançons": ("renuancer",),
    "renvergeaient": ("renverger",),
    "renvergeai": ("renverger",),
    "renvergeais": ("renverger",),
    "renvergeait": ("renverger",),
    "renvergea": ("renverger",),
    "renvergeâmes": ("renverger",),
    "renvergeant": ("renverger",),
    "renvergeas": ("renverger",),
    "renvergeassent": ("renverger",),
    "renvergeasses": ("renverger",),
    "renvergeasse": ("renverger",),
    "renvergeassiez": ("renverger",),
    "renvergeassions": ("renverger",),
    "renvergeâtes": ("renverger",),
    "renvergeât": ("renverger",),
    "renvergée": ("renverger",),
    "renvergées": ("renverger",),
    "renvergé": ("renverger",),
    "renvergent": ("renverger",),
    "renvergeons": ("renverger",),
    "renverge": ("renverger",),
    "renvergera": ("renverger",),
    "renvergeraient": ("renverger",),
    "renvergerai": ("renverger",),
    "renvergerais": ("renverger",),
    "renvergerait": ("renverger",),
    "renvergeras": ("renverger",),
    "renvergèrent": ("renverger",),
    "renvergerez": ("renverger",),
    "renvergeriez": ("renverger",),
    "renvergerions": ("renverger",),
    "renvergerons": ("renverger",),
    "renvergeront": ("renverger",),
    "renvergés": ("renverger",),
    "renverges": ("renverger",),
    "renvergez": ("renverger",),
    "renvergiez": ("renverger",),
    "renvergions": ("renverger",),
    "renviaient": ("renvier",),
    "renviai": ("renvier",),
    "renviais": ("renvier",),
    "renviait": ("renvier",),
    "renvia": ("renvier",),
    "renviâmes": ("renvier",),
    "renviant": ("renvier",),
    "renvias": ("renvier",),
    "renviassent": ("renvier",),
    "renviasses": ("renvier",),
    "renviasse": ("renvier",),
    "renviassiez": ("renvier",),
    "renviassions": ("renvier",),
    "renviâtes": ("renvier",),
    "renviât": ("renvier",),
    "renviée": ("renvier",),
    "renviées": ("renvier",),
    "renvié": ("renvier",),
    "renvient": ("renvier",),
    "renvie": ("renvier",),
    "renviera": ("renvier",),
    "renvieraient": ("renvier",),
    "renvierai": ("renvier",),
    "renvierais": ("renvier",),
    "renvierait": ("renvier",),
    "renvieras": ("renvier",),
    "renvièrent": ("renvier",),
    "renvierez": ("renvier",),
    "renvieriez": ("renvier",),
    "renvierions": ("renvier",),
    "renvierons": ("renvier",),
    "renvieront": ("renvier",),
    "renviés": ("renvier",),
    "renvies": ("renvier",),
    "renviez": ("renvier",),
    "renviiez": ("renvier",),
    "renviions": ("renvier",),
    "renvions": ("renvier",),
    "renverra": ("renvoyer",),
    "renverraient": ("renvoyer",),
    "renverrai": ("renvoyer",),
    "renverrais": ("renvoyer",),
    "renverrait": ("renvoyer",),
    "renverras": ("renvoyer",),
    "renverrez": ("renvoyer",),
    "renverriez": ("renvoyer",),
    "renverrions": ("renvoyer",),
    "renverrons": ("renvoyer",),
    "renverront": ("renvoyer",),
    "renvoient": ("renvoyer",),
    "renvoie": ("renvoyer",),
    "renvoies": ("renvoyer",),
    "renvoyaient": ("renvoyer",),
    "renvoyai": ("renvoyer",),
    "renvoyais": ("renvoyer",),
    "renvoyait": ("renvoyer",),
    "renvoya": ("renvoyer",),
    "renvoyâmes": ("renvoyer",),
    "renvoyant": ("renvoyer",),
    "renvoyas": ("renvoyer",),
    "renvoyassent": ("renvoyer",),
    "renvoyasses": ("renvoyer",),
    "renvoyasse": ("renvoyer",),
    "renvoyassiez": ("renvoyer",),
    "renvoyassions": ("renvoyer",),
    "renvoyâtes": ("renvoyer",),
    "renvoyât": ("renvoyer",),
    "renvoyée": ("renvoyer",),
    "renvoyées": ("renvoyer",),
    "renvoyé": ("renvoyer",),
    "renvoyèrent": ("renvoyer",),
    "renvoyés": ("renvoyer",),
    "renvoyez": ("renvoyer",),
    "renvoyiez": ("renvoyer",),
    "renvoyions": ("renvoyer",),
    "renvoyons": ("renvoyer",),
    "réobligeaient": ("réobliger",),
    "réobligeai": ("réobliger",),
    "réobligeais": ("réobliger",),
    "réobligeait": ("réobliger",),
    "réobligea": ("réobliger",),
    "réobligeâmes": ("réobliger",),
    "réobligeant": ("réobliger",),
    "réobligeas": ("réobliger",),
    "réobligeassent": ("réobliger",),
    "réobligeasses": ("réobliger",),
    "réobligeasse": ("réobliger",),
    "réobligeassiez": ("réobliger",),
    "réobligeassions": ("réobliger",),
    "réobligeâtes": ("réobliger",),
    "réobligeât": ("réobliger",),
    "réobligée": ("réobliger",),
    "réobligées": ("réobliger",),
    "réobligé": ("réobliger",),
    "réobligent": ("réobliger",),
    "réobligeons": ("réobliger",),
    "réoblige": ("réobliger",),
    "réobligera": ("réobliger",),
    "réobligeraient": ("réobliger",),
    "réobligerai": ("réobliger",),
    "réobligerais": ("réobliger",),
    "réobligerait": ("réobliger",),
    "réobligeras": ("réobliger",),
    "réobligèrent": ("réobliger",),
    "réobligerez": ("réobliger",),
    "réobligeriez": ("réobliger",),
    "réobligerions": ("réobliger",),
    "réobligerons": ("réobliger",),
    "réobligeront": ("réobliger",),
    "réobligés": ("réobliger",),
    "réobliges": ("réobliger",),
    "réobligez": ("réobliger",),
    "réobligiez": ("réobliger",),
    "réobligions": ("réobliger",),
    "réobscurcie": ("réobscurcir",),
    "réobscurcies": ("réobscurcir",),
    "réobscurci": ("réobscurcir",),
    "réobscurcîmes": ("réobscurcir",),
    "réobscurcira": ("réobscurcir",),
    "réobscurciraient": ("réobscurcir",),
    "réobscurcirai": ("réobscurcir",),
    "réobscurcirais": ("réobscurcir",),
    "réobscurcirait": ("réobscurcir",),
    "réobscurciras": ("réobscurcir",),
    "réobscurcirent": ("réobscurcir",),
    "réobscurcirez": ("réobscurcir",),
    "réobscurciriez": ("réobscurcir",),
    "réobscurcirions": ("réobscurcir",),
    "réobscurcirons": ("réobscurcir",),
    "réobscurciront": ("réobscurcir",),
    "réobscurcis": ("réobscurcir",),
    "réobscurcissaient": ("réobscurcir",),
    "réobscurcissais": ("réobscurcir",),
    "réobscurcissait": ("réobscurcir",),
    "réobscurcissant": ("réobscurcir",),
    "réobscurcissent": ("réobscurcir",),
    "réobscurcisse": ("réobscurcir",),
    "réobscurcisses": ("réobscurcir",),
    "réobscurcissez": ("réobscurcir",),
    "réobscurcissiez": ("réobscurcir",),
    "réobscurcissions": ("réobscurcir",),
    "réobscurcissons": ("réobscurcir",),
    "réobscurcîtes": ("réobscurcir",),
    "réobscurcit": ("réobscurcir",),
    "réobscurcît": ("réobscurcir",),
    "réobtempéraient": ("réobtempérer",),
    "réobtempérai": ("réobtempérer",),
    "réobtempérais": ("réobtempérer",),
    "réobtempérait": ("réobtempérer",),
    "réobtempéra": ("réobtempérer",),
    "réobtempérâmes": ("réobtempérer",),
    "réobtempérant": ("réobtempérer",),
    "réobtempéras": ("réobtempérer",),
    "réobtempérassent": ("réobtempérer",),
    "réobtempérasses": ("réobtempérer",),
    "réobtempérasse": ("réobtempérer",),
    "réobtempérassiez": ("réobtempérer",),
    "réobtempérassions": ("réobtempérer",),
    "réobtempérâtes": ("réobtempérer",),
    "réobtempérât": ("réobtempérer",),
    "réobtempérée": ("réobtempérer",),
    "réobtempérées": ("réobtempérer",),
    "réobtempéré": ("réobtempérer",),
    "réobtempèrent": ("réobtempérer",),
    "réobtempère": ("réobtempérer",),
    "réobtempérera": ("réobtempérer",),
    "réobtempéreraient": ("réobtempérer",),
    "réobtempérerai": ("réobtempérer",),
    "réobtempérerais": ("réobtempérer",),
    "réobtempérerait": ("réobtempérer",),
    "réobtempéreras": ("réobtempérer",),
    "réobtempérèrent": ("réobtempérer",),
    "réobtempérerez": ("réobtempérer",),
    "réobtempéreriez": ("réobtempérer",),
    "réobtempérerions": ("réobtempérer",),
    "réobtempérerons": ("réobtempérer",),
    "réobtempéreront": ("réobtempérer",),
    "réobtempérés": ("réobtempérer",),
    "réobtempères": ("réobtempérer",),
    "réobtempérez": ("réobtempérer",),
    "réobtempériez": ("réobtempérer",),
    "réobtempérions": ("réobtempérer",),
    "réobtempérons": ("réobtempérer",),
    "réobtenaient": ("réobtenir",),
    "réobtenais": ("réobtenir",),
    "réobtenait": ("réobtenir",),
    "réobtenant": ("réobtenir",),
    "réobtenez": ("réobtenir",),
    "réobteniez": ("réobtenir",),
    "réobtenions": ("réobtenir",),
    "réobtenons": ("réobtenir",),
    "réobtenue": ("réobtenir",),
    "réobtenues": ("réobtenir",),
    "réobtenu": ("réobtenir",),
    "réobtenus": ("réobtenir",),
    "réobtiendra": ("réobtenir",),
    "réobtiendraient": ("réobtenir",),
    "réobtiendrai": ("réobtenir",),
    "réobtiendrais": ("réobtenir",),
    "réobtiendrait": ("réobtenir",),
    "réobtiendras": ("réobtenir",),
    "réobtiendrez": ("réobtenir",),
    "réobtiendriez": ("réobtenir",),
    "réobtiendrions": ("réobtenir",),
    "réobtiendrons": ("réobtenir",),
    "réobtiendront": ("réobtenir",),
    "réobtiennent": ("réobtenir",),
    "réobtienne": ("réobtenir",),
    "réobtiennes": ("réobtenir",),
    "réobtiens": ("réobtenir",),
    "réobtient": ("réobtenir",),
    "réobtînmes": ("réobtenir",),
    "réobtinrent": ("réobtenir",),
    "réobtins": ("réobtenir",),
    "réobtinssent": ("réobtenir",),
    "réobtinsses": ("réobtenir",),
    "réobtinsse": ("réobtenir",),
    "réobtinssiez": ("réobtenir",),
    "réobtinssions": ("réobtenir",),
    "réobtîntes": ("réobtenir",),
    "réobtint": ("réobtenir",),
    "réobtînt": ("réobtenir",),
    "réoctroient": ("réoctroyer",),
    "réoctroie": ("réoctroyer",),
    "réoctroiera": ("réoctroyer",),
    "réoctroieraient": ("réoctroyer",),
    "réoctroierai": ("réoctroyer",),
    "réoctroierais": ("réoctroyer",),
    "réoctroierait": ("réoctroyer",),
    "réoctroieras": ("réoctroyer",),
    "réoctroierez": ("réoctroyer",),
    "réoctroieriez": ("réoctroyer",),
    "réoctroierions": ("réoctroyer",),
    "réoctroierons": ("réoctroyer",),
    "réoctroieront": ("réoctroyer",),
    "réoctroies": ("réoctroyer",),
    "réoctroyaient": ("réoctroyer",),
    "réoctroyai": ("réoctroyer",),
    "réoctroyais": ("réoctroyer",),
    "réoctroyait": ("réoctroyer",),
    "réoctroya": ("réoctroyer",),
    "réoctroyâmes": ("réoctroyer",),
    "réoctroyant": ("réoctroyer",),
    "réoctroyas": ("réoctroyer",),
    "réoctroyassent": ("réoctroyer",),
    "réoctroyasses": ("réoctroyer",),
    "réoctroyasse": ("réoctroyer",),
    "réoctroyassiez": ("réoctroyer",),
    "réoctroyassions": ("réoctroyer",),
    "réoctroyâtes": ("réoctroyer",),
    "réoctroyât": ("réoctroyer",),
    "réoctroyée": ("réoctroyer",),
    "réoctroyées": ("réoctroyer",),
    "réoctroyé": ("réoctroyer",),
    "réoctroyèrent": ("réoctroyer",),
    "réoctroyés": ("réoctroyer",),
    "réoctroyez": ("réoctroyer",),
    "réoctroyiez": ("réoctroyer",),
    "réoctroyions": ("réoctroyer",),
    "réoctroyons": ("réoctroyer",),
    "réopéraient": ("réopérer",),
    "réopérai": ("réopérer",),
    "réopérais": ("réopérer",),
    "réopérait": ("réopérer",),
    "réopéra": ("réopérer",),
    "réopérâmes": ("réopérer",),
    "réopérant": ("réopérer",),
    "réopéras": ("réopérer",),
    "réopérassent": ("réopérer",),
    "réopérasses": ("réopérer",),
    "réopérasse": ("réopérer",),
    "réopérassiez": ("réopérer",),
    "réopérassions": ("réopérer",),
    "réopérâtes": ("réopérer",),
    "réopérât": ("réopérer",),
    "réopérée": ("réopérer",),
    "réopérées": ("réopérer",),
    "réopéré": ("réopérer",),
    "réopèrent": ("réopérer",),
    "réopère": ("réopérer",),
    "réopérera": ("réopérer",),
    "réopéreraient": ("réopérer",),
    "réopérerai": ("réopérer",),
    "réopérerais": ("réopérer",),
    "réopérerait": ("réopérer",),
    "réopéreras": ("réopérer",),
    "réopérèrent": ("réopérer",),
    "réopérerez": ("réopérer",),
    "réopéreriez": ("réopérer",),
    "réopérerions": ("réopérer",),
    "réopérerons": ("réopérer",),
    "réopéreront": ("réopérer",),
    "réopérés": ("réopérer",),
    "réopères": ("réopérer",),
    "réopérez": ("réopérer",),
    "réopériez": ("réopérer",),
    "réopérions": ("réopérer",),
    "réopérons": ("réopérer",),
    "réordonnançaient": ("réordonnancer",),
    "réordonnançai": ("réordonnancer",),
    "réordonnançais": ("réordonnancer",),
    "réordonnançait": ("réordonnancer",),
    "réordonnança": ("réordonnancer",),
    "réordonnançâmes": ("réordonnancer",),
    "réordonnançant": ("réordonnancer",),
    "réordonnanças": ("réordonnancer",),
    "réordonnançassent": ("réordonnancer",),
    "réordonnançasses": ("réordonnancer",),
    "réordonnançasse": ("réordonnancer",),
    "réordonnançassiez": ("réordonnancer",),
    "réordonnançassions": ("réordonnancer",),
    "réordonnançâtes": ("réordonnancer",),
    "réordonnançât": ("réordonnancer",),
    "réordonnancée": ("réordonnancer",),
    "réordonnancées": ("réordonnancer",),
    "réordonnancé": ("réordonnancer",),
    "réordonnancent": ("réordonnancer",),
    "réordonnance": ("réordonnancer",),
    "réordonnancera": ("réordonnancer",),
    "réordonnanceraient": ("réordonnancer",),
    "réordonnancerai": ("réordonnancer",),
    "réordonnancerais": ("réordonnancer",),
    "réordonnancerait": ("réordonnancer",),
    "réordonnanceras": ("réordonnancer",),
    "réordonnancèrent": ("réordonnancer",),
    "réordonnancerez": ("réordonnancer",),
    "réordonnanceriez": ("réordonnancer",),
    "réordonnancerions": ("réordonnancer",),
    "réordonnancerons": ("réordonnancer",),
    "réordonnanceront": ("réordonnancer",),
    "réordonnancés": ("réordonnancer",),
    "réordonnances": ("réordonnancer",),
    "réordonnancez": ("réordonnancer",),
    "réordonnanciez": ("réordonnancer",),
    "réordonnancions": ("réordonnancer",),
    "réordonnançons": ("réordonnancer",),
    "réorthographiaient": ("réorthographier",),
    "réorthographiai": ("réorthographier",),
    "réorthographiais": ("réorthographier",),
    "réorthographiait": ("réorthographier",),
    "réorthographia": ("réorthographier",),
    "réorthographiâmes": ("réorthographier",),
    "réorthographiant": ("réorthographier",),
    "réorthographias": ("réorthographier",),
    "réorthographiassent": ("réorthographier",),
    "réorthographiasses": ("réorthographier",),
    "réorthographiasse": ("réorthographier",),
    "réorthographiassiez": ("réorthographier",),
    "réorthographiassions": ("réorthographier",),
    "réorthographiâtes": ("réorthographier",),
    "réorthographiât": ("réorthographier",),
    "réorthographiée": ("réorthographier",),
    "réorthographiées": ("réorthographier",),
    "réorthographié": ("réorthographier",),
    "réorthographient": ("réorthographier",),
    "réorthographie": ("réorthographier",),
    "réorthographiera": ("réorthographier",),
    "réorthographieraient": ("réorthographier",),
    "réorthographierai": ("réorthographier",),
    "réorthographierais": ("réorthographier",),
    "réorthographierait": ("réorthographier",),
    "réorthographieras": ("réorthographier",),
    "réorthographièrent": ("réorthographier",),
    "réorthographierez": ("réorthographier",),
    "réorthographieriez": ("réorthographier",),
    "réorthographierions": ("réorthographier",),
    "réorthographierons": ("réorthographier",),
    "réorthographieront": ("réorthographier",),
    "réorthographiés": ("réorthographier",),
    "réorthographies": ("réorthographier",),
    "réorthographiez": ("réorthographier",),
    "réorthographiiez": ("réorthographier",),
    "réorthographiions": ("réorthographier",),
    "réorthographions": ("réorthographier",),
    "réouverte": ("réouvrir",),
    "réouvertes": ("réouvrir",),
    "réouvert": ("réouvrir",),
    "réouverts": ("réouvrir",),
    "réouvraient": ("réouvrir",),
    "réouvrais": ("réouvrir",),
    "réouvrait": ("réouvrir",),
    "réouvrant": ("réouvrir",),
    "réouvrent": ("réouvrir",),
    "réouvre": ("réouvrir",),
    "réouvres": ("réouvrir",),
    "réouvrez": ("réouvrir",),
    "réouvriez": ("réouvrir",),
    "réouvrîmes": ("réouvrir",),
    "réouvrions": ("réouvrir",),
    "réouvrira": ("réouvrir",),
    "réouvriraient": ("réouvrir",),
    "réouvrirai": ("réouvrir",),
    "réouvrirais": ("réouvrir",),
    "réouvrirait": ("réouvrir",),
    "réouvriras": ("réouvrir",),
    "réouvrirent": ("réouvrir",),
    "réouvrirez": ("réouvrir",),
    "réouvririez": ("réouvrir",),
    "réouvririons": ("réouvrir",),
    "réouvrirons": ("réouvrir",),
    "réouvriront": ("réouvrir",),
    "réouvris": ("réouvrir",),
    "réouvrissent": ("réouvrir",),
    "réouvrisses": ("réouvrir",),
    "réouvrisse": ("réouvrir",),
    "réouvrissiez": ("réouvrir",),
    "réouvrissions": ("réouvrir",),
    "réouvrîtes": ("réouvrir",),
    "réouvrit": ("réouvrir",),
    "réouvrît": ("réouvrir",),
    "réouvrons": ("réouvrir",),
    "réoxygénaient": ("réoxygéner",),
    "réoxygénai": ("réoxygéner",),
    "réoxygénais": ("réoxygéner",),
    "réoxygénait": ("réoxygéner",),
    "réoxygéna": ("réoxygéner",),
    "réoxygénâmes": ("réoxygéner",),
    "réoxygénant": ("réoxygéner",),
    "réoxygénas": ("réoxygéner",),
    "réoxygénassent": ("réoxygéner",),
    "réoxygénasses": ("réoxygéner",),
    "réoxygénasse": ("réoxygéner",),
    "réoxygénassiez": ("réoxygéner",),
    "réoxygénassions": ("réoxygéner",),
    "réoxygénâtes": ("réoxygéner",),
    "réoxygénât": ("réoxygéner",),
    "réoxygénée": ("réoxygéner",),
    "réoxygénées": ("réoxygéner",),
    "réoxygéné": ("réoxygéner",),
    "réoxygènent": ("réoxygéner",),
    "réoxygène": ("réoxygéner",),
    "réoxygénera": ("réoxygéner",),
    "réoxygéneraient": ("réoxygéner",),
    "réoxygénerai": ("réoxygéner",),
    "réoxygénerais": ("réoxygéner",),
    "réoxygénerait": ("réoxygéner",),
    "réoxygéneras": ("réoxygéner",),
    "réoxygénèrent": ("réoxygéner",),
    "réoxygénerez": ("réoxygéner",),
    "réoxygéneriez": ("réoxygéner",),
    "réoxygénerions": ("réoxygéner",),
    "réoxygénerons": ("réoxygéner",),
    "réoxygéneront": ("réoxygéner",),
    "réoxygénés": ("réoxygéner",),
    "réoxygènes": ("réoxygéner",),
    "réoxygénez": ("réoxygéner",),
    "réoxygéniez": ("réoxygéner",),
    "réoxygénions": ("réoxygéner",),
    "réoxygénons": ("réoxygéner",),
    "repacifiaient": ("repacifier",),
    "repacifiai": ("repacifier",),
    "repacifiais": ("repacifier",),
    "repacifiait": ("repacifier",),
    "repacifia": ("repacifier",),
    "repacifiâmes": ("repacifier",),
    "repacifiant": ("repacifier",),
    "repacifias": ("repacifier",),
    "repacifiassent": ("repacifier",),
    "repacifiasses": ("repacifier",),
    "repacifiasse": ("repacifier",),
    "repacifiassiez": ("repacifier",),
    "repacifiassions": ("repacifier",),
    "repacifiâtes": ("repacifier",),
    "repacifiât": ("repacifier",),
    "repacifiée": ("repacifier",),
    "repacifiées": ("repacifier",),
    "repacifié": ("repacifier",),
    "repacifient": ("repacifier",),
    "repacifie": ("repacifier",),
    "repacifiera": ("repacifier",),
    "repacifieraient": ("repacifier",),
    "repacifierai": ("repacifier",),
    "repacifierais": ("repacifier",),
    "repacifierait": ("repacifier",),
    "repacifieras": ("repacifier",),
    "repacifièrent": ("repacifier",),
    "repacifierez": ("repacifier",),
    "repacifieriez": ("repacifier",),
    "repacifierions": ("repacifier",),
    "repacifierons": ("repacifier",),
    "repacifieront": ("repacifier",),
    "repacifiés": ("repacifier",),
    "repacifies": ("repacifier",),
    "repacifiez": ("repacifier",),
    "repacifiiez": ("repacifier",),
    "repacifiions": ("repacifier",),
    "repacifions": ("repacifier",),
    "repais": ("repaître",),
    "repaissaient": ("repaître",),
    "repaissais": ("repaître",),
    "repaissait": ("repaître",),
    "repaissant": ("repaître",),
    "repaissent": ("repaître",),
    "repaisse": ("repaître",),
    "repaisses": ("repaître",),
    "repaissez": ("repaître",),
    "repaissiez": ("repaître",),
    "repaissions": ("repaître",),
    "repaissons": ("repaître",),
    "repaît": ("repaître",),
    "repaîtra": ("repaître",),
    "repaîtraient": ("repaître",),
    "repaîtrai": ("repaître",),
    "repaîtrais": ("repaître",),
    "repaîtrait": ("repaître",),
    "repaîtras": ("repaître",),
    "repaîtrez": ("repaître",),
    "repaîtriez": ("repaître",),
    "repaîtrions": ("repaître",),
    "repaîtrons": ("repaître",),
    "repaîtront": ("repaître",),
    "repue": ("repaître",),
    "repues": ("repaître",),
    "repu": ("repouvoir",),
    "repûmes": ("repouvoir",),
    "repurent": ("repouvoir",),
    "repus": ("repouvoir",),
    "repussent": ("repouvoir",),
    "repusses": ("repouvoir",),
    "repusse": ("repouvoir",),
    "repussiez": ("repouvoir",),
    "repussions": ("repouvoir",),
    "repûtes": ("repouvoir",),
    "reput": ("repouvoir",),
    "repût": ("repouvoir",),
    "répandaient": ("répandre",),
    "répandais": ("répandre",),
    "répandait": ("répandre",),
    "répandant": ("répandre",),
    "répandent": ("répandre",),
    "répande": ("répandre",),
    "répandes": ("répandre",),
    "répandez": ("répandre",),
    "répandiez": ("répandre",),
    "répandîmes": ("répandre",),
    "répandions": ("répandre",),
    "répandirent": ("répandre",),
    "répandis": ("répandre",),
    "répandissent": ("répandre",),
    "répandisses": ("répandre",),
    "répandisse": ("répandre",),
    "répandissiez": ("répandre",),
    "répandissions": ("répandre",),
    "répandîtes": ("répandre",),
    "répandit": ("répandre",),
    "répandît": ("répandre",),
    "répandons": ("répandre",),
    "répand": ("répandre",),
    "répandra": ("répandre",),
    "répandraient": ("répandre",),
    "répandrai": ("répandre",),
    "répandrais": ("répandre",),
    "répandrait": ("répandre",),
    "répandras": ("répandre",),
    "répandrez": ("répandre",),
    "répandriez": ("répandre",),
    "répandrions": ("répandre",),
    "répandrons": ("répandre",),
    "répandront": ("répandre",),
    "répands": ("répandre",),
    "répandue": ("répandre",),
    "répandues": ("répandre",),
    "répandu": ("répandre",),
    "répandus": ("répandre",),
    "repaquetaient": ("repaqueter",),
    "repaquetai": ("repaqueter",),
    "repaquetais": ("repaqueter",),
    "repaquetait": ("repaqueter",),
    "repaqueta": ("repaqueter",),
    "repaquetâmes": ("repaqueter",),
    "repaquetant": ("repaqueter",),
    "repaquetas": ("repaqueter",),
    "repaquetassent": ("repaqueter",),
    "repaquetasses": ("repaqueter",),
    "repaquetasse": ("repaqueter",),
    "repaquetassiez": ("repaqueter",),
    "repaquetassions": ("repaqueter",),
    "repaquetâtes": ("repaqueter",),
    "repaquetât": ("repaqueter",),
    "repaquetée": ("repaqueter",),
    "repaquetées": ("repaqueter",),
    "repaqueté": ("repaqueter",),
    "repaquetèrent": ("repaqueter",),
    "repaquetés": ("repaqueter",),
    "repaquetez": ("repaqueter",),
    "repaquetiez": ("repaqueter",),
    "repaquetions": ("repaqueter",),
    "repaquetons": ("repaqueter",),
    "repaquettent": ("repaqueter",),
    "repaquette": ("repaqueter",),
    "repaquettera": ("repaqueter",),
    "repaquetteraient": ("repaqueter",),
    "repaquetterai": ("repaqueter",),
    "repaquetterais": ("repaqueter",),
    "repaquetterait": ("repaqueter",),
    "repaquetteras": ("repaqueter",),
    "repaquetterez": ("repaqueter",),
    "repaquetteriez": ("repaqueter",),
    "repaquetterions": ("repaqueter",),
    "repaquetterons": ("repaqueter",),
    "repaquetteront": ("repaqueter",),
    "repaquettes": ("repaqueter",),
    "reparais": ("reparaître",),
    "reparaissaient": ("reparaître",),
    "reparaissais": ("reparaître",),
    "reparaissait": ("reparaître",),
    "reparaissant": ("reparaître",),
    "reparaissent": ("reparaître",),
    "reparaisse": ("reparaître",),
    "reparaisses": ("reparaître",),
    "reparaissez": ("reparaître",),
    "reparaissiez": ("reparaître",),
    "reparaissions": ("reparaître",),
    "reparaissons": ("reparaître",),
    "reparaît": ("reparaître",),
    "reparaîtra": ("reparaître",),
    "reparaîtraient": ("reparaître",),
    "reparaîtrai": ("reparaître",),
    "reparaîtrais": ("reparaître",),
    "reparaîtrait": ("reparaître",),
    "reparaîtras": ("reparaître",),
    "reparaîtrez": ("reparaître",),
    "reparaîtriez": ("reparaître",),
    "reparaîtrions": ("reparaître",),
    "reparaîtrons": ("reparaître",),
    "reparaîtront": ("reparaître",),
    "reparue": ("reparaître",),
    "reparues": ("reparaître",),
    "reparu": ("reparaître",),
    "reparûmes": ("reparaître",),
    "reparurent": ("reparaître",),
    "reparus": ("reparaître",),
    "reparussent": ("reparaître",),
    "reparusses": ("reparaître",),
    "reparusse": ("reparaître",),
    "reparussiez": ("reparaître",),
    "reparussions": ("reparaître",),
    "reparûtes": ("reparaître",),
    "reparut": ("reparaître",),
    "reparût": ("reparaître",),
    "reparcouraient": ("reparcourir",),
    "reparcourais": ("reparcourir",),
    "reparcourait": ("reparcourir",),
    "reparcourant": ("reparcourir",),
    "reparcourent": ("reparcourir",),
    "reparcoure": ("reparcourir",),
    "reparcoures": ("reparcourir",),
    "reparcourez": ("reparcourir",),
    "reparcouriez": ("reparcourir",),
    "reparcourions": ("reparcourir",),
    "reparcourons": ("reparcourir",),
    "reparcourra": ("reparcourir",),
    "reparcourraient": ("reparcourir",),
    "reparcourrai": ("reparcourir",),
    "reparcourrais": ("reparcourir",),
    "reparcourrait": ("reparcourir",),
    "reparcourras": ("reparcourir",),
    "reparcourrez": ("reparcourir",),
    "reparcourriez": ("reparcourir",),
    "reparcourrions": ("reparcourir",),
    "reparcourrons": ("reparcourir",),
    "reparcourront": ("reparcourir",),
    "reparcours": ("reparcourir",),
    "reparcourt": ("reparcourir",),
    "reparcourue": ("reparcourir",),
    "reparcourues": ("reparcourir",),
    "reparcouru": ("reparcourir",),
    "reparcourûmes": ("reparcourir",),
    "reparcoururent": ("reparcourir",),
    "reparcourus": ("reparcourir",),
    "reparcourussent": ("reparcourir",),
    "reparcourusses": ("reparcourir",),
    "reparcourusse": ("reparcourir",),
    "reparcourussiez": ("reparcourir",),
    "reparcourussions": ("reparcourir",),
    "reparcourûtes": ("reparcourir",),
    "reparcourut": ("reparcourir",),
    "reparcourût": ("reparcourir",),
    "repariaient": ("reparier",),
    "repariai": ("reparier",),
    "repariais": ("reparier",),
    "repariait": ("reparier",),
    "reparia": ("reparier",),
    "repariâmes": ("reparier",),
    "repariant": ("reparier",),
    "reparias": ("reparier",),
    "repariassent": ("reparier",),
    "repariasses": ("reparier",),
    "repariasse": ("reparier",),
    "repariassiez": ("reparier",),
    "repariassions": ("reparier",),
    "repariâtes": ("reparier",),
    "repariât": ("reparier",),
    "repariée": ("reparier",),
    "repariées": ("reparier",),
    "reparié": ("reparier",),
    "reparient": ("reparier",),
    "reparie": ("reparier",),
    "repariera": ("reparier",),
    "reparieraient": ("reparier",),
    "reparierai": ("reparier",),
    "reparierais": ("reparier",),
    "reparierait": ("reparier",),
    "reparieras": ("reparier",),
    "reparièrent": ("reparier",),
    "reparierez": ("reparier",),
    "reparieriez": ("reparier",),
    "reparierions": ("reparier",),
    "reparierons": ("reparier",),
    "reparieront": ("reparier",),
    "repariés": ("reparier",),
    "reparies": ("reparier",),
    "repariez": ("reparier",),
    "repariiez": ("reparier",),
    "repariions": ("reparier",),
    "reparions": ("reparier",),
    "reparquetaient": ("reparqueter",),
    "reparquetai": ("reparqueter",),
    "reparquetais": ("reparqueter",),
    "reparquetait": ("reparqueter",),
    "reparqueta": ("reparqueter",),
    "reparquetâmes": ("reparqueter",),
    "reparquetant": ("reparqueter",),
    "reparquetas": ("reparqueter",),
    "reparquetassent": ("reparqueter",),
    "reparquetasses": ("reparqueter",),
    "reparquetasse": ("reparqueter",),
    "reparquetassiez": ("reparqueter",),
    "reparquetassions": ("reparqueter",),
    "reparquetâtes": ("reparqueter",),
    "reparquetât": ("reparqueter",),
    "reparquetée": ("reparqueter",),
    "reparquetées": ("reparqueter",),
    "reparqueté": ("reparqueter",),
    "reparquetèrent": ("reparqueter",),
    "reparquetés": ("reparqueter",),
    "reparquetez": ("reparqueter",),
    "reparquetiez": ("reparqueter",),
    "reparquetions": ("reparqueter",),
    "reparquetons": ("reparqueter",),
    "reparquettent": ("reparqueter",),
    "reparquette": ("reparqueter",),
    "reparquettera": ("reparqueter",),
    "reparquetteraient": ("reparqueter",),
    "reparquetterai": ("reparqueter",),
    "reparquetterais": ("reparqueter",),
    "reparquetterait": ("reparqueter",),
    "reparquetteras": ("reparqueter",),
    "reparquetterez": ("reparqueter",),
    "reparquetteriez": ("reparqueter",),
    "reparquetterions": ("reparqueter",),
    "reparquetterons": ("reparqueter",),
    "reparquetteront": ("reparqueter",),
    "reparquettes": ("reparqueter",),
    "repartageaient": ("repartager",),
    "repartageai": ("repartager",),
    "repartageais": ("repartager",),
    "repartageait": ("repartager",),
    "repartagea": ("repartager",),
    "repartageâmes": ("repartager",),
    "repartageant": ("repartager",),
    "repartageas": ("repartager",),
    "repartageassent": ("repartager",),
    "repartageasses": ("repartager",),
    "repartageasse": ("repartager",),
    "repartageassiez": ("repartager",),
    "repartageassions": ("repartager",),
    "repartageâtes": ("repartager",),
    "repartageât": ("repartager",),
    "repartagée": ("repartager",),
    "repartagées": ("repartager",),
    "repartagé": ("repartager",),
    "repartagent": ("repartager",),
    "repartageons": ("repartager",),
    "repartage": ("repartager",),
    "repartagera": ("repartager",),
    "repartageraient": ("repartager",),
    "repartagerai": ("repartager",),
    "repartagerais": ("repartager",),
    "repartagerait": ("repartager",),
    "repartageras": ("repartager",),
    "repartagèrent": ("repartager",),
    "repartagerez": ("repartager",),
    "repartageriez": ("repartager",),
    "repartagerions": ("repartager",),
    "repartagerons": ("repartager",),
    "repartageront": ("repartager",),
    "repartagés": ("repartager",),
    "repartages": ("repartager",),
    "repartagez": ("repartager",),
    "repartagiez": ("repartager",),
    "repartagions": ("repartager",),
    "repars": ("repartir",),
    "repartaient": ("repartir",),
    "repartais": ("repartir",),
    "repartait": ("repartir",),
    "repartant": ("repartir",),
    "repartent": ("repartir",),
    "reparte": ("repartir",),
    "repartes": ("repartir",),
    "repartez": ("repartir",),
    "repartie": ("repartir",),
    "répartie": ("répartir",),
    "reparties": ("repartir",),
    "réparties": ("répartir",),
    "repartiez": ("repartir",),
    "reparti": ("repartir",),
    "réparti": ("répartir",),
    "repartîmes": ("repartir",),
    "répartîmes": ("répartir",),
    "repartions": ("repartir",),
    "repartira": ("repartir",),
    "répartira": ("répartir",),
    "repartiraient": ("repartir",),
    "répartiraient": ("répartir",),
    "repartirai": ("repartir",),
    "répartirai": ("répartir",),
    "repartirais": ("repartir",),
    "répartirais": ("répartir",),
    "repartirait": ("repartir",),
    "répartirait": ("répartir",),
    "repartiras": ("repartir",),
    "répartiras": ("répartir",),
    "repartirent": ("repartir",),
    "répartirent": ("répartir",),
    "repartirez": ("repartir",),
    "répartirez": ("répartir",),
    "repartiriez": ("repartir",),
    "répartiriez": ("répartir",),
    "repartirions": ("repartir",),
    "répartirions": ("répartir",),
    "repartirons": ("repartir",),
    "répartirons": ("répartir",),
    "repartiront": ("repartir",),
    "répartiront": ("répartir",),
    "repartis": ("repartir",),
    "répartis": ("répartir",),
    "répartissaient": ("répartir",),
    "répartissais": ("répartir",),
    "répartissait": ("répartir",),
    "répartissant": ("répartir",),
    "répartissent": ("répartir",),
    "repartissent": ("repartir",),
    "répartisse": ("répartir",),
    "répartisses": ("répartir",),
    "repartisses": ("repartir",),
    "repartisse": ("repartir",),
    "répartissez": ("répartir",),
    "répartissiez": ("répartir",),
    "repartissiez": ("repartir",),
    "répartissions": ("répartir",),
    "repartissions": ("repartir",),
    "répartissons": ("répartir",),
    "repartîtes": ("repartir",),
    "répartîtes": ("répartir",),
    "repartit": ("repartir",),
    "répartit": ("répartir",),
    "repartît": ("repartir",),
    "répartît": ("répartir",),
    "repartons": ("repartir",),
    "repart": ("repartir",),
    "repassaient": ("repasser",),
    "repassai": ("repasser",),
    "repassais": ("repasser",),
    "repassait": ("repasser",),
    "repassa": ("repasser",),
    "repassâmes": ("repasser",),
    "repassant": ("repasser",),
    "repassas": ("repasser",),
    "repassassent": ("repasser",),
    "repassasses": ("repasser",),
    "repassasse": ("repasser",),
    "repassassiez": ("repasser",),
    "repassassions": ("repasser",),
    "repassâtes": ("repasser",),
    "repassât": ("repasser",),
    "repassée": ("repasser",),
    "repassées": ("repasser",),
    "repassé": ("repasser",),
    "repassent": ("repasser",),
    "repasse": ("repasser",),
    "repassera": ("repasser",),
    "repasseraient": ("repasser",),
    "repasserai": ("repasser",),
    "repasserais": ("repasser",),
    "repasserait": ("repasser",),
    "repasseras": ("repasser",),
    "repassèrent": ("repasser",),
    "repasserez": ("repasser",),
    "repasseriez": ("repasser",),
    "repasserions": ("repasser",),
    "repasserons": ("repasser",),
    "repasseront": ("repasser",),
    "repassés": ("repasser",),
    "repasses": ("repasser",),
    "repassez": ("repasser",),
    "repassiez": ("repasser",),
    "repassions": ("repasser",),
    "repassons": ("repasser",),
    "repaient": ("repayer",),
    "repaie": ("repayer",),
    "repaiera": ("repayer",),
    "repaieraient": ("repayer",),
    "repaierai": ("repayer",),
    "repaierais": ("repayer",),
    "repaierait": ("repayer",),
    "repaieras": ("repayer",),
    "repaierez": ("repayer",),
    "repaieriez": ("repayer",),
    "repaierions": ("repayer",),
    "repaierons": ("repayer",),
    "repaieront": ("repayer",),
    "repaies": ("repayer",),
    "repayaient": ("repayer",),
    "repayai": ("repayer",),
    "repayais": ("repayer",),
    "repayait": ("repayer",),
    "repaya": ("repayer",),
    "repayâmes": ("repayer",),
    "repayant": ("repayer",),
    "repayas": ("repayer",),
    "repayassent": ("repayer",),
    "repayasses": ("repayer",),
    "repayasse": ("repayer",),
    "repayassiez": ("repayer",),
    "repayassions": ("repayer",),
    "repayâtes": ("repayer",),
    "repayât": ("repayer",),
    "repayée": ("repayer",),
    "repayées": ("repayer",),
    "repayé": ("repayer",),
    "repayent": ("repayer",),
    "repaye": ("repayer",),
    "repayera": ("repayer",),
    "repayeraient": ("repayer",),
    "repayerai": ("repayer",),
    "repayerais": ("repayer",),
    "repayerait": ("repayer",),
    "repayeras": ("repayer",),
    "repayèrent": ("repayer",),
    "repayerez": ("repayer",),
    "repayeriez": ("repayer",),
    "repayerions": ("repayer",),
    "repayerons": ("repayer",),
    "repayeront": ("repayer",),
    "repayés": ("repayer",),
    "repayes": ("repayer",),
    "repayez": ("repayer",),
    "repayiez": ("repayer",),
    "repayions": ("repayer",),
    "repayons": ("repayer",),
    "repeignaient": ("repeindre",),
    "repeignais": ("repeindre",),
    "repeignait": ("repeindre",),
    "repeignant": ("repeindre",),
    "repeignent": ("repeindre",),
    "repeigne": ("repeindre",),
    "repeignes": ("repeindre",),
    "repeignez": ("repeindre",),
    "repeigniez": ("repeindre",),
    "repeignîmes": ("repeindre",),
    "repeignions": ("repeindre",),
    "repeignirent": ("repeindre",),
    "repeignis": ("repeindre",),
    "repeignissent": ("repeindre",),
    "repeignisses": ("repeindre",),
    "repeignisse": ("repeindre",),
    "repeignissiez": ("repeindre",),
    "repeignissions": ("repeindre",),
    "repeignîtes": ("repeindre",),
    "repeignit": ("repeindre",),
    "repeignît": ("repeindre",),
    "repeignons": ("repeindre",),
    "repeindra": ("repeindre",),
    "repeindraient": ("repeindre",),
    "repeindrai": ("repeindre",),
    "repeindrais": ("repeindre",),
    "repeindrait": ("repeindre",),
    "repeindras": ("repeindre",),
    "repeindrez": ("repeindre",),
    "repeindriez": ("repeindre",),
    "repeindrions": ("repeindre",),
    "repeindrons": ("repeindre",),
    "repeindront": ("repeindre",),
    "repeins": ("repeindre",),
    "repeinte": ("repeindre",),
    "repeintes": ("repeindre",),
    "repeint": ("repeindre",),
    "repeints": ("repeindre",),
    "rependaient": ("rependre",),
    "rependais": ("rependre",),
    "rependait": ("rependre",),
    "rependant": ("rependre",),
    "rependent": ("rependre",),
    "repende": ("rependre",),
    "rependes": ("rependre",),
    "rependez": ("rependre",),
    "rependiez": ("rependre",),
    "rependîmes": ("rependre",),
    "rependions": ("rependre",),
    "rependirent": ("rependre",),
    "rependis": ("rependre",),
    "rependissent": ("rependre",),
    "rependisses": ("rependre",),
    "rependisse": ("rependre",),
    "rependissiez": ("rependre",),
    "rependissions": ("rependre",),
    "rependîtes": ("rependre",),
    "rependit": ("rependre",),
    "rependît": ("rependre",),
    "rependons": ("rependre",),
    "repend": ("rependre",),
    "rependra": ("rependre",),
    "rependraient": ("rependre",),
    "rependrai": ("rependre",),
    "rependrais": ("rependre",),
    "rependrait": ("rependre",),
    "rependras": ("rependre",),
    "rependrez": ("rependre",),
    "rependriez": ("rependre",),
    "rependrions": ("rependre",),
    "rependrons": ("rependre",),
    "rependront": ("rependre",),
    "repends": ("rependre",),
    "rependue": ("rependre",),
    "rependues": ("rependre",),
    "rependu": ("rependre",),
    "rependus": ("rependre",),
    "repénétraient": ("repénétrer",),
    "repénétrai": ("repénétrer",),
    "repénétrais": ("repénétrer",),
    "repénétrait": ("repénétrer",),
    "repénétra": ("repénétrer",),
    "repénétrâmes": ("repénétrer",),
    "repénétrant": ("repénétrer",),
    "repénétras": ("repénétrer",),
    "repénétrassent": ("repénétrer",),
    "repénétrasses": ("repénétrer",),
    "repénétrasse": ("repénétrer",),
    "repénétrassiez": ("repénétrer",),
    "repénétrassions": ("repénétrer",),
    "repénétrâtes": ("repénétrer",),
    "repénétrât": ("repénétrer",),
    "repénétrée": ("repénétrer",),
    "repénétrées": ("repénétrer",),
    "repénétré": ("repénétrer",),
    "repénètrent": ("repénétrer",),
    "repénètre": ("repénétrer",),
    "repénétrera": ("repénétrer",),
    "repénétreraient": ("repénétrer",),
    "repénétrerai": ("repénétrer",),
    "repénétrerais": ("repénétrer",),
    "repénétrerait": ("repénétrer",),
    "repénétreras": ("repénétrer",),
    "repénétrèrent": ("repénétrer",),
    "repénétrerez": ("repénétrer",),
    "repénétreriez": ("repénétrer",),
    "repénétrerions": ("repénétrer",),
    "repénétrerons": ("repénétrer",),
    "repénétreront": ("repénétrer",),
    "repénétrés": ("repénétrer",),
    "repénètres": ("repénétrer",),
    "repénétrez": ("repénétrer",),
    "repénétriez": ("repénétrer",),
    "repénétrions": ("repénétrer",),
    "repénétrons": ("repénétrer",),
    "repens": ("repentir",),
    "repentaient": ("repentir",),
    "repentais": ("repentir",),
    "repentait": ("repentir",),
    "repentant": ("repentir",),
    "repentent": ("repentir",),
    "repente": ("repentir",),
    "repentes": ("repentir",),
    "repentez": ("repentir",),
    "repentie": ("repentir",),
    "repenties": ("repentir",),
    "repentiez": ("repentir",),
    "repenti": ("repentir",),
    "repentîmes": ("repentir",),
    "repentions": ("repentir",),
    "repentira": ("repentir",),
    "repentiraient": ("repentir",),
    "repentirai": ("repentir",),
    "repentirais": ("repentir",),
    "repentirait": ("repentir",),
    "repentiras": ("repentir",),
    "repentirent": ("repentir",),
    "repentirez": ("repentir",),
    "repentiriez": ("repentir",),
    "repentirions": ("repentir",),
    "repentirons": ("repentir",),
    "repentiront": ("repentir",),
    "repentis": ("repentir",),
    "repentissent": ("repentir",),
    "repentisses": ("repentir",),
    "repentisse": ("repentir",),
    "repentissiez": ("repentir",),
    "repentissions": ("repentir",),
    "repentîtes": ("repentir",),
    "repentit": ("repentir",),
    "repentît": ("repentir",),
    "repentons": ("repentir",),
    "repent": ("repentir",),
    "reperçaient": ("repercer",),
    "reperçai": ("repercer",),
    "reperçais": ("repercer",),
    "reperçait": ("repercer",),
    "reperça": ("repercer",),
    "reperçâmes": ("repercer",),
    "reperçant": ("repercer",),
    "reperças": ("repercer",),
    "reperçassent": ("repercer",),
    "reperçasses": ("repercer",),
    "reperçasse": ("repercer",),
    "reperçassiez": ("repercer",),
    "reperçassions": ("repercer",),
    "reperçâtes": ("repercer",),
    "reperçât": ("repercer",),
    "repercée": ("repercer",),
    "repercées": ("repercer",),
    "repercé": ("repercer",),
    "repercent": ("repercer",),
    "reperce": ("repercer",),
    "repercera": ("repercer",),
    "reperceraient": ("repercer",),
    "repercerai": ("repercer",),
    "repercerais": ("repercer",),
    "repercerait": ("repercer",),
    "reperceras": ("repercer",),
    "repercèrent": ("repercer",),
    "repercerez": ("repercer",),
    "reperceriez": ("repercer",),
    "repercerions": ("repercer",),
    "repercerons": ("repercer",),
    "reperceront": ("repercer",),
    "repercés": ("repercer",),
    "reperces": ("repercer",),
    "repercez": ("repercer",),
    "reperciez": ("repercer",),
    "repercions": ("repercer",),
    "reperçons": ("repercer",),
    "repercevaient": ("repercevoir",),
    "repercevais": ("repercevoir",),
    "repercevait": ("repercevoir",),
    "repercevant": ("repercevoir",),
    "repercevez": ("repercevoir",),
    "reperceviez": ("repercevoir",),
    "repercevions": ("repercevoir",),
    "repercevons": ("repercevoir",),
    "repercevra": ("repercevoir",),
    "repercevraient": ("repercevoir",),
    "repercevrai": ("repercevoir",),
    "repercevrais": ("repercevoir",),
    "repercevrait": ("repercevoir",),
    "repercevras": ("repercevoir",),
    "repercevrez": ("repercevoir",),
    "repercevriez": ("repercevoir",),
    "repercevrions": ("repercevoir",),
    "repercevrons": ("repercevoir",),
    "repercevront": ("repercevoir",),
    "reperçois": ("repercevoir",),
    "reperçoit": ("repercevoir",),
    "reperçoivent": ("repercevoir",),
    "reperçoive": ("repercevoir",),
    "reperçoives": ("repercevoir",),
    "reperçue": ("repercevoir",),
    "reperçues": ("repercevoir",),
    "reperçu": ("repercevoir",),
    "reperçûmes": ("repercevoir",),
    "reperçurent": ("repercevoir",),
    "reperçus": ("repercevoir",),
    "reperçussent": ("repercevoir",),
    "reperçusses": ("repercevoir",),
    "reperçusse": ("repercevoir",),
    "reperçussiez": ("repercevoir",),
    "reperçussions": ("repercevoir",),
    "reperçûtes": ("repercevoir",),
    "reperçut": ("repercevoir",),
    "reperçût": ("repercevoir",),
    "reperdaient": ("reperdre",),
    "reperdais": ("reperdre",),
    "reperdait": ("reperdre",),
    "reperdant": ("reperdre",),
    "reperdent": ("reperdre",),
    "reperde": ("reperdre",),
    "reperdes": ("reperdre",),
    "reperdez": ("reperdre",),
    "reperdiez": ("reperdre",),
    "reperdîmes": ("reperdre",),
    "reperdions": ("reperdre",),
    "reperdirent": ("reperdre",),
    "reperdis": ("reperdre",),
    "reperdissent": ("reperdre",),
    "reperdisses": ("reperdre",),
    "reperdisse": ("reperdre",),
    "reperdissiez": ("reperdre",),
    "reperdissions": ("reperdre",),
    "reperdîtes": ("reperdre",),
    "reperdit": ("reperdre",),
    "reperdît": ("reperdre",),
    "reperdons": ("reperdre",),
    "reperd": ("reperdre",),
    "reperdra": ("reperdre",),
    "reperdraient": ("reperdre",),
    "reperdrai": ("reperdre",),
    "reperdrais": ("reperdre",),
    "reperdrait": ("reperdre",),
    "reperdras": ("reperdre",),
    "reperdrez": ("reperdre",),
    "reperdriez": ("reperdre",),
    "reperdrions": ("reperdre",),
    "reperdrons": ("reperdre",),
    "reperdront": ("reperdre",),
    "reperds": ("reperdre",),
    "reperdue": ("reperdre",),
    "reperdues": ("reperdre",),
    "reperdu": ("reperdre",),
    "reperdus": ("reperdre",),
    "repéraient": ("repérer",),
    "repérai": ("repérer",),
    "repérais": ("repérer",),
    "repérait": ("repérer",),
    "repéra": ("repérer",),
    "repérâmes": ("repérer",),
    "repérant": ("repérer",),
    "repéras": ("repérer",),
    "repérassent": ("repérer",),
    "repérasses": ("repérer",),
    "repérasse": ("repérer",),
    "repérassiez": ("repérer",),
    "repérassions": ("repérer",),
    "repérâtes": ("repérer",),
    "repérât": ("repérer",),
    "repérée": ("repérer",),
    "repérées": ("repérer",),
    "repéré": ("repérer",),
    "repèrent": ("repérer",),
    "repère": ("repérer",),
    "repérera": ("repérer",),
    "repéreraient": ("repérer",),
    "repérerai": ("repérer",),
    "repérerais": ("repérer",),
    "repérerait": ("repérer",),
    "repéreras": ("repérer",),
    "repérèrent": ("repérer",),
    "repérerez": ("repérer",),
    "repéreriez": ("repérer",),
    "repérerions": ("repérer",),
    "repérerons": ("repérer",),
    "repéreront": ("repérer",),
    "repérés": ("repérer",),
    "repères": ("repérer",),
    "repérez": ("repérer",),
    "repériez": ("repérer",),
    "repérions": ("repérer",),
    "repérons": ("repérer",),
    "répertoriaient": ("répertorier",),
    "répertoriai": ("répertorier",),
    "répertoriais": ("répertorier",),
    "répertoriait": ("répertorier",),
    "répertoria": ("répertorier",),
    "répertoriâmes": ("répertorier",),
    "répertoriant": ("répertorier",),
    "répertorias": ("répertorier",),
    "répertoriassent": ("répertorier",),
    "répertoriasses": ("répertorier",),
    "répertoriasse": ("répertorier",),
    "répertoriassiez": ("répertorier",),
    "répertoriassions": ("répertorier",),
    "répertoriâtes": ("répertorier",),
    "répertoriât": ("répertorier",),
    "répertoriée": ("répertorier",),
    "répertoriées": ("répertorier",),
    "répertorié": ("répertorier",),
    "répertorient": ("répertorier",),
    "répertorie": ("répertorier",),
    "répertoriera": ("répertorier",),
    "répertorieraient": ("répertorier",),
    "répertorierai": ("répertorier",),
    "répertorierais": ("répertorier",),
    "répertorierait": ("répertorier",),
    "répertorieras": ("répertorier",),
    "répertorièrent": ("répertorier",),
    "répertorierez": ("répertorier",),
    "répertorieriez": ("répertorier",),
    "répertorierions": ("répertorier",),
    "répertorierons": ("répertorier",),
    "répertorieront": ("répertorier",),
    "répertoriés": ("répertorier",),
    "répertories": ("répertorier",),
    "répertoriez": ("répertorier",),
    "répertoriiez": ("répertorier",),
    "répertoriions": ("répertorier",),
    "répertorions": ("répertorier",),
    "repesaient": ("repeser",),
    "repesai": ("repeser",),
    "repesais": ("repeser",),
    "repesait": ("repeser",),
    "repesa": ("repeser",),
    "repesâmes": ("repeser",),
    "repesant": ("repeser",),
    "repesas": ("repeser",),
    "repesassent": ("repeser",),
    "repesasses": ("repeser",),
    "repesasse": ("repeser",),
    "repesassiez": ("repeser",),
    "repesassions": ("repeser",),
    "repesâtes": ("repeser",),
    "repesât": ("repeser",),
    "repesée": ("repeser",),
    "repesées": ("repeser",),
    "repesé": ("repeser",),
    "repèsent": ("repeser",),
    "repèse": ("repeser",),
    "repèsera": ("repeser",),
    "repèseraient": ("repeser",),
    "repèserai": ("repeser",),
    "repèserais": ("repeser",),
    "repèserait": ("repeser",),
    "repèseras": ("repeser",),
    "repesèrent": ("repeser",),
    "repèserez": ("repeser",),
    "repèseriez": ("repeser",),
    "repèserions": ("repeser",),
    "repèserons": ("repeser",),
    "repèseront": ("repeser",),
    "repesés": ("repeser",),
    "repèses": ("repeser",),
    "repesez": ("repeser",),
    "repesiez": ("repeser",),
    "repesions": ("repeser",),
    "repesons": ("repeser",),
    "repétrie": ("repétrir",),
    "repétries": ("repétrir",),
    "repétri": ("repétrir",),
    "repétrîmes": ("repétrir",),
    "repétrira": ("repétrir",),
    "repétriraient": ("repétrir",),
    "repétrirai": ("repétrir",),
    "repétrirais": ("repétrir",),
    "repétrirait": ("repétrir",),
    "repétriras": ("repétrir",),
    "repétrirent": ("repétrir",),
    "repétrirez": ("repétrir",),
    "repétririez": ("repétrir",),
    "repétririons": ("repétrir",),
    "repétrirons": ("repétrir",),
    "repétriront": ("repétrir",),
    "repétris": ("repétrir",),
    "repétrissaient": ("repétrir",),
    "repétrissais": ("repétrir",),
    "repétrissait": ("repétrir",),
    "repétrissant": ("repétrir",),
    "repétrissent": ("repétrir",),
    "repétrisse": ("repétrir",),
    "repétrisses": ("repétrir",),
    "repétrissez": ("repétrir",),
    "repétrissiez": ("repétrir",),
    "repétrissions": ("repétrir",),
    "repétrissons": ("repétrir",),
    "repétrîtes": ("repétrir",),
    "repétrit": ("repétrir",),
    "repétrît": ("repétrir",),
    "rephotocopiaient": ("rephotocopier",),
    "rephotocopiai": ("rephotocopier",),
    "rephotocopiais": ("rephotocopier",),
    "rephotocopiait": ("rephotocopier",),
    "rephotocopia": ("rephotocopier",),
    "rephotocopiâmes": ("rephotocopier",),
    "rephotocopiant": ("rephotocopier",),
    "rephotocopias": ("rephotocopier",),
    "rephotocopiassent": ("rephotocopier",),
    "rephotocopiasses": ("rephotocopier",),
    "rephotocopiasse": ("rephotocopier",),
    "rephotocopiassiez": ("rephotocopier",),
    "rephotocopiassions": ("rephotocopier",),
    "rephotocopiâtes": ("rephotocopier",),
    "rephotocopiât": ("rephotocopier",),
    "rephotocopiée": ("rephotocopier",),
    "rephotocopiées": ("rephotocopier",),
    "rephotocopié": ("rephotocopier",),
    "rephotocopient": ("rephotocopier",),
    "rephotocopie": ("rephotocopier",),
    "rephotocopiera": ("rephotocopier",),
    "rephotocopieraient": ("rephotocopier",),
    "rephotocopierai": ("rephotocopier",),
    "rephotocopierais": ("rephotocopier",),
    "rephotocopierait": ("rephotocopier",),
    "rephotocopieras": ("rephotocopier",),
    "rephotocopièrent": ("rephotocopier",),
    "rephotocopierez": ("rephotocopier",),
    "rephotocopieriez": ("rephotocopier",),
    "rephotocopierions": ("rephotocopier",),
    "rephotocopierons": ("rephotocopier",),
    "rephotocopieront": ("rephotocopier",),
    "rephotocopiés": ("rephotocopier",),
    "rephotocopies": ("rephotocopier",),
    "rephotocopiez": ("rephotocopier",),
    "rephotocopiiez": ("rephotocopier",),
    "rephotocopiions": ("rephotocopier",),
    "rephotocopions": ("rephotocopier",),
    "rephotographiaient": ("rephotographier",),
    "rephotographiai": ("rephotographier",),
    "rephotographiais": ("rephotographier",),
    "rephotographiait": ("rephotographier",),
    "rephotographia": ("rephotographier",),
    "rephotographiâmes": ("rephotographier",),
    "rephotographiant": ("rephotographier",),
    "rephotographias": ("rephotographier",),
    "rephotographiassent": ("rephotographier",),
    "rephotographiasses": ("rephotographier",),
    "rephotographiasse": ("rephotographier",),
    "rephotographiassiez": ("rephotographier",),
    "rephotographiassions": ("rephotographier",),
    "rephotographiâtes": ("rephotographier",),
    "rephotographiât": ("rephotographier",),
    "rephotographiée": ("rephotographier",),
    "rephotographiées": ("rephotographier",),
    "rephotographié": ("rephotographier",),
    "rephotographient": ("rephotographier",),
    "rephotographie": ("rephotographier",),
    "rephotographiera": ("rephotographier",),
    "rephotographieraient": ("rephotographier",),
    "rephotographierai": ("rephotographier",),
    "rephotographierais": ("rephotographier",),
    "rephotographierait": ("rephotographier",),
    "rephotographieras": ("rephotographier",),
    "rephotographièrent": ("rephotographier",),
    "rephotographierez": ("rephotographier",),
    "rephotographieriez": ("rephotographier",),
    "rephotographierions": ("rephotographier",),
    "rephotographierons": ("rephotographier",),
    "rephotographieront": ("rephotographier",),
    "rephotographiés": ("rephotographier",),
    "rephotographies": ("rephotographier",),
    "rephotographiez": ("rephotographier",),
    "rephotographiiez": ("rephotographier",),
    "rephotographiions": ("rephotographier",),
    "rephotographions": ("rephotographier",),
    "repiégeaient": ("repiéger",),
    "repiégeai": ("repiéger",),
    "repiégeais": ("repiéger",),
    "repiégeait": ("repiéger",),
    "repiégea": ("repiéger",),
    "repiégeâmes": ("repiéger",),
    "repiégeant": ("repiéger",),
    "repiégeas": ("repiéger",),
    "repiégeassent": ("repiéger",),
    "repiégeasses": ("repiéger",),
    "repiégeasse": ("repiéger",),
    "repiégeassiez": ("repiéger",),
    "repiégeassions": ("repiéger",),
    "repiégeâtes": ("repiéger",),
    "repiégeât": ("repiéger",),
    "repiégée": ("repiéger",),
    "repiégées": ("repiéger",),
    "repiégé": ("repiéger",),
    "repiègent": ("repiéger",),
    "repiégeons": ("repiéger",),
    "repiège": ("repiéger",),
    "repiégera": ("repiéger",),
    "repiégeraient": ("repiéger",),
    "repiégerai": ("repiéger",),
    "repiégerais": ("repiéger",),
    "repiégerait": ("repiéger",),
    "repiégeras": ("repiéger",),
    "repiégèrent": ("repiéger",),
    "repiégerez": ("repiéger",),
    "repiégeriez": ("repiéger",),
    "repiégerions": ("repiéger",),
    "repiégerons": ("repiéger",),
    "repiégeront": ("repiéger",),
    "repiégés": ("repiéger",),
    "repièges": ("repiéger",),
    "repiégez": ("repiéger",),
    "repiégiez": ("repiéger",),
    "repiégions": ("repiéger",),
    "repinçaient": ("repincer",),
    "repinçai": ("repincer",),
    "repinçais": ("repincer",),
    "repinçait": ("repincer",),
    "repinça": ("repincer",),
    "repinçâmes": ("repincer",),
    "repinçant": ("repincer",),
    "repinças": ("repincer",),
    "repinçassent": ("repincer",),
    "repinçasses": ("repincer",),
    "repinçasse": ("repincer",),
    "repinçassiez": ("repincer",),
    "repinçassions": ("repincer",),
    "repinçâtes": ("repincer",),
    "repinçât": ("repincer",),
    "repincée": ("repincer",),
    "repincées": ("repincer",),
    "repincé": ("repincer",),
    "repincent": ("repincer",),
    "repince": ("repincer",),
    "repincera": ("repincer",),
    "repinceraient": ("repincer",),
    "repincerai": ("repincer",),
    "repincerais": ("repincer",),
    "repincerait": ("repincer",),
    "repinceras": ("repincer",),
    "repincèrent": ("repincer",),
    "repincerez": ("repincer",),
    "repinceriez": ("repincer",),
    "repincerions": ("repincer",),
    "repincerons": ("repincer",),
    "repinceront": ("repincer",),
    "repincés": ("repincer",),
    "repinces": ("repincer",),
    "repincez": ("repincer",),
    "repinciez": ("repincer",),
    "repincions": ("repincer",),
    "repinçons": ("repincer",),
    "repionçaient": ("repioncer",),
    "repionçai": ("repioncer",),
    "repionçais": ("repioncer",),
    "repionçait": ("repioncer",),
    "repionça": ("repioncer",),
    "repionçâmes": ("repioncer",),
    "repionçant": ("repioncer",),
    "repionças": ("repioncer",),
    "repionçassent": ("repioncer",),
    "repionçasses": ("repioncer",),
    "repionçasse": ("repioncer",),
    "repionçassiez": ("repioncer",),
    "repionçassions": ("repioncer",),
    "repionçâtes": ("repioncer",),
    "repionçât": ("repioncer",),
    "repioncé": ("repioncer",),
    "repioncent": ("repioncer",),
    "repionce": ("repioncer",),
    "repioncera": ("repioncer",),
    "repionceraient": ("repioncer",),
    "repioncerai": ("repioncer",),
    "repioncerais": ("repioncer",),
    "repioncerait": ("repioncer",),
    "repionceras": ("repioncer",),
    "repioncèrent": ("repioncer",),
    "repioncerez": ("repioncer",),
    "repionceriez": ("repioncer",),
    "repioncerions": ("repioncer",),
    "repioncerons": ("repioncer",),
    "repionceront": ("repioncer",),
    "repionces": ("repioncer",),
    "repioncez": ("repioncer",),
    "repionciez": ("repioncer",),
    "repioncions": ("repioncer",),
    "repionçons": ("repioncer",),
    "replaçaient": ("replacer",),
    "replaçai": ("replacer",),
    "replaçais": ("replacer",),
    "replaçait": ("replacer",),
    "replaça": ("replacer",),
    "replaçâmes": ("replacer",),
    "replaçant": ("replacer",),
    "replaças": ("replacer",),
    "replaçassent": ("replacer",),
    "replaçasses": ("replacer",),
    "replaçasse": ("replacer",),
    "replaçassiez": ("replacer",),
    "replaçassions": ("replacer",),
    "replaçâtes": ("replacer",),
    "replaçât": ("replacer",),
    "replacée": ("replacer",),
    "replacées": ("replacer",),
    "replacé": ("replacer",),
    "replacent": ("replacer",),
    "replace": ("replacer",),
    "replacera": ("replacer",),
    "replaceraient": ("replacer",),
    "replacerai": ("replacer",),
    "replacerais": ("replacer",),
    "replacerait": ("replacer",),
    "replaceras": ("replacer",),
    "replacèrent": ("replacer",),
    "replacerez": ("replacer",),
    "replaceriez": ("replacer",),
    "replacerions": ("replacer",),
    "replacerons": ("replacer",),
    "replaceront": ("replacer",),
    "replacés": ("replacer",),
    "replaces": ("replacer",),
    "replacez": ("replacer",),
    "replaciez": ("replacer",),
    "replacions": ("replacer",),
    "replaçons": ("replacer",),
    "replanifiaient": ("replanifier",),
    "replanifiai": ("replanifier",),
    "replanifiais": ("replanifier",),
    "replanifiait": ("replanifier",),
    "replanifia": ("replanifier",),
    "replanifiâmes": ("replanifier",),
    "replanifiant": ("replanifier",),
    "replanifias": ("replanifier",),
    "replanifiassent": ("replanifier",),
    "replanifiasses": ("replanifier",),
    "replanifiasse": ("replanifier",),
    "replanifiassiez": ("replanifier",),
    "replanifiassions": ("replanifier",),
    "replanifiâtes": ("replanifier",),
    "replanifiât": ("replanifier",),
    "replanifiée": ("replanifier",),
    "replanifiées": ("replanifier",),
    "replanifié": ("replanifier",),
    "replanifient": ("replanifier",),
    "replanifie": ("replanifier",),
    "replanifiera": ("replanifier",),
    "replanifieraient": ("replanifier",),
    "replanifierai": ("replanifier",),
    "replanifierais": ("replanifier",),
    "replanifierait": ("replanifier",),
    "replanifieras": ("replanifier",),
    "replanifièrent": ("replanifier",),
    "replanifierez": ("replanifier",),
    "replanifieriez": ("replanifier",),
    "replanifierions": ("replanifier",),
    "replanifierons": ("replanifier",),
    "replanifieront": ("replanifier",),
    "replanifiés": ("replanifier",),
    "replanifies": ("replanifier",),
    "replanifiez": ("replanifier",),
    "replanifiiez": ("replanifier",),
    "replanifiions": ("replanifier",),
    "replanifions": ("replanifier",),
    "replanie": ("replanir",),
    "replanies": ("replanir",),
    "replani": ("replanir",),
    "replanîmes": ("replanir",),
    "replanira": ("replanir",),
    "replaniraient": ("replanir",),
    "replanirai": ("replanir",),
    "replanirais": ("replanir",),
    "replanirait": ("replanir",),
    "replaniras": ("replanir",),
    "replanirent": ("replanir",),
    "replanirez": ("replanir",),
    "replaniriez": ("replanir",),
    "replanirions": ("replanir",),
    "replanirons": ("replanir",),
    "replaniront": ("replanir",),
    "replanis": ("replanir",),
    "replanissaient": ("replanir",),
    "replanissais": ("replanir",),
    "replanissait": ("replanir",),
    "replanissant": ("replanir",),
    "replanissent": ("replanir",),
    "replanisse": ("replanir",),
    "replanisses": ("replanir",),
    "replanissez": ("replanir",),
    "replanissiez": ("replanir",),
    "replanissions": ("replanir",),
    "replanissons": ("replanir",),
    "replanîtes": ("replanir",),
    "replanit": ("replanir",),
    "replanît": ("replanir",),
    "replastifiaient": ("replastifier",),
    "replastifiai": ("replastifier",),
    "replastifiais": ("replastifier",),
    "replastifiait": ("replastifier",),
    "replastifia": ("replastifier",),
    "replastifiâmes": ("replastifier",),
    "replastifiant": ("replastifier",),
    "replastifias": ("replastifier",),
    "replastifiassent": ("replastifier",),
    "replastifiasses": ("replastifier",),
    "replastifiasse": ("replastifier",),
    "replastifiassiez": ("replastifier",),
    "replastifiassions": ("replastifier",),
    "replastifiâtes": ("replastifier",),
    "replastifiât": ("replastifier",),
    "replastifiée": ("replastifier",),
    "replastifiées": ("replastifier",),
    "replastifié": ("replastifier",),
    "replastifient": ("replastifier",),
    "replastifie": ("replastifier",),
    "replastifiera": ("replastifier",),
    "replastifieraient": ("replastifier",),
    "replastifierai": ("replastifier",),
    "replastifierais": ("replastifier",),
    "replastifierait": ("replastifier",),
    "replastifieras": ("replastifier",),
    "replastifièrent": ("replastifier",),
    "replastifierez": ("replastifier",),
    "replastifieriez": ("replastifier",),
    "replastifierions": ("replastifier",),
    "replastifierons": ("replastifier",),
    "replastifieront": ("replastifier",),
    "replastifiés": ("replastifier",),
    "replastifies": ("replastifier",),
    "replastifiez": ("replastifier",),
    "replastifiiez": ("replastifier",),
    "replastifiions": ("replastifier",),
    "replastifions": ("replastifier",),
    "repleut": ("repleuvoir",),
    "repleuvaient": ("repleuvoir",),
    "repleuvait": ("repleuvoir",),
    "repleuvant": ("repleuvoir",),
    "repleuvent": ("repleuvoir",),
    "repleuve": ("repleuvoir",),
    "repleuvra": ("repleuvoir",),
    "repleuvraient": ("repleuvoir",),
    "repleuvrait": ("repleuvoir",),
    "repleuvront": ("repleuvoir",),
    "replu": ("repleuvoir",),
    "replurent": ("repleuvoir",),
    "replussent": ("repleuvoir",),
    "replut": ("repleuvoir",),
    "replût": ("repleuvoir",),
    "repliaient": ("replier",),
    "repliai": ("replier",),
    "repliais": ("replier",),
    "repliait": ("replier",),
    "replia": ("replier",),
    "repliâmes": ("replier",),
    "repliant": ("replier",),
    "replias": ("replier",),
    "repliassent": ("replier",),
    "repliasses": ("replier",),
    "repliasse": ("replier",),
    "repliassiez": ("replier",),
    "repliassions": ("replier",),
    "repliâtes": ("replier",),
    "repliât": ("replier",),
    "repliée": ("replier",),
    "repliées": ("replier",),
    "replié": ("replier",),
    "replient": ("replier",),
    "replie": ("replier",),
    "repliera": ("replier",),
    "replieraient": ("replier",),
    "replierai": ("replier",),
    "replierais": ("replier",),
    "replierait": ("replier",),
    "replieras": ("replier",),
    "replièrent": ("replier",),
    "replierez": ("replier",),
    "replieriez": ("replier",),
    "replierions": ("replier",),
    "replierons": ("replier",),
    "replieront": ("replier",),
    "repliés": ("replier",),
    "replies": ("replier",),
    "repliez": ("replier",),
    "repliiez": ("replier",),
    "repliions": ("replier",),
    "replions": ("replier",),
    "replongeaient": ("replonger",),
    "replongeai": ("replonger",),
    "replongeais": ("replonger",),
    "replongeait": ("replonger",),
    "replongea": ("replonger",),
    "replongeâmes": ("replonger",),
    "replongeant": ("replonger",),
    "replongeas": ("replonger",),
    "replongeassent": ("replonger",),
    "replongeasses": ("replonger",),
    "replongeasse": ("replonger",),
    "replongeassiez": ("replonger",),
    "replongeassions": ("replonger",),
    "replongeâtes": ("replonger",),
    "replongeât": ("replonger",),
    "replongée": ("replonger",),
    "replongées": ("replonger",),
    "replongé": ("replonger",),
    "replongent": ("replonger",),
    "replongeons": ("replonger",),
    "replonge": ("replonger",),
    "replongera": ("replonger",),
    "replongeraient": ("replonger",),
    "replongerai": ("replonger",),
    "replongerais": ("replonger",),
    "replongerait": ("replonger",),
    "replongeras": ("replonger",),
    "replongèrent": ("replonger",),
    "replongerez": ("replonger",),
    "replongeriez": ("replonger",),
    "replongerions": ("replonger",),
    "replongerons": ("replonger",),
    "replongeront": ("replonger",),
    "replongés": ("replonger",),
    "replonges": ("replonger",),
    "replongez": ("replonger",),
    "replongiez": ("replonger",),
    "replongions": ("replonger",),
    "reploient": ("reployer",),
    "reploie": ("reployer",),
    "reploiera": ("reployer",),
    "reploieraient": ("reployer",),
    "reploierai": ("reployer",),
    "reploierais": ("reployer",),
    "reploierait": ("reployer",),
    "reploieras": ("reployer",),
    "reploierez": ("reployer",),
    "reploieriez": ("reployer",),
    "reploierions": ("reployer",),
    "reploierons": ("reployer",),
    "reploieront": ("reployer",),
    "reploies": ("reployer",),
    "reployaient": ("reployer",),
    "reployai": ("reployer",),
    "reployais": ("reployer",),
    "reployait": ("reployer",),
    "reploya": ("reployer",),
    "reployâmes": ("reployer",),
    "reployant": ("reployer",),
    "reployas": ("reployer",),
    "reployassent": ("reployer",),
    "reployasses": ("reployer",),
    "reployasse": ("reployer",),
    "reployassiez": ("reployer",),
    "reployassions": ("reployer",),
    "reployâtes": ("reployer",),
    "reployât": ("reployer",),
    "reployée": ("reployer",),
    "reployées": ("reployer",),
    "reployé": ("reployer",),
    "reployèrent": ("reployer",),
    "reployés": ("reployer",),
    "reployez": ("reployer",),
    "reployiez": ("reployer",),
    "reployions": ("reployer",),
    "reployons": ("reployer",),
    "repoliçaient": ("repolicer",),
    "repoliçai": ("repolicer",),
    "repoliçais": ("repolicer",),
    "repoliçait": ("repolicer",),
    "repoliça": ("repolicer",),
    "repoliçâmes": ("repolicer",),
    "repoliçant": ("repolicer",),
    "repoliças": ("repolicer",),
    "repoliçassent": ("repolicer",),
    "repoliçasses": ("repolicer",),
    "repoliçasse": ("repolicer",),
    "repoliçassiez": ("repolicer",),
    "repoliçassions": ("repolicer",),
    "repoliçâtes": ("repolicer",),
    "repoliçât": ("repolicer",),
    "repolicée": ("repolicer",),
    "repolicées": ("repolicer",),
    "repolicé": ("repolicer",),
    "repolicent": ("repolicer",),
    "repolice": ("repolicer",),
    "repolicera": ("repolicer",),
    "repoliceraient": ("repolicer",),
    "repolicerai": ("repolicer",),
    "repolicerais": ("repolicer",),
    "repolicerait": ("repolicer",),
    "repoliceras": ("repolicer",),
    "repolicèrent": ("repolicer",),
    "repolicerez": ("repolicer",),
    "repoliceriez": ("repolicer",),
    "repolicerions": ("repolicer",),
    "repolicerons": ("repolicer",),
    "repoliceront": ("repolicer",),
    "repolicés": ("repolicer",),
    "repolices": ("repolicer",),
    "repolicez": ("repolicer",),
    "repoliciez": ("repolicer",),
    "repolicions": ("repolicer",),
    "repoliçons": ("repolicer",),
    "repolie": ("repolir",),
    "repolies": ("repolir",),
    "repoli": ("repolir",),
    "repolîmes": ("repolir",),
    "repolira": ("repolir",),
    "repoliraient": ("repolir",),
    "repolirai": ("repolir",),
    "repolirais": ("repolir",),
    "repolirait": ("repolir",),
    "repoliras": ("repolir",),
    "repolirent": ("repolir",),
    "repolirez": ("repolir",),
    "repoliriez": ("repolir",),
    "repolirions": ("repolir",),
    "repolirons": ("repolir",),
    "repoliront": ("repolir",),
    "repolis": ("repolir",),
    "repolissaient": ("repolir",),
    "repolissais": ("repolir",),
    "repolissait": ("repolir",),
    "repolissant": ("repolir",),
    "repolissent": ("repolir",),
    "repolisse": ("repolir",),
    "repolisses": ("repolir",),
    "repolissez": ("repolir",),
    "repolissiez": ("repolir",),
    "repolissions": ("repolir",),
    "repolissons": ("repolir",),
    "repolîtes": ("repolir",),
    "repolit": ("repolir",),
    "repolît": ("repolir",),
    "reponçaient": ("reponcer",),
    "reponçai": ("reponcer",),
    "reponçais": ("reponcer",),
    "reponçait": ("reponcer",),
    "reponça": ("reponcer",),
    "reponçâmes": ("reponcer",),
    "reponçant": ("reponcer",),
    "reponças": ("reponcer",),
    "reponçassent": ("reponcer",),
    "reponçasses": ("reponcer",),
    "reponçasse": ("reponcer",),
    "reponçassiez": ("reponcer",),
    "reponçassions": ("reponcer",),
    "reponçâtes": ("reponcer",),
    "reponçât": ("reponcer",),
    "reponcée": ("reponcer",),
    "reponcées": ("reponcer",),
    "reponcé": ("reponcer",),
    "reponcent": ("reponcer",),
    "reponce": ("reponcer",),
    "reponcera": ("reponcer",),
    "reponceraient": ("reponcer",),
    "reponcerai": ("reponcer",),
    "reponcerais": ("reponcer",),
    "reponcerait": ("reponcer",),
    "reponceras": ("reponcer",),
    "reponcèrent": ("reponcer",),
    "reponcerez": ("reponcer",),
    "reponceriez": ("reponcer",),
    "reponcerions": ("reponcer",),
    "reponcerons": ("reponcer",),
    "reponceront": ("reponcer",),
    "reponcés": ("reponcer",),
    "reponces": ("reponcer",),
    "reponcez": ("reponcer",),
    "reponciez": ("reponcer",),
    "reponcions": ("reponcer",),
    "reponçons": ("reponcer",),
    "répondaient": ("répondre",),
    "répondais": ("répondre",),
    "répondait": ("répondre",),
    "répondant": ("répondre",),
    "répondent": ("répondre",),
    "réponde": ("répondre",),
    "répondes": ("répondre",),
    "répondez": ("répondre",),
    "répondiez": ("répondre",),
    "répondîmes": ("répondre",),
    "répondions": ("répondre",),
    "répondirent": ("répondre",),
    "répondis": ("répondre",),
    "répondissent": ("répondre",),
    "répondisses": ("répondre",),
    "répondisse": ("répondre",),
    "répondissiez": ("répondre",),
    "répondissions": ("répondre",),
    "répondîtes": ("répondre",),
    "répondit": ("répondre",),
    "répondît": ("répondre",),
    "répondons": ("répondre",),
    "répond": ("répondre",),
    "répondra": ("répondre",),
    "répondraient": ("répondre",),
    "répondrai": ("répondre",),
    "répondrais": ("répondre",),
    "répondrait": ("répondre",),
    "répondras": ("répondre",),
    "répondrez": ("répondre",),
    "répondriez": ("répondre",),
    "répondrions": ("répondre",),
    "répondrons": ("répondre",),
    "répondront": ("répondre",),
    "réponds": ("répondre",),
    "répondue": ("répondre",),
    "répondues": ("répondre",),
    "répondu": ("répondre",),
    "répondus": ("répondre",),
    "repossédaient": ("reposséder",),
    "repossédai": ("reposséder",),
    "repossédais": ("reposséder",),
    "repossédait": ("reposséder",),
    "reposséda": ("reposséder",),
    "repossédâmes": ("reposséder",),
    "repossédant": ("reposséder",),
    "repossédas": ("reposséder",),
    "repossédassent": ("reposséder",),
    "repossédasses": ("reposséder",),
    "repossédasse": ("reposséder",),
    "repossédassiez": ("reposséder",),
    "repossédassions": ("reposséder",),
    "repossédâtes": ("reposséder",),
    "repossédât": ("reposséder",),
    "repossédée": ("reposséder",),
    "repossédées": ("reposséder",),
    "repossédé": ("reposséder",),
    "repossèdent": ("reposséder",),
    "repossède": ("reposséder",),
    "repossédera": ("reposséder",),
    "reposséderaient": ("reposséder",),
    "reposséderai": ("reposséder",),
    "reposséderais": ("reposséder",),
    "reposséderait": ("reposséder",),
    "reposséderas": ("reposséder",),
    "repossédèrent": ("reposséder",),
    "reposséderez": ("reposséder",),
    "reposséderiez": ("reposséder",),
    "reposséderions": ("reposséder",),
    "reposséderons": ("reposséder",),
    "reposséderont": ("reposséder",),
    "repossédés": ("reposséder",),
    "repossèdes": ("reposséder",),
    "repossédez": ("reposséder",),
    "repossédiez": ("reposséder",),
    "repossédions": ("reposséder",),
    "repossédons": ("reposséder",),
    "repotassaient": ("repotasser",),
    "repotassai": ("repotasser",),
    "repotassais": ("repotasser",),
    "repotassait": ("repotasser",),
    "repotassa": ("repotasser",),
    "repotassâmes": ("repotasser",),
    "repotassant": ("repotasser",),
    "repotassas": ("repotasser",),
    "repotassassent": ("repotasser",),
    "repotassasses": ("repotasser",),
    "repotassasse": ("repotasser",),
    "repotassassiez": ("repotasser",),
    "repotassassions": ("repotasser",),
    "repotassâtes": ("repotasser",),
    "repotassât": ("repotasser",),
    "repotassée": ("repotasser",),
    "repotassées": ("repotasser",),
    "repotassé": ("repotasser",),
    "repotassent": ("repotasser",),
    "repotasse": ("repotasser",),
    "repotassera": ("repotasser",),
    "repotasseraient": ("repotasser",),
    "repotasserai": ("repotasser",),
    "repotasserais": ("repotasser",),
    "repotasserait": ("repotasser",),
    "repotasseras": ("repotasser",),
    "repotassèrent": ("repotasser",),
    "repotasserez": ("repotasser",),
    "repotasseriez": ("repotasser",),
    "repotasserions": ("repotasser",),
    "repotasserons": ("repotasser",),
    "repotasseront": ("repotasser",),
    "repotassés": ("repotasser",),
    "repotasses": ("repotasser",),
    "repotassez": ("repotasser",),
    "repotassiez": ("repotasser",),
    "repotassions": ("repotasser",),
    "repotassons": ("repotasser",),
    "repourvoient": ("repourvoir",),
    "repourvoie": ("repourvoir",),
    "repourvoies": ("repourvoir",),
    "repourvoira": ("repourvoir",),
    "repourvoiraient": ("repourvoir",),
    "repourvoirai": ("repourvoir",),
    "repourvoirais": ("repourvoir",),
    "repourvoirait": ("repourvoir",),
    "repourvoiras": ("repourvoir",),
    "repourvoirez": ("repourvoir",),
    "repourvoiriez": ("repourvoir",),
    "repourvoirions": ("repourvoir",),
    "repourvoirons": ("repourvoir",),
    "repourvoiront": ("repourvoir",),
    "repourvois": ("repourvoir",),
    "repourvoit": ("repourvoir",),
    "repourvoyaient": ("repourvoir",),
    "repourvoyais": ("repourvoir",),
    "repourvoyait": ("repourvoir",),
    "repourvoyant": ("repourvoir",),
    "repourvoyez": ("repourvoir",),
    "repourvoyiez": ("repourvoir",),
    "repourvoyions": ("repourvoir",),
    "repourvoyons": ("repourvoir",),
    "repourvue": ("repourvoir",),
    "repourvues": ("repourvoir",),
    "repourvu": ("repourvoir",),
    "repourvûmes": ("repourvoir",),
    "repourvurent": ("repourvoir",),
    "repourvus": ("repourvoir",),
    "repourvussent": ("repourvoir",),
    "repourvusses": ("repourvoir",),
    "repourvusse": ("repourvoir",),
    "repourvussiez": ("repourvoir",),
    "repourvussions": ("repourvoir",),
    "repourvûtes": ("repourvoir",),
    "repourvut": ("repourvoir",),
    "repourvût": ("repourvoir",),
    "repeut": ("repouvoir",),
    "repeuvent": ("repouvoir",),
    "repeux": ("repouvoir",),
    "repourra": ("repouvoir",),
    "repourraient": ("repouvoir",),
    "repourrai": ("repouvoir",),
    "repourrais": ("repouvoir",),
    "repourrait": ("repouvoir",),
    "repourras": ("repouvoir",),
    "repourrez": ("repouvoir",),
    "repourriez": ("repouvoir",),
    "repourrions": ("repouvoir",),
    "repourrons": ("repouvoir",),
    "repourront": ("repouvoir",),
    "repouvaient": ("repouvoir",),
    "repouvais": ("repouvoir",),
    "repouvait": ("repouvoir",),
    "repouvant": ("repouvoir",),
    "repouvez": ("repouvoir",),
    "repouviez": ("repouvoir",),
    "repouvions": ("repouvoir",),
    "repouvons": ("repouvoir",),
    "repuis": ("repouvoir",),
    "repuissent": ("repouvoir",),
    "repuisse": ("repouvoir",),
    "repuisses": ("repouvoir",),
    "repuissiez": ("repouvoir",),
    "repuissions": ("repouvoir",),
    "reprécédaient": ("reprécéder",),
    "reprécédai": ("reprécéder",),
    "reprécédais": ("reprécéder",),
    "reprécédait": ("reprécéder",),
    "reprécéda": ("reprécéder",),
    "reprécédâmes": ("reprécéder",),
    "reprécédant": ("reprécéder",),
    "reprécédas": ("reprécéder",),
    "reprécédassent": ("reprécéder",),
    "reprécédasses": ("reprécéder",),
    "reprécédasse": ("reprécéder",),
    "reprécédassiez": ("reprécéder",),
    "reprécédassions": ("reprécéder",),
    "reprécédâtes": ("reprécéder",),
    "reprécédât": ("reprécéder",),
    "reprécédée": ("reprécéder",),
    "reprécédées": ("reprécéder",),
    "reprécédé": ("reprécéder",),
    "reprécèdent": ("reprécéder",),
    "reprécède": ("reprécéder",),
    "reprécédera": ("reprécéder",),
    "reprécéderaient": ("reprécéder",),
    "reprécéderai": ("reprécéder",),
    "reprécéderais": ("reprécéder",),
    "reprécéderait": ("reprécéder",),
    "reprécéderas": ("reprécéder",),
    "reprécédèrent": ("reprécéder",),
    "reprécéderez": ("reprécéder",),
    "reprécéderiez": ("reprécéder",),
    "reprécéderions": ("reprécéder",),
    "reprécéderons": ("reprécéder",),
    "reprécéderont": ("reprécéder",),
    "reprécédés": ("reprécéder",),
    "reprécèdes": ("reprécéder",),
    "reprécédez": ("reprécéder",),
    "reprécédiez": ("reprécéder",),
    "reprécédions": ("reprécéder",),
    "reprécédons": ("reprécéder",),
    "repréfaçaient": ("repréfacer",),
    "repréfaçai": ("repréfacer",),
    "repréfaçais": ("repréfacer",),
    "repréfaçait": ("repréfacer",),
    "repréfaça": ("repréfacer",),
    "repréfaçâmes": ("repréfacer",),
    "repréfaçant": ("repréfacer",),
    "repréfaças": ("repréfacer",),
    "repréfaçassent": ("repréfacer",),
    "repréfaçasses": ("repréfacer",),
    "repréfaçasse": ("repréfacer",),
    "repréfaçassiez": ("repréfacer",),
    "repréfaçassions": ("repréfacer",),
    "repréfaçâtes": ("repréfacer",),
    "repréfaçât": ("repréfacer",),
    "repréfacée": ("repréfacer",),
    "repréfacées": ("repréfacer",),
    "repréfacé": ("repréfacer",),
    "repréfacent": ("repréfacer",),
    "repréface": ("repréfacer",),
    "repréfacera": ("repréfacer",),
    "repréfaceraient": ("repréfacer",),
    "repréfacerai": ("repréfacer",),
    "repréfacerais": ("repréfacer",),
    "repréfacerait": ("repréfacer",),
    "repréfaceras": ("repréfacer",),
    "repréfacèrent": ("repréfacer",),
    "repréfacerez": ("repréfacer",),
    "repréfaceriez": ("repréfacer",),
    "repréfacerions": ("repréfacer",),
    "repréfacerons": ("repréfacer",),
    "repréfaceront": ("repréfacer",),
    "repréfacés": ("repréfacer",),
    "repréfaces": ("repréfacer",),
    "repréfacez": ("repréfacer",),
    "repréfaciez": ("repréfacer",),
    "repréfacions": ("repréfacer",),
    "repréfaçons": ("repréfacer",),
    "reprenaient": ("reprendre",),
    "reprenais": ("reprendre",),
    "reprenait": ("reprendre",),
    "reprenant": ("reprendre",),
    "reprend": ("reprendre",),
    "reprendra": ("reprendre",),
    "reprendraient": ("reprendre",),
    "reprendrai": ("reprendre",),
    "reprendrais": ("reprendre",),
    "reprendrait": ("reprendre",),
    "reprendras": ("reprendre",),
    "reprendrez": ("reprendre",),
    "reprendriez": ("reprendre",),
    "reprendrions": ("reprendre",),
    "reprendrons": ("reprendre",),
    "reprendront": ("reprendre",),
    "reprends": ("reprendre",),
    "reprenez": ("reprendre",),
    "repreniez": ("reprendre",),
    "reprenions": ("reprendre",),
    "reprennent": ("reprendre",),
    "reprenne": ("reprendre",),
    "reprennes": ("reprendre",),
    "reprenons": ("reprendre",),
    "reprîmes": ("reprendre",),
    "reprirent": ("reprendre",),
    "reprise": ("reprendre",),
    "reprises": ("reprendre",),
    "repris": ("reprendre",),
    "reprissent": ("reprendre",),
    "reprisses": ("reprendre",),
    "reprisse": ("reprendre",),
    "reprissiez": ("reprendre",),
    "reprissions": ("reprendre",),
    "reprîtes": ("reprendre",),
    "reprit": ("reprendre",),
    "reprît": ("reprendre",),
    "represcrira": ("represcrire",),
    "represcriraient": ("represcrire",),
    "represcrirai": ("represcrire",),
    "represcrirais": ("represcrire",),
    "represcrirait": ("represcrire",),
    "represcriras": ("represcrire",),
    "represcrirez": ("represcrire",),
    "represcririez": ("represcrire",),
    "represcririons": ("represcrire",),
    "represcrirons": ("represcrire",),
    "represcriront": ("represcrire",),
    "represcris": ("represcrire",),
    "represcrite": ("represcrire",),
    "represcrites": ("represcrire",),
    "represcrit": ("represcrire",),
    "represcrits": ("represcrire",),
    "represcrivaient": ("represcrire",),
    "represcrivais": ("represcrire",),
    "represcrivait": ("represcrire",),
    "represcrivant": ("represcrire",),
    "represcrivent": ("represcrire",),
    "represcrive": ("represcrire",),
    "represcrives": ("represcrire",),
    "represcrivez": ("represcrire",),
    "represcriviez": ("represcrire",),
    "represcrivîmes": ("represcrire",),
    "represcrivions": ("represcrire",),
    "represcrivirent": ("represcrire",),
    "represcrivis": ("represcrire",),
    "represcrivissent": ("represcrire",),
    "represcrivisses": ("represcrire",),
    "represcrivisse": ("represcrire",),
    "represcrivissiez": ("represcrire",),
    "represcrivissions": ("represcrire",),
    "represcrivîtes": ("represcrire",),
    "represcrivit": ("represcrire",),
    "represcrivît": ("represcrire",),
    "represcrivons": ("represcrire",),
    "reprévenaient": ("reprévenir",),
    "reprévenais": ("reprévenir",),
    "reprévenait": ("reprévenir",),
    "reprévenant": ("reprévenir",),
    "reprévenez": ("reprévenir",),
    "repréveniez": ("reprévenir",),
    "reprévenions": ("reprévenir",),
    "reprévenons": ("reprévenir",),
    "reprévenue": ("reprévenir",),
    "reprévenues": ("reprévenir",),
    "reprévenu": ("reprévenir",),
    "reprévenus": ("reprévenir",),
    "repréviendra": ("reprévenir",),
    "repréviendraient": ("reprévenir",),
    "repréviendrai": ("reprévenir",),
    "repréviendrais": ("reprévenir",),
    "repréviendrait": ("reprévenir",),
    "repréviendras": ("reprévenir",),
    "repréviendrez": ("reprévenir",),
    "repréviendriez": ("reprévenir",),
    "repréviendrions": ("reprévenir",),
    "repréviendrons": ("reprévenir",),
    "repréviendront": ("reprévenir",),
    "repréviennent": ("reprévenir",),
    "reprévienne": ("reprévenir",),
    "repréviennes": ("reprévenir",),
    "repréviens": ("reprévenir",),
    "reprévient": ("reprévenir",),
    "reprévînmes": ("reprévenir",),
    "reprévinrent": ("reprévenir",),
    "reprévins": ("reprévenir",),
    "reprévinssent": ("reprévenir",),
    "reprévinsses": ("reprévenir",),
    "reprévinsse": ("reprévenir",),
    "reprévinssiez": ("reprévenir",),
    "reprévinssions": ("reprévenir",),
    "reprévîntes": ("reprévenir",),
    "reprévint": ("reprévenir",),
    "reprévînt": ("reprévenir",),
    "repriaient": ("reprier",),
    "repriai": ("reprier",),
    "repriais": ("reprier",),
    "repriait": ("reprier",),
    "repria": ("reprier",),
    "repriâmes": ("reprier",),
    "repriant": ("reprier",),
    "reprias": ("reprier",),
    "repriassent": ("reprier",),
    "repriasses": ("reprier",),
    "repriasse": ("reprier",),
    "repriassiez": ("reprier",),
    "repriassions": ("reprier",),
    "repriâtes": ("reprier",),
    "repriât": ("reprier",),
    "repriée": ("reprier",),
    "repriées": ("reprier",),
    "reprié": ("reprier",),
    "reprient": ("reprier",),
    "reprie": ("reprier",),
    "repriera": ("reprier",),
    "reprieraient": ("reprier",),
    "reprierai": ("reprier",),
    "reprierais": ("reprier",),
    "reprierait": ("reprier",),
    "reprieras": ("reprier",),
    "reprièrent": ("reprier",),
    "reprierez": ("reprier",),
    "reprieriez": ("reprier",),
    "reprierions": ("reprier",),
    "reprierons": ("reprier",),
    "reprieront": ("reprier",),
    "repriés": ("reprier",),
    "repries": ("reprier",),
    "repriez": ("reprier",),
    "repriiez": ("reprier",),
    "repriions": ("reprier",),
    "reprions": ("reprier",),
    "reprocédaient": ("reprocéder",),
    "reprocédai": ("reprocéder",),
    "reprocédais": ("reprocéder",),
    "reprocédait": ("reprocéder",),
    "reprocéda": ("reprocéder",),
    "reprocédâmes": ("reprocéder",),
    "reprocédant": ("reprocéder",),
    "reprocédas": ("reprocéder",),
    "reprocédassent": ("reprocéder",),
    "reprocédasses": ("reprocéder",),
    "reprocédasse": ("reprocéder",),
    "reprocédassiez": ("reprocéder",),
    "reprocédassions": ("reprocéder",),
    "reprocédâtes": ("reprocéder",),
    "reprocédât": ("reprocéder",),
    "reprocédée": ("reprocéder",),
    "reprocédées": ("reprocéder",),
    "reprocédé": ("reprocéder",),
    "reprocèdent": ("reprocéder",),
    "reprocède": ("reprocéder",),
    "reprocédera": ("reprocéder",),
    "reprocéderaient": ("reprocéder",),
    "reprocéderai": ("reprocéder",),
    "reprocéderais": ("reprocéder",),
    "reprocéderait": ("reprocéder",),
    "reprocéderas": ("reprocéder",),
    "reprocédèrent": ("reprocéder",),
    "reprocéderez": ("reprocéder",),
    "reprocéderiez": ("reprocéder",),
    "reprocéderions": ("reprocéder",),
    "reprocéderons": ("reprocéder",),
    "reprocéderont": ("reprocéder",),
    "reprocédés": ("reprocéder",),
    "reprocèdes": ("reprocéder",),
    "reprocédez": ("reprocéder",),
    "reprocédiez": ("reprocéder",),
    "reprocédions": ("reprocéder",),
    "reprocédons": ("reprocéder",),
    "reproduira": ("reproduire",),
    "reproduiraient": ("reproduire",),
    "reproduirai": ("reproduire",),
    "reproduirais": ("reproduire",),
    "reproduirait": ("reproduire",),
    "reproduiras": ("reproduire",),
    "reproduirez": ("reproduire",),
    "reproduiriez": ("reproduire",),
    "reproduirions": ("reproduire",),
    "reproduirons": ("reproduire",),
    "reproduiront": ("reproduire",),
    "reproduisaient": ("reproduire",),
    "reproduisais": ("reproduire",),
    "reproduisait": ("reproduire",),
    "reproduisant": ("reproduire",),
    "reproduisent": ("reproduire",),
    "reproduise": ("reproduire",),
    "reproduises": ("reproduire",),
    "reproduisez": ("reproduire",),
    "reproduisiez": ("reproduire",),
    "reproduisîmes": ("reproduire",),
    "reproduisions": ("reproduire",),
    "reproduisirent": ("reproduire",),
    "reproduisis": ("reproduire",),
    "reproduisissent": ("reproduire",),
    "reproduisisses": ("reproduire",),
    "reproduisisse": ("reproduire",),
    "reproduisissiez": ("reproduire",),
    "reproduisissions": ("reproduire",),
    "reproduisîtes": ("reproduire",),
    "reproduisit": ("reproduire",),
    "reproduisît": ("reproduire",),
    "reproduisons": ("reproduire",),
    "reproduis": ("reproduire",),
    "reproduite": ("reproduire",),
    "reproduites": ("reproduire",),
    "reproduit": ("reproduire",),
    "reproduits": ("reproduire",),
    "reprographiaient": ("reprographier",),
    "reprographiai": ("reprographier",),
    "reprographiais": ("reprographier",),
    "reprographiait": ("reprographier",),
    "reprographia": ("reprographier",),
    "reprographiâmes": ("reprographier",),
    "reprographiant": ("reprographier",),
    "reprographias": ("reprographier",),
    "reprographiassent": ("reprographier",),
    "reprographiasses": ("reprographier",),
    "reprographiasse": ("reprographier",),
    "reprographiassiez": ("reprographier",),
    "reprographiassions": ("reprographier",),
    "reprographiâtes": ("reprographier",),
    "reprographiât": ("reprographier",),
    "reprographiée": ("reprographier",),
    "reprographiées": ("reprographier",),
    "reprographié": ("reprographier",),
    "reprographient": ("reprographier",),
    "reprographie": ("reprographier",),
    "reprographiera": ("reprographier",),
    "reprographieraient": ("reprographier",),
    "reprographierai": ("reprographier",),
    "reprographierais": ("reprographier",),
    "reprographierait": ("reprographier",),
    "reprographieras": ("reprographier",),
    "reprographièrent": ("reprographier",),
    "reprographierez": ("reprographier",),
    "reprographieriez": ("reprographier",),
    "reprographierions": ("reprographier",),
    "reprographierons": ("reprographier",),
    "reprographieront": ("reprographier",),
    "reprographiés": ("reprographier",),
    "reprographies": ("reprographier",),
    "reprographiez": ("reprographier",),
    "reprographiiez": ("reprographier",),
    "reprographiions": ("reprographier",),
    "reprographions": ("reprographier",),
    "reprojetaient": ("reprojeter",),
    "reprojetai": ("reprojeter",),
    "reprojetais": ("reprojeter",),
    "reprojetait": ("reprojeter",),
    "reprojeta": ("reprojeter",),
    "reprojetâmes": ("reprojeter",),
    "reprojetant": ("reprojeter",),
    "reprojetas": ("reprojeter",),
    "reprojetassent": ("reprojeter",),
    "reprojetasses": ("reprojeter",),
    "reprojetasse": ("reprojeter",),
    "reprojetassiez": ("reprojeter",),
    "reprojetassions": ("reprojeter",),
    "reprojetâtes": ("reprojeter",),
    "reprojetât": ("reprojeter",),
    "reprojetée": ("reprojeter",),
    "reprojetées": ("reprojeter",),
    "reprojeté": ("reprojeter",),
    "reprojetèrent": ("reprojeter",),
    "reprojetés": ("reprojeter",),
    "reprojetez": ("reprojeter",),
    "reprojetiez": ("reprojeter",),
    "reprojetions": ("reprojeter",),
    "reprojetons": ("reprojeter",),
    "reprojettent": ("reprojeter",),
    "reprojette": ("reprojeter",),
    "reprojettera": ("reprojeter",),
    "reprojetteraient": ("reprojeter",),
    "reprojetterai": ("reprojeter",),
    "reprojetterais": ("reprojeter",),
    "reprojetterait": ("reprojeter",),
    "reprojetteras": ("reprojeter",),
    "reprojetterez": ("reprojeter",),
    "reprojetteriez": ("reprojeter",),
    "reprojetterions": ("reprojeter",),
    "reprojetterons": ("reprojeter",),
    "reprojetteront": ("reprojeter",),
    "reprojettes": ("reprojeter",),
    "repromenaient": ("repromener",),
    "repromenai": ("repromener",),
    "repromenais": ("repromener",),
    "repromenait": ("repromener",),
    "repromena": ("repromener",),
    "repromenâmes": ("repromener",),
    "repromenant": ("repromener",),
    "repromenas": ("repromener",),
    "repromenassent": ("repromener",),
    "repromenasses": ("repromener",),
    "repromenasse": ("repromener",),
    "repromenassiez": ("repromener",),
    "repromenassions": ("repromener",),
    "repromenâtes": ("repromener",),
    "repromenât": ("repromener",),
    "repromenée": ("repromener",),
    "repromenées": ("repromener",),
    "repromené": ("repromener",),
    "repromènent": ("repromener",),
    "repromène": ("repromener",),
    "repromènera": ("repromener",),
    "repromèneraient": ("repromener",),
    "repromènerai": ("repromener",),
    "repromènerais": ("repromener",),
    "repromènerait": ("repromener",),
    "repromèneras": ("repromener",),
    "repromenèrent": ("repromener",),
    "repromènerez": ("repromener",),
    "repromèneriez": ("repromener",),
    "repromènerions": ("repromener",),
    "repromènerons": ("repromener",),
    "repromèneront": ("repromener",),
    "repromenés": ("repromener",),
    "repromènes": ("repromener",),
    "repromenez": ("repromener",),
    "repromeniez": ("repromener",),
    "repromenions": ("repromener",),
    "repromenons": ("repromener",),
    "repromet": ("repromettre",),
    "repromets": ("repromettre",),
    "repromettaient": ("repromettre",),
    "repromettais": ("repromettre",),
    "repromettait": ("repromettre",),
    "repromettant": ("repromettre",),
    "repromettent": ("repromettre",),
    "repromette": ("repromettre",),
    "repromettes": ("repromettre",),
    "repromettez": ("repromettre",),
    "repromettiez": ("repromettre",),
    "repromettions": ("repromettre",),
    "repromettons": ("repromettre",),
    "repromettra": ("repromettre",),
    "repromettraient": ("repromettre",),
    "repromettrai": ("repromettre",),
    "repromettrais": ("repromettre",),
    "repromettrait": ("repromettre",),
    "repromettras": ("repromettre",),
    "repromettrez": ("repromettre",),
    "repromettriez": ("repromettre",),
    "repromettrions": ("repromettre",),
    "repromettrons": ("repromettre",),
    "repromettront": ("repromettre",),
    "repromîmes": ("repromettre",),
    "repromirent": ("repromettre",),
    "repromise": ("repromettre",),
    "repromises": ("repromettre",),
    "repromis": ("repromettre",),
    "repromissent": ("repromettre",),
    "repromisses": ("repromettre",),
    "repromisse": ("repromettre",),
    "repromissiez": ("repromettre",),
    "repromissions": ("repromettre",),
    "repromîtes": ("repromettre",),
    "repromit": ("repromettre",),
    "repromît": ("repromettre",),
    "reprononçaient": ("reprononcer",),
    "reprononçai": ("reprononcer",),
    "reprononçais": ("reprononcer",),
    "reprononçait": ("reprononcer",),
    "reprononça": ("reprononcer",),
    "reprononçâmes": ("reprononcer",),
    "reprononçant": ("reprononcer",),
    "reprononças": ("reprononcer",),
    "reprononçassent": ("reprononcer",),
    "reprononçasses": ("reprononcer",),
    "reprononçasse": ("reprononcer",),
    "reprononçassiez": ("reprononcer",),
    "reprononçassions": ("reprononcer",),
    "reprononçâtes": ("reprononcer",),
    "reprononçât": ("reprononcer",),
    "reprononcée": ("reprononcer",),
    "reprononcées": ("reprononcer",),
    "reprononcé": ("reprononcer",),
    "reprononcent": ("reprononcer",),
    "reprononce": ("reprononcer",),
    "reprononcera": ("reprononcer",),
    "reprononceraient": ("reprononcer",),
    "reprononcerai": ("reprononcer",),
    "reprononcerais": ("reprononcer",),
    "reprononcerait": ("reprononcer",),
    "reprononceras": ("reprononcer",),
    "reprononcèrent": ("reprononcer",),
    "reprononcerez": ("reprononcer",),
    "reprononceriez": ("reprononcer",),
    "reprononcerions": ("reprononcer",),
    "reprononcerons": ("reprononcer",),
    "reprononceront": ("reprononcer",),
    "reprononcés": ("reprononcer",),
    "reprononces": ("reprononcer",),
    "reprononcez": ("reprononcer",),
    "reprononciez": ("reprononcer",),
    "reprononcions": ("reprononcer",),
    "reprononçons": ("reprononcer",),
    "reprospéraient": ("reprospérer",),
    "reprospérai": ("reprospérer",),
    "reprospérais": ("reprospérer",),
    "reprospérait": ("reprospérer",),
    "reprospéra": ("reprospérer",),
    "reprospérâmes": ("reprospérer",),
    "reprospérant": ("reprospérer",),
    "reprospéras": ("reprospérer",),
    "reprospérassent": ("reprospérer",),
    "reprospérasses": ("reprospérer",),
    "reprospérasse": ("reprospérer",),
    "reprospérassiez": ("reprospérer",),
    "reprospérassions": ("reprospérer",),
    "reprospérâtes": ("reprospérer",),
    "reprospérât": ("reprospérer",),
    "reprospérée": ("reprospérer",),
    "reprospérées": ("reprospérer",),
    "reprospéré": ("reprospérer",),
    "reprospèrent": ("reprospérer",),
    "reprospère": ("reprospérer",),
    "reprospérera": ("reprospérer",),
    "reprospéreraient": ("reprospérer",),
    "reprospérerai": ("reprospérer",),
    "reprospérerais": ("reprospérer",),
    "reprospérerait": ("reprospérer",),
    "reprospéreras": ("reprospérer",),
    "reprospérèrent": ("reprospérer",),
    "reprospérerez": ("reprospérer",),
    "reprospéreriez": ("reprospérer",),
    "reprospérerions": ("reprospérer",),
    "reprospérerons": ("reprospérer",),
    "reprospéreront": ("reprospérer",),
    "reprospérés": ("reprospérer",),
    "reprospères": ("reprospérer",),
    "reprospérez": ("reprospérer",),
    "reprospériez": ("reprospérer",),
    "reprospérions": ("reprospérer",),
    "reprospérons": ("reprospérer",),
    "reprotégeaient": ("reprotéger",),
    "reprotégeai": ("reprotéger",),
    "reprotégeais": ("reprotéger",),
    "reprotégeait": ("reprotéger",),
    "reprotégea": ("reprotéger",),
    "reprotégeâmes": ("reprotéger",),
    "reprotégeant": ("reprotéger",),
    "reprotégeas": ("reprotéger",),
    "reprotégeassent": ("reprotéger",),
    "reprotégeasses": ("reprotéger",),
    "reprotégeasse": ("reprotéger",),
    "reprotégeassiez": ("reprotéger",),
    "reprotégeassions": ("reprotéger",),
    "reprotégeâtes": ("reprotéger",),
    "reprotégeât": ("reprotéger",),
    "reprotégée": ("reprotéger",),
    "reprotégées": ("reprotéger",),
    "reprotégé": ("reprotéger",),
    "reprotègent": ("reprotéger",),
    "reprotégeons": ("reprotéger",),
    "reprotège": ("reprotéger",),
    "reprotégera": ("reprotéger",),
    "reprotégeraient": ("reprotéger",),
    "reprotégerai": ("reprotéger",),
    "reprotégerais": ("reprotéger",),
    "reprotégerait": ("reprotéger",),
    "reprotégeras": ("reprotéger",),
    "reprotégèrent": ("reprotéger",),
    "reprotégerez": ("reprotéger",),
    "reprotégeriez": ("reprotéger",),
    "reprotégerions": ("reprotéger",),
    "reprotégerons": ("reprotéger",),
    "reprotégeront": ("reprotéger",),
    "reprotégés": ("reprotéger",),
    "reprotèges": ("reprotéger",),
    "reprotégez": ("reprotéger",),
    "reprotégiez": ("reprotéger",),
    "reprotégions": ("reprotéger",),
    "republiaient": ("republier",),
    "republiai": ("republier",),
    "republiais": ("republier",),
    "republiait": ("republier",),
    "republia": ("republier",),
    "republiâmes": ("republier",),
    "republiant": ("republier",),
    "republias": ("republier",),
    "republiassent": ("republier",),
    "republiasses": ("republier",),
    "republiasse": ("republier",),
    "republiassiez": ("republier",),
    "republiassions": ("republier",),
    "republiâtes": ("republier",),
    "republiât": ("republier",),
    "republiée": ("republier",),
    "republiées": ("republier",),
    "republié": ("republier",),
    "republient": ("republier",),
    "republie": ("republier",),
    "republiera": ("republier",),
    "republieraient": ("republier",),
    "republierai": ("republier",),
    "republierais": ("republier",),
    "republierait": ("republier",),
    "republieras": ("republier",),
    "republièrent": ("republier",),
    "republierez": ("republier",),
    "republieriez": ("republier",),
    "republierions": ("republier",),
    "republierons": ("republier",),
    "republieront": ("republier",),
    "republiés": ("republier",),
    "republies": ("republier",),
    "republiez": ("republier",),
    "republiiez": ("republier",),
    "republiions": ("republier",),
    "republions": ("republier",),
    "répudiaient": ("répudier",),
    "répudiai": ("répudier",),
    "répudiais": ("répudier",),
    "répudiait": ("répudier",),
    "répudia": ("répudier",),
    "répudiâmes": ("répudier",),
    "répudiant": ("répudier",),
    "répudias": ("répudier",),
    "répudiassent": ("répudier",),
    "répudiasses": ("répudier",),
    "répudiasse": ("répudier",),
    "répudiassiez": ("répudier",),
    "répudiassions": ("répudier",),
    "répudiâtes": ("répudier",),
    "répudiât": ("répudier",),
    "répudiée": ("répudier",),
    "répudiées": ("répudier",),
    "répudié": ("répudier",),
    "répudient": ("répudier",),
    "répudie": ("répudier",),
    "répudiera": ("répudier",),
    "répudieraient": ("répudier",),
    "répudierai": ("répudier",),
    "répudierais": ("répudier",),
    "répudierait": ("répudier",),
    "répudieras": ("répudier",),
    "répudièrent": ("répudier",),
    "répudierez": ("répudier",),
    "répudieriez": ("répudier",),
    "répudierions": ("répudier",),
    "répudierons": ("répudier",),
    "répudieront": ("répudier",),
    "répudiés": ("répudier",),
    "répudies": ("répudier",),
    "répudiez": ("répudier",),
    "répudiiez": ("répudier",),
    "répudiions": ("répudier",),
    "répudions": ("répudier",),
    "repurgeaient": ("repurger",),
    "repurgeai": ("repurger",),
    "repurgeais": ("repurger",),
    "repurgeait": ("repurger",),
    "repurgea": ("repurger",),
    "repurgeâmes": ("repurger",),
    "repurgeant": ("repurger",),
    "repurgeas": ("repurger",),
    "repurgeassent": ("repurger",),
    "repurgeasses": ("repurger",),
    "repurgeasse": ("repurger",),
    "repurgeassiez": ("repurger",),
    "repurgeassions": ("repurger",),
    "repurgeâtes": ("repurger",),
    "repurgeât": ("repurger",),
    "repurgée": ("repurger",),
    "repurgées": ("repurger",),
    "repurgé": ("repurger",),
    "repurgent": ("repurger",),
    "repurgeons": ("repurger",),
    "repurge": ("repurger",),
    "repurgera": ("repurger",),
    "repurgeraient": ("repurger",),
    "repurgerai": ("repurger",),
    "repurgerais": ("repurger",),
    "repurgerait": ("repurger",),
    "repurgeras": ("repurger",),
    "repurgèrent": ("repurger",),
    "repurgerez": ("repurger",),
    "repurgeriez": ("repurger",),
    "repurgerions": ("repurger",),
    "repurgerons": ("repurger",),
    "repurgeront": ("repurger",),
    "repurgés": ("repurger",),
    "repurges": ("repurger",),
    "repurgez": ("repurger",),
    "repurgiez": ("repurger",),
    "repurgions": ("repurger",),
    "requalifiaient": ("requalifier",),
    "requalifiai": ("requalifier",),
    "requalifiais": ("requalifier",),
    "requalifiait": ("requalifier",),
    "requalifia": ("requalifier",),
    "requalifiâmes": ("requalifier",),
    "requalifiant": ("requalifier",),
    "requalifias": ("requalifier",),
    "requalifiassent": ("requalifier",),
    "requalifiasses": ("requalifier",),
    "requalifiasse": ("requalifier",),
    "requalifiassiez": ("requalifier",),
    "requalifiassions": ("requalifier",),
    "requalifiâtes": ("requalifier",),
    "requalifiât": ("requalifier",),
    "requalifiée": ("requalifier",),
    "requalifiées": ("requalifier",),
    "requalifié": ("requalifier",),
    "requalifient": ("requalifier",),
    "requalifie": ("requalifier",),
    "requalifiera": ("requalifier",),
    "requalifieraient": ("requalifier",),
    "requalifierai": ("requalifier",),
    "requalifierais": ("requalifier",),
    "requalifierait": ("requalifier",),
    "requalifieras": ("requalifier",),
    "requalifièrent": ("requalifier",),
    "requalifierez": ("requalifier",),
    "requalifieriez": ("requalifier",),
    "requalifierions": ("requalifier",),
    "requalifierons": ("requalifier",),
    "requalifieront": ("requalifier",),
    "requalifiés": ("requalifier",),
    "requalifies": ("requalifier",),
    "requalifiez": ("requalifier",),
    "requalifiiez": ("requalifier",),
    "requalifiions": ("requalifier",),
    "requalifions": ("requalifier",),
    "requéraient": ("requérir",),
    "requérais": ("requérir",),
    "requérait": ("requérir",),
    "requérant": ("requérir",),
    "requérez": ("requérir",),
    "requériez": ("requérir",),
    "requérions": ("requérir",),
    "requérons": ("requérir",),
    "requerra": ("requérir",),
    "requerraient": ("requérir",),
    "requerrai": ("requérir",),
    "requerrais": ("requérir",),
    "requerrait": ("requérir",),
    "requerras": ("requérir",),
    "requerrez": ("requérir",),
    "requerriez": ("requérir",),
    "requerrions": ("requérir",),
    "requerrons": ("requérir",),
    "requerront": ("requérir",),
    "requièrent": ("requérir",),
    "requière": ("requérir",),
    "requières": ("requérir",),
    "requiers": ("requérir",),
    "requiert": ("requérir",),
    "requîmes": ("requérir",),
    "requirent": ("requérir",),
    "requise": ("requérir",),
    "requises": ("requérir",),
    "requis": ("requérir",),
    "requissent": ("requérir",),
    "requisses": ("requérir",),
    "requisse": ("requérir",),
    "requissiez": ("requérir",),
    "requissions": ("requérir",),
    "requîtes": ("requérir",),
    "requit": ("requérir",),
    "requît": ("requérir",),
    "reremplaçaient": ("reremplacer",),
    "reremplaçai": ("reremplacer",),
    "reremplaçais": ("reremplacer",),
    "reremplaçait": ("reremplacer",),
    "reremplaça": ("reremplacer",),
    "reremplaçâmes": ("reremplacer",),
    "reremplaçant": ("reremplacer",),
    "reremplaças": ("reremplacer",),
    "reremplaçassent": ("reremplacer",),
    "reremplaçasses": ("reremplacer",),
    "reremplaçasse": ("reremplacer",),
    "reremplaçassiez": ("reremplacer",),
    "reremplaçassions": ("reremplacer",),
    "reremplaçâtes": ("reremplacer",),
    "reremplaçât": ("reremplacer",),
    "reremplacée": ("reremplacer",),
    "reremplacées": ("reremplacer",),
    "reremplacé": ("reremplacer",),
    "reremplacent": ("reremplacer",),
    "reremplace": ("reremplacer",),
    "reremplacera": ("reremplacer",),
    "reremplaceraient": ("reremplacer",),
    "reremplacerai": ("reremplacer",),
    "reremplacerais": ("reremplacer",),
    "reremplacerait": ("reremplacer",),
    "reremplaceras": ("reremplacer",),
    "reremplacèrent": ("reremplacer",),
    "reremplacerez": ("reremplacer",),
    "reremplaceriez": ("reremplacer",),
    "reremplacerions": ("reremplacer",),
    "reremplacerons": ("reremplacer",),
    "reremplaceront": ("reremplacer",),
    "reremplacés": ("reremplacer",),
    "reremplaces": ("reremplacer",),
    "reremplacez": ("reremplacer",),
    "reremplaciez": ("reremplacer",),
    "reremplacions": ("reremplacer",),
    "reremplaçons": ("reremplacer",),
    "rerenonçaient": ("rerenoncer",),
    "rerenonçai": ("rerenoncer",),
    "rerenonçais": ("rerenoncer",),
    "rerenonçait": ("rerenoncer",),
    "rerenonça": ("rerenoncer",),
    "rerenonçâmes": ("rerenoncer",),
    "rerenonçant": ("rerenoncer",),
    "rerenonças": ("rerenoncer",),
    "rerenonçassent": ("rerenoncer",),
    "rerenonçasses": ("rerenoncer",),
    "rerenonçasse": ("rerenoncer",),
    "rerenonçassiez": ("rerenoncer",),
    "rerenonçassions": ("rerenoncer",),
    "rerenonçâtes": ("rerenoncer",),
    "rerenonçât": ("rerenoncer",),
    "rerenoncée": ("rerenoncer",),
    "rerenoncées": ("rerenoncer",),
    "rerenoncé": ("rerenoncer",),
    "rerenoncent": ("rerenoncer",),
    "rerenonce": ("rerenoncer",),
    "rerenoncera": ("rerenoncer",),
    "rerenonceraient": ("rerenoncer",),
    "rerenoncerai": ("rerenoncer",),
    "rerenoncerais": ("rerenoncer",),
    "rerenoncerait": ("rerenoncer",),
    "rerenonceras": ("rerenoncer",),
    "rerenoncèrent": ("rerenoncer",),
    "rerenoncerez": ("rerenoncer",),
    "rerenonceriez": ("rerenoncer",),
    "rerenoncerions": ("rerenoncer",),
    "rerenoncerons": ("rerenoncer",),
    "rerenonceront": ("rerenoncer",),
    "rerenoncés": ("rerenoncer",),
    "rerenonces": ("rerenoncer",),
    "rerenoncez": ("rerenoncer",),
    "rerenonciez": ("rerenoncer",),
    "rerenoncions": ("rerenoncer",),
    "rerenonçons": ("rerenoncer",),
    "rerinçaient": ("rerincer",),
    "rerinçai": ("rerincer",),
    "rerinçais": ("rerincer",),
    "rerinçait": ("rerincer",),
    "rerinça": ("rerincer",),
    "rerinçâmes": ("rerincer",),
    "rerinçant": ("rerincer",),
    "rerinças": ("rerincer",),
    "rerinçassent": ("rerincer",),
    "rerinçasses": ("rerincer",),
    "rerinçasse": ("rerincer",),
    "rerinçassiez": ("rerincer",),
    "rerinçassions": ("rerincer",),
    "rerinçâtes": ("rerincer",),
    "rerinçât": ("rerincer",),
    "rerincée": ("rerincer",),
    "rerincées": ("rerincer",),
    "rerincé": ("rerincer",),
    "rerincent": ("rerincer",),
    "rerince": ("rerincer",),
    "rerincera": ("rerincer",),
    "rerinceraient": ("rerincer",),
    "rerincerai": ("rerincer",),
    "rerincerais": ("rerincer",),
    "rerincerait": ("rerincer",),
    "rerinceras": ("rerincer",),
    "rerincèrent": ("rerincer",),
    "rerincerez": ("rerincer",),
    "rerinceriez": ("rerincer",),
    "rerincerions": ("rerincer",),
    "rerincerons": ("rerincer",),
    "rerinceront": ("rerincer",),
    "rerincés": ("rerincer",),
    "rerinces": ("rerincer",),
    "rerincez": ("rerincer",),
    "rerinciez": ("rerincer",),
    "rerincions": ("rerincer",),
    "rerinçons": ("rerincer",),
    "resacrifiaient": ("resacrifier",),
    "resacrifiai": ("resacrifier",),
    "resacrifiais": ("resacrifier",),
    "resacrifiait": ("resacrifier",),
    "resacrifia": ("resacrifier",),
    "resacrifiâmes": ("resacrifier",),
    "resacrifiant": ("resacrifier",),
    "resacrifias": ("resacrifier",),
    "resacrifiassent": ("resacrifier",),
    "resacrifiasses": ("resacrifier",),
    "resacrifiasse": ("resacrifier",),
    "resacrifiassiez": ("resacrifier",),
    "resacrifiassions": ("resacrifier",),
    "resacrifiâtes": ("resacrifier",),
    "resacrifiât": ("resacrifier",),
    "resacrifiée": ("resacrifier",),
    "resacrifiées": ("resacrifier",),
    "resacrifié": ("resacrifier",),
    "resacrifient": ("resacrifier",),
    "resacrifie": ("resacrifier",),
    "resacrifiera": ("resacrifier",),
    "resacrifieraient": ("resacrifier",),
    "resacrifierai": ("resacrifier",),
    "resacrifierais": ("resacrifier",),
    "resacrifierait": ("resacrifier",),
    "resacrifieras": ("resacrifier",),
    "resacrifièrent": ("resacrifier",),
    "resacrifierez": ("resacrifier",),
    "resacrifieriez": ("resacrifier",),
    "resacrifierions": ("resacrifier",),
    "resacrifierons": ("resacrifier",),
    "resacrifieront": ("resacrifier",),
    "resacrifiés": ("resacrifier",),
    "resacrifies": ("resacrifier",),
    "resacrifiez": ("resacrifier",),
    "resacrifiiez": ("resacrifier",),
    "resacrifiions": ("resacrifier",),
    "resacrifions": ("resacrifier",),
    "resalie": ("resalir",),
    "resalies": ("resalir",),
    "resali": ("resalir",),
    "resalîmes": ("resalir",),
    "resalira": ("resalir",),
    "resaliraient": ("resalir",),
    "resalirai": ("resalir",),
    "resalirais": ("resalir",),
    "resalirait": ("resalir",),
    "resaliras": ("resalir",),
    "resalirent": ("resalir",),
    "resalirez": ("resalir",),
    "resaliriez": ("resalir",),
    "resalirions": ("resalir",),
    "resalirons": ("resalir",),
    "resaliront": ("resalir",),
    "resalis": ("resalir",),
    "resalissaient": ("resalir",),
    "resalissais": ("resalir",),
    "resalissait": ("resalir",),
    "resalissant": ("resalir",),
    "resalissent": ("resalir",),
    "resalisse": ("resalir",),
    "resalisses": ("resalir",),
    "resalissez": ("resalir",),
    "resalissiez": ("resalir",),
    "resalissions": ("resalir",),
    "resalissons": ("resalir",),
    "resalîtes": ("resalir",),
    "resalit": ("resalir",),
    "resalît": ("resalir",),
    "resarcie": ("resarcir",),
    "resarcies": ("resarcir",),
    "resarci": ("resarcir",),
    "resarcîmes": ("resarcir",),
    "resarcira": ("resarcir",),
    "resarciraient": ("resarcir",),
    "resarcirai": ("resarcir",),
    "resarcirais": ("resarcir",),
    "resarcirait": ("resarcir",),
    "resarciras": ("resarcir",),
    "resarcirent": ("resarcir",),
    "resarcirez": ("resarcir",),
    "resarciriez": ("resarcir",),
    "resarcirions": ("resarcir",),
    "resarcirons": ("resarcir",),
    "resarciront": ("resarcir",),
    "resarcis": ("resarcir",),
    "resarcissaient": ("resarcir",),
    "resarcissais": ("resarcir",),
    "resarcissait": ("resarcir",),
    "resarcissant": ("resarcir",),
    "resarcissent": ("resarcir",),
    "resarcisse": ("resarcir",),
    "resarcisses": ("resarcir",),
    "resarcissez": ("resarcir",),
    "resarcissiez": ("resarcir",),
    "resarcissions": ("resarcir",),
    "resarcissons": ("resarcir",),
    "resarcîtes": ("resarcir",),
    "resarcit": ("resarcir",),
    "resarcît": ("resarcir",),
    "resauçaient": ("resaucer",),
    "resauçai": ("resaucer",),
    "resauçais": ("resaucer",),
    "resauçait": ("resaucer",),
    "resauça": ("resaucer",),
    "resauçâmes": ("resaucer",),
    "resauçant": ("resaucer",),
    "resauças": ("resaucer",),
    "resauçassent": ("resaucer",),
    "resauçasses": ("resaucer",),
    "resauçasse": ("resaucer",),
    "resauçassiez": ("resaucer",),
    "resauçassions": ("resaucer",),
    "resauçâtes": ("resaucer",),
    "resauçât": ("resaucer",),
    "resaucée": ("resaucer",),
    "resaucées": ("resaucer",),
    "resaucé": ("resaucer",),
    "resaucent": ("resaucer",),
    "resauce": ("resaucer",),
    "resaucera": ("resaucer",),
    "resauceraient": ("resaucer",),
    "resaucerai": ("resaucer",),
    "resaucerais": ("resaucer",),
    "resaucerait": ("resaucer",),
    "resauceras": ("resaucer",),
    "resaucèrent": ("resaucer",),
    "resaucerez": ("resaucer",),
    "resauceriez": ("resaucer",),
    "resaucerions": ("resaucer",),
    "resaucerons": ("resaucer",),
    "resauceront": ("resaucer",),
    "resaucés": ("resaucer",),
    "resauces": ("resaucer",),
    "resaucez": ("resaucer",),
    "resauciez": ("resaucer",),
    "resaucions": ("resaucer",),
    "resauçons": ("resaucer",),
    "resachant": ("resavoir",),
    "resachent": ("resavoir",),
    "resache": ("resavoir",),
    "resaches": ("resavoir",),
    "resachez": ("resavoir",),
    "resachiez": ("resavoir",),
    "resachions": ("resavoir",),
    "resachons": ("resavoir",),
    "resais": ("resavoir",),
    "resait": ("resavoir",),
    "resaura": ("resavoir",),
    "resauraient": ("resavoir",),
    "resaurai": ("resavoir",),
    "resaurais": ("resavoir",),
    "resaurait": ("resavoir",),
    "resauras": ("resavoir",),
    "resaurez": ("resavoir",),
    "resauriez": ("resavoir",),
    "resaurions": ("resavoir",),
    "resaurons": ("resavoir",),
    "resauront": ("resavoir",),
    "resavaient": ("resavoir",),
    "resavais": ("resavoir",),
    "resavait": ("resavoir",),
    "resavent": ("resavoir",),
    "resavez": ("resavoir",),
    "resaviez": ("resavoir",),
    "resavions": ("resavoir",),
    "resavons": ("resavoir",),
    "resue": ("resavoir",),
    "resues": ("resavoir",),
    "resu": ("resavoir",),
    "resûmes": ("resavoir",),
    "resurent": ("resavoir",),
    "resus": ("resavoir",),
    "resussent": ("resavoir",),
    "resusses": ("resavoir",),
    "resusse": ("resavoir",),
    "resussiez": ("resavoir",),
    "resussions": ("resavoir",),
    "resûtes": ("resavoir",),
    "resut": ("resavoir",),
    "resût": ("resavoir",),
    "réselaient": ("réseler",),
    "réselai": ("réseler",),
    "réselais": ("réseler",),
    "réselait": ("réseler",),
    "résela": ("réseler",),
    "réselâmes": ("réseler",),
    "réselant": ("réseler",),
    "réselas": ("réseler",),
    "réselassent": ("réseler",),
    "réselasses": ("réseler",),
    "réselasse": ("réseler",),
    "réselassiez": ("réseler",),
    "réselassions": ("réseler",),
    "réselâtes": ("réseler",),
    "réselât": ("réseler",),
    "réselée": ("réseler",),
    "réselées": ("réseler",),
    "réselé": ("réseler",),
    "résèlent": ("réseler",),
    "résèle": ("réseler",),
    "résèlera": ("réseler",),
    "résèleraient": ("réseler",),
    "résèlerai": ("réseler",),
    "résèlerais": ("réseler",),
    "résèlerait": ("réseler",),
    "résèleras": ("réseler",),
    "réselèrent": ("réseler",),
    "résèlerez": ("réseler",),
    "résèleriez": ("réseler",),
    "résèlerions": ("réseler",),
    "résèlerons": ("réseler",),
    "résèleront": ("réseler",),
    "réselés": ("réseler",),
    "résèles": ("réseler",),
    "réselez": ("réseler",),
    "réseliez": ("réseler",),
    "réselions": ("réseler",),
    "réselons": ("réseler",),
    "resemaient": ("resemer",),
    "resemai": ("resemer",),
    "resemais": ("resemer",),
    "resemait": ("resemer",),
    "resema": ("resemer",),
    "resemâmes": ("resemer",),
    "resemant": ("resemer",),
    "resemas": ("resemer",),
    "resemassent": ("resemer",),
    "resemasses": ("resemer",),
    "resemasse": ("resemer",),
    "resemassiez": ("resemer",),
    "resemassions": ("resemer",),
    "resemâtes": ("resemer",),
    "resemât": ("resemer",),
    "resemée": ("resemer",),
    "resemées": ("resemer",),
    "resemé": ("resemer",),
    "resèment": ("resemer",),
    "resème": ("resemer",),
    "resèmera": ("resemer",),
    "resèmeraient": ("resemer",),
    "resèmerai": ("resemer",),
    "resèmerais": ("resemer",),
    "resèmerait": ("resemer",),
    "resèmeras": ("resemer",),
    "resemèrent": ("resemer",),
    "resèmerez": ("resemer",),
    "resèmeriez": ("resemer",),
    "resèmerions": ("resemer",),
    "resèmerons": ("resemer",),
    "resèmeront": ("resemer",),
    "resemés": ("resemer",),
    "resèmes": ("resemer",),
    "resemez": ("resemer",),
    "resemiez": ("resemer",),
    "resemions": ("resemer",),
    "resemons": ("resemer",),
    "resemonçaient": ("resemoncer",),
    "resemonçai": ("resemoncer",),
    "resemonçais": ("resemoncer",),
    "resemonçait": ("resemoncer",),
    "resemonça": ("resemoncer",),
    "resemonçâmes": ("resemoncer",),
    "resemonçant": ("resemoncer",),
    "resemonças": ("resemoncer",),
    "resemonçassent": ("resemoncer",),
    "resemonçasses": ("resemoncer",),
    "resemonçasse": ("resemoncer",),
    "resemonçassiez": ("resemoncer",),
    "resemonçassions": ("resemoncer",),
    "resemonçâtes": ("resemoncer",),
    "resemonçât": ("resemoncer",),
    "resemoncée": ("resemoncer",),
    "resemoncées": ("resemoncer",),
    "resemoncé": ("resemoncer",),
    "resemoncent": ("resemoncer",),
    "resemonce": ("resemoncer",),
    "resemoncera": ("resemoncer",),
    "resemonceraient": ("resemoncer",),
    "resemoncerai": ("resemoncer",),
    "resemoncerais": ("resemoncer",),
    "resemoncerait": ("resemoncer",),
    "resemonceras": ("resemoncer",),
    "resemoncèrent": ("resemoncer",),
    "resemoncerez": ("resemoncer",),
    "resemonceriez": ("resemoncer",),
    "resemoncerions": ("resemoncer",),
    "resemoncerons": ("resemoncer",),
    "resemonceront": ("resemoncer",),
    "resemoncés": ("resemoncer",),
    "resemonces": ("resemoncer",),
    "resemoncez": ("resemoncer",),
    "resemonciez": ("resemoncer",),
    "resemoncions": ("resemoncer",),
    "resemonçons": ("resemoncer",),
    "resens": ("resentir",),
    "resentaient": ("resentir",),
    "resentais": ("resentir",),
    "resentait": ("resentir",),
    "resentant": ("resentir",),
    "resentent": ("resentir",),
    "resente": ("resentir",),
    "resentes": ("resentir",),
    "resentez": ("resentir",),
    "resentie": ("resentir",),
    "resenties": ("resentir",),
    "resentiez": ("resentir",),
    "resenti": ("resentir",),
    "resentîmes": ("resentir",),
    "resentions": ("resentir",),
    "resentira": ("resentir",),
    "resentiraient": ("resentir",),
    "resentirai": ("resentir",),
    "resentirais": ("resentir",),
    "resentirait": ("resentir",),
    "resentiras": ("resentir",),
    "resentirent": ("resentir",),
    "resentirez": ("resentir",),
    "resentiriez": ("resentir",),
    "resentirions": ("resentir",),
    "resentirons": ("resentir",),
    "resentiront": ("resentir",),
    "resentis": ("resentir",),
    "resentissent": ("resentir",),
    "resentisses": ("resentir",),
    "resentisse": ("resentir",),
    "resentissiez": ("resentir",),
    "resentissions": ("resentir",),
    "resentîtes": ("resentir",),
    "resentit": ("resentir",),
    "resentît": ("resentir",),
    "resentons": ("resentir",),
    "resent": ("resentir",),
    "réséquaient": ("réséquer",),
    "réséquai": ("réséquer",),
    "réséquais": ("réséquer",),
    "réséquait": ("réséquer",),
    "réséqua": ("réséquer",),
    "réséquâmes": ("réséquer",),
    "réséquant": ("réséquer",),
    "réséquas": ("réséquer",),
    "réséquassent": ("réséquer",),
    "réséquasses": ("réséquer",),
    "réséquasse": ("réséquer",),
    "réséquassiez": ("réséquer",),
    "réséquassions": ("réséquer",),
    "réséquâtes": ("réséquer",),
    "réséquât": ("réséquer",),
    "réséquée": ("réséquer",),
    "réséquées": ("réséquer",),
    "réséqué": ("réséquer",),
    "résèquent": ("réséquer",),
    "résèque": ("réséquer",),
    "réséquera": ("réséquer",),
    "réséqueraient": ("réséquer",),
    "réséquerai": ("réséquer",),
    "réséquerais": ("réséquer",),
    "réséquerait": ("réséquer",),
    "réséqueras": ("réséquer",),
    "réséquèrent": ("réséquer",),
    "réséquerez": ("réséquer",),
    "réséqueriez": ("réséquer",),
    "réséquerions": ("réséquer",),
    "réséquerons": ("réséquer",),
    "réséqueront": ("réséquer",),
    "réséqués": ("réséquer",),
    "résèques": ("réséquer",),
    "réséquez": ("réséquer",),
    "réséquiez": ("réséquer",),
    "réséquions": ("réséquer",),
    "réséquons": ("réséquer",),
    "resers": ("reservir",),
    "resert": ("reservir",),
    "reservaient": ("reservir",),
    "reservais": ("reservir",),
    "reservait": ("reservir",),
    "reservant": ("reservir",),
    "reservent": ("reservir",),
    "reserve": ("reservir",),
    "reserves": ("reservir",),
    "reservez": ("reservir",),
    "reservie": ("reservir",),
    "reservies": ("reservir",),
    "reserviez": ("reservir",),
    "reservi": ("reservir",),
    "reservîmes": ("reservir",),
    "reservions": ("reservir",),
    "reservira": ("reservir",),
    "reserviraient": ("reservir",),
    "reservirai": ("reservir",),
    "reservirais": ("reservir",),
    "reservirait": ("reservir",),
    "reserviras": ("reservir",),
    "reservirent": ("reservir",),
    "reservirez": ("reservir",),
    "reserviriez": ("reservir",),
    "reservirions": ("reservir",),
    "reservirons": ("reservir",),
    "reserviront": ("reservir",),
    "reservis": ("reservir",),
    "reservissent": ("reservir",),
    "reservisses": ("reservir",),
    "reservisse": ("reservir",),
    "reservissiez": ("reservir",),
    "reservissions": ("reservir",),
    "reservîtes": ("reservir",),
    "reservit": ("reservir",),
    "reservît": ("reservir",),
    "reservons": ("reservir",),
    "resignifiaient": ("resignifier",),
    "resignifiai": ("resignifier",),
    "resignifiais": ("resignifier",),
    "resignifiait": ("resignifier",),
    "resignifia": ("resignifier",),
    "resignifiâmes": ("resignifier",),
    "resignifiant": ("resignifier",),
    "resignifias": ("resignifier",),
    "resignifiassent": ("resignifier",),
    "resignifiasses": ("resignifier",),
    "resignifiasse": ("resignifier",),
    "resignifiassiez": ("resignifier",),
    "resignifiassions": ("resignifier",),
    "resignifiâtes": ("resignifier",),
    "resignifiât": ("resignifier",),
    "resignifiée": ("resignifier",),
    "resignifiées": ("resignifier",),
    "resignifié": ("resignifier",),
    "resignifient": ("resignifier",),
    "resignifie": ("resignifier",),
    "resignifiera": ("resignifier",),
    "resignifieraient": ("resignifier",),
    "resignifierai": ("resignifier",),
    "resignifierais": ("resignifier",),
    "resignifierait": ("resignifier",),
    "resignifieras": ("resignifier",),
    "resignifièrent": ("resignifier",),
    "resignifierez": ("resignifier",),
    "resignifieriez": ("resignifier",),
    "resignifierions": ("resignifier",),
    "resignifierons": ("resignifier",),
    "resignifieront": ("resignifier",),
    "resignifiés": ("resignifier",),
    "resignifies": ("resignifier",),
    "resignifiez": ("resignifier",),
    "resignifiiez": ("resignifier",),
    "resignifiions": ("resignifier",),
    "resignifions": ("resignifier",),
    "résiliaient": ("résilier",),
    "résiliai": ("résilier",),
    "résiliais": ("résilier",),
    "résiliait": ("résilier",),
    "résilia": ("résilier",),
    "résiliâmes": ("résilier",),
    "résiliant": ("résilier",),
    "résilias": ("résilier",),
    "résiliassent": ("résilier",),
    "résiliasses": ("résilier",),
    "résiliasse": ("résilier",),
    "résiliassiez": ("résilier",),
    "résiliassions": ("résilier",),
    "résiliâtes": ("résilier",),
    "résiliât": ("résilier",),
    "résiliée": ("résilier",),
    "résiliées": ("résilier",),
    "résilié": ("résilier",),
    "résilient": ("résilier",),
    "résilie": ("résilier",),
    "résiliera": ("résilier",),
    "résilieraient": ("résilier",),
    "résilierai": ("résilier",),
    "résilierais": ("résilier",),
    "résilierait": ("résilier",),
    "résilieras": ("résilier",),
    "résilièrent": ("résilier",),
    "résilierez": ("résilier",),
    "résilieriez": ("résilier",),
    "résilierions": ("résilier",),
    "résilierons": ("résilier",),
    "résilieront": ("résilier",),
    "résiliés": ("résilier",),
    "résilies": ("résilier",),
    "résiliez": ("résilier",),
    "résiliiez": ("résilier",),
    "résiliions": ("résilier",),
    "résilions": ("résilier",),
    "résinifiaient": ("résinifier",),
    "résinifiai": ("résinifier",),
    "résinifiais": ("résinifier",),
    "résinifiait": ("résinifier",),
    "résinifia": ("résinifier",),
    "résinifiâmes": ("résinifier",),
    "résinifiant": ("résinifier",),
    "résinifias": ("résinifier",),
    "résinifiassent": ("résinifier",),
    "résinifiasses": ("résinifier",),
    "résinifiasse": ("résinifier",),
    "résinifiassiez": ("résinifier",),
    "résinifiassions": ("résinifier",),
    "résinifiâtes": ("résinifier",),
    "résinifiât": ("résinifier",),
    "résinifiée": ("résinifier",),
    "résinifiées": ("résinifier",),
    "résinifié": ("résinifier",),
    "résinifient": ("résinifier",),
    "résinifie": ("résinifier",),
    "résinifiera": ("résinifier",),
    "résinifieraient": ("résinifier",),
    "résinifierai": ("résinifier",),
    "résinifierais": ("résinifier",),
    "résinifierait": ("résinifier",),
    "résinifieras": ("résinifier",),
    "résinifièrent": ("résinifier",),
    "résinifierez": ("résinifier",),
    "résinifieriez": ("résinifier",),
    "résinifierions": ("résinifier",),
    "résinifierons": ("résinifier",),
    "résinifieront": ("résinifier",),
    "résinifiés": ("résinifier",),
    "résinifies": ("résinifier",),
    "résinifiez": ("résinifier",),
    "résinifiiez": ("résinifier",),
    "résinifiions": ("résinifier",),
    "résinifions": ("résinifier",),
    "resongeaient": ("resonger",),
    "resongeai": ("resonger",),
    "resongeais": ("resonger",),
    "resongeait": ("resonger",),
    "resongea": ("resonger",),
    "resongeâmes": ("resonger",),
    "resongeant": ("resonger",),
    "resongeas": ("resonger",),
    "resongeassent": ("resonger",),
    "resongeasses": ("resonger",),
    "resongeasse": ("resonger",),
    "resongeassiez": ("resonger",),
    "resongeassions": ("resonger",),
    "resongeâtes": ("resonger",),
    "resongeât": ("resonger",),
    "resongée": ("resonger",),
    "resongées": ("resonger",),
    "resongé": ("resonger",),
    "resongent": ("resonger",),
    "resongeons": ("resonger",),
    "resonge": ("resonger",),
    "resongera": ("resonger",),
    "resongeraient": ("resonger",),
    "resongerai": ("resonger",),
    "resongerais": ("resonger",),
    "resongerait": ("resonger",),
    "resongeras": ("resonger",),
    "resongèrent": ("resonger",),
    "resongerez": ("resonger",),
    "resongeriez": ("resonger",),
    "resongerions": ("resonger",),
    "resongerons": ("resonger",),
    "resongeront": ("resonger",),
    "resongés": ("resonger",),
    "resonges": ("resonger",),
    "resongez": ("resonger",),
    "resongiez": ("resonger",),
    "resongions": ("resonger",),
    "résolue": ("résoudre",),
    "résolues": ("résoudre",),
    "résolu": ("résoudre",),
    "résolûmes": ("résoudre",),
    "résolurent": ("résoudre",),
    "résolus": ("résoudre",),
    "résolussent": ("résoudre",),
    "résolusses": ("résoudre",),
    "résolusse": ("résoudre",),
    "résolussiez": ("résoudre",),
    "résolussions": ("résoudre",),
    "résolûtes": ("résoudre",),
    "résolut": ("résoudre",),
    "résolût": ("résoudre",),
    "résolvaient": ("résoudre",),
    "résolvais": ("résoudre",),
    "résolvait": ("résoudre",),
    "résolvant": ("résoudre",),
    "résolvent": ("résoudre",),
    "résolve": ("résoudre",),
    "résolves": ("résoudre",),
    "résolvez": ("résoudre",),
    "résolviez": ("résoudre",),
    "résolvions": ("résoudre",),
    "résolvons": ("résoudre",),
    "résoudra": ("résoudre",),
    "résoudraient": ("résoudre",),
    "résoudrai": ("résoudre",),
    "résoudrais": ("résoudre",),
    "résoudrait": ("résoudre",),
    "résoudras": ("résoudre",),
    "résoudrez": ("résoudre",),
    "résoudriez": ("résoudre",),
    "résoudrions": ("résoudre",),
    "résoudrons": ("résoudre",),
    "résoudront": ("résoudre",),
    "résous": ("résoudre",),
    "résout": ("résoudre",),
    "resoulevaient": ("resoulever",),
    "resoulevai": ("resoulever",),
    "resoulevais": ("resoulever",),
    "resoulevait": ("resoulever",),
    "resouleva": ("resoulever",),
    "resoulevâmes": ("resoulever",),
    "resoulevant": ("resoulever",),
    "resoulevas": ("resoulever",),
    "resoulevassent": ("resoulever",),
    "resoulevasses": ("resoulever",),
    "resoulevasse": ("resoulever",),
    "resoulevassiez": ("resoulever",),
    "resoulevassions": ("resoulever",),
    "resoulevâtes": ("resoulever",),
    "resoulevât": ("resoulever",),
    "resoulevée": ("resoulever",),
    "resoulevées": ("resoulever",),
    "resoulevé": ("resoulever",),
    "resoulèvent": ("resoulever",),
    "resoulève": ("resoulever",),
    "resoulèvera": ("resoulever",),
    "resoulèveraient": ("resoulever",),
    "resoulèverai": ("resoulever",),
    "resoulèverais": ("resoulever",),
    "resoulèverait": ("resoulever",),
    "resoulèveras": ("resoulever",),
    "resoulevèrent": ("resoulever",),
    "resoulèverez": ("resoulever",),
    "resoulèveriez": ("resoulever",),
    "resoulèverions": ("resoulever",),
    "resoulèverons": ("resoulever",),
    "resoulèveront": ("resoulever",),
    "resoulevés": ("resoulever",),
    "resoulèves": ("resoulever",),
    "resoulevez": ("resoulever",),
    "resouleviez": ("resoulever",),
    "resoulevions": ("resoulever",),
    "resoulevons": ("resoulever",),
    "resouriaient": ("resourire",),
    "resouriais": ("resourire",),
    "resouriait": ("resourire",),
    "resouriant": ("resourire",),
    "resourient": ("resourire",),
    "resourie": ("resourire",),
    "resouries": ("resourire",),
    "resouriez": ("resourire",),
    "resouriiez": ("resourire",),
    "resouriions": ("resourire",),
    "resouri": ("resourire",),
    "resourîmes": ("resourire",),
    "resourions": ("resourire",),
    "resourira": ("resourire",),
    "resouriraient": ("resourire",),
    "resourirai": ("resourire",),
    "resourirais": ("resourire",),
    "resourirait": ("resourire",),
    "resouriras": ("resourire",),
    "resourirent": ("resourire",),
    "resourirez": ("resourire",),
    "resouririez": ("resourire",),
    "resouririons": ("resourire",),
    "resourirons": ("resourire",),
    "resouriront": ("resourire",),
    "resouris": ("resourire",),
    "resourissent": ("resourire",),
    "resourisses": ("resourire",),
    "resourisse": ("resourire",),
    "resourissiez": ("resourire",),
    "resourissions": ("resourire",),
    "resourîtes": ("resourire",),
    "resourit": ("resourire",),
    "resourît": ("resourire",),
    "resouscrira": ("resouscrire",),
    "resouscriraient": ("resouscrire",),
    "resouscrirai": ("resouscrire",),
    "resouscrirais": ("resouscrire",),
    "resouscrirait": ("resouscrire",),
    "resouscriras": ("resouscrire",),
    "resouscrirez": ("resouscrire",),
    "resouscririez": ("resouscrire",),
    "resouscririons": ("resouscrire",),
    "resouscrirons": ("resouscrire",),
    "resouscriront": ("resouscrire",),
    "resouscris": ("resouscrire",),
    "resouscrite": ("resouscrire",),
    "resouscrites": ("resouscrire",),
    "resouscrit": ("resouscrire",),
    "resouscrits": ("resouscrire",),
    "resouscrivaient": ("resouscrire",),
    "resouscrivais": ("resouscrire",),
    "resouscrivait": ("resouscrire",),
    "resouscrivant": ("resouscrire",),
    "resouscrivent": ("resouscrire",),
    "resouscrive": ("resouscrire",),
    "resouscrives": ("resouscrire",),
    "resouscrivez": ("resouscrire",),
    "resouscriviez": ("resouscrire",),
    "resouscrivîmes": ("resouscrire",),
    "resouscrivions": ("resouscrire",),
    "resouscrivirent": ("resouscrire",),
    "resouscrivis": ("resouscrire",),
    "resouscrivissent": ("resouscrire",),
    "resouscrivisses": ("resouscrire",),
    "resouscrivisse": ("resouscrire",),
    "resouscrivissiez": ("resouscrire",),
    "resouscrivissions": ("resouscrire",),
    "resouscrivîtes": ("resouscrire",),
    "resouscrivit": ("resouscrire",),
    "resouscrivît": ("resouscrire",),
    "resouscrivons": ("resouscrire",),
    "resplendi": ("resplendir",),
    "resplendîmes": ("resplendir",),
    "resplendira": ("resplendir",),
    "resplendiraient": ("resplendir",),
    "resplendirai": ("resplendir",),
    "resplendirais": ("resplendir",),
    "resplendirait": ("resplendir",),
    "resplendiras": ("resplendir",),
    "resplendirent": ("resplendir",),
    "resplendirez": ("resplendir",),
    "resplendiriez": ("resplendir",),
    "resplendirions": ("resplendir",),
    "resplendirons": ("resplendir",),
    "resplendiront": ("resplendir",),
    "resplendis": ("resplendir",),
    "resplendissaient": ("resplendir",),
    "resplendissais": ("resplendir",),
    "resplendissait": ("resplendir",),
    "resplendissant": ("resplendir",),
    "resplendissent": ("resplendir",),
    "resplendisse": ("resplendir",),
    "resplendisses": ("resplendir",),
    "resplendissez": ("resplendir",),
    "resplendissiez": ("resplendir",),
    "resplendissions": ("resplendir",),
    "resplendissons": ("resplendir",),
    "resplendîtes": ("resplendir",),
    "resplendit": ("resplendir",),
    "resplendît": ("resplendir",),
    "ressaisie": ("ressaisir",),
    "ressaisies": ("ressaisir",),
    "ressaisi": ("ressaisir",),
    "ressaisîmes": ("ressaisir",),
    "ressaisira": ("ressaisir",),
    "ressaisiraient": ("ressaisir",),
    "ressaisirai": ("ressaisir",),
    "ressaisirais": ("ressaisir",),
    "ressaisirait": ("ressaisir",),
    "ressaisiras": ("ressaisir",),
    "ressaisirent": ("ressaisir",),
    "ressaisirez": ("ressaisir",),
    "ressaisiriez": ("ressaisir",),
    "ressaisirions": ("ressaisir",),
    "ressaisirons": ("ressaisir",),
    "ressaisiront": ("ressaisir",),
    "ressaisis": ("ressaisir",),
    "ressaisissaient": ("ressaisir",),
    "ressaisissais": ("ressaisir",),
    "ressaisissait": ("ressaisir",),
    "ressaisissant": ("ressaisir",),
    "ressaisissent": ("ressaisir",),
    "ressaisisse": ("ressaisir",),
    "ressaisisses": ("ressaisir",),
    "ressaisissez": ("ressaisir",),
    "ressaisissiez": ("ressaisir",),
    "ressaisissions": ("ressaisir",),
    "ressaisissons": ("ressaisir",),
    "ressaisîtes": ("ressaisir",),
    "ressaisit": ("ressaisir",),
    "ressaisît": ("ressaisir",),
    "ressassaient": ("ressasser",),
    "ressassai": ("ressasser",),
    "ressassais": ("ressasser",),
    "ressassait": ("ressasser",),
    "ressassa": ("ressasser",),
    "ressassâmes": ("ressasser",),
    "ressassant": ("ressasser",),
    "ressassas": ("ressasser",),
    "ressassassent": ("ressasser",),
    "ressassasses": ("ressasser",),
    "ressassasse": ("ressasser",),
    "ressassassiez": ("ressasser",),
    "ressassassions": ("ressasser",),
    "ressassâtes": ("ressasser",),
    "ressassât": ("ressasser",),
    "ressassée": ("ressasser",),
    "ressassées": ("ressasser",),
    "ressassé": ("ressasser",),
    "ressassent": ("ressasser",),
    "ressasse": ("ressasser",),
    "ressassera": ("ressasser",),
    "ressasseraient": ("ressasser",),
    "ressasserai": ("ressasser",),
    "ressasserais": ("ressasser",),
    "ressasserait": ("ressasser",),
    "ressasseras": ("ressasser",),
    "ressassèrent": ("ressasser",),
    "ressasserez": ("ressasser",),
    "ressasseriez": ("ressasser",),
    "ressasserions": ("ressasser",),
    "ressasserons": ("ressasser",),
    "ressasseront": ("ressasser",),
    "ressassés": ("ressasser",),
    "ressasses": ("ressasser",),
    "ressassez": ("ressasser",),
    "ressassiez": ("ressasser",),
    "ressassions": ("ressasser",),
    "ressassons": ("ressasser",),
    "ressaient": ("ressayer",),
    "ressaie": ("ressayer",),
    "ressaiera": ("ressayer",),
    "ressaieraient": ("ressayer",),
    "ressaierai": ("ressayer",),
    "ressaierais": ("ressayer",),
    "ressaierait": ("ressayer",),
    "ressaieras": ("ressayer",),
    "ressaierez": ("ressayer",),
    "ressaieriez": ("ressayer",),
    "ressaierions": ("ressayer",),
    "ressaierons": ("ressayer",),
    "ressaieront": ("ressayer",),
    "ressaies": ("ressayer",),
    "ressayaient": ("ressayer",),
    "ressayai": ("ressayer",),
    "ressayais": ("ressayer",),
    "ressayait": ("ressayer",),
    "ressaya": ("ressayer",),
    "ressayâmes": ("ressayer",),
    "ressayant": ("ressayer",),
    "ressayas": ("ressayer",),
    "ressayassent": ("ressayer",),
    "ressayasses": ("ressayer",),
    "ressayasse": ("ressayer",),
    "ressayassiez": ("ressayer",),
    "ressayassions": ("ressayer",),
    "ressayâtes": ("ressayer",),
    "ressayât": ("ressayer",),
    "ressayée": ("ressayer",),
    "ressayées": ("ressayer",),
    "ressayé": ("ressayer",),
    "ressayent": ("ressayer",),
    "ressaye": ("ressayer",),
    "ressayera": ("ressayer",),
    "ressayeraient": ("ressayer",),
    "ressayerai": ("ressayer",),
    "ressayerais": ("ressayer",),
    "ressayerait": ("ressayer",),
    "ressayeras": ("ressayer",),
    "ressayèrent": ("ressayer",),
    "ressayerez": ("ressayer",),
    "ressayeriez": ("ressayer",),
    "ressayerions": ("ressayer",),
    "ressayerons": ("ressayer",),
    "ressayeront": ("ressayer",),
    "ressayés": ("ressayer",),
    "ressayes": ("ressayer",),
    "ressayez": ("ressayer",),
    "ressayiez": ("ressayer",),
    "ressayions": ("ressayer",),
    "ressayons": ("ressayer",),
    "ressemelaient": ("ressemeler",),
    "ressemelai": ("ressemeler",),
    "ressemelais": ("ressemeler",),
    "ressemelait": ("ressemeler",),
    "ressemela": ("ressemeler",),
    "ressemelâmes": ("ressemeler",),
    "ressemelant": ("ressemeler",),
    "ressemelas": ("ressemeler",),
    "ressemelassent": ("ressemeler",),
    "ressemelasses": ("ressemeler",),
    "ressemelasse": ("ressemeler",),
    "ressemelassiez": ("ressemeler",),
    "ressemelassions": ("ressemeler",),
    "ressemelâtes": ("ressemeler",),
    "ressemelât": ("ressemeler",),
    "ressemelée": ("ressemeler",),
    "ressemelées": ("ressemeler",),
    "ressemelé": ("ressemeler",),
    "ressemelèrent": ("ressemeler",),
    "ressemelés": ("ressemeler",),
    "ressemelez": ("ressemeler",),
    "ressemeliez": ("ressemeler",),
    "ressemelions": ("ressemeler",),
    "ressemellent": ("ressemeler",),
    "ressemelle": ("ressemeler",),
    "ressemellera": ("ressemeler",),
    "ressemelleraient": ("ressemeler",),
    "ressemellerai": ("ressemeler",),
    "ressemellerais": ("ressemeler",),
    "ressemellerait": ("ressemeler",),
    "ressemelleras": ("ressemeler",),
    "ressemellerez": ("ressemeler",),
    "ressemelleriez": ("ressemeler",),
    "ressemellerions": ("ressemeler",),
    "ressemellerons": ("ressemeler",),
    "ressemelleront": ("ressemeler",),
    "ressemelles": ("ressemeler",),
    "ressemelons": ("ressemeler",),
    "ressemaient": ("ressemer",),
    "ressemai": ("ressemer",),
    "ressemais": ("ressemer",),
    "ressemait": ("ressemer",),
    "ressema": ("ressemer",),
    "ressemâmes": ("ressemer",),
    "ressemant": ("ressemer",),
    "ressemas": ("ressemer",),
    "ressemassent": ("ressemer",),
    "ressemasses": ("ressemer",),
    "ressemasse": ("ressemer",),
    "ressemassiez": ("ressemer",),
    "ressemassions": ("ressemer",),
    "ressemâtes": ("ressemer",),
    "ressemât": ("ressemer",),
    "ressemée": ("ressemer",),
    "ressemées": ("ressemer",),
    "ressemé": ("ressemer",),
    "ressèment": ("ressemer",),
    "ressème": ("ressemer",),
    "ressèmera": ("ressemer",),
    "ressèmeraient": ("ressemer",),
    "ressèmerai": ("ressemer",),
    "ressèmerais": ("ressemer",),
    "ressèmerait": ("ressemer",),
    "ressèmeras": ("ressemer",),
    "ressemèrent": ("ressemer",),
    "ressèmerez": ("ressemer",),
    "ressèmeriez": ("ressemer",),
    "ressèmerions": ("ressemer",),
    "ressèmerons": ("ressemer",),
    "ressèmeront": ("ressemer",),
    "ressemés": ("ressemer",),
    "ressèmes": ("ressemer",),
    "ressemez": ("ressemer",),
    "ressemiez": ("ressemer",),
    "ressemions": ("ressemer",),
    "ressemons": ("ressemer",),
    "ressens": ("ressentir",),
    "ressentaient": ("ressentir",),
    "ressentais": ("ressentir",),
    "ressentait": ("ressentir",),
    "ressentant": ("ressentir",),
    "ressentent": ("ressentir",),
    "ressente": ("ressentir",),
    "ressentes": ("ressentir",),
    "ressentez": ("ressentir",),
    "ressentie": ("ressentir",),
    "ressenties": ("ressentir",),
    "ressentiez": ("ressentir",),
    "ressenti": ("ressentir",),
    "ressentîmes": ("ressentir",),
    "ressentions": ("ressentir",),
    "ressentira": ("ressentir",),
    "ressentiraient": ("ressentir",),
    "ressentirai": ("ressentir",),
    "ressentirais": ("ressentir",),
    "ressentirait": ("ressentir",),
    "ressentiras": ("ressentir",),
    "ressentirent": ("ressentir",),
    "ressentirez": ("ressentir",),
    "ressentiriez": ("ressentir",),
    "ressentirions": ("ressentir",),
    "ressentirons": ("ressentir",),
    "ressentiront": ("ressentir",),
    "ressentis": ("ressentir",),
    "ressentissent": ("ressentir",),
    "ressentisses": ("ressentir",),
    "ressentisse": ("ressentir",),
    "ressentissiez": ("ressentir",),
    "ressentissions": ("ressentir",),
    "ressentîtes": ("ressentir",),
    "ressentit": ("ressentir",),
    "ressentît": ("ressentir",),
    "ressentons": ("ressentir",),
    "ressent": ("ressentir",),
    "ressers": ("resservir",),
    "ressert": ("resservir",),
    "resservaient": ("resservir",),
    "resservais": ("resservir",),
    "resservait": ("resservir",),
    "resservant": ("resservir",),
    "resservent": ("resservir",),
    "resserve": ("resservir",),
    "resserves": ("resservir",),
    "resservez": ("resservir",),
    "resservie": ("resservir",),
    "resservies": ("resservir",),
    "resserviez": ("resservir",),
    "resservi": ("resservir",),
    "resservîmes": ("resservir",),
    "resservions": ("resservir",),
    "resservira": ("resservir",),
    "resserviraient": ("resservir",),
    "resservirai": ("resservir",),
    "resservirais": ("resservir",),
    "resservirait": ("resservir",),
    "resserviras": ("resservir",),
    "resservirent": ("resservir",),
    "resservirez": ("resservir",),
    "resserviriez": ("resservir",),
    "resservirions": ("resservir",),
    "resservirons": ("resservir",),
    "resserviront": ("resservir",),
    "resservis": ("resservir",),
    "resservissent": ("resservir",),
    "resservisses": ("resservir",),
    "resservisse": ("resservir",),
    "resservissiez": ("resservir",),
    "resservissions": ("resservir",),
    "resservîtes": ("resservir",),
    "resservit": ("resservir",),
    "resservît": ("resservir",),
    "resservons": ("resservir",),
    "ressors": ("ressortir",),
    "ressortaient": ("ressortir",),
    "ressortais": ("ressortir",),
    "ressortait": ("ressortir",),
    "ressortant": ("ressortir",),
    "ressortent": ("ressortir",),
    "ressorte": ("ressortir",),
    "ressortes": ("ressortir",),
    "ressortez": ("ressortir",),
    "ressortie": ("ressortir",),
    "ressorties": ("ressortir",),
    "ressortiez": ("ressortir",),
    "ressorti": ("ressortir",),
    "ressortîmes": ("ressortir",),
    "ressortions": ("ressortir",),
    "ressortira": ("ressortir",),
    "ressortiraient": ("ressortir",),
    "ressortirai": ("ressortir",),
    "ressortirais": ("ressortir",),
    "ressortirait": ("ressortir",),
    "ressortiras": ("ressortir",),
    "ressortirent": ("ressortir",),
    "ressortirez": ("ressortir",),
    "ressortiriez": ("ressortir",),
    "ressortirions": ("ressortir",),
    "ressortirons": ("ressortir",),
    "ressortiront": ("ressortir",),
    "ressortis": ("ressortir",),
    "ressortissaient": ("ressortir",),
    "ressortissais": ("ressortir",),
    "ressortissait": ("ressortir",),
    "ressortissant": ("ressortir",),
    "ressortissent": ("ressortir",),
    "ressortisse": ("ressortir",),
    "ressortisses": ("ressortir",),
    "ressortissez": ("ressortir",),
    "ressortissiez": ("ressortir",),
    "ressortissions": ("ressortir",),
    "ressortissons": ("ressortir",),
    "ressortîtes": ("ressortir",),
    "ressortit": ("ressortir",),
    "ressortît": ("ressortir",),
    "ressortons": ("ressortir",),
    "ressort": ("ressortir",),
    "ressourçaient": ("ressourcer",),
    "ressourçai": ("ressourcer",),
    "ressourçais": ("ressourcer",),
    "ressourçait": ("ressourcer",),
    "ressourça": ("ressourcer",),
    "ressourçâmes": ("ressourcer",),
    "ressourçant": ("ressourcer",),
    "ressourças": ("ressourcer",),
    "ressourçassent": ("ressourcer",),
    "ressourçasses": ("ressourcer",),
    "ressourçasse": ("ressourcer",),
    "ressourçassiez": ("ressourcer",),
    "ressourçassions": ("ressourcer",),
    "ressourçâtes": ("ressourcer",),
    "ressourçât": ("ressourcer",),
    "ressourcée": ("ressourcer",),
    "ressourcées": ("ressourcer",),
    "ressourcé": ("ressourcer",),
    "ressourcent": ("ressourcer",),
    "ressource": ("ressourcer",),
    "ressourcera": ("ressourcer",),
    "ressourceraient": ("ressourcer",),
    "ressourcerai": ("ressourcer",),
    "ressourcerais": ("ressourcer",),
    "ressourcerait": ("ressourcer",),
    "ressourceras": ("ressourcer",),
    "ressourcèrent": ("ressourcer",),
    "ressourcerez": ("ressourcer",),
    "ressourceriez": ("ressourcer",),
    "ressourcerions": ("ressourcer",),
    "ressourcerons": ("ressourcer",),
    "ressourceront": ("ressourcer",),
    "ressourcés": ("ressourcer",),
    "ressources": ("ressourcer",),
    "ressourcez": ("ressourcer",),
    "ressourciez": ("ressourcer",),
    "ressourcions": ("ressourcer",),
    "ressourçons": ("ressourcer",),
    "ressouvenaient": ("ressouvenir",),
    "ressouvenais": ("ressouvenir",),
    "ressouvenait": ("ressouvenir",),
    "ressouvenant": ("ressouvenir",),
    "ressouvenez": ("ressouvenir",),
    "ressouveniez": ("ressouvenir",),
    "ressouvenions": ("ressouvenir",),
    "ressouvenons": ("ressouvenir",),
    "ressouvenue": ("ressouvenir",),
    "ressouvenues": ("ressouvenir",),
    "ressouvenu": ("ressouvenir",),
    "ressouvenus": ("ressouvenir",),
    "ressouviendra": ("ressouvenir",),
    "ressouviendraient": ("ressouvenir",),
    "ressouviendrai": ("ressouvenir",),
    "ressouviendrais": ("ressouvenir",),
    "ressouviendrait": ("ressouvenir",),
    "ressouviendras": ("ressouvenir",),
    "ressouviendrez": ("ressouvenir",),
    "ressouviendriez": ("ressouvenir",),
    "ressouviendrions": ("ressouvenir",),
    "ressouviendrons": ("ressouvenir",),
    "ressouviendront": ("ressouvenir",),
    "ressouviennent": ("ressouvenir",),
    "ressouvienne": ("ressouvenir",),
    "ressouviennes": ("ressouvenir",),
    "ressouviens": ("ressouvenir",),
    "ressouvient": ("ressouvenir",),
    "ressouvînmes": ("ressouvenir",),
    "ressouvinrent": ("ressouvenir",),
    "ressouvins": ("ressouvenir",),
    "ressouvinssent": ("ressouvenir",),
    "ressouvinsses": ("ressouvenir",),
    "ressouvinsse": ("ressouvenir",),
    "ressouvinssiez": ("ressouvenir",),
    "ressouvinssions": ("ressouvenir",),
    "ressouvîntes": ("ressouvenir",),
    "ressouvint": ("ressouvenir",),
    "ressouvînt": ("ressouvenir",),
    "ressurgie": ("ressurgir",),
    "ressurgies": ("ressurgir",),
    "ressurgi": ("ressurgir",),
    "ressurgîmes": ("ressurgir",),
    "ressurgira": ("ressurgir",),
    "ressurgiraient": ("ressurgir",),
    "ressurgirai": ("ressurgir",),
    "ressurgirais": ("ressurgir",),
    "ressurgirait": ("ressurgir",),
    "ressurgiras": ("ressurgir",),
    "ressurgirent": ("ressurgir",),
    "ressurgirez": ("ressurgir",),
    "ressurgiriez": ("ressurgir",),
    "ressurgirions": ("ressurgir",),
    "ressurgirons": ("ressurgir",),
    "ressurgiront": ("ressurgir",),
    "ressurgis": ("ressurgir",),
    "ressurgissaient": ("ressurgir",),
    "ressurgissais": ("ressurgir",),
    "ressurgissait": ("ressurgir",),
    "ressurgissant": ("ressurgir",),
    "ressurgissent": ("ressurgir",),
    "ressurgisse": ("ressurgir",),
    "ressurgisses": ("ressurgir",),
    "ressurgissez": ("ressurgir",),
    "ressurgissiez": ("ressurgir",),
    "ressurgissions": ("ressurgir",),
    "ressurgissons": ("ressurgir",),
    "ressurgîtes": ("ressurgir",),
    "ressurgit": ("ressurgir",),
    "ressurgît": ("ressurgir",),
    "ressuient": ("ressuyer",),
    "ressuie": ("ressuyer",),
    "ressuiera": ("ressuyer",),
    "ressuieraient": ("ressuyer",),
    "ressuierai": ("ressuyer",),
    "ressuierais": ("ressuyer",),
    "ressuierait": ("ressuyer",),
    "ressuieras": ("ressuyer",),
    "ressuierez": ("ressuyer",),
    "ressuieriez": ("ressuyer",),
    "ressuierions": ("ressuyer",),
    "ressuierons": ("ressuyer",),
    "ressuieront": ("ressuyer",),
    "ressuies": ("ressuyer",),
    "ressuyaient": ("ressuyer",),
    "ressuyai": ("ressuyer",),
    "ressuyais": ("ressuyer",),
    "ressuyait": ("ressuyer",),
    "ressuya": ("ressuyer",),
    "ressuyâmes": ("ressuyer",),
    "ressuyant": ("ressuyer",),
    "ressuyas": ("ressuyer",),
    "ressuyassent": ("ressuyer",),
    "ressuyasses": ("ressuyer",),
    "ressuyasse": ("ressuyer",),
    "ressuyassiez": ("ressuyer",),
    "ressuyassions": ("ressuyer",),
    "ressuyâtes": ("ressuyer",),
    "ressuyât": ("ressuyer",),
    "ressuyée": ("ressuyer",),
    "ressuyées": ("ressuyer",),
    "ressuyé": ("ressuyer",),
    "ressuyèrent": ("ressuyer",),
    "ressuyés": ("ressuyer",),
    "ressuyez": ("ressuyer",),
    "ressuyiez": ("ressuyer",),
    "ressuyions": ("ressuyer",),
    "ressuyons": ("ressuyer",),
    "restreignaient": ("restreindre",),
    "restreignais": ("restreindre",),
    "restreignait": ("restreindre",),
    "restreignant": ("restreindre",),
    "restreignent": ("restreindre",),
    "restreigne": ("restreindre",),
    "restreignes": ("restreindre",),
    "restreignez": ("restreindre",),
    "restreigniez": ("restreindre",),
    "restreignîmes": ("restreindre",),
    "restreignions": ("restreindre",),
    "restreignirent": ("restreindre",),
    "restreignis": ("restreindre",),
    "restreignissent": ("restreindre",),
    "restreignisses": ("restreindre",),
    "restreignisse": ("restreindre",),
    "restreignissiez": ("restreindre",),
    "restreignissions": ("restreindre",),
    "restreignîtes": ("restreindre",),
    "restreignit": ("restreindre",),
    "restreignît": ("restreindre",),
    "restreignons": ("restreindre",),
    "restreindra": ("restreindre",),
    "restreindraient": ("restreindre",),
    "restreindrai": ("restreindre",),
    "restreindrais": ("restreindre",),
    "restreindrait": ("restreindre",),
    "restreindras": ("restreindre",),
    "restreindrez": ("restreindre",),
    "restreindriez": ("restreindre",),
    "restreindrions": ("restreindre",),
    "restreindrons": ("restreindre",),
    "restreindront": ("restreindre",),
    "restreins": ("restreindre",),
    "restreinte": ("restreindre",),
    "restreintes": ("restreindre",),
    "restreint": ("restreindre",),
    "restreints": ("restreindre",),
    "resuçaient": ("resucer",),
    "resuçai": ("resucer",),
    "resuçais": ("resucer",),
    "resuçait": ("resucer",),
    "resuça": ("resucer",),
    "resuçâmes": ("resucer",),
    "resuçant": ("resucer",),
    "resuças": ("resucer",),
    "resuçassent": ("resucer",),
    "resuçasses": ("resucer",),
    "resuçasse": ("resucer",),
    "resuçassiez": ("resucer",),
    "resuçassions": ("resucer",),
    "resuçâtes": ("resucer",),
    "resuçât": ("resucer",),
    "resucée": ("resucer",),
    "resucées": ("resucer",),
    "resucé": ("resucer",),
    "resucent": ("resucer",),
    "resuce": ("resucer",),
    "resucera": ("resucer",),
    "resuceraient": ("resucer",),
    "resucerai": ("resucer",),
    "resucerais": ("resucer",),
    "resucerait": ("resucer",),
    "resuceras": ("resucer",),
    "resucèrent": ("resucer",),
    "resucerez": ("resucer",),
    "resuceriez": ("resucer",),
    "resucerions": ("resucer",),
    "resucerons": ("resucer",),
    "resuceront": ("resucer",),
    "resucés": ("resucer",),
    "resuces": ("resucer",),
    "resucez": ("resucer",),
    "resuciez": ("resucer",),
    "resucions": ("resucer",),
    "resuçons": ("resucer",),
    "resuis": ("resuivre",),
    "resuit": ("resuivre",),
    "resuivaient": ("resuivre",),
    "resuivais": ("resuivre",),
    "resuivait": ("resuivre",),
    "resuivant": ("resuivre",),
    "resuivent": ("resuivre",),
    "resuive": ("resuivre",),
    "resuives": ("resuivre",),
    "resuivez": ("resuivre",),
    "resuivie": ("resuivre",),
    "resuivies": ("resuivre",),
    "resuiviez": ("resuivre",),
    "resuivi": ("resuivre",),
    "resuivîmes": ("resuivre",),
    "resuivions": ("resuivre",),
    "resuivirent": ("resuivre",),
    "resuivis": ("resuivre",),
    "resuivissent": ("resuivre",),
    "resuivisses": ("resuivre",),
    "resuivisse": ("resuivre",),
    "resuivissiez": ("resuivre",),
    "resuivissions": ("resuivre",),
    "resuivîtes": ("resuivre",),
    "resuivit": ("resuivre",),
    "resuivît": ("resuivre",),
    "resuivons": ("resuivre",),
    "resuivra": ("resuivre",),
    "resuivraient": ("resuivre",),
    "resuivrai": ("resuivre",),
    "resuivrais": ("resuivre",),
    "resuivrait": ("resuivre",),
    "resuivras": ("resuivre",),
    "resuivrez": ("resuivre",),
    "resuivriez": ("resuivre",),
    "resuivrions": ("resuivre",),
    "resuivrons": ("resuivre",),
    "resuivront": ("resuivre",),
    "resuppliaient": ("resupplier",),
    "resuppliai": ("resupplier",),
    "resuppliais": ("resupplier",),
    "resuppliait": ("resupplier",),
    "resupplia": ("resupplier",),
    "resuppliâmes": ("resupplier",),
    "resuppliant": ("resupplier",),
    "resupplias": ("resupplier",),
    "resuppliassent": ("resupplier",),
    "resuppliasses": ("resupplier",),
    "resuppliasse": ("resupplier",),
    "resuppliassiez": ("resupplier",),
    "resuppliassions": ("resupplier",),
    "resuppliâtes": ("resupplier",),
    "resuppliât": ("resupplier",),
    "resuppliée": ("resupplier",),
    "resuppliées": ("resupplier",),
    "resupplié": ("resupplier",),
    "resupplient": ("resupplier",),
    "resupplie": ("resupplier",),
    "resuppliera": ("resupplier",),
    "resupplieraient": ("resupplier",),
    "resupplierai": ("resupplier",),
    "resupplierais": ("resupplier",),
    "resupplierait": ("resupplier",),
    "resupplieras": ("resupplier",),
    "resupplièrent": ("resupplier",),
    "resupplierez": ("resupplier",),
    "resupplieriez": ("resupplier",),
    "resupplierions": ("resupplier",),
    "resupplierons": ("resupplier",),
    "resupplieront": ("resupplier",),
    "resuppliés": ("resupplier",),
    "resupplies": ("resupplier",),
    "resuppliez": ("resupplier",),
    "resuppliiez": ("resupplier",),
    "resuppliions": ("resupplier",),
    "resupplions": ("resupplier",),
    "resurfaçaient": ("resurfacer",),
    "resurfaçai": ("resurfacer",),
    "resurfaçais": ("resurfacer",),
    "resurfaçait": ("resurfacer",),
    "resurfaça": ("resurfacer",),
    "resurfaçâmes": ("resurfacer",),
    "resurfaçant": ("resurfacer",),
    "resurfaças": ("resurfacer",),
    "resurfaçassent": ("resurfacer",),
    "resurfaçasses": ("resurfacer",),
    "resurfaçasse": ("resurfacer",),
    "resurfaçassiez": ("resurfacer",),
    "resurfaçassions": ("resurfacer",),
    "resurfaçâtes": ("resurfacer",),
    "resurfaçât": ("resurfacer",),
    "resurfacée": ("resurfacer",),
    "resurfacées": ("resurfacer",),
    "resurfacé": ("resurfacer",),
    "resurfacent": ("resurfacer",),
    "resurface": ("resurfacer",),
    "resurfacera": ("resurfacer",),
    "resurfaceraient": ("resurfacer",),
    "resurfacerai": ("resurfacer",),
    "resurfacerais": ("resurfacer",),
    "resurfacerait": ("resurfacer",),
    "resurfaceras": ("resurfacer",),
    "resurfacèrent": ("resurfacer",),
    "resurfacerez": ("resurfacer",),
    "resurfaceriez": ("resurfacer",),
    "resurfacerions": ("resurfacer",),
    "resurfacerons": ("resurfacer",),
    "resurfaceront": ("resurfacer",),
    "resurfacés": ("resurfacer",),
    "resurfaces": ("resurfacer",),
    "resurfacez": ("resurfacer",),
    "resurfaciez": ("resurfacer",),
    "resurfacions": ("resurfacer",),
    "resurfaçons": ("resurfacer",),
    "résurgeaient": ("résurger",),
    "résurgeai": ("résurger",),
    "résurgeais": ("résurger",),
    "résurgeait": ("résurger",),
    "résurgea": ("résurger",),
    "résurgeâmes": ("résurger",),
    "résurgeant": ("résurger",),
    "résurgeas": ("résurger",),
    "résurgeassent": ("résurger",),
    "résurgeasses": ("résurger",),
    "résurgeasse": ("résurger",),
    "résurgeassiez": ("résurger",),
    "résurgeassions": ("résurger",),
    "résurgeâtes": ("résurger",),
    "résurgeât": ("résurger",),
    "résurgée": ("résurger",),
    "résurgées": ("résurger",),
    "résurgé": ("résurger",),
    "résurgent": ("résurger",),
    "résurgeons": ("résurger",),
    "résurge": ("résurger",),
    "résurgera": ("résurger",),
    "résurgeraient": ("résurger",),
    "résurgerai": ("résurger",),
    "résurgerais": ("résurger",),
    "résurgerait": ("résurger",),
    "résurgeras": ("résurger",),
    "résurgèrent": ("résurger",),
    "résurgerez": ("résurger",),
    "résurgeriez": ("résurger",),
    "résurgerions": ("résurger",),
    "résurgerons": ("résurger",),
    "résurgeront": ("résurger",),
    "résurgés": ("résurger",),
    "résurges": ("résurger",),
    "résurgez": ("résurger",),
    "résurgiez": ("résurger",),
    "résurgions": ("résurger",),
    "resurgie": ("resurgir",),
    "resurgies": ("resurgir",),
    "resurgi": ("resurgir",),
    "resurgîmes": ("resurgir",),
    "resurgira": ("resurgir",),
    "resurgiraient": ("resurgir",),
    "resurgirai": ("resurgir",),
    "resurgirais": ("resurgir",),
    "resurgirait": ("resurgir",),
    "resurgiras": ("resurgir",),
    "resurgirent": ("resurgir",),
    "resurgirez": ("resurgir",),
    "resurgiriez": ("resurgir",),
    "resurgirions": ("resurgir",),
    "resurgirons": ("resurgir",),
    "resurgiront": ("resurgir",),
    "resurgis": ("resurgir",),
    "resurgissaient": ("resurgir",),
    "resurgissais": ("resurgir",),
    "resurgissait": ("resurgir",),
    "resurgissant": ("resurgir",),
    "resurgissent": ("resurgir",),
    "resurgisse": ("resurgir",),
    "resurgisses": ("resurgir",),
    "resurgissez": ("resurgir",),
    "resurgissiez": ("resurgir",),
    "resurgissions": ("resurgir",),
    "resurgissons": ("resurgir",),
    "resurgîtes": ("resurgir",),
    "resurgit": ("resurgir",),
    "resurgît": ("resurgir",),
    "rétablie": ("rétablir",),
    "rétablies": ("rétablir",),
    "rétabli": ("rétablir",),
    "rétablîmes": ("rétablir",),
    "rétablira": ("rétablir",),
    "rétabliraient": ("rétablir",),
    "rétablirai": ("rétablir",),
    "rétablirais": ("rétablir",),
    "rétablirait": ("rétablir",),
    "rétabliras": ("rétablir",),
    "rétablirent": ("rétablir",),
    "rétablirez": ("rétablir",),
    "rétabliriez": ("rétablir",),
    "rétablirions": ("rétablir",),
    "rétablirons": ("rétablir",),
    "rétabliront": ("rétablir",),
    "rétablis": ("rétablir",),
    "rétablissaient": ("rétablir",),
    "rétablissais": ("rétablir",),
    "rétablissait": ("rétablir",),
    "rétablissant": ("rétablir",),
    "rétablissent": ("rétablir",),
    "rétablisse": ("rétablir",),
    "rétablisses": ("rétablir",),
    "rétablissez": ("rétablir",),
    "rétablissiez": ("rétablir",),
    "rétablissions": ("rétablir",),
    "rétablissons": ("rétablir",),
    "rétablîtes": ("rétablir",),
    "rétablit": ("rétablir",),
    "rétablît": ("rétablir",),
    "retançaient": ("retancer",),
    "retançai": ("retancer",),
    "retançais": ("retancer",),
    "retançait": ("retancer",),
    "retança": ("retancer",),
    "retançâmes": ("retancer",),
    "retançant": ("retancer",),
    "retanças": ("retancer",),
    "retançassent": ("retancer",),
    "retançasses": ("retancer",),
    "retançasse": ("retancer",),
    "retançassiez": ("retancer",),
    "retançassions": ("retancer",),
    "retançâtes": ("retancer",),
    "retançât": ("retancer",),
    "retancée": ("retancer",),
    "retancées": ("retancer",),
    "retancé": ("retancer",),
    "retancent": ("retancer",),
    "retance": ("retancer",),
    "retancera": ("retancer",),
    "retanceraient": ("retancer",),
    "retancerai": ("retancer",),
    "retancerais": ("retancer",),
    "retancerait": ("retancer",),
    "retanceras": ("retancer",),
    "retancèrent": ("retancer",),
    "retancerez": ("retancer",),
    "retanceriez": ("retancer",),
    "retancerions": ("retancer",),
    "retancerons": ("retancer",),
    "retanceront": ("retancer",),
    "retancés": ("retancer",),
    "retances": ("retancer",),
    "retancez": ("retancer",),
    "retanciez": ("retancer",),
    "retancions": ("retancer",),
    "retançons": ("retancer",),
    "retassaient": ("retasser",),
    "retassai": ("retasser",),
    "retassais": ("retasser",),
    "retassait": ("retasser",),
    "retassa": ("retasser",),
    "retassâmes": ("retasser",),
    "retassant": ("retasser",),
    "retassas": ("retasser",),
    "retassassent": ("retasser",),
    "retassasses": ("retasser",),
    "retassasse": ("retasser",),
    "retassassiez": ("retasser",),
    "retassassions": ("retasser",),
    "retassâtes": ("retasser",),
    "retassât": ("retasser",),
    "retassée": ("retasser",),
    "retassées": ("retasser",),
    "retassé": ("retasser",),
    "retassent": ("retasser",),
    "retasse": ("retasser",),
    "retassera": ("retasser",),
    "retasseraient": ("retasser",),
    "retasserai": ("retasser",),
    "retasserais": ("retasser",),
    "retasserait": ("retasser",),
    "retasseras": ("retasser",),
    "retassèrent": ("retasser",),
    "retasserez": ("retasser",),
    "retasseriez": ("retasser",),
    "retasserions": ("retasser",),
    "retasserons": ("retasser",),
    "retasseront": ("retasser",),
    "retassés": ("retasser",),
    "retasses": ("retasser",),
    "retassez": ("retasser",),
    "retassiez": ("retasser",),
    "retassions": ("retasser",),
    "retassons": ("retasser",),
    "retâtaient": ("retâter",),
    "retâtai": ("retâter",),
    "retâtais": ("retâter",),
    "retâtait": ("retâter",),
    "retâta": ("retâter",),
    "retâtâmes": ("retâter",),
    "retâtant": ("retâter",),
    "retâtas": ("retâter",),
    "retâtassent": ("retâter",),
    "retâtasses": ("retâter",),
    "retâtasse": ("retâter",),
    "retâtassiez": ("retâter",),
    "retâtassions": ("retâter",),
    "retâtâtes": ("retâter",),
    "retâtât": ("retâter",),
    "retâtée": ("retâter",),
    "retâtées": ("retâter",),
    "retâté": ("retâter",),
    "retâtent": ("retâter",),
    "retâte": ("retâter",),
    "retâtera": ("retâter",),
    "retâteraient": ("retâter",),
    "retâterai": ("retâter",),
    "retâterais": ("retâter",),
    "retâterait": ("retâter",),
    "retâteras": ("retâter",),
    "retâtèrent": ("retâter",),
    "retâterez": ("retâter",),
    "retâteriez": ("retâter",),
    "retâterions": ("retâter",),
    "retâterons": ("retâter",),
    "retâteront": ("retâter",),
    "retâtés": ("retâter",),
    "retâtes": ("retâter",),
    "retâtez": ("retâter",),
    "retâtiez": ("retâter",),
    "retâtions": ("retâter",),
    "retâtons": ("retâter",),
    "reteignaient": ("reteindre",),
    "reteignais": ("reteindre",),
    "reteignait": ("reteindre",),
    "reteignant": ("reteindre",),
    "reteignent": ("reteindre",),
    "reteigne": ("reteindre",),
    "reteignes": ("reteindre",),
    "reteignez": ("reteindre",),
    "reteigniez": ("reteindre",),
    "reteignîmes": ("reteindre",),
    "reteignions": ("reteindre",),
    "reteignirent": ("reteindre",),
    "reteignis": ("reteindre",),
    "reteignissent": ("reteindre",),
    "reteignisses": ("reteindre",),
    "reteignisse": ("reteindre",),
    "reteignissiez": ("reteindre",),
    "reteignissions": ("reteindre",),
    "reteignîtes": ("reteindre",),
    "reteignit": ("reteindre",),
    "reteignît": ("reteindre",),
    "reteignons": ("reteindre",),
    "reteindra": ("reteindre",),
    "reteindraient": ("reteindre",),
    "reteindrai": ("reteindre",),
    "reteindrais": ("reteindre",),
    "reteindrait": ("reteindre",),
    "reteindras": ("reteindre",),
    "reteindrez": ("reteindre",),
    "reteindriez": ("reteindre",),
    "reteindrions": ("reteindre",),
    "reteindrons": ("reteindre",),
    "reteindront": ("reteindre",),
    "reteins": ("reteindre",),
    "reteinte": ("reteindre",),
    "reteintes": ("reteindre",),
    "reteint": ("reteindre",),
    "reteints": ("reteindre",),
    "retélégraphiaient": ("retélégraphier",),
    "retélégraphiai": ("retélégraphier",),
    "retélégraphiais": ("retélégraphier",),
    "retélégraphiait": ("retélégraphier",),
    "retélégraphia": ("retélégraphier",),
    "retélégraphiâmes": ("retélégraphier",),
    "retélégraphiant": ("retélégraphier",),
    "retélégraphias": ("retélégraphier",),
    "retélégraphiassent": ("retélégraphier",),
    "retélégraphiasses": ("retélégraphier",),
    "retélégraphiasse": ("retélégraphier",),
    "retélégraphiassiez": ("retélégraphier",),
    "retélégraphiassions": ("retélégraphier",),
    "retélégraphiâtes": ("retélégraphier",),
    "retélégraphiât": ("retélégraphier",),
    "retélégraphiée": ("retélégraphier",),
    "retélégraphiées": ("retélégraphier",),
    "retélégraphié": ("retélégraphier",),
    "retélégraphient": ("retélégraphier",),
    "retélégraphie": ("retélégraphier",),
    "retélégraphiera": ("retélégraphier",),
    "retélégraphieraient": ("retélégraphier",),
    "retélégraphierai": ("retélégraphier",),
    "retélégraphierais": ("retélégraphier",),
    "retélégraphierait": ("retélégraphier",),
    "retélégraphieras": ("retélégraphier",),
    "retélégraphièrent": ("retélégraphier",),
    "retélégraphierez": ("retélégraphier",),
    "retélégraphieriez": ("retélégraphier",),
    "retélégraphierions": ("retélégraphier",),
    "retélégraphierons": ("retélégraphier",),
    "retélégraphieront": ("retélégraphier",),
    "retélégraphiés": ("retélégraphier",),
    "retélégraphies": ("retélégraphier",),
    "retélégraphiez": ("retélégraphier",),
    "retélégraphiiez": ("retélégraphier",),
    "retélégraphiions": ("retélégraphier",),
    "retélégraphions": ("retélégraphier",),
    "retendaient": ("retendre",),
    "retendais": ("retendre",),
    "retendait": ("retendre",),
    "retendant": ("retendre",),
    "retendent": ("retendre",),
    "retende": ("retendre",),
    "retendes": ("retendre",),
    "retendez": ("retendre",),
    "retendiez": ("retendre",),
    "retendîmes": ("retendre",),
    "retendions": ("retendre",),
    "retendirent": ("retendre",),
    "retendis": ("retendre",),
    "retendissent": ("retendre",),
    "retendisses": ("retendre",),
    "retendisse": ("retendre",),
    "retendissiez": ("retendre",),
    "retendissions": ("retendre",),
    "retendîtes": ("retendre",),
    "retendit": ("retendre",),
    "retendît": ("retendre",),
    "retendons": ("retendre",),
    "retend": ("retendre",),
    "retendra": ("retendre",),
    "retendraient": ("retendre",),
    "retendrai": ("retendre",),
    "retendrais": ("retendre",),
    "retendrait": ("retendre",),
    "retendras": ("retendre",),
    "retendrez": ("retendre",),
    "retendriez": ("retendre",),
    "retendrions": ("retendre",),
    "retendrons": ("retendre",),
    "retendront": ("retendre",),
    "retends": ("retendre",),
    "retendue": ("retendre",),
    "retendues": ("retendre",),
    "retendu": ("retendre",),
    "retendus": ("retendre",),
    "retenaient": ("retenir",),
    "retenais": ("retenir",),
    "retenait": ("retenir",),
    "retenant": ("retenir",),
    "retenez": ("retenir",),
    "reteniez": ("retenir",),
    "retenions": ("retenir",),
    "retenons": ("retenir",),
    "retenue": ("retenir",),
    "retenues": ("retenir",),
    "retenu": ("retenir",),
    "retenus": ("retenir",),
    "retiendra": ("retenir",),
    "retiendraient": ("retenir",),
    "retiendrai": ("retenir",),
    "retiendrais": ("retenir",),
    "retiendrait": ("retenir",),
    "retiendras": ("retenir",),
    "retiendrez": ("retenir",),
    "retiendriez": ("retenir",),
    "retiendrions": ("retenir",),
    "retiendrons": ("retenir",),
    "retiendront": ("retenir",),
    "retiennent": ("retenir",),
    "retienne": ("retenir",),
    "retiennes": ("retenir",),
    "retiens": ("retenir",),
    "retient": ("retenir",),
    "retînmes": ("retenir",),
    "retinrent": ("retenir",),
    "retins": ("retenir",),
    "retinssent": ("retenir",),
    "retinsses": ("retenir",),
    "retinsse": ("retenir",),
    "retinssiez": ("retenir",),
    "retinssions": ("retenir",),
    "retîntes": ("retenir",),
    "retint": ("retenir",),
    "retînt": ("retenir",),
    "retenti": ("retentir",),
    "retentîmes": ("retentir",),
    "retentira": ("retentir",),
    "retentiraient": ("retentir",),
    "retentirai": ("retentir",),
    "retentirais": ("retentir",),
    "retentirait": ("retentir",),
    "retentiras": ("retentir",),
    "retentirent": ("retentir",),
    "retentirez": ("retentir",),
    "retentiriez": ("retentir",),
    "retentirions": ("retentir",),
    "retentirons": ("retentir",),
    "retentiront": ("retentir",),
    "retentis": ("retentir",),
    "retentissaient": ("retentir",),
    "retentissais": ("retentir",),
    "retentissait": ("retentir",),
    "retentissant": ("retentir",),
    "retentissent": ("retentir",),
    "retentisse": ("retentir",),
    "retentisses": ("retentir",),
    "retentissez": ("retentir",),
    "retentissiez": ("retentir",),
    "retentissions": ("retentir",),
    "retentissons": ("retentir",),
    "retentîtes": ("retentir",),
    "retentit": ("retentir",),
    "retentît": ("retentir",),
    "reterçaient": ("retercer",),
    "reterçai": ("retercer",),
    "reterçais": ("retercer",),
    "reterçait": ("retercer",),
    "reterça": ("retercer",),
    "reterçâmes": ("retercer",),
    "reterçant": ("retercer",),
    "reterças": ("retercer",),
    "reterçassent": ("retercer",),
    "reterçasses": ("retercer",),
    "reterçasse": ("retercer",),
    "reterçassiez": ("retercer",),
    "reterçassions": ("retercer",),
    "reterçâtes": ("retercer",),
    "reterçât": ("retercer",),
    "retercée": ("retercer",),
    "retercées": ("retercer",),
    "retercé": ("retercer",),
    "retercent": ("retercer",),
    "reterce": ("retercer",),
    "retercera": ("retercer",),
    "reterceraient": ("retercer",),
    "retercerai": ("retercer",),
    "retercerais": ("retercer",),
    "retercerait": ("retercer",),
    "reterceras": ("retercer",),
    "retercèrent": ("retercer",),
    "retercerez": ("retercer",),
    "reterceriez": ("retercer",),
    "retercerions": ("retercer",),
    "retercerons": ("retercer",),
    "reterceront": ("retercer",),
    "retercés": ("retercer",),
    "reterces": ("retercer",),
    "retercez": ("retercer",),
    "reterciez": ("retercer",),
    "retercions": ("retercer",),
    "reterçons": ("retercer",),
    "rétifiaient": ("rétifier",),
    "rétifiai": ("rétifier",),
    "rétifiais": ("rétifier",),
    "rétifiait": ("rétifier",),
    "rétifia": ("rétifier",),
    "rétifiâmes": ("rétifier",),
    "rétifiant": ("rétifier",),
    "rétifias": ("rétifier",),
    "rétifiassent": ("rétifier",),
    "rétifiasses": ("rétifier",),
    "rétifiasse": ("rétifier",),
    "rétifiassiez": ("rétifier",),
    "rétifiassions": ("rétifier",),
    "rétifiâtes": ("rétifier",),
    "rétifiât": ("rétifier",),
    "rétifiée": ("rétifier",),
    "rétifiées": ("rétifier",),
    "rétifié": ("rétifier",),
    "rétifient": ("rétifier",),
    "rétifie": ("rétifier",),
    "rétifiera": ("rétifier",),
    "rétifieraient": ("rétifier",),
    "rétifierai": ("rétifier",),
    "rétifierais": ("rétifier",),
    "rétifierait": ("rétifier",),
    "rétifieras": ("rétifier",),
    "rétifièrent": ("rétifier",),
    "rétifierez": ("rétifier",),
    "rétifieriez": ("rétifier",),
    "rétifierions": ("rétifier",),
    "rétifierons": ("rétifier",),
    "rétifieront": ("rétifier",),
    "rétifiés": ("rétifier",),
    "rétifies": ("rétifier",),
    "rétifiez": ("rétifier",),
    "rétifiiez": ("rétifier",),
    "rétifiions": ("rétifier",),
    "rétifions": ("rétifier",),
    "retondaient": ("retondre",),
    "retondais": ("retondre",),
    "retondait": ("retondre",),
    "retondant": ("retondre",),
    "retondent": ("retondre",),
    "retonde": ("retondre",),
    "retondes": ("retondre",),
    "retondez": ("retondre",),
    "retondiez": ("retondre",),
    "retondîmes": ("retondre",),
    "retondions": ("retondre",),
    "retondirent": ("retondre",),
    "retondis": ("retondre",),
    "retondissent": ("retondre",),
    "retondisses": ("retondre",),
    "retondisse": ("retondre",),
    "retondissiez": ("retondre",),
    "retondissions": ("retondre",),
    "retondîtes": ("retondre",),
    "retondit": ("retondre",),
    "retondît": ("retondre",),
    "retondons": ("retondre",),
    "retond": ("retondre",),
    "retondra": ("retondre",),
    "retondraient": ("retondre",),
    "retondrai": ("retondre",),
    "retondrais": ("retondre",),
    "retondrait": ("retondre",),
    "retondras": ("retondre",),
    "retondrez": ("retondre",),
    "retondriez": ("retondre",),
    "retondrions": ("retondre",),
    "retondrons": ("retondre",),
    "retondront": ("retondre",),
    "retonds": ("retondre",),
    "retondue": ("retondre",),
    "retondues": ("retondre",),
    "retondu": ("retondre",),
    "retondus": ("retondre",),
    "retordaient": ("retordre",),
    "retordais": ("retordre",),
    "retordait": ("retordre",),
    "retordant": ("retordre",),
    "retordent": ("retordre",),
    "retorde": ("retordre",),
    "retordes": ("retordre",),
    "retordez": ("retordre",),
    "retordiez": ("retordre",),
    "retordîmes": ("retordre",),
    "retordions": ("retordre",),
    "retordirent": ("retordre",),
    "retordis": ("retordre",),
    "retordissent": ("retordre",),
    "retordisses": ("retordre",),
    "retordisse": ("retordre",),
    "retordissiez": ("retordre",),
    "retordissions": ("retordre",),
    "retordîtes": ("retordre",),
    "retordit": ("retordre",),
    "retordît": ("retordre",),
    "retordons": ("retordre",),
    "retord": ("retordre",),
    "retordra": ("retordre",),
    "retordraient": ("retordre",),
    "retordrai": ("retordre",),
    "retordrais": ("retordre",),
    "retordrait": ("retordre",),
    "retordras": ("retordre",),
    "retordrez": ("retordre",),
    "retordriez": ("retordre",),
    "retordrions": ("retordre",),
    "retordrons": ("retordre",),
    "retordront": ("retordre",),
    "retords": ("retordre",),
    "retordue": ("retordre",),
    "retordues": ("retordre",),
    "retordu": ("retordre",),
    "retordus": ("retordre",),
    "retraçaient": ("retracer",),
    "retraçai": ("retracer",),
    "retraçais": ("retracer",),
    "retraçait": ("retracer",),
    "retraça": ("retracer",),
    "retraçâmes": ("retracer",),
    "retraçant": ("retracer",),
    "retraças": ("retracer",),
    "retraçassent": ("retracer",),
    "retraçasses": ("retracer",),
    "retraçasse": ("retracer",),
    "retraçassiez": ("retracer",),
    "retraçassions": ("retracer",),
    "retraçâtes": ("retracer",),
    "retraçât": ("retracer",),
    "retracée": ("retracer",),
    "retracées": ("retracer",),
    "retracé": ("retracer",),
    "retracent": ("retracer",),
    "retrace": ("retracer",),
    "retracera": ("retracer",),
    "retraceraient": ("retracer",),
    "retracerai": ("retracer",),
    "retracerais": ("retracer",),
    "retracerait": ("retracer",),
    "retraceras": ("retracer",),
    "retracèrent": ("retracer",),
    "retracerez": ("retracer",),
    "retraceriez": ("retracer",),
    "retracerions": ("retracer",),
    "retracerons": ("retracer",),
    "retraceront": ("retracer",),
    "retracés": ("retracer",),
    "retraces": ("retracer",),
    "retracez": ("retracer",),
    "retraciez": ("retracer",),
    "retracions": ("retracer",),
    "retraçons": ("retracer",),
    "retraduira": ("retraduire",),
    "retraduiraient": ("retraduire",),
    "retraduirai": ("retraduire",),
    "retraduirais": ("retraduire",),
    "retraduirait": ("retraduire",),
    "retraduiras": ("retraduire",),
    "retraduirez": ("retraduire",),
    "retraduiriez": ("retraduire",),
    "retraduirions": ("retraduire",),
    "retraduirons": ("retraduire",),
    "retraduiront": ("retraduire",),
    "retraduisaient": ("retraduire",),
    "retraduisais": ("retraduire",),
    "retraduisait": ("retraduire",),
    "retraduisant": ("retraduire",),
    "retraduisent": ("retraduire",),
    "retraduise": ("retraduire",),
    "retraduises": ("retraduire",),
    "retraduisez": ("retraduire",),
    "retraduisiez": ("retraduire",),
    "retraduisîmes": ("retraduire",),
    "retraduisions": ("retraduire",),
    "retraduisirent": ("retraduire",),
    "retraduisis": ("retraduire",),
    "retraduisissent": ("retraduire",),
    "retraduisisses": ("retraduire",),
    "retraduisisse": ("retraduire",),
    "retraduisissiez": ("retraduire",),
    "retraduisissions": ("retraduire",),
    "retraduisîtes": ("retraduire",),
    "retraduisit": ("retraduire",),
    "retraduisît": ("retraduire",),
    "retraduisons": ("retraduire",),
    "retraduis": ("retraduire",),
    "retraduite": ("retraduire",),
    "retraduites": ("retraduire",),
    "retraduit": ("retraduire",),
    "retraduits": ("retraduire",),
    "retraient": ("retraire",),
    "retraie": ("retraire",),
    "retraies": ("retraire",),
    "retraira": ("retraire",),
    "retrairaient": ("retraire",),
    "retrairai": ("retraire",),
    "retrairais": ("retraire",),
    "retrairait": ("retraire",),
    "retrairas": ("retraire",),
    "retrairez": ("retraire",),
    "retrairiez": ("retraire",),
    "retrairions": ("retraire",),
    "retrairons": ("retraire",),
    "retrairont": ("retraire",),
    "retrais": ("retraire",),
    "retraite": ("retraire",),
    "retraites": ("retraire",),
    "retrait": ("retraire",),
    "retraits": ("retraire",),
    "retrayaient": ("retraire",),
    "retrayais": ("retraire",),
    "retrayait": ("retraire",),
    "retrayant": ("retraire",),
    "retrayez": ("retraire",),
    "retrayiez": ("retraire",),
    "retrayions": ("retraire",),
    "retrayons": ("retraire",),
    "retranscrira": ("retranscrire",),
    "retranscriraient": ("retranscrire",),
    "retranscrirai": ("retranscrire",),
    "retranscrirais": ("retranscrire",),
    "retranscrirait": ("retranscrire",),
    "retranscriras": ("retranscrire",),
    "retranscrirez": ("retranscrire",),
    "retranscririez": ("retranscrire",),
    "retranscririons": ("retranscrire",),
    "retranscrirons": ("retranscrire",),
    "retranscriront": ("retranscrire",),
    "retranscris": ("retranscrire",),
    "retranscrite": ("retranscrire",),
    "retranscrites": ("retranscrire",),
    "retranscrit": ("retranscrire",),
    "retranscrits": ("retranscrire",),
    "retranscrivaient": ("retranscrire",),
    "retranscrivais": ("retranscrire",),
    "retranscrivait": ("retranscrire",),
    "retranscrivant": ("retranscrire",),
    "retranscrivent": ("retranscrire",),
    "retranscrive": ("retranscrire",),
    "retranscrives": ("retranscrire",),
    "retranscrivez": ("retranscrire",),
    "retranscriviez": ("retranscrire",),
    "retranscrivîmes": ("retranscrire",),
    "retranscrivions": ("retranscrire",),
    "retranscrivirent": ("retranscrire",),
    "retranscrivis": ("retranscrire",),
    "retranscrivissent": ("retranscrire",),
    "retranscrivisses": ("retranscrire",),
    "retranscrivisse": ("retranscrire",),
    "retranscrivissiez": ("retranscrire",),
    "retranscrivissions": ("retranscrire",),
    "retranscrivîtes": ("retranscrire",),
    "retranscrivit": ("retranscrire",),
    "retranscrivît": ("retranscrire",),
    "retranscrivons": ("retranscrire",),
    "retransféraient": ("retransférer",),
    "retransférai": ("retransférer",),
    "retransférais": ("retransférer",),
    "retransférait": ("retransférer",),
    "retransféra": ("retransférer",),
    "retransférâmes": ("retransférer",),
    "retransférant": ("retransférer",),
    "retransféras": ("retransférer",),
    "retransférassent": ("retransférer",),
    "retransférasses": ("retransférer",),
    "retransférasse": ("retransférer",),
    "retransférassiez": ("retransférer",),
    "retransférassions": ("retransférer",),
    "retransférâtes": ("retransférer",),
    "retransférât": ("retransférer",),
    "retransférée": ("retransférer",),
    "retransférées": ("retransférer",),
    "retransféré": ("retransférer",),
    "retransfèrent": ("retransférer",),
    "retransfère": ("retransférer",),
    "retransférera": ("retransférer",),
    "retransféreraient": ("retransférer",),
    "retransférerai": ("retransférer",),
    "retransférerais": ("retransférer",),
    "retransférerait": ("retransférer",),
    "retransféreras": ("retransférer",),
    "retransférèrent": ("retransférer",),
    "retransférerez": ("retransférer",),
    "retransféreriez": ("retransférer",),
    "retransférerions": ("retransférer",),
    "retransférerons": ("retransférer",),
    "retransféreront": ("retransférer",),
    "retransférés": ("retransférer",),
    "retransfères": ("retransférer",),
    "retransférez": ("retransférer",),
    "retransfériez": ("retransférer",),
    "retransférions": ("retransférer",),
    "retransférons": ("retransférer",),
    "retransmet": ("retransmettre",),
    "retransmets": ("retransmettre",),
    "retransmettaient": ("retransmettre",),
    "retransmettais": ("retransmettre",),
    "retransmettait": ("retransmettre",),
    "retransmettant": ("retransmettre",),
    "retransmettent": ("retransmettre",),
    "retransmette": ("retransmettre",),
    "retransmettes": ("retransmettre",),
    "retransmettez": ("retransmettre",),
    "retransmettiez": ("retransmettre",),
    "retransmettions": ("retransmettre",),
    "retransmettons": ("retransmettre",),
    "retransmettra": ("retransmettre",),
    "retransmettraient": ("retransmettre",),
    "retransmettrai": ("retransmettre",),
    "retransmettrais": ("retransmettre",),
    "retransmettrait": ("retransmettre",),
    "retransmettras": ("retransmettre",),
    "retransmettrez": ("retransmettre",),
    "retransmettriez": ("retransmettre",),
    "retransmettrions": ("retransmettre",),
    "retransmettrons": ("retransmettre",),
    "retransmettront": ("retransmettre",),
    "retransmîmes": ("retransmettre",),
    "retransmirent": ("retransmettre",),
    "retransmise": ("retransmettre",),
    "retransmises": ("retransmettre",),
    "retransmis": ("retransmettre",),
    "retransmissent": ("retransmettre",),
    "retransmisses": ("retransmettre",),
    "retransmisse": ("retransmettre",),
    "retransmissiez": ("retransmettre",),
    "retransmissions": ("retransmettre",),
    "retransmîtes": ("retransmettre",),
    "retransmit": ("retransmettre",),
    "retransmît": ("retransmettre",),
    "retransperçaient": ("retranspercer",),
    "retransperçai": ("retranspercer",),
    "retransperçais": ("retranspercer",),
    "retransperçait": ("retranspercer",),
    "retransperça": ("retranspercer",),
    "retransperçâmes": ("retranspercer",),
    "retransperçant": ("retranspercer",),
    "retransperças": ("retranspercer",),
    "retransperçassent": ("retranspercer",),
    "retransperçasses": ("retranspercer",),
    "retransperçasse": ("retranspercer",),
    "retransperçassiez": ("retranspercer",),
    "retransperçassions": ("retranspercer",),
    "retransperçâtes": ("retranspercer",),
    "retransperçât": ("retranspercer",),
    "retranspercée": ("retranspercer",),
    "retranspercées": ("retranspercer",),
    "retranspercé": ("retranspercer",),
    "retranspercent": ("retranspercer",),
    "retransperce": ("retranspercer",),
    "retranspercera": ("retranspercer",),
    "retransperceraient": ("retranspercer",),
    "retranspercerai": ("retranspercer",),
    "retranspercerais": ("retranspercer",),
    "retranspercerait": ("retranspercer",),
    "retransperceras": ("retranspercer",),
    "retranspercèrent": ("retranspercer",),
    "retranspercerez": ("retranspercer",),
    "retransperceriez": ("retranspercer",),
    "retranspercerions": ("retranspercer",),
    "retranspercerons": ("retranspercer",),
    "retransperceront": ("retranspercer",),
    "retranspercés": ("retranspercer",),
    "retransperces": ("retranspercer",),
    "retranspercez": ("retranspercer",),
    "retransperciez": ("retranspercer",),
    "retranspercions": ("retranspercer",),
    "retransperçons": ("retranspercer",),
    "rétrécie": ("rétrécir",),
    "rétrécies": ("rétrécir",),
    "rétréci": ("rétrécir",),
    "rétrécîmes": ("rétrécir",),
    "rétrécira": ("rétrécir",),
    "rétréciraient": ("rétrécir",),
    "rétrécirai": ("rétrécir",),
    "rétrécirais": ("rétrécir",),
    "rétrécirait": ("rétrécir",),
    "rétréciras": ("rétrécir",),
    "rétrécirent": ("rétrécir",),
    "rétrécirez": ("rétrécir",),
    "rétréciriez": ("rétrécir",),
    "rétrécirions": ("rétrécir",),
    "rétrécirons": ("rétrécir",),
    "rétréciront": ("rétrécir",),
    "rétrécis": ("rétrécir",),
    "rétrécissaient": ("rétrécir",),
    "rétrécissais": ("rétrécir",),
    "rétrécissait": ("rétrécir",),
    "rétrécissant": ("rétrécir",),
    "rétrécissent": ("rétrécir",),
    "rétrécisse": ("rétrécir",),
    "rétrécisses": ("rétrécir",),
    "rétrécissez": ("rétrécir",),
    "rétrécissiez": ("rétrécir",),
    "rétrécissions": ("rétrécir",),
    "rétrécissons": ("rétrécir",),
    "rétrécîtes": ("rétrécir",),
    "rétrécit": ("rétrécir",),
    "rétrécît": ("rétrécir",),
    "retreignaient": ("retreindre",),
    "rétreignaient": ("rétreindre",),
    "retreignais": ("retreindre",),
    "rétreignais": ("rétreindre",),
    "retreignait": ("retreindre",),
    "rétreignait": ("rétreindre",),
    "retreignant": ("retreindre",),
    "rétreignant": ("rétreindre",),
    "retreignent": ("retreindre",),
    "rétreignent": ("rétreindre",),
    "retreigne": ("retreindre",),
    "rétreigne": ("rétreindre",),
    "retreignes": ("retreindre",),
    "rétreignes": ("rétreindre",),
    "retreignez": ("retreindre",),
    "rétreignez": ("rétreindre",),
    "retreigniez": ("retreindre",),
    "rétreigniez": ("rétreindre",),
    "retreignîmes": ("retreindre",),
    "rétreignîmes": ("rétreindre",),
    "retreignions": ("retreindre",),
    "rétreignions": ("rétreindre",),
    "retreignirent": ("retreindre",),
    "rétreignirent": ("rétreindre",),
    "retreignis": ("retreindre",),
    "rétreignis": ("rétreindre",),
    "retreignissent": ("retreindre",),
    "rétreignissent": ("rétreindre",),
    "retreignisses": ("retreindre",),
    "rétreignisses": ("rétreindre",),
    "retreignisse": ("retreindre",),
    "rétreignisse": ("rétreindre",),
    "retreignissiez": ("retreindre",),
    "rétreignissiez": ("rétreindre",),
    "retreignissions": ("retreindre",),
    "rétreignissions": ("rétreindre",),
    "retreignîtes": ("retreindre",),
    "rétreignîtes": ("rétreindre",),
    "retreignit": ("retreindre",),
    "rétreignit": ("rétreindre",),
    "retreignît": ("retreindre",),
    "rétreignît": ("rétreindre",),
    "retreignons": ("retreindre",),
    "rétreignons": ("rétreindre",),
    "retreindra": ("retreindre",),
    "rétreindra": ("rétreindre",),
    "retreindraient": ("retreindre",),
    "rétreindraient": ("rétreindre",),
    "retreindrai": ("retreindre",),
    "rétreindrai": ("rétreindre",),
    "retreindrais": ("retreindre",),
    "rétreindrais": ("rétreindre",),
    "retreindrait": ("retreindre",),
    "rétreindrait": ("rétreindre",),
    "retreindras": ("retreindre",),
    "rétreindras": ("rétreindre",),
    "retreindrez": ("retreindre",),
    "rétreindrez": ("rétreindre",),
    "retreindriez": ("retreindre",),
    "rétreindriez": ("rétreindre",),
    "retreindrions": ("retreindre",),
    "rétreindrions": ("rétreindre",),
    "retreindrons": ("retreindre",),
    "rétreindrons": ("rétreindre",),
    "retreindront": ("retreindre",),
    "rétreindront": ("rétreindre",),
    "retreins": ("retreindre",),
    "rétreins": ("rétreindre",),
    "retreinte": ("retreindre",),
    "rétreinte": ("rétreindre",),
    "retreintes": ("retreindre",),
    "rétreintes": ("rétreindre",),
    "retreint": ("retreindre",),
    "rétreint": ("rétreindre",),
    "retreints": ("retreindre",),
    "rétreints": ("rétreindre",),
    "retriaient": ("retrier",),
    "retriai": ("retrier",),
    "retriais": ("retrier",),
    "retriait": ("retrier",),
    "retria": ("retrier",),
    "retriâmes": ("retrier",),
    "retriant": ("retrier",),
    "retrias": ("retrier",),
    "retriassent": ("retrier",),
    "retriasses": ("retrier",),
    "retriasse": ("retrier",),
    "retriassiez": ("retrier",),
    "retriassions": ("retrier",),
    "retriâtes": ("retrier",),
    "retriât": ("retrier",),
    "retriée": ("retrier",),
    "retriées": ("retrier",),
    "retrié": ("retrier",),
    "retrient": ("retrier",),
    "retrie": ("retrier",),
    "retriera": ("retrier",),
    "retrieraient": ("retrier",),
    "retrierai": ("retrier",),
    "retrierais": ("retrier",),
    "retrierait": ("retrier",),
    "retrieras": ("retrier",),
    "retrièrent": ("retrier",),
    "retrierez": ("retrier",),
    "retrieriez": ("retrier",),
    "retrierions": ("retrier",),
    "retrierons": ("retrier",),
    "retrieront": ("retrier",),
    "retriés": ("retrier",),
    "retries": ("retrier",),
    "retriez": ("retrier",),
    "retriiez": ("retrier",),
    "retriions": ("retrier",),
    "retrions": ("retrier",),
    "rétroagi": ("rétroagir",),
    "rétroagîmes": ("rétroagir",),
    "rétroagira": ("rétroagir",),
    "rétroagiraient": ("rétroagir",),
    "rétroagirai": ("rétroagir",),
    "rétroagirais": ("rétroagir",),
    "rétroagirait": ("rétroagir",),
    "rétroagiras": ("rétroagir",),
    "rétroagirent": ("rétroagir",),
    "rétroagirez": ("rétroagir",),
    "rétroagiriez": ("rétroagir",),
    "rétroagirions": ("rétroagir",),
    "rétroagirons": ("rétroagir",),
    "rétroagiront": ("rétroagir",),
    "rétroagis": ("rétroagir",),
    "rétroagissaient": ("rétroagir",),
    "rétroagissais": ("rétroagir",),
    "rétroagissait": ("rétroagir",),
    "rétroagissant": ("rétroagir",),
    "rétroagissent": ("rétroagir",),
    "rétroagisse": ("rétroagir",),
    "rétroagisses": ("rétroagir",),
    "rétroagissez": ("rétroagir",),
    "rétroagissiez": ("rétroagir",),
    "rétroagissions": ("rétroagir",),
    "rétroagissons": ("rétroagir",),
    "rétroagîtes": ("rétroagir",),
    "rétroagit": ("rétroagir",),
    "rétroagît": ("rétroagir",),
    "rétrocédaient": ("rétrocéder",),
    "rétrocédai": ("rétrocéder",),
    "rétrocédais": ("rétrocéder",),
    "rétrocédait": ("rétrocéder",),
    "rétrocéda": ("rétrocéder",),
    "rétrocédâmes": ("rétrocéder",),
    "rétrocédant": ("rétrocéder",),
    "rétrocédas": ("rétrocéder",),
    "rétrocédassent": ("rétrocéder",),
    "rétrocédasses": ("rétrocéder",),
    "rétrocédasse": ("rétrocéder",),
    "rétrocédassiez": ("rétrocéder",),
    "rétrocédassions": ("rétrocéder",),
    "rétrocédâtes": ("rétrocéder",),
    "rétrocédât": ("rétrocéder",),
    "rétrocédée": ("rétrocéder",),
    "rétrocédées": ("rétrocéder",),
    "rétrocédé": ("rétrocéder",),
    "rétrocèdent": ("rétrocéder",),
    "rétrocède": ("rétrocéder",),
    "rétrocédera": ("rétrocéder",),
    "rétrocéderaient": ("rétrocéder",),
    "rétrocéderai": ("rétrocéder",),
    "rétrocéderais": ("rétrocéder",),
    "rétrocéderait": ("rétrocéder",),
    "rétrocéderas": ("rétrocéder",),
    "rétrocédèrent": ("rétrocéder",),
    "rétrocéderez": ("rétrocéder",),
    "rétrocéderiez": ("rétrocéder",),
    "rétrocéderions": ("rétrocéder",),
    "rétrocéderons": ("rétrocéder",),
    "rétrocéderont": ("rétrocéder",),
    "rétrocédés": ("rétrocéder",),
    "rétrocèdes": ("rétrocéder",),
    "rétrocédez": ("rétrocéder",),
    "rétrocédiez": ("rétrocéder",),
    "rétrocédions": ("rétrocéder",),
    "rétrocédons": ("rétrocéder",),
    "rétrodéviaient": ("rétrodévier",),
    "rétrodéviai": ("rétrodévier",),
    "rétrodéviais": ("rétrodévier",),
    "rétrodéviait": ("rétrodévier",),
    "rétrodévia": ("rétrodévier",),
    "rétrodéviâmes": ("rétrodévier",),
    "rétrodéviant": ("rétrodévier",),
    "rétrodévias": ("rétrodévier",),
    "rétrodéviassent": ("rétrodévier",),
    "rétrodéviasses": ("rétrodévier",),
    "rétrodéviasse": ("rétrodévier",),
    "rétrodéviassiez": ("rétrodévier",),
    "rétrodéviassions": ("rétrodévier",),
    "rétrodéviâtes": ("rétrodévier",),
    "rétrodéviât": ("rétrodévier",),
    "rétrodéviée": ("rétrodévier",),
    "rétrodéviées": ("rétrodévier",),
    "rétrodévié": ("rétrodévier",),
    "rétrodévient": ("rétrodévier",),
    "rétrodévie": ("rétrodévier",),
    "rétrodéviera": ("rétrodévier",),
    "rétrodévieraient": ("rétrodévier",),
    "rétrodévierai": ("rétrodévier",),
    "rétrodévierais": ("rétrodévier",),
    "rétrodévierait": ("rétrodévier",),
    "rétrodévieras": ("rétrodévier",),
    "rétrodévièrent": ("rétrodévier",),
    "rétrodévierez": ("rétrodévier",),
    "rétrodévieriez": ("rétrodévier",),
    "rétrodévierions": ("rétrodévier",),
    "rétrodévierons": ("rétrodévier",),
    "rétrodévieront": ("rétrodévier",),
    "rétrodéviés": ("rétrodévier",),
    "rétrodévies": ("rétrodévier",),
    "rétrodéviez": ("rétrodévier",),
    "rétrodéviiez": ("rétrodévier",),
    "rétrodéviions": ("rétrodévier",),
    "rétrodévions": ("rétrodévier",),
    "rétrofléchie": ("rétrofléchir",),
    "rétrofléchies": ("rétrofléchir",),
    "rétrofléchi": ("rétrofléchir",),
    "rétrofléchîmes": ("rétrofléchir",),
    "rétrofléchira": ("rétrofléchir",),
    "rétrofléchiraient": ("rétrofléchir",),
    "rétrofléchirai": ("rétrofléchir",),
    "rétrofléchirais": ("rétrofléchir",),
    "rétrofléchirait": ("rétrofléchir",),
    "rétrofléchiras": ("rétrofléchir",),
    "rétrofléchirent": ("rétrofléchir",),
    "rétrofléchirez": ("rétrofléchir",),
    "rétrofléchiriez": ("rétrofléchir",),
    "rétrofléchirions": ("rétrofléchir",),
    "rétrofléchirons": ("rétrofléchir",),
    "rétrofléchiront": ("rétrofléchir",),
    "rétrofléchis": ("rétrofléchir",),
    "rétrofléchissaient": ("rétrofléchir",),
    "rétrofléchissais": ("rétrofléchir",),
    "rétrofléchissait": ("rétrofléchir",),
    "rétrofléchissant": ("rétrofléchir",),
    "rétrofléchissent": ("rétrofléchir",),
    "rétrofléchisse": ("rétrofléchir",),
    "rétrofléchisses": ("rétrofléchir",),
    "rétrofléchissez": ("rétrofléchir",),
    "rétrofléchissiez": ("rétrofléchir",),
    "rétrofléchissions": ("rétrofléchir",),
    "rétrofléchissons": ("rétrofléchir",),
    "rétrofléchîtes": ("rétrofléchir",),
    "rétrofléchit": ("rétrofléchir",),
    "rétrofléchît": ("rétrofléchir",),
    "rétroréfléchie": ("rétroréfléchir",),
    "rétroréfléchies": ("rétroréfléchir",),
    "rétroréfléchi": ("rétroréfléchir",),
    "rétroréfléchîmes": ("rétroréfléchir",),
    "rétroréfléchira": ("rétroréfléchir",),
    "rétroréfléchiraient": ("rétroréfléchir",),
    "rétroréfléchirai": ("rétroréfléchir",),
    "rétroréfléchirais": ("rétroréfléchir",),
    "rétroréfléchirait": ("rétroréfléchir",),
    "rétroréfléchiras": ("rétroréfléchir",),
    "rétroréfléchirent": ("rétroréfléchir",),
    "rétroréfléchirez": ("rétroréfléchir",),
    "rétroréfléchiriez": ("rétroréfléchir",),
    "rétroréfléchirions": ("rétroréfléchir",),
    "rétroréfléchirons": ("rétroréfléchir",),
    "rétroréfléchiront": ("rétroréfléchir",),
    "rétroréfléchis": ("rétroréfléchir",),
    "rétroréfléchissaient": ("rétroréfléchir",),
    "rétroréfléchissais": ("rétroréfléchir",),
    "rétroréfléchissait": ("rétroréfléchir",),
    "rétroréfléchissant": ("rétroréfléchir",),
    "rétroréfléchissent": ("rétroréfléchir",),
    "rétroréfléchisse": ("rétroréfléchir",),
    "rétroréfléchisses": ("rétroréfléchir",),
    "rétroréfléchissez": ("rétroréfléchir",),
    "rétroréfléchissiez": ("rétroréfléchir",),
    "rétroréfléchissions": ("rétroréfléchir",),
    "rétroréfléchissons": ("rétroréfléchir",),
    "rétroréfléchîtes": ("rétroréfléchir",),
    "rétroréfléchit": ("rétroréfléchir",),
    "rétroréfléchît": ("rétroréfléchir",),
    "réunifiaient": ("réunifier",),
    "réunifiai": ("réunifier",),
    "réunifiais": ("réunifier",),
    "réunifiait": ("réunifier",),
    "réunifia": ("réunifier",),
    "réunifiâmes": ("réunifier",),
    "réunifiant": ("réunifier",),
    "réunifias": ("réunifier",),
    "réunifiassent": ("réunifier",),
    "réunifiasses": ("réunifier",),
    "réunifiasse": ("réunifier",),
    "réunifiassiez": ("réunifier",),
    "réunifiassions": ("réunifier",),
    "réunifiâtes": ("réunifier",),
    "réunifiât": ("réunifier",),
    "réunifiée": ("réunifier",),
    "réunifiées": ("réunifier",),
    "réunifié": ("réunifier",),
    "réunifient": ("réunifier",),
    "réunifie": ("réunifier",),
    "réunifiera": ("réunifier",),
    "réunifieraient": ("réunifier",),
    "réunifierai": ("réunifier",),
    "réunifierais": ("réunifier",),
    "réunifierait": ("réunifier",),
    "réunifieras": ("réunifier",),
    "réunifièrent": ("réunifier",),
    "réunifierez": ("réunifier",),
    "réunifieriez": ("réunifier",),
    "réunifierions": ("réunifier",),
    "réunifierons": ("réunifier",),
    "réunifieront": ("réunifier",),
    "réunifiés": ("réunifier",),
    "réunifies": ("réunifier",),
    "réunifiez": ("réunifier",),
    "réunifiiez": ("réunifier",),
    "réunifiions": ("réunifier",),
    "réunifions": ("réunifier",),
    "réunie": ("réunir",),
    "réunies": ("réunir",),
    "réuni": ("réunir",),
    "réunîmes": ("réunir",),
    "réunira": ("réunir",),
    "réuniraient": ("réunir",),
    "réunirai": ("réunir",),
    "réunirais": ("réunir",),
    "réunirait": ("réunir",),
    "réuniras": ("réunir",),
    "réunirent": ("réunir",),
    "réunirez": ("réunir",),
    "réuniriez": ("réunir",),
    "réunirions": ("réunir",),
    "réunirons": ("réunir",),
    "réuniront": ("réunir",),
    "réunis": ("réunir",),
    "réunissaient": ("réunir",),
    "réunissais": ("réunir",),
    "réunissait": ("réunir",),
    "réunissant": ("réunir",),
    "réunissent": ("réunir",),
    "réunisse": ("réunir",),
    "réunisses": ("réunir",),
    "réunissez": ("réunir",),
    "réunissiez": ("réunir",),
    "réunissions": ("réunir",),
    "réunissons": ("réunir",),
    "réunîtes": ("réunir",),
    "réunit": ("réunir",),
    "réunît": ("réunir",),
    "réussie": ("réussir",),
    "réussies": ("réussir",),
    "réussi": ("réussir",),
    "réussîmes": ("réussir",),
    "réussira": ("réussir",),
    "réussiraient": ("réussir",),
    "réussirai": ("réussir",),
    "réussirais": ("réussir",),
    "réussirait": ("réussir",),
    "réussiras": ("réussir",),
    "réussirent": ("réussir",),
    "réussirez": ("réussir",),
    "réussiriez": ("réussir",),
    "réussirions": ("réussir",),
    "réussirons": ("réussir",),
    "réussiront": ("réussir",),
    "réussis": ("réussir",),
    "réussissaient": ("réussir",),
    "réussissais": ("réussir",),
    "réussissait": ("réussir",),
    "réussissant": ("réussir",),
    "réussissent": ("réussir",),
    "réussisse": ("réussir",),
    "réussisses": ("réussir",),
    "réussissez": ("réussir",),
    "réussissiez": ("réussir",),
    "réussissions": ("réussir",),
    "réussissons": ("réussir",),
    "réussîtes": ("réussir",),
    "réussit": ("réussir",),
    "réussît": ("réussir",),
    "revainc": ("revaincre",),
    "revaincra": ("revaincre",),
    "revaincraient": ("revaincre",),
    "revaincrai": ("revaincre",),
    "revaincrais": ("revaincre",),
    "revaincrait": ("revaincre",),
    "revaincras": ("revaincre",),
    "revaincrez": ("revaincre",),
    "revaincriez": ("revaincre",),
    "revaincrions": ("revaincre",),
    "revaincrons": ("revaincre",),
    "revaincront": ("revaincre",),
    "revaincs": ("revaincre",),
    "revaincue": ("revaincre",),
    "revaincues": ("revaincre",),
    "revaincu": ("revaincre",),
    "revaincus": ("revaincre",),
    "revainquaient": ("revaincre",),
    "revainquais": ("revaincre",),
    "revainquait": ("revaincre",),
    "revainquant": ("revaincre",),
    "revainquent": ("revaincre",),
    "revainque": ("revaincre",),
    "revainques": ("revaincre",),
    "revainquez": ("revaincre",),
    "revainquiez": ("revaincre",),
    "revainquîmes": ("revaincre",),
    "revainquions": ("revaincre",),
    "revainquirent": ("revaincre",),
    "revainquis": ("revaincre",),
    "revainquissent": ("revaincre",),
    "revainquisses": ("revaincre",),
    "revainquisse": ("revaincre",),
    "revainquissiez": ("revaincre",),
    "revainquissions": ("revaincre",),
    "revainquîtes": ("revaincre",),
    "revainquit": ("revaincre",),
    "revainquît": ("revaincre",),
    "revainquons": ("revaincre",),
    "revalu": ("revaloir",),
    "revaudra": ("revaloir",),
    "revaudraient": ("revaloir",),
    "revaudrai": ("revaloir",),
    "revaudrais": ("revaloir",),
    "revaudrait": ("revaloir",),
    "revaudras": ("revaloir",),
    "revaudrez": ("revaloir",),
    "revaudriez": ("revaloir",),
    "revaudrions": ("revaloir",),
    "revaudrons": ("revaloir",),
    "revaudront": ("revaloir",),
    "rêvassaient": ("rêvasser",),
    "rêvassai": ("rêvasser",),
    "rêvassais": ("rêvasser",),
    "rêvassait": ("rêvasser",),
    "rêvassa": ("rêvasser",),
    "rêvassâmes": ("rêvasser",),
    "rêvassant": ("rêvasser",),
    "rêvassas": ("rêvasser",),
    "rêvassassent": ("rêvasser",),
    "rêvassasses": ("rêvasser",),
    "rêvassasse": ("rêvasser",),
    "rêvassassiez": ("rêvasser",),
    "rêvassassions": ("rêvasser",),
    "rêvassâtes": ("rêvasser",),
    "rêvassât": ("rêvasser",),
    "rêvassé": ("rêvasser",),
    "rêvassent": ("rêvasser",),
    "rêvasse": ("rêvasser",),
    "rêvassera": ("rêvasser",),
    "rêvasseraient": ("rêvasser",),
    "rêvasserai": ("rêvasser",),
    "rêvasserais": ("rêvasser",),
    "rêvasserait": ("rêvasser",),
    "rêvasseras": ("rêvasser",),
    "rêvassèrent": ("rêvasser",),
    "rêvasserez": ("rêvasser",),
    "rêvasseriez": ("rêvasser",),
    "rêvasserions": ("rêvasser",),
    "rêvasserons": ("rêvasser",),
    "rêvasseront": ("rêvasser",),
    "rêvasses": ("rêvasser",),
    "rêvassez": ("rêvasser",),
    "rêvassiez": ("rêvasser",),
    "rêvassions": ("rêvasser",),
    "rêvassons": ("rêvasser",),
    "révélaient": ("révéler",),
    "révélai": ("révéler",),
    "révélais": ("révéler",),
    "révélait": ("révéler",),
    "révéla": ("révéler",),
    "révélâmes": ("révéler",),
    "révélant": ("révéler",),
    "révélas": ("révéler",),
    "révélassent": ("révéler",),
    "révélasses": ("révéler",),
    "révélasse": ("révéler",),
    "révélassiez": ("révéler",),
    "révélassions": ("révéler",),
    "révélâtes": ("révéler",),
    "révélât": ("révéler",),
    "révélée": ("révéler",),
    "révélées": ("révéler",),
    "révélé": ("révéler",),
    "révèlent": ("révéler",),
    "révèle": ("révéler",),
    "révélera": ("révéler",),
    "révéleraient": ("révéler",),
    "révélerai": ("révéler",),
    "révélerais": ("révéler",),
    "révélerait": ("révéler",),
    "révéleras": ("révéler",),
    "révélèrent": ("révéler",),
    "révélerez": ("révéler",),
    "révéleriez": ("révéler",),
    "révélerions": ("révéler",),
    "révélerons": ("révéler",),
    "révéleront": ("révéler",),
    "révélés": ("révéler",),
    "révèles": ("révéler",),
    "révélez": ("révéler",),
    "révéliez": ("révéler",),
    "révélions": ("révéler",),
    "révélons": ("révéler",),
    "revendaient": ("revendre",),
    "revendais": ("revendre",),
    "revendait": ("revendre",),
    "revendant": ("revendre",),
    "revendent": ("revendre",),
    "revende": ("revendre",),
    "revendes": ("revendre",),
    "revendez": ("revendre",),
    "revendiez": ("revendre",),
    "revendîmes": ("revendre",),
    "revendions": ("revendre",),
    "revendirent": ("revendre",),
    "revendis": ("revendre",),
    "revendissent": ("revendre",),
    "revendisses": ("revendre",),
    "revendisse": ("revendre",),
    "revendissiez": ("revendre",),
    "revendissions": ("revendre",),
    "revendîtes": ("revendre",),
    "revendit": ("revendre",),
    "revendît": ("revendre",),
    "revendons": ("revendre",),
    "revend": ("revendre",),
    "revendra": ("revendre",),
    "revendraient": ("revendre",),
    "revendrai": ("revendre",),
    "revendrais": ("revendre",),
    "revendrait": ("revendre",),
    "revendras": ("revendre",),
    "revendrez": ("revendre",),
    "revendriez": ("revendre",),
    "revendrions": ("revendre",),
    "revendrons": ("revendre",),
    "revendront": ("revendre",),
    "revends": ("revendre",),
    "revendue": ("revendre",),
    "revendues": ("revendre",),
    "revendu": ("revendre",),
    "revendus": ("revendre",),
    "revengeaient": ("revenger",),
    "revengeai": ("revenger",),
    "revengeais": ("revenger",),
    "revengeait": ("revenger",),
    "revengea": ("revenger",),
    "revengeâmes": ("revenger",),
    "revengeant": ("revenger",),
    "revengeas": ("revenger",),
    "revengeassent": ("revenger",),
    "revengeasses": ("revenger",),
    "revengeasse": ("revenger",),
    "revengeassiez": ("revenger",),
    "revengeassions": ("revenger",),
    "revengeâtes": ("revenger",),
    "revengeât": ("revenger",),
    "revengée": ("revenger",),
    "revengées": ("revenger",),
    "revengé": ("revenger",),
    "revengent": ("revenger",),
    "revengeons": ("revenger",),
    "revenge": ("revenger",),
    "revengera": ("revenger",),
    "revengeraient": ("revenger",),
    "revengerai": ("revenger",),
    "revengerais": ("revenger",),
    "revengerait": ("revenger",),
    "revengeras": ("revenger",),
    "revengèrent": ("revenger",),
    "revengerez": ("revenger",),
    "revengeriez": ("revenger",),
    "revengerions": ("revenger",),
    "revengerons": ("revenger",),
    "revengeront": ("revenger",),
    "revengés": ("revenger",),
    "revenges": ("revenger",),
    "revengez": ("revenger",),
    "revengiez": ("revenger",),
    "revengions": ("revenger",),
    "revenaient": ("revenir",),
    "revenais": ("revenir",),
    "revenait": ("revenir",),
    "revenant": ("revenir",),
    "revenez": ("revenir",),
    "reveniez": ("revenir",),
    "revenions": ("revenir",),
    "revenons": ("revenir",),
    "revenue": ("revenir",),
    "revenues": ("revenir",),
    "revenu": ("revenir",),
    "revenus": ("revenir",),
    "reviendra": ("revenir",),
    "reviendraient": ("revenir",),
    "reviendrai": ("revenir",),
    "reviendrais": ("revenir",),
    "reviendrait": ("revenir",),
    "reviendras": ("revenir",),
    "reviendrez": ("revenir",),
    "reviendriez": ("revenir",),
    "reviendrions": ("revenir",),
    "reviendrons": ("revenir",),
    "reviendront": ("revenir",),
    "reviennent": ("revenir",),
    "revienne": ("revenir",),
    "reviennes": ("revenir",),
    "reviens": ("revenir",),
    "revient": ("revenir",),
    "revînmes": ("revenir",),
    "revinrent": ("revenir",),
    "revins": ("revenir",),
    "revinssent": ("revenir",),
    "revinsses": ("revenir",),
    "revinsse": ("revenir",),
    "revinssiez": ("revenir",),
    "revinssions": ("revenir",),
    "revîntes": ("revenir",),
    "revint": ("revenir",),
    "revînt": ("revenir",),
    "réverbéraient": ("réverbérer",),
    "réverbérai": ("réverbérer",),
    "réverbérais": ("réverbérer",),
    "réverbérait": ("réverbérer",),
    "réverbéra": ("réverbérer",),
    "réverbérâmes": ("réverbérer",),
    "réverbérant": ("réverbérer",),
    "réverbéras": ("réverbérer",),
    "réverbérassent": ("réverbérer",),
    "réverbérasses": ("réverbérer",),
    "réverbérasse": ("réverbérer",),
    "réverbérassiez": ("réverbérer",),
    "réverbérassions": ("réverbérer",),
    "réverbérâtes": ("réverbérer",),
    "réverbérât": ("réverbérer",),
    "réverbérée": ("réverbérer",),
    "réverbérées": ("réverbérer",),
    "réverbéré": ("réverbérer",),
    "réverbèrent": ("réverbérer",),
    "réverbère": ("réverbérer",),
    "réverbérera": ("réverbérer",),
    "réverbéreraient": ("réverbérer",),
    "réverbérerai": ("réverbérer",),
    "réverbérerais": ("réverbérer",),
    "réverbérerait": ("réverbérer",),
    "réverbéreras": ("réverbérer",),
    "réverbérèrent": ("réverbérer",),
    "réverbérerez": ("réverbérer",),
    "réverbéreriez": ("réverbérer",),
    "réverbérerions": ("réverbérer",),
    "réverbérerons": ("réverbérer",),
    "réverbéreront": ("réverbérer",),
    "réverbérés": ("réverbérer",),
    "réverbères": ("réverbérer",),
    "réverbérez": ("réverbérer",),
    "réverbériez": ("réverbérer",),
    "réverbérions": ("réverbérer",),
    "réverbérons": ("réverbérer",),
    "reverdie": ("reverdir",),
    "reverdies": ("reverdir",),
    "reverdi": ("reverdir",),
    "reverdîmes": ("reverdir",),
    "reverdira": ("reverdir",),
    "reverdiraient": ("reverdir",),
    "reverdirai": ("reverdir",),
    "reverdirais": ("reverdir",),
    "reverdirait": ("reverdir",),
    "reverdiras": ("reverdir",),
    "reverdirent": ("reverdir",),
    "reverdirez": ("reverdir",),
    "reverdiriez": ("reverdir",),
    "reverdirions": ("reverdir",),
    "reverdirons": ("reverdir",),
    "reverdiront": ("reverdir",),
    "reverdis": ("reverdir",),
    "reverdissaient": ("reverdir",),
    "reverdissais": ("reverdir",),
    "reverdissait": ("reverdir",),
    "reverdissant": ("reverdir",),
    "reverdissent": ("reverdir",),
    "reverdisse": ("reverdir",),
    "reverdisses": ("reverdir",),
    "reverdissez": ("reverdir",),
    "reverdissiez": ("reverdir",),
    "reverdissions": ("reverdir",),
    "reverdissons": ("reverdir",),
    "reverdîtes": ("reverdir",),
    "reverdit": ("reverdir",),
    "reverdît": ("reverdir",),
    "révéraient": ("révérer",),
    "révérai": ("révérer",),
    "révérais": ("révérer",),
    "révérait": ("révérer",),
    "révéra": ("révérer",),
    "révérâmes": ("révérer",),
    "révérant": ("révérer",),
    "révéras": ("révérer",),
    "révérassent": ("révérer",),
    "révérasses": ("révérer",),
    "révérasse": ("révérer",),
    "révérassiez": ("révérer",),
    "révérassions": ("révérer",),
    "révérâtes": ("révérer",),
    "révérât": ("révérer",),
    "révérée": ("révérer",),
    "révérées": ("révérer",),
    "révéré": ("révérer",),
    "révèrent": ("révérer",),
    "révère": ("révérer",),
    "révérera": ("révérer",),
    "révéreraient": ("révérer",),
    "révérerai": ("révérer",),
    "révérerais": ("révérer",),
    "révérerait": ("révérer",),
    "révéreras": ("révérer",),
    "révérèrent": ("révérer",),
    "révérerez": ("révérer",),
    "révéreriez": ("révérer",),
    "révérerions": ("révérer",),
    "révérerons": ("révérer",),
    "révéreront": ("révérer",),
    "révérés": ("révérer",),
    "révères": ("révérer",),
    "révérez": ("révérer",),
    "révériez": ("révérer",),
    "révérions": ("révérer",),
    "révérons": ("révérer",),
    "revérifiaient": ("revérifier",),
    "revérifiai": ("revérifier",),
    "revérifiais": ("revérifier",),
    "revérifiait": ("revérifier",),
    "revérifia": ("revérifier",),
    "revérifiâmes": ("revérifier",),
    "revérifiant": ("revérifier",),
    "revérifias": ("revérifier",),
    "revérifiassent": ("revérifier",),
    "revérifiasses": ("revérifier",),
    "revérifiasse": ("revérifier",),
    "revérifiassiez": ("revérifier",),
    "revérifiassions": ("revérifier",),
    "revérifiâtes": ("revérifier",),
    "revérifiât": ("revérifier",),
    "revérifiée": ("revérifier",),
    "revérifiées": ("revérifier",),
    "revérifié": ("revérifier",),
    "revérifient": ("revérifier",),
    "revérifie": ("revérifier",),
    "revérifiera": ("revérifier",),
    "revérifieraient": ("revérifier",),
    "revérifierai": ("revérifier",),
    "revérifierais": ("revérifier",),
    "revérifierait": ("revérifier",),
    "revérifieras": ("revérifier",),
    "revérifièrent": ("revérifier",),
    "revérifierez": ("revérifier",),
    "revérifieriez": ("revérifier",),
    "revérifierions": ("revérifier",),
    "revérifierons": ("revérifier",),
    "revérifieront": ("revérifier",),
    "revérifiés": ("revérifier",),
    "revérifies": ("revérifier",),
    "revérifiez": ("revérifier",),
    "revérifiiez": ("revérifier",),
    "revérifiions": ("revérifier",),
    "revérifions": ("revérifier",),
    "revernie": ("revernir",),
    "revernies": ("revernir",),
    "reverni": ("revernir",),
    "revernîmes": ("revernir",),
    "revernira": ("revernir",),
    "reverniraient": ("revernir",),
    "revernirai": ("revernir",),
    "revernirais": ("revernir",),
    "revernirait": ("revernir",),
    "reverniras": ("revernir",),
    "revernirent": ("revernir",),
    "revernirez": ("revernir",),
    "reverniriez": ("revernir",),
    "revernirions": ("revernir",),
    "revernirons": ("revernir",),
    "reverniront": ("revernir",),
    "revernis": ("revernir",),
    "revernissaient": ("revernir",),
    "revernissais": ("revernir",),
    "revernissait": ("revernir",),
    "revernissant": ("revernir",),
    "revernissent": ("revernir",),
    "revernisse": ("revernir",),
    "revernisses": ("revernir",),
    "revernissez": ("revernir",),
    "revernissiez": ("revernir",),
    "revernissions": ("revernir",),
    "revernissons": ("revernir",),
    "revernîtes": ("revernir",),
    "revernit": ("revernir",),
    "revernît": ("revernir",),
    "revêtaient": ("revêtir",),
    "revêtais": ("revêtir",),
    "revêtait": ("revêtir",),
    "revêtant": ("revêtir",),
    "revêtent": ("revêtir",),
    "revête": ("revêtir",),
    "revêtes": ("revêtir",),
    "revêtez": ("revêtir",),
    "revêtiez": ("revêtir",),
    "revêtîmes": ("revêtir",),
    "revêtions": ("revêtir",),
    "revêtira": ("revêtir",),
    "revêtiraient": ("revêtir",),
    "revêtirai": ("revêtir",),
    "revêtirais": ("revêtir",),
    "revêtirait": ("revêtir",),
    "revêtiras": ("revêtir",),
    "revêtirent": ("revêtir",),
    "revêtirez": ("revêtir",),
    "revêtiriez": ("revêtir",),
    "revêtirions": ("revêtir",),
    "revêtirons": ("revêtir",),
    "revêtiront": ("revêtir",),
    "revêtis": ("revêtir",),
    "revêtissent": ("revêtir",),
    "revêtisses": ("revêtir",),
    "revêtisse": ("revêtir",),
    "revêtissiez": ("revêtir",),
    "revêtissions": ("revêtir",),
    "revêtîtes": ("revêtir",),
    "revêtit": ("revêtir",),
    "revêtît": ("revêtir",),
    "revêtons": ("revêtir",),
    "revêt": ("revêtir",),
    "revêts": ("revêtir",),
    "revêtue": ("revêtir",),
    "revêtues": ("revêtir",),
    "revêtu": ("revêtir",),
    "revêtus": ("revêtir",),
    "reviolaçaient": ("reviolacer",),
    "reviolaçai": ("reviolacer",),
    "reviolaçais": ("reviolacer",),
    "reviolaçait": ("reviolacer",),
    "reviolaça": ("reviolacer",),
    "reviolaçâmes": ("reviolacer",),
    "reviolaçant": ("reviolacer",),
    "reviolaças": ("reviolacer",),
    "reviolaçassent": ("reviolacer",),
    "reviolaçasses": ("reviolacer",),
    "reviolaçasse": ("reviolacer",),
    "reviolaçassiez": ("reviolacer",),
    "reviolaçassions": ("reviolacer",),
    "reviolaçâtes": ("reviolacer",),
    "reviolaçât": ("reviolacer",),
    "reviolacée": ("reviolacer",),
    "reviolacées": ("reviolacer",),
    "reviolacé": ("reviolacer",),
    "reviolacent": ("reviolacer",),
    "reviolace": ("reviolacer",),
    "reviolacera": ("reviolacer",),
    "reviolaceraient": ("reviolacer",),
    "reviolacerai": ("reviolacer",),
    "reviolacerais": ("reviolacer",),
    "reviolacerait": ("reviolacer",),
    "reviolaceras": ("reviolacer",),
    "reviolacèrent": ("reviolacer",),
    "reviolacerez": ("reviolacer",),
    "reviolaceriez": ("reviolacer",),
    "reviolacerions": ("reviolacer",),
    "reviolacerons": ("reviolacer",),
    "reviolaceront": ("reviolacer",),
    "reviolacés": ("reviolacer",),
    "reviolaces": ("reviolacer",),
    "reviolacez": ("reviolacer",),
    "reviolaciez": ("reviolacer",),
    "reviolacions": ("reviolacer",),
    "reviolaçons": ("reviolacer",),
    "revivifiaient": ("revivifier",),
    "revivifiai": ("revivifier",),
    "revivifiais": ("revivifier",),
    "revivifiait": ("revivifier",),
    "revivifia": ("revivifier",),
    "revivifiâmes": ("revivifier",),
    "revivifiant": ("revivifier",),
    "revivifias": ("revivifier",),
    "revivifiassent": ("revivifier",),
    "revivifiasses": ("revivifier",),
    "revivifiasse": ("revivifier",),
    "revivifiassiez": ("revivifier",),
    "revivifiassions": ("revivifier",),
    "revivifiâtes": ("revivifier",),
    "revivifiât": ("revivifier",),
    "revivifiée": ("revivifier",),
    "revivifiées": ("revivifier",),
    "revivifié": ("revivifier",),
    "revivifient": ("revivifier",),
    "revivifie": ("revivifier",),
    "revivifiera": ("revivifier",),
    "revivifieraient": ("revivifier",),
    "revivifierai": ("revivifier",),
    "revivifierais": ("revivifier",),
    "revivifierait": ("revivifier",),
    "revivifieras": ("revivifier",),
    "revivifièrent": ("revivifier",),
    "revivifierez": ("revivifier",),
    "revivifieriez": ("revivifier",),
    "revivifierions": ("revivifier",),
    "revivifierons": ("revivifier",),
    "revivifieront": ("revivifier",),
    "revivifiés": ("revivifier",),
    "revivifies": ("revivifier",),
    "revivifiez": ("revivifier",),
    "revivifiiez": ("revivifier",),
    "revivifiions": ("revivifier",),
    "revivifions": ("revivifier",),
    "revécue": ("revivre",),
    "revécues": ("revivre",),
    "revécu": ("revivre",),
    "revécûmes": ("revivre",),
    "revécurent": ("revivre",),
    "revécus": ("revivre",),
    "revécussent": ("revivre",),
    "revécusses": ("revivre",),
    "revécusse": ("revivre",),
    "revécussiez": ("revivre",),
    "revécussions": ("revivre",),
    "revécûtes": ("revivre",),
    "revécut": ("revivre",),
    "revécût": ("revivre",),
    "revis": ("revoir",),
    "revit": ("revoir",),
    "revivaient": ("revivre",),
    "revivais": ("revivre",),
    "revivait": ("revivre",),
    "revivant": ("revivre",),
    "revivent": ("revivre",),
    "revive": ("revivre",),
    "revives": ("revivre",),
    "revivez": ("revivre",),
    "reviviez": ("revivre",),
    "revivions": ("revivre",),
    "revivons": ("revivre",),
    "revivra": ("revivre",),
    "revivraient": ("revivre",),
    "revivrai": ("revivre",),
    "revivrais": ("revivre",),
    "revivrait": ("revivre",),
    "revivras": ("revivre",),
    "revivrez": ("revivre",),
    "revivriez": ("revivre",),
    "revivrions": ("revivre",),
    "revivrons": ("revivre",),
    "revivront": ("revivre",),
    "reverra": ("revoir",),
    "reverraient": ("revoir",),
    "reverrai": ("revoir",),
    "reverrais": ("revoir",),
    "reverrait": ("revoir",),
    "reverras": ("revoir",),
    "reverrez": ("revoir",),
    "reverriez": ("revoir",),
    "reverrions": ("revoir",),
    "reverrons": ("revoir",),
    "reverront": ("revoir",),
    "revîmes": ("revoir",),
    "revirent": ("revoir",),
    "revissent": ("revoir",),
    "revisses": ("revoir",),
    "revisse": ("revoir",),
    "revissiez": ("revoir",),
    "revissions": ("revoir",),
    "revîtes": ("revoir",),
    "revît": ("revoir",),
    "revoient": ("revoir",),
    "revoie": ("revoir",),
    "revoies": ("revoir",),
    "revois": ("revoir",),
    "revoit": ("revoir",),
    "revoyaient": ("revoir",),
    "revoyais": ("revoir",),
    "revoyait": ("revoir",),
    "revoyant": ("revoir",),
    "revoyez": ("revoir",),
    "revoyiez": ("revoir",),
    "revoyions": ("revoir",),
    "revoyons": ("revoir",),
    "revue": ("revoir",),
    "revues": ("revoir",),
    "revu": ("revoir",),
    "revus": ("revoir",),
    "revomie": ("revomir",),
    "revomies": ("revomir",),
    "revomi": ("revomir",),
    "revomîmes": ("revomir",),
    "revomira": ("revomir",),
    "revomiraient": ("revomir",),
    "revomirai": ("revomir",),
    "revomirais": ("revomir",),
    "revomirait": ("revomir",),
    "revomiras": ("revomir",),
    "revomirent": ("revomir",),
    "revomirez": ("revomir",),
    "revomiriez": ("revomir",),
    "revomirions": ("revomir",),
    "revomirons": ("revomir",),
    "revomiront": ("revomir",),
    "revomis": ("revomir",),
    "revomissaient": ("revomir",),
    "revomissais": ("revomir",),
    "revomissait": ("revomir",),
    "revomissant": ("revomir",),
    "revomissent": ("revomir",),
    "revomisse": ("revomir",),
    "revomisses": ("revomir",),
    "revomissez": ("revomir",),
    "revomissiez": ("revomir",),
    "revomissions": ("revomir",),
    "revomissons": ("revomir",),
    "revomîtes": ("revomir",),
    "revomit": ("revomir",),
    "revomît": ("revomir",),
    "reveuillent": ("revouloir",),
    "reveuille": ("revouloir",),
    "reveuilles": ("revouloir",),
    "reveuillez": ("revouloir",),
    "reveuillons": ("revouloir",),
    "reveulent": ("revouloir",),
    "reveut": ("revouloir",),
    "reveux": ("revouloir",),
    "revoudra": ("revouloir",),
    "revoudraient": ("revouloir",),
    "revoudrai": ("revouloir",),
    "revoudrais": ("revouloir",),
    "revoudrait": ("revouloir",),
    "revoudras": ("revouloir",),
    "revoudrez": ("revouloir",),
    "revoudriez": ("revouloir",),
    "revoudrions": ("revouloir",),
    "revoudrons": ("revouloir",),
    "revoudront": ("revouloir",),
    "revoulaient": ("revouloir",),
    "revoulais": ("revouloir",),
    "revoulait": ("revouloir",),
    "revoulant": ("revouloir",),
    "revoulez": ("revouloir",),
    "revouliez": ("revouloir",),
    "revoulions": ("revouloir",),
    "revoulons": ("revouloir",),
    "revoulue": ("revouloir",),
    "revoulues": ("revouloir",),
    "revoulu": ("revouloir",),
    "revoulûmes": ("revouloir",),
    "revoulurent": ("revouloir",),
    "revoulus": ("revouloir",),
    "revoulussent": ("revouloir",),
    "revoulusses": ("revouloir",),
    "revoulusse": ("revouloir",),
    "revoulussiez": ("revouloir",),
    "revoulussions": ("revouloir",),
    "revoulûtes": ("revouloir",),
    "revoulut": ("revouloir",),
    "revoulût": ("revouloir",),
    "revoyageaient": ("revoyager",),
    "revoyageai": ("revoyager",),
    "revoyageais": ("revoyager",),
    "revoyageait": ("revoyager",),
    "revoyagea": ("revoyager",),
    "revoyageâmes": ("revoyager",),
    "revoyageant": ("revoyager",),
    "revoyageas": ("revoyager",),
    "revoyageassent": ("revoyager",),
    "revoyageasses": ("revoyager",),
    "revoyageasse": ("revoyager",),
    "revoyageassiez": ("revoyager",),
    "revoyageassions": ("revoyager",),
    "revoyageâtes": ("revoyager",),
    "revoyageât": ("revoyager",),
    "revoyagé": ("revoyager",),
    "revoyagent": ("revoyager",),
    "revoyageons": ("revoyager",),
    "revoyage": ("revoyager",),
    "revoyagera": ("revoyager",),
    "revoyageraient": ("revoyager",),
    "revoyagerai": ("revoyager",),
    "revoyagerais": ("revoyager",),
    "revoyagerait": ("revoyager",),
    "revoyageras": ("revoyager",),
    "revoyagèrent": ("revoyager",),
    "revoyagerez": ("revoyager",),
    "revoyageriez": ("revoyager",),
    "revoyagerions": ("revoyager",),
    "revoyagerons": ("revoyager",),
    "revoyageront": ("revoyager",),
    "revoyages": ("revoyager",),
    "revoyagez": ("revoyager",),
    "revoyagiez": ("revoyager",),
    "revoyagions": ("revoyager",),
    "rhodiaient": ("rhodier",),
    "rhodiai": ("rhodier",),
    "rhodiais": ("rhodier",),
    "rhodiait": ("rhodier",),
    "rhodia": ("rhodier",),
    "rhodiâmes": ("rhodier",),
    "rhodiant": ("rhodier",),
    "rhodias": ("rhodier",),
    "rhodiassent": ("rhodier",),
    "rhodiasses": ("rhodier",),
    "rhodiasse": ("rhodier",),
    "rhodiassiez": ("rhodier",),
    "rhodiassions": ("rhodier",),
    "rhodiâtes": ("rhodier",),
    "rhodiât": ("rhodier",),
    "rhodiée": ("rhodier",),
    "rhodiées": ("rhodier",),
    "rhodié": ("rhodier",),
    "rhodient": ("rhodier",),
    "rhodie": ("rhodier",),
    "rhodiera": ("rhodier",),
    "rhodieraient": ("rhodier",),
    "rhodierai": ("rhodier",),
    "rhodierais": ("rhodier",),
    "rhodierait": ("rhodier",),
    "rhodieras": ("rhodier",),
    "rhodièrent": ("rhodier",),
    "rhodierez": ("rhodier",),
    "rhodieriez": ("rhodier",),
    "rhodierions": ("rhodier",),
    "rhodierons": ("rhodier",),
    "rhodieront": ("rhodier",),
    "rhodiés": ("rhodier",),
    "rhodies": ("rhodier",),
    "rhodiez": ("rhodier",),
    "rhodiiez": ("rhodier",),
    "rhodiions": ("rhodier",),
    "rhodions": ("rhodier",),
    "ricassaient": ("ricasser",),
    "ricassai": ("ricasser",),
    "ricassais": ("ricasser",),
    "ricassait": ("ricasser",),
    "ricassa": ("ricasser",),
    "ricassâmes": ("ricasser",),
    "ricassant": ("ricasser",),
    "ricassas": ("ricasser",),
    "ricassassent": ("ricasser",),
    "ricassasses": ("ricasser",),
    "ricassasse": ("ricasser",),
    "ricassassiez": ("ricasser",),
    "ricassassions": ("ricasser",),
    "ricassâtes": ("ricasser",),
    "ricassât": ("ricasser",),
    "ricassée": ("ricasser",),
    "ricassées": ("ricasser",),
    "ricassé": ("ricasser",),
    "ricassent": ("ricasser",),
    "ricasse": ("ricasser",),
    "ricassera": ("ricasser",),
    "ricasseraient": ("ricasser",),
    "ricasserai": ("ricasser",),
    "ricasserais": ("ricasser",),
    "ricasserait": ("ricasser",),
    "ricasseras": ("ricasser",),
    "ricassèrent": ("ricasser",),
    "ricasserez": ("ricasser",),
    "ricasseriez": ("ricasser",),
    "ricasserions": ("ricasser",),
    "ricasserons": ("ricasser",),
    "ricasseront": ("ricasser",),
    "ricassés": ("ricasser",),
    "ricasses": ("ricasser",),
    "ricassez": ("ricasser",),
    "ricassiez": ("ricasser",),
    "ricassions": ("ricasser",),
    "ricassons": ("ricasser",),
    "ridelaient": ("rideler",),
    "ridelai": ("rideler",),
    "ridelais": ("rideler",),
    "ridelait": ("rideler",),
    "ridela": ("rideler",),
    "ridelâmes": ("rideler",),
    "ridelant": ("rideler",),
    "ridelas": ("rideler",),
    "ridelassent": ("rideler",),
    "ridelasses": ("rideler",),
    "ridelasse": ("rideler",),
    "ridelassiez": ("rideler",),
    "ridelassions": ("rideler",),
    "ridelâtes": ("rideler",),
    "ridelât": ("rideler",),
    "ridelée": ("rideler",),
    "ridelées": ("rideler",),
    "ridelé": ("rideler",),
    "ridelèrent": ("rideler",),
    "ridelés": ("rideler",),
    "ridelez": ("rideler",),
    "rideliez": ("rideler",),
    "ridelions": ("rideler",),
    "ridellent": ("rideler",),
    "ridelle": ("rideler",),
    "ridellera": ("rideler",),
    "ridelleraient": ("rideler",),
    "ridellerai": ("rideler",),
    "ridellerais": ("rideler",),
    "ridellerait": ("rideler",),
    "ridelleras": ("rideler",),
    "ridellerez": ("rideler",),
    "ridelleriez": ("rideler",),
    "ridellerions": ("rideler",),
    "ridellerons": ("rideler",),
    "ridelleront": ("rideler",),
    "ridelles": ("rideler",),
    "ridelons": ("rideler",),
    "rigidifiaient": ("rigidifier",),
    "rigidifiai": ("rigidifier",),
    "rigidifiais": ("rigidifier",),
    "rigidifiait": ("rigidifier",),
    "rigidifia": ("rigidifier",),
    "rigidifiâmes": ("rigidifier",),
    "rigidifiant": ("rigidifier",),
    "rigidifias": ("rigidifier",),
    "rigidifiassent": ("rigidifier",),
    "rigidifiasses": ("rigidifier",),
    "rigidifiasse": ("rigidifier",),
    "rigidifiassiez": ("rigidifier",),
    "rigidifiassions": ("rigidifier",),
    "rigidifiâtes": ("rigidifier",),
    "rigidifiât": ("rigidifier",),
    "rigidifiée": ("rigidifier",),
    "rigidifiées": ("rigidifier",),
    "rigidifié": ("rigidifier",),
    "rigidifient": ("rigidifier",),
    "rigidifie": ("rigidifier",),
    "rigidifiera": ("rigidifier",),
    "rigidifieraient": ("rigidifier",),
    "rigidifierai": ("rigidifier",),
    "rigidifierais": ("rigidifier",),
    "rigidifierait": ("rigidifier",),
    "rigidifieras": ("rigidifier",),
    "rigidifièrent": ("rigidifier",),
    "rigidifierez": ("rigidifier",),
    "rigidifieriez": ("rigidifier",),
    "rigidifierions": ("rigidifier",),
    "rigidifierons": ("rigidifier",),
    "rigidifieront": ("rigidifier",),
    "rigidifiés": ("rigidifier",),
    "rigidifies": ("rigidifier",),
    "rigidifiez": ("rigidifier",),
    "rigidifiiez": ("rigidifier",),
    "rigidifiions": ("rigidifier",),
    "rigidifions": ("rigidifier",),
    "rinçaient": ("rincer",),
    "rinçai": ("rincer",),
    "rinçais": ("rincer",),
    "rinçait": ("rincer",),
    "rinça": ("rincer",),
    "rinçâmes": ("rincer",),
    "rinçant": ("rincer",),
    "rinças": ("rincer",),
    "rinçassent": ("rincer",),
    "rinçasses": ("rincer",),
    "rinçasse": ("rincer",),
    "rinçassiez": ("rincer",),
    "rinçassions": ("rincer",),
    "rinçâtes": ("rincer",),
    "rinçât": ("rincer",),
    "rincée": ("rincer",),
    "rincées": ("rincer",),
    "rincé": ("rincer",),
    "rincent": ("rincer",),
    "rince": ("rincer",),
    "rincera": ("rincer",),
    "rinceraient": ("rincer",),
    "rincerai": ("rincer",),
    "rincerais": ("rincer",),
    "rincerait": ("rincer",),
    "rinceras": ("rincer",),
    "rincèrent": ("rincer",),
    "rincerez": ("rincer",),
    "rinceriez": ("rincer",),
    "rincerions": ("rincer",),
    "rincerons": ("rincer",),
    "rinceront": ("rincer",),
    "rincés": ("rincer",),
    "rinces": ("rincer",),
    "rincez": ("rincer",),
    "rinciez": ("rincer",),
    "rincions": ("rincer",),
    "rinçons": ("rincer",),
    "riaient": ("rire",),
    "riais": ("rire",),
    "riait": ("rire",),
    "riant": ("rire",),
    "rient": ("rire",),
    "rie": ("rire",),
    "ries": ("rire",),
    "riez": ("rire",),
    "riiez": ("rire",),
    "riions": ("rire",),
    "ri": ("rire",),
    "rîmes": ("rire",),
    "rions": ("rire",),
    "rira": ("rire",),
    "riraient": ("rire",),
    "rirai": ("rire",),
    "rirais": ("rire",),
    "rirait": ("rire",),
    "riras": ("rire",),
    "rirent": ("rire",),
    "rirez": ("rire",),
    "ririez": ("rire",),
    "ririons": ("rire",),
    "rirons": ("rire",),
    "riront": ("rire",),
    "ris": ("rire",),
    "rissent": ("rire",),
    "risses": ("rire",),
    "risse": ("rire",),
    "rissiez": ("rire",),
    "rissions": ("rire",),
    "rîtes": ("rire",),
    "rit": ("rire",),
    "rît": ("rire",),
    "rivetaient": ("riveter",),
    "rivetai": ("riveter",),
    "rivetais": ("riveter",),
    "rivetait": ("riveter",),
    "riveta": ("riveter",),
    "rivetâmes": ("riveter",),
    "rivetant": ("riveter",),
    "rivetas": ("riveter",),
    "rivetassent": ("riveter",),
    "rivetasses": ("riveter",),
    "rivetasse": ("riveter",),
    "rivetassiez": ("riveter",),
    "rivetassions": ("riveter",),
    "rivetâtes": ("riveter",),
    "rivetât": ("riveter",),
    "rivetée": ("riveter",),
    "rivetées": ("riveter",),
    "riveté": ("riveter",),
    "rivetèrent": ("riveter",),
    "rivetés": ("riveter",),
    "rivetez": ("riveter",),
    "rivetiez": ("riveter",),
    "rivetions": ("riveter",),
    "rivetons": ("riveter",),
    "rivettent": ("riveter",),
    "rivette": ("riveter",),
    "rivettera": ("riveter",),
    "rivetteraient": ("riveter",),
    "rivetterai": ("riveter",),
    "rivetterais": ("riveter",),
    "rivetterait": ("riveter",),
    "rivetteras": ("riveter",),
    "rivetterez": ("riveter",),
    "rivetteriez": ("riveter",),
    "rivetterions": ("riveter",),
    "rivetterons": ("riveter",),
    "rivetteront": ("riveter",),
    "rivettes": ("riveter",),
    "robelaient": ("robeler",),
    "robelai": ("robeler",),
    "robelais": ("robeler",),
    "robelait": ("robeler",),
    "robela": ("robeler",),
    "robelâmes": ("robeler",),
    "robelant": ("robeler",),
    "robelas": ("robeler",),
    "robelassent": ("robeler",),
    "robelasses": ("robeler",),
    "robelasse": ("robeler",),
    "robelassiez": ("robeler",),
    "robelassions": ("robeler",),
    "robelâtes": ("robeler",),
    "robelât": ("robeler",),
    "robelée": ("robeler",),
    "robelées": ("robeler",),
    "robelé": ("robeler",),
    "robèlent": ("robeler",),
    "robèle": ("robeler",),
    "robèlera": ("robeler",),
    "robèleraient": ("robeler",),
    "robèlerai": ("robeler",),
    "robèlerais": ("robeler",),
    "robèlerait": ("robeler",),
    "robèleras": ("robeler",),
    "robelèrent": ("robeler",),
    "robèlerez": ("robeler",),
    "robèleriez": ("robeler",),
    "robèlerions": ("robeler",),
    "robèlerons": ("robeler",),
    "robèleront": ("robeler",),
    "robelés": ("robeler",),
    "robèles": ("robeler",),
    "robelez": ("robeler",),
    "robeliez": ("robeler",),
    "robelions": ("robeler",),
    "robelons": ("robeler",),
    "rofferte": ("roffrir",),
    "roffertes": ("roffrir",),
    "roffert": ("roffrir",),
    "rofferts": ("roffrir",),
    "roffraient": ("roffrir",),
    "roffrais": ("roffrir",),
    "roffrait": ("roffrir",),
    "roffrant": ("roffrir",),
    "roffrent": ("roffrir",),
    "roffre": ("roffrir",),
    "roffres": ("roffrir",),
    "roffrez": ("roffrir",),
    "roffriez": ("roffrir",),
    "roffrîmes": ("roffrir",),
    "roffrions": ("roffrir",),
    "roffrira": ("roffrir",),
    "roffriraient": ("roffrir",),
    "roffrirai": ("roffrir",),
    "roffrirais": ("roffrir",),
    "roffrirait": ("roffrir",),
    "roffriras": ("roffrir",),
    "roffrirent": ("roffrir",),
    "roffrirez": ("roffrir",),
    "roffririez": ("roffrir",),
    "roffririons": ("roffrir",),
    "roffrirons": ("roffrir",),
    "roffriront": ("roffrir",),
    "roffris": ("roffrir",),
    "roffrissent": ("roffrir",),
    "roffrisses": ("roffrir",),
    "roffrisse": ("roffrir",),
    "roffrissiez": ("roffrir",),
    "roffrissions": ("roffrir",),
    "roffrîtes": ("roffrir",),
    "roffrit": ("roffrir",),
    "roffrît": ("roffrir",),
    "roffrons": ("roffrir",),
    "roidie": ("roidir",),
    "roidies": ("roidir",),
    "roidi": ("roidir",),
    "roidîmes": ("roidir",),
    "roidira": ("roidir",),
    "roidiraient": ("roidir",),
    "roidirai": ("roidir",),
    "roidirais": ("roidir",),
    "roidirait": ("roidir",),
    "roidiras": ("roidir",),
    "roidirent": ("roidir",),
    "roidirez": ("roidir",),
    "roidiriez": ("roidir",),
    "roidirions": ("roidir",),
    "roidirons": ("roidir",),
    "roidiront": ("roidir",),
    "roidis": ("roidir",),
    "roidissaient": ("roidir",),
    "roidissais": ("roidir",),
    "roidissait": ("roidir",),
    "roidissant": ("roidir",),
    "roidissent": ("roidir",),
    "roidisse": ("roidir",),
    "roidisses": ("roidir",),
    "roidissez": ("roidir",),
    "roidissiez": ("roidir",),
    "roidissions": ("roidir",),
    "roidissons": ("roidir",),
    "roidîtes": ("roidir",),
    "roidit": ("roidir",),
    "roidît": ("roidir",),
    "romançaient": ("romancer",),
    "romançai": ("romancer",),
    "romançais": ("romancer",),
    "romançait": ("romancer",),
    "romança": ("romancer",),
    "romançâmes": ("romancer",),
    "romançant": ("romancer",),
    "romanças": ("romancer",),
    "romançassent": ("romancer",),
    "romançasses": ("romancer",),
    "romançasse": ("romancer",),
    "romançassiez": ("romancer",),
    "romançassions": ("romancer",),
    "romançâtes": ("romancer",),
    "romançât": ("romancer",),
    "romancée": ("romancer",),
    "romancées": ("romancer",),
    "romancé": ("romancer",),
    "romancent": ("romancer",),
    "romance": ("romancer",),
    "romancera": ("romancer",),
    "romanceraient": ("romancer",),
    "romancerai": ("romancer",),
    "romancerais": ("romancer",),
    "romancerait": ("romancer",),
    "romanceras": ("romancer",),
    "romancèrent": ("romancer",),
    "romancerez": ("romancer",),
    "romanceriez": ("romancer",),
    "romancerions": ("romancer",),
    "romancerons": ("romancer",),
    "romanceront": ("romancer",),
    "romancés": ("romancer",),
    "romances": ("romancer",),
    "romancez": ("romancer",),
    "romanciez": ("romancer",),
    "romancions": ("romancer",),
    "romançons": ("romancer",),
    "rompaient": ("rompre",),
    "rompais": ("rompre",),
    "rompait": ("rompre",),
    "rompant": ("rompre",),
    "rompent": ("rompre",),
    "rompe": ("rompre",),
    "rompes": ("rompre",),
    "rompez": ("rompre",),
    "rompiez": ("rompre",),
    "rompîmes": ("rompre",),
    "rompions": ("rompre",),
    "rompirent": ("rompre",),
    "rompis": ("rompre",),
    "rompissent": ("rompre",),
    "rompisses": ("rompre",),
    "rompisse": ("rompre",),
    "rompissiez": ("rompre",),
    "rompissions": ("rompre",),
    "rompîtes": ("rompre",),
    "rompit": ("rompre",),
    "rompît": ("rompre",),
    "rompons": ("rompre",),
    "rompra": ("rompre",),
    "rompraient": ("rompre",),
    "romprai": ("rompre",),
    "romprais": ("rompre",),
    "romprait": ("rompre",),
    "rompras": ("rompre",),
    "romprez": ("rompre",),
    "rompriez": ("rompre",),
    "romprions": ("rompre",),
    "romprons": ("rompre",),
    "rompront": ("rompre",),
    "romps": ("rompre",),
    "rompt": ("rompre",),
    "rompue": ("rompre",),
    "rompues": ("rompre",),
    "rompu": ("rompre",),
    "rompus": ("rompre",),
    "rondie": ("rondir",),
    "rondies": ("rondir",),
    "rondi": ("rondir",),
    "rondîmes": ("rondir",),
    "rondira": ("rondir",),
    "rondiraient": ("rondir",),
    "rondirai": ("rondir",),
    "rondirais": ("rondir",),
    "rondirait": ("rondir",),
    "rondiras": ("rondir",),
    "rondirent": ("rondir",),
    "rondirez": ("rondir",),
    "rondiriez": ("rondir",),
    "rondirions": ("rondir",),
    "rondirons": ("rondir",),
    "rondiront": ("rondir",),
    "rondis": ("rondir",),
    "rondissaient": ("rondir",),
    "rondissais": ("rondir",),
    "rondissait": ("rondir",),
    "rondissant": ("rondir",),
    "rondissent": ("rondir",),
    "rondisse": ("rondir",),
    "rondisses": ("rondir",),
    "rondissez": ("rondir",),
    "rondissiez": ("rondir",),
    "rondissions": ("rondir",),
    "rondissons": ("rondir",),
    "rondîtes": ("rondir",),
    "rondit": ("rondir",),
    "rondît": ("rondir",),
    "rongeaient": ("ronger",),
    "rongeai": ("ronger",),
    "rongeais": ("ronger",),
    "rongeait": ("ronger",),
    "rongea": ("ronger",),
    "rongeâmes": ("ronger",),
    "rongeant": ("ronger",),
    "rongeas": ("ronger",),
    "rongeassent": ("ronger",),
    "rongeasses": ("ronger",),
    "rongeasse": ("ronger",),
    "rongeassiez": ("ronger",),
    "rongeassions": ("ronger",),
    "rongeâtes": ("ronger",),
    "rongeât": ("ronger",),
    "rongée": ("ronger",),
    "rongées": ("ronger",),
    "rongé": ("ronger",),
    "rongent": ("ronger",),
    "rongeons": ("ronger",),
    "ronge": ("ronger",),
    "rongera": ("ronger",),
    "rongeraient": ("ronger",),
    "rongerai": ("ronger",),
    "rongerais": ("ronger",),
    "rongerait": ("ronger",),
    "rongeras": ("ronger",),
    "rongèrent": ("ronger",),
    "rongerez": ("ronger",),
    "rongeriez": ("ronger",),
    "rongerions": ("ronger",),
    "rongerons": ("ronger",),
    "rongeront": ("ronger",),
    "rongés": ("ronger",),
    "ronges": ("ronger",),
    "rongez": ("ronger",),
    "rongiez": ("ronger",),
    "rongions": ("ronger",),
    "rosie": ("rosir",),
    "rosies": ("rosir",),
    "rosi": ("rosir",),
    "rosîmes": ("rosir",),
    "rosira": ("rosir",),
    "rosiraient": ("rosir",),
    "rosirai": ("rosir",),
    "rosirais": ("rosir",),
    "rosirait": ("rosir",),
    "rosiras": ("rosir",),
    "rosirent": ("rosir",),
    "rosirez": ("rosir",),
    "rosiriez": ("rosir",),
    "rosirions": ("rosir",),
    "rosirons": ("rosir",),
    "rosiront": ("rosir",),
    "rosis": ("rosir",),
    "rosissaient": ("rosir",),
    "rosissais": ("rosir",),
    "rosissait": ("rosir",),
    "rosissant": ("rosir",),
    "rosissent": ("rosir",),
    "rosisse": ("rosir",),
    "rosisses": ("rosir",),
    "rosissez": ("rosir",),
    "rosissiez": ("rosir",),
    "rosissions": ("rosir",),
    "rosissons": ("rosir",),
    "rosîtes": ("rosir",),
    "rosit": ("rosir",),
    "rosît": ("rosir",),
    "rosoient": ("rosoyer",),
    "rosoie": ("rosoyer",),
    "rosoiera": ("rosoyer",),
    "rosoieraient": ("rosoyer",),
    "rosoierai": ("rosoyer",),
    "rosoierais": ("rosoyer",),
    "rosoierait": ("rosoyer",),
    "rosoieras": ("rosoyer",),
    "rosoierez": ("rosoyer",),
    "rosoieriez": ("rosoyer",),
    "rosoierions": ("rosoyer",),
    "rosoierons": ("rosoyer",),
    "rosoieront": ("rosoyer",),
    "rosoies": ("rosoyer",),
    "rosoyaient": ("rosoyer",),
    "rosoyai": ("rosoyer",),
    "rosoyais": ("rosoyer",),
    "rosoyait": ("rosoyer",),
    "rosoya": ("rosoyer",),
    "rosoyâmes": ("rosoyer",),
    "rosoyant": ("rosoyer",),
    "rosoyas": ("rosoyer",),
    "rosoyassent": ("rosoyer",),
    "rosoyasses": ("rosoyer",),
    "rosoyasse": ("rosoyer",),
    "rosoyassiez": ("rosoyer",),
    "rosoyassions": ("rosoyer",),
    "rosoyâtes": ("rosoyer",),
    "rosoyât": ("rosoyer",),
    "rosoyée": ("rosoyer",),
    "rosoyées": ("rosoyer",),
    "rosoyé": ("rosoyer",),
    "rosoyèrent": ("rosoyer",),
    "rosoyés": ("rosoyer",),
    "rosoyez": ("rosoyer",),
    "rosoyiez": ("rosoyer",),
    "rosoyions": ("rosoyer",),
    "rosoyons": ("rosoyer",),
    "rôtie": ("rôtir",),
    "rôties": ("rôtir",),
    "rôti": ("rôtir",),
    "rôtîmes": ("rôtir",),
    "rôtira": ("rôtir",),
    "rôtiraient": ("rôtir",),
    "rôtirai": ("rôtir",),
    "rôtirais": ("rôtir",),
    "rôtirait": ("rôtir",),
    "rôtiras": ("rôtir",),
    "rôtirent": ("rôtir",),
    "rôtirez": ("rôtir",),
    "rôtiriez": ("rôtir",),
    "rôtirions": ("rôtir",),
    "rôtirons": ("rôtir",),
    "rôtiront": ("rôtir",),
    "rôtis": ("rôtir",),
    "rôtissaient": ("rôtir",),
    "rôtissais": ("rôtir",),
    "rôtissait": ("rôtir",),
    "rôtissant": ("rôtir",),
    "rôtissent": ("rôtir",),
    "rôtisse": ("rôtir",),
    "rôtisses": ("rôtir",),
    "rôtissez": ("rôtir",),
    "rôtissiez": ("rôtir",),
    "rôtissions": ("rôtir",),
    "rôtissons": ("rôtir",),
    "rôtîtes": ("rôtir",),
    "rôtit": ("rôtir",),
    "rôtît": ("rôtir",),
    "rougeoient": ("rougeoyer",),
    "rougeoie": ("rougeoyer",),
    "rougeoiera": ("rougeoyer",),
    "rougeoieraient": ("rougeoyer",),
    "rougeoierai": ("rougeoyer",),
    "rougeoierais": ("rougeoyer",),
    "rougeoierait": ("rougeoyer",),
    "rougeoieras": ("rougeoyer",),
    "rougeoierez": ("rougeoyer",),
    "rougeoieriez": ("rougeoyer",),
    "rougeoierions": ("rougeoyer",),
    "rougeoierons": ("rougeoyer",),
    "rougeoieront": ("rougeoyer",),
    "rougeoies": ("rougeoyer",),
    "rougeoyaient": ("rougeoyer",),
    "rougeoyai": ("rougeoyer",),
    "rougeoyais": ("rougeoyer",),
    "rougeoyait": ("rougeoyer",),
    "rougeoya": ("rougeoyer",),
    "rougeoyâmes": ("rougeoyer",),
    "rougeoyant": ("rougeoyer",),
    "rougeoyas": ("rougeoyer",),
    "rougeoyassent": ("rougeoyer",),
    "rougeoyasses": ("rougeoyer",),
    "rougeoyasse": ("rougeoyer",),
    "rougeoyassiez": ("rougeoyer",),
    "rougeoyassions": ("rougeoyer",),
    "rougeoyâtes": ("rougeoyer",),
    "rougeoyât": ("rougeoyer",),
    "rougeoyée": ("rougeoyer",),
    "rougeoyées": ("rougeoyer",),
    "rougeoyé": ("rougeoyer",),
    "rougeoyèrent": ("rougeoyer",),
    "rougeoyés": ("rougeoyer",),
    "rougeoyez": ("rougeoyer",),
    "rougeoyiez": ("rougeoyer",),
    "rougeoyions": ("rougeoyer",),
    "rougeoyons": ("rougeoyer",),
    "rougie": ("rougir",),
    "rougies": ("rougir",),
    "rougi": ("rougir",),
    "rougîmes": ("rougir",),
    "rougira": ("rougir",),
    "rougiraient": ("rougir",),
    "rougirai": ("rougir",),
    "rougirais": ("rougir",),
    "rougirait": ("rougir",),
    "rougiras": ("rougir",),
    "rougirent": ("rougir",),
    "rougirez": ("rougir",),
    "rougiriez": ("rougir",),
    "rougirions": ("rougir",),
    "rougirons": ("rougir",),
    "rougiront": ("rougir",),
    "rougis": ("rougir",),
    "rougissaient": ("rougir",),
    "rougissais": ("rougir",),
    "rougissait": ("rougir",),
    "rougissant": ("rougir",),
    "rougissent": ("rougir",),
    "rougisse": ("rougir",),
    "rougisses": ("rougir",),
    "rougissez": ("rougir",),
    "rougissiez": ("rougir",),
    "rougissions": ("rougir",),
    "rougissons": ("rougir",),
    "rougîtes": ("rougir",),
    "rougit": ("rougir",),
    "rougît": ("rougir",),
    "rouie": ("rouir",),
    "rouies": ("rouir",),
    "roui": ("rouir",),
    "rouîmes": ("rouir",),
    "rouira": ("rouir",),
    "rouiraient": ("rouir",),
    "rouirai": ("rouir",),
    "rouirais": ("rouir",),
    "rouirait": ("rouir",),
    "rouiras": ("rouir",),
    "rouirent": ("rouir",),
    "rouirez": ("rouir",),
    "rouiriez": ("rouir",),
    "rouirions": ("rouir",),
    "rouirons": ("rouir",),
    "rouiront": ("rouir",),
    "rouis": ("rouir",),
    "rouissaient": ("rouir",),
    "rouissais": ("rouir",),
    "rouissait": ("rouir",),
    "rouissant": ("rouir",),
    "rouissent": ("rouir",),
    "rouisse": ("rouir",),
    "rouisses": ("rouir",),
    "rouissez": ("rouir",),
    "rouissiez": ("rouir",),
    "rouissions": ("rouir",),
    "rouissons": ("rouir",),
    "rouîtes": ("rouir",),
    "rouit": ("rouir",),
    "rouît": ("rouir",),
    "rouspétaient": ("rouspéter",),
    "rouspétai": ("rouspéter",),
    "rouspétais": ("rouspéter",),
    "rouspétait": ("rouspéter",),
    "rouspéta": ("rouspéter",),
    "rouspétâmes": ("rouspéter",),
    "rouspétant": ("rouspéter",),
    "rouspétas": ("rouspéter",),
    "rouspétassent": ("rouspéter",),
    "rouspétasses": ("rouspéter",),
    "rouspétasse": ("rouspéter",),
    "rouspétassiez": ("rouspéter",),
    "rouspétassions": ("rouspéter",),
    "rouspétâtes": ("rouspéter",),
    "rouspétât": ("rouspéter",),
    "rouspété": ("rouspéter",),
    "rouspètent": ("rouspéter",),
    "rouspète": ("rouspéter",),
    "rouspétera": ("rouspéter",),
    "rouspéteraient": ("rouspéter",),
    "rouspéterai": ("rouspéter",),
    "rouspéterais": ("rouspéter",),
    "rouspéterait": ("rouspéter",),
    "rouspéteras": ("rouspéter",),
    "rouspétèrent": ("rouspéter",),
    "rouspéterez": ("rouspéter",),
    "rouspéteriez": ("rouspéter",),
    "rouspéterions": ("rouspéter",),
    "rouspéterons": ("rouspéter",),
    "rouspéteront": ("rouspéter",),
    "rouspètes": ("rouspéter",),
    "rouspétez": ("rouspéter",),
    "rouspétiez": ("rouspéter",),
    "rouspétions": ("rouspéter",),
    "rouspétons": ("rouspéter",),
    "rousselaient": ("rousseler",),
    "rousselai": ("rousseler",),
    "rousselais": ("rousseler",),
    "rousselait": ("rousseler",),
    "roussela": ("rousseler",),
    "rousselâmes": ("rousseler",),
    "rousselant": ("rousseler",),
    "rousselas": ("rousseler",),
    "rousselassent": ("rousseler",),
    "rousselasses": ("rousseler",),
    "rousselasse": ("rousseler",),
    "rousselassiez": ("rousseler",),
    "rousselassions": ("rousseler",),
    "rousselâtes": ("rousseler",),
    "rousselât": ("rousseler",),
    "rousselée": ("rousseler",),
    "rousselées": ("rousseler",),
    "rousselé": ("rousseler",),
    "rousselèrent": ("rousseler",),
    "rousselés": ("rousseler",),
    "rousselez": ("rousseler",),
    "rousseliez": ("rousseler",),
    "rousselions": ("rousseler",),
    "roussellent": ("rousseler",),
    "rousselle": ("rousseler",),
    "roussellera": ("rousseler",),
    "rousselleraient": ("rousseler",),
    "roussellerai": ("rousseler",),
    "roussellerais": ("rousseler",),
    "roussellerait": ("rousseler",),
    "rousselleras": ("rousseler",),
    "roussellerez": ("rousseler",),
    "rousselleriez": ("rousseler",),
    "roussellerions": ("rousseler",),
    "roussellerons": ("rousseler",),
    "rousselleront": ("rousseler",),
    "rousselles": ("rousseler",),
    "rousselons": ("rousseler",),
    "roussie": ("roussir",),
    "roussies": ("roussir",),
    "roussi": ("roussir",),
    "roussîmes": ("roussir",),
    "roussira": ("roussir",),
    "roussiraient": ("roussir",),
    "roussirai": ("roussir",),
    "roussirais": ("roussir",),
    "roussirait": ("roussir",),
    "roussiras": ("roussir",),
    "roussirent": ("roussir",),
    "roussirez": ("roussir",),
    "roussiriez": ("roussir",),
    "roussirions": ("roussir",),
    "roussirons": ("roussir",),
    "roussiront": ("roussir",),
    "roussis": ("roussir",),
    "roussissaient": ("roussir",),
    "roussissais": ("roussir",),
    "roussissait": ("roussir",),
    "roussissant": ("roussir",),
    "roussissent": ("roussir",),
    "roussisse": ("roussir",),
    "roussisses": ("roussir",),
    "roussissez": ("roussir",),
    "roussissiez": ("roussir",),
    "roussissions": ("roussir",),
    "roussissons": ("roussir",),
    "roussîtes": ("roussir",),
    "roussit": ("roussir",),
    "roussît": ("roussir",),
    "roustie": ("roustir",),
    "rousties": ("roustir",),
    "rousti": ("roustir",),
    "roustîmes": ("roustir",),
    "roustira": ("roustir",),
    "roustiraient": ("roustir",),
    "roustirai": ("roustir",),
    "roustirais": ("roustir",),
    "roustirait": ("roustir",),
    "roustiras": ("roustir",),
    "roustirent": ("roustir",),
    "roustirez": ("roustir",),
    "roustiriez": ("roustir",),
    "roustirions": ("roustir",),
    "roustirons": ("roustir",),
    "roustiront": ("roustir",),
    "roustis": ("roustir",),
    "roustissaient": ("roustir",),
    "roustissais": ("roustir",),
    "roustissait": ("roustir",),
    "roustissant": ("roustir",),
    "roustissent": ("roustir",),
    "roustisse": ("roustir",),
    "roustisses": ("roustir",),
    "roustissez": ("roustir",),
    "roustissiez": ("roustir",),
    "roustissions": ("roustir",),
    "roustissons": ("roustir",),
    "roustîtes": ("roustir",),
    "roustit": ("roustir",),
    "roustît": ("roustir",),
    "rouverte": ("rouvrir",),
    "rouvertes": ("rouvrir",),
    "rouvert": ("rouvrir",),
    "rouverts": ("rouvrir",),
    "rouvraient": ("rouvrir",),
    "rouvrais": ("rouvrir",),
    "rouvrait": ("rouvrir",),
    "rouvrant": ("rouvrir",),
    "rouvrent": ("rouvrir",),
    "rouvre": ("rouvrir",),
    "rouvres": ("rouvrir",),
    "rouvrez": ("rouvrir",),
    "rouvriez": ("rouvrir",),
    "rouvrîmes": ("rouvrir",),
    "rouvrions": ("rouvrir",),
    "rouvrira": ("rouvrir",),
    "rouvriraient": ("rouvrir",),
    "rouvrirai": ("rouvrir",),
    "rouvrirais": ("rouvrir",),
    "rouvrirait": ("rouvrir",),
    "rouvriras": ("rouvrir",),
    "rouvrirent": ("rouvrir",),
    "rouvrirez": ("rouvrir",),
    "rouvririez": ("rouvrir",),
    "rouvririons": ("rouvrir",),
    "rouvrirons": ("rouvrir",),
    "rouvriront": ("rouvrir",),
    "rouvris": ("rouvrir",),
    "rouvrissent": ("rouvrir",),
    "rouvrisses": ("rouvrir",),
    "rouvrisse": ("rouvrir",),
    "rouvrissiez": ("rouvrir",),
    "rouvrissions": ("rouvrir",),
    "rouvrîtes": ("rouvrir",),
    "rouvrit": ("rouvrir",),
    "rouvrît": ("rouvrir",),
    "rouvrons": ("rouvrir",),
    "roient": ("royer",),
    "roie": ("royer",),
    "roiera": ("royer",),
    "roieraient": ("royer",),
    "roierai": ("royer",),
    "roierais": ("royer",),
    "roierait": ("royer",),
    "roieras": ("royer",),
    "roierez": ("royer",),
    "roieriez": ("royer",),
    "roierions": ("royer",),
    "roierons": ("royer",),
    "roieront": ("royer",),
    "roies": ("royer",),
    "royaient": ("royer",),
    "royai": ("royer",),
    "royais": ("royer",),
    "royait": ("royer",),
    "roya": ("royer",),
    "royâmes": ("royer",),
    "royant": ("royer",),
    "royas": ("royer",),
    "royassent": ("royer",),
    "royasses": ("royer",),
    "royasse": ("royer",),
    "royassiez": ("royer",),
    "royassions": ("royer",),
    "royâtes": ("royer",),
    "royât": ("royer",),
    "royée": ("royer",),
    "royées": ("royer",),
    "royé": ("royer",),
    "royèrent": ("royer",),
    "royés": ("royer",),
    "royez": ("royer",),
    "royiez": ("royer",),
    "royions": ("royer",),
    "royons": ("royer",),
    "rubéfiaient": ("rubéfier",),
    "rubéfiai": ("rubéfier",),
    "rubéfiais": ("rubéfier",),
    "rubéfiait": ("rubéfier",),
    "rubéfia": ("rubéfier",),
    "rubéfiâmes": ("rubéfier",),
    "rubéfiant": ("rubéfier",),
    "rubéfias": ("rubéfier",),
    "rubéfiassent": ("rubéfier",),
    "rubéfiasses": ("rubéfier",),
    "rubéfiasse": ("rubéfier",),
    "rubéfiassiez": ("rubéfier",),
    "rubéfiassions": ("rubéfier",),
    "rubéfiâtes": ("rubéfier",),
    "rubéfiât": ("rubéfier",),
    "rubéfiée": ("rubéfier",),
    "rubéfiées": ("rubéfier",),
    "rubéfié": ("rubéfier",),
    "rubéfient": ("rubéfier",),
    "rubéfie": ("rubéfier",),
    "rubéfiera": ("rubéfier",),
    "rubéfieraient": ("rubéfier",),
    "rubéfierai": ("rubéfier",),
    "rubéfierais": ("rubéfier",),
    "rubéfierait": ("rubéfier",),
    "rubéfieras": ("rubéfier",),
    "rubéfièrent": ("rubéfier",),
    "rubéfierez": ("rubéfier",),
    "rubéfieriez": ("rubéfier",),
    "rubéfierions": ("rubéfier",),
    "rubéfierons": ("rubéfier",),
    "rubéfieront": ("rubéfier",),
    "rubéfiés": ("rubéfier",),
    "rubéfies": ("rubéfier",),
    "rubéfiez": ("rubéfier",),
    "rubéfiiez": ("rubéfier",),
    "rubéfiions": ("rubéfier",),
    "rubéfions": ("rubéfier",),
    "rudoient": ("rudoyer",),
    "rudoie": ("rudoyer",),
    "rudoiera": ("rudoyer",),
    "rudoieraient": ("rudoyer",),
    "rudoierai": ("rudoyer",),
    "rudoierais": ("rudoyer",),
    "rudoierait": ("rudoyer",),
    "rudoieras": ("rudoyer",),
    "rudoierez": ("rudoyer",),
    "rudoieriez": ("rudoyer",),
    "rudoierions": ("rudoyer",),
    "rudoierons": ("rudoyer",),
    "rudoieront": ("rudoyer",),
    "rudoies": ("rudoyer",),
    "rudoyaient": ("rudoyer",),
    "rudoyai": ("rudoyer",),
    "rudoyais": ("rudoyer",),
    "rudoyait": ("rudoyer",),
    "rudoya": ("rudoyer",),
    "rudoyâmes": ("rudoyer",),
    "rudoyant": ("rudoyer",),
    "rudoyas": ("rudoyer",),
    "rudoyassent": ("rudoyer",),
    "rudoyasses": ("rudoyer",),
    "rudoyasse": ("rudoyer",),
    "rudoyassiez": ("rudoyer",),
    "rudoyassions": ("rudoyer",),
    "rudoyâtes": ("rudoyer",),
    "rudoyât": ("rudoyer",),
    "rudoyée": ("rudoyer",),
    "rudoyées": ("rudoyer",),
    "rudoyé": ("rudoyer",),
    "rudoyèrent": ("rudoyer",),
    "rudoyés": ("rudoyer",),
    "rudoyez": ("rudoyer",),
    "rudoyiez": ("rudoyer",),
    "rudoyions": ("rudoyer",),
    "rudoyons": ("rudoyer",),
    "rugie": ("rugir",),
    "rugies": ("rugir",),
    "rugi": ("rugir",),
    "rugîmes": ("rugir",),
    "rugira": ("rugir",),
    "rugiraient": ("rugir",),
    "rugirai": ("rugir",),
    "rugirais": ("rugir",),
    "rugirait": ("rugir",),
    "rugiras": ("rugir",),
    "rugirent": ("rugir",),
    "rugirez": ("rugir",),
    "rugiriez": ("rugir",),
    "rugirions": ("rugir",),
    "rugirons": ("rugir",),
    "rugiront": ("rugir",),
    "rugis": ("rugir",),
    "rugissaient": ("rugir",),
    "rugissais": ("rugir",),
    "rugissait": ("rugir",),
    "rugissant": ("rugir",),
    "rugissent": ("rugir",),
    "rugisse": ("rugir",),
    "rugisses": ("rugir",),
    "rugissez": ("rugir",),
    "rugissiez": ("rugir",),
    "rugissions": ("rugir",),
    "rugissons": ("rugir",),
    "rugîtes": ("rugir",),
    "rugit": ("rugir",),
    "rugît": ("rugir",),
    "ruisselaient": ("ruisseler",),
    "ruisselai": ("ruisseler",),
    "ruisselais": ("ruisseler",),
    "ruisselait": ("ruisseler",),
    "ruissela": ("ruisseler",),
    "ruisselâmes": ("ruisseler",),
    "ruisselant": ("ruisseler",),
    "ruisselas": ("ruisseler",),
    "ruisselassent": ("ruisseler",),
    "ruisselasses": ("ruisseler",),
    "ruisselasse": ("ruisseler",),
    "ruisselassiez": ("ruisseler",),
    "ruisselassions": ("ruisseler",),
    "ruisselâtes": ("ruisseler",),
    "ruisselât": ("ruisseler",),
    "ruisselé": ("ruisseler",),
    "ruisselèrent": ("ruisseler",),
    "ruisselez": ("ruisseler",),
    "ruisseliez": ("ruisseler",),
    "ruisselions": ("ruisseler",),
    "ruissellent": ("ruisseler",),
    "ruisselle": ("ruisseler",),
    "ruissellera": ("ruisseler",),
    "ruisselleraient": ("ruisseler",),
    "ruissellerai": ("ruisseler",),
    "ruissellerais": ("ruisseler",),
    "ruissellerait": ("ruisseler",),
    "ruisselleras": ("ruisseler",),
    "ruissellerez": ("ruisseler",),
    "ruisselleriez": ("ruisseler",),
    "ruissellerions": ("ruisseler",),
    "ruissellerons": ("ruisseler",),
    "ruisselleront": ("ruisseler",),
    "ruisselles": ("ruisseler",),
    "ruisselons": ("ruisseler",),
    "russifiaient": ("russifier",),
    "russifiai": ("russifier",),
    "russifiais": ("russifier",),
    "russifiait": ("russifier",),
    "russifia": ("russifier",),
    "russifiâmes": ("russifier",),
    "russifiant": ("russifier",),
    "russifias": ("russifier",),
    "russifiassent": ("russifier",),
    "russifiasses": ("russifier",),
    "russifiasse": ("russifier",),
    "russifiassiez": ("russifier",),
    "russifiassions": ("russifier",),
    "russifiâtes": ("russifier",),
    "russifiât": ("russifier",),
    "russifiée": ("russifier",),
    "russifiées": ("russifier",),
    "russifié": ("russifier",),
    "russifient": ("russifier",),
    "russifie": ("russifier",),
    "russifiera": ("russifier",),
    "russifieraient": ("russifier",),
    "russifierai": ("russifier",),
    "russifierais": ("russifier",),
    "russifierait": ("russifier",),
    "russifieras": ("russifier",),
    "russifièrent": ("russifier",),
    "russifierez": ("russifier",),
    "russifieriez": ("russifier",),
    "russifierions": ("russifier",),
    "russifierons": ("russifier",),
    "russifieront": ("russifier",),
    "russifiés": ("russifier",),
    "russifies": ("russifier",),
    "russifiez": ("russifier",),
    "russifiiez": ("russifier",),
    "russifiions": ("russifier",),
    "russifions": ("russifier",),
    "saccageaient": ("saccager",),
    "saccageai": ("saccager",),
    "saccageais": ("saccager",),
    "saccageait": ("saccager",),
    "saccagea": ("saccager",),
    "saccageâmes": ("saccager",),
    "saccageant": ("saccager",),
    "saccageas": ("saccager",),
    "saccageassent": ("saccager",),
    "saccageasses": ("saccager",),
    "saccageasse": ("saccager",),
    "saccageassiez": ("saccager",),
    "saccageassions": ("saccager",),
    "saccageâtes": ("saccager",),
    "saccageât": ("saccager",),
    "saccagée": ("saccager",),
    "saccagées": ("saccager",),
    "saccagé": ("saccager",),
    "saccagent": ("saccager",),
    "saccageons": ("saccager",),
    "saccage": ("saccager",),
    "saccagera": ("saccager",),
    "saccageraient": ("saccager",),
    "saccagerai": ("saccager",),
    "saccagerais": ("saccager",),
    "saccagerait": ("saccager",),
    "saccageras": ("saccager",),
    "saccagèrent": ("saccager",),
    "saccagerez": ("saccager",),
    "saccageriez": ("saccager",),
    "saccagerions": ("saccager",),
    "saccagerons": ("saccager",),
    "saccageront": ("saccager",),
    "saccagés": ("saccager",),
    "saccages": ("saccager",),
    "saccagez": ("saccager",),
    "saccagiez": ("saccager",),
    "saccagions": ("saccager",),
    "saccharifiaient": ("saccharifier",),
    "saccharifiai": ("saccharifier",),
    "saccharifiais": ("saccharifier",),
    "saccharifiait": ("saccharifier",),
    "saccharifia": ("saccharifier",),
    "saccharifiâmes": ("saccharifier",),
    "saccharifiant": ("saccharifier",),
    "saccharifias": ("saccharifier",),
    "saccharifiassent": ("saccharifier",),
    "saccharifiasses": ("saccharifier",),
    "saccharifiasse": ("saccharifier",),
    "saccharifiassiez": ("saccharifier",),
    "saccharifiassions": ("saccharifier",),
    "saccharifiâtes": ("saccharifier",),
    "saccharifiât": ("saccharifier",),
    "saccharifiée": ("saccharifier",),
    "saccharifiées": ("saccharifier",),
    "saccharifié": ("saccharifier",),
    "saccharifient": ("saccharifier",),
    "saccharifie": ("saccharifier",),
    "saccharifiera": ("saccharifier",),
    "saccharifieraient": ("saccharifier",),
    "saccharifierai": ("saccharifier",),
    "saccharifierais": ("saccharifier",),
    "saccharifierait": ("saccharifier",),
    "saccharifieras": ("saccharifier",),
    "saccharifièrent": ("saccharifier",),
    "saccharifierez": ("saccharifier",),
    "saccharifieriez": ("saccharifier",),
    "saccharifierions": ("saccharifier",),
    "saccharifierons": ("saccharifier",),
    "saccharifieront": ("saccharifier",),
    "saccharifiés": ("saccharifier",),
    "saccharifies": ("saccharifier",),
    "saccharifiez": ("saccharifier",),
    "saccharifiiez": ("saccharifier",),
    "saccharifiions": ("saccharifier",),
    "saccharifions": ("saccharifier",),
    "sacrifiaient": ("sacrifier",),
    "sacrifiai": ("sacrifier",),
    "sacrifiais": ("sacrifier",),
    "sacrifiait": ("sacrifier",),
    "sacrifia": ("sacrifier",),
    "sacrifiâmes": ("sacrifier",),
    "sacrifiant": ("sacrifier",),
    "sacrifias": ("sacrifier",),
    "sacrifiassent": ("sacrifier",),
    "sacrifiasses": ("sacrifier",),
    "sacrifiasse": ("sacrifier",),
    "sacrifiassiez": ("sacrifier",),
    "sacrifiassions": ("sacrifier",),
    "sacrifiâtes": ("sacrifier",),
    "sacrifiât": ("sacrifier",),
    "sacrifiée": ("sacrifier",),
    "sacrifiées": ("sacrifier",),
    "sacrifié": ("sacrifier",),
    "sacrifient": ("sacrifier",),
    "sacrifie": ("sacrifier",),
    "sacrifiera": ("sacrifier",),
    "sacrifieraient": ("sacrifier",),
    "sacrifierai": ("sacrifier",),
    "sacrifierais": ("sacrifier",),
    "sacrifierait": ("sacrifier",),
    "sacrifieras": ("sacrifier",),
    "sacrifièrent": ("sacrifier",),
    "sacrifierez": ("sacrifier",),
    "sacrifieriez": ("sacrifier",),
    "sacrifierions": ("sacrifier",),
    "sacrifierons": ("sacrifier",),
    "sacrifieront": ("sacrifier",),
    "sacrifiés": ("sacrifier",),
    "sacrifies": ("sacrifier",),
    "sacrifiez": ("sacrifier",),
    "sacrifiiez": ("sacrifier",),
    "sacrifiions": ("sacrifier",),
    "sacrifions": ("sacrifier",),
    "saillaient": ("saillir",),
    "saillait": ("saillir",),
    "saillant": ("saillir",),
    "saillent": ("saillir",),
    "saille": ("saillir",),
    "saillera": ("saillir",),
    "sailleraient": ("saillir",),
    "saillerait": ("saillir",),
    "sailleront": ("saillir",),
    "saillie": ("saillir",),
    "saillies": ("saillir",),
    "sailli": ("saillir",),
    "saillîmes": ("saillir",),
    "saillira": ("saillir",),
    "sailliraient": ("saillir",),
    "saillirai": ("saillir",),
    "saillirais": ("saillir",),
    "saillirait": ("saillir",),
    "sailliras": ("saillir",),
    "saillirent": ("saillir",),
    "saillirez": ("saillir",),
    "sailliriez": ("saillir",),
    "saillirions": ("saillir",),
    "saillirons": ("saillir",),
    "sailliront": ("saillir",),
    "saillis": ("saillir",),
    "saillissaient": ("saillir",),
    "saillissais": ("saillir",),
    "saillissait": ("saillir",),
    "saillissant": ("saillir",),
    "saillissent": ("saillir",),
    "saillisse": ("saillir",),
    "saillisses": ("saillir",),
    "saillissez": ("saillir",),
    "saillissiez": ("saillir",),
    "saillissions": ("saillir",),
    "saillissons": ("saillir",),
    "saillîtes": ("saillir",),
    "saillit": ("saillir",),
    "saillît": ("saillir",),
    "saisîmes-engageâmes": ("saisir-engager",),
    "saisira-engagera": ("saisir-engager",),
    "saisirions-engagerions": ("saisir-engager",),
    "saisis-engages": ("saisir-engager",),
    "saisissent-engagent": ("saisir-engager",),
    "saisissez-engagez": ("saisir-engager",),
    "saisie": ("saisir",),
    "saisies": ("saisir",),
    "saisi": ("saisir",),
    "saisîmes": ("saisir",),
    "saisira": ("saisir",),
    "saisiraient": ("saisir",),
    "saisirai": ("saisir",),
    "saisirais": ("saisir",),
    "saisirait": ("saisir",),
    "saisiras": ("saisir",),
    "saisirent": ("saisir",),
    "saisirez": ("saisir",),
    "saisiriez": ("saisir",),
    "saisirions": ("saisir",),
    "saisirons": ("saisir",),
    "saisiront": ("saisir",),
    "saisis": ("saisir",),
    "saisissaient": ("saisir",),
    "saisissais": ("saisir",),
    "saisissait": ("saisir",),
    "saisissant": ("saisir",),
    "saisissent": ("saisir",),
    "saisisse": ("saisir",),
    "saisisses": ("saisir",),
    "saisissez": ("saisir",),
    "saisissiez": ("saisir",),
    "saisissions": ("saisir",),
    "saisissons": ("saisir",),
    "saisîtes": ("saisir",),
    "saisit": ("saisir",),
    "saisît": ("saisir",),
    "salariaient": ("salarier",),
    "salariai": ("salarier",),
    "salariais": ("salarier",),
    "salariait": ("salarier",),
    "salaria": ("salarier",),
    "salariâmes": ("salarier",),
    "salariant": ("salarier",),
    "salarias": ("salarier",),
    "salariassent": ("salarier",),
    "salariasses": ("salarier",),
    "salariasse": ("salarier",),
    "salariassiez": ("salarier",),
    "salariassions": ("salarier",),
    "salariâtes": ("salarier",),
    "salariât": ("salarier",),
    "salariée": ("salarier",),
    "salariées": ("salarier",),
    "salarié": ("salarier",),
    "salarient": ("salarier",),
    "salarie": ("salarier",),
    "salariera": ("salarier",),
    "salarieraient": ("salarier",),
    "salarierai": ("salarier",),
    "salarierais": ("salarier",),
    "salarierait": ("salarier",),
    "salarieras": ("salarier",),
    "salarièrent": ("salarier",),
    "salarierez": ("salarier",),
    "salarieriez": ("salarier",),
    "salarierions": ("salarier",),
    "salarierons": ("salarier",),
    "salarieront": ("salarier",),
    "salariés": ("salarier",),
    "salaries": ("salarier",),
    "salariez": ("salarier",),
    "salariiez": ("salarier",),
    "salariions": ("salarier",),
    "salarions": ("salarier",),
    "salifiaient": ("salifier",),
    "salifiai": ("salifier",),
    "salifiais": ("salifier",),
    "salifiait": ("salifier",),
    "salifia": ("salifier",),
    "salifiâmes": ("salifier",),
    "salifiant": ("salifier",),
    "salifias": ("salifier",),
    "salifiassent": ("salifier",),
    "salifiasses": ("salifier",),
    "salifiasse": ("salifier",),
    "salifiassiez": ("salifier",),
    "salifiassions": ("salifier",),
    "salifiâtes": ("salifier",),
    "salifiât": ("salifier",),
    "salifiée": ("salifier",),
    "salifiées": ("salifier",),
    "salifié": ("salifier",),
    "salifient": ("salifier",),
    "salifie": ("salifier",),
    "salifiera": ("salifier",),
    "salifieraient": ("salifier",),
    "salifierai": ("salifier",),
    "salifierais": ("salifier",),
    "salifierait": ("salifier",),
    "salifieras": ("salifier",),
    "salifièrent": ("salifier",),
    "salifierez": ("salifier",),
    "salifieriez": ("salifier",),
    "salifierions": ("salifier",),
    "salifierons": ("salifier",),
    "salifieront": ("salifier",),
    "salifiés": ("salifier",),
    "salifies": ("salifier",),
    "salifiez": ("salifier",),
    "salifiiez": ("salifier",),
    "salifiions": ("salifier",),
    "salifions": ("salifier",),
    "salie": ("salir",),
    "salies": ("salir",),
    "sali": ("salir",),
    "salîmes": ("salir",),
    "salira": ("salir",),
    "saliraient": ("salir",),
    "salirai": ("salir",),
    "salirais": ("salir",),
    "salirait": ("salir",),
    "saliras": ("salir",),
    "salirent": ("salir",),
    "salirez": ("salir",),
    "saliriez": ("salir",),
    "salirions": ("salir",),
    "salirons": ("salir",),
    "saliront": ("salir",),
    "salis": ("salir",),
    "salissaient": ("salir",),
    "salissais": ("salir",),
    "salissait": ("salir",),
    "salissant": ("salir",),
    "salissent": ("salir",),
    "salisse": ("salir",),
    "salisses": ("salir",),
    "salissez": ("salir",),
    "salissiez": ("salir",),
    "salissions": ("salir",),
    "salissons": ("salir",),
    "salîtes": ("salir",),
    "salit": ("salir",),
    "salît": ("salir",),
    "sancie": ("sancir",),
    "sancies": ("sancir",),
    "sanci": ("sancir",),
    "sancîmes": ("sancir",),
    "sancira": ("sancir",),
    "sanciraient": ("sancir",),
    "sancirai": ("sancir",),
    "sancirais": ("sancir",),
    "sancirait": ("sancir",),
    "sanciras": ("sancir",),
    "sancirent": ("sancir",),
    "sancirez": ("sancir",),
    "sanciriez": ("sancir",),
    "sancirions": ("sancir",),
    "sancirons": ("sancir",),
    "sanciront": ("sancir",),
    "sancis": ("sancir",),
    "sancissaient": ("sancir",),
    "sancissais": ("sancir",),
    "sancissait": ("sancir",),
    "sancissant": ("sancir",),
    "sancissent": ("sancir",),
    "sancisse": ("sancir",),
    "sancisses": ("sancir",),
    "sancissez": ("sancir",),
    "sancissiez": ("sancir",),
    "sancissions": ("sancir",),
    "sancissons": ("sancir",),
    "sancîtes": ("sancir",),
    "sancit": ("sancir",),
    "sancît": ("sancir",),
    "sanctifiaient": ("sanctifier",),
    "sanctifiai": ("sanctifier",),
    "sanctifiais": ("sanctifier",),
    "sanctifiait": ("sanctifier",),
    "sanctifia": ("sanctifier",),
    "sanctifiâmes": ("sanctifier",),
    "sanctifiant": ("sanctifier",),
    "sanctifias": ("sanctifier",),
    "sanctifiassent": ("sanctifier",),
    "sanctifiasses": ("sanctifier",),
    "sanctifiasse": ("sanctifier",),
    "sanctifiassiez": ("sanctifier",),
    "sanctifiassions": ("sanctifier",),
    "sanctifiâtes": ("sanctifier",),
    "sanctifiât": ("sanctifier",),
    "sanctifiée": ("sanctifier",),
    "sanctifiées": ("sanctifier",),
    "sanctifié": ("sanctifier",),
    "sanctifient": ("sanctifier",),
    "sanctifie": ("sanctifier",),
    "sanctifiera": ("sanctifier",),
    "sanctifieraient": ("sanctifier",),
    "sanctifierai": ("sanctifier",),
    "sanctifierais": ("sanctifier",),
    "sanctifierait": ("sanctifier",),
    "sanctifieras": ("sanctifier",),
    "sanctifièrent": ("sanctifier",),
    "sanctifierez": ("sanctifier",),
    "sanctifieriez": ("sanctifier",),
    "sanctifierions": ("sanctifier",),
    "sanctifierons": ("sanctifier",),
    "sanctifieront": ("sanctifier",),
    "sanctifiés": ("sanctifier",),
    "sanctifies": ("sanctifier",),
    "sanctifiez": ("sanctifier",),
    "sanctifiiez": ("sanctifier",),
    "sanctifiions": ("sanctifier",),
    "sanctifions": ("sanctifier",),
    "saponifiaient": ("saponifier",),
    "saponifiai": ("saponifier",),
    "saponifiais": ("saponifier",),
    "saponifiait": ("saponifier",),
    "saponifia": ("saponifier",),
    "saponifiâmes": ("saponifier",),
    "saponifiant": ("saponifier",),
    "saponifias": ("saponifier",),
    "saponifiassent": ("saponifier",),
    "saponifiasses": ("saponifier",),
    "saponifiasse": ("saponifier",),
    "saponifiassiez": ("saponifier",),
    "saponifiassions": ("saponifier",),
    "saponifiâtes": ("saponifier",),
    "saponifiât": ("saponifier",),
    "saponifiée": ("saponifier",),
    "saponifiées": ("saponifier",),
    "saponifié": ("saponifier",),
    "saponifient": ("saponifier",),
    "saponifie": ("saponifier",),
    "saponifiera": ("saponifier",),
    "saponifieraient": ("saponifier",),
    "saponifierai": ("saponifier",),
    "saponifierais": ("saponifier",),
    "saponifierait": ("saponifier",),
    "saponifieras": ("saponifier",),
    "saponifièrent": ("saponifier",),
    "saponifierez": ("saponifier",),
    "saponifieriez": ("saponifier",),
    "saponifierions": ("saponifier",),
    "saponifierons": ("saponifier",),
    "saponifieront": ("saponifier",),
    "saponifiés": ("saponifier",),
    "saponifies": ("saponifier",),
    "saponifiez": ("saponifier",),
    "saponifiiez": ("saponifier",),
    "saponifiions": ("saponifier",),
    "saponifions": ("saponifier",),
    "sassaient": ("sasser",),
    "sassai": ("sasser",),
    "sassais": ("sasser",),
    "sassait": ("sasser",),
    "sassa": ("sasser",),
    "sassâmes": ("sasser",),
    "sassant": ("sasser",),
    "sassas": ("sasser",),
    "sassassent": ("sasser",),
    "sassasses": ("sasser",),
    "sassasse": ("sasser",),
    "sassassiez": ("sasser",),
    "sassassions": ("sasser",),
    "sassâtes": ("sasser",),
    "sassât": ("sasser",),
    "sassée": ("sasser",),
    "sassées": ("sasser",),
    "sassé": ("sasser",),
    "sassent": ("sasser",),
    "sasse": ("sasser",),
    "sassera": ("sasser",),
    "sasseraient": ("sasser",),
    "sasserai": ("sasser",),
    "sasserais": ("sasser",),
    "sasserait": ("sasser",),
    "sasseras": ("sasser",),
    "sassèrent": ("sasser",),
    "sasserez": ("sasser",),
    "sasseriez": ("sasser",),
    "sasserions": ("sasser",),
    "sasserons": ("sasser",),
    "sasseront": ("sasser",),
    "sassés": ("sasser",),
    "sasses": ("sasser",),
    "sassez": ("sasser",),
    "sassiez": ("sasser",),
    "sassions": ("sasser",),
    "sassons": ("sasser",),
    "satisfaisaient": ("satisfaire",),
    "satisfaisais": ("satisfaire",),
    "satisfaisait": ("satisfaire",),
    "satisfaisant": ("satisfaire",),
    "satisfaisiez": ("satisfaire",),
    "satisfaisions": ("satisfaire",),
    "satisfaisons": ("satisfaire",),
    "satisfais": ("satisfaire",),
    "satisfaite": ("satisfaire",),
    "satisfaites": ("satisfaire",),
    "satisfait": ("satisfaire",),
    "satisfaits": ("satisfaire",),
    "satisfassent": ("satisfaire",),
    "satisfasse": ("satisfaire",),
    "satisfasses": ("satisfaire",),
    "satisfassiez": ("satisfaire",),
    "satisfassions": ("satisfaire",),
    "satisfera": ("satisfaire",),
    "satisferaient": ("satisfaire",),
    "satisferai": ("satisfaire",),
    "satisferais": ("satisfaire",),
    "satisferait": ("satisfaire",),
    "satisferas": ("satisfaire",),
    "satisferez": ("satisfaire",),
    "satisferiez": ("satisfaire",),
    "satisferions": ("satisfaire",),
    "satisferons": ("satisfaire",),
    "satisferont": ("satisfaire",),
    "satisfîmes": ("satisfaire",),
    "satisfirent": ("satisfaire",),
    "satisfis": ("satisfaire",),
    "satisfissent": ("satisfaire",),
    "satisfisses": ("satisfaire",),
    "satisfisse": ("satisfaire",),
    "satisfissiez": ("satisfaire",),
    "satisfissions": ("satisfaire",),
    "satisfîtes": ("satisfaire",),
    "satisfit": ("satisfaire",),
    "satisfît": ("satisfaire",),
    "satisfont": ("satisfaire",),
    "sauçaient": ("saucer",),
    "sauçai": ("saucer",),
    "sauçais": ("saucer",),
    "sauçait": ("saucer",),
    "sauça": ("saucer",),
    "sauçâmes": ("saucer",),
    "sauçant": ("saucer",),
    "sauças": ("saucer",),
    "sauçassent": ("saucer",),
    "sauçasses": ("saucer",),
    "sauçasse": ("saucer",),
    "sauçassiez": ("saucer",),
    "sauçassions": ("saucer",),
    "sauçâtes": ("saucer",),
    "sauçât": ("saucer",),
    "saucée": ("saucer",),
    "saucées": ("saucer",),
    "saucé": ("saucer",),
    "saucent": ("saucer",),
    "sauce": ("saucer",),
    "saucera": ("saucer",),
    "sauceraient": ("saucer",),
    "saucerai": ("saucer",),
    "saucerais": ("saucer",),
    "saucerait": ("saucer",),
    "sauceras": ("saucer",),
    "saucèrent": ("saucer",),
    "saucerez": ("saucer",),
    "sauceriez": ("saucer",),
    "saucerions": ("saucer",),
    "saucerons": ("saucer",),
    "sauceront": ("saucer",),
    "saucés": ("saucer",),
    "sauces": ("saucer",),
    "saucez": ("saucer",),
    "sauciez": ("saucer",),
    "saucions": ("saucer",),
    "sauçons": ("saucer",),
    "saurie": ("saurir",),
    "sauries": ("saurir",),
    "sauri": ("saurir",),
    "saurîmes": ("saurir",),
    "saurira": ("saurir",),
    "sauriraient": ("saurir",),
    "saurirai": ("saurir",),
    "saurirais": ("saurir",),
    "saurirait": ("saurir",),
    "sauriras": ("saurir",),
    "saurirent": ("saurir",),
    "saurirez": ("saurir",),
    "sauririez": ("saurir",),
    "sauririons": ("saurir",),
    "saurirons": ("saurir",),
    "sauriront": ("saurir",),
    "sauris": ("saurir",),
    "saurissaient": ("saurir",),
    "saurissais": ("saurir",),
    "saurissait": ("saurir",),
    "saurissant": ("saurir",),
    "saurissent": ("saurir",),
    "saurisse": ("saurir",),
    "saurisses": ("saurir",),
    "saurissez": ("saurir",),
    "saurissiez": ("saurir",),
    "saurissions": ("saurir",),
    "saurissons": ("saurir",),
    "saurîtes": ("saurir",),
    "saurit": ("saurir",),
    "saurît": ("saurir",),
    "sautelaient": ("sauteler",),
    "sautelai": ("sauteler",),
    "sautelais": ("sauteler",),
    "sautelait": ("sauteler",),
    "sautela": ("sauteler",),
    "sautelâmes": ("sauteler",),
    "sautelant": ("sauteler",),
    "sautelas": ("sauteler",),
    "sautelassent": ("sauteler",),
    "sautelasses": ("sauteler",),
    "sautelasse": ("sauteler",),
    "sautelassiez": ("sauteler",),
    "sautelassions": ("sauteler",),
    "sautelâtes": ("sauteler",),
    "sautelât": ("sauteler",),
    "sautelée": ("sauteler",),
    "sautelées": ("sauteler",),
    "sautelé": ("sauteler",),
    "sautelèrent": ("sauteler",),
    "sautelés": ("sauteler",),
    "sautelez": ("sauteler",),
    "sauteliez": ("sauteler",),
    "sautelions": ("sauteler",),
    "sautellent": ("sauteler",),
    "sautelle": ("sauteler",),
    "sautellera": ("sauteler",),
    "sautelleraient": ("sauteler",),
    "sautellerai": ("sauteler",),
    "sautellerais": ("sauteler",),
    "sautellerait": ("sauteler",),
    "sautelleras": ("sauteler",),
    "sautellerez": ("sauteler",),
    "sautelleriez": ("sauteler",),
    "sautellerions": ("sauteler",),
    "sautellerons": ("sauteler",),
    "sautelleront": ("sauteler",),
    "sautelles": ("sauteler",),
    "sautelons": ("sauteler",),
    "sauvetaient": ("sauveter",),
    "sauvetai": ("sauveter",),
    "sauvetais": ("sauveter",),
    "sauvetait": ("sauveter",),
    "sauveta": ("sauveter",),
    "sauvetâmes": ("sauveter",),
    "sauvetant": ("sauveter",),
    "sauvetas": ("sauveter",),
    "sauvetassent": ("sauveter",),
    "sauvetasses": ("sauveter",),
    "sauvetasse": ("sauveter",),
    "sauvetassiez": ("sauveter",),
    "sauvetassions": ("sauveter",),
    "sauvetâtes": ("sauveter",),
    "sauvetât": ("sauveter",),
    "sauvetée": ("sauveter",),
    "sauvetées": ("sauveter",),
    "sauveté": ("sauveter",),
    "sauvetèrent": ("sauveter",),
    "sauvetés": ("sauveter",),
    "sauvetez": ("sauveter",),
    "sauvetiez": ("sauveter",),
    "sauvetions": ("sauveter",),
    "sauvetons": ("sauveter",),
    "sauvettent": ("sauveter",),
    "sauvette": ("sauveter",),
    "sauvettera": ("sauveter",),
    "sauvetteraient": ("sauveter",),
    "sauvetterai": ("sauveter",),
    "sauvetterais": ("sauveter",),
    "sauvetterait": ("sauveter",),
    "sauvetteras": ("sauveter",),
    "sauvetterez": ("sauveter",),
    "sauvetteriez": ("sauveter",),
    "sauvetterions": ("sauveter",),
    "sauvetterons": ("sauveter",),
    "sauvetteront": ("sauveter",),
    "sauvettes": ("sauveter",),
    "sachant": ("savoir",),
    "sachent": ("savoir",),
    "sache": ("savoir",),
    "saches": ("savoir",),
    "sachez": ("savoir",),
    "sachiez": ("savoir",),
    "sachions": ("savoir",),
    "sachons": ("savoir",),
    "sais": ("savoir",),
    "sait": ("savoir",),
    "saura": ("savoir",),
    "sauraient": ("savoir",),
    "saurai": ("savoir",),
    "saurais": ("savoir",),
    "saurait": ("savoir",),
    "sauras": ("savoir",),
    "saurez": ("savoir",),
    "sauriez": ("savoir",),
    "saurions": ("savoir",),
    "saurons": ("savoir",),
    "sauront": ("savoir",),
    "savaient": ("savoir",),
    "savais": ("savoir",),
    "savait": ("savoir",),
    "savent": ("savoir",),
    "savez": ("savoir",),
    "saviez": ("savoir",),
    "savions": ("savoir",),
    "savons": ("savoir",),
    "sue": ("savoir",),
    "sues": ("savoir",),
    "su": ("savoir",),
    "sûmes": ("savoir",),
    "surent": ("savoir",),
    "sus": ("savoir",),
    "sussent": ("savoir",),
    "susses": ("savoir",),
    "susse": ("savoir",),
    "sussiez": ("savoir",),
    "sussions": ("savoir",),
    "sûtes": ("savoir",),
    "sut": ("savoir",),
    "sût": ("savoir",),
    "scarifiaient": ("scarifier",),
    "scarifiai": ("scarifier",),
    "scarifiais": ("scarifier",),
    "scarifiait": ("scarifier",),
    "scarifia": ("scarifier",),
    "scarifiâmes": ("scarifier",),
    "scarifiant": ("scarifier",),
    "scarifias": ("scarifier",),
    "scarifiassent": ("scarifier",),
    "scarifiasses": ("scarifier",),
    "scarifiasse": ("scarifier",),
    "scarifiassiez": ("scarifier",),
    "scarifiassions": ("scarifier",),
    "scarifiâtes": ("scarifier",),
    "scarifiât": ("scarifier",),
    "scarifiée": ("scarifier",),
    "scarifiées": ("scarifier",),
    "scarifié": ("scarifier",),
    "scarifient": ("scarifier",),
    "scarifie": ("scarifier",),
    "scarifiera": ("scarifier",),
    "scarifieraient": ("scarifier",),
    "scarifierai": ("scarifier",),
    "scarifierais": ("scarifier",),
    "scarifierait": ("scarifier",),
    "scarifieras": ("scarifier",),
    "scarifièrent": ("scarifier",),
    "scarifierez": ("scarifier",),
    "scarifieriez": ("scarifier",),
    "scarifierions": ("scarifier",),
    "scarifierons": ("scarifier",),
    "scarifieront": ("scarifier",),
    "scarifiés": ("scarifier",),
    "scarifies": ("scarifier",),
    "scarifiez": ("scarifier",),
    "scarifiiez": ("scarifier",),
    "scarifiions": ("scarifier",),
    "scarifions": ("scarifier",),
    "scénographiaient": ("scénographier",),
    "scénographiai": ("scénographier",),
    "scénographiais": ("scénographier",),
    "scénographiait": ("scénographier",),
    "scénographia": ("scénographier",),
    "scénographiâmes": ("scénographier",),
    "scénographiant": ("scénographier",),
    "scénographias": ("scénographier",),
    "scénographiassent": ("scénographier",),
    "scénographiasses": ("scénographier",),
    "scénographiasse": ("scénographier",),
    "scénographiassiez": ("scénographier",),
    "scénographiassions": ("scénographier",),
    "scénographiâtes": ("scénographier",),
    "scénographiât": ("scénographier",),
    "scénographiée": ("scénographier",),
    "scénographiées": ("scénographier",),
    "scénographié": ("scénographier",),
    "scénographient": ("scénographier",),
    "scénographie": ("scénographier",),
    "scénographiera": ("scénographier",),
    "scénographieraient": ("scénographier",),
    "scénographierai": ("scénographier",),
    "scénographierais": ("scénographier",),
    "scénographierait": ("scénographier",),
    "scénographieras": ("scénographier",),
    "scénographièrent": ("scénographier",),
    "scénographierez": ("scénographier",),
    "scénographieriez": ("scénographier",),
    "scénographierions": ("scénographier",),
    "scénographierons": ("scénographier",),
    "scénographieront": ("scénographier",),
    "scénographiés": ("scénographier",),
    "scénographies": ("scénographier",),
    "scénographiez": ("scénographier",),
    "scénographiiez": ("scénographier",),
    "scénographiions": ("scénographier",),
    "scénographions": ("scénographier",),
    "schistifiaient": ("schistifier",),
    "schistifiai": ("schistifier",),
    "schistifiais": ("schistifier",),
    "schistifiait": ("schistifier",),
    "schistifia": ("schistifier",),
    "schistifiâmes": ("schistifier",),
    "schistifiant": ("schistifier",),
    "schistifias": ("schistifier",),
    "schistifiassent": ("schistifier",),
    "schistifiasses": ("schistifier",),
    "schistifiasse": ("schistifier",),
    "schistifiassiez": ("schistifier",),
    "schistifiassions": ("schistifier",),
    "schistifiâtes": ("schistifier",),
    "schistifiât": ("schistifier",),
    "schistifiée": ("schistifier",),
    "schistifiées": ("schistifier",),
    "schistifié": ("schistifier",),
    "schistifient": ("schistifier",),
    "schistifie": ("schistifier",),
    "schistifiera": ("schistifier",),
    "schistifieraient": ("schistifier",),
    "schistifierai": ("schistifier",),
    "schistifierais": ("schistifier",),
    "schistifierait": ("schistifier",),
    "schistifieras": ("schistifier",),
    "schistifièrent": ("schistifier",),
    "schistifierez": ("schistifier",),
    "schistifieriez": ("schistifier",),
    "schistifierions": ("schistifier",),
    "schistifierons": ("schistifier",),
    "schistifieront": ("schistifier",),
    "schistifiés": ("schistifier",),
    "schistifies": ("schistifier",),
    "schistifiez": ("schistifier",),
    "schistifiiez": ("schistifier",),
    "schistifiions": ("schistifier",),
    "schistifions": ("schistifier",),
    "schuélaient": ("schuéler",),
    "schuélai": ("schuéler",),
    "schuélais": ("schuéler",),
    "schuélait": ("schuéler",),
    "schuéla": ("schuéler",),
    "schuélâmes": ("schuéler",),
    "schuélant": ("schuéler",),
    "schuélas": ("schuéler",),
    "schuélassent": ("schuéler",),
    "schuélasses": ("schuéler",),
    "schuélasse": ("schuéler",),
    "schuélassiez": ("schuéler",),
    "schuélassions": ("schuéler",),
    "schuélâtes": ("schuéler",),
    "schuélât": ("schuéler",),
    "schuélée": ("schuéler",),
    "schuélées": ("schuéler",),
    "schuélé": ("schuéler",),
    "schuèlent": ("schuéler",),
    "schuèle": ("schuéler",),
    "schuélera": ("schuéler",),
    "schuéleraient": ("schuéler",),
    "schuélerai": ("schuéler",),
    "schuélerais": ("schuéler",),
    "schuélerait": ("schuéler",),
    "schuéleras": ("schuéler",),
    "schuélèrent": ("schuéler",),
    "schuélerez": ("schuéler",),
    "schuéleriez": ("schuéler",),
    "schuélerions": ("schuéler",),
    "schuélerons": ("schuéler",),
    "schuéleront": ("schuéler",),
    "schuélés": ("schuéler",),
    "schuèles": ("schuéler",),
    "schuélez": ("schuéler",),
    "schuéliez": ("schuéler",),
    "schuélions": ("schuéler",),
    "schuélons": ("schuéler",),
    "sciaient": ("scier",),
    "sciai": ("scier",),
    "sciais": ("scier",),
    "sciait": ("scier",),
    "scia": ("scier",),
    "sciâmes": ("scier",),
    "sciant": ("scier",),
    "scias": ("scier",),
    "sciassent": ("scier",),
    "sciasses": ("scier",),
    "sciasse": ("scier",),
    "sciassiez": ("scier",),
    "sciassions": ("scier",),
    "sciâtes": ("scier",),
    "sciât": ("scier",),
    "sciée": ("scier",),
    "sciées": ("scier",),
    "scié": ("scier",),
    "scient": ("scier",),
    "scie": ("scier",),
    "sciera": ("scier",),
    "scieraient": ("scier",),
    "scierai": ("scier",),
    "scierais": ("scier",),
    "scierait": ("scier",),
    "scieras": ("scier",),
    "scièrent": ("scier",),
    "scierez": ("scier",),
    "scieriez": ("scier",),
    "scierions": ("scier",),
    "scierons": ("scier",),
    "scieront": ("scier",),
    "sciés": ("scier",),
    "scies": ("scier",),
    "sciez": ("scier",),
    "sciiez": ("scier",),
    "sciions": ("scier",),
    "scions": ("scier",),
    "sclérifiaient": ("sclérifier",),
    "sclérifiai": ("sclérifier",),
    "sclérifiais": ("sclérifier",),
    "sclérifiait": ("sclérifier",),
    "sclérifia": ("sclérifier",),
    "sclérifiâmes": ("sclérifier",),
    "sclérifiant": ("sclérifier",),
    "sclérifias": ("sclérifier",),
    "sclérifiassent": ("sclérifier",),
    "sclérifiasses": ("sclérifier",),
    "sclérifiasse": ("sclérifier",),
    "sclérifiassiez": ("sclérifier",),
    "sclérifiassions": ("sclérifier",),
    "sclérifiâtes": ("sclérifier",),
    "sclérifiât": ("sclérifier",),
    "sclérifiée": ("sclérifier",),
    "sclérifiées": ("sclérifier",),
    "sclérifié": ("sclérifier",),
    "sclérifient": ("sclérifier",),
    "sclérifie": ("sclérifier",),
    "sclérifiera": ("sclérifier",),
    "sclérifieraient": ("sclérifier",),
    "sclérifierai": ("sclérifier",),
    "sclérifierais": ("sclérifier",),
    "sclérifierait": ("sclérifier",),
    "sclérifieras": ("sclérifier",),
    "sclérifièrent": ("sclérifier",),
    "sclérifierez": ("sclérifier",),
    "sclérifieriez": ("sclérifier",),
    "sclérifierions": ("sclérifier",),
    "sclérifierons": ("sclérifier",),
    "sclérifieront": ("sclérifier",),
    "sclérifiés": ("sclérifier",),
    "sclérifies": ("sclérifier",),
    "sclérifiez": ("sclérifier",),
    "sclérifiiez": ("sclérifier",),
    "sclérifiions": ("sclérifier",),
    "sclérifions": ("sclérifier",),
    "scorifiaient": ("scorifier",),
    "scorifiai": ("scorifier",),
    "scorifiais": ("scorifier",),
    "scorifiait": ("scorifier",),
    "scorifia": ("scorifier",),
    "scorifiâmes": ("scorifier",),
    "scorifiant": ("scorifier",),
    "scorifias": ("scorifier",),
    "scorifiassent": ("scorifier",),
    "scorifiasses": ("scorifier",),
    "scorifiasse": ("scorifier",),
    "scorifiassiez": ("scorifier",),
    "scorifiassions": ("scorifier",),
    "scorifiâtes": ("scorifier",),
    "scorifiât": ("scorifier",),
    "scorifiée": ("scorifier",),
    "scorifiées": ("scorifier",),
    "scorifié": ("scorifier",),
    "scorifient": ("scorifier",),
    "scorifie": ("scorifier",),
    "scorifiera": ("scorifier",),
    "scorifieraient": ("scorifier",),
    "scorifierai": ("scorifier",),
    "scorifierais": ("scorifier",),
    "scorifierait": ("scorifier",),
    "scorifieras": ("scorifier",),
    "scorifièrent": ("scorifier",),
    "scorifierez": ("scorifier",),
    "scorifieriez": ("scorifier",),
    "scorifierions": ("scorifier",),
    "scorifierons": ("scorifier",),
    "scorifieront": ("scorifier",),
    "scorifiés": ("scorifier",),
    "scorifies": ("scorifier",),
    "scorifiez": ("scorifier",),
    "scorifiiez": ("scorifier",),
    "scorifiions": ("scorifier",),
    "scorifions": ("scorifier",),
    "séchaient": ("sécher",),
    "séchai": ("sécher",),
    "séchais": ("sécher",),
    "séchait": ("sécher",),
    "sécha": ("sécher",),
    "séchâmes": ("sécher",),
    "séchant": ("sécher",),
    "séchas": ("sécher",),
    "séchassent": ("sécher",),
    "séchasses": ("sécher",),
    "séchasse": ("sécher",),
    "séchassiez": ("sécher",),
    "séchassions": ("sécher",),
    "séchâtes": ("sécher",),
    "séchât": ("sécher",),
    "séchée": ("sécher",),
    "séchées": ("sécher",),
    "séché": ("sécher",),
    "sèchent": ("sécher",),
    "sèche": ("sécher",),
    "séchera": ("sécher",),
    "sécheraient": ("sécher",),
    "sécherai": ("sécher",),
    "sécherais": ("sécher",),
    "sécherait": ("sécher",),
    "sécheras": ("sécher",),
    "séchèrent": ("sécher",),
    "sécherez": ("sécher",),
    "sécheriez": ("sécher",),
    "sécherions": ("sécher",),
    "sécherons": ("sécher",),
    "sécheront": ("sécher",),
    "séchés": ("sécher",),
    "sèches": ("sécher",),
    "séchez": ("sécher",),
    "séchiez": ("sécher",),
    "séchions": ("sécher",),
    "séchons": ("sécher",),
    "secouraient": ("secourir",),
    "secourais": ("secourir",),
    "secourait": ("secourir",),
    "secourant": ("secourir",),
    "secourent": ("secourir",),
    "secoure": ("secourir",),
    "secoures": ("secourir",),
    "secourez": ("secourir",),
    "secouriez": ("secourir",),
    "secourions": ("secourir",),
    "secourons": ("secourir",),
    "secourra": ("secourir",),
    "secourraient": ("secourir",),
    "secourrai": ("secourir",),
    "secourrais": ("secourir",),
    "secourrait": ("secourir",),
    "secourras": ("secourir",),
    "secourrez": ("secourir",),
    "secourriez": ("secourir",),
    "secourrions": ("secourir",),
    "secourrons": ("secourir",),
    "secourront": ("secourir",),
    "secours": ("secourir",),
    "secourt": ("secourir",),
    "secourue": ("secourir",),
    "secourues": ("secourir",),
    "secouru": ("secourir",),
    "secourûmes": ("secourir",),
    "secoururent": ("secourir",),
    "secourus": ("secourir",),
    "secourussent": ("secourir",),
    "secourusses": ("secourir",),
    "secourusse": ("secourir",),
    "secourussiez": ("secourir",),
    "secourussions": ("secourir",),
    "secourûtes": ("secourir",),
    "secourut": ("secourir",),
    "secourût": ("secourir",),
    "séduira": ("séduire",),
    "séduiraient": ("séduire",),
    "séduirai": ("séduire",),
    "séduirais": ("séduire",),
    "séduirait": ("séduire",),
    "séduiras": ("séduire",),
    "séduirez": ("séduire",),
    "séduiriez": ("séduire",),
    "séduirions": ("séduire",),
    "séduirons": ("séduire",),
    "séduiront": ("séduire",),
    "séduisaient": ("séduire",),
    "séduisais": ("séduire",),
    "séduisait": ("séduire",),
    "séduisant": ("séduire",),
    "séduisent": ("séduire",),
    "séduise": ("séduire",),
    "séduises": ("séduire",),
    "séduisez": ("séduire",),
    "séduisiez": ("séduire",),
    "séduisîmes": ("séduire",),
    "séduisions": ("séduire",),
    "séduisirent": ("séduire",),
    "séduisis": ("séduire",),
    "séduisissent": ("séduire",),
    "séduisisses": ("séduire",),
    "séduisisse": ("séduire",),
    "séduisissiez": ("séduire",),
    "séduisissions": ("séduire",),
    "séduisîtes": ("séduire",),
    "séduisit": ("séduire",),
    "séduisît": ("séduire",),
    "séduisons": ("séduire",),
    "séduis": ("séduire",),
    "séduite": ("séduire",),
    "séduites": ("séduire",),
    "séduit": ("séduire",),
    "séduits": ("séduire",),
    "ségrégeaient": ("ségréger",),
    "ségrégeai": ("ségréger",),
    "ségrégeais": ("ségréger",),
    "ségrégeait": ("ségréger",),
    "ségrégea": ("ségréger",),
    "ségrégeâmes": ("ségréger",),
    "ségrégeant": ("ségréger",),
    "ségrégeas": ("ségréger",),
    "ségrégeassent": ("ségréger",),
    "ségrégeasses": ("ségréger",),
    "ségrégeasse": ("ségréger",),
    "ségrégeassiez": ("ségréger",),
    "ségrégeassions": ("ségréger",),
    "ségrégeâtes": ("ségréger",),
    "ségrégeât": ("ségréger",),
    "ségrégée": ("ségréger",),
    "ségrégées": ("ségréger",),
    "ségrégé": ("ségréger",),
    "ségrègent": ("ségréger",),
    "ségrégeons": ("ségréger",),
    "ségrège": ("ségréger",),
    "ségrégera": ("ségréger",),
    "ségrégeraient": ("ségréger",),
    "ségrégerai": ("ségréger",),
    "ségrégerais": ("ségréger",),
    "ségrégerait": ("ségréger",),
    "ségrégeras": ("ségréger",),
    "ségrégèrent": ("ségréger",),
    "ségrégerez": ("ségréger",),
    "ségrégeriez": ("ségréger",),
    "ségrégerions": ("ségréger",),
    "ségrégerons": ("ségréger",),
    "ségrégeront": ("ségréger",),
    "ségrégés": ("ségréger",),
    "ségrèges": ("ségréger",),
    "ségrégez": ("ségréger",),
    "ségrégiez": ("ségréger",),
    "ségrégions": ("ségréger",),
    "ségréguaient": ("ségréguer",),
    "ségréguai": ("ségréguer",),
    "ségréguais": ("ségréguer",),
    "ségréguait": ("ségréguer",),
    "ségrégua": ("ségréguer",),
    "ségréguâmes": ("ségréguer",),
    "ségréguant": ("ségréguer",),
    "ségréguas": ("ségréguer",),
    "ségréguassent": ("ségréguer",),
    "ségréguasses": ("ségréguer",),
    "ségréguasse": ("ségréguer",),
    "ségréguassiez": ("ségréguer",),
    "ségréguassions": ("ségréguer",),
    "ségréguâtes": ("ségréguer",),
    "ségréguât": ("ségréguer",),
    "ségréguée": ("ségréguer",),
    "ségréguées": ("ségréguer",),
    "ségrégué": ("ségréguer",),
    "ségrèguent": ("ségréguer",),
    "ségrègue": ("ségréguer",),
    "ségréguera": ("ségréguer",),
    "ségrégueraient": ("ségréguer",),
    "ségréguerai": ("ségréguer",),
    "ségréguerais": ("ségréguer",),
    "ségréguerait": ("ségréguer",),
    "ségrégueras": ("ségréguer",),
    "ségréguèrent": ("ségréguer",),
    "ségréguerez": ("ségréguer",),
    "ségrégueriez": ("ségréguer",),
    "ségréguerions": ("ségréguer",),
    "ségréguerons": ("ségréguer",),
    "ségrégueront": ("ségréguer",),
    "ségrégués": ("ségréguer",),
    "ségrègues": ("ségréguer",),
    "ségréguez": ("ségréguer",),
    "ségréguiez": ("ségréguer",),
    "ségréguions": ("ségréguer",),
    "ségréguons": ("ségréguer",),
    "séléniaient": ("sélénier",),
    "séléniai": ("sélénier",),
    "séléniais": ("sélénier",),
    "séléniait": ("sélénier",),
    "sélénia": ("sélénier",),
    "séléniâmes": ("sélénier",),
    "séléniant": ("sélénier",),
    "sélénias": ("sélénier",),
    "séléniassent": ("sélénier",),
    "séléniasses": ("sélénier",),
    "séléniasse": ("sélénier",),
    "séléniassiez": ("sélénier",),
    "séléniassions": ("sélénier",),
    "séléniâtes": ("sélénier",),
    "séléniât": ("sélénier",),
    "séléniée": ("sélénier",),
    "séléniées": ("sélénier",),
    "sélénié": ("sélénier",),
    "sélénient": ("sélénier",),
    "sélénie": ("sélénier",),
    "séléniera": ("sélénier",),
    "sélénieraient": ("sélénier",),
    "sélénierai": ("sélénier",),
    "sélénierais": ("sélénier",),
    "sélénierait": ("sélénier",),
    "sélénieras": ("sélénier",),
    "sélénièrent": ("sélénier",),
    "sélénierez": ("sélénier",),
    "sélénieriez": ("sélénier",),
    "sélénierions": ("sélénier",),
    "sélénierons": ("sélénier",),
    "sélénieront": ("sélénier",),
    "séléniés": ("sélénier",),
    "sélénies": ("sélénier",),
    "séléniez": ("sélénier",),
    "séléniiez": ("sélénier",),
    "séléniions": ("sélénier",),
    "sélénions": ("sélénier",),
    "semençaient": ("semencer",),
    "semençai": ("semencer",),
    "semençais": ("semencer",),
    "semençait": ("semencer",),
    "semença": ("semencer",),
    "semençâmes": ("semencer",),
    "semençant": ("semencer",),
    "semenças": ("semencer",),
    "semençassent": ("semencer",),
    "semençasses": ("semencer",),
    "semençasse": ("semencer",),
    "semençassiez": ("semencer",),
    "semençassions": ("semencer",),
    "semençâtes": ("semencer",),
    "semençât": ("semencer",),
    "semencée": ("semencer",),
    "semencées": ("semencer",),
    "semencé": ("semencer",),
    "semencent": ("semencer",),
    "semence": ("semencer",),
    "semencera": ("semencer",),
    "semenceraient": ("semencer",),
    "semencerai": ("semencer",),
    "semencerais": ("semencer",),
    "semencerait": ("semencer",),
    "semenceras": ("semencer",),
    "semencèrent": ("semencer",),
    "semencerez": ("semencer",),
    "semenceriez": ("semencer",),
    "semencerions": ("semencer",),
    "semencerons": ("semencer",),
    "semenceront": ("semencer",),
    "semencés": ("semencer",),
    "semences": ("semencer",),
    "semencez": ("semencer",),
    "semenciez": ("semencer",),
    "semencions": ("semencer",),
    "semençons": ("semencer",),
    "semaient": ("semer",),
    "semai": ("semer",),
    "semais": ("semer",),
    "semait": ("semer",),
    "sema": ("semer",),
    "semâmes": ("semer",),
    "semant": ("semer",),
    "semas": ("semer",),
    "semassent": ("semer",),
    "semasses": ("semer",),
    "semasse": ("semer",),
    "semassiez": ("semer",),
    "semassions": ("semer",),
    "semâtes": ("semer",),
    "semât": ("semer",),
    "semée": ("semer",),
    "semées": ("semer",),
    "semé": ("semer",),
    "sèment": ("semer",),
    "sème": ("semer",),
    "sèmera": ("semer",),
    "sèmeraient": ("semer",),
    "sèmerai": ("semer",),
    "sèmerais": ("semer",),
    "sèmerait": ("semer",),
    "sèmeras": ("semer",),
    "semèrent": ("semer",),
    "sèmerez": ("semer",),
    "sèmeriez": ("semer",),
    "sèmerions": ("semer",),
    "sèmerons": ("semer",),
    "sèmeront": ("semer",),
    "semés": ("semer",),
    "sèmes": ("semer",),
    "semez": ("semer",),
    "semiez": ("semer",),
    "semions": ("semer",),
    "semons": ("semer",),
    "semonçaient": ("semoncer",),
    "semonçai": ("semoncer",),
    "semonçais": ("semoncer",),
    "semonçait": ("semoncer",),
    "semonça": ("semoncer",),
    "semonçâmes": ("semoncer",),
    "semonçant": ("semoncer",),
    "semonças": ("semoncer",),
    "semonçassent": ("semoncer",),
    "semonçasses": ("semoncer",),
    "semonçasse": ("semoncer",),
    "semonçassiez": ("semoncer",),
    "semonçassions": ("semoncer",),
    "semonçâtes": ("semoncer",),
    "semonçât": ("semoncer",),
    "semoncée": ("semoncer",),
    "semoncées": ("semoncer",),
    "semoncé": ("semoncer",),
    "semoncent": ("semoncer",),
    "semonce": ("semoncer",),
    "semoncera": ("semoncer",),
    "semonceraient": ("semoncer",),
    "semoncerai": ("semoncer",),
    "semoncerais": ("semoncer",),
    "semoncerait": ("semoncer",),
    "semonceras": ("semoncer",),
    "semoncèrent": ("semoncer",),
    "semoncerez": ("semoncer",),
    "semonceriez": ("semoncer",),
    "semoncerions": ("semoncer",),
    "semoncerons": ("semoncer",),
    "semonceront": ("semoncer",),
    "semoncés": ("semoncer",),
    "semonces": ("semoncer",),
    "semoncez": ("semoncer",),
    "semonciez": ("semoncer",),
    "semoncions": ("semoncer",),
    "semonçons": ("semoncer",),
    "sentenciaient": ("sentencier",),
    "sentenciai": ("sentencier",),
    "sentenciais": ("sentencier",),
    "sentenciait": ("sentencier",),
    "sentencia": ("sentencier",),
    "sentenciâmes": ("sentencier",),
    "sentenciant": ("sentencier",),
    "sentencias": ("sentencier",),
    "sentenciassent": ("sentencier",),
    "sentenciasses": ("sentencier",),
    "sentenciasse": ("sentencier",),
    "sentenciassiez": ("sentencier",),
    "sentenciassions": ("sentencier",),
    "sentenciâtes": ("sentencier",),
    "sentenciât": ("sentencier",),
    "sentenciée": ("sentencier",),
    "sentenciées": ("sentencier",),
    "sentencié": ("sentencier",),
    "sentencient": ("sentencier",),
    "sentencie": ("sentencier",),
    "sentenciera": ("sentencier",),
    "sentencieraient": ("sentencier",),
    "sentencierai": ("sentencier",),
    "sentencierais": ("sentencier",),
    "sentencierait": ("sentencier",),
    "sentencieras": ("sentencier",),
    "sentencièrent": ("sentencier",),
    "sentencierez": ("sentencier",),
    "sentencieriez": ("sentencier",),
    "sentencierions": ("sentencier",),
    "sentencierons": ("sentencier",),
    "sentencieront": ("sentencier",),
    "sentenciés": ("sentencier",),
    "sentencies": ("sentencier",),
    "sentenciez": ("sentencier",),
    "sentenciiez": ("sentencier",),
    "sentenciions": ("sentencier",),
    "sentencions": ("sentencier",),
    "sens": ("sentir",),
    "sentaient": ("sentir",),
    "sentais": ("sentir",),
    "sentait": ("sentir",),
    "sentant": ("sentir",),
    "sentent": ("sentir",),
    "sente": ("sentir",),
    "sentes": ("sentir",),
    "sentez": ("sentir",),
    "sentie": ("sentir",),
    "senties": ("sentir",),
    "sentiez": ("sentir",),
    "senti": ("sentir",),
    "sentîmes": ("sentir",),
    "sentions": ("sentir",),
    "sentira": ("sentir",),
    "sentiraient": ("sentir",),
    "sentirai": ("sentir",),
    "sentirais": ("sentir",),
    "sentirait": ("sentir",),
    "sentiras": ("sentir",),
    "sentirent": ("sentir",),
    "sentirez": ("sentir",),
    "sentiriez": ("sentir",),
    "sentirions": ("sentir",),
    "sentirons": ("sentir",),
    "sentiront": ("sentir",),
    "sentis": ("sentir",),
    "sentissent": ("sentir",),
    "sentisses": ("sentir",),
    "sentisse": ("sentir",),
    "sentissiez": ("sentir",),
    "sentissions": ("sentir",),
    "sentîtes": ("sentir",),
    "sentit": ("sentir",),
    "sentît": ("sentir",),
    "sentons": ("sentir",),
    "sent": ("sentir",),
    "seyaient": ("seoir",),
    "seyait": ("seoir",),
    "seyant": ("seoir",),
    "sied": ("seoir",),
    "siéent": ("seoir",),
    "siée": ("seoir",),
    "siéra": ("seoir",),
    "siéraient": ("seoir",),
    "siérait": ("seoir",),
    "siéront": ("seoir",),
    "séquençaient": ("séquencer",),
    "séquençai": ("séquencer",),
    "séquençais": ("séquencer",),
    "séquençait": ("séquencer",),
    "séquença": ("séquencer",),
    "séquençâmes": ("séquencer",),
    "séquençant": ("séquencer",),
    "séquenças": ("séquencer",),
    "séquençassent": ("séquencer",),
    "séquençasses": ("séquencer",),
    "séquençasse": ("séquencer",),
    "séquençassiez": ("séquencer",),
    "séquençassions": ("séquencer",),
    "séquençâtes": ("séquencer",),
    "séquençât": ("séquencer",),
    "séquencée": ("séquencer",),
    "séquencées": ("séquencer",),
    "séquencé": ("séquencer",),
    "séquencent": ("séquencer",),
    "séquence": ("séquencer",),
    "séquencera": ("séquencer",),
    "séquenceraient": ("séquencer",),
    "séquencerai": ("séquencer",),
    "séquencerais": ("séquencer",),
    "séquencerait": ("séquencer",),
    "séquenceras": ("séquencer",),
    "séquencèrent": ("séquencer",),
    "séquencerez": ("séquencer",),
    "séquenceriez": ("séquencer",),
    "séquencerions": ("séquencer",),
    "séquencerons": ("séquencer",),
    "séquenceront": ("séquencer",),
    "séquencés": ("séquencer",),
    "séquences": ("séquencer",),
    "séquencez": ("séquencer",),
    "séquenciez": ("séquencer",),
    "séquencions": ("séquencer",),
    "séquençons": ("séquencer",),
    "sérançaient": ("sérancer",),
    "sérançai": ("sérancer",),
    "sérançais": ("sérancer",),
    "sérançait": ("sérancer",),
    "sérança": ("sérancer",),
    "sérançâmes": ("sérancer",),
    "sérançant": ("sérancer",),
    "séranças": ("sérancer",),
    "sérançassent": ("sérancer",),
    "sérançasses": ("sérancer",),
    "sérançasse": ("sérancer",),
    "sérançassiez": ("sérancer",),
    "sérançassions": ("sérancer",),
    "sérançâtes": ("sérancer",),
    "sérançât": ("sérancer",),
    "sérancée": ("sérancer",),
    "sérancées": ("sérancer",),
    "sérancé": ("sérancer",),
    "sérancent": ("sérancer",),
    "sérance": ("sérancer",),
    "sérancera": ("sérancer",),
    "séranceraient": ("sérancer",),
    "sérancerai": ("sérancer",),
    "sérancerais": ("sérancer",),
    "sérancerait": ("sérancer",),
    "séranceras": ("sérancer",),
    "sérancèrent": ("sérancer",),
    "sérancerez": ("sérancer",),
    "séranceriez": ("sérancer",),
    "sérancerions": ("sérancer",),
    "sérancerons": ("sérancer",),
    "séranceront": ("sérancer",),
    "sérancés": ("sérancer",),
    "sérances": ("sérancer",),
    "sérancez": ("sérancer",),
    "séranciez": ("sérancer",),
    "sérancions": ("sérancer",),
    "sérançons": ("sérancer",),
    "serfouie": ("serfouir",),
    "serfouies": ("serfouir",),
    "serfoui": ("serfouir",),
    "serfouîmes": ("serfouir",),
    "serfouira": ("serfouir",),
    "serfouiraient": ("serfouir",),
    "serfouirai": ("serfouir",),
    "serfouirais": ("serfouir",),
    "serfouirait": ("serfouir",),
    "serfouiras": ("serfouir",),
    "serfouirent": ("serfouir",),
    "serfouirez": ("serfouir",),
    "serfouiriez": ("serfouir",),
    "serfouirions": ("serfouir",),
    "serfouirons": ("serfouir",),
    "serfouiront": ("serfouir",),
    "serfouis": ("serfouir",),
    "serfouissaient": ("serfouir",),
    "serfouissais": ("serfouir",),
    "serfouissait": ("serfouir",),
    "serfouissant": ("serfouir",),
    "serfouissent": ("serfouir",),
    "serfouisse": ("serfouir",),
    "serfouisses": ("serfouir",),
    "serfouissez": ("serfouir",),
    "serfouissiez": ("serfouir",),
    "serfouissions": ("serfouir",),
    "serfouissons": ("serfouir",),
    "serfouîtes": ("serfouir",),
    "serfouit": ("serfouir",),
    "serfouît": ("serfouir",),
    "sériaient": ("sérier",),
    "sériai": ("sérier",),
    "sériais": ("sérier",),
    "sériait": ("sérier",),
    "séria": ("sérier",),
    "sériâmes": ("sérier",),
    "sériant": ("sérier",),
    "sérias": ("sérier",),
    "sériassent": ("sérier",),
    "sériasses": ("sérier",),
    "sériasse": ("sérier",),
    "sériassiez": ("sérier",),
    "sériassions": ("sérier",),
    "sériâtes": ("sérier",),
    "sériât": ("sérier",),
    "sériée": ("sérier",),
    "sériées": ("sérier",),
    "sérié": ("sérier",),
    "sérient": ("sérier",),
    "série": ("sérier",),
    "sériera": ("sérier",),
    "sérieraient": ("sérier",),
    "sérierai": ("sérier",),
    "sérierais": ("sérier",),
    "sérierait": ("sérier",),
    "sérieras": ("sérier",),
    "sérièrent": ("sérier",),
    "sérierez": ("sérier",),
    "sérieriez": ("sérier",),
    "sérierions": ("sérier",),
    "sérierons": ("sérier",),
    "sérieront": ("sérier",),
    "sériés": ("sérier",),
    "séries": ("sérier",),
    "sériez": ("sérier",),
    "sériiez": ("sérier",),
    "sériions": ("sérier",),
    "sérions": ("sérier",),
    "sertie": ("sertir",),
    "serties": ("sertir",),
    "serti": ("sertir",),
    "sertîmes": ("sertir",),
    "sertira": ("sertir",),
    "sertiraient": ("sertir",),
    "sertirai": ("sertir",),
    "sertirais": ("sertir",),
    "sertirait": ("sertir",),
    "sertiras": ("sertir",),
    "sertirent": ("sertir",),
    "sertirez": ("sertir",),
    "sertiriez": ("sertir",),
    "sertirions": ("sertir",),
    "sertirons": ("sertir",),
    "sertiront": ("sertir",),
    "sertis": ("sertir",),
    "sertissaient": ("sertir",),
    "sertissais": ("sertir",),
    "sertissait": ("sertir",),
    "sertissant": ("sertir",),
    "sertissent": ("sertir",),
    "sertisse": ("sertir",),
    "sertisses": ("sertir",),
    "sertissez": ("sertir",),
    "sertissiez": ("sertir",),
    "sertissions": ("sertir",),
    "sertissons": ("sertir",),
    "sertîtes": ("sertir",),
    "sertit": ("sertir",),
    "sertît": ("sertir",),
    "sers": ("servir",),
    "sert": ("servir",),
    "servaient": ("servir",),
    "servais": ("servir",),
    "servait": ("servir",),
    "servant": ("servir",),
    "servent": ("servir",),
    "serve": ("servir",),
    "serves": ("servir",),
    "servez": ("servir",),
    "servie": ("servir",),
    "servies": ("servir",),
    "serviez": ("servir",),
    "servi": ("servir",),
    "servîmes": ("servir",),
    "servions": ("servir",),
    "servira": ("servir",),
    "serviraient": ("servir",),
    "servirai": ("servir",),
    "servirais": ("servir",),
    "servirait": ("servir",),
    "serviras": ("servir",),
    "servirent": ("servir",),
    "servirez": ("servir",),
    "serviriez": ("servir",),
    "servirions": ("servir",),
    "servirons": ("servir",),
    "serviront": ("servir",),
    "servis": ("servir",),
    "servissent": ("servir",),
    "servisses": ("servir",),
    "servisse": ("servir",),
    "servissiez": ("servir",),
    "servissions": ("servir",),
    "servîtes": ("servir",),
    "servit": ("servir",),
    "servît": ("servir",),
    "servons": ("servir",),
    "sévi": ("sévir",),
    "sévîmes": ("sévir",),
    "sévira": ("sévir",),
    "séviraient": ("sévir",),
    "sévirai": ("sévir",),
    "sévirais": ("sévir",),
    "sévirait": ("sévir",),
    "séviras": ("sévir",),
    "sévirent": ("sévir",),
    "sévirez": ("sévir",),
    "séviriez": ("sévir",),
    "sévirions": ("sévir",),
    "sévirons": ("sévir",),
    "séviront": ("sévir",),
    "sévis": ("sévir",),
    "sévissaient": ("sévir",),
    "sévissais": ("sévir",),
    "sévissait": ("sévir",),
    "sévissant": ("sévir",),
    "sévissent": ("sévir",),
    "sévisse": ("sévir",),
    "sévisses": ("sévir",),
    "sévissez": ("sévir",),
    "sévissiez": ("sévir",),
    "sévissions": ("sévir",),
    "sévissons": ("sévir",),
    "sévîtes": ("sévir",),
    "sévit": ("sévir",),
    "sévît": ("sévir",),
    "sevraient": ("sevrer",),
    "sevrai": ("sevrer",),
    "sevrais": ("sevrer",),
    "sevrait": ("sevrer",),
    "sevra": ("sevrer",),
    "sevrâmes": ("sevrer",),
    "sevrant": ("sevrer",),
    "sevras": ("sevrer",),
    "sevrassent": ("sevrer",),
    "sevrasses": ("sevrer",),
    "sevrasse": ("sevrer",),
    "sevrassiez": ("sevrer",),
    "sevrassions": ("sevrer",),
    "sevrâtes": ("sevrer",),
    "sevrât": ("sevrer",),
    "sevrée": ("sevrer",),
    "sevrées": ("sevrer",),
    "sevré": ("sevrer",),
    "sèvrent": ("sevrer",),
    "sèvre": ("sevrer",),
    "sèvrera": ("sevrer",),
    "sèvreraient": ("sevrer",),
    "sèvrerai": ("sevrer",),
    "sèvrerais": ("sevrer",),
    "sèvrerait": ("sevrer",),
    "sèvreras": ("sevrer",),
    "sevrèrent": ("sevrer",),
    "sèvrerez": ("sevrer",),
    "sèvreriez": ("sevrer",),
    "sèvrerions": ("sevrer",),
    "sèvrerons": ("sevrer",),
    "sèvreront": ("sevrer",),
    "sevrés": ("sevrer",),
    "sèvres": ("sevrer",),
    "sevrez": ("sevrer",),
    "sevriez": ("sevrer",),
    "sevrions": ("sevrer",),
    "sevrons": ("sevrer",),
    "sidéraient": ("sidérer",),
    "sidérai": ("sidérer",),
    "sidérais": ("sidérer",),
    "sidérait": ("sidérer",),
    "sidéra": ("sidérer",),
    "sidérâmes": ("sidérer",),
    "sidérant": ("sidérer",),
    "sidéras": ("sidérer",),
    "sidérassent": ("sidérer",),
    "sidérasses": ("sidérer",),
    "sidérasse": ("sidérer",),
    "sidérassiez": ("sidérer",),
    "sidérassions": ("sidérer",),
    "sidérâtes": ("sidérer",),
    "sidérât": ("sidérer",),
    "sidérée": ("sidérer",),
    "sidérées": ("sidérer",),
    "sidéré": ("sidérer",),
    "sidèrent": ("sidérer",),
    "sidère": ("sidérer",),
    "sidérera": ("sidérer",),
    "sidéreraient": ("sidérer",),
    "sidérerai": ("sidérer",),
    "sidérerais": ("sidérer",),
    "sidérerait": ("sidérer",),
    "sidéreras": ("sidérer",),
    "sidérèrent": ("sidérer",),
    "sidérerez": ("sidérer",),
    "sidéreriez": ("sidérer",),
    "sidérerions": ("sidérer",),
    "sidérerons": ("sidérer",),
    "sidéreront": ("sidérer",),
    "sidérés": ("sidérer",),
    "sidères": ("sidérer",),
    "sidérez": ("sidérer",),
    "sidériez": ("sidérer",),
    "sidérions": ("sidérer",),
    "sidérons": ("sidérer",),
    "siégeaient": ("siéger",),
    "siégeai": ("siéger",),
    "siégeais": ("siéger",),
    "siégeait": ("siéger",),
    "siégea": ("siéger",),
    "siégeâmes": ("siéger",),
    "siégeant": ("siéger",),
    "siégeas": ("siéger",),
    "siégeassent": ("siéger",),
    "siégeasses": ("siéger",),
    "siégeasse": ("siéger",),
    "siégeassiez": ("siéger",),
    "siégeassions": ("siéger",),
    "siégeâtes": ("siéger",),
    "siégeât": ("siéger",),
    "siégé": ("siéger",),
    "siègent": ("siéger",),
    "siégeons": ("siéger",),
    "siège": ("siéger",),
    "siégera": ("siéger",),
    "siégeraient": ("siéger",),
    "siégerai": ("siéger",),
    "siégerais": ("siéger",),
    "siégerait": ("siéger",),
    "siégeras": ("siéger",),
    "siégèrent": ("siéger",),
    "siégerez": ("siéger",),
    "siégeriez": ("siéger",),
    "siégerions": ("siéger",),
    "siégerons": ("siéger",),
    "siégeront": ("siéger",),
    "sièges": ("siéger",),
    "siégez": ("siéger",),
    "siégiez": ("siéger",),
    "siégions": ("siéger",),
    "signifiaient": ("signifier",),
    "signifiai": ("signifier",),
    "signifiais": ("signifier",),
    "signifiait": ("signifier",),
    "signifia": ("signifier",),
    "signifiâmes": ("signifier",),
    "signifiant": ("signifier",),
    "signifias": ("signifier",),
    "signifiassent": ("signifier",),
    "signifiasses": ("signifier",),
    "signifiasse": ("signifier",),
    "signifiassiez": ("signifier",),
    "signifiassions": ("signifier",),
    "signifiâtes": ("signifier",),
    "signifiât": ("signifier",),
    "signifiée": ("signifier",),
    "signifiées": ("signifier",),
    "signifié": ("signifier",),
    "signifient": ("signifier",),
    "signifie": ("signifier",),
    "signifiera": ("signifier",),
    "signifieraient": ("signifier",),
    "signifierai": ("signifier",),
    "signifierais": ("signifier",),
    "signifierait": ("signifier",),
    "signifieras": ("signifier",),
    "signifièrent": ("signifier",),
    "signifierez": ("signifier",),
    "signifieriez": ("signifier",),
    "signifierions": ("signifier",),
    "signifierons": ("signifier",),
    "signifieront": ("signifier",),
    "signifiés": ("signifier",),
    "signifies": ("signifier",),
    "signifiez": ("signifier",),
    "signifiiez": ("signifier",),
    "signifiions": ("signifier",),
    "signifions": ("signifier",),
    "silençaient": ("silencer",),
    "silençai": ("silencer",),
    "silençais": ("silencer",),
    "silençait": ("silencer",),
    "silença": ("silencer",),
    "silençâmes": ("silencer",),
    "silençant": ("silencer",),
    "silenças": ("silencer",),
    "silençassent": ("silencer",),
    "silençasses": ("silencer",),
    "silençasse": ("silencer",),
    "silençassiez": ("silencer",),
    "silençassions": ("silencer",),
    "silençâtes": ("silencer",),
    "silençât": ("silencer",),
    "silencée": ("silencer",),
    "silencées": ("silencer",),
    "silencé": ("silencer",),
    "silencent": ("silencer",),
    "silence": ("silencer",),
    "silencera": ("silencer",),
    "silenceraient": ("silencer",),
    "silencerai": ("silencer",),
    "silencerais": ("silencer",),
    "silencerait": ("silencer",),
    "silenceras": ("silencer",),
    "silencèrent": ("silencer",),
    "silencerez": ("silencer",),
    "silenceriez": ("silencer",),
    "silencerions": ("silencer",),
    "silencerons": ("silencer",),
    "silenceront": ("silencer",),
    "silencés": ("silencer",),
    "silences": ("silencer",),
    "silencez": ("silencer",),
    "silenciez": ("silencer",),
    "silencions": ("silencer",),
    "silençons": ("silencer",),
    "siliçaient": ("silicer",),
    "siliçai": ("silicer",),
    "siliçais": ("silicer",),
    "siliçait": ("silicer",),
    "siliça": ("silicer",),
    "siliçâmes": ("silicer",),
    "siliçant": ("silicer",),
    "siliças": ("silicer",),
    "siliçassent": ("silicer",),
    "siliçasses": ("silicer",),
    "siliçasse": ("silicer",),
    "siliçassiez": ("silicer",),
    "siliçassions": ("silicer",),
    "siliçâtes": ("silicer",),
    "siliçât": ("silicer",),
    "silicée": ("silicer",),
    "silicées": ("silicer",),
    "silicé": ("silicer",),
    "silicent": ("silicer",),
    "silice": ("silicer",),
    "silicera": ("silicer",),
    "siliceraient": ("silicer",),
    "silicerai": ("silicer",),
    "silicerais": ("silicer",),
    "silicerait": ("silicer",),
    "siliceras": ("silicer",),
    "silicèrent": ("silicer",),
    "silicerez": ("silicer",),
    "siliceriez": ("silicer",),
    "silicerions": ("silicer",),
    "silicerons": ("silicer",),
    "siliceront": ("silicer",),
    "silicés": ("silicer",),
    "silices": ("silicer",),
    "silicez": ("silicer",),
    "siliciez": ("silicier",),
    "silicions": ("silicier",),
    "siliçons": ("silicer",),
    "siliciaient": ("silicier",),
    "siliciai": ("silicier",),
    "siliciais": ("silicier",),
    "siliciait": ("silicier",),
    "silicia": ("silicier",),
    "siliciâmes": ("silicier",),
    "siliciant": ("silicier",),
    "silicias": ("silicier",),
    "siliciassent": ("silicier",),
    "siliciasses": ("silicier",),
    "siliciasse": ("silicier",),
    "siliciassiez": ("silicier",),
    "siliciassions": ("silicier",),
    "siliciâtes": ("silicier",),
    "siliciât": ("silicier",),
    "siliciée": ("silicier",),
    "siliciées": ("silicier",),
    "silicié": ("silicier",),
    "silicient": ("silicier",),
    "silicie": ("silicier",),
    "siliciera": ("silicier",),
    "silicieraient": ("silicier",),
    "silicierai": ("silicier",),
    "silicierais": ("silicier",),
    "silicierait": ("silicier",),
    "silicieras": ("silicier",),
    "silicièrent": ("silicier",),
    "silicierez": ("silicier",),
    "silicieriez": ("silicier",),
    "silicierions": ("silicier",),
    "silicierons": ("silicier",),
    "silicieront": ("silicier",),
    "siliciés": ("silicier",),
    "silicies": ("silicier",),
    "siliciiez": ("silicier",),
    "siliciions": ("silicier",),
    "silicifiaient": ("silicifier",),
    "silicifiai": ("silicifier",),
    "silicifiais": ("silicifier",),
    "silicifiait": ("silicifier",),
    "silicifia": ("silicifier",),
    "silicifiâmes": ("silicifier",),
    "silicifiant": ("silicifier",),
    "silicifias": ("silicifier",),
    "silicifiassent": ("silicifier",),
    "silicifiasses": ("silicifier",),
    "silicifiasse": ("silicifier",),
    "silicifiassiez": ("silicifier",),
    "silicifiassions": ("silicifier",),
    "silicifiâtes": ("silicifier",),
    "silicifiât": ("silicifier",),
    "silicifiée": ("silicifier",),
    "silicifiées": ("silicifier",),
    "silicifié": ("silicifier",),
    "silicifient": ("silicifier",),
    "silicifie": ("silicifier",),
    "silicifiera": ("silicifier",),
    "silicifieraient": ("silicifier",),
    "silicifierai": ("silicifier",),
    "silicifierais": ("silicifier",),
    "silicifierait": ("silicifier",),
    "silicifieras": ("silicifier",),
    "silicifièrent": ("silicifier",),
    "silicifierez": ("silicifier",),
    "silicifieriez": ("silicifier",),
    "silicifierions": ("silicifier",),
    "silicifierons": ("silicifier",),
    "silicifieront": ("silicifier",),
    "silicifiés": ("silicifier",),
    "silicifies": ("silicifier",),
    "silicifiez": ("silicifier",),
    "silicifiiez": ("silicifier",),
    "silicifiions": ("silicifier",),
    "silicifions": ("silicifier",),
    "simpletaient": ("simpleter",),
    "simpletai": ("simpleter",),
    "simpletais": ("simpleter",),
    "simpletait": ("simpleter",),
    "simpleta": ("simpleter",),
    "simpletâmes": ("simpleter",),
    "simpletant": ("simpleter",),
    "simpletas": ("simpleter",),
    "simpletassent": ("simpleter",),
    "simpletasses": ("simpleter",),
    "simpletasse": ("simpleter",),
    "simpletassiez": ("simpleter",),
    "simpletassions": ("simpleter",),
    "simpletâtes": ("simpleter",),
    "simpletât": ("simpleter",),
    "simpletée": ("simpleter",),
    "simpletées": ("simpleter",),
    "simpleté": ("simpleter",),
    "simpletèrent": ("simpleter",),
    "simpletés": ("simpleter",),
    "simpletez": ("simpleter",),
    "simpletiez": ("simpleter",),
    "simpletions": ("simpleter",),
    "simpletons": ("simpleter",),
    "simplettent": ("simpleter",),
    "simplette": ("simpleter",),
    "simplettera": ("simpleter",),
    "simpletteraient": ("simpleter",),
    "simpletterai": ("simpleter",),
    "simpletterais": ("simpleter",),
    "simpletterait": ("simpleter",),
    "simpletteras": ("simpleter",),
    "simpletterez": ("simpleter",),
    "simpletteriez": ("simpleter",),
    "simpletterions": ("simpleter",),
    "simpletterons": ("simpleter",),
    "simpletteront": ("simpleter",),
    "simplettes": ("simpleter",),
    "simplifiaient": ("simplifier",),
    "simplifiai": ("simplifier",),
    "simplifiais": ("simplifier",),
    "simplifiait": ("simplifier",),
    "simplifia": ("simplifier",),
    "simplifiâmes": ("simplifier",),
    "simplifiant": ("simplifier",),
    "simplifias": ("simplifier",),
    "simplifiassent": ("simplifier",),
    "simplifiasses": ("simplifier",),
    "simplifiasse": ("simplifier",),
    "simplifiassiez": ("simplifier",),
    "simplifiassions": ("simplifier",),
    "simplifiâtes": ("simplifier",),
    "simplifiât": ("simplifier",),
    "simplifiée": ("simplifier",),
    "simplifiées": ("simplifier",),
    "simplifié": ("simplifier",),
    "simplifient": ("simplifier",),
    "simplifie": ("simplifier",),
    "simplifiera": ("simplifier",),
    "simplifieraient": ("simplifier",),
    "simplifierai": ("simplifier",),
    "simplifierais": ("simplifier",),
    "simplifierait": ("simplifier",),
    "simplifieras": ("simplifier",),
    "simplifièrent": ("simplifier",),
    "simplifierez": ("simplifier",),
    "simplifieriez": ("simplifier",),
    "simplifierions": ("simplifier",),
    "simplifierons": ("simplifier",),
    "simplifieront": ("simplifier",),
    "simplifiés": ("simplifier",),
    "simplifies": ("simplifier",),
    "simplifiez": ("simplifier",),
    "simplifiiez": ("simplifier",),
    "simplifiions": ("simplifier",),
    "simplifions": ("simplifier",),
    "singeaient": ("singer",),
    "singeai": ("singer",),
    "singeais": ("singer",),
    "singeait": ("singer",),
    "singea": ("singer",),
    "singeâmes": ("singer",),
    "singeant": ("singer",),
    "singeas": ("singer",),
    "singeassent": ("singer",),
    "singeasses": ("singer",),
    "singeasse": ("singer",),
    "singeassiez": ("singer",),
    "singeassions": ("singer",),
    "singeâtes": ("singer",),
    "singeât": ("singer",),
    "singée": ("singer",),
    "singées": ("singer",),
    "singé": ("singer",),
    "singent": ("singer",),
    "singeons": ("singer",),
    "singe": ("singer",),
    "singera": ("singer",),
    "singeraient": ("singer",),
    "singerai": ("singer",),
    "singerais": ("singer",),
    "singerait": ("singer",),
    "singeras": ("singer",),
    "singèrent": ("singer",),
    "singerez": ("singer",),
    "singeriez": ("singer",),
    "singerions": ("singer",),
    "singerons": ("singer",),
    "singeront": ("singer",),
    "singés": ("singer",),
    "singes": ("singer",),
    "singez": ("singer",),
    "singiez": ("singer",),
    "singions": ("singer",),
    "sirénaient": ("siréner",),
    "sirénai": ("siréner",),
    "sirénais": ("siréner",),
    "sirénait": ("siréner",),
    "siréna": ("siréner",),
    "sirénâmes": ("siréner",),
    "sirénant": ("siréner",),
    "sirénas": ("siréner",),
    "sirénassent": ("siréner",),
    "sirénasses": ("siréner",),
    "sirénasse": ("siréner",),
    "sirénassiez": ("siréner",),
    "sirénassions": ("siréner",),
    "sirénâtes": ("siréner",),
    "sirénât": ("siréner",),
    "sirénée": ("siréner",),
    "sirénées": ("siréner",),
    "siréné": ("siréner",),
    "sirènent": ("siréner",),
    "sirène": ("siréner",),
    "sirénera": ("siréner",),
    "siréneraient": ("siréner",),
    "sirénerai": ("siréner",),
    "sirénerais": ("siréner",),
    "sirénerait": ("siréner",),
    "siréneras": ("siréner",),
    "sirénèrent": ("siréner",),
    "sirénerez": ("siréner",),
    "siréneriez": ("siréner",),
    "sirénerions": ("siréner",),
    "sirénerons": ("siréner",),
    "siréneront": ("siréner",),
    "sirénés": ("siréner",),
    "sirènes": ("siréner",),
    "sirénez": ("siréner",),
    "siréniez": ("siréner",),
    "sirénions": ("siréner",),
    "sirénons": ("siréner",),
    "sismographiaient": ("sismographier",),
    "sismographiai": ("sismographier",),
    "sismographiais": ("sismographier",),
    "sismographiait": ("sismographier",),
    "sismographia": ("sismographier",),
    "sismographiâmes": ("sismographier",),
    "sismographiant": ("sismographier",),
    "sismographias": ("sismographier",),
    "sismographiassent": ("sismographier",),
    "sismographiasses": ("sismographier",),
    "sismographiasse": ("sismographier",),
    "sismographiassiez": ("sismographier",),
    "sismographiassions": ("sismographier",),
    "sismographiâtes": ("sismographier",),
    "sismographiât": ("sismographier",),
    "sismographiée": ("sismographier",),
    "sismographiées": ("sismographier",),
    "sismographié": ("sismographier",),
    "sismographient": ("sismographier",),
    "sismographie": ("sismographier",),
    "sismographiera": ("sismographier",),
    "sismographieraient": ("sismographier",),
    "sismographierai": ("sismographier",),
    "sismographierais": ("sismographier",),
    "sismographierait": ("sismographier",),
    "sismographieras": ("sismographier",),
    "sismographièrent": ("sismographier",),
    "sismographierez": ("sismographier",),
    "sismographieriez": ("sismographier",),
    "sismographierions": ("sismographier",),
    "sismographierons": ("sismographier",),
    "sismographieront": ("sismographier",),
    "sismographiés": ("sismographier",),
    "sismographies": ("sismographier",),
    "sismographiez": ("sismographier",),
    "sismographiiez": ("sismographier",),
    "sismographiions": ("sismographier",),
    "sismographions": ("sismographier",),
    "skiaient": ("skier",),
    "skiai": ("skier",),
    "skiais": ("skier",),
    "skiait": ("skier",),
    "skia": ("skier",),
    "skiâmes": ("skier",),
    "skiant": ("skier",),
    "skias": ("skier",),
    "skiassent": ("skier",),
    "skiasses": ("skier",),
    "skiasse": ("skier",),
    "skiassiez": ("skier",),
    "skiassions": ("skier",),
    "skiâtes": ("skier",),
    "skiât": ("skier",),
    "skié": ("skier",),
    "skient": ("skier",),
    "skie": ("skier",),
    "skiera": ("skier",),
    "skieraient": ("skier",),
    "skierai": ("skier",),
    "skierais": ("skier",),
    "skierait": ("skier",),
    "skieras": ("skier",),
    "skièrent": ("skier",),
    "skierez": ("skier",),
    "skieriez": ("skier",),
    "skierions": ("skier",),
    "skierons": ("skier",),
    "skieront": ("skier",),
    "skies": ("skier",),
    "skiez": ("skier",),
    "skiiez": ("skier",),
    "skiions": ("skier",),
    "skions": ("skier",),
    "sliçaient": ("slicer",),
    "sliçai": ("slicer",),
    "sliçais": ("slicer",),
    "sliçait": ("slicer",),
    "sliça": ("slicer",),
    "sliçâmes": ("slicer",),
    "sliçant": ("slicer",),
    "sliças": ("slicer",),
    "sliçassent": ("slicer",),
    "sliçasses": ("slicer",),
    "sliçasse": ("slicer",),
    "sliçassiez": ("slicer",),
    "sliçassions": ("slicer",),
    "sliçâtes": ("slicer",),
    "sliçât": ("slicer",),
    "slicée": ("slicer",),
    "slicées": ("slicer",),
    "slicé": ("slicer",),
    "slicent": ("slicer",),
    "slice": ("slicer",),
    "slicera": ("slicer",),
    "sliceraient": ("slicer",),
    "slicerai": ("slicer",),
    "slicerais": ("slicer",),
    "slicerait": ("slicer",),
    "sliceras": ("slicer",),
    "slicèrent": ("slicer",),
    "slicerez": ("slicer",),
    "sliceriez": ("slicer",),
    "slicerions": ("slicer",),
    "slicerons": ("slicer",),
    "sliceront": ("slicer",),
    "slicés": ("slicer",),
    "slices": ("slicer",),
    "slicez": ("slicer",),
    "sliciez": ("slicer",),
    "slicions": ("slicer",),
    "sliçons": ("slicer",),
    "solfiaient": ("solfier",),
    "solfiai": ("solfier",),
    "solfiais": ("solfier",),
    "solfiait": ("solfier",),
    "solfia": ("solfier",),
    "solfiâmes": ("solfier",),
    "solfiant": ("solfier",),
    "solfias": ("solfier",),
    "solfiassent": ("solfier",),
    "solfiasses": ("solfier",),
    "solfiasse": ("solfier",),
    "solfiassiez": ("solfier",),
    "solfiassions": ("solfier",),
    "solfiâtes": ("solfier",),
    "solfiât": ("solfier",),
    "solfiée": ("solfier",),
    "solfiées": ("solfier",),
    "solfié": ("solfier",),
    "solfient": ("solfier",),
    "solfie": ("solfier",),
    "solfiera": ("solfier",),
    "solfieraient": ("solfier",),
    "solfierai": ("solfier",),
    "solfierais": ("solfier",),
    "solfierait": ("solfier",),
    "solfieras": ("solfier",),
    "solfièrent": ("solfier",),
    "solfierez": ("solfier",),
    "solfieriez": ("solfier",),
    "solfierions": ("solfier",),
    "solfierons": ("solfier",),
    "solfieront": ("solfier",),
    "solfiés": ("solfier",),
    "solfies": ("solfier",),
    "solfiez": ("solfier",),
    "solfiiez": ("solfier",),
    "solfiions": ("solfier",),
    "solfions": ("solfier",),
    "solidifiaient": ("solidifier",),
    "solidifiai": ("solidifier",),
    "solidifiais": ("solidifier",),
    "solidifiait": ("solidifier",),
    "solidifia": ("solidifier",),
    "solidifiâmes": ("solidifier",),
    "solidifiant": ("solidifier",),
    "solidifias": ("solidifier",),
    "solidifiassent": ("solidifier",),
    "solidifiasses": ("solidifier",),
    "solidifiasse": ("solidifier",),
    "solidifiassiez": ("solidifier",),
    "solidifiassions": ("solidifier",),
    "solidifiâtes": ("solidifier",),
    "solidifiât": ("solidifier",),
    "solidifiée": ("solidifier",),
    "solidifiées": ("solidifier",),
    "solidifié": ("solidifier",),
    "solidifient": ("solidifier",),
    "solidifie": ("solidifier",),
    "solidifiera": ("solidifier",),
    "solidifieraient": ("solidifier",),
    "solidifierai": ("solidifier",),
    "solidifierais": ("solidifier",),
    "solidifierait": ("solidifier",),
    "solidifieras": ("solidifier",),
    "solidifièrent": ("solidifier",),
    "solidifierez": ("solidifier",),
    "solidifieriez": ("solidifier",),
    "solidifierions": ("solidifier",),
    "solidifierons": ("solidifier",),
    "solidifieront": ("solidifier",),
    "solidifiés": ("solidifier",),
    "solidifies": ("solidifier",),
    "solidifiez": ("solidifier",),
    "solidifiiez": ("solidifier",),
    "solidifiions": ("solidifier",),
    "solidifions": ("solidifier",),
    "solmifiaient": ("solmifier",),
    "solmifiai": ("solmifier",),
    "solmifiais": ("solmifier",),
    "solmifiait": ("solmifier",),
    "solmifia": ("solmifier",),
    "solmifiâmes": ("solmifier",),
    "solmifiant": ("solmifier",),
    "solmifias": ("solmifier",),
    "solmifiassent": ("solmifier",),
    "solmifiasses": ("solmifier",),
    "solmifiasse": ("solmifier",),
    "solmifiassiez": ("solmifier",),
    "solmifiassions": ("solmifier",),
    "solmifiâtes": ("solmifier",),
    "solmifiât": ("solmifier",),
    "solmifiée": ("solmifier",),
    "solmifiées": ("solmifier",),
    "solmifié": ("solmifier",),
    "solmifient": ("solmifier",),
    "solmifie": ("solmifier",),
    "solmifiera": ("solmifier",),
    "solmifieraient": ("solmifier",),
    "solmifierai": ("solmifier",),
    "solmifierais": ("solmifier",),
    "solmifierait": ("solmifier",),
    "solmifieras": ("solmifier",),
    "solmifièrent": ("solmifier",),
    "solmifierez": ("solmifier",),
    "solmifieriez": ("solmifier",),
    "solmifierions": ("solmifier",),
    "solmifierons": ("solmifier",),
    "solmifieront": ("solmifier",),
    "solmifiés": ("solmifier",),
    "solmifies": ("solmifier",),
    "solmifiez": ("solmifier",),
    "solmifiiez": ("solmifier",),
    "solmifiions": ("solmifier",),
    "solmifions": ("solmifier",),
    "songeaient": ("songer",),
    "songeai": ("songer",),
    "songeais": ("songer",),
    "songeait": ("songer",),
    "songea": ("songer",),
    "songeâmes": ("songer",),
    "songeant": ("songer",),
    "songeas": ("songer",),
    "songeassent": ("songer",),
    "songeasses": ("songer",),
    "songeasse": ("songer",),
    "songeassiez": ("songer",),
    "songeassions": ("songer",),
    "songeâtes": ("songer",),
    "songeât": ("songer",),
    "songé": ("songer",),
    "songent": ("songer",),
    "songeons": ("songer",),
    "songe": ("songer",),
    "songera": ("songer",),
    "songeraient": ("songer",),
    "songerai": ("songer",),
    "songerais": ("songer",),
    "songerait": ("songer",),
    "songeras": ("songer",),
    "songèrent": ("songer",),
    "songerez": ("songer",),
    "songeriez": ("songer",),
    "songerions": ("songer",),
    "songerons": ("songer",),
    "songeront": ("songer",),
    "songes": ("songer",),
    "songez": ("songer",),
    "songiez": ("songer",),
    "songions": ("songer",),
    "sors": ("sortir",),
    "sortaient": ("sortir",),
    "sortais": ("sortir",),
    "sortait": ("sortir",),
    "sortant": ("sortir",),
    "sortent": ("sortir",),
    "sorte": ("sortir",),
    "sortes": ("sortir",),
    "sortez": ("sortir",),
    "sortie": ("sortir",),
    "sorties": ("sortir",),
    "sortiez": ("sortir",),
    "sorti": ("sortir",),
    "sortîmes": ("sortir",),
    "sortions": ("sortir",),
    "sortira": ("sortir",),
    "sortiraient": ("sortir",),
    "sortirai": ("sortir",),
    "sortirais": ("sortir",),
    "sortirait": ("sortir",),
    "sortiras": ("sortir",),
    "sortirent": ("sortir",),
    "sortirez": ("sortir",),
    "sortiriez": ("sortir",),
    "sortirions": ("sortir",),
    "sortirons": ("sortir",),
    "sortiront": ("sortir",),
    "sortis": ("sortir",),
    "sortissaient": ("sortir",),
    "sortissais": ("sortir",),
    "sortissait": ("sortir",),
    "sortissant": ("sortir",),
    "sortissent": ("sortir",),
    "sortisse": ("sortir",),
    "sortisses": ("sortir",),
    "sortissez": ("sortir",),
    "sortissiez": ("sortir",),
    "sortissions": ("sortir",),
    "sortissons": ("sortir",),
    "sortîtes": ("sortir",),
    "sortit": ("sortir",),
    "sortît": ("sortir",),
    "sortons": ("sortir",),
    "sort": ("sortir",),
    "soubat": ("soubattre",),
    "soubats": ("soubattre",),
    "soubattaient": ("soubattre",),
    "soubattais": ("soubattre",),
    "soubattait": ("soubattre",),
    "soubattant": ("soubattre",),
    "soubattent": ("soubattre",),
    "soubatte": ("soubattre",),
    "soubattes": ("soubattre",),
    "soubattez": ("soubattre",),
    "soubattiez": ("soubattre",),
    "soubattîmes": ("soubattre",),
    "soubattions": ("soubattre",),
    "soubattirent": ("soubattre",),
    "soubattis": ("soubattre",),
    "soubattissent": ("soubattre",),
    "soubattisses": ("soubattre",),
    "soubattisse": ("soubattre",),
    "soubattissiez": ("soubattre",),
    "soubattissions": ("soubattre",),
    "soubattîtes": ("soubattre",),
    "soubattit": ("soubattre",),
    "soubattît": ("soubattre",),
    "soubattons": ("soubattre",),
    "soubattra": ("soubattre",),
    "soubattraient": ("soubattre",),
    "soubattrai": ("soubattre",),
    "soubattrais": ("soubattre",),
    "soubattrait": ("soubattre",),
    "soubattras": ("soubattre",),
    "soubattrez": ("soubattre",),
    "soubattriez": ("soubattre",),
    "soubattrions": ("soubattre",),
    "soubattrons": ("soubattre",),
    "soubattront": ("soubattre",),
    "soubattue": ("soubattre",),
    "soubattues": ("soubattre",),
    "soubattu": ("soubattre",),
    "soubattus": ("soubattre",),
    "souchetaient": ("soucheter",),
    "souchetai": ("soucheter",),
    "souchetais": ("soucheter",),
    "souchetait": ("soucheter",),
    "soucheta": ("soucheter",),
    "souchetâmes": ("soucheter",),
    "souchetant": ("soucheter",),
    "souchetas": ("soucheter",),
    "souchetassent": ("soucheter",),
    "souchetasses": ("soucheter",),
    "souchetasse": ("soucheter",),
    "souchetassiez": ("soucheter",),
    "souchetassions": ("soucheter",),
    "souchetâtes": ("soucheter",),
    "souchetât": ("soucheter",),
    "souchetée": ("soucheter",),
    "souchetées": ("soucheter",),
    "soucheté": ("soucheter",),
    "souchetèrent": ("soucheter",),
    "souchetés": ("soucheter",),
    "souchetez": ("soucheter",),
    "souchetiez": ("soucheter",),
    "souchetions": ("soucheter",),
    "souchetons": ("soucheter",),
    "souchettent": ("soucheter",),
    "souchette": ("soucheter",),
    "souchettera": ("soucheter",),
    "souchetteraient": ("soucheter",),
    "souchetterai": ("soucheter",),
    "souchetterais": ("soucheter",),
    "souchetterait": ("soucheter",),
    "souchetteras": ("soucheter",),
    "souchetterez": ("soucheter",),
    "souchetteriez": ("soucheter",),
    "souchetterions": ("soucheter",),
    "souchetterons": ("soucheter",),
    "souchetteront": ("soucheter",),
    "souchettes": ("soucheter",),
    "souchevaient": ("souchever",),
    "souchevai": ("souchever",),
    "souchevais": ("souchever",),
    "souchevait": ("souchever",),
    "soucheva": ("souchever",),
    "souchevâmes": ("souchever",),
    "souchevant": ("souchever",),
    "souchevas": ("souchever",),
    "souchevassent": ("souchever",),
    "souchevasses": ("souchever",),
    "souchevasse": ("souchever",),
    "souchevassiez": ("souchever",),
    "souchevassions": ("souchever",),
    "souchevâtes": ("souchever",),
    "souchevât": ("souchever",),
    "souchevée": ("souchever",),
    "souchevées": ("souchever",),
    "souchevé": ("souchever",),
    "souchèvent": ("souchever",),
    "souchève": ("souchever",),
    "souchèvera": ("souchever",),
    "souchèveraient": ("souchever",),
    "souchèverai": ("souchever",),
    "souchèverais": ("souchever",),
    "souchèverait": ("souchever",),
    "souchèveras": ("souchever",),
    "souchevèrent": ("souchever",),
    "souchèverez": ("souchever",),
    "souchèveriez": ("souchever",),
    "souchèverions": ("souchever",),
    "souchèverons": ("souchever",),
    "souchèveront": ("souchever",),
    "souchevés": ("souchever",),
    "souchèves": ("souchever",),
    "souchevez": ("souchever",),
    "soucheviez": ("souchever",),
    "souchevions": ("souchever",),
    "souchevons": ("souchever",),
    "souciaient": ("soucier",),
    "souciai": ("soucier",),
    "souciais": ("soucier",),
    "souciait": ("soucier",),
    "soucia": ("soucier",),
    "souciâmes": ("soucier",),
    "souciant": ("soucier",),
    "soucias": ("soucier",),
    "souciassent": ("soucier",),
    "souciasses": ("soucier",),
    "souciasse": ("soucier",),
    "souciassiez": ("soucier",),
    "souciassions": ("soucier",),
    "souciâtes": ("soucier",),
    "souciât": ("soucier",),
    "souciée": ("soucier",),
    "souciées": ("soucier",),
    "soucié": ("soucier",),
    "soucient": ("soucier",),
    "soucie": ("soucier",),
    "souciera": ("soucier",),
    "soucieraient": ("soucier",),
    "soucierai": ("soucier",),
    "soucierais": ("soucier",),
    "soucierait": ("soucier",),
    "soucieras": ("soucier",),
    "soucièrent": ("soucier",),
    "soucierez": ("soucier",),
    "soucieriez": ("soucier",),
    "soucierions": ("soucier",),
    "soucierons": ("soucier",),
    "soucieront": ("soucier",),
    "souciés": ("soucier",),
    "soucies": ("soucier",),
    "souciez": ("soucier",),
    "souciiez": ("soucier",),
    "souciions": ("soucier",),
    "soucions": ("soucier",),
    "soudoient": ("soudoyer",),
    "soudoie": ("soudoyer",),
    "soudoiera": ("soudoyer",),
    "soudoieraient": ("soudoyer",),
    "soudoierai": ("soudoyer",),
    "soudoierais": ("soudoyer",),
    "soudoierait": ("soudoyer",),
    "soudoieras": ("soudoyer",),
    "soudoierez": ("soudoyer",),
    "soudoieriez": ("soudoyer",),
    "soudoierions": ("soudoyer",),
    "soudoierons": ("soudoyer",),
    "soudoieront": ("soudoyer",),
    "soudoies": ("soudoyer",),
    "soudoyaient": ("soudoyer",),
    "soudoyai": ("soudoyer",),
    "soudoyais": ("soudoyer",),
    "soudoyait": ("soudoyer",),
    "soudoya": ("soudoyer",),
    "soudoyâmes": ("soudoyer",),
    "soudoyant": ("soudoyer",),
    "soudoyas": ("soudoyer",),
    "soudoyassent": ("soudoyer",),
    "soudoyasses": ("soudoyer",),
    "soudoyasse": ("soudoyer",),
    "soudoyassiez": ("soudoyer",),
    "soudoyassions": ("soudoyer",),
    "soudoyâtes": ("soudoyer",),
    "soudoyât": ("soudoyer",),
    "soudoyée": ("soudoyer",),
    "soudoyées": ("soudoyer",),
    "soudoyé": ("soudoyer",),
    "soudoyèrent": ("soudoyer",),
    "soudoyés": ("soudoyer",),
    "soudoyez": ("soudoyer",),
    "soudoyiez": ("soudoyer",),
    "soudoyions": ("soudoyer",),
    "soudoyons": ("soudoyer",),
    "souffletaient": ("souffleter",),
    "souffletai": ("souffleter",),
    "souffletais": ("souffleter",),
    "souffletait": ("souffleter",),
    "souffleta": ("souffleter",),
    "souffletâmes": ("souffleter",),
    "souffletant": ("souffleter",),
    "souffletas": ("souffleter",),
    "souffletassent": ("souffleter",),
    "souffletasses": ("souffleter",),
    "souffletasse": ("souffleter",),
    "souffletassiez": ("souffleter",),
    "souffletassions": ("souffleter",),
    "souffletâtes": ("souffleter",),
    "souffletât": ("souffleter",),
    "souffletée": ("souffleter",),
    "souffletées": ("souffleter",),
    "souffleté": ("souffleter",),
    "souffletèrent": ("souffleter",),
    "souffletés": ("souffleter",),
    "souffletez": ("souffleter",),
    "souffletiez": ("souffleter",),
    "souffletions": ("souffleter",),
    "souffletons": ("souffleter",),
    "soufflettent": ("souffleter",),
    "soufflette": ("souffleter",),
    "soufflettera": ("souffleter",),
    "souffletteraient": ("souffleter",),
    "souffletterai": ("souffleter",),
    "souffletterais": ("souffleter",),
    "souffletterait": ("souffleter",),
    "souffletteras": ("souffleter",),
    "souffletterez": ("souffleter",),
    "souffletteriez": ("souffleter",),
    "souffletterions": ("souffleter",),
    "souffletterons": ("souffleter",),
    "souffletteront": ("souffleter",),
    "soufflettes": ("souffleter",),
    "soufferte": ("souffrir",),
    "souffertes": ("souffrir",),
    "souffert": ("souffrir",),
    "soufferts": ("souffrir",),
    "souffraient": ("souffrir",),
    "souffrais": ("souffrir",),
    "souffrait": ("souffrir",),
    "souffrant": ("souffrir",),
    "souffrent": ("souffrir",),
    "souffre": ("souffrir",),
    "souffres": ("souffrir",),
    "souffrez": ("souffrir",),
    "souffriez": ("souffrir",),
    "souffrîmes": ("souffrir",),
    "souffrions": ("souffrir",),
    "souffrira": ("souffrir",),
    "souffriraient": ("souffrir",),
    "souffrirai": ("souffrir",),
    "souffrirais": ("souffrir",),
    "souffrirait": ("souffrir",),
    "souffriras": ("souffrir",),
    "souffrirent": ("souffrir",),
    "souffrirez": ("souffrir",),
    "souffririez": ("souffrir",),
    "souffririons": ("souffrir",),
    "souffrirons": ("souffrir",),
    "souffriront": ("souffrir",),
    "souffris": ("souffrir",),
    "souffrissent": ("souffrir",),
    "souffrisses": ("souffrir",),
    "souffrisse": ("souffrir",),
    "souffrissiez": ("souffrir",),
    "souffrissions": ("souffrir",),
    "souffrîtes": ("souffrir",),
    "souffrit": ("souffrir",),
    "souffrît": ("souffrir",),
    "souffrons": ("souffrir",),
    "soulageaient": ("soulager",),
    "soulageai": ("soulager",),
    "soulageais": ("soulager",),
    "soulageait": ("soulager",),
    "soulagea": ("soulager",),
    "soulageâmes": ("soulager",),
    "soulageant": ("soulager",),
    "soulageas": ("soulager",),
    "soulageassent": ("soulager",),
    "soulageasses": ("soulager",),
    "soulageasse": ("soulager",),
    "soulageassiez": ("soulager",),
    "soulageassions": ("soulager",),
    "soulageâtes": ("soulager",),
    "soulageât": ("soulager",),
    "soulagée": ("soulager",),
    "soulagées": ("soulager",),
    "soulagé": ("soulager",),
    "soulagent": ("soulager",),
    "soulageons": ("soulager",),
    "soulage": ("soulager",),
    "soulagera": ("soulager",),
    "soulageraient": ("soulager",),
    "soulagerai": ("soulager",),
    "soulagerais": ("soulager",),
    "soulagerait": ("soulager",),
    "soulageras": ("soulager",),
    "soulagèrent": ("soulager",),
    "soulagerez": ("soulager",),
    "soulageriez": ("soulager",),
    "soulagerions": ("soulager",),
    "soulagerons": ("soulager",),
    "soulageront": ("soulager",),
    "soulagés": ("soulager",),
    "soulages": ("soulager",),
    "soulagez": ("soulager",),
    "soulagiez": ("soulager",),
    "soulagions": ("soulager",),
    "soulevaient": ("soulever",),
    "soulevai": ("soulever",),
    "soulevais": ("soulever",),
    "soulevait": ("soulever",),
    "souleva": ("soulever",),
    "soulevâmes": ("soulever",),
    "soulevant": ("soulever",),
    "soulevas": ("soulever",),
    "soulevassent": ("soulever",),
    "soulevasses": ("soulever",),
    "soulevasse": ("soulever",),
    "soulevassiez": ("soulever",),
    "soulevassions": ("soulever",),
    "soulevâtes": ("soulever",),
    "soulevât": ("soulever",),
    "soulevée": ("soulever",),
    "soulevées": ("soulever",),
    "soulevé": ("soulever",),
    "soulèvent": ("soulever",),
    "soulève": ("soulever",),
    "soulèvera": ("soulever",),
    "soulèveraient": ("soulever",),
    "soulèverai": ("soulever",),
    "soulèverais": ("soulever",),
    "soulèverait": ("soulever",),
    "soulèveras": ("soulever",),
    "soulevèrent": ("soulever",),
    "soulèverez": ("soulever",),
    "soulèveriez": ("soulever",),
    "soulèverions": ("soulever",),
    "soulèverons": ("soulever",),
    "soulèveront": ("soulever",),
    "soulevés": ("soulever",),
    "soulèves": ("soulever",),
    "soulevez": ("soulever",),
    "souleviez": ("soulever",),
    "soulevions": ("soulever",),
    "soulevons": ("soulever",),
    "soumet": ("soumettre",),
    "soumets": ("soumettre",),
    "soumettaient": ("soumettre",),
    "soumettais": ("soumettre",),
    "soumettait": ("soumettre",),
    "soumettant": ("soumettre",),
    "soumettent": ("soumettre",),
    "soumette": ("soumettre",),
    "soumettes": ("soumettre",),
    "soumettez": ("soumettre",),
    "soumettiez": ("soumettre",),
    "soumettions": ("soumettre",),
    "soumettons": ("soumettre",),
    "soumettra": ("soumettre",),
    "soumettraient": ("soumettre",),
    "soumettrai": ("soumettre",),
    "soumettrais": ("soumettre",),
    "soumettrait": ("soumettre",),
    "soumettras": ("soumettre",),
    "soumettrez": ("soumettre",),
    "soumettriez": ("soumettre",),
    "soumettrions": ("soumettre",),
    "soumettrons": ("soumettre",),
    "soumettront": ("soumettre",),
    "soumîmes": ("soumettre",),
    "soumirent": ("soumettre",),
    "soumise": ("soumettre",),
    "soumises": ("soumettre",),
    "soumis": ("soumettre",),
    "soumissent": ("soumettre",),
    "soumisses": ("soumettre",),
    "soumisse": ("soumettre",),
    "soumissiez": ("soumettre",),
    "soumissions": ("soumettre",),
    "soumîtes": ("soumettre",),
    "soumit": ("soumettre",),
    "soumît": ("soumettre",),
    "soupesaient": ("soupeser",),
    "soupesai": ("soupeser",),
    "soupesais": ("soupeser",),
    "soupesait": ("soupeser",),
    "soupesa": ("soupeser",),
    "soupesâmes": ("soupeser",),
    "soupesant": ("soupeser",),
    "soupesas": ("soupeser",),
    "soupesassent": ("soupeser",),
    "soupesasses": ("soupeser",),
    "soupesasse": ("soupeser",),
    "soupesassiez": ("soupeser",),
    "soupesassions": ("soupeser",),
    "soupesâtes": ("soupeser",),
    "soupesât": ("soupeser",),
    "soupesée": ("soupeser",),
    "soupesées": ("soupeser",),
    "soupesé": ("soupeser",),
    "soupèsent": ("soupeser",),
    "soupèse": ("soupeser",),
    "soupèsera": ("soupeser",),
    "soupèseraient": ("soupeser",),
    "soupèserai": ("soupeser",),
    "soupèserais": ("soupeser",),
    "soupèserait": ("soupeser",),
    "soupèseras": ("soupeser",),
    "soupesèrent": ("soupeser",),
    "soupèserez": ("soupeser",),
    "soupèseriez": ("soupeser",),
    "soupèserions": ("soupeser",),
    "soupèserons": ("soupeser",),
    "soupèseront": ("soupeser",),
    "soupesés": ("soupeser",),
    "soupèses": ("soupeser",),
    "soupesez": ("soupeser",),
    "soupesiez": ("soupeser",),
    "soupesions": ("soupeser",),
    "soupesons": ("soupeser",),
    "souquetaient": ("souqueter",),
    "souquetai": ("souqueter",),
    "souquetais": ("souqueter",),
    "souquetait": ("souqueter",),
    "souqueta": ("souqueter",),
    "souquetâmes": ("souqueter",),
    "souquetant": ("souqueter",),
    "souquetas": ("souqueter",),
    "souquetassent": ("souqueter",),
    "souquetasses": ("souqueter",),
    "souquetasse": ("souqueter",),
    "souquetassiez": ("souqueter",),
    "souquetassions": ("souqueter",),
    "souquetâtes": ("souqueter",),
    "souquetât": ("souqueter",),
    "souquetée": ("souqueter",),
    "souquetées": ("souqueter",),
    "souqueté": ("souqueter",),
    "souquetèrent": ("souqueter",),
    "souquetés": ("souqueter",),
    "souquetez": ("souqueter",),
    "souquetiez": ("souqueter",),
    "souquetions": ("souqueter",),
    "souquetons": ("souqueter",),
    "souquettent": ("souqueter",),
    "souquette": ("souqueter",),
    "souquettera": ("souqueter",),
    "souquetteraient": ("souqueter",),
    "souquetterai": ("souqueter",),
    "souquetterais": ("souqueter",),
    "souquetterait": ("souqueter",),
    "souquetteras": ("souqueter",),
    "souquetterez": ("souqueter",),
    "souquetteriez": ("souqueter",),
    "souquetterions": ("souqueter",),
    "souquetterons": ("souqueter",),
    "souquetteront": ("souqueter",),
    "souquettes": ("souqueter",),
    "sourçaient": ("sourcer",),
    "sourçai": ("sourcer",),
    "sourçais": ("sourcer",),
    "sourçait": ("sourcer",),
    "sourça": ("sourcer",),
    "sourçâmes": ("sourcer",),
    "sourçant": ("sourcer",),
    "sourças": ("sourcer",),
    "sourçassent": ("sourcer",),
    "sourçasses": ("sourcer",),
    "sourçasse": ("sourcer",),
    "sourçassiez": ("sourcer",),
    "sourçassions": ("sourcer",),
    "sourçâtes": ("sourcer",),
    "sourçât": ("sourcer",),
    "sourcée": ("sourcer",),
    "sourcées": ("sourcer",),
    "sourcé": ("sourcer",),
    "sourcent": ("sourcer",),
    "source": ("sourcer",),
    "sourcera": ("sourcer",),
    "sourceraient": ("sourcer",),
    "sourcerai": ("sourcer",),
    "sourcerais": ("sourcer",),
    "sourcerait": ("sourcer",),
    "sourceras": ("sourcer",),
    "sourcèrent": ("sourcer",),
    "sourcerez": ("sourcer",),
    "sourceriez": ("sourcer",),
    "sourcerions": ("sourcer",),
    "sourcerons": ("sourcer",),
    "sourceront": ("sourcer",),
    "sourcés": ("sourcer",),
    "sources": ("sourcer",),
    "sourcez": ("sourcer",),
    "sourciez": ("sourcer",),
    "sourcions": ("sourcer",),
    "sourçons": ("sourcer",),
    "sourdaient": ("sourdre",),
    "sourdait": ("sourdre",),
    "sourdent": ("sourdre",),
    "sourd": ("sourdre",),
    "souriaient": ("sourire",),
    "souriais": ("sourire",),
    "souriait": ("sourire",),
    "souriant": ("sourire",),
    "sourient": ("sourire",),
    "sourie": ("sourire",),
    "souries": ("sourire",),
    "souriez": ("sourire",),
    "souriiez": ("sourire",),
    "souriions": ("sourire",),
    "souri": ("sourire",),
    "sourîmes": ("sourire",),
    "sourions": ("sourire",),
    "sourira": ("sourire",),
    "souriraient": ("sourire",),
    "sourirai": ("sourire",),
    "sourirais": ("sourire",),
    "sourirait": ("sourire",),
    "souriras": ("sourire",),
    "sourirent": ("sourire",),
    "sourirez": ("sourire",),
    "souririez": ("sourire",),
    "souririons": ("sourire",),
    "sourirons": ("sourire",),
    "souriront": ("sourire",),
    "souris": ("sourire",),
    "sourissent": ("sourire",),
    "sourisses": ("sourire",),
    "sourisse": ("sourire",),
    "sourissiez": ("sourire",),
    "sourissions": ("sourire",),
    "sourîtes": ("sourire",),
    "sourit": ("sourire",),
    "sourît": ("sourire",),
    "souscrira": ("souscrire",),
    "souscriraient": ("souscrire",),
    "souscrirai": ("souscrire",),
    "souscrirais": ("souscrire",),
    "souscrirait": ("souscrire",),
    "souscriras": ("souscrire",),
    "souscrirez": ("souscrire",),
    "souscririez": ("souscrire",),
    "souscririons": ("souscrire",),
    "souscrirons": ("souscrire",),
    "souscriront": ("souscrire",),
    "souscris": ("souscrire",),
    "souscrite": ("souscrire",),
    "souscrites": ("souscrire",),
    "souscrit": ("souscrire",),
    "souscrits": ("souscrire",),
    "souscrivaient": ("souscrire",),
    "souscrivais": ("souscrire",),
    "souscrivait": ("souscrire",),
    "souscrivant": ("souscrire",),
    "souscrivent": ("souscrire",),
    "souscrive": ("souscrire",),
    "souscrives": ("souscrire",),
    "souscrivez": ("souscrire",),
    "souscriviez": ("souscrire",),
    "souscrivîmes": ("souscrire",),
    "souscrivions": ("souscrire",),
    "souscrivirent": ("souscrire",),
    "souscrivis": ("souscrire",),
    "souscrivissent": ("souscrire",),
    "souscrivisses": ("souscrire",),
    "souscrivisse": ("souscrire",),
    "souscrivissiez": ("souscrire",),
    "souscrivissions": ("souscrire",),
    "souscrivîtes": ("souscrire",),
    "souscrivit": ("souscrire",),
    "souscrivît": ("souscrire",),
    "souscrivons": ("souscrire",),
    "sousquetaient": ("sousqueter",),
    "sousquetai": ("sousqueter",),
    "sousquetais": ("sousqueter",),
    "sousquetait": ("sousqueter",),
    "sousqueta": ("sousqueter",),
    "sousquetâmes": ("sousqueter",),
    "sousquetant": ("sousqueter",),
    "sousquetas": ("sousqueter",),
    "sousquetassent": ("sousqueter",),
    "sousquetasses": ("sousqueter",),
    "sousquetasse": ("sousqueter",),
    "sousquetassiez": ("sousqueter",),
    "sousquetassions": ("sousqueter",),
    "sousquetâtes": ("sousqueter",),
    "sousquetât": ("sousqueter",),
    "sousquetée": ("sousqueter",),
    "sousquetées": ("sousqueter",),
    "sousqueté": ("sousqueter",),
    "sousquetèrent": ("sousqueter",),
    "sousquetés": ("sousqueter",),
    "sousquetez": ("sousqueter",),
    "sousquetiez": ("sousqueter",),
    "sousquetions": ("sousqueter",),
    "sousquetons": ("sousqueter",),
    "sousquettent": ("sousqueter",),
    "sousquette": ("sousqueter",),
    "sousquettera": ("sousqueter",),
    "sousquetteraient": ("sousqueter",),
    "sousquetterai": ("sousqueter",),
    "sousquetterais": ("sousqueter",),
    "sousquetterait": ("sousqueter",),
    "sousquetteras": ("sousqueter",),
    "sousquetterez": ("sousqueter",),
    "sousquetteriez": ("sousqueter",),
    "sousquetterions": ("sousqueter",),
    "sousquetterons": ("sousqueter",),
    "sousquetteront": ("sousqueter",),
    "sousquettes": ("sousqueter",),
    "soustraient": ("soustraire",),
    "soustraie": ("soustraire",),
    "soustraies": ("soustraire",),
    "soustraira": ("soustraire",),
    "soustrairaient": ("soustraire",),
    "soustrairai": ("soustraire",),
    "soustrairais": ("soustraire",),
    "soustrairait": ("soustraire",),
    "soustrairas": ("soustraire",),
    "soustrairez": ("soustraire",),
    "soustrairiez": ("soustraire",),
    "soustrairions": ("soustraire",),
    "soustrairons": ("soustraire",),
    "soustrairont": ("soustraire",),
    "soustrais": ("soustraire",),
    "soustraite": ("soustraire",),
    "soustraites": ("soustraire",),
    "soustrait": ("soustraire",),
    "soustraits": ("soustraire",),
    "soustrayaient": ("soustraire",),
    "soustrayais": ("soustraire",),
    "soustrayait": ("soustraire",),
    "soustrayant": ("soustraire",),
    "soustrayez": ("soustraire",),
    "soustrayiez": ("soustraire",),
    "soustrayions": ("soustraire",),
    "soustrayons": ("soustraire",),
    "soutenaient": ("soutenir",),
    "soutenais": ("soutenir",),
    "soutenait": ("soutenir",),
    "soutenant": ("soutenir",),
    "soutenez": ("soutenir",),
    "souteniez": ("soutenir",),
    "soutenions": ("soutenir",),
    "soutenons": ("soutenir",),
    "soutenue": ("soutenir",),
    "soutenues": ("soutenir",),
    "soutenu": ("soutenir",),
    "soutenus": ("soutenir",),
    "soutiendra": ("soutenir",),
    "soutiendraient": ("soutenir",),
    "soutiendrai": ("soutenir",),
    "soutiendrais": ("soutenir",),
    "soutiendrait": ("soutenir",),
    "soutiendras": ("soutenir",),
    "soutiendrez": ("soutenir",),
    "soutiendriez": ("soutenir",),
    "soutiendrions": ("soutenir",),
    "soutiendrons": ("soutenir",),
    "soutiendront": ("soutenir",),
    "soutiennent": ("soutenir",),
    "soutienne": ("soutenir",),
    "soutiennes": ("soutenir",),
    "soutiens": ("soutenir",),
    "soutient": ("soutenir",),
    "soutînmes": ("soutenir",),
    "soutinrent": ("soutenir",),
    "soutins": ("soutenir",),
    "soutinssent": ("soutenir",),
    "soutinsses": ("soutenir",),
    "soutinsse": ("soutenir",),
    "soutinssiez": ("soutenir",),
    "soutinssions": ("soutenir",),
    "soutîntes": ("soutenir",),
    "soutint": ("soutenir",),
    "soutînt": ("soutenir",),
    "souvenaient": ("souvenir",),
    "souvenais": ("souvenir",),
    "souvenait": ("souvenir",),
    "souvenant": ("souvenir",),
    "souvenez": ("souvenir",),
    "souveniez": ("souvenir",),
    "souvenions": ("souvenir",),
    "souvenons": ("souvenir",),
    "souvenue": ("souvenir",),
    "souvenues": ("souvenir",),
    "souvenu": ("souvenir",),
    "souvenus": ("souvenir",),
    "souviendra": ("souvenir",),
    "souviendraient": ("souvenir",),
    "souviendrai": ("souvenir",),
    "souviendrais": ("souvenir",),
    "souviendrait": ("souvenir",),
    "souviendras": ("souvenir",),
    "souviendrez": ("souvenir",),
    "souviendriez": ("souvenir",),
    "souviendrions": ("souvenir",),
    "souviendrons": ("souvenir",),
    "souviendront": ("souvenir",),
    "souviennent": ("souvenir",),
    "souvienne": ("souvenir",),
    "souviennes": ("souvenir",),
    "souviens": ("souvenir",),
    "souvient": ("souvenir",),
    "souvînmes": ("souvenir",),
    "souvinrent": ("souvenir",),
    "souvins": ("souvenir",),
    "souvinssent": ("souvenir",),
    "souvinsses": ("souvenir",),
    "souvinsse": ("souvenir",),
    "souvinssiez": ("souvenir",),
    "souvinssions": ("souvenir",),
    "souvîntes": ("souvenir",),
    "souvint": ("souvenir",),
    "souvînt": ("souvenir",),
    "spathifiaient": ("spathifier",),
    "spathifiai": ("spathifier",),
    "spathifiais": ("spathifier",),
    "spathifiait": ("spathifier",),
    "spathifia": ("spathifier",),
    "spathifiâmes": ("spathifier",),
    "spathifiant": ("spathifier",),
    "spathifias": ("spathifier",),
    "spathifiassent": ("spathifier",),
    "spathifiasses": ("spathifier",),
    "spathifiasse": ("spathifier",),
    "spathifiassiez": ("spathifier",),
    "spathifiassions": ("spathifier",),
    "spathifiâtes": ("spathifier",),
    "spathifiât": ("spathifier",),
    "spathifiée": ("spathifier",),
    "spathifiées": ("spathifier",),
    "spathifié": ("spathifier",),
    "spathifient": ("spathifier",),
    "spathifie": ("spathifier",),
    "spathifiera": ("spathifier",),
    "spathifieraient": ("spathifier",),
    "spathifierai": ("spathifier",),
    "spathifierais": ("spathifier",),
    "spathifierait": ("spathifier",),
    "spathifieras": ("spathifier",),
    "spathifièrent": ("spathifier",),
    "spathifierez": ("spathifier",),
    "spathifieriez": ("spathifier",),
    "spathifierions": ("spathifier",),
    "spathifierons": ("spathifier",),
    "spathifieront": ("spathifier",),
    "spathifiés": ("spathifier",),
    "spathifies": ("spathifier",),
    "spathifiez": ("spathifier",),
    "spathifiiez": ("spathifier",),
    "spathifiions": ("spathifier",),
    "spathifions": ("spathifier",),
    "spécifiaient": ("spécifier",),
    "spécifiai": ("spécifier",),
    "spécifiais": ("spécifier",),
    "spécifiait": ("spécifier",),
    "spécifia": ("spécifier",),
    "spécifiâmes": ("spécifier",),
    "spécifiant": ("spécifier",),
    "spécifias": ("spécifier",),
    "spécifiassent": ("spécifier",),
    "spécifiasses": ("spécifier",),
    "spécifiasse": ("spécifier",),
    "spécifiassiez": ("spécifier",),
    "spécifiassions": ("spécifier",),
    "spécifiâtes": ("spécifier",),
    "spécifiât": ("spécifier",),
    "spécifiée": ("spécifier",),
    "spécifiées": ("spécifier",),
    "spécifié": ("spécifier",),
    "spécifient": ("spécifier",),
    "spécifie": ("spécifier",),
    "spécifiera": ("spécifier",),
    "spécifieraient": ("spécifier",),
    "spécifierai": ("spécifier",),
    "spécifierais": ("spécifier",),
    "spécifierait": ("spécifier",),
    "spécifieras": ("spécifier",),
    "spécifièrent": ("spécifier",),
    "spécifierez": ("spécifier",),
    "spécifieriez": ("spécifier",),
    "spécifierions": ("spécifier",),
    "spécifierons": ("spécifier",),
    "spécifieront": ("spécifier",),
    "spécifiés": ("spécifier",),
    "spécifies": ("spécifier",),
    "spécifiez": ("spécifier",),
    "spécifiiez": ("spécifier",),
    "spécifiions": ("spécifier",),
    "spécifions": ("spécifier",),
    "sphacélaient": ("sphacéler",),
    "sphacélai": ("sphacéler",),
    "sphacélais": ("sphacéler",),
    "sphacélait": ("sphacéler",),
    "sphacéla": ("sphacéler",),
    "sphacélâmes": ("sphacéler",),
    "sphacélant": ("sphacéler",),
    "sphacélas": ("sphacéler",),
    "sphacélassent": ("sphacéler",),
    "sphacélasses": ("sphacéler",),
    "sphacélasse": ("sphacéler",),
    "sphacélassiez": ("sphacéler",),
    "sphacélassions": ("sphacéler",),
    "sphacélâtes": ("sphacéler",),
    "sphacélât": ("sphacéler",),
    "sphacélée": ("sphacéler",),
    "sphacélées": ("sphacéler",),
    "sphacélé": ("sphacéler",),
    "sphacèlent": ("sphacéler",),
    "sphacèle": ("sphacéler",),
    "sphacélera": ("sphacéler",),
    "sphacéleraient": ("sphacéler",),
    "sphacélerai": ("sphacéler",),
    "sphacélerais": ("sphacéler",),
    "sphacélerait": ("sphacéler",),
    "sphacéleras": ("sphacéler",),
    "sphacélèrent": ("sphacéler",),
    "sphacélerez": ("sphacéler",),
    "sphacéleriez": ("sphacéler",),
    "sphacélerions": ("sphacéler",),
    "sphacélerons": ("sphacéler",),
    "sphacéleront": ("sphacéler",),
    "sphacélés": ("sphacéler",),
    "sphacèles": ("sphacéler",),
    "sphacélez": ("sphacéler",),
    "sphacéliez": ("sphacéler",),
    "sphacélions": ("sphacéler",),
    "sphacélons": ("sphacéler",),
    "spoliaient": ("spolier",),
    "spoliai": ("spolier",),
    "spoliais": ("spolier",),
    "spoliait": ("spolier",),
    "spolia": ("spolier",),
    "spoliâmes": ("spolier",),
    "spoliant": ("spolier",),
    "spolias": ("spolier",),
    "spoliassent": ("spolier",),
    "spoliasses": ("spolier",),
    "spoliasse": ("spolier",),
    "spoliassiez": ("spolier",),
    "spoliassions": ("spolier",),
    "spoliâtes": ("spolier",),
    "spoliât": ("spolier",),
    "spoliée": ("spolier",),
    "spoliées": ("spolier",),
    "spolié": ("spolier",),
    "spolient": ("spolier",),
    "spolie": ("spolier",),
    "spoliera": ("spolier",),
    "spolieraient": ("spolier",),
    "spolierai": ("spolier",),
    "spolierais": ("spolier",),
    "spolierait": ("spolier",),
    "spolieras": ("spolier",),
    "spolièrent": ("spolier",),
    "spolierez": ("spolier",),
    "spolieriez": ("spolier",),
    "spolierions": ("spolier",),
    "spolierons": ("spolier",),
    "spolieront": ("spolier",),
    "spoliés": ("spolier",),
    "spolies": ("spolier",),
    "spoliez": ("spolier",),
    "spoliiez": ("spolier",),
    "spoliions": ("spolier",),
    "spolions": ("spolier",),
    "starifiaient": ("starifier",),
    "starifiai": ("starifier",),
    "starifiais": ("starifier",),
    "starifiait": ("starifier",),
    "starifia": ("starifier",),
    "starifiâmes": ("starifier",),
    "starifiant": ("starifier",),
    "starifias": ("starifier",),
    "starifiassent": ("starifier",),
    "starifiasses": ("starifier",),
    "starifiasse": ("starifier",),
    "starifiassiez": ("starifier",),
    "starifiassions": ("starifier",),
    "starifiâtes": ("starifier",),
    "starifiât": ("starifier",),
    "starifiée": ("starifier",),
    "starifiées": ("starifier",),
    "starifié": ("starifier",),
    "starifient": ("starifier",),
    "starifie": ("starifier",),
    "starifiera": ("starifier",),
    "starifieraient": ("starifier",),
    "starifierai": ("starifier",),
    "starifierais": ("starifier",),
    "starifierait": ("starifier",),
    "starifieras": ("starifier",),
    "starifièrent": ("starifier",),
    "starifierez": ("starifier",),
    "starifieriez": ("starifier",),
    "starifierions": ("starifier",),
    "starifierons": ("starifier",),
    "starifieront": ("starifier",),
    "starifiés": ("starifier",),
    "starifies": ("starifier",),
    "starifiez": ("starifier",),
    "starifiiez": ("starifier",),
    "starifiions": ("starifier",),
    "starifions": ("starifier",),
    "statufiaient": ("statufier",),
    "statufiai": ("statufier",),
    "statufiais": ("statufier",),
    "statufiait": ("statufier",),
    "statufia": ("statufier",),
    "statufiâmes": ("statufier",),
    "statufiant": ("statufier",),
    "statufias": ("statufier",),
    "statufiassent": ("statufier",),
    "statufiasses": ("statufier",),
    "statufiasse": ("statufier",),
    "statufiassiez": ("statufier",),
    "statufiassions": ("statufier",),
    "statufiâtes": ("statufier",),
    "statufiât": ("statufier",),
    "statufiée": ("statufier",),
    "statufiées": ("statufier",),
    "statufié": ("statufier",),
    "statufient": ("statufier",),
    "statufie": ("statufier",),
    "statufiera": ("statufier",),
    "statufieraient": ("statufier",),
    "statufierai": ("statufier",),
    "statufierais": ("statufier",),
    "statufierait": ("statufier",),
    "statufieras": ("statufier",),
    "statufièrent": ("statufier",),
    "statufierez": ("statufier",),
    "statufieriez": ("statufier",),
    "statufierions": ("statufier",),
    "statufierons": ("statufier",),
    "statufieront": ("statufier",),
    "statufiés": ("statufier",),
    "statufies": ("statufier",),
    "statufiez": ("statufier",),
    "statufiiez": ("statufier",),
    "statufiions": ("statufier",),
    "statufions": ("statufier",),
    "stemaient": ("stemer",),
    "stemai": ("stemer",),
    "stemais": ("stemer",),
    "stemait": ("stemer",),
    "stema": ("stemer",),
    "stemâmes": ("stemer",),
    "stemant": ("stemer",),
    "stemas": ("stemer",),
    "stemassent": ("stemer",),
    "stemasses": ("stemer",),
    "stemasse": ("stemer",),
    "stemassiez": ("stemer",),
    "stemassions": ("stemer",),
    "stemâtes": ("stemer",),
    "stemât": ("stemer",),
    "stemée": ("stemer",),
    "stemées": ("stemer",),
    "stemé": ("stemer",),
    "stèment": ("stemer",),
    "stème": ("stemer",),
    "stèmera": ("stemer",),
    "stèmeraient": ("stemer",),
    "stèmerai": ("stemer",),
    "stèmerais": ("stemer",),
    "stèmerait": ("stemer",),
    "stèmeras": ("stemer",),
    "stemèrent": ("stemer",),
    "stèmerez": ("stemer",),
    "stèmeriez": ("stemer",),
    "stèmerions": ("stemer",),
    "stèmerons": ("stemer",),
    "stèmeront": ("stemer",),
    "stemés": ("stemer",),
    "stèmes": ("stemer",),
    "stemez": ("stemer",),
    "stemiez": ("stemer",),
    "stemions": ("stemer",),
    "stemons": ("stemer",),
    "sténographiaient": ("sténographier",),
    "sténographiai": ("sténographier",),
    "sténographiais": ("sténographier",),
    "sténographiait": ("sténographier",),
    "sténographia": ("sténographier",),
    "sténographiâmes": ("sténographier",),
    "sténographiant": ("sténographier",),
    "sténographias": ("sténographier",),
    "sténographiassent": ("sténographier",),
    "sténographiasses": ("sténographier",),
    "sténographiasse": ("sténographier",),
    "sténographiassiez": ("sténographier",),
    "sténographiassions": ("sténographier",),
    "sténographiâtes": ("sténographier",),
    "sténographiât": ("sténographier",),
    "sténographiée": ("sténographier",),
    "sténographiées": ("sténographier",),
    "sténographié": ("sténographier",),
    "sténographient": ("sténographier",),
    "sténographie": ("sténographier",),
    "sténographiera": ("sténographier",),
    "sténographieraient": ("sténographier",),
    "sténographierai": ("sténographier",),
    "sténographierais": ("sténographier",),
    "sténographierait": ("sténographier",),
    "sténographieras": ("sténographier",),
    "sténographièrent": ("sténographier",),
    "sténographierez": ("sténographier",),
    "sténographieriez": ("sténographier",),
    "sténographierions": ("sténographier",),
    "sténographierons": ("sténographier",),
    "sténographieront": ("sténographier",),
    "sténographiés": ("sténographier",),
    "sténographies": ("sténographier",),
    "sténographiez": ("sténographier",),
    "sténographiiez": ("sténographier",),
    "sténographiions": ("sténographier",),
    "sténographions": ("sténographier",),
    "stéraient": ("stérer",),
    "stérai": ("stérer",),
    "stérais": ("stérer",),
    "stérait": ("stérer",),
    "stéra": ("stérer",),
    "stérâmes": ("stérer",),
    "stérant": ("stérer",),
    "stéras": ("stérer",),
    "stérassent": ("stérer",),
    "stérasses": ("stérer",),
    "stérasse": ("stérer",),
    "stérassiez": ("stérer",),
    "stérassions": ("stérer",),
    "stérâtes": ("stérer",),
    "stérât": ("stérer",),
    "stérée": ("stérer",),
    "stérées": ("stérer",),
    "stéré": ("stérer",),
    "stèrent": ("stérer",),
    "stère": ("stérer",),
    "stérera": ("stérer",),
    "stéreraient": ("stérer",),
    "stérerai": ("stérer",),
    "stérerais": ("stérer",),
    "stérerait": ("stérer",),
    "stéreras": ("stérer",),
    "stérèrent": ("stérer",),
    "stérerez": ("stérer",),
    "stéreriez": ("stérer",),
    "stérerions": ("stérer",),
    "stérerons": ("stérer",),
    "stéreront": ("stérer",),
    "stérés": ("stérer",),
    "stères": ("stérer",),
    "stérez": ("stérer",),
    "stériez": ("stérer",),
    "stérions": ("stérer",),
    "stérons": ("stérer",),
    "stipendiaient": ("stipendier",),
    "stipendiai": ("stipendier",),
    "stipendiais": ("stipendier",),
    "stipendiait": ("stipendier",),
    "stipendia": ("stipendier",),
    "stipendiâmes": ("stipendier",),
    "stipendiant": ("stipendier",),
    "stipendias": ("stipendier",),
    "stipendiassent": ("stipendier",),
    "stipendiasses": ("stipendier",),
    "stipendiasse": ("stipendier",),
    "stipendiassiez": ("stipendier",),
    "stipendiassions": ("stipendier",),
    "stipendiâtes": ("stipendier",),
    "stipendiât": ("stipendier",),
    "stipendiée": ("stipendier",),
    "stipendiées": ("stipendier",),
    "stipendié": ("stipendier",),
    "stipendient": ("stipendier",),
    "stipendie": ("stipendier",),
    "stipendiera": ("stipendier",),
    "stipendieraient": ("stipendier",),
    "stipendierai": ("stipendier",),
    "stipendierais": ("stipendier",),
    "stipendierait": ("stipendier",),
    "stipendieras": ("stipendier",),
    "stipendièrent": ("stipendier",),
    "stipendierez": ("stipendier",),
    "stipendieriez": ("stipendier",),
    "stipendierions": ("stipendier",),
    "stipendierons": ("stipendier",),
    "stipendieront": ("stipendier",),
    "stipendiés": ("stipendier",),
    "stipendies": ("stipendier",),
    "stipendiez": ("stipendier",),
    "stipendiiez": ("stipendier",),
    "stipendiions": ("stipendier",),
    "stipendions": ("stipendier",),
    "strapassaient": ("strapasser",),
    "strapassai": ("strapasser",),
    "strapassais": ("strapasser",),
    "strapassait": ("strapasser",),
    "strapassa": ("strapasser",),
    "strapassâmes": ("strapasser",),
    "strapassant": ("strapasser",),
    "strapassas": ("strapasser",),
    "strapassassent": ("strapasser",),
    "strapassasses": ("strapasser",),
    "strapassasse": ("strapasser",),
    "strapassassiez": ("strapasser",),
    "strapassassions": ("strapasser",),
    "strapassâtes": ("strapasser",),
    "strapassât": ("strapasser",),
    "strapassée": ("strapasser",),
    "strapassées": ("strapasser",),
    "strapassé": ("strapasser",),
    "strapassent": ("strapasser",),
    "strapasse": ("strapasser",),
    "strapassera": ("strapasser",),
    "strapasseraient": ("strapasser",),
    "strapasserai": ("strapasser",),
    "strapasserais": ("strapasser",),
    "strapasserait": ("strapasser",),
    "strapasseras": ("strapasser",),
    "strapassèrent": ("strapasser",),
    "strapasserez": ("strapasser",),
    "strapasseriez": ("strapasser",),
    "strapasserions": ("strapasser",),
    "strapasserons": ("strapasser",),
    "strapasseront": ("strapasser",),
    "strapassés": ("strapasser",),
    "strapasses": ("strapasser",),
    "strapassez": ("strapasser",),
    "strapassiez": ("strapasser",),
    "strapassions": ("strapasser",),
    "strapassons": ("strapasser",),
    "stratifiaient": ("stratifier",),
    "stratifiai": ("stratifier",),
    "stratifiais": ("stratifier",),
    "stratifiait": ("stratifier",),
    "stratifia": ("stratifier",),
    "stratifiâmes": ("stratifier",),
    "stratifiant": ("stratifier",),
    "stratifias": ("stratifier",),
    "stratifiassent": ("stratifier",),
    "stratifiasses": ("stratifier",),
    "stratifiasse": ("stratifier",),
    "stratifiassiez": ("stratifier",),
    "stratifiassions": ("stratifier",),
    "stratifiâtes": ("stratifier",),
    "stratifiât": ("stratifier",),
    "stratifiée": ("stratifier",),
    "stratifiées": ("stratifier",),
    "stratifié": ("stratifier",),
    "stratifient": ("stratifier",),
    "stratifie": ("stratifier",),
    "stratifiera": ("stratifier",),
    "stratifieraient": ("stratifier",),
    "stratifierai": ("stratifier",),
    "stratifierais": ("stratifier",),
    "stratifierait": ("stratifier",),
    "stratifieras": ("stratifier",),
    "stratifièrent": ("stratifier",),
    "stratifierez": ("stratifier",),
    "stratifieriez": ("stratifier",),
    "stratifierions": ("stratifier",),
    "stratifierons": ("stratifier",),
    "stratifieront": ("stratifier",),
    "stratifiés": ("stratifier",),
    "stratifies": ("stratifier",),
    "stratifiez": ("stratifier",),
    "stratifiiez": ("stratifier",),
    "stratifiions": ("stratifier",),
    "stratifions": ("stratifier",),
    "striaient": ("strier",),
    "striai": ("strier",),
    "striais": ("strier",),
    "striait": ("strier",),
    "stria": ("strier",),
    "striâmes": ("strier",),
    "striant": ("strier",),
    "strias": ("strier",),
    "striassent": ("strier",),
    "striasses": ("strier",),
    "striasse": ("strier",),
    "striassiez": ("strier",),
    "striassions": ("strier",),
    "striâtes": ("strier",),
    "striât": ("strier",),
    "striée": ("strier",),
    "striées": ("strier",),
    "strié": ("strier",),
    "strient": ("strier",),
    "strie": ("strier",),
    "striera": ("strier",),
    "strieraient": ("strier",),
    "strierai": ("strier",),
    "strierais": ("strier",),
    "strierait": ("strier",),
    "strieras": ("strier",),
    "strièrent": ("strier",),
    "strierez": ("strier",),
    "strieriez": ("strier",),
    "strierions": ("strier",),
    "strierons": ("strier",),
    "strieront": ("strier",),
    "striés": ("strier",),
    "stries": ("strier",),
    "striez": ("strier",),
    "striiez": ("strier",),
    "striions": ("strier",),
    "strions": ("strier",),
    "stupéfaisait": ("stupéfaire",),
    "stupéfaisant": ("stupéfaire",),
    "stupéfait": ("stupéfaire",),
    "stupéfasse": ("stupéfaire",),
    "stupéfera": ("stupéfaire",),
    "stupéferait": ("stupéfaire",),
    "stupéfit": ("stupéfaire",),
    "stupéfît": ("stupéfaire",),
    "stupéfiaient": ("stupéfier",),
    "stupéfiai": ("stupéfier",),
    "stupéfiais": ("stupéfier",),
    "stupéfiait": ("stupéfier",),
    "stupéfia": ("stupéfier",),
    "stupéfiâmes": ("stupéfier",),
    "stupéfiant": ("stupéfier",),
    "stupéfias": ("stupéfier",),
    "stupéfiassent": ("stupéfier",),
    "stupéfiasses": ("stupéfier",),
    "stupéfiasse": ("stupéfier",),
    "stupéfiassiez": ("stupéfier",),
    "stupéfiassions": ("stupéfier",),
    "stupéfiâtes": ("stupéfier",),
    "stupéfiât": ("stupéfier",),
    "stupéfiée": ("stupéfier",),
    "stupéfiées": ("stupéfier",),
    "stupéfié": ("stupéfier",),
    "stupéfient": ("stupéfier",),
    "stupéfie": ("stupéfier",),
    "stupéfiera": ("stupéfier",),
    "stupéfieraient": ("stupéfier",),
    "stupéfierai": ("stupéfier",),
    "stupéfierais": ("stupéfier",),
    "stupéfierait": ("stupéfier",),
    "stupéfieras": ("stupéfier",),
    "stupéfièrent": ("stupéfier",),
    "stupéfierez": ("stupéfier",),
    "stupéfieriez": ("stupéfier",),
    "stupéfierions": ("stupéfier",),
    "stupéfierons": ("stupéfier",),
    "stupéfieront": ("stupéfier",),
    "stupéfiés": ("stupéfier",),
    "stupéfies": ("stupéfier",),
    "stupéfiez": ("stupéfier",),
    "stupéfiiez": ("stupéfier",),
    "stupéfiions": ("stupéfier",),
    "stupéfions": ("stupéfier",),
    "subdéléguaient": ("subdéléguer",),
    "subdéléguai": ("subdéléguer",),
    "subdéléguais": ("subdéléguer",),
    "subdéléguait": ("subdéléguer",),
    "subdélégua": ("subdéléguer",),
    "subdéléguâmes": ("subdéléguer",),
    "subdéléguant": ("subdéléguer",),
    "subdéléguas": ("subdéléguer",),
    "subdéléguassent": ("subdéléguer",),
    "subdéléguasses": ("subdéléguer",),
    "subdéléguasse": ("subdéléguer",),
    "subdéléguassiez": ("subdéléguer",),
    "subdéléguassions": ("subdéléguer",),
    "subdéléguâtes": ("subdéléguer",),
    "subdéléguât": ("subdéléguer",),
    "subdéléguée": ("subdéléguer",),
    "subdéléguées": ("subdéléguer",),
    "subdélégué": ("subdéléguer",),
    "subdélèguent": ("subdéléguer",),
    "subdélègue": ("subdéléguer",),
    "subdéléguera": ("subdéléguer",),
    "subdélégueraient": ("subdéléguer",),
    "subdéléguerai": ("subdéléguer",),
    "subdéléguerais": ("subdéléguer",),
    "subdéléguerait": ("subdéléguer",),
    "subdélégueras": ("subdéléguer",),
    "subdéléguèrent": ("subdéléguer",),
    "subdéléguerez": ("subdéléguer",),
    "subdélégueriez": ("subdéléguer",),
    "subdéléguerions": ("subdéléguer",),
    "subdéléguerons": ("subdéléguer",),
    "subdélégueront": ("subdéléguer",),
    "subdélégués": ("subdéléguer",),
    "subdélègues": ("subdéléguer",),
    "subdéléguez": ("subdéléguer",),
    "subdéléguiez": ("subdéléguer",),
    "subdéléguions": ("subdéléguer",),
    "subdéléguons": ("subdéléguer",),
    "subduira": ("subduire",),
    "subduiraient": ("subduire",),
    "subduirai": ("subduire",),
    "subduirais": ("subduire",),
    "subduirait": ("subduire",),
    "subduiras": ("subduire",),
    "subduirez": ("subduire",),
    "subduiriez": ("subduire",),
    "subduirions": ("subduire",),
    "subduirons": ("subduire",),
    "subduiront": ("subduire",),
    "subduisaient": ("subduire",),
    "subduisais": ("subduire",),
    "subduisait": ("subduire",),
    "subduisant": ("subduire",),
    "subduisent": ("subduire",),
    "subduise": ("subduire",),
    "subduises": ("subduire",),
    "subduisez": ("subduire",),
    "subduisiez": ("subduire",),
    "subduisîmes": ("subduire",),
    "subduisions": ("subduire",),
    "subduisirent": ("subduire",),
    "subduisis": ("subduire",),
    "subduisissent": ("subduire",),
    "subduisisses": ("subduire",),
    "subduisisse": ("subduire",),
    "subduisissiez": ("subduire",),
    "subduisissions": ("subduire",),
    "subduisîtes": ("subduire",),
    "subduisit": ("subduire",),
    "subduisît": ("subduire",),
    "subduisons": ("subduire",),
    "subduis": ("subduire",),
    "subduite": ("subduire",),
    "subduites": ("subduire",),
    "subduit": ("subduire",),
    "subduits": ("subduire",),
    "subérifiaient": ("subérifier",),
    "subérifiai": ("subérifier",),
    "subérifiais": ("subérifier",),
    "subérifiait": ("subérifier",),
    "subérifia": ("subérifier",),
    "subérifiâmes": ("subérifier",),
    "subérifiant": ("subérifier",),
    "subérifias": ("subérifier",),
    "subérifiassent": ("subérifier",),
    "subérifiasses": ("subérifier",),
    "subérifiasse": ("subérifier",),
    "subérifiassiez": ("subérifier",),
    "subérifiassions": ("subérifier",),
    "subérifiâtes": ("subérifier",),
    "subérifiât": ("subérifier",),
    "subérifiée": ("subérifier",),
    "subérifiées": ("subérifier",),
    "subérifié": ("subérifier",),
    "subérifient": ("subérifier",),
    "subérifie": ("subérifier",),
    "subérifiera": ("subérifier",),
    "subérifieraient": ("subérifier",),
    "subérifierai": ("subérifier",),
    "subérifierais": ("subérifier",),
    "subérifierait": ("subérifier",),
    "subérifieras": ("subérifier",),
    "subérifièrent": ("subérifier",),
    "subérifierez": ("subérifier",),
    "subérifieriez": ("subérifier",),
    "subérifierions": ("subérifier",),
    "subérifierons": ("subérifier",),
    "subérifieront": ("subérifier",),
    "subérifiés": ("subérifier",),
    "subérifies": ("subérifier",),
    "subérifiez": ("subérifier",),
    "subérifiiez": ("subérifier",),
    "subérifiions": ("subérifier",),
    "subérifions": ("subérifier",),
    "subie": ("subir",),
    "subies": ("subir",),
    "subi": ("subir",),
    "subîmes": ("subir",),
    "subira": ("subir",),
    "subiraient": ("subir",),
    "subirai": ("subir",),
    "subirais": ("subir",),
    "subirait": ("subir",),
    "subiras": ("subir",),
    "subirent": ("subir",),
    "subirez": ("subir",),
    "subiriez": ("subir",),
    "subirions": ("subir",),
    "subirons": ("subir",),
    "subiront": ("subir",),
    "subis": ("subir",),
    "subissaient": ("subir",),
    "subissais": ("subir",),
    "subissait": ("subir",),
    "subissant": ("subir",),
    "subissent": ("subir",),
    "subisse": ("subir",),
    "subisses": ("subir",),
    "subissez": ("subir",),
    "subissiez": ("subir",),
    "subissions": ("subir",),
    "subissons": ("subir",),
    "subîtes": ("subir",),
    "subit": ("subir",),
    "subît": ("subir",),
    "submergeaient": ("submerger",),
    "submergeai": ("submerger",),
    "submergeais": ("submerger",),
    "submergeait": ("submerger",),
    "submergea": ("submerger",),
    "submergeâmes": ("submerger",),
    "submergeant": ("submerger",),
    "submergeas": ("submerger",),
    "submergeassent": ("submerger",),
    "submergeasses": ("submerger",),
    "submergeasse": ("submerger",),
    "submergeassiez": ("submerger",),
    "submergeassions": ("submerger",),
    "submergeâtes": ("submerger",),
    "submergeât": ("submerger",),
    "submergée": ("submerger",),
    "submergées": ("submerger",),
    "submergé": ("submerger",),
    "submergent": ("submerger",),
    "submergeons": ("submerger",),
    "submerge": ("submerger",),
    "submergera": ("submerger",),
    "submergeraient": ("submerger",),
    "submergerai": ("submerger",),
    "submergerais": ("submerger",),
    "submergerait": ("submerger",),
    "submergeras": ("submerger",),
    "submergèrent": ("submerger",),
    "submergerez": ("submerger",),
    "submergeriez": ("submerger",),
    "submergerions": ("submerger",),
    "submergerons": ("submerger",),
    "submergeront": ("submerger",),
    "submergés": ("submerger",),
    "submerges": ("submerger",),
    "submergez": ("submerger",),
    "submergiez": ("submerger",),
    "submergions": ("submerger",),
    "subrogeaient": ("subroger",),
    "subrogeai": ("subroger",),
    "subrogeais": ("subroger",),
    "subrogeait": ("subroger",),
    "subrogea": ("subroger",),
    "subrogeâmes": ("subroger",),
    "subrogeant": ("subroger",),
    "subrogeas": ("subroger",),
    "subrogeassent": ("subroger",),
    "subrogeasses": ("subroger",),
    "subrogeasse": ("subroger",),
    "subrogeassiez": ("subroger",),
    "subrogeassions": ("subroger",),
    "subrogeâtes": ("subroger",),
    "subrogeât": ("subroger",),
    "subrogée": ("subroger",),
    "subrogées": ("subroger",),
    "subrogé": ("subroger",),
    "subrogent": ("subroger",),
    "subrogeons": ("subroger",),
    "subroge": ("subroger",),
    "subrogera": ("subroger",),
    "subrogeraient": ("subroger",),
    "subrogerai": ("subroger",),
    "subrogerais": ("subroger",),
    "subrogerait": ("subroger",),
    "subrogeras": ("subroger",),
    "subrogèrent": ("subroger",),
    "subrogerez": ("subroger",),
    "subrogeriez": ("subroger",),
    "subrogerions": ("subroger",),
    "subrogerons": ("subroger",),
    "subrogeront": ("subroger",),
    "subrogés": ("subroger",),
    "subroges": ("subroger",),
    "subrogez": ("subroger",),
    "subrogiez": ("subroger",),
    "subrogions": ("subroger",),
    "substantiaient": ("substantier",),
    "substantiai": ("substantier",),
    "substantiais": ("substantier",),
    "substantiait": ("substantier",),
    "substantia": ("substantier",),
    "substantiâmes": ("substantier",),
    "substantiant": ("substantier",),
    "substantias": ("substantier",),
    "substantiassent": ("substantier",),
    "substantiasses": ("substantier",),
    "substantiasse": ("substantier",),
    "substantiassiez": ("substantier",),
    "substantiassions": ("substantier",),
    "substantiâtes": ("substantier",),
    "substantiât": ("substantier",),
    "substantiée": ("substantier",),
    "substantiées": ("substantier",),
    "substantié": ("substantier",),
    "substantient": ("substantier",),
    "substantie": ("substantier",),
    "substantiera": ("substantier",),
    "substantieraient": ("substantier",),
    "substantierai": ("substantier",),
    "substantierais": ("substantier",),
    "substantierait": ("substantier",),
    "substantieras": ("substantier",),
    "substantièrent": ("substantier",),
    "substantierez": ("substantier",),
    "substantieriez": ("substantier",),
    "substantierions": ("substantier",),
    "substantierons": ("substantier",),
    "substantieront": ("substantier",),
    "substantiés": ("substantier",),
    "substanties": ("substantier",),
    "substantiez": ("substantier",),
    "substantiiez": ("substantier",),
    "substantiions": ("substantier",),
    "substantions": ("substantier",),
    "substantifiaient": ("substantifier",),
    "substantifiai": ("substantifier",),
    "substantifiais": ("substantifier",),
    "substantifiait": ("substantifier",),
    "substantifia": ("substantifier",),
    "substantifiâmes": ("substantifier",),
    "substantifiant": ("substantifier",),
    "substantifias": ("substantifier",),
    "substantifiassent": ("substantifier",),
    "substantifiasses": ("substantifier",),
    "substantifiasse": ("substantifier",),
    "substantifiassiez": ("substantifier",),
    "substantifiassions": ("substantifier",),
    "substantifiâtes": ("substantifier",),
    "substantifiât": ("substantifier",),
    "substantifiée": ("substantifier",),
    "substantifiées": ("substantifier",),
    "substantifié": ("substantifier",),
    "substantifient": ("substantifier",),
    "substantifie": ("substantifier",),
    "substantifiera": ("substantifier",),
    "substantifieraient": ("substantifier",),
    "substantifierai": ("substantifier",),
    "substantifierais": ("substantifier",),
    "substantifierait": ("substantifier",),
    "substantifieras": ("substantifier",),
    "substantifièrent": ("substantifier",),
    "substantifierez": ("substantifier",),
    "substantifieriez": ("substantifier",),
    "substantifierions": ("substantifier",),
    "substantifierons": ("substantifier",),
    "substantifieront": ("substantifier",),
    "substantifiés": ("substantifier",),
    "substantifies": ("substantifier",),
    "substantifiez": ("substantifier",),
    "substantifiiez": ("substantifier",),
    "substantifiions": ("substantifier",),
    "substantifions": ("substantifier",),
    "subvenaient": ("subvenir",),
    "subvenais": ("subvenir",),
    "subvenait": ("subvenir",),
    "subvenant": ("subvenir",),
    "subvenez": ("subvenir",),
    "subveniez": ("subvenir",),
    "subvenions": ("subvenir",),
    "subvenons": ("subvenir",),
    "subvenu": ("subvenir",),
    "subviendra": ("subvenir",),
    "subviendraient": ("subvenir",),
    "subviendrai": ("subvenir",),
    "subviendrais": ("subvenir",),
    "subviendrait": ("subvenir",),
    "subviendras": ("subvenir",),
    "subviendrez": ("subvenir",),
    "subviendriez": ("subvenir",),
    "subviendrions": ("subvenir",),
    "subviendrons": ("subvenir",),
    "subviendront": ("subvenir",),
    "subviennent": ("subvenir",),
    "subvienne": ("subvenir",),
    "subviennes": ("subvenir",),
    "subviens": ("subvenir",),
    "subvient": ("subvenir",),
    "subvînmes": ("subvenir",),
    "subvinrent": ("subvenir",),
    "subvins": ("subvenir",),
    "subvinssent": ("subvenir",),
    "subvinsses": ("subvenir",),
    "subvinsse": ("subvenir",),
    "subvinssiez": ("subvenir",),
    "subvinssions": ("subvenir",),
    "subvîntes": ("subvenir",),
    "subvint": ("subvenir",),
    "subvînt": ("subvenir",),
    "subvertie": ("subvertir",),
    "subverties": ("subvertir",),
    "subverti": ("subvertir",),
    "subvertîmes": ("subvertir",),
    "subvertira": ("subvertir",),
    "subvertiraient": ("subvertir",),
    "subvertirai": ("subvertir",),
    "subvertirais": ("subvertir",),
    "subvertirait": ("subvertir",),
    "subvertiras": ("subvertir",),
    "subvertirent": ("subvertir",),
    "subvertirez": ("subvertir",),
    "subvertiriez": ("subvertir",),
    "subvertirions": ("subvertir",),
    "subvertirons": ("subvertir",),
    "subvertiront": ("subvertir",),
    "subvertis": ("subvertir",),
    "subvertissaient": ("subvertir",),
    "subvertissais": ("subvertir",),
    "subvertissait": ("subvertir",),
    "subvertissant": ("subvertir",),
    "subvertissent": ("subvertir",),
    "subvertisse": ("subvertir",),
    "subvertisses": ("subvertir",),
    "subvertissez": ("subvertir",),
    "subvertissiez": ("subvertir",),
    "subvertissions": ("subvertir",),
    "subvertissons": ("subvertir",),
    "subvertîtes": ("subvertir",),
    "subvertit": ("subvertir",),
    "subvertît": ("subvertir",),
    "succédaient": ("succéder",),
    "succédai": ("succéder",),
    "succédais": ("succéder",),
    "succédait": ("succéder",),
    "succéda": ("succéder",),
    "succédâmes": ("succéder",),
    "succédant": ("succéder",),
    "succédas": ("succéder",),
    "succédassent": ("succéder",),
    "succédasses": ("succéder",),
    "succédasse": ("succéder",),
    "succédassiez": ("succéder",),
    "succédassions": ("succéder",),
    "succédâtes": ("succéder",),
    "succédât": ("succéder",),
    "succédé": ("succéder",),
    "succèdent": ("succéder",),
    "succède": ("succéder",),
    "succédera": ("succéder",),
    "succéderaient": ("succéder",),
    "succéderai": ("succéder",),
    "succéderais": ("succéder",),
    "succéderait": ("succéder",),
    "succéderas": ("succéder",),
    "succédèrent": ("succéder",),
    "succéderez": ("succéder",),
    "succéderiez": ("succéder",),
    "succéderions": ("succéder",),
    "succéderons": ("succéder",),
    "succéderont": ("succéder",),
    "succèdes": ("succéder",),
    "succédez": ("succéder",),
    "succédiez": ("succéder",),
    "succédions": ("succéder",),
    "succédons": ("succéder",),
    "suçaient": ("sucer",),
    "suçai": ("sucer",),
    "suçais": ("sucer",),
    "suçait": ("sucer",),
    "suça": ("sucer",),
    "suçâmes": ("sucer",),
    "suçant": ("sucer",),
    "suças": ("sucer",),
    "suçassent": ("sucer",),
    "suçasses": ("sucer",),
    "suçasse": ("sucer",),
    "suçassiez": ("sucer",),
    "suçassions": ("sucer",),
    "suçâtes": ("sucer",),
    "suçât": ("sucer",),
    "sucée": ("sucer",),
    "sucées": ("sucer",),
    "sucé": ("sucer",),
    "sucent": ("sucer",),
    "suce": ("sucer",),
    "sucera": ("sucer",),
    "suceraient": ("sucer",),
    "sucerai": ("sucer",),
    "sucerais": ("sucer",),
    "sucerait": ("sucer",),
    "suceras": ("sucer",),
    "sucèrent": ("sucer",),
    "sucerez": ("sucer",),
    "suceriez": ("sucer",),
    "sucerions": ("sucer",),
    "sucerons": ("sucer",),
    "suceront": ("sucer",),
    "sucés": ("sucer",),
    "suces": ("sucer",),
    "sucez": ("sucer",),
    "suciez": ("sucer",),
    "sucions": ("sucer",),
    "suçons": ("sucer",),
    "sudorifiaient": ("sudorifier",),
    "sudorifiai": ("sudorifier",),
    "sudorifiais": ("sudorifier",),
    "sudorifiait": ("sudorifier",),
    "sudorifia": ("sudorifier",),
    "sudorifiâmes": ("sudorifier",),
    "sudorifiant": ("sudorifier",),
    "sudorifias": ("sudorifier",),
    "sudorifiassent": ("sudorifier",),
    "sudorifiasses": ("sudorifier",),
    "sudorifiasse": ("sudorifier",),
    "sudorifiassiez": ("sudorifier",),
    "sudorifiassions": ("sudorifier",),
    "sudorifiâtes": ("sudorifier",),
    "sudorifiât": ("sudorifier",),
    "sudorifiée": ("sudorifier",),
    "sudorifiées": ("sudorifier",),
    "sudorifié": ("sudorifier",),
    "sudorifient": ("sudorifier",),
    "sudorifie": ("sudorifier",),
    "sudorifiera": ("sudorifier",),
    "sudorifieraient": ("sudorifier",),
    "sudorifierai": ("sudorifier",),
    "sudorifierais": ("sudorifier",),
    "sudorifierait": ("sudorifier",),
    "sudorifieras": ("sudorifier",),
    "sudorifièrent": ("sudorifier",),
    "sudorifierez": ("sudorifier",),
    "sudorifieriez": ("sudorifier",),
    "sudorifierions": ("sudorifier",),
    "sudorifierons": ("sudorifier",),
    "sudorifieront": ("sudorifier",),
    "sudorifiés": ("sudorifier",),
    "sudorifies": ("sudorifier",),
    "sudorifiez": ("sudorifier",),
    "sudorifiiez": ("sudorifier",),
    "sudorifiions": ("sudorifier",),
    "sudorifions": ("sudorifier",),
    "suffi": ("suffire",),
    "suffîmes": ("suffire",),
    "suffira": ("suffire",),
    "suffiraient": ("suffire",),
    "suffirai": ("suffire",),
    "suffirais": ("suffire",),
    "suffirait": ("suffire",),
    "suffiras": ("suffire",),
    "suffirent": ("suffire",),
    "suffirez": ("suffire",),
    "suffiriez": ("suffire",),
    "suffirions": ("suffire",),
    "suffirons": ("suffire",),
    "suffiront": ("suffire",),
    "suffisaient": ("suffire",),
    "suffisais": ("suffire",),
    "suffisait": ("suffire",),
    "suffisant": ("suffire",),
    "suffisent": ("suffire",),
    "suffise": ("suffire",),
    "suffises": ("suffire",),
    "suffisez": ("suffire",),
    "suffisiez": ("suffire",),
    "suffisions": ("suffire",),
    "suffisons": ("suffire",),
    "suffis": ("suffire",),
    "suffissent": ("suffire",),
    "suffisses": ("suffire",),
    "suffisse": ("suffire",),
    "suffissiez": ("suffire",),
    "suffissions": ("suffire",),
    "suffîtes": ("suffire",),
    "suffit": ("suffire",),
    "suffît": ("suffire",),
    "suggéraient": ("suggérer",),
    "suggérai": ("suggérer",),
    "suggérais": ("suggérer",),
    "suggérait": ("suggérer",),
    "suggéra": ("suggérer",),
    "suggérâmes": ("suggérer",),
    "suggérant": ("suggérer",),
    "suggéras": ("suggérer",),
    "suggérassent": ("suggérer",),
    "suggérasses": ("suggérer",),
    "suggérasse": ("suggérer",),
    "suggérassiez": ("suggérer",),
    "suggérassions": ("suggérer",),
    "suggérâtes": ("suggérer",),
    "suggérât": ("suggérer",),
    "suggérée": ("suggérer",),
    "suggérées": ("suggérer",),
    "suggéré": ("suggérer",),
    "suggèrent": ("suggérer",),
    "suggère": ("suggérer",),
    "suggérera": ("suggérer",),
    "suggéreraient": ("suggérer",),
    "suggérerai": ("suggérer",),
    "suggérerais": ("suggérer",),
    "suggérerait": ("suggérer",),
    "suggéreras": ("suggérer",),
    "suggérèrent": ("suggérer",),
    "suggérerez": ("suggérer",),
    "suggéreriez": ("suggérer",),
    "suggérerions": ("suggérer",),
    "suggérerons": ("suggérer",),
    "suggéreront": ("suggérer",),
    "suggérés": ("suggérer",),
    "suggères": ("suggérer",),
    "suggérez": ("suggérer",),
    "suggériez": ("suggérer",),
    "suggérions": ("suggérer",),
    "suggérons": ("suggérer",),
    "suit": ("suivre",),
    "suivaient": ("suivre",),
    "suivais": ("suivre",),
    "suivait": ("suivre",),
    "suivant": ("suivre",),
    "suivent": ("suivre",),
    "suive": ("suivre",),
    "suives": ("suivre",),
    "suivez": ("suivre",),
    "suivie": ("suivre",),
    "suivies": ("suivre",),
    "suiviez": ("suivre",),
    "suivi": ("suivre",),
    "suivîmes": ("suivre",),
    "suivions": ("suivre",),
    "suivirent": ("suivre",),
    "suivis": ("suivre",),
    "suivissent": ("suivre",),
    "suivisses": ("suivre",),
    "suivisse": ("suivre",),
    "suivissiez": ("suivre",),
    "suivissions": ("suivre",),
    "suivîtes": ("suivre",),
    "suivit": ("suivre",),
    "suivît": ("suivre",),
    "suivons": ("suivre",),
    "suivra": ("suivre",),
    "suivraient": ("suivre",),
    "suivrai": ("suivre",),
    "suivrais": ("suivre",),
    "suivrait": ("suivre",),
    "suivras": ("suivre",),
    "suivrez": ("suivre",),
    "suivriez": ("suivre",),
    "suivrions": ("suivre",),
    "suivrons": ("suivre",),
    "suivront": ("suivre",),
    "superfinie": ("superfinir",),
    "superfinies": ("superfinir",),
    "superfini": ("superfinir",),
    "superfinîmes": ("superfinir",),
    "superfinira": ("superfinir",),
    "superfiniraient": ("superfinir",),
    "superfinirai": ("superfinir",),
    "superfinirais": ("superfinir",),
    "superfinirait": ("superfinir",),
    "superfiniras": ("superfinir",),
    "superfinirent": ("superfinir",),
    "superfinirez": ("superfinir",),
    "superfiniriez": ("superfinir",),
    "superfinirions": ("superfinir",),
    "superfinirons": ("superfinir",),
    "superfiniront": ("superfinir",),
    "superfinis": ("superfinir",),
    "superfinissaient": ("superfinir",),
    "superfinissais": ("superfinir",),
    "superfinissait": ("superfinir",),
    "superfinissant": ("superfinir",),
    "superfinissent": ("superfinir",),
    "superfinisse": ("superfinir",),
    "superfinisses": ("superfinir",),
    "superfinissez": ("superfinir",),
    "superfinissiez": ("superfinir",),
    "superfinissions": ("superfinir",),
    "superfinissons": ("superfinir",),
    "superfinîtes": ("superfinir",),
    "superfinit": ("superfinir",),
    "superfinît": ("superfinir",),
    "suppléaient": ("suppléer",),
    "suppléai": ("suppléer",),
    "suppléais": ("suppléer",),
    "suppléait": ("suppléer",),
    "suppléa": ("suppléer",),
    "suppléâmes": ("suppléer",),
    "suppléant": ("suppléer",),
    "suppléas": ("suppléer",),
    "suppléassent": ("suppléer",),
    "suppléasses": ("suppléer",),
    "suppléasse": ("suppléer",),
    "suppléassiez": ("suppléer",),
    "suppléassions": ("suppléer",),
    "suppléâtes": ("suppléer",),
    "suppléât": ("suppléer",),
    "suppléée": ("suppléer",),
    "suppléées": ("suppléer",),
    "suppléé": ("suppléer",),
    "suppléent": ("suppléer",),
    "supplée": ("suppléer",),
    "suppléera": ("suppléer",),
    "suppléeraient": ("suppléer",),
    "suppléerai": ("suppléer",),
    "suppléerais": ("suppléer",),
    "suppléerait": ("suppléer",),
    "suppléeras": ("suppléer",),
    "suppléèrent": ("suppléer",),
    "suppléerez": ("suppléer",),
    "suppléeriez": ("suppléer",),
    "suppléerions": ("suppléer",),
    "suppléerons": ("suppléer",),
    "suppléeront": ("suppléer",),
    "suppléés": ("suppléer",),
    "supplées": ("suppléer",),
    "suppléez": ("suppléer",),
    "suppléiez": ("suppléer",),
    "suppléions": ("suppléer",),
    "suppléons": ("suppléer",),
    "suppliciaient": ("supplicier",),
    "suppliciai": ("supplicier",),
    "suppliciais": ("supplicier",),
    "suppliciait": ("supplicier",),
    "supplicia": ("supplicier",),
    "suppliciâmes": ("supplicier",),
    "suppliciant": ("supplicier",),
    "supplicias": ("supplicier",),
    "suppliciassent": ("supplicier",),
    "suppliciasses": ("supplicier",),
    "suppliciasse": ("supplicier",),
    "suppliciassiez": ("supplicier",),
    "suppliciassions": ("supplicier",),
    "suppliciâtes": ("supplicier",),
    "suppliciât": ("supplicier",),
    "suppliciée": ("supplicier",),
    "suppliciées": ("supplicier",),
    "supplicié": ("supplicier",),
    "supplicient": ("supplicier",),
    "supplicie": ("supplicier",),
    "suppliciera": ("supplicier",),
    "supplicieraient": ("supplicier",),
    "supplicierai": ("supplicier",),
    "supplicierais": ("supplicier",),
    "supplicierait": ("supplicier",),
    "supplicieras": ("supplicier",),
    "supplicièrent": ("supplicier",),
    "supplicierez": ("supplicier",),
    "supplicieriez": ("supplicier",),
    "supplicierions": ("supplicier",),
    "supplicierons": ("supplicier",),
    "supplicieront": ("supplicier",),
    "suppliciés": ("supplicier",),
    "supplicies": ("supplicier",),
    "suppliciez": ("supplicier",),
    "suppliciiez": ("supplicier",),
    "suppliciions": ("supplicier",),
    "supplicions": ("supplicier",),
    "suppliaient": ("supplier",),
    "suppliai": ("supplier",),
    "suppliais": ("supplier",),
    "suppliait": ("supplier",),
    "supplia": ("supplier",),
    "suppliâmes": ("supplier",),
    "suppliant": ("supplier",),
    "supplias": ("supplier",),
    "suppliassent": ("supplier",),
    "suppliasses": ("supplier",),
    "suppliasse": ("supplier",),
    "suppliassiez": ("supplier",),
    "suppliassions": ("supplier",),
    "suppliâtes": ("supplier",),
    "suppliât": ("supplier",),
    "suppliée": ("supplier",),
    "suppliées": ("supplier",),
    "supplié": ("supplier",),
    "supplient": ("supplier",),
    "supplie": ("supplier",),
    "suppliera": ("supplier",),
    "supplieraient": ("supplier",),
    "supplierai": ("supplier",),
    "supplierais": ("supplier",),
    "supplierait": ("supplier",),
    "supplieras": ("supplier",),
    "supplièrent": ("supplier",),
    "supplierez": ("supplier",),
    "supplieriez": ("supplier",),
    "supplierions": ("supplier",),
    "supplierons": ("supplier",),
    "supplieront": ("supplier",),
    "suppliés": ("supplier",),
    "supplies": ("supplier",),
    "suppliez": ("supplier",),
    "suppliiez": ("supplier",),
    "suppliions": ("supplier",),
    "supplions": ("supplier",),
    "surachetaient": ("suracheter",),
    "surachetai": ("suracheter",),
    "surachetais": ("suracheter",),
    "surachetait": ("suracheter",),
    "suracheta": ("suracheter",),
    "surachetâmes": ("suracheter",),
    "surachetant": ("suracheter",),
    "surachetas": ("suracheter",),
    "surachetassent": ("suracheter",),
    "surachetasses": ("suracheter",),
    "surachetasse": ("suracheter",),
    "surachetassiez": ("suracheter",),
    "surachetassions": ("suracheter",),
    "surachetâtes": ("suracheter",),
    "surachetât": ("suracheter",),
    "surachetée": ("suracheter",),
    "surachetées": ("suracheter",),
    "suracheté": ("suracheter",),
    "surachètent": ("suracheter",),
    "surachète": ("suracheter",),
    "surachètera": ("suracheter",),
    "surachèteraient": ("suracheter",),
    "surachèterai": ("suracheter",),
    "surachèterais": ("suracheter",),
    "surachèterait": ("suracheter",),
    "surachèteras": ("suracheter",),
    "surachetèrent": ("suracheter",),
    "surachèterez": ("suracheter",),
    "surachèteriez": ("suracheter",),
    "surachèterions": ("suracheter",),
    "surachèterons": ("suracheter",),
    "surachèteront": ("suracheter",),
    "surachetés": ("suracheter",),
    "surachètes": ("suracheter",),
    "surachetez": ("suracheter",),
    "surachetiez": ("suracheter",),
    "surachetions": ("suracheter",),
    "surachetons": ("suracheter",),
    "surchargeaient": ("surcharger",),
    "surchargeai": ("surcharger",),
    "surchargeais": ("surcharger",),
    "surchargeait": ("surcharger",),
    "surchargea": ("surcharger",),
    "surchargeâmes": ("surcharger",),
    "surchargeant": ("surcharger",),
    "surchargeas": ("surcharger",),
    "surchargeassent": ("surcharger",),
    "surchargeasses": ("surcharger",),
    "surchargeasse": ("surcharger",),
    "surchargeassiez": ("surcharger",),
    "surchargeassions": ("surcharger",),
    "surchargeâtes": ("surcharger",),
    "surchargeât": ("surcharger",),
    "surchargée": ("surcharger",),
    "surchargées": ("surcharger",),
    "surchargé": ("surcharger",),
    "surchargent": ("surcharger",),
    "surchargeons": ("surcharger",),
    "surcharge": ("surcharger",),
    "surchargera": ("surcharger",),
    "surchargeraient": ("surcharger",),
    "surchargerai": ("surcharger",),
    "surchargerais": ("surcharger",),
    "surchargerait": ("surcharger",),
    "surchargeras": ("surcharger",),
    "surchargèrent": ("surcharger",),
    "surchargerez": ("surcharger",),
    "surchargeriez": ("surcharger",),
    "surchargerions": ("surcharger",),
    "surchargerons": ("surcharger",),
    "surchargeront": ("surcharger",),
    "surchargés": ("surcharger",),
    "surcharges": ("surcharger",),
    "surchargez": ("surcharger",),
    "surchargiez": ("surcharger",),
    "surchargions": ("surcharger",),
    "surclassaient": ("surclasser",),
    "surclassai": ("surclasser",),
    "surclassais": ("surclasser",),
    "surclassait": ("surclasser",),
    "surclassa": ("surclasser",),
    "surclassâmes": ("surclasser",),
    "surclassant": ("surclasser",),
    "surclassas": ("surclasser",),
    "surclassassent": ("surclasser",),
    "surclassasses": ("surclasser",),
    "surclassasse": ("surclasser",),
    "surclassassiez": ("surclasser",),
    "surclassassions": ("surclasser",),
    "surclassâtes": ("surclasser",),
    "surclassât": ("surclasser",),
    "surclassée": ("surclasser",),
    "surclassées": ("surclasser",),
    "surclassé": ("surclasser",),
    "surclassent": ("surclasser",),
    "surclasse": ("surclasser",),
    "surclassera": ("surclasser",),
    "surclasseraient": ("surclasser",),
    "surclasserai": ("surclasser",),
    "surclasserais": ("surclasser",),
    "surclasserait": ("surclasser",),
    "surclasseras": ("surclasser",),
    "surclassèrent": ("surclasser",),
    "surclasserez": ("surclasser",),
    "surclasseriez": ("surclasser",),
    "surclasserions": ("surclasser",),
    "surclasserons": ("surclasser",),
    "surclasseront": ("surclasser",),
    "surclassés": ("surclasser",),
    "surclasses": ("surclasser",),
    "surclassez": ("surclasser",),
    "surclassiez": ("surclasser",),
    "surclassions": ("surclasser",),
    "surclassons": ("surclasser",),
    "surcrois": ("surcroître",),
    "surcroissaient": ("surcroître",),
    "surcroissais": ("surcroître",),
    "surcroissait": ("surcroître",),
    "surcroissant": ("surcroître",),
    "surcroissent": ("surcroître",),
    "surcroisse": ("surcroître",),
    "surcroisses": ("surcroître",),
    "surcroissez": ("surcroître",),
    "surcroissiez": ("surcroître",),
    "surcroissions": ("surcroître",),
    "surcroissons": ("surcroître",),
    "surcroît": ("surcroître",),
    "surcroîtra": ("surcroître",),
    "surcroîtraient": ("surcroître",),
    "surcroîtrai": ("surcroître",),
    "surcroîtrais": ("surcroître",),
    "surcroîtrait": ("surcroître",),
    "surcroîtras": ("surcroître",),
    "surcroîtrez": ("surcroître",),
    "surcroîtriez": ("surcroître",),
    "surcroîtrions": ("surcroître",),
    "surcroîtrons": ("surcroître",),
    "surcroîtront": ("surcroître",),
    "surcrue": ("surcroître",),
    "surcrues": ("surcroître",),
    "surcrû": ("surcroître",),
    "surcrûmes": ("surcroître",),
    "surcrurent": ("surcroître",),
    "surcrus": ("surcroître",),
    "surcrussent": ("surcroître",),
    "surcrusses": ("surcroître",),
    "surcrusse": ("surcroître",),
    "surcrussiez": ("surcroître",),
    "surcrussions": ("surcroître",),
    "surcrûtes": ("surcroître",),
    "surcrut": ("surcroître",),
    "surcrût": ("surcroître",),
    "surcuira": ("surcuire",),
    "surcuiraient": ("surcuire",),
    "surcuirai": ("surcuire",),
    "surcuirais": ("surcuire",),
    "surcuirait": ("surcuire",),
    "surcuiras": ("surcuire",),
    "surcuirez": ("surcuire",),
    "surcuiriez": ("surcuire",),
    "surcuirions": ("surcuire",),
    "surcuirons": ("surcuire",),
    "surcuiront": ("surcuire",),
    "surcuisaient": ("surcuire",),
    "surcuisais": ("surcuire",),
    "surcuisait": ("surcuire",),
    "surcuisant": ("surcuire",),
    "surcuisent": ("surcuire",),
    "surcuise": ("surcuire",),
    "surcuises": ("surcuire",),
    "surcuisez": ("surcuire",),
    "surcuisiez": ("surcuire",),
    "surcuisîmes": ("surcuire",),
    "surcuisions": ("surcuire",),
    "surcuisirent": ("surcuire",),
    "surcuisis": ("surcuire",),
    "surcuisissent": ("surcuire",),
    "surcuisisses": ("surcuire",),
    "surcuisisse": ("surcuire",),
    "surcuisissiez": ("surcuire",),
    "surcuisissions": ("surcuire",),
    "surcuisîtes": ("surcuire",),
    "surcuisit": ("surcuire",),
    "surcuisît": ("surcuire",),
    "surcuisons": ("surcuire",),
    "surcuis": ("surcuire",),
    "surcuite": ("surcuire",),
    "surcuites": ("surcuire",),
    "surcuit": ("surcuire",),
    "surcuits": ("surcuire",),
    "surdirigeaient": ("surdiriger",),
    "surdirigeai": ("surdiriger",),
    "surdirigeais": ("surdiriger",),
    "surdirigeait": ("surdiriger",),
    "surdirigea": ("surdiriger",),
    "surdirigeâmes": ("surdiriger",),
    "surdirigeant": ("surdiriger",),
    "surdirigeas": ("surdiriger",),
    "surdirigeassent": ("surdiriger",),
    "surdirigeasses": ("surdiriger",),
    "surdirigeasse": ("surdiriger",),
    "surdirigeassiez": ("surdiriger",),
    "surdirigeassions": ("surdiriger",),
    "surdirigeâtes": ("surdiriger",),
    "surdirigeât": ("surdiriger",),
    "surdirigée": ("surdiriger",),
    "surdirigées": ("surdiriger",),
    "surdirigé": ("surdiriger",),
    "surdirigent": ("surdiriger",),
    "surdirigeons": ("surdiriger",),
    "surdirige": ("surdiriger",),
    "surdirigera": ("surdiriger",),
    "surdirigeraient": ("surdiriger",),
    "surdirigerai": ("surdiriger",),
    "surdirigerais": ("surdiriger",),
    "surdirigerait": ("surdiriger",),
    "surdirigeras": ("surdiriger",),
    "surdirigèrent": ("surdiriger",),
    "surdirigerez": ("surdiriger",),
    "surdirigeriez": ("surdiriger",),
    "surdirigerions": ("surdiriger",),
    "surdirigerons": ("surdiriger",),
    "surdirigeront": ("surdiriger",),
    "surdirigés": ("surdiriger",),
    "surdiriges": ("surdiriger",),
    "surdirigez": ("surdiriger",),
    "surdirigiez": ("surdiriger",),
    "surdirigions": ("surdiriger",),
    "surédifiaient": ("surédifier",),
    "surédifiai": ("surédifier",),
    "surédifiais": ("surédifier",),
    "surédifiait": ("surédifier",),
    "surédifia": ("surédifier",),
    "surédifiâmes": ("surédifier",),
    "surédifiant": ("surédifier",),
    "surédifias": ("surédifier",),
    "surédifiassent": ("surédifier",),
    "surédifiasses": ("surédifier",),
    "surédifiasse": ("surédifier",),
    "surédifiassiez": ("surédifier",),
    "surédifiassions": ("surédifier",),
    "surédifiâtes": ("surédifier",),
    "surédifiât": ("surédifier",),
    "surédifiée": ("surédifier",),
    "surédifiées": ("surédifier",),
    "surédifié": ("surédifier",),
    "surédifient": ("surédifier",),
    "surédifie": ("surédifier",),
    "surédifiera": ("surédifier",),
    "surédifieraient": ("surédifier",),
    "surédifierai": ("surédifier",),
    "surédifierais": ("surédifier",),
    "surédifierait": ("surédifier",),
    "surédifieras": ("surédifier",),
    "surédifièrent": ("surédifier",),
    "surédifierez": ("surédifier",),
    "surédifieriez": ("surédifier",),
    "surédifierions": ("surédifier",),
    "surédifierons": ("surédifier",),
    "surédifieront": ("surédifier",),
    "surédifiés": ("surédifier",),
    "surédifies": ("surédifier",),
    "surédifiez": ("surédifier",),
    "surédifiiez": ("surédifier",),
    "surédifiions": ("surédifier",),
    "surédifions": ("surédifier",),
    "surélevaient": ("surélever",),
    "surélevai": ("surélever",),
    "surélevais": ("surélever",),
    "surélevait": ("surélever",),
    "suréleva": ("surélever",),
    "surélevâmes": ("surélever",),
    "surélevant": ("surélever",),
    "surélevas": ("surélever",),
    "surélevassent": ("surélever",),
    "surélevasses": ("surélever",),
    "surélevasse": ("surélever",),
    "surélevassiez": ("surélever",),
    "surélevassions": ("surélever",),
    "surélevâtes": ("surélever",),
    "surélevât": ("surélever",),
    "surélevée": ("surélever",),
    "surélevées": ("surélever",),
    "surélevé": ("surélever",),
    "surélèvent": ("surélever",),
    "surélève": ("surélever",),
    "surélèvera": ("surélever",),
    "surélèveraient": ("surélever",),
    "surélèverai": ("surélever",),
    "surélèverais": ("surélever",),
    "surélèverait": ("surélever",),
    "surélèveras": ("surélever",),
    "surélevèrent": ("surélever",),
    "surélèverez": ("surélever",),
    "surélèveriez": ("surélever",),
    "surélèverions": ("surélever",),
    "surélèverons": ("surélever",),
    "surélèveront": ("surélever",),
    "surélevés": ("surélever",),
    "surélèves": ("surélever",),
    "surélevez": ("surélever",),
    "suréleviez": ("surélever",),
    "surélevions": ("surélever",),
    "surélevons": ("surélever",),
    "surenchérie": ("surenchérir",),
    "surenchéries": ("surenchérir",),
    "surenchéri": ("surenchérir",),
    "surenchérîmes": ("surenchérir",),
    "surenchérira": ("surenchérir",),
    "surenchériraient": ("surenchérir",),
    "surenchérirai": ("surenchérir",),
    "surenchérirais": ("surenchérir",),
    "surenchérirait": ("surenchérir",),
    "surenchériras": ("surenchérir",),
    "surenchérirent": ("surenchérir",),
    "surenchérirez": ("surenchérir",),
    "surenchéririez": ("surenchérir",),
    "surenchéririons": ("surenchérir",),
    "surenchérirons": ("surenchérir",),
    "surenchériront": ("surenchérir",),
    "surenchéris": ("surenchérir",),
    "surenchérissaient": ("surenchérir",),
    "surenchérissais": ("surenchérir",),
    "surenchérissait": ("surenchérir",),
    "surenchérissant": ("surenchérir",),
    "surenchérissent": ("surenchérir",),
    "surenchérisse": ("surenchérir",),
    "surenchérisses": ("surenchérir",),
    "surenchérissez": ("surenchérir",),
    "surenchérissiez": ("surenchérir",),
    "surenchérissions": ("surenchérir",),
    "surenchérissons": ("surenchérir",),
    "surenchérîtes": ("surenchérir",),
    "surenchérit": ("surenchérir",),
    "surenchérît": ("surenchérir",),
    "surfaçaient": ("surfacer",),
    "surfaçai": ("surfacer",),
    "surfaçais": ("surfacer",),
    "surfaçait": ("surfacer",),
    "surfaça": ("surfacer",),
    "surfaçâmes": ("surfacer",),
    "surfaçant": ("surfacer",),
    "surfaças": ("surfacer",),
    "surfaçassent": ("surfacer",),
    "surfaçasses": ("surfacer",),
    "surfaçasse": ("surfacer",),
    "surfaçassiez": ("surfacer",),
    "surfaçassions": ("surfacer",),
    "surfaçâtes": ("surfacer",),
    "surfaçât": ("surfacer",),
    "surfacée": ("surfacer",),
    "surfacées": ("surfacer",),
    "surfacé": ("surfacer",),
    "surfacent": ("surfacer",),
    "surface": ("surfacer",),
    "surfacera": ("surfacer",),
    "surfaceraient": ("surfacer",),
    "surfacerai": ("surfacer",),
    "surfacerais": ("surfacer",),
    "surfacerait": ("surfacer",),
    "surfaceras": ("surfacer",),
    "surfacèrent": ("surfacer",),
    "surfacerez": ("surfacer",),
    "surfaceriez": ("surfacer",),
    "surfacerions": ("surfacer",),
    "surfacerons": ("surfacer",),
    "surfaceront": ("surfacer",),
    "surfacés": ("surfacer",),
    "surfaces": ("surfacer",),
    "surfacez": ("surfacer",),
    "surfaciez": ("surfacer",),
    "surfacions": ("surfacer",),
    "surfaçons": ("surfacer",),
    "surfaisaient": ("surfaire",),
    "surfaisais": ("surfaire",),
    "surfaisait": ("surfaire",),
    "surfaisant": ("surfaire",),
    "surfaisiez": ("surfaire",),
    "surfaisions": ("surfaire",),
    "surfaisons": ("surfaire",),
    "surfais": ("surfaire",),
    "surfaite": ("surfaire",),
    "surfaites": ("surfaire",),
    "surfait": ("surfaire",),
    "surfaits": ("surfaire",),
    "surfassent": ("surfaire",),
    "surfasse": ("surfaire",),
    "surfasses": ("surfaire",),
    "surfassiez": ("surfaire",),
    "surfassions": ("surfaire",),
    "surfera": ("surfaire",),
    "surferaient": ("surfaire",),
    "surferai": ("surfaire",),
    "surferais": ("surfaire",),
    "surferait": ("surfaire",),
    "surferas": ("surfaire",),
    "surferez": ("surfaire",),
    "surferiez": ("surfaire",),
    "surferions": ("surfaire",),
    "surferons": ("surfaire",),
    "surferont": ("surfaire",),
    "surfîmes": ("surfaire",),
    "surfirent": ("surfaire",),
    "surfis": ("surfaire",),
    "surfissent": ("surfaire",),
    "surfisses": ("surfaire",),
    "surfisse": ("surfaire",),
    "surfissiez": ("surfaire",),
    "surfissions": ("surfaire",),
    "surfîtes": ("surfaire",),
    "surfit": ("surfaire",),
    "surfît": ("surfaire",),
    "surfont": ("surfaire",),
    "surfinançaient": ("surfinancer",),
    "surfinançai": ("surfinancer",),
    "surfinançais": ("surfinancer",),
    "surfinançait": ("surfinancer",),
    "surfinança": ("surfinancer",),
    "surfinançâmes": ("surfinancer",),
    "surfinançant": ("surfinancer",),
    "surfinanças": ("surfinancer",),
    "surfinançassent": ("surfinancer",),
    "surfinançasses": ("surfinancer",),
    "surfinançasse": ("surfinancer",),
    "surfinançassiez": ("surfinancer",),
    "surfinançassions": ("surfinancer",),
    "surfinançâtes": ("surfinancer",),
    "surfinançât": ("surfinancer",),
    "surfinancée": ("surfinancer",),
    "surfinancées": ("surfinancer",),
    "surfinancé": ("surfinancer",),
    "surfinancent": ("surfinancer",),
    "surfinance": ("surfinancer",),
    "surfinancera": ("surfinancer",),
    "surfinanceraient": ("surfinancer",),
    "surfinancerai": ("surfinancer",),
    "surfinancerais": ("surfinancer",),
    "surfinancerait": ("surfinancer",),
    "surfinanceras": ("surfinancer",),
    "surfinancèrent": ("surfinancer",),
    "surfinancerez": ("surfinancer",),
    "surfinanceriez": ("surfinancer",),
    "surfinancerions": ("surfinancer",),
    "surfinancerons": ("surfinancer",),
    "surfinanceront": ("surfinancer",),
    "surfinancés": ("surfinancer",),
    "surfinances": ("surfinancer",),
    "surfinancez": ("surfinancer",),
    "surfinanciez": ("surfinancer",),
    "surfinancions": ("surfinancer",),
    "surfinançons": ("surfinancer",),
    "surfondaient": ("surfondre",),
    "surfondais": ("surfondre",),
    "surfondait": ("surfondre",),
    "surfondant": ("surfondre",),
    "surfondent": ("surfondre",),
    "surfonde": ("surfondre",),
    "surfondes": ("surfondre",),
    "surfondez": ("surfondre",),
    "surfondiez": ("surfondre",),
    "surfondîmes": ("surfondre",),
    "surfondions": ("surfondre",),
    "surfondirent": ("surfondre",),
    "surfondis": ("surfondre",),
    "surfondissent": ("surfondre",),
    "surfondisses": ("surfondre",),
    "surfondisse": ("surfondre",),
    "surfondissiez": ("surfondre",),
    "surfondissions": ("surfondre",),
    "surfondîtes": ("surfondre",),
    "surfondit": ("surfondre",),
    "surfondît": ("surfondre",),
    "surfondons": ("surfondre",),
    "surfond": ("surfondre",),
    "surfondra": ("surfondre",),
    "surfondraient": ("surfondre",),
    "surfondrai": ("surfondre",),
    "surfondrais": ("surfondre",),
    "surfondrait": ("surfondre",),
    "surfondras": ("surfondre",),
    "surfondrez": ("surfondre",),
    "surfondriez": ("surfondre",),
    "surfondrions": ("surfondre",),
    "surfondrons": ("surfondre",),
    "surfondront": ("surfondre",),
    "surfonds": ("surfondre",),
    "surfondue": ("surfondre",),
    "surfondues": ("surfondre",),
    "surfondu": ("surfondre",),
    "surfondus": ("surfondre",),
    "surgelaient": ("surgeler",),
    "surgelai": ("surgeler",),
    "surgelais": ("surgeler",),
    "surgelait": ("surgeler",),
    "surgela": ("surgeler",),
    "surgelâmes": ("surgeler",),
    "surgelant": ("surgeler",),
    "surgelas": ("surgeler",),
    "surgelassent": ("surgeler",),
    "surgelasses": ("surgeler",),
    "surgelasse": ("surgeler",),
    "surgelassiez": ("surgeler",),
    "surgelassions": ("surgeler",),
    "surgelâtes": ("surgeler",),
    "surgelât": ("surgeler",),
    "surgelée": ("surgeler",),
    "surgelées": ("surgeler",),
    "surgelé": ("surgeler",),
    "surgèlent": ("surgeler",),
    "surgèle": ("surgeler",),
    "surgèlera": ("surgeler",),
    "surgèleraient": ("surgeler",),
    "surgèlerai": ("surgeler",),
    "surgèlerais": ("surgeler",),
    "surgèlerait": ("surgeler",),
    "surgèleras": ("surgeler",),
    "surgelèrent": ("surgeler",),
    "surgèlerez": ("surgeler",),
    "surgèleriez": ("surgeler",),
    "surgèlerions": ("surgeler",),
    "surgèlerons": ("surgeler",),
    "surgèleront": ("surgeler",),
    "surgelés": ("surgeler",),
    "surgèles": ("surgeler",),
    "surgelez": ("surgeler",),
    "surgeliez": ("surgeler",),
    "surgelions": ("surgeler",),
    "surgelons": ("surgeler",),
    "surgie": ("surgir",),
    "surgies": ("surgir",),
    "surgi": ("surgir",),
    "surgîmes": ("surgir",),
    "surgira": ("surgir",),
    "surgiraient": ("surgir",),
    "surgirai": ("surgir",),
    "surgirais": ("surgir",),
    "surgirait": ("surgir",),
    "surgiras": ("surgir",),
    "surgirent": ("surgir",),
    "surgirez": ("surgir",),
    "surgiriez": ("surgir",),
    "surgirions": ("surgir",),
    "surgirons": ("surgir",),
    "surgiront": ("surgir",),
    "surgis": ("surgir",),
    "surgissaient": ("surgir",),
    "surgissais": ("surgir",),
    "surgissait": ("surgir",),
    "surgissant": ("surgir",),
    "surgissent": ("surgir",),
    "surgisse": ("surgir",),
    "surgisses": ("surgir",),
    "surgissez": ("surgir",),
    "surgissiez": ("surgir",),
    "surgissions": ("surgir",),
    "surgissons": ("surgir",),
    "surgîtes": ("surgir",),
    "surgit": ("surgir",),
    "surgît": ("surgir",),
    "surglaçaient": ("surglacer",),
    "surglaçai": ("surglacer",),
    "surglaçais": ("surglacer",),
    "surglaçait": ("surglacer",),
    "surglaça": ("surglacer",),
    "surglaçâmes": ("surglacer",),
    "surglaçant": ("surglacer",),
    "surglaças": ("surglacer",),
    "surglaçassent": ("surglacer",),
    "surglaçasses": ("surglacer",),
    "surglaçasse": ("surglacer",),
    "surglaçassiez": ("surglacer",),
    "surglaçassions": ("surglacer",),
    "surglaçâtes": ("surglacer",),
    "surglaçât": ("surglacer",),
    "surglacée": ("surglacer",),
    "surglacées": ("surglacer",),
    "surglacé": ("surglacer",),
    "surglacent": ("surglacer",),
    "surglace": ("surglacer",),
    "surglacera": ("surglacer",),
    "surglaceraient": ("surglacer",),
    "surglacerai": ("surglacer",),
    "surglacerais": ("surglacer",),
    "surglacerait": ("surglacer",),
    "surglaceras": ("surglacer",),
    "surglacèrent": ("surglacer",),
    "surglacerez": ("surglacer",),
    "surglaceriez": ("surglacer",),
    "surglacerions": ("surglacer",),
    "surglacerons": ("surglacer",),
    "surglaceront": ("surglacer",),
    "surglacés": ("surglacer",),
    "surglaces": ("surglacer",),
    "surglacez": ("surglacer",),
    "surglaciez": ("surglacer",),
    "surglacions": ("surglacer",),
    "surglaçons": ("surglacer",),
    "surinvestie": ("surinvestir",),
    "surinvesties": ("surinvestir",),
    "surinvesti": ("surinvestir",),
    "surinvestîmes": ("surinvestir",),
    "surinvestira": ("surinvestir",),
    "surinvestiraient": ("surinvestir",),
    "surinvestirai": ("surinvestir",),
    "surinvestirais": ("surinvestir",),
    "surinvestirait": ("surinvestir",),
    "surinvestiras": ("surinvestir",),
    "surinvestirent": ("surinvestir",),
    "surinvestirez": ("surinvestir",),
    "surinvestiriez": ("surinvestir",),
    "surinvestirions": ("surinvestir",),
    "surinvestirons": ("surinvestir",),
    "surinvestiront": ("surinvestir",),
    "surinvestis": ("surinvestir",),
    "surinvestissaient": ("surinvestir",),
    "surinvestissais": ("surinvestir",),
    "surinvestissait": ("surinvestir",),
    "surinvestissant": ("surinvestir",),
    "surinvestissent": ("surinvestir",),
    "surinvestisse": ("surinvestir",),
    "surinvestisses": ("surinvestir",),
    "surinvestissez": ("surinvestir",),
    "surinvestissiez": ("surinvestir",),
    "surinvestissions": ("surinvestir",),
    "surinvestissons": ("surinvestir",),
    "surinvestîtes": ("surinvestir",),
    "surinvestit": ("surinvestir",),
    "surinvestît": ("surinvestir",),
    "surie": ("surir",),
    "suries": ("surir",),
    "suri": ("surir",),
    "surîmes": ("surir",),
    "surira": ("surir",),
    "suriraient": ("surir",),
    "surirai": ("surir",),
    "surirais": ("surir",),
    "surirait": ("surir",),
    "suriras": ("surir",),
    "surirent": ("surir",),
    "surirez": ("surir",),
    "suririez": ("surir",),
    "suririons": ("surir",),
    "surirons": ("surir",),
    "suriront": ("surir",),
    "suris": ("surir",),
    "surissaient": ("surir",),
    "surissais": ("surir",),
    "surissait": ("surir",),
    "surissant": ("surir",),
    "surissent": ("surir",),
    "surisse": ("surir",),
    "surisses": ("surir",),
    "surissez": ("surir",),
    "surissiez": ("surir",),
    "surissions": ("surir",),
    "surissons": ("surir",),
    "surîtes": ("surir",),
    "surit": ("surir",),
    "surît": ("surir",),
    "surjetaient": ("surjeter",),
    "surjetai": ("surjeter",),
    "surjetais": ("surjeter",),
    "surjetait": ("surjeter",),
    "surjeta": ("surjeter",),
    "surjetâmes": ("surjeter",),
    "surjetant": ("surjeter",),
    "surjetas": ("surjeter",),
    "surjetassent": ("surjeter",),
    "surjetasses": ("surjeter",),
    "surjetasse": ("surjeter",),
    "surjetassiez": ("surjeter",),
    "surjetassions": ("surjeter",),
    "surjetâtes": ("surjeter",),
    "surjetât": ("surjeter",),
    "surjetée": ("surjeter",),
    "surjetées": ("surjeter",),
    "surjeté": ("surjeter",),
    "surjetèrent": ("surjeter",),
    "surjetés": ("surjeter",),
    "surjetez": ("surjeter",),
    "surjetiez": ("surjeter",),
    "surjetions": ("surjeter",),
    "surjetons": ("surjeter",),
    "surjettent": ("surjeter",),
    "surjette": ("surjeter",),
    "surjettera": ("surjeter",),
    "surjetteraient": ("surjeter",),
    "surjetterai": ("surjeter",),
    "surjetterais": ("surjeter",),
    "surjetterait": ("surjeter",),
    "surjetteras": ("surjeter",),
    "surjetterez": ("surjeter",),
    "surjetteriez": ("surjeter",),
    "surjetterions": ("surjeter",),
    "surjetterons": ("surjeter",),
    "surjetteront": ("surjeter",),
    "surjettes": ("surjeter",),
    "surliaient": ("surlier",),
    "surliai": ("surlier",),
    "surliais": ("surlier",),
    "surliait": ("surlier",),
    "surlia": ("surlier",),
    "surliâmes": ("surlier",),
    "surliant": ("surlier",),
    "surlias": ("surlier",),
    "surliassent": ("surlier",),
    "surliasses": ("surlier",),
    "surliasse": ("surlier",),
    "surliassiez": ("surlier",),
    "surliassions": ("surlier",),
    "surliâtes": ("surlier",),
    "surliât": ("surlier",),
    "surliée": ("surlier",),
    "surliées": ("surlier",),
    "surlié": ("surlier",),
    "surlient": ("surlier",),
    "surlie": ("surlier",),
    "surliera": ("surlier",),
    "surlieraient": ("surlier",),
    "surlierai": ("surlier",),
    "surlierais": ("surlier",),
    "surlierait": ("surlier",),
    "surlieras": ("surlier",),
    "surlièrent": ("surlier",),
    "surlierez": ("surlier",),
    "surlieriez": ("surlier",),
    "surlierions": ("surlier",),
    "surlierons": ("surlier",),
    "surlieront": ("surlier",),
    "surliés": ("surlier",),
    "surlies": ("surlier",),
    "surliez": ("surlier",),
    "surliiez": ("surlier",),
    "surliions": ("surlier",),
    "surlions": ("surlier",),
    "surmenaient": ("surmener",),
    "surmenai": ("surmener",),
    "surmenais": ("surmener",),
    "surmenait": ("surmener",),
    "surmena": ("surmener",),
    "surmenâmes": ("surmener",),
    "surmenant": ("surmener",),
    "surmenas": ("surmener",),
    "surmenassent": ("surmener",),
    "surmenasses": ("surmener",),
    "surmenasse": ("surmener",),
    "surmenassiez": ("surmener",),
    "surmenassions": ("surmener",),
    "surmenâtes": ("surmener",),
    "surmenât": ("surmener",),
    "surmenée": ("surmener",),
    "surmenées": ("surmener",),
    "surmené": ("surmener",),
    "surmènent": ("surmener",),
    "surmène": ("surmener",),
    "surmènera": ("surmener",),
    "surmèneraient": ("surmener",),
    "surmènerai": ("surmener",),
    "surmènerais": ("surmener",),
    "surmènerait": ("surmener",),
    "surmèneras": ("surmener",),
    "surmenèrent": ("surmener",),
    "surmènerez": ("surmener",),
    "surmèneriez": ("surmener",),
    "surmènerions": ("surmener",),
    "surmènerons": ("surmener",),
    "surmèneront": ("surmener",),
    "surmenés": ("surmener",),
    "surmènes": ("surmener",),
    "surmenez": ("surmener",),
    "surmeniez": ("surmener",),
    "surmenions": ("surmener",),
    "surmenons": ("surmener",),
    "surmultipliaient": ("surmultiplier",),
    "surmultipliai": ("surmultiplier",),
    "surmultipliais": ("surmultiplier",),
    "surmultipliait": ("surmultiplier",),
    "surmultiplia": ("surmultiplier",),
    "surmultipliâmes": ("surmultiplier",),
    "surmultipliant": ("surmultiplier",),
    "surmultiplias": ("surmultiplier",),
    "surmultipliassent": ("surmultiplier",),
    "surmultipliasses": ("surmultiplier",),
    "surmultipliasse": ("surmultiplier",),
    "surmultipliassiez": ("surmultiplier",),
    "surmultipliassions": ("surmultiplier",),
    "surmultipliâtes": ("surmultiplier",),
    "surmultipliât": ("surmultiplier",),
    "surmultipliée": ("surmultiplier",),
    "surmultipliées": ("surmultiplier",),
    "surmultiplié": ("surmultiplier",),
    "surmultiplient": ("surmultiplier",),
    "surmultiplie": ("surmultiplier",),
    "surmultipliera": ("surmultiplier",),
    "surmultiplieraient": ("surmultiplier",),
    "surmultiplierai": ("surmultiplier",),
    "surmultiplierais": ("surmultiplier",),
    "surmultiplierait": ("surmultiplier",),
    "surmultiplieras": ("surmultiplier",),
    "surmultiplièrent": ("surmultiplier",),
    "surmultiplierez": ("surmultiplier",),
    "surmultiplieriez": ("surmultiplier",),
    "surmultiplierions": ("surmultiplier",),
    "surmultiplierons": ("surmultiplier",),
    "surmultiplieront": ("surmultiplier",),
    "surmultipliés": ("surmultiplier",),
    "surmultiplies": ("surmultiplier",),
    "surmultipliez": ("surmultiplier",),
    "surmultipliiez": ("surmultiplier",),
    "surmultipliions": ("surmultiplier",),
    "surmultiplions": ("surmultiplier",),
    "surnageaient": ("surnager",),
    "surnageai": ("surnager",),
    "surnageais": ("surnager",),
    "surnageait": ("surnager",),
    "surnagea": ("surnager",),
    "surnageâmes": ("surnager",),
    "surnageant": ("surnager",),
    "surnageas": ("surnager",),
    "surnageassent": ("surnager",),
    "surnageasses": ("surnager",),
    "surnageasse": ("surnager",),
    "surnageassiez": ("surnager",),
    "surnageassions": ("surnager",),
    "surnageâtes": ("surnager",),
    "surnageât": ("surnager",),
    "surnagé": ("surnager",),
    "surnagent": ("surnager",),
    "surnageons": ("surnager",),
    "surnage": ("surnager",),
    "surnagera": ("surnager",),
    "surnageraient": ("surnager",),
    "surnagerai": ("surnager",),
    "surnagerais": ("surnager",),
    "surnagerait": ("surnager",),
    "surnageras": ("surnager",),
    "surnagèrent": ("surnager",),
    "surnagerez": ("surnager",),
    "surnageriez": ("surnager",),
    "surnagerions": ("surnager",),
    "surnagerons": ("surnager",),
    "surnageront": ("surnager",),
    "surnages": ("surnager",),
    "surnagez": ("surnager",),
    "surnagiez": ("surnager",),
    "surnagions": ("surnager",),
    "surnourrie": ("surnourrir",),
    "surnourries": ("surnourrir",),
    "surnourri": ("surnourrir",),
    "surnourrîmes": ("surnourrir",),
    "surnourrira": ("surnourrir",),
    "surnourriraient": ("surnourrir",),
    "surnourrirai": ("surnourrir",),
    "surnourrirais": ("surnourrir",),
    "surnourrirait": ("surnourrir",),
    "surnourriras": ("surnourrir",),
    "surnourrirent": ("surnourrir",),
    "surnourrirez": ("surnourrir",),
    "surnourririez": ("surnourrir",),
    "surnourririons": ("surnourrir",),
    "surnourrirons": ("surnourrir",),
    "surnourriront": ("surnourrir",),
    "surnourris": ("surnourrir",),
    "surnourrissaient": ("surnourrir",),
    "surnourrissais": ("surnourrir",),
    "surnourrissait": ("surnourrir",),
    "surnourrissant": ("surnourrir",),
    "surnourrissent": ("surnourrir",),
    "surnourrisse": ("surnourrir",),
    "surnourrisses": ("surnourrir",),
    "surnourrissez": ("surnourrir",),
    "surnourrissiez": ("surnourrir",),
    "surnourrissions": ("surnourrir",),
    "surnourrissons": ("surnourrir",),
    "surnourrîtes": ("surnourrir",),
    "surnourrit": ("surnourrir",),
    "surnourrît": ("surnourrir",),
    "surofferte": ("suroffrir",),
    "suroffertes": ("suroffrir",),
    "suroffert": ("suroffrir",),
    "surofferts": ("suroffrir",),
    "suroffraient": ("suroffrir",),
    "suroffrais": ("suroffrir",),
    "suroffrait": ("suroffrir",),
    "suroffrant": ("suroffrir",),
    "suroffrent": ("suroffrir",),
    "suroffre": ("suroffrir",),
    "suroffres": ("suroffrir",),
    "suroffrez": ("suroffrir",),
    "suroffriez": ("suroffrir",),
    "suroffrîmes": ("suroffrir",),
    "suroffrions": ("suroffrir",),
    "suroffrira": ("suroffrir",),
    "suroffriraient": ("suroffrir",),
    "suroffrirai": ("suroffrir",),
    "suroffrirais": ("suroffrir",),
    "suroffrirait": ("suroffrir",),
    "suroffriras": ("suroffrir",),
    "suroffrirent": ("suroffrir",),
    "suroffrirez": ("suroffrir",),
    "suroffririez": ("suroffrir",),
    "suroffririons": ("suroffrir",),
    "suroffrirons": ("suroffrir",),
    "suroffriront": ("suroffrir",),
    "suroffris": ("suroffrir",),
    "suroffrissent": ("suroffrir",),
    "suroffrisses": ("suroffrir",),
    "suroffrisse": ("suroffrir",),
    "suroffrissiez": ("suroffrir",),
    "suroffrissions": ("suroffrir",),
    "suroffrîtes": ("suroffrir",),
    "suroffrit": ("suroffrir",),
    "suroffrît": ("suroffrir",),
    "suroffrons": ("suroffrir",),
    "suroxygénaient": ("suroxygéner",),
    "suroxygénai": ("suroxygéner",),
    "suroxygénais": ("suroxygéner",),
    "suroxygénait": ("suroxygéner",),
    "suroxygéna": ("suroxygéner",),
    "suroxygénâmes": ("suroxygéner",),
    "suroxygénant": ("suroxygéner",),
    "suroxygénas": ("suroxygéner",),
    "suroxygénassent": ("suroxygéner",),
    "suroxygénasses": ("suroxygéner",),
    "suroxygénasse": ("suroxygéner",),
    "suroxygénassiez": ("suroxygéner",),
    "suroxygénassions": ("suroxygéner",),
    "suroxygénâtes": ("suroxygéner",),
    "suroxygénât": ("suroxygéner",),
    "suroxygénée": ("suroxygéner",),
    "suroxygénées": ("suroxygéner",),
    "suroxygéné": ("suroxygéner",),
    "suroxygènent": ("suroxygéner",),
    "suroxygène": ("suroxygéner",),
    "suroxygénera": ("suroxygéner",),
    "suroxygéneraient": ("suroxygéner",),
    "suroxygénerai": ("suroxygéner",),
    "suroxygénerais": ("suroxygéner",),
    "suroxygénerait": ("suroxygéner",),
    "suroxygéneras": ("suroxygéner",),
    "suroxygénèrent": ("suroxygéner",),
    "suroxygénerez": ("suroxygéner",),
    "suroxygéneriez": ("suroxygéner",),
    "suroxygénerions": ("suroxygéner",),
    "suroxygénerons": ("suroxygéner",),
    "suroxygéneront": ("suroxygéner",),
    "suroxygénés": ("suroxygéner",),
    "suroxygènes": ("suroxygéner",),
    "suroxygénez": ("suroxygéner",),
    "suroxygéniez": ("suroxygéner",),
    "suroxygénions": ("suroxygéner",),
    "suroxygénons": ("suroxygéner",),
    "surpassaient": ("surpasser",),
    "surpassai": ("surpasser",),
    "surpassais": ("surpasser",),
    "surpassait": ("surpasser",),
    "surpassa": ("surpasser",),
    "surpassâmes": ("surpasser",),
    "surpassant": ("surpasser",),
    "surpassas": ("surpasser",),
    "surpassassent": ("surpasser",),
    "surpassasses": ("surpasser",),
    "surpassasse": ("surpasser",),
    "surpassassiez": ("surpasser",),
    "surpassassions": ("surpasser",),
    "surpassâtes": ("surpasser",),
    "surpassât": ("surpasser",),
    "surpassée": ("surpasser",),
    "surpassées": ("surpasser",),
    "surpassé": ("surpasser",),
    "surpassent": ("surpasser",),
    "surpasse": ("surpasser",),
    "surpassera": ("surpasser",),
    "surpasseraient": ("surpasser",),
    "surpasserai": ("surpasser",),
    "surpasserais": ("surpasser",),
    "surpasserait": ("surpasser",),
    "surpasseras": ("surpasser",),
    "surpassèrent": ("surpasser",),
    "surpasserez": ("surpasser",),
    "surpasseriez": ("surpasser",),
    "surpasserions": ("surpasser",),
    "surpasserons": ("surpasser",),
    "surpasseront": ("surpasser",),
    "surpassés": ("surpasser",),
    "surpasses": ("surpasser",),
    "surpassez": ("surpasser",),
    "surpassiez": ("surpasser",),
    "surpassions": ("surpasser",),
    "surpassons": ("surpasser",),
    "surpaient": ("surpayer",),
    "surpaie": ("surpayer",),
    "surpaiera": ("surpayer",),
    "surpaieraient": ("surpayer",),
    "surpaierai": ("surpayer",),
    "surpaierais": ("surpayer",),
    "surpaierait": ("surpayer",),
    "surpaieras": ("surpayer",),
    "surpaierez": ("surpayer",),
    "surpaieriez": ("surpayer",),
    "surpaierions": ("surpayer",),
    "surpaierons": ("surpayer",),
    "surpaieront": ("surpayer",),
    "surpaies": ("surpayer",),
    "surpayaient": ("surpayer",),
    "surpayai": ("surpayer",),
    "surpayais": ("surpayer",),
    "surpayait": ("surpayer",),
    "surpaya": ("surpayer",),
    "surpayâmes": ("surpayer",),
    "surpayant": ("surpayer",),
    "surpayas": ("surpayer",),
    "surpayassent": ("surpayer",),
    "surpayasses": ("surpayer",),
    "surpayasse": ("surpayer",),
    "surpayassiez": ("surpayer",),
    "surpayassions": ("surpayer",),
    "surpayâtes": ("surpayer",),
    "surpayât": ("surpayer",),
    "surpayée": ("surpayer",),
    "surpayées": ("surpayer",),
    "surpayé": ("surpayer",),
    "surpayent": ("surpayer",),
    "surpaye": ("surpayer",),
    "surpayera": ("surpayer",),
    "surpayeraient": ("surpayer",),
    "surpayerai": ("surpayer",),
    "surpayerais": ("surpayer",),
    "surpayerait": ("surpayer",),
    "surpayeras": ("surpayer",),
    "surpayèrent": ("surpayer",),
    "surpayerez": ("surpayer",),
    "surpayeriez": ("surpayer",),
    "surpayerions": ("surpayer",),
    "surpayerons": ("surpayer",),
    "surpayeront": ("surpayer",),
    "surpayés": ("surpayer",),
    "surpayes": ("surpayer",),
    "surpayez": ("surpayer",),
    "surpayiez": ("surpayer",),
    "surpayions": ("surpayer",),
    "surpayons": ("surpayer",),
    "surprenaient": ("surprendre",),
    "surprenais": ("surprendre",),
    "surprenait": ("surprendre",),
    "surprenant": ("surprendre",),
    "surprend": ("surprendre",),
    "surprendra": ("surprendre",),
    "surprendraient": ("surprendre",),
    "surprendrai": ("surprendre",),
    "surprendrais": ("surprendre",),
    "surprendrait": ("surprendre",),
    "surprendras": ("surprendre",),
    "surprendrez": ("surprendre",),
    "surprendriez": ("surprendre",),
    "surprendrions": ("surprendre",),
    "surprendrons": ("surprendre",),
    "surprendront": ("surprendre",),
    "surprends": ("surprendre",),
    "surprenez": ("surprendre",),
    "surpreniez": ("surprendre",),
    "surprenions": ("surprendre",),
    "surprennent": ("surprendre",),
    "surprenne": ("surprendre",),
    "surprennes": ("surprendre",),
    "surprenons": ("surprendre",),
    "surprîmes": ("surprendre",),
    "surprirent": ("surprendre",),
    "surprise": ("surprendre",),
    "surprises": ("surprendre",),
    "surpris": ("surprendre",),
    "surprissent": ("surprendre",),
    "surprisses": ("surprendre",),
    "surprisse": ("surprendre",),
    "surprissiez": ("surprendre",),
    "surprissions": ("surprendre",),
    "surprîtes": ("surprendre",),
    "surprit": ("surprendre",),
    "surprît": ("surprendre",),
    "surproduira": ("surproduire",),
    "surproduiraient": ("surproduire",),
    "surproduirai": ("surproduire",),
    "surproduirais": ("surproduire",),
    "surproduirait": ("surproduire",),
    "surproduiras": ("surproduire",),
    "surproduirez": ("surproduire",),
    "surproduiriez": ("surproduire",),
    "surproduirions": ("surproduire",),
    "surproduirons": ("surproduire",),
    "surproduiront": ("surproduire",),
    "surproduisaient": ("surproduire",),
    "surproduisais": ("surproduire",),
    "surproduisait": ("surproduire",),
    "surproduisant": ("surproduire",),
    "surproduisent": ("surproduire",),
    "surproduise": ("surproduire",),
    "surproduises": ("surproduire",),
    "surproduisez": ("surproduire",),
    "surproduisiez": ("surproduire",),
    "surproduisîmes": ("surproduire",),
    "surproduisions": ("surproduire",),
    "surproduisirent": ("surproduire",),
    "surproduisis": ("surproduire",),
    "surproduisissent": ("surproduire",),
    "surproduisisses": ("surproduire",),
    "surproduisisse": ("surproduire",),
    "surproduisissiez": ("surproduire",),
    "surproduisissions": ("surproduire",),
    "surproduisîtes": ("surproduire",),
    "surproduisit": ("surproduire",),
    "surproduisît": ("surproduire",),
    "surproduisons": ("surproduire",),
    "surproduis": ("surproduire",),
    "surproduite": ("surproduire",),
    "surproduites": ("surproduire",),
    "surproduit": ("surproduire",),
    "surproduits": ("surproduire",),
    "surprotégeaient": ("surprotéger",),
    "surprotégeai": ("surprotéger",),
    "surprotégeais": ("surprotéger",),
    "surprotégeait": ("surprotéger",),
    "surprotégea": ("surprotéger",),
    "surprotégeâmes": ("surprotéger",),
    "surprotégeant": ("surprotéger",),
    "surprotégeas": ("surprotéger",),
    "surprotégeassent": ("surprotéger",),
    "surprotégeasses": ("surprotéger",),
    "surprotégeasse": ("surprotéger",),
    "surprotégeassiez": ("surprotéger",),
    "surprotégeassions": ("surprotéger",),
    "surprotégeâtes": ("surprotéger",),
    "surprotégeât": ("surprotéger",),
    "surprotégée": ("surprotéger",),
    "surprotégées": ("surprotéger",),
    "surprotégé": ("surprotéger",),
    "surprotègent": ("surprotéger",),
    "surprotégeons": ("surprotéger",),
    "surprotège": ("surprotéger",),
    "surprotégera": ("surprotéger",),
    "surprotégeraient": ("surprotéger",),
    "surprotégerai": ("surprotéger",),
    "surprotégerais": ("surprotéger",),
    "surprotégerait": ("surprotéger",),
    "surprotégeras": ("surprotéger",),
    "surprotégèrent": ("surprotéger",),
    "surprotégerez": ("surprotéger",),
    "surprotégeriez": ("surprotéger",),
    "surprotégerions": ("surprotéger",),
    "surprotégerons": ("surprotéger",),
    "surprotégeront": ("surprotéger",),
    "surprotégés": ("surprotéger",),
    "surprotèges": ("surprotéger",),
    "surprotégez": ("surprotéger",),
    "surprotégiez": ("surprotéger",),
    "surprotégions": ("surprotéger",),
    "surqualifiaient": ("surqualifier",),
    "surqualifiai": ("surqualifier",),
    "surqualifiais": ("surqualifier",),
    "surqualifiait": ("surqualifier",),
    "surqualifia": ("surqualifier",),
    "surqualifiâmes": ("surqualifier",),
    "surqualifiant": ("surqualifier",),
    "surqualifias": ("surqualifier",),
    "surqualifiassent": ("surqualifier",),
    "surqualifiasses": ("surqualifier",),
    "surqualifiasse": ("surqualifier",),
    "surqualifiassiez": ("surqualifier",),
    "surqualifiassions": ("surqualifier",),
    "surqualifiâtes": ("surqualifier",),
    "surqualifiât": ("surqualifier",),
    "surqualifiée": ("surqualifier",),
    "surqualifiées": ("surqualifier",),
    "surqualifié": ("surqualifier",),
    "surqualifient": ("surqualifier",),
    "surqualifie": ("surqualifier",),
    "surqualifiera": ("surqualifier",),
    "surqualifieraient": ("surqualifier",),
    "surqualifierai": ("surqualifier",),
    "surqualifierais": ("surqualifier",),
    "surqualifierait": ("surqualifier",),
    "surqualifieras": ("surqualifier",),
    "surqualifièrent": ("surqualifier",),
    "surqualifierez": ("surqualifier",),
    "surqualifieriez": ("surqualifier",),
    "surqualifierions": ("surqualifier",),
    "surqualifierons": ("surqualifier",),
    "surqualifieront": ("surqualifier",),
    "surqualifiés": ("surqualifier",),
    "surqualifies": ("surqualifier",),
    "surqualifiez": ("surqualifier",),
    "surqualifiiez": ("surqualifier",),
    "surqualifiions": ("surqualifier",),
    "surqualifions": ("surqualifier",),
    "surréagi": ("surréagir",),
    "surréagîmes": ("surréagir",),
    "surréagira": ("surréagir",),
    "surréagiraient": ("surréagir",),
    "surréagirai": ("surréagir",),
    "surréagirais": ("surréagir",),
    "surréagirait": ("surréagir",),
    "surréagiras": ("surréagir",),
    "surréagirent": ("surréagir",),
    "surréagirez": ("surréagir",),
    "surréagiriez": ("surréagir",),
    "surréagirions": ("surréagir",),
    "surréagirons": ("surréagir",),
    "surréagiront": ("surréagir",),
    "surréagis": ("surréagir",),
    "surréagissaient": ("surréagir",),
    "surréagissais": ("surréagir",),
    "surréagissait": ("surréagir",),
    "surréagissant": ("surréagir",),
    "surréagissent": ("surréagir",),
    "surréagisse": ("surréagir",),
    "surréagisses": ("surréagir",),
    "surréagissez": ("surréagir",),
    "surréagissiez": ("surréagir",),
    "surréagissions": ("surréagir",),
    "surréagissons": ("surréagir",),
    "surréagîtes": ("surréagir",),
    "surréagit": ("surréagir",),
    "surréagît": ("surréagir",),
    "sursemaient": ("sursemer",),
    "sursemai": ("sursemer",),
    "sursemais": ("sursemer",),
    "sursemait": ("sursemer",),
    "sursema": ("sursemer",),
    "sursemâmes": ("sursemer",),
    "sursemant": ("sursemer",),
    "sursemas": ("sursemer",),
    "sursemassent": ("sursemer",),
    "sursemasses": ("sursemer",),
    "sursemasse": ("sursemer",),
    "sursemassiez": ("sursemer",),
    "sursemassions": ("sursemer",),
    "sursemâtes": ("sursemer",),
    "sursemât": ("sursemer",),
    "sursemée": ("sursemer",),
    "sursemées": ("sursemer",),
    "sursemé": ("sursemer",),
    "sursèment": ("sursemer",),
    "sursème": ("sursemer",),
    "sursèmera": ("sursemer",),
    "sursèmeraient": ("sursemer",),
    "sursèmerai": ("sursemer",),
    "sursèmerais": ("sursemer",),
    "sursèmerait": ("sursemer",),
    "sursèmeras": ("sursemer",),
    "sursemèrent": ("sursemer",),
    "sursèmerez": ("sursemer",),
    "sursèmeriez": ("sursemer",),
    "sursèmerions": ("sursemer",),
    "sursèmerons": ("sursemer",),
    "sursèmeront": ("sursemer",),
    "sursemés": ("sursemer",),
    "sursèmes": ("sursemer",),
    "sursemez": ("sursemer",),
    "sursemiez": ("sursemer",),
    "sursemions": ("sursemer",),
    "sursemons": ("sursemer",),
    "surseoira": ("surseoir",),
    "surseoiraient": ("surseoir",),
    "surseoirai": ("surseoir",),
    "surseoirais": ("surseoir",),
    "surseoirait": ("surseoir",),
    "surseoiras": ("surseoir",),
    "surseoirez": ("surseoir",),
    "surseoiriez": ("surseoir",),
    "surseoirions": ("surseoir",),
    "surseoirons": ("surseoir",),
    "surseoiront": ("surseoir",),
    "sursîmes": ("surseoir",),
    "sursirent": ("surseoir",),
    "sursis": ("surseoir",),
    "sursissent": ("surseoir",),
    "sursisses": ("surseoir",),
    "sursisse": ("surseoir",),
    "sursissiez": ("surseoir",),
    "sursissions": ("surseoir",),
    "sursîtes": ("surseoir",),
    "sursit": ("surseoir",),
    "sursît": ("surseoir",),
    "sursoient": ("surseoir",),
    "sursoie": ("surseoir",),
    "sursoies": ("surseoir",),
    "sursois": ("surseoir",),
    "sursoit": ("surseoir",),
    "sursoyaient": ("surseoir",),
    "sursoyais": ("surseoir",),
    "sursoyait": ("surseoir",),
    "sursoyant": ("surseoir",),
    "sursoyez": ("surseoir",),
    "sursoyiez": ("surseoir",),
    "sursoyions": ("surseoir",),
    "sursoyons": ("surseoir",),
    "sursignifiaient": ("sursignifier",),
    "sursignifiai": ("sursignifier",),
    "sursignifiais": ("sursignifier",),
    "sursignifiait": ("sursignifier",),
    "sursignifia": ("sursignifier",),
    "sursignifiâmes": ("sursignifier",),
    "sursignifiant": ("sursignifier",),
    "sursignifias": ("sursignifier",),
    "sursignifiassent": ("sursignifier",),
    "sursignifiasses": ("sursignifier",),
    "sursignifiasse": ("sursignifier",),
    "sursignifiassiez": ("sursignifier",),
    "sursignifiassions": ("sursignifier",),
    "sursignifiâtes": ("sursignifier",),
    "sursignifiât": ("sursignifier",),
    "sursignifiée": ("sursignifier",),
    "sursignifiées": ("sursignifier",),
    "sursignifié": ("sursignifier",),
    "sursignifient": ("sursignifier",),
    "sursignifie": ("sursignifier",),
    "sursignifiera": ("sursignifier",),
    "sursignifieraient": ("sursignifier",),
    "sursignifierai": ("sursignifier",),
    "sursignifierais": ("sursignifier",),
    "sursignifierait": ("sursignifier",),
    "sursignifieras": ("sursignifier",),
    "sursignifièrent": ("sursignifier",),
    "sursignifierez": ("sursignifier",),
    "sursignifieriez": ("sursignifier",),
    "sursignifierions": ("sursignifier",),
    "sursignifierons": ("sursignifier",),
    "sursignifieront": ("sursignifier",),
    "sursignifiés": ("sursignifier",),
    "sursignifies": ("sursignifier",),
    "sursignifiez": ("sursignifier",),
    "sursignifiiez": ("sursignifier",),
    "sursignifiions": ("sursignifier",),
    "sursignifions": ("sursignifier",),
    "surtendaient": ("surtendre",),
    "surtendais": ("surtendre",),
    "surtendait": ("surtendre",),
    "surtendant": ("surtendre",),
    "surtendent": ("surtendre",),
    "surtende": ("surtendre",),
    "surtendes": ("surtendre",),
    "surtendez": ("surtendre",),
    "surtendiez": ("surtendre",),
    "surtendîmes": ("surtendre",),
    "surtendions": ("surtendre",),
    "surtendirent": ("surtendre",),
    "surtendis": ("surtendre",),
    "surtendissent": ("surtendre",),
    "surtendisses": ("surtendre",),
    "surtendisse": ("surtendre",),
    "surtendissiez": ("surtendre",),
    "surtendissions": ("surtendre",),
    "surtendîtes": ("surtendre",),
    "surtendit": ("surtendre",),
    "surtendît": ("surtendre",),
    "surtendons": ("surtendre",),
    "surtend": ("surtendre",),
    "surtendra": ("surtendre",),
    "surtendraient": ("surtendre",),
    "surtendrai": ("surtendre",),
    "surtendrais": ("surtendre",),
    "surtendrait": ("surtendre",),
    "surtendras": ("surtendre",),
    "surtendrez": ("surtendre",),
    "surtendriez": ("surtendre",),
    "surtendrions": ("surtendre",),
    "surtendrons": ("surtendre",),
    "surtendront": ("surtendre",),
    "surtends": ("surtendre",),
    "surtendue": ("surtendre",),
    "surtendues": ("surtendre",),
    "surtendu": ("surtendre",),
    "surtendus": ("surtendre",),
    "surtondaient": ("surtondre",),
    "surtondais": ("surtondre",),
    "surtondait": ("surtondre",),
    "surtondant": ("surtondre",),
    "surtondent": ("surtondre",),
    "surtonde": ("surtondre",),
    "surtondes": ("surtondre",),
    "surtondez": ("surtondre",),
    "surtondiez": ("surtondre",),
    "surtondîmes": ("surtondre",),
    "surtondions": ("surtondre",),
    "surtondirent": ("surtondre",),
    "surtondis": ("surtondre",),
    "surtondissent": ("surtondre",),
    "surtondisses": ("surtondre",),
    "surtondisse": ("surtondre",),
    "surtondissiez": ("surtondre",),
    "surtondissions": ("surtondre",),
    "surtondîtes": ("surtondre",),
    "surtondit": ("surtondre",),
    "surtondît": ("surtondre",),
    "surtondons": ("surtondre",),
    "surtond": ("surtondre",),
    "surtondra": ("surtondre",),
    "surtondraient": ("surtondre",),
    "surtondrai": ("surtondre",),
    "surtondrais": ("surtondre",),
    "surtondrait": ("surtondre",),
    "surtondras": ("surtondre",),
    "surtondrez": ("surtondre",),
    "surtondriez": ("surtondre",),
    "surtondrions": ("surtondre",),
    "surtondrons": ("surtondre",),
    "surtondront": ("surtondre",),
    "surtonds": ("surtondre",),
    "surtondue": ("surtondre",),
    "surtondues": ("surtondre",),
    "surtondu": ("surtondre",),
    "surtondus": ("surtondre",),
    "survendaient": ("survendre",),
    "survendais": ("survendre",),
    "survendait": ("survendre",),
    "survendant": ("survendre",),
    "survendent": ("survendre",),
    "survende": ("survendre",),
    "survendes": ("survendre",),
    "survendez": ("survendre",),
    "survendiez": ("survendre",),
    "survendîmes": ("survendre",),
    "survendions": ("survendre",),
    "survendirent": ("survendre",),
    "survendis": ("survendre",),
    "survendissent": ("survendre",),
    "survendisses": ("survendre",),
    "survendisse": ("survendre",),
    "survendissiez": ("survendre",),
    "survendissions": ("survendre",),
    "survendîtes": ("survendre",),
    "survendit": ("survendre",),
    "survendît": ("survendre",),
    "survendons": ("survendre",),
    "survend": ("survendre",),
    "survendra": ("survendre",),
    "survendraient": ("survendre",),
    "survendrai": ("survendre",),
    "survendrais": ("survendre",),
    "survendrait": ("survendre",),
    "survendras": ("survendre",),
    "survendrez": ("survendre",),
    "survendriez": ("survendre",),
    "survendrions": ("survendre",),
    "survendrons": ("survendre",),
    "survendront": ("survendre",),
    "survends": ("survendre",),
    "survendue": ("survendre",),
    "survendues": ("survendre",),
    "survendu": ("survendre",),
    "survendus": ("survendre",),
    "survenaient": ("survenir",),
    "survenais": ("survenir",),
    "survenait": ("survenir",),
    "survenant": ("survenir",),
    "survenez": ("survenir",),
    "surveniez": ("survenir",),
    "survenions": ("survenir",),
    "survenons": ("survenir",),
    "survenue": ("survenir",),
    "survenues": ("survenir",),
    "survenu": ("survenir",),
    "survenus": ("survenir",),
    "surviendra": ("survenir",),
    "surviendraient": ("survenir",),
    "surviendrai": ("survenir",),
    "surviendrais": ("survenir",),
    "surviendrait": ("survenir",),
    "surviendras": ("survenir",),
    "surviendrez": ("survenir",),
    "surviendriez": ("survenir",),
    "surviendrions": ("survenir",),
    "surviendrons": ("survenir",),
    "surviendront": ("survenir",),
    "surviennent": ("survenir",),
    "survienne": ("survenir",),
    "surviennes": ("survenir",),
    "surviens": ("survenir",),
    "survient": ("survenir",),
    "survînmes": ("survenir",),
    "survinrent": ("survenir",),
    "survins": ("survenir",),
    "survinssent": ("survenir",),
    "survinsses": ("survenir",),
    "survinsse": ("survenir",),
    "survinssiez": ("survenir",),
    "survinssions": ("survenir",),
    "survîntes": ("survenir",),
    "survint": ("survenir",),
    "survînt": ("survenir",),
    "survêtaient": ("survêtir",),
    "survêtais": ("survêtir",),
    "survêtait": ("survêtir",),
    "survêtant": ("survêtir",),
    "survêtent": ("survêtir",),
    "survête": ("survêtir",),
    "survêtes": ("survêtir",),
    "survêtez": ("survêtir",),
    "survêtiez": ("survêtir",),
    "survêtîmes": ("survêtir",),
    "survêtions": ("survêtir",),
    "survêtira": ("survêtir",),
    "survêtiraient": ("survêtir",),
    "survêtirai": ("survêtir",),
    "survêtirais": ("survêtir",),
    "survêtirait": ("survêtir",),
    "survêtiras": ("survêtir",),
    "survêtirent": ("survêtir",),
    "survêtirez": ("survêtir",),
    "survêtiriez": ("survêtir",),
    "survêtirions": ("survêtir",),
    "survêtirons": ("survêtir",),
    "survêtiront": ("survêtir",),
    "survêtis": ("survêtir",),
    "survêtissent": ("survêtir",),
    "survêtisses": ("survêtir",),
    "survêtisse": ("survêtir",),
    "survêtissiez": ("survêtir",),
    "survêtissions": ("survêtir",),
    "survêtîtes": ("survêtir",),
    "survêtit": ("survêtir",),
    "survêtît": ("survêtir",),
    "survêtons": ("survêtir",),
    "survêt": ("survêtir",),
    "survêts": ("survêtir",),
    "survêtue": ("survêtir",),
    "survêtues": ("survêtir",),
    "survêtu": ("survêtir",),
    "survêtus": ("survêtir",),
    "survieillie": ("survieillir",),
    "survieillies": ("survieillir",),
    "survieilli": ("survieillir",),
    "survieillîmes": ("survieillir",),
    "survieillira": ("survieillir",),
    "survieilliraient": ("survieillir",),
    "survieillirai": ("survieillir",),
    "survieillirais": ("survieillir",),
    "survieillirait": ("survieillir",),
    "survieilliras": ("survieillir",),
    "survieillirent": ("survieillir",),
    "survieillirez": ("survieillir",),
    "survieilliriez": ("survieillir",),
    "survieillirions": ("survieillir",),
    "survieillirons": ("survieillir",),
    "survieilliront": ("survieillir",),
    "survieillis": ("survieillir",),
    "survieillissaient": ("survieillir",),
    "survieillissais": ("survieillir",),
    "survieillissait": ("survieillir",),
    "survieillissant": ("survieillir",),
    "survieillissent": ("survieillir",),
    "survieillisse": ("survieillir",),
    "survieillisses": ("survieillir",),
    "survieillissez": ("survieillir",),
    "survieillissiez": ("survieillir",),
    "survieillissions": ("survieillir",),
    "survieillissons": ("survieillir",),
    "survieillîtes": ("survieillir",),
    "survieillit": ("survieillir",),
    "survieillît": ("survieillir",),
    "survécu": ("survivre",),
    "survécûmes": ("survivre",),
    "survécurent": ("survivre",),
    "survécus": ("survivre",),
    "survécussent": ("survivre",),
    "survécusses": ("survivre",),
    "survécusse": ("survivre",),
    "survécussiez": ("survivre",),
    "survécussions": ("survivre",),
    "survécûtes": ("survivre",),
    "survécut": ("survivre",),
    "survécût": ("survivre",),
    "survis": ("survivre",),
    "survit": ("survivre",),
    "survivaient": ("survivre",),
    "survivais": ("survivre",),
    "survivait": ("survivre",),
    "survivant": ("survivre",),
    "survivent": ("survivre",),
    "survive": ("survivre",),
    "survives": ("survivre",),
    "survivez": ("survivre",),
    "surviviez": ("survivre",),
    "survivions": ("survivre",),
    "survivons": ("survivre",),
    "survivra": ("survivre",),
    "survivraient": ("survivre",),
    "survivrai": ("survivre",),
    "survivrais": ("survivre",),
    "survivrait": ("survivre",),
    "survivras": ("survivre",),
    "survivrez": ("survivre",),
    "survivriez": ("survivre",),
    "survivrions": ("survivre",),
    "survivrons": ("survivre",),
    "survivront": ("survivre",),
    "suscrira": ("suscrire",),
    "suscriraient": ("suscrire",),
    "suscrirai": ("suscrire",),
    "suscrirais": ("suscrire",),
    "suscrirait": ("suscrire",),
    "suscriras": ("suscrire",),
    "suscrirez": ("suscrire",),
    "suscririez": ("suscrire",),
    "suscririons": ("suscrire",),
    "suscrirons": ("suscrire",),
    "suscriront": ("suscrire",),
    "suscris": ("suscrire",),
    "suscrite": ("suscrire",),
    "suscrites": ("suscrire",),
    "suscrit": ("suscrire",),
    "suscrits": ("suscrire",),
    "suscrivaient": ("suscrire",),
    "suscrivais": ("suscrire",),
    "suscrivait": ("suscrire",),
    "suscrivant": ("suscrire",),
    "suscrivent": ("suscrire",),
    "suscrive": ("suscrire",),
    "suscrives": ("suscrire",),
    "suscrivez": ("suscrire",),
    "suscriviez": ("suscrire",),
    "suscrivîmes": ("suscrire",),
    "suscrivions": ("suscrire",),
    "suscrivirent": ("suscrire",),
    "suscrivis": ("suscrire",),
    "suscrivissent": ("suscrire",),
    "suscrivisses": ("suscrire",),
    "suscrivisse": ("suscrire",),
    "suscrivissiez": ("suscrire",),
    "suscrivissions": ("suscrire",),
    "suscrivîtes": ("suscrire",),
    "suscrivit": ("suscrire",),
    "suscrivît": ("suscrire",),
    "suscrivons": ("suscrire",),
    "suspendaient": ("suspendre",),
    "suspendais": ("suspendre",),
    "suspendait": ("suspendre",),
    "suspendant": ("suspendre",),
    "suspendent": ("suspendre",),
    "suspende": ("suspendre",),
    "suspendes": ("suspendre",),
    "suspendez": ("suspendre",),
    "suspendiez": ("suspendre",),
    "suspendîmes": ("suspendre",),
    "suspendions": ("suspendre",),
    "suspendirent": ("suspendre",),
    "suspendis": ("suspendre",),
    "suspendissent": ("suspendre",),
    "suspendisses": ("suspendre",),
    "suspendisse": ("suspendre",),
    "suspendissiez": ("suspendre",),
    "suspendissions": ("suspendre",),
    "suspendîtes": ("suspendre",),
    "suspendit": ("suspendre",),
    "suspendît": ("suspendre",),
    "suspendons": ("suspendre",),
    "suspend": ("suspendre",),
    "suspendra": ("suspendre",),
    "suspendraient": ("suspendre",),
    "suspendrai": ("suspendre",),
    "suspendrais": ("suspendre",),
    "suspendrait": ("suspendre",),
    "suspendras": ("suspendre",),
    "suspendrez": ("suspendre",),
    "suspendriez": ("suspendre",),
    "suspendrions": ("suspendre",),
    "suspendrons": ("suspendre",),
    "suspendront": ("suspendre",),
    "suspends": ("suspendre",),
    "suspendue": ("suspendre",),
    "suspendues": ("suspendre",),
    "suspendu": ("suspendre",),
    "suspendus": ("suspendre",),
    "tabassaient": ("tabasser",),
    "tabassai": ("tabasser",),
    "tabassais": ("tabasser",),
    "tabassait": ("tabasser",),
    "tabassa": ("tabasser",),
    "tabassâmes": ("tabasser",),
    "tabassant": ("tabasser",),
    "tabassas": ("tabasser",),
    "tabassassent": ("tabasser",),
    "tabassasses": ("tabasser",),
    "tabassasse": ("tabasser",),
    "tabassassiez": ("tabasser",),
    "tabassassions": ("tabasser",),
    "tabassâtes": ("tabasser",),
    "tabassât": ("tabasser",),
    "tabassée": ("tabasser",),
    "tabassées": ("tabasser",),
    "tabassé": ("tabasser",),
    "tabassent": ("tabasser",),
    "tabasse": ("tabasser",),
    "tabassera": ("tabasser",),
    "tabasseraient": ("tabasser",),
    "tabasserai": ("tabasser",),
    "tabasserais": ("tabasser",),
    "tabasserait": ("tabasser",),
    "tabasseras": ("tabasser",),
    "tabassèrent": ("tabasser",),
    "tabasserez": ("tabasser",),
    "tabasseriez": ("tabasser",),
    "tabasserions": ("tabasser",),
    "tabasserons": ("tabasser",),
    "tabasseront": ("tabasser",),
    "tabassés": ("tabasser",),
    "tabasses": ("tabasser",),
    "tabassez": ("tabasser",),
    "tabassiez": ("tabasser",),
    "tabassions": ("tabasser",),
    "tabassons": ("tabasser",),
    "tachetaient": ("tacheter",),
    "tachetai": ("tacheter",),
    "tachetais": ("tacheter",),
    "tachetait": ("tacheter",),
    "tacheta": ("tacheter",),
    "tachetâmes": ("tacheter",),
    "tachetant": ("tacheter",),
    "tachetas": ("tacheter",),
    "tachetassent": ("tacheter",),
    "tachetasses": ("tacheter",),
    "tachetasse": ("tacheter",),
    "tachetassiez": ("tacheter",),
    "tachetassions": ("tacheter",),
    "tachetâtes": ("tacheter",),
    "tachetât": ("tacheter",),
    "tachetée": ("tacheter",),
    "tachetées": ("tacheter",),
    "tacheté": ("tacheter",),
    "tachetèrent": ("tacheter",),
    "tachetés": ("tacheter",),
    "tachetez": ("tacheter",),
    "tachetiez": ("tacheter",),
    "tachetions": ("tacheter",),
    "tachetons": ("tacheter",),
    "tachettent": ("tacheter",),
    "tachette": ("tacheter",),
    "tachettera": ("tacheter",),
    "tachetteraient": ("tacheter",),
    "tachetterai": ("tacheter",),
    "tachetterais": ("tacheter",),
    "tachetterait": ("tacheter",),
    "tachetteras": ("tacheter",),
    "tachetterez": ("tacheter",),
    "tachetteriez": ("tacheter",),
    "tachetterions": ("tacheter",),
    "tachetterons": ("tacheter",),
    "tachetteront": ("tacheter",),
    "tachettes": ("tacheter",),
    "taira": ("taire",),
    "tairaient": ("taire",),
    "tairai": ("taire",),
    "tairais": ("taire",),
    "tairait": ("taire",),
    "tairas": ("taire",),
    "tairez": ("taire",),
    "tairiez": ("taire",),
    "tairions": ("taire",),
    "tairons": ("taire",),
    "tairont": ("taire",),
    "taisaient": ("taire",),
    "taisais": ("taire",),
    "taisait": ("taire",),
    "taisant": ("taire",),
    "taisent": ("taire",),
    "taise": ("taire",),
    "taises": ("taire",),
    "taisez": ("taire",),
    "taisiez": ("taire",),
    "taisions": ("taire",),
    "taisons": ("taire",),
    "tais": ("taire",),
    "tait": ("taire",),
    "tue": ("taire",),
    "tues": ("taire",),
    "tu": ("taire",),
    "tûmes": ("taire",),
    "turent": ("taire",),
    "tus": ("taire",),
    "tussent": ("taire",),
    "tusses": ("taire",),
    "tusse": ("taire",),
    "tussiez": ("taire",),
    "tussions": ("taire",),
    "tûtes": ("taire",),
    "tut": ("taire",),
    "tût": ("taire",),
    "tançaient": ("tancer",),
    "tançai": ("tancer",),
    "tançais": ("tancer",),
    "tançait": ("tancer",),
    "tança": ("tancer",),
    "tançâmes": ("tancer",),
    "tançant": ("tancer",),
    "tanças": ("tancer",),
    "tançassent": ("tancer",),
    "tançasses": ("tancer",),
    "tançasse": ("tancer",),
    "tançassiez": ("tancer",),
    "tançassions": ("tancer",),
    "tançâtes": ("tancer",),
    "tançât": ("tancer",),
    "tancée": ("tancer",),
    "tancées": ("tancer",),
    "tancé": ("tancer",),
    "tancent": ("tancer",),
    "tance": ("tancer",),
    "tancera": ("tancer",),
    "tanceraient": ("tancer",),
    "tancerai": ("tancer",),
    "tancerais": ("tancer",),
    "tancerait": ("tancer",),
    "tanceras": ("tancer",),
    "tancèrent": ("tancer",),
    "tancerez": ("tancer",),
    "tanceriez": ("tancer",),
    "tancerions": ("tancer",),
    "tancerons": ("tancer",),
    "tanceront": ("tancer",),
    "tancés": ("tancer",),
    "tances": ("tancer",),
    "tancez": ("tancer",),
    "tanciez": ("tancer",),
    "tancions": ("tancer",),
    "tançons": ("tancer",),
    "tanguiaient": ("tanguier",),
    "tanguiai": ("tanguier",),
    "tanguiais": ("tanguier",),
    "tanguiait": ("tanguier",),
    "tanguia": ("tanguier",),
    "tanguiâmes": ("tanguier",),
    "tanguiant": ("tanguier",),
    "tanguias": ("tanguier",),
    "tanguiassent": ("tanguier",),
    "tanguiasses": ("tanguier",),
    "tanguiasse": ("tanguier",),
    "tanguiassiez": ("tanguier",),
    "tanguiassions": ("tanguier",),
    "tanguiâtes": ("tanguier",),
    "tanguiât": ("tanguier",),
    "tanguiée": ("tanguier",),
    "tanguiées": ("tanguier",),
    "tanguié": ("tanguier",),
    "tanguient": ("tanguier",),
    "tanguie": ("tanguier",),
    "tanguiera": ("tanguier",),
    "tanguieraient": ("tanguier",),
    "tanguierai": ("tanguier",),
    "tanguierais": ("tanguier",),
    "tanguierait": ("tanguier",),
    "tanguieras": ("tanguier",),
    "tanguièrent": ("tanguier",),
    "tanguierez": ("tanguier",),
    "tanguieriez": ("tanguier",),
    "tanguierions": ("tanguier",),
    "tanguierons": ("tanguier",),
    "tanguieront": ("tanguier",),
    "tanguiés": ("tanguier",),
    "tanguies": ("tanguier",),
    "tanguiez": ("tanguier",),
    "tanguiiez": ("tanguier",),
    "tanguiions": ("tanguier",),
    "tanguions": ("tanguier",),
    "tapageaient": ("tapager",),
    "tapageai": ("tapager",),
    "tapageais": ("tapager",),
    "tapageait": ("tapager",),
    "tapagea": ("tapager",),
    "tapageâmes": ("tapager",),
    "tapageant": ("tapager",),
    "tapageas": ("tapager",),
    "tapageassent": ("tapager",),
    "tapageasses": ("tapager",),
    "tapageasse": ("tapager",),
    "tapageassiez": ("tapager",),
    "tapageassions": ("tapager",),
    "tapageâtes": ("tapager",),
    "tapageât": ("tapager",),
    "tapagé": ("tapager",),
    "tapagent": ("tapager",),
    "tapageons": ("tapager",),
    "tapage": ("tapager",),
    "tapagera": ("tapager",),
    "tapageraient": ("tapager",),
    "tapagerai": ("tapager",),
    "tapagerais": ("tapager",),
    "tapagerait": ("tapager",),
    "tapageras": ("tapager",),
    "tapagèrent": ("tapager",),
    "tapagerez": ("tapager",),
    "tapageriez": ("tapager",),
    "tapagerions": ("tapager",),
    "tapagerons": ("tapager",),
    "tapageront": ("tapager",),
    "tapages": ("tapager",),
    "tapagez": ("tapager",),
    "tapagiez": ("tapager",),
    "tapagions": ("tapager",),
    "tapie": ("tapir",),
    "tapies": ("tapir",),
    "tapi": ("tapir",),
    "tapîmes": ("tapir",),
    "tapira": ("tapir",),
    "tapiraient": ("tapir",),
    "tapirai": ("tapir",),
    "tapirais": ("tapir",),
    "tapirait": ("tapir",),
    "tapiras": ("tapir",),
    "tapirent": ("tapir",),
    "tapirez": ("tapir",),
    "tapiriez": ("tapir",),
    "tapirions": ("tapir",),
    "tapirons": ("tapir",),
    "tapiront": ("tapir",),
    "tapis": ("tapir",),
    "tapissaient": ("tapir",),
    "tapissais": ("tapir",),
    "tapissait": ("tapir",),
    "tapissant": ("tapir",),
    "tapissent": ("tapir",),
    "tapisse": ("tapir",),
    "tapisses": ("tapir",),
    "tapissez": ("tapir",),
    "tapissiez": ("tapir",),
    "tapissions": ("tapir",),
    "tapissons": ("tapir",),
    "tapîtes": ("tapir",),
    "tapit": ("tapir",),
    "tapît": ("tapir",),
    "tarifiaient": ("tarifier",),
    "tarifiai": ("tarifier",),
    "tarifiais": ("tarifier",),
    "tarifiait": ("tarifier",),
    "tarifia": ("tarifier",),
    "tarifiâmes": ("tarifier",),
    "tarifiant": ("tarifier",),
    "tarifias": ("tarifier",),
    "tarifiassent": ("tarifier",),
    "tarifiasses": ("tarifier",),
    "tarifiasse": ("tarifier",),
    "tarifiassiez": ("tarifier",),
    "tarifiassions": ("tarifier",),
    "tarifiâtes": ("tarifier",),
    "tarifiât": ("tarifier",),
    "tarifiée": ("tarifier",),
    "tarifiées": ("tarifier",),
    "tarifié": ("tarifier",),
    "tarifient": ("tarifier",),
    "tarifie": ("tarifier",),
    "tarifiera": ("tarifier",),
    "tarifieraient": ("tarifier",),
    "tarifierai": ("tarifier",),
    "tarifierais": ("tarifier",),
    "tarifierait": ("tarifier",),
    "tarifieras": ("tarifier",),
    "tarifièrent": ("tarifier",),
    "tarifierez": ("tarifier",),
    "tarifieriez": ("tarifier",),
    "tarifierions": ("tarifier",),
    "tarifierons": ("tarifier",),
    "tarifieront": ("tarifier",),
    "tarifiés": ("tarifier",),
    "tarifies": ("tarifier",),
    "tarifiez": ("tarifier",),
    "tarifiiez": ("tarifier",),
    "tarifiions": ("tarifier",),
    "tarifions": ("tarifier",),
    "tarie": ("tarir",),
    "taries": ("tarir",),
    "tari": ("tarir",),
    "tarîmes": ("tarir",),
    "tarira": ("tarir",),
    "tariraient": ("tarir",),
    "tarirai": ("tarir",),
    "tarirais": ("tarir",),
    "tarirait": ("tarir",),
    "tariras": ("tarir",),
    "tarirent": ("tarir",),
    "tarirez": ("tarir",),
    "taririez": ("tarir",),
    "taririons": ("tarir",),
    "tarirons": ("tarir",),
    "tariront": ("tarir",),
    "taris": ("tarir",),
    "tarissaient": ("tarir",),
    "tarissais": ("tarir",),
    "tarissait": ("tarir",),
    "tarissant": ("tarir",),
    "tarissent": ("tarir",),
    "tarisse": ("tarir",),
    "tarisses": ("tarir",),
    "tarissez": ("tarir",),
    "tarissiez": ("tarir",),
    "tarissions": ("tarir",),
    "tarissons": ("tarir",),
    "tarîtes": ("tarir",),
    "tarit": ("tarir",),
    "tarît": ("tarir",),
    "tartie": ("tartir",),
    "tarties": ("tartir",),
    "tarti": ("tartir",),
    "tartîmes": ("tartir",),
    "tartira": ("tartir",),
    "tartiraient": ("tartir",),
    "tartirai": ("tartir",),
    "tartirais": ("tartir",),
    "tartirait": ("tartir",),
    "tartiras": ("tartir",),
    "tartirent": ("tartir",),
    "tartirez": ("tartir",),
    "tartiriez": ("tartir",),
    "tartirions": ("tartir",),
    "tartirons": ("tartir",),
    "tartiront": ("tartir",),
    "tartis": ("tartir",),
    "tartissaient": ("tartir",),
    "tartissais": ("tartir",),
    "tartissait": ("tartir",),
    "tartissant": ("tartir",),
    "tartissent": ("tartir",),
    "tartisse": ("tartir",),
    "tartisses": ("tartir",),
    "tartissez": ("tartir",),
    "tartissiez": ("tartir",),
    "tartissions": ("tartir",),
    "tartissons": ("tartir",),
    "tartîtes": ("tartir",),
    "tartit": ("tartir",),
    "tartît": ("tartir",),
    "tartufiaient": ("tartufier",),
    "tartufiai": ("tartufier",),
    "tartufiais": ("tartufier",),
    "tartufiait": ("tartufier",),
    "tartufia": ("tartufier",),
    "tartufiâmes": ("tartufier",),
    "tartufiant": ("tartufier",),
    "tartufias": ("tartufier",),
    "tartufiassent": ("tartufier",),
    "tartufiasses": ("tartufier",),
    "tartufiasse": ("tartufier",),
    "tartufiassiez": ("tartufier",),
    "tartufiassions": ("tartufier",),
    "tartufiâtes": ("tartufier",),
    "tartufiât": ("tartufier",),
    "tartufiée": ("tartufier",),
    "tartufiées": ("tartufier",),
    "tartufié": ("tartufier",),
    "tartufient": ("tartufier",),
    "tartufie": ("tartufier",),
    "tartufiera": ("tartufier",),
    "tartufieraient": ("tartufier",),
    "tartufierai": ("tartufier",),
    "tartufierais": ("tartufier",),
    "tartufierait": ("tartufier",),
    "tartufieras": ("tartufier",),
    "tartufièrent": ("tartufier",),
    "tartufierez": ("tartufier",),
    "tartufieriez": ("tartufier",),
    "tartufierions": ("tartufier",),
    "tartufierons": ("tartufier",),
    "tartufieront": ("tartufier",),
    "tartufiés": ("tartufier",),
    "tartufies": ("tartufier",),
    "tartufiez": ("tartufier",),
    "tartufiiez": ("tartufier",),
    "tartufiions": ("tartufier",),
    "tartufions": ("tartufier",),
    "tassaient": ("tasser",),
    "tassai": ("tasser",),
    "tassais": ("tasser",),
    "tassait": ("tasser",),
    "tassa": ("tasser",),
    "tassâmes": ("tasser",),
    "tassant": ("tasser",),
    "tassas": ("tasser",),
    "tassassent": ("tasser",),
    "tassasses": ("tasser",),
    "tassasse": ("tasser",),
    "tassassiez": ("tasser",),
    "tassassions": ("tasser",),
    "tassâtes": ("tasser",),
    "tassât": ("tasser",),
    "tassée": ("tasser",),
    "tassées": ("tasser",),
    "tassé": ("tasser",),
    "tassent": ("tasser",),
    "tasse": ("tasser",),
    "tassera": ("tasser",),
    "tasseraient": ("tasser",),
    "tasserai": ("tasser",),
    "tasserais": ("tasser",),
    "tasserait": ("tasser",),
    "tasseras": ("tasser",),
    "tassèrent": ("tasser",),
    "tasserez": ("tasser",),
    "tasseriez": ("tasser",),
    "tasserions": ("tasser",),
    "tasserons": ("tasser",),
    "tasseront": ("tasser",),
    "tassés": ("tasser",),
    "tasses": ("tasser",),
    "tassez": ("tasser",),
    "tassiez": ("tasser",),
    "tassions": ("tasser",),
    "tassons": ("tasser",),
    "tâtaient": ("tâter",),
    "tâtai": ("tâter",),
    "tâtais": ("tâter",),
    "tâtait": ("tâter",),
    "tâta": ("tâter",),
    "tâtâmes": ("tâter",),
    "tâtant": ("tâter",),
    "tâtas": ("tâter",),
    "tâtassent": ("tâter",),
    "tâtasses": ("tâter",),
    "tâtasse": ("tâter",),
    "tâtassiez": ("tâter",),
    "tâtassions": ("tâter",),
    "tâtâtes": ("tâter",),
    "tâtât": ("tâter",),
    "tâtée": ("tâter",),
    "tâtées": ("tâter",),
    "tâté": ("tâter",),
    "tâtent": ("tâter",),
    "tâte": ("tâter",),
    "tâtera": ("tâter",),
    "tâteraient": ("tâter",),
    "tâterai": ("tâter",),
    "tâterais": ("tâter",),
    "tâterait": ("tâter",),
    "tâteras": ("tâter",),
    "tâtèrent": ("tâter",),
    "tâterez": ("tâter",),
    "tâteriez": ("tâter",),
    "tâterions": ("tâter",),
    "tâterons": ("tâter",),
    "tâteront": ("tâter",),
    "tâtés": ("tâter",),
    "tâtes": ("tâter",),
    "tâtez": ("tâter",),
    "tâtiez": ("tâter",),
    "tâtions": ("tâter",),
    "tâtons": ("tâter",),
    "taudifiaient": ("taudifier",),
    "taudifiai": ("taudifier",),
    "taudifiais": ("taudifier",),
    "taudifiait": ("taudifier",),
    "taudifia": ("taudifier",),
    "taudifiâmes": ("taudifier",),
    "taudifiant": ("taudifier",),
    "taudifias": ("taudifier",),
    "taudifiassent": ("taudifier",),
    "taudifiasses": ("taudifier",),
    "taudifiasse": ("taudifier",),
    "taudifiassiez": ("taudifier",),
    "taudifiassions": ("taudifier",),
    "taudifiâtes": ("taudifier",),
    "taudifiât": ("taudifier",),
    "taudifiée": ("taudifier",),
    "taudifiées": ("taudifier",),
    "taudifié": ("taudifier",),
    "taudifient": ("taudifier",),
    "taudifie": ("taudifier",),
    "taudifiera": ("taudifier",),
    "taudifieraient": ("taudifier",),
    "taudifierai": ("taudifier",),
    "taudifierais": ("taudifier",),
    "taudifierait": ("taudifier",),
    "taudifieras": ("taudifier",),
    "taudifièrent": ("taudifier",),
    "taudifierez": ("taudifier",),
    "taudifieriez": ("taudifier",),
    "taudifierions": ("taudifier",),
    "taudifierons": ("taudifier",),
    "taudifieront": ("taudifier",),
    "taudifiés": ("taudifier",),
    "taudifies": ("taudifier",),
    "taudifiez": ("taudifier",),
    "taudifiiez": ("taudifier",),
    "taudifiions": ("taudifier",),
    "taudifions": ("taudifier",),
    "tavelaient": ("taveler",),
    "tavelai": ("taveler",),
    "tavelais": ("taveler",),
    "tavelait": ("taveler",),
    "tavela": ("taveler",),
    "tavelâmes": ("taveler",),
    "tavelant": ("taveler",),
    "tavelas": ("taveler",),
    "tavelassent": ("taveler",),
    "tavelasses": ("taveler",),
    "tavelasse": ("taveler",),
    "tavelassiez": ("taveler",),
    "tavelassions": ("taveler",),
    "tavelâtes": ("taveler",),
    "tavelât": ("taveler",),
    "tavelée": ("taveler",),
    "tavelées": ("taveler",),
    "tavelé": ("taveler",),
    "tavelèrent": ("taveler",),
    "tavelés": ("taveler",),
    "tavelez": ("taveler",),
    "taveliez": ("taveler",),
    "tavelions": ("taveler",),
    "tavellent": ("taveler",),
    "tavelle": ("taveler",),
    "tavellera": ("taveler",),
    "tavelleraient": ("taveler",),
    "tavellerai": ("taveler",),
    "tavellerais": ("taveler",),
    "tavellerait": ("taveler",),
    "tavelleras": ("taveler",),
    "tavellerez": ("taveler",),
    "tavelleriez": ("taveler",),
    "tavellerions": ("taveler",),
    "tavellerons": ("taveler",),
    "tavelleront": ("taveler",),
    "tavelles": ("taveler",),
    "tavelons": ("taveler",),
    "teignaient": ("teindre",),
    "teignais": ("teindre",),
    "teignait": ("teindre",),
    "teignant": ("teindre",),
    "teignent": ("teindre",),
    "teigne": ("teindre",),
    "teignes": ("teindre",),
    "teignez": ("teindre",),
    "teigniez": ("teindre",),
    "teignîmes": ("teindre",),
    "teignions": ("teindre",),
    "teignirent": ("teindre",),
    "teignis": ("teindre",),
    "teignissent": ("teindre",),
    "teignisses": ("teindre",),
    "teignisse": ("teindre",),
    "teignissiez": ("teindre",),
    "teignissions": ("teindre",),
    "teignîtes": ("teindre",),
    "teignit": ("teindre",),
    "teignît": ("teindre",),
    "teignons": ("teindre",),
    "teindra": ("teindre",),
    "teindraient": ("teindre",),
    "teindrai": ("teindre",),
    "teindrais": ("teindre",),
    "teindrait": ("teindre",),
    "teindras": ("teindre",),
    "teindrez": ("teindre",),
    "teindriez": ("teindre",),
    "teindrions": ("teindre",),
    "teindrons": ("teindre",),
    "teindront": ("teindre",),
    "teins": ("teindre",),
    "teinte": ("teindre",),
    "teintes": ("teindre",),
    "teint": ("teindre",),
    "teints": ("teindre",),
    "téléchargeaient": ("télécharger",),
    "téléchargeai": ("télécharger",),
    "téléchargeais": ("télécharger",),
    "téléchargeait": ("télécharger",),
    "téléchargea": ("télécharger",),
    "téléchargeâmes": ("télécharger",),
    "téléchargeant": ("télécharger",),
    "téléchargeas": ("télécharger",),
    "téléchargeassent": ("télécharger",),
    "téléchargeasses": ("télécharger",),
    "téléchargeasse": ("télécharger",),
    "téléchargeassiez": ("télécharger",),
    "téléchargeassions": ("télécharger",),
    "téléchargeâtes": ("télécharger",),
    "téléchargeât": ("télécharger",),
    "téléchargée": ("télécharger",),
    "téléchargées": ("télécharger",),
    "téléchargé": ("télécharger",),
    "téléchargent": ("télécharger",),
    "téléchargeons": ("télécharger",),
    "télécharge": ("télécharger",),
    "téléchargera": ("télécharger",),
    "téléchargeraient": ("télécharger",),
    "téléchargerai": ("télécharger",),
    "téléchargerais": ("télécharger",),
    "téléchargerait": ("télécharger",),
    "téléchargeras": ("télécharger",),
    "téléchargèrent": ("télécharger",),
    "téléchargerez": ("télécharger",),
    "téléchargeriez": ("télécharger",),
    "téléchargerions": ("télécharger",),
    "téléchargerons": ("télécharger",),
    "téléchargeront": ("télécharger",),
    "téléchargés": ("télécharger",),
    "télécharges": ("télécharger",),
    "téléchargez": ("télécharger",),
    "téléchargiez": ("télécharger",),
    "téléchargions": ("télécharger",),
    "télécopiaient": ("télécopier",),
    "télécopiai": ("télécopier",),
    "télécopiais": ("télécopier",),
    "télécopiait": ("télécopier",),
    "télécopia": ("télécopier",),
    "télécopiâmes": ("télécopier",),
    "télécopiant": ("télécopier",),
    "télécopias": ("télécopier",),
    "télécopiassent": ("télécopier",),
    "télécopiasses": ("télécopier",),
    "télécopiasse": ("télécopier",),
    "télécopiassiez": ("télécopier",),
    "télécopiassions": ("télécopier",),
    "télécopiâtes": ("télécopier",),
    "télécopiât": ("télécopier",),
    "télécopiée": ("télécopier",),
    "télécopiées": ("télécopier",),
    "télécopié": ("télécopier",),
    "télécopient": ("télécopier",),
    "télécopie": ("télécopier",),
    "télécopiera": ("télécopier",),
    "télécopieraient": ("télécopier",),
    "télécopierai": ("télécopier",),
    "télécopierais": ("télécopier",),
    "télécopierait": ("télécopier",),
    "télécopieras": ("télécopier",),
    "télécopièrent": ("télécopier",),
    "télécopierez": ("télécopier",),
    "télécopieriez": ("télécopier",),
    "télécopierions": ("télécopier",),
    "télécopierons": ("télécopier",),
    "télécopieront": ("télécopier",),
    "télécopiés": ("télécopier",),
    "télécopies": ("télécopier",),
    "télécopiez": ("télécopier",),
    "télécopiiez": ("télécopier",),
    "télécopiions": ("télécopier",),
    "télécopions": ("télécopier",),
    "télédéchargeaient": ("télédécharger",),
    "télédéchargeai": ("télédécharger",),
    "télédéchargeais": ("télédécharger",),
    "télédéchargeait": ("télédécharger",),
    "télédéchargea": ("télédécharger",),
    "télédéchargeâmes": ("télédécharger",),
    "télédéchargeant": ("télédécharger",),
    "télédéchargeas": ("télédécharger",),
    "télédéchargeassent": ("télédécharger",),
    "télédéchargeasses": ("télédécharger",),
    "télédéchargeasse": ("télédécharger",),
    "télédéchargeassiez": ("télédécharger",),
    "télédéchargeassions": ("télédécharger",),
    "télédéchargeâtes": ("télédécharger",),
    "télédéchargeât": ("télédécharger",),
    "télédéchargée": ("télédécharger",),
    "télédéchargées": ("télédécharger",),
    "télédéchargé": ("télédécharger",),
    "télédéchargent": ("télédécharger",),
    "télédéchargeons": ("télédécharger",),
    "télédécharge": ("télédécharger",),
    "télédéchargera": ("télédécharger",),
    "télédéchargeraient": ("télédécharger",),
    "télédéchargerai": ("télédécharger",),
    "télédéchargerais": ("télédécharger",),
    "télédéchargerait": ("télédécharger",),
    "télédéchargeras": ("télédécharger",),
    "télédéchargèrent": ("télédécharger",),
    "télédéchargerez": ("télédécharger",),
    "télédéchargeriez": ("télédécharger",),
    "télédéchargerions": ("télédécharger",),
    "télédéchargerons": ("télédécharger",),
    "télédéchargeront": ("télédécharger",),
    "télédéchargés": ("télédécharger",),
    "télédécharges": ("télédécharger",),
    "télédéchargez": ("télédécharger",),
    "télédéchargiez": ("télédécharger",),
    "télédéchargions": ("télédécharger",),
    "téléféraient": ("téléférer",),
    "téléférai": ("téléférer",),
    "téléférais": ("téléférer",),
    "téléférait": ("téléférer",),
    "téléféra": ("téléférer",),
    "téléférâmes": ("téléférer",),
    "téléférant": ("téléférer",),
    "téléféras": ("téléférer",),
    "téléférassent": ("téléférer",),
    "téléférasses": ("téléférer",),
    "téléférasse": ("téléférer",),
    "téléférassiez": ("téléférer",),
    "téléférassions": ("téléférer",),
    "téléférâtes": ("téléférer",),
    "téléférât": ("téléférer",),
    "téléférée": ("téléférer",),
    "téléférées": ("téléférer",),
    "téléféré": ("téléférer",),
    "téléfèrent": ("téléférer",),
    "téléfère": ("téléférer",),
    "téléférera": ("téléférer",),
    "téléféreraient": ("téléférer",),
    "téléférerai": ("téléférer",),
    "téléférerais": ("téléférer",),
    "téléférerait": ("téléférer",),
    "téléféreras": ("téléférer",),
    "téléférèrent": ("téléférer",),
    "téléférerez": ("téléférer",),
    "téléféreriez": ("téléférer",),
    "téléférerions": ("téléférer",),
    "téléférerons": ("téléférer",),
    "téléféreront": ("téléférer",),
    "téléférés": ("téléférer",),
    "téléfères": ("téléférer",),
    "téléférez": ("téléférer",),
    "téléfériez": ("téléférer",),
    "téléférions": ("téléférer",),
    "téléférons": ("téléférer",),
    "télégraphiaient": ("télégraphier",),
    "télégraphiai": ("télégraphier",),
    "télégraphiais": ("télégraphier",),
    "télégraphiait": ("télégraphier",),
    "télégraphia": ("télégraphier",),
    "télégraphiâmes": ("télégraphier",),
    "télégraphiant": ("télégraphier",),
    "télégraphias": ("télégraphier",),
    "télégraphiassent": ("télégraphier",),
    "télégraphiasses": ("télégraphier",),
    "télégraphiasse": ("télégraphier",),
    "télégraphiassiez": ("télégraphier",),
    "télégraphiassions": ("télégraphier",),
    "télégraphiâtes": ("télégraphier",),
    "télégraphiât": ("télégraphier",),
    "télégraphiée": ("télégraphier",),
    "télégraphiées": ("télégraphier",),
    "télégraphié": ("télégraphier",),
    "télégraphient": ("télégraphier",),
    "télégraphie": ("télégraphier",),
    "télégraphiera": ("télégraphier",),
    "télégraphieraient": ("télégraphier",),
    "télégraphierai": ("télégraphier",),
    "télégraphierais": ("télégraphier",),
    "télégraphierait": ("télégraphier",),
    "télégraphieras": ("télégraphier",),
    "télégraphièrent": ("télégraphier",),
    "télégraphierez": ("télégraphier",),
    "télégraphieriez": ("télégraphier",),
    "télégraphierions": ("télégraphier",),
    "télégraphierons": ("télégraphier",),
    "télégraphieront": ("télégraphier",),
    "télégraphiés": ("télégraphier",),
    "télégraphies": ("télégraphier",),
    "télégraphiez": ("télégraphier",),
    "télégraphiiez": ("télégraphier",),
    "télégraphiions": ("télégraphier",),
    "télégraphions": ("télégraphier",),
    "téléjaugeaient": ("téléjauger",),
    "téléjaugeai": ("téléjauger",),
    "téléjaugeais": ("téléjauger",),
    "téléjaugeait": ("téléjauger",),
    "téléjaugea": ("téléjauger",),
    "téléjaugeâmes": ("téléjauger",),
    "téléjaugeant": ("téléjauger",),
    "téléjaugeas": ("téléjauger",),
    "téléjaugeassent": ("téléjauger",),
    "téléjaugeasses": ("téléjauger",),
    "téléjaugeasse": ("téléjauger",),
    "téléjaugeassiez": ("téléjauger",),
    "téléjaugeassions": ("téléjauger",),
    "téléjaugeâtes": ("téléjauger",),
    "téléjaugeât": ("téléjauger",),
    "téléjaugée": ("téléjauger",),
    "téléjaugées": ("téléjauger",),
    "téléjaugé": ("téléjauger",),
    "téléjaugent": ("téléjauger",),
    "téléjaugeons": ("téléjauger",),
    "téléjauge": ("téléjauger",),
    "téléjaugera": ("téléjauger",),
    "téléjaugeraient": ("téléjauger",),
    "téléjaugerai": ("téléjauger",),
    "téléjaugerais": ("téléjauger",),
    "téléjaugerait": ("téléjauger",),
    "téléjaugeras": ("téléjauger",),
    "téléjaugèrent": ("téléjauger",),
    "téléjaugerez": ("téléjauger",),
    "téléjaugeriez": ("téléjauger",),
    "téléjaugerions": ("téléjauger",),
    "téléjaugerons": ("téléjauger",),
    "téléjaugeront": ("téléjauger",),
    "téléjaugés": ("téléjauger",),
    "téléjauges": ("téléjauger",),
    "téléjaugez": ("téléjauger",),
    "téléjaugiez": ("téléjauger",),
    "téléjaugions": ("téléjauger",),
    "télémétraient": ("télémétrer",),
    "télémétrai": ("télémétrer",),
    "télémétrais": ("télémétrer",),
    "télémétrait": ("télémétrer",),
    "télémétra": ("télémétrer",),
    "télémétrâmes": ("télémétrer",),
    "télémétrant": ("télémétrer",),
    "télémétras": ("télémétrer",),
    "télémétrassent": ("télémétrer",),
    "télémétrasses": ("télémétrer",),
    "télémétrasse": ("télémétrer",),
    "télémétrassiez": ("télémétrer",),
    "télémétrassions": ("télémétrer",),
    "télémétrâtes": ("télémétrer",),
    "télémétrât": ("télémétrer",),
    "télémétrée": ("télémétrer",),
    "télémétrées": ("télémétrer",),
    "télémétré": ("télémétrer",),
    "télémètrent": ("télémétrer",),
    "télémètre": ("télémétrer",),
    "télémétrera": ("télémétrer",),
    "télémétreraient": ("télémétrer",),
    "télémétrerai": ("télémétrer",),
    "télémétrerais": ("télémétrer",),
    "télémétrerait": ("télémétrer",),
    "télémétreras": ("télémétrer",),
    "télémétrèrent": ("télémétrer",),
    "télémétrerez": ("télémétrer",),
    "télémétreriez": ("télémétrer",),
    "télémétrerions": ("télémétrer",),
    "télémétrerons": ("télémétrer",),
    "télémétreront": ("télémétrer",),
    "télémétrés": ("télémétrer",),
    "télémètres": ("télémétrer",),
    "télémétrez": ("télémétrer",),
    "télémétriez": ("télémétrer",),
    "télémétrions": ("télémétrer",),
    "télémétrons": ("télémétrer",),
    "téléopéraient": ("téléopérer",),
    "téléopérai": ("téléopérer",),
    "téléopérais": ("téléopérer",),
    "téléopérait": ("téléopérer",),
    "téléopéra": ("téléopérer",),
    "téléopérâmes": ("téléopérer",),
    "téléopérant": ("téléopérer",),
    "téléopéras": ("téléopérer",),
    "téléopérassent": ("téléopérer",),
    "téléopérasses": ("téléopérer",),
    "téléopérasse": ("téléopérer",),
    "téléopérassiez": ("téléopérer",),
    "téléopérassions": ("téléopérer",),
    "téléopérâtes": ("téléopérer",),
    "téléopérât": ("téléopérer",),
    "téléopérée": ("téléopérer",),
    "téléopérées": ("téléopérer",),
    "téléopéré": ("téléopérer",),
    "téléopèrent": ("téléopérer",),
    "téléopère": ("téléopérer",),
    "téléopérera": ("téléopérer",),
    "téléopéreraient": ("téléopérer",),
    "téléopérerai": ("téléopérer",),
    "téléopérerais": ("téléopérer",),
    "téléopérerait": ("téléopérer",),
    "téléopéreras": ("téléopérer",),
    "téléopérèrent": ("téléopérer",),
    "téléopérerez": ("téléopérer",),
    "téléopéreriez": ("téléopérer",),
    "téléopérerions": ("téléopérer",),
    "téléopérerons": ("téléopérer",),
    "téléopéreront": ("téléopérer",),
    "téléopérés": ("téléopérer",),
    "téléopères": ("téléopérer",),
    "téléopérez": ("téléopérer",),
    "téléopériez": ("téléopérer",),
    "téléopérions": ("téléopérer",),
    "téléopérons": ("téléopérer",),
    "téléphéraient": ("téléphérer",),
    "téléphérai": ("téléphérer",),
    "téléphérais": ("téléphérer",),
    "téléphérait": ("téléphérer",),
    "téléphéra": ("téléphérer",),
    "téléphérâmes": ("téléphérer",),
    "téléphérant": ("téléphérer",),
    "téléphéras": ("téléphérer",),
    "téléphérassent": ("téléphérer",),
    "téléphérasses": ("téléphérer",),
    "téléphérasse": ("téléphérer",),
    "téléphérassiez": ("téléphérer",),
    "téléphérassions": ("téléphérer",),
    "téléphérâtes": ("téléphérer",),
    "téléphérât": ("téléphérer",),
    "téléphérée": ("téléphérer",),
    "téléphérées": ("téléphérer",),
    "téléphéré": ("téléphérer",),
    "téléphèrent": ("téléphérer",),
    "téléphère": ("téléphérer",),
    "téléphérera": ("téléphérer",),
    "téléphéreraient": ("téléphérer",),
    "téléphérerai": ("téléphérer",),
    "téléphérerais": ("téléphérer",),
    "téléphérerait": ("téléphérer",),
    "téléphéreras": ("téléphérer",),
    "téléphérèrent": ("téléphérer",),
    "téléphérerez": ("téléphérer",),
    "téléphéreriez": ("téléphérer",),
    "téléphérerions": ("téléphérer",),
    "téléphérerons": ("téléphérer",),
    "téléphéreront": ("téléphérer",),
    "téléphérés": ("téléphérer",),
    "téléphères": ("téléphérer",),
    "téléphérez": ("téléphérer",),
    "téléphériez": ("téléphérer",),
    "téléphérions": ("téléphérer",),
    "téléphérons": ("téléphérer",),
    "téléréglaient": ("télérégler",),
    "téléréglai": ("télérégler",),
    "téléréglais": ("télérégler",),
    "téléréglait": ("télérégler",),
    "télérégla": ("télérégler",),
    "téléréglâmes": ("télérégler",),
    "téléréglant": ("télérégler",),
    "téléréglas": ("télérégler",),
    "téléréglassent": ("télérégler",),
    "téléréglasses": ("télérégler",),
    "téléréglasse": ("télérégler",),
    "téléréglassiez": ("télérégler",),
    "téléréglassions": ("télérégler",),
    "téléréglâtes": ("télérégler",),
    "téléréglât": ("télérégler",),
    "téléréglée": ("télérégler",),
    "téléréglées": ("télérégler",),
    "téléréglé": ("télérégler",),
    "télérèglent": ("télérégler",),
    "télérègle": ("télérégler",),
    "téléréglera": ("télérégler",),
    "télérégleraient": ("télérégler",),
    "téléréglerai": ("télérégler",),
    "téléréglerais": ("télérégler",),
    "téléréglerait": ("télérégler",),
    "télérégleras": ("télérégler",),
    "téléréglèrent": ("télérégler",),
    "téléréglerez": ("télérégler",),
    "télérégleriez": ("télérégler",),
    "téléréglerions": ("télérégler",),
    "téléréglerons": ("télérégler",),
    "télérégleront": ("télérégler",),
    "téléréglés": ("télérégler",),
    "télérègles": ("télérégler",),
    "téléréglez": ("télérégler",),
    "télérégliez": ("télérégler",),
    "téléréglions": ("télérégler",),
    "téléréglons": ("télérégler",),
    "télétransmet": ("télétransmettre",),
    "télétransmets": ("télétransmettre",),
    "télétransmettaient": ("télétransmettre",),
    "télétransmettais": ("télétransmettre",),
    "télétransmettait": ("télétransmettre",),
    "télétransmettant": ("télétransmettre",),
    "télétransmettent": ("télétransmettre",),
    "télétransmette": ("télétransmettre",),
    "télétransmettes": ("télétransmettre",),
    "télétransmettez": ("télétransmettre",),
    "télétransmettiez": ("télétransmettre",),
    "télétransmettions": ("télétransmettre",),
    "télétransmettons": ("télétransmettre",),
    "télétransmettra": ("télétransmettre",),
    "télétransmettraient": ("télétransmettre",),
    "télétransmettrai": ("télétransmettre",),
    "télétransmettrais": ("télétransmettre",),
    "télétransmettrait": ("télétransmettre",),
    "télétransmettras": ("télétransmettre",),
    "télétransmettrez": ("télétransmettre",),
    "télétransmettriez": ("télétransmettre",),
    "télétransmettrions": ("télétransmettre",),
    "télétransmettrons": ("télétransmettre",),
    "télétransmettront": ("télétransmettre",),
    "télétransmîmes": ("télétransmettre",),
    "télétransmirent": ("télétransmettre",),
    "télétransmise": ("télétransmettre",),
    "télétransmises": ("télétransmettre",),
    "télétransmis": ("télétransmettre",),
    "télétransmissent": ("télétransmettre",),
    "télétransmisses": ("télétransmettre",),
    "télétransmisse": ("télétransmettre",),
    "télétransmissiez": ("télétransmettre",),
    "télétransmissions": ("télétransmettre",),
    "télétransmîtes": ("télétransmettre",),
    "télétransmit": ("télétransmettre",),
    "télétransmît": ("télétransmettre",),
    "tempéraient": ("tempérer",),
    "tempérai": ("tempérer",),
    "tempérais": ("tempérer",),
    "tempérait": ("tempérer",),
    "tempéra": ("tempérer",),
    "tempérâmes": ("tempérer",),
    "tempérant": ("tempérer",),
    "tempéras": ("tempérer",),
    "tempérassent": ("tempérer",),
    "tempérasses": ("tempérer",),
    "tempérasse": ("tempérer",),
    "tempérassiez": ("tempérer",),
    "tempérassions": ("tempérer",),
    "tempérâtes": ("tempérer",),
    "tempérât": ("tempérer",),
    "tempérée": ("tempérer",),
    "tempérées": ("tempérer",),
    "tempéré": ("tempérer",),
    "tempèrent": ("tempérer",),
    "tempère": ("tempérer",),
    "tempérera": ("tempérer",),
    "tempéreraient": ("tempérer",),
    "tempérerai": ("tempérer",),
    "tempérerais": ("tempérer",),
    "tempérerait": ("tempérer",),
    "tempéreras": ("tempérer",),
    "tempérèrent": ("tempérer",),
    "tempérerez": ("tempérer",),
    "tempéreriez": ("tempérer",),
    "tempérerions": ("tempérer",),
    "tempérerons": ("tempérer",),
    "tempéreront": ("tempérer",),
    "tempérés": ("tempérer",),
    "tempères": ("tempérer",),
    "tempérez": ("tempérer",),
    "tempériez": ("tempérer",),
    "tempérions": ("tempérer",),
    "tempérons": ("tempérer",),
    "tendaient": ("tendre",),
    "tendais": ("tendre",),
    "tendait": ("tendre",),
    "tendant": ("tendre",),
    "tendent": ("tendre",),
    "tende": ("tendre",),
    "tendes": ("tendre",),
    "tendez": ("tendre",),
    "tendiez": ("tendre",),
    "tendîmes": ("tendre",),
    "tendions": ("tendre",),
    "tendirent": ("tendre",),
    "tendis": ("tendre",),
    "tendissent": ("tendre",),
    "tendisses": ("tendre",),
    "tendisse": ("tendre",),
    "tendissiez": ("tendre",),
    "tendissions": ("tendre",),
    "tendîtes": ("tendre",),
    "tendit": ("tendre",),
    "tendît": ("tendre",),
    "tendons": ("tendre",),
    "tend": ("tendre",),
    "tendra": ("tendre",),
    "tendraient": ("tendre",),
    "tendrai": ("tendre",),
    "tendrais": ("tendre",),
    "tendrait": ("tendre",),
    "tendras": ("tendre",),
    "tendrez": ("tendre",),
    "tendriez": ("tendre",),
    "tendrions": ("tendre",),
    "tendrons": ("tendre",),
    "tendront": ("tendre",),
    "tends": ("tendre",),
    "tendue": ("tendre",),
    "tendues": ("tendre",),
    "tendu": ("tendre",),
    "tendus": ("tendre",),
    "tenaient": ("tenir",),
    "tenais": ("tenir",),
    "tenait": ("tenir",),
    "tenant": ("tenir",),
    "tenez": ("tenir",),
    "teniez": ("tenir",),
    "tenions": ("tenir",),
    "tenons": ("tenir",),
    "tenue": ("tenir",),
    "tenues": ("tenir",),
    "tenu": ("tenir",),
    "tenus": ("tenir",),
    "tiendra": ("tenir",),
    "tiendraient": ("tenir",),
    "tiendrai": ("tenir",),
    "tiendrais": ("tenir",),
    "tiendrait": ("tenir",),
    "tiendras": ("tenir",),
    "tiendrez": ("tenir",),
    "tiendriez": ("tenir",),
    "tiendrions": ("tenir",),
    "tiendrons": ("tenir",),
    "tiendront": ("tenir",),
    "tiennent": ("tenir",),
    "tienne": ("tenir",),
    "tiennes": ("tenir",),
    "tiens": ("tenir",),
    "tient": ("tenir",),
    "tînmes": ("tenir",),
    "tinrent": ("tenir",),
    "tins": ("tenir",),
    "tinssent": ("tenir",),
    "tinsses": ("tenir",),
    "tinsse": ("tenir",),
    "tinssiez": ("tenir",),
    "tinssions": ("tenir",),
    "tîntes": ("tenir",),
    "tint": ("tenir",),
    "tînt": ("tenir",),
    "terçaient": ("tercer",),
    "terçai": ("tercer",),
    "terçais": ("tercer",),
    "terçait": ("tercer",),
    "terça": ("tercer",),
    "terçâmes": ("tercer",),
    "terçant": ("tercer",),
    "terças": ("tercer",),
    "terçassent": ("tercer",),
    "terçasses": ("tercer",),
    "terçasse": ("tercer",),
    "terçassiez": ("tercer",),
    "terçassions": ("tercer",),
    "terçâtes": ("tercer",),
    "terçât": ("tercer",),
    "tercée": ("tercer",),
    "tercées": ("tercer",),
    "tercé": ("tercer",),
    "tercent": ("tercer",),
    "terce": ("tercer",),
    "tercera": ("tercer",),
    "terceraient": ("tercer",),
    "tercerai": ("tercer",),
    "tercerais": ("tercer",),
    "tercerait": ("tercer",),
    "terceras": ("tercer",),
    "tercèrent": ("tercer",),
    "tercerez": ("tercer",),
    "terceriez": ("tercer",),
    "tercerions": ("tercer",),
    "tercerons": ("tercer",),
    "terceront": ("tercer",),
    "tercés": ("tercer",),
    "terces": ("tercer",),
    "tercez": ("tercer",),
    "terciez": ("tercer",),
    "tercions": ("tercer",),
    "terçons": ("tercer",),
    "térébraient": ("térébrer",),
    "térébrai": ("térébrer",),
    "térébrais": ("térébrer",),
    "térébrait": ("térébrer",),
    "térébra": ("térébrer",),
    "térébrâmes": ("térébrer",),
    "térébrant": ("térébrer",),
    "térébras": ("térébrer",),
    "térébrassent": ("térébrer",),
    "térébrasses": ("térébrer",),
    "térébrasse": ("térébrer",),
    "térébrassiez": ("térébrer",),
    "térébrassions": ("térébrer",),
    "térébrâtes": ("térébrer",),
    "térébrât": ("térébrer",),
    "térébrée": ("térébrer",),
    "térébrées": ("térébrer",),
    "térébré": ("térébrer",),
    "térèbrent": ("térébrer",),
    "térèbre": ("térébrer",),
    "térébrera": ("térébrer",),
    "térébreraient": ("térébrer",),
    "térébrerai": ("térébrer",),
    "térébrerais": ("térébrer",),
    "térébrerait": ("térébrer",),
    "térébreras": ("térébrer",),
    "térébrèrent": ("térébrer",),
    "térébrerez": ("térébrer",),
    "térébreriez": ("térébrer",),
    "térébrerions": ("térébrer",),
    "térébrerons": ("térébrer",),
    "térébreront": ("térébrer",),
    "térébrés": ("térébrer",),
    "térèbres": ("térébrer",),
    "térébrez": ("térébrer",),
    "térébriez": ("térébrer",),
    "térébrions": ("térébrer",),
    "térébrons": ("térébrer",),
    "ternie": ("ternir",),
    "ternies": ("ternir",),
    "terni": ("ternir",),
    "ternîmes": ("ternir",),
    "ternira": ("ternir",),
    "terniraient": ("ternir",),
    "ternirai": ("ternir",),
    "ternirais": ("ternir",),
    "ternirait": ("ternir",),
    "terniras": ("ternir",),
    "ternirent": ("ternir",),
    "ternirez": ("ternir",),
    "terniriez": ("ternir",),
    "ternirions": ("ternir",),
    "ternirons": ("ternir",),
    "terniront": ("ternir",),
    "ternis": ("ternir",),
    "ternissaient": ("ternir",),
    "ternissais": ("ternir",),
    "ternissait": ("ternir",),
    "ternissant": ("ternir",),
    "ternissent": ("ternir",),
    "ternisse": ("ternir",),
    "ternisses": ("ternir",),
    "ternissez": ("ternir",),
    "ternissiez": ("ternir",),
    "ternissions": ("ternir",),
    "ternissons": ("ternir",),
    "ternîtes": ("ternir",),
    "ternit": ("ternir",),
    "ternît": ("ternir",),
    "terrassaient": ("terrasser",),
    "terrassai": ("terrasser",),
    "terrassais": ("terrasser",),
    "terrassait": ("terrasser",),
    "terrassa": ("terrasser",),
    "terrassâmes": ("terrasser",),
    "terrassant": ("terrasser",),
    "terrassas": ("terrasser",),
    "terrassassent": ("terrasser",),
    "terrassasses": ("terrasser",),
    "terrassasse": ("terrasser",),
    "terrassassiez": ("terrasser",),
    "terrassassions": ("terrasser",),
    "terrassâtes": ("terrasser",),
    "terrassât": ("terrasser",),
    "terrassée": ("terrasser",),
    "terrassées": ("terrasser",),
    "terrassé": ("terrasser",),
    "terrassent": ("terrasser",),
    "terrasse": ("terrasser",),
    "terrassera": ("terrasser",),
    "terrasseraient": ("terrasser",),
    "terrasserai": ("terrasser",),
    "terrasserais": ("terrasser",),
    "terrasserait": ("terrasser",),
    "terrasseras": ("terrasser",),
    "terrassèrent": ("terrasser",),
    "terrasserez": ("terrasser",),
    "terrasseriez": ("terrasser",),
    "terrasserions": ("terrasser",),
    "terrasserons": ("terrasser",),
    "terrasseront": ("terrasser",),
    "terrassés": ("terrasser",),
    "terrasses": ("terrasser",),
    "terrassez": ("terrasser",),
    "terrassiez": ("terrasser",),
    "terrassions": ("terrasser",),
    "terrassons": ("terrasser",),
    "terrifiaient": ("terrifier",),
    "terrifiai": ("terrifier",),
    "terrifiais": ("terrifier",),
    "terrifiait": ("terrifier",),
    "terrifia": ("terrifier",),
    "terrifiâmes": ("terrifier",),
    "terrifiant": ("terrifier",),
    "terrifias": ("terrifier",),
    "terrifiassent": ("terrifier",),
    "terrifiasses": ("terrifier",),
    "terrifiasse": ("terrifier",),
    "terrifiassiez": ("terrifier",),
    "terrifiassions": ("terrifier",),
    "terrifiâtes": ("terrifier",),
    "terrifiât": ("terrifier",),
    "terrifiée": ("terrifier",),
    "terrifiées": ("terrifier",),
    "terrifié": ("terrifier",),
    "terrifient": ("terrifier",),
    "terrifie": ("terrifier",),
    "terrifiera": ("terrifier",),
    "terrifieraient": ("terrifier",),
    "terrifierai": ("terrifier",),
    "terrifierais": ("terrifier",),
    "terrifierait": ("terrifier",),
    "terrifieras": ("terrifier",),
    "terrifièrent": ("terrifier",),
    "terrifierez": ("terrifier",),
    "terrifieriez": ("terrifier",),
    "terrifierions": ("terrifier",),
    "terrifierons": ("terrifier",),
    "terrifieront": ("terrifier",),
    "terrifiés": ("terrifier",),
    "terrifies": ("terrifier",),
    "terrifiez": ("terrifier",),
    "terrifiiez": ("terrifier",),
    "terrifiions": ("terrifier",),
    "terrifions": ("terrifier",),
    "terrie": ("terrir",),
    "terries": ("terrir",),
    "terri": ("terrir",),
    "terrîmes": ("terrir",),
    "terrira": ("terrir",),
    "terriraient": ("terrir",),
    "terrirai": ("terrir",),
    "terrirais": ("terrir",),
    "terrirait": ("terrir",),
    "terriras": ("terrir",),
    "terrirent": ("terrir",),
    "terrirez": ("terrir",),
    "terririez": ("terrir",),
    "terririons": ("terrir",),
    "terrirons": ("terrir",),
    "terriront": ("terrir",),
    "terris": ("terrir",),
    "terrissaient": ("terrir",),
    "terrissais": ("terrir",),
    "terrissait": ("terrir",),
    "terrissant": ("terrir",),
    "terrissent": ("terrir",),
    "terrisse": ("terrir",),
    "terrisses": ("terrir",),
    "terrissez": ("terrir",),
    "terrissiez": ("terrir",),
    "terrissions": ("terrir",),
    "terrissons": ("terrir",),
    "terrîtes": ("terrir",),
    "territ": ("terrir",),
    "terrît": ("terrir",),
    "tétaient": ("téter",),
    "tétai": ("téter",),
    "tétais": ("téter",),
    "tétait": ("téter",),
    "téta": ("téter",),
    "tétâmes": ("téter",),
    "tétant": ("téter",),
    "tétas": ("téter",),
    "tétassent": ("téter",),
    "tétasses": ("téter",),
    "tétasse": ("téter",),
    "tétassiez": ("téter",),
    "tétassions": ("téter",),
    "tétâtes": ("téter",),
    "tétât": ("téter",),
    "tétée": ("téter",),
    "tétées": ("téter",),
    "tété": ("téter",),
    "tètent": ("téter",),
    "tète": ("téter",),
    "tétera": ("téter",),
    "téteraient": ("téter",),
    "téterai": ("téter",),
    "téterais": ("téter",),
    "téterait": ("téter",),
    "téteras": ("téter",),
    "tétèrent": ("téter",),
    "téterez": ("téter",),
    "téteriez": ("téter",),
    "téterions": ("téter",),
    "téterons": ("téter",),
    "téteront": ("téter",),
    "tétés": ("téter",),
    "tètes": ("téter",),
    "tétez": ("téter",),
    "tétiez": ("téter",),
    "tétions": ("téter",),
    "tétons": ("téter",),
    "thermoanesthésiaient": ("thermoanesthésier",),
    "thermoanesthésiai": ("thermoanesthésier",),
    "thermoanesthésiais": ("thermoanesthésier",),
    "thermoanesthésiait": ("thermoanesthésier",),
    "thermoanesthésia": ("thermoanesthésier",),
    "thermoanesthésiâmes": ("thermoanesthésier",),
    "thermoanesthésiant": ("thermoanesthésier",),
    "thermoanesthésias": ("thermoanesthésier",),
    "thermoanesthésiassent": ("thermoanesthésier",),
    "thermoanesthésiasses": ("thermoanesthésier",),
    "thermoanesthésiasse": ("thermoanesthésier",),
    "thermoanesthésiassiez": ("thermoanesthésier",),
    "thermoanesthésiassions": ("thermoanesthésier",),
    "thermoanesthésiâtes": ("thermoanesthésier",),
    "thermoanesthésiât": ("thermoanesthésier",),
    "thermoanesthésiée": ("thermoanesthésier",),
    "thermoanesthésiées": ("thermoanesthésier",),
    "thermoanesthésié": ("thermoanesthésier",),
    "thermoanesthésient": ("thermoanesthésier",),
    "thermoanesthésie": ("thermoanesthésier",),
    "thermoanesthésiera": ("thermoanesthésier",),
    "thermoanesthésieraient": ("thermoanesthésier",),
    "thermoanesthésierai": ("thermoanesthésier",),
    "thermoanesthésierais": ("thermoanesthésier",),
    "thermoanesthésierait": ("thermoanesthésier",),
    "thermoanesthésieras": ("thermoanesthésier",),
    "thermoanesthésièrent": ("thermoanesthésier",),
    "thermoanesthésierez": ("thermoanesthésier",),
    "thermoanesthésieriez": ("thermoanesthésier",),
    "thermoanesthésierions": ("thermoanesthésier",),
    "thermoanesthésierons": ("thermoanesthésier",),
    "thermoanesthésieront": ("thermoanesthésier",),
    "thermoanesthésiés": ("thermoanesthésier",),
    "thermoanesthésies": ("thermoanesthésier",),
    "thermoanesthésiez": ("thermoanesthésier",),
    "thermoanesthésiiez": ("thermoanesthésier",),
    "thermoanesthésiions": ("thermoanesthésier",),
    "thermoanesthésions": ("thermoanesthésier",),
    "thermomassaient": ("thermomasser",),
    "thermomassai": ("thermomasser",),
    "thermomassais": ("thermomasser",),
    "thermomassait": ("thermomasser",),
    "thermomassa": ("thermomasser",),
    "thermomassâmes": ("thermomasser",),
    "thermomassant": ("thermomasser",),
    "thermomassas": ("thermomasser",),
    "thermomassassent": ("thermomasser",),
    "thermomassasses": ("thermomasser",),
    "thermomassasse": ("thermomasser",),
    "thermomassassiez": ("thermomasser",),
    "thermomassassions": ("thermomasser",),
    "thermomassâtes": ("thermomasser",),
    "thermomassât": ("thermomasser",),
    "thermomassée": ("thermomasser",),
    "thermomassées": ("thermomasser",),
    "thermomassé": ("thermomasser",),
    "thermomassent": ("thermomasser",),
    "thermomasse": ("thermomasser",),
    "thermomassera": ("thermomasser",),
    "thermomasseraient": ("thermomasser",),
    "thermomasserai": ("thermomasser",),
    "thermomasserais": ("thermomasser",),
    "thermomasserait": ("thermomasser",),
    "thermomasseras": ("thermomasser",),
    "thermomassèrent": ("thermomasser",),
    "thermomasserez": ("thermomasser",),
    "thermomasseriez": ("thermomasser",),
    "thermomasserions": ("thermomasser",),
    "thermomasserons": ("thermomasser",),
    "thermomasseront": ("thermomasser",),
    "thermomassés": ("thermomasser",),
    "thermomasses": ("thermomasser",),
    "thermomassez": ("thermomasser",),
    "thermomassiez": ("thermomasser",),
    "thermomassions": ("thermomasser",),
    "thermomassons": ("thermomasser",),
    "thermorégénéraient": ("thermorégénérer",),
    "thermorégénérai": ("thermorégénérer",),
    "thermorégénérais": ("thermorégénérer",),
    "thermorégénérait": ("thermorégénérer",),
    "thermorégénéra": ("thermorégénérer",),
    "thermorégénérâmes": ("thermorégénérer",),
    "thermorégénérant": ("thermorégénérer",),
    "thermorégénéras": ("thermorégénérer",),
    "thermorégénérassent": ("thermorégénérer",),
    "thermorégénérasses": ("thermorégénérer",),
    "thermorégénérasse": ("thermorégénérer",),
    "thermorégénérassiez": ("thermorégénérer",),
    "thermorégénérassions": ("thermorégénérer",),
    "thermorégénérâtes": ("thermorégénérer",),
    "thermorégénérât": ("thermorégénérer",),
    "thermorégénérée": ("thermorégénérer",),
    "thermorégénérées": ("thermorégénérer",),
    "thermorégénéré": ("thermorégénérer",),
    "thermorégénèrent": ("thermorégénérer",),
    "thermorégénère": ("thermorégénérer",),
    "thermorégénérera": ("thermorégénérer",),
    "thermorégénéreraient": ("thermorégénérer",),
    "thermorégénérerai": ("thermorégénérer",),
    "thermorégénérerais": ("thermorégénérer",),
    "thermorégénérerait": ("thermorégénérer",),
    "thermorégénéreras": ("thermorégénérer",),
    "thermorégénérèrent": ("thermorégénérer",),
    "thermorégénérerez": ("thermorégénérer",),
    "thermorégénéreriez": ("thermorégénérer",),
    "thermorégénérerions": ("thermorégénérer",),
    "thermorégénérerons": ("thermorégénérer",),
    "thermorégénéreront": ("thermorégénérer",),
    "thermorégénérés": ("thermorégénérer",),
    "thermorégénères": ("thermorégénérer",),
    "thermorégénérez": ("thermorégénérer",),
    "thermorégénériez": ("thermorégénérer",),
    "thermorégénérions": ("thermorégénérer",),
    "thermorégénérons": ("thermorégénérer",),
    "tiédie": ("tiédir",),
    "tiédies": ("tiédir",),
    "tiédi": ("tiédir",),
    "tiédîmes": ("tiédir",),
    "tiédira": ("tiédir",),
    "tiédiraient": ("tiédir",),
    "tiédirai": ("tiédir",),
    "tiédirais": ("tiédir",),
    "tiédirait": ("tiédir",),
    "tiédiras": ("tiédir",),
    "tiédirent": ("tiédir",),
    "tiédirez": ("tiédir",),
    "tiédiriez": ("tiédir",),
    "tiédirions": ("tiédir",),
    "tiédirons": ("tiédir",),
    "tiédiront": ("tiédir",),
    "tiédis": ("tiédir",),
    "tiédissaient": ("tiédir",),
    "tiédissais": ("tiédir",),
    "tiédissait": ("tiédir",),
    "tiédissant": ("tiédir",),
    "tiédissent": ("tiédir",),
    "tiédisse": ("tiédir",),
    "tiédisses": ("tiédir",),
    "tiédissez": ("tiédir",),
    "tiédissiez": ("tiédir",),
    "tiédissions": ("tiédir",),
    "tiédissons": ("tiédir",),
    "tiédîtes": ("tiédir",),
    "tiédit": ("tiédir",),
    "tiédît": ("tiédir",),
    "tierçaient": ("tiercer",),
    "tierçai": ("tiercer",),
    "tierçais": ("tiercer",),
    "tierçait": ("tiercer",),
    "tierça": ("tiercer",),
    "tierçâmes": ("tiercer",),
    "tierçant": ("tiercer",),
    "tierças": ("tiercer",),
    "tierçassent": ("tiercer",),
    "tierçasses": ("tiercer",),
    "tierçasse": ("tiercer",),
    "tierçassiez": ("tiercer",),
    "tierçassions": ("tiercer",),
    "tierçâtes": ("tiercer",),
    "tierçât": ("tiercer",),
    "tiercée": ("tiercer",),
    "tiercées": ("tiercer",),
    "tiercé": ("tiercer",),
    "tiercent": ("tiercer",),
    "tierce": ("tiercer",),
    "tiercera": ("tiercer",),
    "tierceraient": ("tiercer",),
    "tiercerai": ("tiercer",),
    "tiercerais": ("tiercer",),
    "tiercerait": ("tiercer",),
    "tierceras": ("tiercer",),
    "tiercèrent": ("tiercer",),
    "tiercerez": ("tiercer",),
    "tierceriez": ("tiercer",),
    "tiercerions": ("tiercer",),
    "tiercerons": ("tiercer",),
    "tierceront": ("tiercer",),
    "tiercés": ("tiercer",),
    "tierces": ("tiercer",),
    "tiercez": ("tiercer",),
    "tierciez": ("tiercer",),
    "tiercions": ("tiercer",),
    "tierçons": ("tiercer",),
    "tiquetaient": ("tiqueter",),
    "tiquetai": ("tiqueter",),
    "tiquetais": ("tiqueter",),
    "tiquetait": ("tiqueter",),
    "tiqueta": ("tiqueter",),
    "tiquetâmes": ("tiqueter",),
    "tiquetant": ("tiqueter",),
    "tiquetas": ("tiqueter",),
    "tiquetassent": ("tiqueter",),
    "tiquetasses": ("tiqueter",),
    "tiquetasse": ("tiqueter",),
    "tiquetassiez": ("tiqueter",),
    "tiquetassions": ("tiqueter",),
    "tiquetâtes": ("tiqueter",),
    "tiquetât": ("tiqueter",),
    "tiquetée": ("tiqueter",),
    "tiquetées": ("tiqueter",),
    "tiqueté": ("tiqueter",),
    "tiquetèrent": ("tiqueter",),
    "tiquetés": ("tiqueter",),
    "tiquetez": ("tiqueter",),
    "tiquetiez": ("tiqueter",),
    "tiquetions": ("tiqueter",),
    "tiquetons": ("tiqueter",),
    "tiquettent": ("tiqueter",),
    "tiquette": ("tiqueter",),
    "tiquettera": ("tiqueter",),
    "tiquetteraient": ("tiqueter",),
    "tiquetterai": ("tiqueter",),
    "tiquetterais": ("tiqueter",),
    "tiquetterait": ("tiqueter",),
    "tiquetteras": ("tiqueter",),
    "tiquetterez": ("tiqueter",),
    "tiquetteriez": ("tiqueter",),
    "tiquetterions": ("tiqueter",),
    "tiquetterons": ("tiqueter",),
    "tiquetteront": ("tiqueter",),
    "tiquettes": ("tiqueter",),
    "tirassaient": ("tirasser",),
    "tirassai": ("tirasser",),
    "tirassais": ("tirasser",),
    "tirassait": ("tirasser",),
    "tirassa": ("tirasser",),
    "tirassâmes": ("tirasser",),
    "tirassant": ("tirasser",),
    "tirassas": ("tirasser",),
    "tirassassent": ("tirasser",),
    "tirassasses": ("tirasser",),
    "tirassasse": ("tirasser",),
    "tirassassiez": ("tirasser",),
    "tirassassions": ("tirasser",),
    "tirassâtes": ("tirasser",),
    "tirassât": ("tirasser",),
    "tirassée": ("tirasser",),
    "tirassées": ("tirasser",),
    "tirassé": ("tirasser",),
    "tirassent": ("tirasser",),
    "tirasse": ("tirasser",),
    "tirassera": ("tirasser",),
    "tirasseraient": ("tirasser",),
    "tirasserai": ("tirasser",),
    "tirasserais": ("tirasser",),
    "tirasserait": ("tirasser",),
    "tirasseras": ("tirasser",),
    "tirassèrent": ("tirasser",),
    "tirasserez": ("tirasser",),
    "tirasseriez": ("tirasser",),
    "tirasserions": ("tirasser",),
    "tirasserons": ("tirasser",),
    "tirasseront": ("tirasser",),
    "tirassés": ("tirasser",),
    "tirasses": ("tirasser",),
    "tirassez": ("tirasser",),
    "tirassiez": ("tirasser",),
    "tirassions": ("tirasser",),
    "tirassons": ("tirasser",),
    "toléraient": ("tolérer",),
    "tolérai": ("tolérer",),
    "tolérais": ("tolérer",),
    "tolérait": ("tolérer",),
    "toléra": ("tolérer",),
    "tolérâmes": ("tolérer",),
    "tolérant": ("tolérer",),
    "toléras": ("tolérer",),
    "tolérassent": ("tolérer",),
    "tolérasses": ("tolérer",),
    "tolérasse": ("tolérer",),
    "tolérassiez": ("tolérer",),
    "tolérassions": ("tolérer",),
    "tolérâtes": ("tolérer",),
    "tolérât": ("tolérer",),
    "tolérée": ("tolérer",),
    "tolérées": ("tolérer",),
    "toléré": ("tolérer",),
    "tolèrent": ("tolérer",),
    "tolère": ("tolérer",),
    "tolérera": ("tolérer",),
    "toléreraient": ("tolérer",),
    "tolérerai": ("tolérer",),
    "tolérerais": ("tolérer",),
    "tolérerait": ("tolérer",),
    "toléreras": ("tolérer",),
    "tolérèrent": ("tolérer",),
    "tolérerez": ("tolérer",),
    "toléreriez": ("tolérer",),
    "tolérerions": ("tolérer",),
    "tolérerons": ("tolérer",),
    "toléreront": ("tolérer",),
    "tolérés": ("tolérer",),
    "tolères": ("tolérer",),
    "tolérez": ("tolérer",),
    "tolériez": ("tolérer",),
    "tolérions": ("tolérer",),
    "tolérons": ("tolérer",),
    "tondaient": ("tondre",),
    "tondais": ("tondre",),
    "tondait": ("tondre",),
    "tondant": ("tondre",),
    "tondent": ("tondre",),
    "tonde": ("tondre",),
    "tondes": ("tondre",),
    "tondez": ("tondre",),
    "tondiez": ("tondre",),
    "tondîmes": ("tondre",),
    "tondions": ("tondre",),
    "tondirent": ("tondre",),
    "tondis": ("tondre",),
    "tondissent": ("tondre",),
    "tondisses": ("tondre",),
    "tondisse": ("tondre",),
    "tondissiez": ("tondre",),
    "tondissions": ("tondre",),
    "tondîtes": ("tondre",),
    "tondit": ("tondre",),
    "tondît": ("tondre",),
    "tondons": ("tondre",),
    "tond": ("tondre",),
    "tondra": ("tondre",),
    "tondraient": ("tondre",),
    "tondrai": ("tondre",),
    "tondrais": ("tondre",),
    "tondrait": ("tondre",),
    "tondras": ("tondre",),
    "tondrez": ("tondre",),
    "tondriez": ("tondre",),
    "tondrions": ("tondre",),
    "tondrons": ("tondre",),
    "tondront": ("tondre",),
    "tonds": ("tondre",),
    "tondue": ("tondre",),
    "tondues": ("tondre",),
    "tondu": ("tondre",),
    "tondus": ("tondre",),
    "tonifiaient": ("tonifier",),
    "tonifiai": ("tonifier",),
    "tonifiais": ("tonifier",),
    "tonifiait": ("tonifier",),
    "tonifia": ("tonifier",),
    "tonifiâmes": ("tonifier",),
    "tonifiant": ("tonifier",),
    "tonifias": ("tonifier",),
    "tonifiassent": ("tonifier",),
    "tonifiasses": ("tonifier",),
    "tonifiasse": ("tonifier",),
    "tonifiassiez": ("tonifier",),
    "tonifiassions": ("tonifier",),
    "tonifiâtes": ("tonifier",),
    "tonifiât": ("tonifier",),
    "tonifiée": ("tonifier",),
    "tonifiées": ("tonifier",),
    "tonifié": ("tonifier",),
    "tonifient": ("tonifier",),
    "tonifie": ("tonifier",),
    "tonifiera": ("tonifier",),
    "tonifieraient": ("tonifier",),
    "tonifierai": ("tonifier",),
    "tonifierais": ("tonifier",),
    "tonifierait": ("tonifier",),
    "tonifieras": ("tonifier",),
    "tonifièrent": ("tonifier",),
    "tonifierez": ("tonifier",),
    "tonifieriez": ("tonifier",),
    "tonifierions": ("tonifier",),
    "tonifierons": ("tonifier",),
    "tonifieront": ("tonifier",),
    "tonifiés": ("tonifier",),
    "tonifies": ("tonifier",),
    "tonifiez": ("tonifier",),
    "tonifiiez": ("tonifier",),
    "tonifiions": ("tonifier",),
    "tonifions": ("tonifier",),
    "tonnelaient": ("tonneler",),
    "tonnelai": ("tonneler",),
    "tonnelais": ("tonneler",),
    "tonnelait": ("tonneler",),
    "tonnela": ("tonneler",),
    "tonnelâmes": ("tonneler",),
    "tonnelant": ("tonneler",),
    "tonnelas": ("tonneler",),
    "tonnelassent": ("tonneler",),
    "tonnelasses": ("tonneler",),
    "tonnelasse": ("tonneler",),
    "tonnelassiez": ("tonneler",),
    "tonnelassions": ("tonneler",),
    "tonnelâtes": ("tonneler",),
    "tonnelât": ("tonneler",),
    "tonnelée": ("tonneler",),
    "tonnelées": ("tonneler",),
    "tonnelé": ("tonneler",),
    "tonnelèrent": ("tonneler",),
    "tonnelés": ("tonneler",),
    "tonnelez": ("tonneler",),
    "tonneliez": ("tonneler",),
    "tonnelions": ("tonneler",),
    "tonnellent": ("tonneler",),
    "tonnelle": ("tonneler",),
    "tonnellera": ("tonneler",),
    "tonnelleraient": ("tonneler",),
    "tonnellerai": ("tonneler",),
    "tonnellerais": ("tonneler",),
    "tonnellerait": ("tonneler",),
    "tonnelleras": ("tonneler",),
    "tonnellerez": ("tonneler",),
    "tonnelleriez": ("tonneler",),
    "tonnellerions": ("tonneler",),
    "tonnellerons": ("tonneler",),
    "tonnelleront": ("tonneler",),
    "tonnelles": ("tonneler",),
    "tonnelons": ("tonneler",),
    "tordaient": ("tordre",),
    "tordais": ("tordre",),
    "tordait": ("tordre",),
    "tordant": ("tordre",),
    "tordent": ("tordre",),
    "torde": ("tordre",),
    "tordes": ("tordre",),
    "tordez": ("tordre",),
    "tordiez": ("tordre",),
    "tordîmes": ("tordre",),
    "tordions": ("tordre",),
    "tordirent": ("tordre",),
    "tordis": ("tordre",),
    "tordissent": ("tordre",),
    "tordisses": ("tordre",),
    "tordisse": ("tordre",),
    "tordissiez": ("tordre",),
    "tordissions": ("tordre",),
    "tordîtes": ("tordre",),
    "tordit": ("tordre",),
    "tordît": ("tordre",),
    "tordons": ("tordre",),
    "tord": ("tordre",),
    "tordra": ("tordre",),
    "tordraient": ("tordre",),
    "tordrai": ("tordre",),
    "tordrais": ("tordre",),
    "tordrait": ("tordre",),
    "tordras": ("tordre",),
    "tordrez": ("tordre",),
    "tordriez": ("tordre",),
    "tordrions": ("tordre",),
    "tordrons": ("tordre",),
    "tordront": ("tordre",),
    "tords": ("tordre",),
    "tordue": ("tordre",),
    "tordues": ("tordre",),
    "tordu": ("tordre",),
    "tordus": ("tordre",),
    "toréaient": ("toréer",),
    "toréai": ("toréer",),
    "toréais": ("toréer",),
    "toréait": ("toréer",),
    "toréa": ("toréer",),
    "toréâmes": ("toréer",),
    "toréant": ("toréer",),
    "toréas": ("toréer",),
    "toréassent": ("toréer",),
    "toréasses": ("toréer",),
    "toréasse": ("toréer",),
    "toréassiez": ("toréer",),
    "toréassions": ("toréer",),
    "toréâtes": ("toréer",),
    "toréât": ("toréer",),
    "toréée": ("toréer",),
    "toréées": ("toréer",),
    "toréé": ("toréer",),
    "toréent": ("toréer",),
    "torée": ("toréer",),
    "toréera": ("toréer",),
    "toréeraient": ("toréer",),
    "toréerai": ("toréer",),
    "toréerais": ("toréer",),
    "toréerait": ("toréer",),
    "toréeras": ("toréer",),
    "toréèrent": ("toréer",),
    "toréerez": ("toréer",),
    "toréeriez": ("toréer",),
    "toréerions": ("toréer",),
    "toréerons": ("toréer",),
    "toréeront": ("toréer",),
    "toréés": ("toréer",),
    "torées": ("toréer",),
    "toréez": ("toréer",),
    "toréiez": ("toréer",),
    "toréions": ("toréer",),
    "toréons": ("toréer",),
    "tornassaient": ("tornasser",),
    "tornassai": ("tornasser",),
    "tornassais": ("tornasser",),
    "tornassait": ("tornasser",),
    "tornassa": ("tornasser",),
    "tornassâmes": ("tornasser",),
    "tornassant": ("tornasser",),
    "tornassas": ("tornasser",),
    "tornassassent": ("tornasser",),
    "tornassasses": ("tornasser",),
    "tornassasse": ("tornasser",),
    "tornassassiez": ("tornasser",),
    "tornassassions": ("tornasser",),
    "tornassâtes": ("tornasser",),
    "tornassât": ("tornasser",),
    "tornassée": ("tornasser",),
    "tornassées": ("tornasser",),
    "tornassé": ("tornasser",),
    "tornassent": ("tornasser",),
    "tornasse": ("tornasser",),
    "tornassera": ("tornasser",),
    "tornasseraient": ("tornasser",),
    "tornasserai": ("tornasser",),
    "tornasserais": ("tornasser",),
    "tornasserait": ("tornasser",),
    "tornasseras": ("tornasser",),
    "tornassèrent": ("tornasser",),
    "tornasserez": ("tornasser",),
    "tornasseriez": ("tornasser",),
    "tornasserions": ("tornasser",),
    "tornasserons": ("tornasser",),
    "tornasseront": ("tornasser",),
    "tornassés": ("tornasser",),
    "tornasses": ("tornasser",),
    "tornassez": ("tornasser",),
    "tornassiez": ("tornasser",),
    "tornassions": ("tornasser",),
    "tornassons": ("tornasser",),
    "torréfiaient": ("torréfier",),
    "torréfiai": ("torréfier",),
    "torréfiais": ("torréfier",),
    "torréfiait": ("torréfier",),
    "torréfia": ("torréfier",),
    "torréfiâmes": ("torréfier",),
    "torréfiant": ("torréfier",),
    "torréfias": ("torréfier",),
    "torréfiassent": ("torréfier",),
    "torréfiasses": ("torréfier",),
    "torréfiasse": ("torréfier",),
    "torréfiassiez": ("torréfier",),
    "torréfiassions": ("torréfier",),
    "torréfiâtes": ("torréfier",),
    "torréfiât": ("torréfier",),
    "torréfiée": ("torréfier",),
    "torréfiées": ("torréfier",),
    "torréfié": ("torréfier",),
    "torréfient": ("torréfier",),
    "torréfie": ("torréfier",),
    "torréfiera": ("torréfier",),
    "torréfieraient": ("torréfier",),
    "torréfierai": ("torréfier",),
    "torréfierais": ("torréfier",),
    "torréfierait": ("torréfier",),
    "torréfieras": ("torréfier",),
    "torréfièrent": ("torréfier",),
    "torréfierez": ("torréfier",),
    "torréfieriez": ("torréfier",),
    "torréfierions": ("torréfier",),
    "torréfierons": ("torréfier",),
    "torréfieront": ("torréfier",),
    "torréfiés": ("torréfier",),
    "torréfies": ("torréfier",),
    "torréfiez": ("torréfier",),
    "torréfiiez": ("torréfier",),
    "torréfiions": ("torréfier",),
    "torréfions": ("torréfier",),
    "tournassaient": ("tournasser",),
    "tournassai": ("tournasser",),
    "tournassais": ("tournasser",),
    "tournassait": ("tournasser",),
    "tournassa": ("tournasser",),
    "tournassâmes": ("tournasser",),
    "tournassant": ("tournasser",),
    "tournassas": ("tournasser",),
    "tournassassent": ("tournasser",),
    "tournassasses": ("tournasser",),
    "tournassasse": ("tournasser",),
    "tournassassiez": ("tournasser",),
    "tournassassions": ("tournasser",),
    "tournassâtes": ("tournasser",),
    "tournassât": ("tournasser",),
    "tournassée": ("tournasser",),
    "tournassées": ("tournasser",),
    "tournassé": ("tournasser",),
    "tournassent": ("tournasser",),
    "tournasse": ("tournasser",),
    "tournassera": ("tournasser",),
    "tournasseraient": ("tournasser",),
    "tournasserai": ("tournasser",),
    "tournasserais": ("tournasser",),
    "tournasserait": ("tournasser",),
    "tournasseras": ("tournasser",),
    "tournassèrent": ("tournasser",),
    "tournasserez": ("tournasser",),
    "tournasseriez": ("tournasser",),
    "tournasserions": ("tournasser",),
    "tournasserons": ("tournasser",),
    "tournasseront": ("tournasser",),
    "tournassés": ("tournasser",),
    "tournasses": ("tournasser",),
    "tournassez": ("tournasser",),
    "tournassiez": ("tournasser",),
    "tournassions": ("tournasser",),
    "tournassons": ("tournasser",),
    "tournoient": ("tournoyer",),
    "tournoie": ("tournoyer",),
    "tournoiera": ("tournoyer",),
    "tournoieraient": ("tournoyer",),
    "tournoierai": ("tournoyer",),
    "tournoierais": ("tournoyer",),
    "tournoierait": ("tournoyer",),
    "tournoieras": ("tournoyer",),
    "tournoierez": ("tournoyer",),
    "tournoieriez": ("tournoyer",),
    "tournoierions": ("tournoyer",),
    "tournoierons": ("tournoyer",),
    "tournoieront": ("tournoyer",),
    "tournoies": ("tournoyer",),
    "tournoyaient": ("tournoyer",),
    "tournoyai": ("tournoyer",),
    "tournoyais": ("tournoyer",),
    "tournoyait": ("tournoyer",),
    "tournoya": ("tournoyer",),
    "tournoyâmes": ("tournoyer",),
    "tournoyant": ("tournoyer",),
    "tournoyas": ("tournoyer",),
    "tournoyassent": ("tournoyer",),
    "tournoyasses": ("tournoyer",),
    "tournoyasse": ("tournoyer",),
    "tournoyassiez": ("tournoyer",),
    "tournoyassions": ("tournoyer",),
    "tournoyâtes": ("tournoyer",),
    "tournoyât": ("tournoyer",),
    "tournoyé": ("tournoyer",),
    "tournoyèrent": ("tournoyer",),
    "tournoyez": ("tournoyer",),
    "tournoyiez": ("tournoyer",),
    "tournoyions": ("tournoyer",),
    "tournoyons": ("tournoyer",),
    "toussie": ("toussir",),
    "toussies": ("toussir",),
    "toussi": ("toussir",),
    "toussîmes": ("toussir",),
    "toussira": ("toussir",),
    "toussiraient": ("toussir",),
    "toussirai": ("toussir",),
    "toussirais": ("toussir",),
    "toussirait": ("toussir",),
    "toussiras": ("toussir",),
    "toussirent": ("toussir",),
    "toussirez": ("toussir",),
    "toussiriez": ("toussir",),
    "toussirions": ("toussir",),
    "toussirons": ("toussir",),
    "toussiront": ("toussir",),
    "toussis": ("toussir",),
    "toussissaient": ("toussir",),
    "toussissais": ("toussir",),
    "toussissait": ("toussir",),
    "toussissant": ("toussir",),
    "toussissent": ("toussir",),
    "toussisse": ("toussir",),
    "toussisses": ("toussir",),
    "toussissez": ("toussir",),
    "toussissiez": ("toussir",),
    "toussissions": ("toussir",),
    "toussissons": ("toussir",),
    "toussîtes": ("toussir",),
    "toussit": ("toussir",),
    "toussît": ("toussir",),
    "tracassaient": ("tracasser",),
    "tracassai": ("tracasser",),
    "tracassais": ("tracasser",),
    "tracassait": ("tracasser",),
    "tracassa": ("tracasser",),
    "tracassâmes": ("tracasser",),
    "tracassant": ("tracasser",),
    "tracassas": ("tracasser",),
    "tracassassent": ("tracasser",),
    "tracassasses": ("tracasser",),
    "tracassasse": ("tracasser",),
    "tracassassiez": ("tracasser",),
    "tracassassions": ("tracasser",),
    "tracassâtes": ("tracasser",),
    "tracassât": ("tracasser",),
    "tracassée": ("tracasser",),
    "tracassées": ("tracasser",),
    "tracassé": ("tracasser",),
    "tracassent": ("tracasser",),
    "tracasse": ("tracasser",),
    "tracassera": ("tracasser",),
    "tracasseraient": ("tracasser",),
    "tracasserai": ("tracasser",),
    "tracasserais": ("tracasser",),
    "tracasserait": ("tracasser",),
    "tracasseras": ("tracasser",),
    "tracassèrent": ("tracasser",),
    "tracasserez": ("tracasser",),
    "tracasseriez": ("tracasser",),
    "tracasserions": ("tracasser",),
    "tracasserons": ("tracasser",),
    "tracasseront": ("tracasser",),
    "tracassés": ("tracasser",),
    "tracasses": ("tracasser",),
    "tracassez": ("tracasser",),
    "tracassiez": ("tracasser",),
    "tracassions": ("tracasser",),
    "tracassons": ("tracasser",),
    "traçaient": ("tracer",),
    "traçai": ("tracer",),
    "traçais": ("tracer",),
    "traçait": ("tracer",),
    "traça": ("tracer",),
    "traçâmes": ("tracer",),
    "traçant": ("tracer",),
    "traças": ("tracer",),
    "traçassent": ("tracer",),
    "traçasses": ("tracer",),
    "traçasse": ("tracer",),
    "traçassiez": ("tracer",),
    "traçassions": ("tracer",),
    "traçâtes": ("tracer",),
    "traçât": ("tracer",),
    "tracée": ("tracer",),
    "tracées": ("tracer",),
    "tracé": ("tracer",),
    "tracent": ("tracer",),
    "trace": ("tracer",),
    "tracera": ("tracer",),
    "traceraient": ("tracer",),
    "tracerai": ("tracer",),
    "tracerais": ("tracer",),
    "tracerait": ("tracer",),
    "traceras": ("tracer",),
    "tracèrent": ("tracer",),
    "tracerez": ("tracer",),
    "traceriez": ("tracer",),
    "tracerions": ("tracer",),
    "tracerons": ("tracer",),
    "traceront": ("tracer",),
    "tracés": ("tracer",),
    "traces": ("tracer",),
    "tracez": ("tracer",),
    "traciez": ("tracer",),
    "tracions": ("tracer",),
    "traçons": ("tracer",),
    "traduira": ("traduire",),
    "traduiraient": ("traduire",),
    "traduirai": ("traduire",),
    "traduirais": ("traduire",),
    "traduirait": ("traduire",),
    "traduiras": ("traduire",),
    "traduirez": ("traduire",),
    "traduiriez": ("traduire",),
    "traduirions": ("traduire",),
    "traduirons": ("traduire",),
    "traduiront": ("traduire",),
    "traduisaient": ("traduire",),
    "traduisais": ("traduire",),
    "traduisait": ("traduire",),
    "traduisant": ("traduire",),
    "traduisent": ("traduire",),
    "traduise": ("traduire",),
    "traduises": ("traduire",),
    "traduisez": ("traduire",),
    "traduisiez": ("traduire",),
    "traduisîmes": ("traduire",),
    "traduisions": ("traduire",),
    "traduisirent": ("traduire",),
    "traduisis": ("traduire",),
    "traduisissent": ("traduire",),
    "traduisisses": ("traduire",),
    "traduisisse": ("traduire",),
    "traduisissiez": ("traduire",),
    "traduisissions": ("traduire",),
    "traduisîtes": ("traduire",),
    "traduisit": ("traduire",),
    "traduisît": ("traduire",),
    "traduisons": ("traduire",),
    "traduis": ("traduire",),
    "traduite": ("traduire",),
    "traduites": ("traduire",),
    "traduit": ("traduire",),
    "traduits": ("traduire",),
    "trahie": ("trahir",),
    "trahies": ("trahir",),
    "trahi": ("trahir",),
    "trahîmes": ("trahir",),
    "trahira": ("trahir",),
    "trahiraient": ("trahir",),
    "trahirai": ("trahir",),
    "trahirais": ("trahir",),
    "trahirait": ("trahir",),
    "trahiras": ("trahir",),
    "trahirent": ("trahir",),
    "trahirez": ("trahir",),
    "trahiriez": ("trahir",),
    "trahirions": ("trahir",),
    "trahirons": ("trahir",),
    "trahiront": ("trahir",),
    "trahis": ("trahir",),
    "trahissaient": ("trahir",),
    "trahissais": ("trahir",),
    "trahissait": ("trahir",),
    "trahissant": ("trahir",),
    "trahissent": ("trahir",),
    "trahisse": ("trahir",),
    "trahisses": ("trahir",),
    "trahissez": ("trahir",),
    "trahissiez": ("trahir",),
    "trahissions": ("trahir",),
    "trahissons": ("trahir",),
    "trahîtes": ("trahir",),
    "trahit": ("trahir",),
    "trahît": ("trahir",),
    "traînassaient": ("traînasser",),
    "traînassai": ("traînasser",),
    "traînassais": ("traînasser",),
    "traînassait": ("traînasser",),
    "traînassa": ("traînasser",),
    "traînassâmes": ("traînasser",),
    "traînassant": ("traînasser",),
    "traînassas": ("traînasser",),
    "traînassassent": ("traînasser",),
    "traînassasses": ("traînasser",),
    "traînassasse": ("traînasser",),
    "traînassassiez": ("traînasser",),
    "traînassassions": ("traînasser",),
    "traînassâtes": ("traînasser",),
    "traînassât": ("traînasser",),
    "traînassée": ("traînasser",),
    "traînassées": ("traînasser",),
    "traînassé": ("traînasser",),
    "traînassent": ("traînasser",),
    "traînasse": ("traînasser",),
    "traînassera": ("traînasser",),
    "traînasseraient": ("traînasser",),
    "traînasserai": ("traînasser",),
    "traînasserais": ("traînasser",),
    "traînasserait": ("traînasser",),
    "traînasseras": ("traînasser",),
    "traînassèrent": ("traînasser",),
    "traînasserez": ("traînasser",),
    "traînasseriez": ("traînasser",),
    "traînasserions": ("traînasser",),
    "traînasserons": ("traînasser",),
    "traînasseront": ("traînasser",),
    "traînassés": ("traînasser",),
    "traînasses": ("traînasser",),
    "traînassez": ("traînasser",),
    "traînassiez": ("traînasser",),
    "traînassions": ("traînasser",),
    "traînassons": ("traînasser",),
    "traient": ("traire",),
    "traie": ("traire",),
    "traies": ("traire",),
    "traira": ("traire",),
    "trairaient": ("traire",),
    "trairai": ("traire",),
    "trairais": ("traire",),
    "trairait": ("traire",),
    "trairas": ("traire",),
    "trairez": ("traire",),
    "trairiez": ("traire",),
    "trairions": ("traire",),
    "trairons": ("traire",),
    "trairont": ("traire",),
    "trais": ("traire",),
    "traite": ("traire",),
    "traites": ("traire",),
    "trait": ("traire",),
    "traits": ("traire",),
    "trayaient": ("traire",),
    "trayais": ("traire",),
    "trayait": ("traire",),
    "trayant": ("traire",),
    "trayez": ("traire",),
    "trayiez": ("traire",),
    "trayions": ("traire",),
    "trayons": ("traire",),
    "transcrira": ("transcrire",),
    "transcriraient": ("transcrire",),
    "transcrirai": ("transcrire",),
    "transcrirais": ("transcrire",),
    "transcrirait": ("transcrire",),
    "transcriras": ("transcrire",),
    "transcrirez": ("transcrire",),
    "transcririez": ("transcrire",),
    "transcririons": ("transcrire",),
    "transcrirons": ("transcrire",),
    "transcriront": ("transcrire",),
    "transcris": ("transcrire",),
    "transcrite": ("transcrire",),
    "transcrites": ("transcrire",),
    "transcrit": ("transcrire",),
    "transcrits": ("transcrire",),
    "transcrivaient": ("transcrire",),
    "transcrivais": ("transcrire",),
    "transcrivait": ("transcrire",),
    "transcrivant": ("transcrire",),
    "transcrivent": ("transcrire",),
    "transcrive": ("transcrire",),
    "transcrives": ("transcrire",),
    "transcrivez": ("transcrire",),
    "transcriviez": ("transcrire",),
    "transcrivîmes": ("transcrire",),
    "transcrivions": ("transcrire",),
    "transcrivirent": ("transcrire",),
    "transcrivis": ("transcrire",),
    "transcrivissent": ("transcrire",),
    "transcrivisses": ("transcrire",),
    "transcrivisse": ("transcrire",),
    "transcrivissiez": ("transcrire",),
    "transcrivissions": ("transcrire",),
    "transcrivîtes": ("transcrire",),
    "transcrivit": ("transcrire",),
    "transcrivît": ("transcrire",),
    "transcrivons": ("transcrire",),
    "transestérifiaient": ("transestérifier",),
    "transestérifiai": ("transestérifier",),
    "transestérifiais": ("transestérifier",),
    "transestérifiait": ("transestérifier",),
    "transestérifia": ("transestérifier",),
    "transestérifiâmes": ("transestérifier",),
    "transestérifiant": ("transestérifier",),
    "transestérifias": ("transestérifier",),
    "transestérifiassent": ("transestérifier",),
    "transestérifiasses": ("transestérifier",),
    "transestérifiasse": ("transestérifier",),
    "transestérifiassiez": ("transestérifier",),
    "transestérifiassions": ("transestérifier",),
    "transestérifiâtes": ("transestérifier",),
    "transestérifiât": ("transestérifier",),
    "transestérifiée": ("transestérifier",),
    "transestérifiées": ("transestérifier",),
    "transestérifié": ("transestérifier",),
    "transestérifient": ("transestérifier",),
    "transestérifie": ("transestérifier",),
    "transestérifiera": ("transestérifier",),
    "transestérifieraient": ("transestérifier",),
    "transestérifierai": ("transestérifier",),
    "transestérifierais": ("transestérifier",),
    "transestérifierait": ("transestérifier",),
    "transestérifieras": ("transestérifier",),
    "transestérifièrent": ("transestérifier",),
    "transestérifierez": ("transestérifier",),
    "transestérifieriez": ("transestérifier",),
    "transestérifierions": ("transestérifier",),
    "transestérifierons": ("transestérifier",),
    "transestérifieront": ("transestérifier",),
    "transestérifiés": ("transestérifier",),
    "transestérifies": ("transestérifier",),
    "transestérifiez": ("transestérifier",),
    "transestérifiiez": ("transestérifier",),
    "transestérifiions": ("transestérifier",),
    "transestérifions": ("transestérifier",),
    "transféraient": ("transférer",),
    "transférai": ("transférer",),
    "transférais": ("transférer",),
    "transférait": ("transférer",),
    "transféra": ("transférer",),
    "transférâmes": ("transférer",),
    "transférant": ("transférer",),
    "transféras": ("transférer",),
    "transférassent": ("transférer",),
    "transférasses": ("transférer",),
    "transférasse": ("transférer",),
    "transférassiez": ("transférer",),
    "transférassions": ("transférer",),
    "transférâtes": ("transférer",),
    "transférât": ("transférer",),
    "transférée": ("transférer",),
    "transférées": ("transférer",),
    "transféré": ("transférer",),
    "transfèrent": ("transférer",),
    "transfère": ("transférer",),
    "transférera": ("transférer",),
    "transféreraient": ("transférer",),
    "transférerai": ("transférer",),
    "transférerais": ("transférer",),
    "transférerait": ("transférer",),
    "transféreras": ("transférer",),
    "transférèrent": ("transférer",),
    "transférerez": ("transférer",),
    "transféreriez": ("transférer",),
    "transférerions": ("transférer",),
    "transférerons": ("transférer",),
    "transféreront": ("transférer",),
    "transférés": ("transférer",),
    "transfères": ("transférer",),
    "transférez": ("transférer",),
    "transfériez": ("transférer",),
    "transférions": ("transférer",),
    "transférons": ("transférer",),
    "transigeaient": ("transiger",),
    "transigeai": ("transiger",),
    "transigeais": ("transiger",),
    "transigeait": ("transiger",),
    "transigea": ("transiger",),
    "transigeâmes": ("transiger",),
    "transigeant": ("transiger",),
    "transigeas": ("transiger",),
    "transigeassent": ("transiger",),
    "transigeasses": ("transiger",),
    "transigeasse": ("transiger",),
    "transigeassiez": ("transiger",),
    "transigeassions": ("transiger",),
    "transigeâtes": ("transiger",),
    "transigeât": ("transiger",),
    "transigé": ("transiger",),
    "transigent": ("transiger",),
    "transigeons": ("transiger",),
    "transige": ("transiger",),
    "transigera": ("transiger",),
    "transigeraient": ("transiger",),
    "transigerai": ("transiger",),
    "transigerais": ("transiger",),
    "transigerait": ("transiger",),
    "transigeras": ("transiger",),
    "transigèrent": ("transiger",),
    "transigerez": ("transiger",),
    "transigeriez": ("transiger",),
    "transigerions": ("transiger",),
    "transigerons": ("transiger",),
    "transigeront": ("transiger",),
    "transiges": ("transiger",),
    "transigez": ("transiger",),
    "transigiez": ("transiger",),
    "transigions": ("transiger",),
    "transie": ("transir",),
    "transies": ("transir",),
    "transi": ("transir",),
    "transîmes": ("transir",),
    "transira": ("transir",),
    "transiraient": ("transir",),
    "transirai": ("transir",),
    "transirais": ("transir",),
    "transirait": ("transir",),
    "transiras": ("transir",),
    "transirent": ("transir",),
    "transirez": ("transir",),
    "transiriez": ("transir",),
    "transirions": ("transir",),
    "transirons": ("transir",),
    "transiront": ("transir",),
    "transis": ("transir",),
    "transissaient": ("transir",),
    "transissais": ("transir",),
    "transissait": ("transir",),
    "transissant": ("transir",),
    "transissent": ("transir",),
    "transisse": ("transir",),
    "transisses": ("transir",),
    "transissez": ("transir",),
    "transissiez": ("transir",),
    "transissions": ("transir",),
    "transissons": ("transir",),
    "transîtes": ("transir",),
    "transit": ("transir",),
    "transît": ("transir",),
    "translitéraient": ("translitérer",),
    "translitérai": ("translitérer",),
    "translitérais": ("translitérer",),
    "translitérait": ("translitérer",),
    "translitéra": ("translitérer",),
    "translitérâmes": ("translitérer",),
    "translitérant": ("translitérer",),
    "translitéras": ("translitérer",),
    "translitérassent": ("translitérer",),
    "translitérasses": ("translitérer",),
    "translitérasse": ("translitérer",),
    "translitérassiez": ("translitérer",),
    "translitérassions": ("translitérer",),
    "translitérâtes": ("translitérer",),
    "translitérât": ("translitérer",),
    "translitérée": ("translitérer",),
    "translitérées": ("translitérer",),
    "translitéré": ("translitérer",),
    "translitèrent": ("translitérer",),
    "translitère": ("translitérer",),
    "translitérera": ("translitérer",),
    "translitéreraient": ("translitérer",),
    "translitérerai": ("translitérer",),
    "translitérerais": ("translitérer",),
    "translitérerait": ("translitérer",),
    "translitéreras": ("translitérer",),
    "translitérèrent": ("translitérer",),
    "translitérerez": ("translitérer",),
    "translitéreriez": ("translitérer",),
    "translitérerions": ("translitérer",),
    "translitérerons": ("translitérer",),
    "translitéreront": ("translitérer",),
    "translitérés": ("translitérer",),
    "translitères": ("translitérer",),
    "translitérez": ("translitérer",),
    "translitériez": ("translitérer",),
    "translitérions": ("translitérer",),
    "translitérons": ("translitérer",),
    "translittéraient": ("translittérer",),
    "translittérai": ("translittérer",),
    "translittérais": ("translittérer",),
    "translittérait": ("translittérer",),
    "translittéra": ("translittérer",),
    "translittérâmes": ("translittérer",),
    "translittérant": ("translittérer",),
    "translittéras": ("translittérer",),
    "translittérassent": ("translittérer",),
    "translittérasses": ("translittérer",),
    "translittérasse": ("translittérer",),
    "translittérassiez": ("translittérer",),
    "translittérassions": ("translittérer",),
    "translittérâtes": ("translittérer",),
    "translittérât": ("translittérer",),
    "translittérée": ("translittérer",),
    "translittérées": ("translittérer",),
    "translittéré": ("translittérer",),
    "translittèrent": ("translittérer",),
    "translittère": ("translittérer",),
    "translittérera": ("translittérer",),
    "translittéreraient": ("translittérer",),
    "translittérerai": ("translittérer",),
    "translittérerais": ("translittérer",),
    "translittérerait": ("translittérer",),
    "translittéreras": ("translittérer",),
    "translittérèrent": ("translittérer",),
    "translittérerez": ("translittérer",),
    "translittéreriez": ("translittérer",),
    "translittérerions": ("translittérer",),
    "translittérerons": ("translittérer",),
    "translittéreront": ("translittérer",),
    "translittérés": ("translittérer",),
    "translittères": ("translittérer",),
    "translittérez": ("translittérer",),
    "translittériez": ("translittérer",),
    "translittérions": ("translittérer",),
    "translittérons": ("translittérer",),
    "transmet": ("transmettre",),
    "transmets": ("transmettre",),
    "transmettaient": ("transmettre",),
    "transmettais": ("transmettre",),
    "transmettait": ("transmettre",),
    "transmettant": ("transmettre",),
    "transmettent": ("transmettre",),
    "transmette": ("transmettre",),
    "transmettes": ("transmettre",),
    "transmettez": ("transmettre",),
    "transmettiez": ("transmettre",),
    "transmettions": ("transmettre",),
    "transmettons": ("transmettre",),
    "transmettra": ("transmettre",),
    "transmettraient": ("transmettre",),
    "transmettrai": ("transmettre",),
    "transmettrais": ("transmettre",),
    "transmettrait": ("transmettre",),
    "transmettras": ("transmettre",),
    "transmettrez": ("transmettre",),
    "transmettriez": ("transmettre",),
    "transmettrions": ("transmettre",),
    "transmettrons": ("transmettre",),
    "transmettront": ("transmettre",),
    "transmîmes": ("transmettre",),
    "transmirent": ("transmettre",),
    "transmise": ("transmettre",),
    "transmises": ("transmettre",),
    "transmis": ("transmettre",),
    "transmissent": ("transmettre",),
    "transmisses": ("transmettre",),
    "transmisse": ("transmettre",),
    "transmissiez": ("transmettre",),
    "transmissions": ("transmettre",),
    "transmîtes": ("transmettre",),
    "transmit": ("transmettre",),
    "transmît": ("transmettre",),
    "transparais": ("transparaître",),
    "transparaissaient": ("transparaître",),
    "transparaissais": ("transparaître",),
    "transparaissait": ("transparaître",),
    "transparaissant": ("transparaître",),
    "transparaissent": ("transparaître",),
    "transparaisse": ("transparaître",),
    "transparaisses": ("transparaître",),
    "transparaissez": ("transparaître",),
    "transparaissiez": ("transparaître",),
    "transparaissions": ("transparaître",),
    "transparaissons": ("transparaître",),
    "transparaît": ("transparaître",),
    "transparaîtra": ("transparaître",),
    "transparaîtraient": ("transparaître",),
    "transparaîtrai": ("transparaître",),
    "transparaîtrais": ("transparaître",),
    "transparaîtrait": ("transparaître",),
    "transparaîtras": ("transparaître",),
    "transparaîtrez": ("transparaître",),
    "transparaîtriez": ("transparaître",),
    "transparaîtrions": ("transparaître",),
    "transparaîtrons": ("transparaître",),
    "transparaîtront": ("transparaître",),
    "transparu": ("transparaître",),
    "transparûmes": ("transparaître",),
    "transparurent": ("transparaître",),
    "transparus": ("transparaître",),
    "transparussent": ("transparaître",),
    "transparusses": ("transparaître",),
    "transparusse": ("transparaître",),
    "transparussiez": ("transparaître",),
    "transparussions": ("transparaître",),
    "transparûtes": ("transparaître",),
    "transparut": ("transparaître",),
    "transparût": ("transparaître",),
    "transpénétraient": ("transpénétrer",),
    "transpénétrai": ("transpénétrer",),
    "transpénétrais": ("transpénétrer",),
    "transpénétrait": ("transpénétrer",),
    "transpénétra": ("transpénétrer",),
    "transpénétrâmes": ("transpénétrer",),
    "transpénétrant": ("transpénétrer",),
    "transpénétras": ("transpénétrer",),
    "transpénétrassent": ("transpénétrer",),
    "transpénétrasses": ("transpénétrer",),
    "transpénétrasse": ("transpénétrer",),
    "transpénétrassiez": ("transpénétrer",),
    "transpénétrassions": ("transpénétrer",),
    "transpénétrâtes": ("transpénétrer",),
    "transpénétrât": ("transpénétrer",),
    "transpénétrée": ("transpénétrer",),
    "transpénétrées": ("transpénétrer",),
    "transpénétré": ("transpénétrer",),
    "transpénètrent": ("transpénétrer",),
    "transpénètre": ("transpénétrer",),
    "transpénétrera": ("transpénétrer",),
    "transpénétreraient": ("transpénétrer",),
    "transpénétrerai": ("transpénétrer",),
    "transpénétrerais": ("transpénétrer",),
    "transpénétrerait": ("transpénétrer",),
    "transpénétreras": ("transpénétrer",),
    "transpénétrèrent": ("transpénétrer",),
    "transpénétrerez": ("transpénétrer",),
    "transpénétreriez": ("transpénétrer",),
    "transpénétrerions": ("transpénétrer",),
    "transpénétrerons": ("transpénétrer",),
    "transpénétreront": ("transpénétrer",),
    "transpénétrés": ("transpénétrer",),
    "transpénètres": ("transpénétrer",),
    "transpénétrez": ("transpénétrer",),
    "transpénétriez": ("transpénétrer",),
    "transpénétrions": ("transpénétrer",),
    "transpénétrons": ("transpénétrer",),
    "transperçaient": ("transpercer",),
    "transperçai": ("transpercer",),
    "transperçais": ("transpercer",),
    "transperçait": ("transpercer",),
    "transperça": ("transpercer",),
    "transperçâmes": ("transpercer",),
    "transperçant": ("transpercer",),
    "transperças": ("transpercer",),
    "transperçassent": ("transpercer",),
    "transperçasses": ("transpercer",),
    "transperçasse": ("transpercer",),
    "transperçassiez": ("transpercer",),
    "transperçassions": ("transpercer",),
    "transperçâtes": ("transpercer",),
    "transperçât": ("transpercer",),
    "transpercée": ("transpercer",),
    "transpercées": ("transpercer",),
    "transpercé": ("transpercer",),
    "transpercent": ("transpercer",),
    "transperce": ("transpercer",),
    "transpercera": ("transpercer",),
    "transperceraient": ("transpercer",),
    "transpercerai": ("transpercer",),
    "transpercerais": ("transpercer",),
    "transpercerait": ("transpercer",),
    "transperceras": ("transpercer",),
    "transpercèrent": ("transpercer",),
    "transpercerez": ("transpercer",),
    "transperceriez": ("transpercer",),
    "transpercerions": ("transpercer",),
    "transpercerons": ("transpercer",),
    "transperceront": ("transpercer",),
    "transpercés": ("transpercer",),
    "transperces": ("transpercer",),
    "transpercez": ("transpercer",),
    "transperciez": ("transpercer",),
    "transpercions": ("transpercer",),
    "transperçons": ("transpercer",),
    "transsubstantiaient": ("transsubstantier",),
    "transsubstantiai": ("transsubstantier",),
    "transsubstantiais": ("transsubstantier",),
    "transsubstantiait": ("transsubstantier",),
    "transsubstantia": ("transsubstantier",),
    "transsubstantiâmes": ("transsubstantier",),
    "transsubstantiant": ("transsubstantier",),
    "transsubstantias": ("transsubstantier",),
    "transsubstantiassent": ("transsubstantier",),
    "transsubstantiasses": ("transsubstantier",),
    "transsubstantiasse": ("transsubstantier",),
    "transsubstantiassiez": ("transsubstantier",),
    "transsubstantiassions": ("transsubstantier",),
    "transsubstantiâtes": ("transsubstantier",),
    "transsubstantiât": ("transsubstantier",),
    "transsubstantiée": ("transsubstantier",),
    "transsubstantiées": ("transsubstantier",),
    "transsubstantié": ("transsubstantier",),
    "transsubstantient": ("transsubstantier",),
    "transsubstantie": ("transsubstantier",),
    "transsubstantiera": ("transsubstantier",),
    "transsubstantieraient": ("transsubstantier",),
    "transsubstantierai": ("transsubstantier",),
    "transsubstantierais": ("transsubstantier",),
    "transsubstantierait": ("transsubstantier",),
    "transsubstantieras": ("transsubstantier",),
    "transsubstantièrent": ("transsubstantier",),
    "transsubstantierez": ("transsubstantier",),
    "transsubstantieriez": ("transsubstantier",),
    "transsubstantierions": ("transsubstantier",),
    "transsubstantierons": ("transsubstantier",),
    "transsubstantieront": ("transsubstantier",),
    "transsubstantiés": ("transsubstantier",),
    "transsubstanties": ("transsubstantier",),
    "transsubstantiez": ("transsubstantier",),
    "transsubstantiiez": ("transsubstantier",),
    "transsubstantiions": ("transsubstantier",),
    "transsubstantions": ("transsubstantier",),
    "transverbéraient": ("transverbérer",),
    "transverbérai": ("transverbérer",),
    "transverbérais": ("transverbérer",),
    "transverbérait": ("transverbérer",),
    "transverbéra": ("transverbérer",),
    "transverbérâmes": ("transverbérer",),
    "transverbérant": ("transverbérer",),
    "transverbéras": ("transverbérer",),
    "transverbérassent": ("transverbérer",),
    "transverbérasses": ("transverbérer",),
    "transverbérasse": ("transverbérer",),
    "transverbérassiez": ("transverbérer",),
    "transverbérassions": ("transverbérer",),
    "transverbérâtes": ("transverbérer",),
    "transverbérât": ("transverbérer",),
    "transverbérée": ("transverbérer",),
    "transverbérées": ("transverbérer",),
    "transverbéré": ("transverbérer",),
    "transverbèrent": ("transverbérer",),
    "transverbère": ("transverbérer",),
    "transverbérera": ("transverbérer",),
    "transverbéreraient": ("transverbérer",),
    "transverbérerai": ("transverbérer",),
    "transverbérerais": ("transverbérer",),
    "transverbérerait": ("transverbérer",),
    "transverbéreras": ("transverbérer",),
    "transverbérèrent": ("transverbérer",),
    "transverbérerez": ("transverbérer",),
    "transverbéreriez": ("transverbérer",),
    "transverbérerions": ("transverbérer",),
    "transverbérerons": ("transverbérer",),
    "transverbéreront": ("transverbérer",),
    "transverbérés": ("transverbérer",),
    "transverbères": ("transverbérer",),
    "transverbérez": ("transverbérer",),
    "transverbériez": ("transverbérer",),
    "transverbérions": ("transverbérer",),
    "transverbérons": ("transverbérer",),
    "travestie": ("travestir",),
    "travesties": ("travestir",),
    "travesti": ("travestir",),
    "travestîmes": ("travestir",),
    "travestira": ("travestir",),
    "travestiraient": ("travestir",),
    "travestirai": ("travestir",),
    "travestirais": ("travestir",),
    "travestirait": ("travestir",),
    "travestiras": ("travestir",),
    "travestirent": ("travestir",),
    "travestirez": ("travestir",),
    "travestiriez": ("travestir",),
    "travestirions": ("travestir",),
    "travestirons": ("travestir",),
    "travestiront": ("travestir",),
    "travestis": ("travestir",),
    "travestissaient": ("travestir",),
    "travestissais": ("travestir",),
    "travestissait": ("travestir",),
    "travestissant": ("travestir",),
    "travestissent": ("travestir",),
    "travestisse": ("travestir",),
    "travestisses": ("travestir",),
    "travestissez": ("travestir",),
    "travestissiez": ("travestir",),
    "travestissions": ("travestir",),
    "travestissons": ("travestir",),
    "travestîtes": ("travestir",),
    "travestit": ("travestir",),
    "travestît": ("travestir",),
    "tréflaient": ("tréfler",),
    "tréflai": ("tréfler",),
    "tréflais": ("tréfler",),
    "tréflait": ("tréfler",),
    "tréfla": ("tréfler",),
    "tréflâmes": ("tréfler",),
    "tréflant": ("tréfler",),
    "tréflas": ("tréfler",),
    "tréflassent": ("tréfler",),
    "tréflasses": ("tréfler",),
    "tréflasse": ("tréfler",),
    "tréflassiez": ("tréfler",),
    "tréflassions": ("tréfler",),
    "tréflâtes": ("tréfler",),
    "tréflât": ("tréfler",),
    "tréflée": ("tréfler",),
    "tréflées": ("tréfler",),
    "tréflé": ("tréfler",),
    "trèflent": ("tréfler",),
    "trèfle": ("tréfler",),
    "tréflera": ("tréfler",),
    "tréfleraient": ("tréfler",),
    "tréflerai": ("tréfler",),
    "tréflerais": ("tréfler",),
    "tréflerait": ("tréfler",),
    "tréfleras": ("tréfler",),
    "tréflèrent": ("tréfler",),
    "tréflerez": ("tréfler",),
    "tréfleriez": ("tréfler",),
    "tréflerions": ("tréfler",),
    "tréflerons": ("tréfler",),
    "tréfleront": ("tréfler",),
    "tréflés": ("tréfler",),
    "trèfles": ("tréfler",),
    "tréflez": ("tréfler",),
    "tréfliez": ("tréfler",),
    "tréflions": ("tréfler",),
    "tréflons": ("tréfler",),
    "tréfondaient": ("tréfondre",),
    "tréfondais": ("tréfondre",),
    "tréfondait": ("tréfondre",),
    "tréfondant": ("tréfondre",),
    "tréfondent": ("tréfondre",),
    "tréfonde": ("tréfondre",),
    "tréfondes": ("tréfondre",),
    "tréfondez": ("tréfondre",),
    "tréfondiez": ("tréfondre",),
    "tréfondîmes": ("tréfondre",),
    "tréfondions": ("tréfondre",),
    "tréfondirent": ("tréfondre",),
    "tréfondis": ("tréfondre",),
    "tréfondissent": ("tréfondre",),
    "tréfondisses": ("tréfondre",),
    "tréfondisse": ("tréfondre",),
    "tréfondissiez": ("tréfondre",),
    "tréfondissions": ("tréfondre",),
    "tréfondîtes": ("tréfondre",),
    "tréfondit": ("tréfondre",),
    "tréfondît": ("tréfondre",),
    "tréfondons": ("tréfondre",),
    "tréfond": ("tréfondre",),
    "tréfondra": ("tréfondre",),
    "tréfondraient": ("tréfondre",),
    "tréfondrai": ("tréfondre",),
    "tréfondrais": ("tréfondre",),
    "tréfondrait": ("tréfondre",),
    "tréfondras": ("tréfondre",),
    "tréfondrez": ("tréfondre",),
    "tréfondriez": ("tréfondre",),
    "tréfondrions": ("tréfondre",),
    "tréfondrons": ("tréfondre",),
    "tréfondront": ("tréfondre",),
    "tréfonds": ("tréfondre",),
    "tréfondue": ("tréfondre",),
    "tréfondues": ("tréfondre",),
    "tréfondu": ("tréfondre",),
    "tréfondus": ("tréfondre",),
    "treillageaient": ("treillager",),
    "treillageai": ("treillager",),
    "treillageais": ("treillager",),
    "treillageait": ("treillager",),
    "treillagea": ("treillager",),
    "treillageâmes": ("treillager",),
    "treillageant": ("treillager",),
    "treillageas": ("treillager",),
    "treillageassent": ("treillager",),
    "treillageasses": ("treillager",),
    "treillageasse": ("treillager",),
    "treillageassiez": ("treillager",),
    "treillageassions": ("treillager",),
    "treillageâtes": ("treillager",),
    "treillageât": ("treillager",),
    "treillagée": ("treillager",),
    "treillagées": ("treillager",),
    "treillagé": ("treillager",),
    "treillagent": ("treillager",),
    "treillageons": ("treillager",),
    "treillage": ("treillager",),
    "treillagera": ("treillager",),
    "treillageraient": ("treillager",),
    "treillagerai": ("treillager",),
    "treillagerais": ("treillager",),
    "treillagerait": ("treillager",),
    "treillageras": ("treillager",),
    "treillagèrent": ("treillager",),
    "treillagerez": ("treillager",),
    "treillageriez": ("treillager",),
    "treillagerions": ("treillager",),
    "treillagerons": ("treillager",),
    "treillageront": ("treillager",),
    "treillagés": ("treillager",),
    "treillages": ("treillager",),
    "treillagez": ("treillager",),
    "treillagiez": ("treillager",),
    "treillagions": ("treillager",),
    "tréjetaient": ("tréjeter",),
    "tréjetai": ("tréjeter",),
    "tréjetais": ("tréjeter",),
    "tréjetait": ("tréjeter",),
    "tréjeta": ("tréjeter",),
    "tréjetâmes": ("tréjeter",),
    "tréjetant": ("tréjeter",),
    "tréjetas": ("tréjeter",),
    "tréjetassent": ("tréjeter",),
    "tréjetasses": ("tréjeter",),
    "tréjetasse": ("tréjeter",),
    "tréjetassiez": ("tréjeter",),
    "tréjetassions": ("tréjeter",),
    "tréjetâtes": ("tréjeter",),
    "tréjetât": ("tréjeter",),
    "tréjetée": ("tréjeter",),
    "tréjetées": ("tréjeter",),
    "tréjeté": ("tréjeter",),
    "tréjetèrent": ("tréjeter",),
    "tréjetés": ("tréjeter",),
    "tréjetez": ("tréjeter",),
    "tréjetiez": ("tréjeter",),
    "tréjetions": ("tréjeter",),
    "tréjetons": ("tréjeter",),
    "tréjettent": ("tréjeter",),
    "tréjette": ("tréjeter",),
    "tréjettera": ("tréjeter",),
    "tréjetteraient": ("tréjeter",),
    "tréjetterai": ("tréjeter",),
    "tréjetterais": ("tréjeter",),
    "tréjetterait": ("tréjeter",),
    "tréjetteras": ("tréjeter",),
    "tréjetterez": ("tréjeter",),
    "tréjetteriez": ("tréjeter",),
    "tréjetterions": ("tréjeter",),
    "tréjetterons": ("tréjeter",),
    "tréjetteront": ("tréjeter",),
    "tréjettes": ("tréjeter",),
    "trépassaient": ("trépasser",),
    "trépassai": ("trépasser",),
    "trépassais": ("trépasser",),
    "trépassait": ("trépasser",),
    "trépassa": ("trépasser",),
    "trépassâmes": ("trépasser",),
    "trépassant": ("trépasser",),
    "trépassas": ("trépasser",),
    "trépassassent": ("trépasser",),
    "trépassasses": ("trépasser",),
    "trépassasse": ("trépasser",),
    "trépassassiez": ("trépasser",),
    "trépassassions": ("trépasser",),
    "trépassâtes": ("trépasser",),
    "trépassât": ("trépasser",),
    "trépassé": ("trépasser",),
    "trépassent": ("trépasser",),
    "trépasse": ("trépasser",),
    "trépassera": ("trépasser",),
    "trépasseraient": ("trépasser",),
    "trépasserai": ("trépasser",),
    "trépasserais": ("trépasser",),
    "trépasserait": ("trépasser",),
    "trépasseras": ("trépasser",),
    "trépassèrent": ("trépasser",),
    "trépasserez": ("trépasser",),
    "trépasseriez": ("trépasser",),
    "trépasserions": ("trépasser",),
    "trépasserons": ("trépasser",),
    "trépasseront": ("trépasser",),
    "trépasses": ("trépasser",),
    "trépassez": ("trépasser",),
    "trépassiez": ("trépasser",),
    "trépassions": ("trépasser",),
    "trépassons": ("trépasser",),
    "tressaillaient": ("tressaillir",),
    "tressaillais": ("tressaillir",),
    "tressaillait": ("tressaillir",),
    "tressaillant": ("tressaillir",),
    "tressaillent": ("tressaillir",),
    "tressaille": ("tressaillir",),
    "tressaillera": ("tressaillir",),
    "tressailleraient": ("tressaillir",),
    "tressaillerai": ("tressaillir",),
    "tressaillerais": ("tressaillir",),
    "tressaillerait": ("tressaillir",),
    "tressailleras": ("tressaillir",),
    "tressaillerez": ("tressaillir",),
    "tressailleriez": ("tressaillir",),
    "tressaillerions": ("tressaillir",),
    "tressaillerons": ("tressaillir",),
    "tressailleront": ("tressaillir",),
    "tressailles": ("tressaillir",),
    "tressaillez": ("tressaillir",),
    "tressailliez": ("tressaillir",),
    "tressailli": ("tressaillir",),
    "tressaillîmes": ("tressaillir",),
    "tressaillions": ("tressaillir",),
    "tressaillira": ("tressaillir",),
    "tressailliraient": ("tressaillir",),
    "tressaillirai": ("tressaillir",),
    "tressaillirais": ("tressaillir",),
    "tressaillirait": ("tressaillir",),
    "tressailliras": ("tressaillir",),
    "tressaillirent": ("tressaillir",),
    "tressaillirez": ("tressaillir",),
    "tressailliriez": ("tressaillir",),
    "tressaillirions": ("tressaillir",),
    "tressaillirons": ("tressaillir",),
    "tressailliront": ("tressaillir",),
    "tressaillis": ("tressaillir",),
    "tressaillissent": ("tressaillir",),
    "tressaillisses": ("tressaillir",),
    "tressaillisse": ("tressaillir",),
    "tressaillissiez": ("tressaillir",),
    "tressaillissions": ("tressaillir",),
    "tressaillîtes": ("tressaillir",),
    "tressaillit": ("tressaillir",),
    "tressaillît": ("tressaillir",),
    "tressaillons": ("tressaillir",),
    "triaient": ("trier",),
    "triai": ("trier",),
    "triais": ("trier",),
    "triait": ("trier",),
    "tria": ("trier",),
    "triâmes": ("trier",),
    "triant": ("trier",),
    "trias": ("trier",),
    "triassent": ("trier",),
    "triasses": ("trier",),
    "triasse": ("trier",),
    "triassiez": ("trier",),
    "triassions": ("trier",),
    "triâtes": ("trier",),
    "triât": ("trier",),
    "triée": ("trier",),
    "triées": ("trier",),
    "trié": ("trier",),
    "trient": ("trier",),
    "trie": ("trier",),
    "triera": ("trier",),
    "trieraient": ("trier",),
    "trierai": ("trier",),
    "trierais": ("trier",),
    "trierait": ("trier",),
    "trieras": ("trier",),
    "trièrent": ("trier",),
    "trierez": ("trier",),
    "trieriez": ("trier",),
    "trierions": ("trier",),
    "trierons": ("trier",),
    "trieront": ("trier",),
    "triés": ("trier",),
    "tries": ("trier",),
    "triez": ("trier",),
    "triiez": ("trier",),
    "triions": ("trier",),
    "trions": ("trier",),
    "trihalogénaient": ("trihalogéner",),
    "trihalogénai": ("trihalogéner",),
    "trihalogénais": ("trihalogéner",),
    "trihalogénait": ("trihalogéner",),
    "trihalogéna": ("trihalogéner",),
    "trihalogénâmes": ("trihalogéner",),
    "trihalogénant": ("trihalogéner",),
    "trihalogénas": ("trihalogéner",),
    "trihalogénassent": ("trihalogéner",),
    "trihalogénasses": ("trihalogéner",),
    "trihalogénasse": ("trihalogéner",),
    "trihalogénassiez": ("trihalogéner",),
    "trihalogénassions": ("trihalogéner",),
    "trihalogénâtes": ("trihalogéner",),
    "trihalogénât": ("trihalogéner",),
    "trihalogénée": ("trihalogéner",),
    "trihalogénées": ("trihalogéner",),
    "trihalogéné": ("trihalogéner",),
    "trihalogènent": ("trihalogéner",),
    "trihalogène": ("trihalogéner",),
    "trihalogénera": ("trihalogéner",),
    "trihalogéneraient": ("trihalogéner",),
    "trihalogénerai": ("trihalogéner",),
    "trihalogénerais": ("trihalogéner",),
    "trihalogénerait": ("trihalogéner",),
    "trihalogéneras": ("trihalogéner",),
    "trihalogénèrent": ("trihalogéner",),
    "trihalogénerez": ("trihalogéner",),
    "trihalogéneriez": ("trihalogéner",),
    "trihalogénerions": ("trihalogéner",),
    "trihalogénerons": ("trihalogéner",),
    "trihalogéneront": ("trihalogéner",),
    "trihalogénés": ("trihalogéner",),
    "trihalogènes": ("trihalogéner",),
    "trihalogénez": ("trihalogéner",),
    "trihalogéniez": ("trihalogéner",),
    "trihalogénions": ("trihalogéner",),
    "trihalogénons": ("trihalogéner",),
    "tripletaient": ("tripleter",),
    "tripletai": ("tripleter",),
    "tripletais": ("tripleter",),
    "tripletait": ("tripleter",),
    "tripleta": ("tripleter",),
    "tripletâmes": ("tripleter",),
    "tripletant": ("tripleter",),
    "tripletas": ("tripleter",),
    "tripletassent": ("tripleter",),
    "tripletasses": ("tripleter",),
    "tripletasse": ("tripleter",),
    "tripletassiez": ("tripleter",),
    "tripletassions": ("tripleter",),
    "tripletâtes": ("tripleter",),
    "tripletât": ("tripleter",),
    "tripletée": ("tripleter",),
    "tripletées": ("tripleter",),
    "tripleté": ("tripleter",),
    "tripletèrent": ("tripleter",),
    "tripletés": ("tripleter",),
    "tripletez": ("tripleter",),
    "tripletiez": ("tripleter",),
    "tripletions": ("tripleter",),
    "tripletons": ("tripleter",),
    "triplettent": ("tripleter",),
    "triplette": ("tripleter",),
    "triplettera": ("tripleter",),
    "tripletteraient": ("tripleter",),
    "tripletterai": ("tripleter",),
    "tripletterais": ("tripleter",),
    "tripletterait": ("tripleter",),
    "tripletteras": ("tripleter",),
    "tripletterez": ("tripleter",),
    "tripletteriez": ("tripleter",),
    "tripletterions": ("tripleter",),
    "tripletterons": ("tripleter",),
    "tripletteront": ("tripleter",),
    "triplettes": ("tripleter",),
    "tripolie": ("tripolir",),
    "tripolies": ("tripolir",),
    "tripoli": ("tripolir",),
    "tripolîmes": ("tripolir",),
    "tripolira": ("tripolir",),
    "tripoliraient": ("tripolir",),
    "tripolirai": ("tripolir",),
    "tripolirais": ("tripolir",),
    "tripolirait": ("tripolir",),
    "tripoliras": ("tripolir",),
    "tripolirent": ("tripolir",),
    "tripolirez": ("tripolir",),
    "tripoliriez": ("tripolir",),
    "tripolirions": ("tripolir",),
    "tripolirons": ("tripolir",),
    "tripoliront": ("tripolir",),
    "tripolis": ("tripolir",),
    "tripolissaient": ("tripolir",),
    "tripolissais": ("tripolir",),
    "tripolissait": ("tripolir",),
    "tripolissant": ("tripolir",),
    "tripolissent": ("tripolir",),
    "tripolisse": ("tripolir",),
    "tripolisses": ("tripolir",),
    "tripolissez": ("tripolir",),
    "tripolissiez": ("tripolir",),
    "tripolissions": ("tripolir",),
    "tripolissons": ("tripolir",),
    "tripolîtes": ("tripolir",),
    "tripolit": ("tripolir",),
    "tripolît": ("tripolir",),
    "triséquaient": ("triséquer",),
    "triséquai": ("triséquer",),
    "triséquais": ("triséquer",),
    "triséquait": ("triséquer",),
    "triséqua": ("triséquer",),
    "triséquâmes": ("triséquer",),
    "triséquant": ("triséquer",),
    "triséquas": ("triséquer",),
    "triséquassent": ("triséquer",),
    "triséquasses": ("triséquer",),
    "triséquasse": ("triséquer",),
    "triséquassiez": ("triséquer",),
    "triséquassions": ("triséquer",),
    "triséquâtes": ("triséquer",),
    "triséquât": ("triséquer",),
    "triséquée": ("triséquer",),
    "triséquées": ("triséquer",),
    "triséqué": ("triséquer",),
    "trisèquent": ("triséquer",),
    "trisèque": ("triséquer",),
    "triséquera": ("triséquer",),
    "triséqueraient": ("triséquer",),
    "triséquerai": ("triséquer",),
    "triséquerais": ("triséquer",),
    "triséquerait": ("triséquer",),
    "triséqueras": ("triséquer",),
    "triséquèrent": ("triséquer",),
    "triséquerez": ("triséquer",),
    "triséqueriez": ("triséquer",),
    "triséquerions": ("triséquer",),
    "triséquerons": ("triséquer",),
    "triséqueront": ("triséquer",),
    "triséqués": ("triséquer",),
    "trisèques": ("triséquer",),
    "triséquez": ("triséquer",),
    "triséquiez": ("triséquer",),
    "triséquions": ("triséquer",),
    "triséquons": ("triséquer",),
    "trompetaient": ("trompeter",),
    "trompetai": ("trompeter",),
    "trompetais": ("trompeter",),
    "trompetait": ("trompeter",),
    "trompeta": ("trompeter",),
    "trompetâmes": ("trompeter",),
    "trompetant": ("trompeter",),
    "trompetas": ("trompeter",),
    "trompetassent": ("trompeter",),
    "trompetasses": ("trompeter",),
    "trompetasse": ("trompeter",),
    "trompetassiez": ("trompeter",),
    "trompetassions": ("trompeter",),
    "trompetâtes": ("trompeter",),
    "trompetât": ("trompeter",),
    "trompetée": ("trompeter",),
    "trompetées": ("trompeter",),
    "trompeté": ("trompeter",),
    "trompetèrent": ("trompeter",),
    "trompetés": ("trompeter",),
    "trompetez": ("trompeter",),
    "trompetiez": ("trompeter",),
    "trompetions": ("trompeter",),
    "trompetons": ("trompeter",),
    "trompettent": ("trompeter",),
    "trompette": ("trompeter",),
    "trompettera": ("trompeter",),
    "trompetteraient": ("trompeter",),
    "trompetterai": ("trompeter",),
    "trompetterais": ("trompeter",),
    "trompetterait": ("trompeter",),
    "trompetteras": ("trompeter",),
    "trompetterez": ("trompeter",),
    "trompetteriez": ("trompeter",),
    "trompetterions": ("trompeter",),
    "trompetterons": ("trompeter",),
    "trompetteront": ("trompeter",),
    "trompettes": ("trompeter",),
    "tubérifiaient": ("tubérifier",),
    "tubérifiai": ("tubérifier",),
    "tubérifiais": ("tubérifier",),
    "tubérifiait": ("tubérifier",),
    "tubérifia": ("tubérifier",),
    "tubérifiâmes": ("tubérifier",),
    "tubérifiant": ("tubérifier",),
    "tubérifias": ("tubérifier",),
    "tubérifiassent": ("tubérifier",),
    "tubérifiasses": ("tubérifier",),
    "tubérifiasse": ("tubérifier",),
    "tubérifiassiez": ("tubérifier",),
    "tubérifiassions": ("tubérifier",),
    "tubérifiâtes": ("tubérifier",),
    "tubérifiât": ("tubérifier",),
    "tubérifiée": ("tubérifier",),
    "tubérifiées": ("tubérifier",),
    "tubérifié": ("tubérifier",),
    "tubérifient": ("tubérifier",),
    "tubérifie": ("tubérifier",),
    "tubérifiera": ("tubérifier",),
    "tubérifieraient": ("tubérifier",),
    "tubérifierai": ("tubérifier",),
    "tubérifierais": ("tubérifier",),
    "tubérifierait": ("tubérifier",),
    "tubérifieras": ("tubérifier",),
    "tubérifièrent": ("tubérifier",),
    "tubérifierez": ("tubérifier",),
    "tubérifieriez": ("tubérifier",),
    "tubérifierions": ("tubérifier",),
    "tubérifierons": ("tubérifier",),
    "tubérifieront": ("tubérifier",),
    "tubérifiés": ("tubérifier",),
    "tubérifies": ("tubérifier",),
    "tubérifiez": ("tubérifier",),
    "tubérifiiez": ("tubérifier",),
    "tubérifiions": ("tubérifier",),
    "tubérifions": ("tubérifier",),
    "tuméfiaient": ("tuméfier",),
    "tuméfiai": ("tuméfier",),
    "tuméfiais": ("tuméfier",),
    "tuméfiait": ("tuméfier",),
    "tuméfia": ("tuméfier",),
    "tuméfiâmes": ("tuméfier",),
    "tuméfiant": ("tuméfier",),
    "tuméfias": ("tuméfier",),
    "tuméfiassent": ("tuméfier",),
    "tuméfiasses": ("tuméfier",),
    "tuméfiasse": ("tuméfier",),
    "tuméfiassiez": ("tuméfier",),
    "tuméfiassions": ("tuméfier",),
    "tuméfiâtes": ("tuméfier",),
    "tuméfiât": ("tuméfier",),
    "tuméfiée": ("tuméfier",),
    "tuméfiées": ("tuméfier",),
    "tuméfié": ("tuméfier",),
    "tuméfient": ("tuméfier",),
    "tuméfie": ("tuméfier",),
    "tuméfiera": ("tuméfier",),
    "tuméfieraient": ("tuméfier",),
    "tuméfierai": ("tuméfier",),
    "tuméfierais": ("tuméfier",),
    "tuméfierait": ("tuméfier",),
    "tuméfieras": ("tuméfier",),
    "tuméfièrent": ("tuméfier",),
    "tuméfierez": ("tuméfier",),
    "tuméfieriez": ("tuméfier",),
    "tuméfierions": ("tuméfier",),
    "tuméfierons": ("tuméfier",),
    "tuméfieront": ("tuméfier",),
    "tuméfiés": ("tuméfier",),
    "tuméfies": ("tuméfier",),
    "tuméfiez": ("tuméfier",),
    "tuméfiiez": ("tuméfier",),
    "tuméfiions": ("tuméfier",),
    "tuméfions": ("tuméfier",),
    "turquifiaient": ("turquifier",),
    "turquifiai": ("turquifier",),
    "turquifiais": ("turquifier",),
    "turquifiait": ("turquifier",),
    "turquifia": ("turquifier",),
    "turquifiâmes": ("turquifier",),
    "turquifiant": ("turquifier",),
    "turquifias": ("turquifier",),
    "turquifiassent": ("turquifier",),
    "turquifiasses": ("turquifier",),
    "turquifiasse": ("turquifier",),
    "turquifiassiez": ("turquifier",),
    "turquifiassions": ("turquifier",),
    "turquifiâtes": ("turquifier",),
    "turquifiât": ("turquifier",),
    "turquifiée": ("turquifier",),
    "turquifiées": ("turquifier",),
    "turquifié": ("turquifier",),
    "turquifient": ("turquifier",),
    "turquifie": ("turquifier",),
    "turquifiera": ("turquifier",),
    "turquifieraient": ("turquifier",),
    "turquifierai": ("turquifier",),
    "turquifierais": ("turquifier",),
    "turquifierait": ("turquifier",),
    "turquifieras": ("turquifier",),
    "turquifièrent": ("turquifier",),
    "turquifierez": ("turquifier",),
    "turquifieriez": ("turquifier",),
    "turquifierions": ("turquifier",),
    "turquifierons": ("turquifier",),
    "turquifieront": ("turquifier",),
    "turquifiés": ("turquifier",),
    "turquifies": ("turquifier",),
    "turquifiez": ("turquifier",),
    "turquifiiez": ("turquifier",),
    "turquifiions": ("turquifier",),
    "turquifions": ("turquifier",),
    "tutoient": ("tutoyer",),
    "tutoie": ("tutoyer",),
    "tutoiera": ("tutoyer",),
    "tutoieraient": ("tutoyer",),
    "tutoierai": ("tutoyer",),
    "tutoierais": ("tutoyer",),
    "tutoierait": ("tutoyer",),
    "tutoieras": ("tutoyer",),
    "tutoierez": ("tutoyer",),
    "tutoieriez": ("tutoyer",),
    "tutoierions": ("tutoyer",),
    "tutoierons": ("tutoyer",),
    "tutoieront": ("tutoyer",),
    "tutoies": ("tutoyer",),
    "tutoyaient": ("tutoyer",),
    "tutoyai": ("tutoyer",),
    "tutoyais": ("tutoyer",),
    "tutoyait": ("tutoyer",),
    "tutoya": ("tutoyer",),
    "tutoyâmes": ("tutoyer",),
    "tutoyant": ("tutoyer",),
    "tutoyas": ("tutoyer",),
    "tutoyassent": ("tutoyer",),
    "tutoyasses": ("tutoyer",),
    "tutoyasse": ("tutoyer",),
    "tutoyassiez": ("tutoyer",),
    "tutoyassions": ("tutoyer",),
    "tutoyâtes": ("tutoyer",),
    "tutoyât": ("tutoyer",),
    "tutoyée": ("tutoyer",),
    "tutoyées": ("tutoyer",),
    "tutoyé": ("tutoyer",),
    "tutoyèrent": ("tutoyer",),
    "tutoyés": ("tutoyer",),
    "tutoyez": ("tutoyer",),
    "tutoyiez": ("tutoyer",),
    "tutoyions": ("tutoyer",),
    "tutoyons": ("tutoyer",),
    "typifiaient": ("typifier",),
    "typifiai": ("typifier",),
    "typifiais": ("typifier",),
    "typifiait": ("typifier",),
    "typifia": ("typifier",),
    "typifiâmes": ("typifier",),
    "typifiant": ("typifier",),
    "typifias": ("typifier",),
    "typifiassent": ("typifier",),
    "typifiasses": ("typifier",),
    "typifiasse": ("typifier",),
    "typifiassiez": ("typifier",),
    "typifiassions": ("typifier",),
    "typifiâtes": ("typifier",),
    "typifiât": ("typifier",),
    "typifiée": ("typifier",),
    "typifiées": ("typifier",),
    "typifié": ("typifier",),
    "typifient": ("typifier",),
    "typifie": ("typifier",),
    "typifiera": ("typifier",),
    "typifieraient": ("typifier",),
    "typifierai": ("typifier",),
    "typifierais": ("typifier",),
    "typifierait": ("typifier",),
    "typifieras": ("typifier",),
    "typifièrent": ("typifier",),
    "typifierez": ("typifier",),
    "typifieriez": ("typifier",),
    "typifierions": ("typifier",),
    "typifierons": ("typifier",),
    "typifieront": ("typifier",),
    "typifiés": ("typifier",),
    "typifies": ("typifier",),
    "typifiez": ("typifier",),
    "typifiiez": ("typifier",),
    "typifiions": ("typifier",),
    "typifions": ("typifier",),
    "typographiaient": ("typographier",),
    "typographiai": ("typographier",),
    "typographiais": ("typographier",),
    "typographiait": ("typographier",),
    "typographia": ("typographier",),
    "typographiâmes": ("typographier",),
    "typographiant": ("typographier",),
    "typographias": ("typographier",),
    "typographiassent": ("typographier",),
    "typographiasses": ("typographier",),
    "typographiasse": ("typographier",),
    "typographiassiez": ("typographier",),
    "typographiassions": ("typographier",),
    "typographiâtes": ("typographier",),
    "typographiât": ("typographier",),
    "typographiée": ("typographier",),
    "typographiées": ("typographier",),
    "typographié": ("typographier",),
    "typographient": ("typographier",),
    "typographie": ("typographier",),
    "typographiera": ("typographier",),
    "typographieraient": ("typographier",),
    "typographierai": ("typographier",),
    "typographierais": ("typographier",),
    "typographierait": ("typographier",),
    "typographieras": ("typographier",),
    "typographièrent": ("typographier",),
    "typographierez": ("typographier",),
    "typographieriez": ("typographier",),
    "typographierions": ("typographier",),
    "typographierons": ("typographier",),
    "typographieront": ("typographier",),
    "typographiés": ("typographier",),
    "typographies": ("typographier",),
    "typographiez": ("typographier",),
    "typographiiez": ("typographier",),
    "typographiions": ("typographier",),
    "typographions": ("typographier",),
    "ulcéraient": ("ulcérer",),
    "ulcérai": ("ulcérer",),
    "ulcérais": ("ulcérer",),
    "ulcérait": ("ulcérer",),
    "ulcéra": ("ulcérer",),
    "ulcérâmes": ("ulcérer",),
    "ulcérant": ("ulcérer",),
    "ulcéras": ("ulcérer",),
    "ulcérassent": ("ulcérer",),
    "ulcérasses": ("ulcérer",),
    "ulcérasse": ("ulcérer",),
    "ulcérassiez": ("ulcérer",),
    "ulcérassions": ("ulcérer",),
    "ulcérâtes": ("ulcérer",),
    "ulcérât": ("ulcérer",),
    "ulcérée": ("ulcérer",),
    "ulcérées": ("ulcérer",),
    "ulcéré": ("ulcérer",),
    "ulcèrent": ("ulcérer",),
    "ulcère": ("ulcérer",),
    "ulcérera": ("ulcérer",),
    "ulcéreraient": ("ulcérer",),
    "ulcérerai": ("ulcérer",),
    "ulcérerais": ("ulcérer",),
    "ulcérerait": ("ulcérer",),
    "ulcéreras": ("ulcérer",),
    "ulcérèrent": ("ulcérer",),
    "ulcérerez": ("ulcérer",),
    "ulcéreriez": ("ulcérer",),
    "ulcérerions": ("ulcérer",),
    "ulcérerons": ("ulcérer",),
    "ulcéreront": ("ulcérer",),
    "ulcérés": ("ulcérer",),
    "ulcères": ("ulcérer",),
    "ulcérez": ("ulcérer",),
    "ulcériez": ("ulcérer",),
    "ulcérions": ("ulcérer",),
    "ulcérons": ("ulcérer",),
    "ultracentrifugeaient": ("ultracentrifuger",),
    "ultracentrifugeai": ("ultracentrifuger",),
    "ultracentrifugeais": ("ultracentrifuger",),
    "ultracentrifugeait": ("ultracentrifuger",),
    "ultracentrifugea": ("ultracentrifuger",),
    "ultracentrifugeâmes": ("ultracentrifuger",),
    "ultracentrifugeant": ("ultracentrifuger",),
    "ultracentrifugeas": ("ultracentrifuger",),
    "ultracentrifugeassent": ("ultracentrifuger",),
    "ultracentrifugeasses": ("ultracentrifuger",),
    "ultracentrifugeasse": ("ultracentrifuger",),
    "ultracentrifugeassiez": ("ultracentrifuger",),
    "ultracentrifugeassions": ("ultracentrifuger",),
    "ultracentrifugeâtes": ("ultracentrifuger",),
    "ultracentrifugeât": ("ultracentrifuger",),
    "ultracentrifugée": ("ultracentrifuger",),
    "ultracentrifugées": ("ultracentrifuger",),
    "ultracentrifugé": ("ultracentrifuger",),
    "ultracentrifugent": ("ultracentrifuger",),
    "ultracentrifugeons": ("ultracentrifuger",),
    "ultracentrifuge": ("ultracentrifuger",),
    "ultracentrifugera": ("ultracentrifuger",),
    "ultracentrifugeraient": ("ultracentrifuger",),
    "ultracentrifugerai": ("ultracentrifuger",),
    "ultracentrifugerais": ("ultracentrifuger",),
    "ultracentrifugerait": ("ultracentrifuger",),
    "ultracentrifugeras": ("ultracentrifuger",),
    "ultracentrifugèrent": ("ultracentrifuger",),
    "ultracentrifugerez": ("ultracentrifuger",),
    "ultracentrifugeriez": ("ultracentrifuger",),
    "ultracentrifugerions": ("ultracentrifuger",),
    "ultracentrifugerons": ("ultracentrifuger",),
    "ultracentrifugeront": ("ultracentrifuger",),
    "ultracentrifugés": ("ultracentrifuger",),
    "ultracentrifuges": ("ultracentrifuger",),
    "ultracentrifugez": ("ultracentrifuger",),
    "ultracentrifugiez": ("ultracentrifuger",),
    "ultracentrifugions": ("ultracentrifuger",),
    "unifiaient": ("unifier",),
    "unifiai": ("unifier",),
    "unifiais": ("unifier",),
    "unifiait": ("unifier",),
    "unifia": ("unifier",),
    "unifiâmes": ("unifier",),
    "unifiant": ("unifier",),
    "unifias": ("unifier",),
    "unifiassent": ("unifier",),
    "unifiasses": ("unifier",),
    "unifiasse": ("unifier",),
    "unifiassiez": ("unifier",),
    "unifiassions": ("unifier",),
    "unifiâtes": ("unifier",),
    "unifiât": ("unifier",),
    "unifiée": ("unifier",),
    "unifiées": ("unifier",),
    "unifié": ("unifier",),
    "unifient": ("unifier",),
    "unifie": ("unifier",),
    "unifiera": ("unifier",),
    "unifieraient": ("unifier",),
    "unifierai": ("unifier",),
    "unifierais": ("unifier",),
    "unifierait": ("unifier",),
    "unifieras": ("unifier",),
    "unifièrent": ("unifier",),
    "unifierez": ("unifier",),
    "unifieriez": ("unifier",),
    "unifierions": ("unifier",),
    "unifierons": ("unifier",),
    "unifieront": ("unifier",),
    "unifiés": ("unifier",),
    "unifies": ("unifier",),
    "unifiez": ("unifier",),
    "unifiiez": ("unifier",),
    "unifiions": ("unifier",),
    "unifions": ("unifier",),
    "unie": ("unir",),
    "unies": ("unir",),
    "uni": ("unir",),
    "unîmes": ("unir",),
    "unira": ("unir",),
    "uniraient": ("unir",),
    "unirai": ("unir",),
    "unirais": ("unir",),
    "unirait": ("unir",),
    "uniras": ("unir",),
    "unirent": ("unir",),
    "unirez": ("unir",),
    "uniriez": ("unir",),
    "unirions": ("unir",),
    "unirons": ("unir",),
    "uniront": ("unir",),
    "unis": ("unir",),
    "unissaient": ("unir",),
    "unissais": ("unir",),
    "unissait": ("unir",),
    "unissant": ("unir",),
    "unissent": ("unir",),
    "unisse": ("unir",),
    "unisses": ("unir",),
    "unissez": ("unir",),
    "unissiez": ("unir",),
    "unissions": ("unir",),
    "unissons": ("unir",),
    "unîtes": ("unir",),
    "unit": ("unir",),
    "unît": ("unir",),
    "urbanifiaient": ("urbanifier",),
    "urbanifiai": ("urbanifier",),
    "urbanifiais": ("urbanifier",),
    "urbanifiait": ("urbanifier",),
    "urbanifia": ("urbanifier",),
    "urbanifiâmes": ("urbanifier",),
    "urbanifiant": ("urbanifier",),
    "urbanifias": ("urbanifier",),
    "urbanifiassent": ("urbanifier",),
    "urbanifiasses": ("urbanifier",),
    "urbanifiasse": ("urbanifier",),
    "urbanifiassiez": ("urbanifier",),
    "urbanifiassions": ("urbanifier",),
    "urbanifiâtes": ("urbanifier",),
    "urbanifiât": ("urbanifier",),
    "urbanifiée": ("urbanifier",),
    "urbanifiées": ("urbanifier",),
    "urbanifié": ("urbanifier",),
    "urbanifient": ("urbanifier",),
    "urbanifie": ("urbanifier",),
    "urbanifiera": ("urbanifier",),
    "urbanifieraient": ("urbanifier",),
    "urbanifierai": ("urbanifier",),
    "urbanifierais": ("urbanifier",),
    "urbanifierait": ("urbanifier",),
    "urbanifieras": ("urbanifier",),
    "urbanifièrent": ("urbanifier",),
    "urbanifierez": ("urbanifier",),
    "urbanifieriez": ("urbanifier",),
    "urbanifierions": ("urbanifier",),
    "urbanifierons": ("urbanifier",),
    "urbanifieront": ("urbanifier",),
    "urbanifiés": ("urbanifier",),
    "urbanifies": ("urbanifier",),
    "urbanifiez": ("urbanifier",),
    "urbanifiiez": ("urbanifier",),
    "urbanifiions": ("urbanifier",),
    "urbanifions": ("urbanifier",),
    "urgeaient": ("urger",),
    "urgeai": ("urger",),
    "urgeais": ("urger",),
    "urgeait": ("urger",),
    "urgea": ("urger",),
    "urgeâmes": ("urger",),
    "urgeant": ("urger",),
    "urgeas": ("urger",),
    "urgeassent": ("urger",),
    "urgeasses": ("urger",),
    "urgeasse": ("urger",),
    "urgeassiez": ("urger",),
    "urgeassions": ("urger",),
    "urgeâtes": ("urger",),
    "urgeât": ("urger",),
    "urgée": ("urger",),
    "urgées": ("urger",),
    "urgé": ("urger",),
    "urgent": ("urger",),
    "urgeons": ("urger",),
    "urge": ("urger",),
    "urgera": ("urger",),
    "urgeraient": ("urger",),
    "urgerai": ("urger",),
    "urgerais": ("urger",),
    "urgerait": ("urger",),
    "urgeras": ("urger",),
    "urgèrent": ("urger",),
    "urgerez": ("urger",),
    "urgeriez": ("urger",),
    "urgerions": ("urger",),
    "urgerons": ("urger",),
    "urgeront": ("urger",),
    "urgés": ("urger",),
    "urges": ("urger",),
    "urgez": ("urger",),
    "urgiez": ("urger",),
    "urgions": ("urger",),
    "vagie": ("vagir",),
    "vagies": ("vagir",),
    "vagi": ("vagir",),
    "vagîmes": ("vagir",),
    "vagira": ("vagir",),
    "vagiraient": ("vagir",),
    "vagirai": ("vagir",),
    "vagirais": ("vagir",),
    "vagirait": ("vagir",),
    "vagiras": ("vagir",),
    "vagirent": ("vagir",),
    "vagirez": ("vagir",),
    "vagiriez": ("vagir",),
    "vagirions": ("vagir",),
    "vagirons": ("vagir",),
    "vagiront": ("vagir",),
    "vagis": ("vagir",),
    "vagissaient": ("vagir",),
    "vagissais": ("vagir",),
    "vagissait": ("vagir",),
    "vagissant": ("vagir",),
    "vagissent": ("vagir",),
    "vagisse": ("vagir",),
    "vagisses": ("vagir",),
    "vagissez": ("vagir",),
    "vagissiez": ("vagir",),
    "vagissions": ("vagir",),
    "vagissons": ("vagir",),
    "vagîtes": ("vagir",),
    "vagit": ("vagir",),
    "vagît": ("vagir",),
    "vainc": ("vaincre",),
    "vaincra": ("vaincre",),
    "vaincraient": ("vaincre",),
    "vaincrai": ("vaincre",),
    "vaincrais": ("vaincre",),
    "vaincrait": ("vaincre",),
    "vaincras": ("vaincre",),
    "vaincrez": ("vaincre",),
    "vaincriez": ("vaincre",),
    "vaincrions": ("vaincre",),
    "vaincrons": ("vaincre",),
    "vaincront": ("vaincre",),
    "vaincs": ("vaincre",),
    "vaincue": ("vaincre",),
    "vaincues": ("vaincre",),
    "vaincu": ("vaincre",),
    "vaincus": ("vaincre",),
    "vainquaient": ("vaincre",),
    "vainquais": ("vaincre",),
    "vainquait": ("vaincre",),
    "vainquant": ("vaincre",),
    "vainquent": ("vaincre",),
    "vainque": ("vaincre",),
    "vainques": ("vaincre",),
    "vainquez": ("vaincre",),
    "vainquiez": ("vaincre",),
    "vainquîmes": ("vaincre",),
    "vainquions": ("vaincre",),
    "vainquirent": ("vaincre",),
    "vainquis": ("vaincre",),
    "vainquissent": ("vaincre",),
    "vainquisses": ("vaincre",),
    "vainquisse": ("vaincre",),
    "vainquissiez": ("vaincre",),
    "vainquissions": ("vaincre",),
    "vainquîtes": ("vaincre",),
    "vainquit": ("vaincre",),
    "vainquît": ("vaincre",),
    "vainquons": ("vaincre",),
    "valetaient": ("valeter",),
    "valetai": ("valeter",),
    "valetais": ("valeter",),
    "valetait": ("valeter",),
    "valeta": ("valeter",),
    "valetâmes": ("valeter",),
    "valetant": ("valeter",),
    "valetas": ("valeter",),
    "valetassent": ("valeter",),
    "valetasses": ("valeter",),
    "valetasse": ("valeter",),
    "valetassiez": ("valeter",),
    "valetassions": ("valeter",),
    "valetâtes": ("valeter",),
    "valetât": ("valeter",),
    "valeté": ("valeter",),
    "valetèrent": ("valeter",),
    "valetez": ("valeter",),
    "valetiez": ("valeter",),
    "valetions": ("valeter",),
    "valetons": ("valeter",),
    "valettent": ("valeter",),
    "valette": ("valeter",),
    "valettera": ("valeter",),
    "valetteraient": ("valeter",),
    "valetterai": ("valeter",),
    "valetterais": ("valeter",),
    "valetterait": ("valeter",),
    "valetteras": ("valeter",),
    "valetterez": ("valeter",),
    "valetteriez": ("valeter",),
    "valetterions": ("valeter",),
    "valetterons": ("valeter",),
    "valetteront": ("valeter",),
    "valettes": ("valeter",),
    "vaillent": ("valoir",),
    "vaille": ("valoir",),
    "vailles": ("valoir",),
    "valaient": ("valoir",),
    "valais": ("valoir",),
    "valait": ("valoir",),
    "valant": ("valoir",),
    "valent": ("valoir",),
    "valez": ("valoir",),
    "valiez": ("valoir",),
    "valions": ("valoir",),
    "valons": ("valoir",),
    "value": ("valoir",),
    "values": ("valoir",),
    "valu": ("valoir",),
    "valûmes": ("valoir",),
    "valurent": ("valoir",),
    "valus": ("valoir",),
    "valussent": ("valoir",),
    "valusses": ("valoir",),
    "valusse": ("valoir",),
    "valussiez": ("valoir",),
    "valussions": ("valoir",),
    "valûtes": ("valoir",),
    "valut": ("valoir",),
    "valût": ("valoir",),
    "vaudra": ("valoir",),
    "vaudraient": ("valoir",),
    "vaudrai": ("valoir",),
    "vaudrais": ("valoir",),
    "vaudrait": ("valoir",),
    "vaudras": ("valoir",),
    "vaudrez": ("valoir",),
    "vaudriez": ("valoir",),
    "vaudrions": ("valoir",),
    "vaudrons": ("valoir",),
    "vaudront": ("valoir",),
    "vaut": ("valoir",),
    "vaux": ("valoir",),
    "variaient": ("varier",),
    "variai": ("varier",),
    "variais": ("varier",),
    "variait": ("varier",),
    "varia": ("varier",),
    "variâmes": ("varier",),
    "variant": ("varier",),
    "varias": ("varier",),
    "variassent": ("varier",),
    "variasses": ("varier",),
    "variasse": ("varier",),
    "variassiez": ("varier",),
    "variassions": ("varier",),
    "variâtes": ("varier",),
    "variât": ("varier",),
    "variée": ("varier",),
    "variées": ("varier",),
    "varié": ("varier",),
    "varient": ("varier",),
    "varie": ("varier",),
    "variera": ("varier",),
    "varieraient": ("varier",),
    "varierai": ("varier",),
    "varierais": ("varier",),
    "varierait": ("varier",),
    "varieras": ("varier",),
    "varièrent": ("varier",),
    "varierez": ("varier",),
    "varieriez": ("varier",),
    "varierions": ("varier",),
    "varierons": ("varier",),
    "varieront": ("varier",),
    "variés": ("varier",),
    "varies": ("varier",),
    "variez": ("varier",),
    "variiez": ("varier",),
    "variions": ("varier",),
    "varions": ("varier",),
    "végétaient": ("végéter",),
    "végétai": ("végéter",),
    "végétais": ("végéter",),
    "végétait": ("végéter",),
    "végéta": ("végéter",),
    "végétâmes": ("végéter",),
    "végétant": ("végéter",),
    "végétas": ("végéter",),
    "végétassent": ("végéter",),
    "végétasses": ("végéter",),
    "végétasse": ("végéter",),
    "végétassiez": ("végéter",),
    "végétassions": ("végéter",),
    "végétâtes": ("végéter",),
    "végétât": ("végéter",),
    "végété": ("végéter",),
    "végètent": ("végéter",),
    "végète": ("végéter",),
    "végétera": ("végéter",),
    "végéteraient": ("végéter",),
    "végéterai": ("végéter",),
    "végéterais": ("végéter",),
    "végéterait": ("végéter",),
    "végéteras": ("végéter",),
    "végétèrent": ("végéter",),
    "végéterez": ("végéter",),
    "végéteriez": ("végéter",),
    "végéterions": ("végéter",),
    "végéterons": ("végéter",),
    "végéteront": ("végéter",),
    "végètes": ("végéter",),
    "végétez": ("végéter",),
    "végétiez": ("végéter",),
    "végétions": ("végéter",),
    "végétons": ("végéter",),
    "vendangeaient": ("vendanger",),
    "vendangeai": ("vendanger",),
    "vendangeais": ("vendanger",),
    "vendangeait": ("vendanger",),
    "vendangea": ("vendanger",),
    "vendangeâmes": ("vendanger",),
    "vendangeant": ("vendanger",),
    "vendangeas": ("vendanger",),
    "vendangeassent": ("vendanger",),
    "vendangeasses": ("vendanger",),
    "vendangeasse": ("vendanger",),
    "vendangeassiez": ("vendanger",),
    "vendangeassions": ("vendanger",),
    "vendangeâtes": ("vendanger",),
    "vendangeât": ("vendanger",),
    "vendangée": ("vendanger",),
    "vendangées": ("vendanger",),
    "vendangé": ("vendanger",),
    "vendangent": ("vendanger",),
    "vendangeons": ("vendanger",),
    "vendange": ("vendanger",),
    "vendangera": ("vendanger",),
    "vendangeraient": ("vendanger",),
    "vendangerai": ("vendanger",),
    "vendangerais": ("vendanger",),
    "vendangerait": ("vendanger",),
    "vendangeras": ("vendanger",),
    "vendangèrent": ("vendanger",),
    "vendangerez": ("vendanger",),
    "vendangeriez": ("vendanger",),
    "vendangerions": ("vendanger",),
    "vendangerons": ("vendanger",),
    "vendangeront": ("vendanger",),
    "vendangés": ("vendanger",),
    "vendanges": ("vendanger",),
    "vendangez": ("vendanger",),
    "vendangiez": ("vendanger",),
    "vendangions": ("vendanger",),
    "vendaient": ("vendre",),
    "vendais": ("vendre",),
    "vendait": ("vendre",),
    "vendant": ("vendre",),
    "vendent": ("vendre",),
    "vende": ("vendre",),
    "vendes": ("vendre",),
    "vendez": ("vendre",),
    "vendiez": ("vendre",),
    "vendîmes": ("vendre",),
    "vendions": ("vendre",),
    "vendirent": ("vendre",),
    "vendis": ("vendre",),
    "vendissent": ("vendre",),
    "vendisses": ("vendre",),
    "vendisse": ("vendre",),
    "vendissiez": ("vendre",),
    "vendissions": ("vendre",),
    "vendîtes": ("vendre",),
    "vendit": ("vendre",),
    "vendît": ("vendre",),
    "vendons": ("vendre",),
    "vend": ("vendre",),
    "vendra": ("vendre",),
    "vendraient": ("vendre",),
    "vendrai": ("vendre",),
    "vendrais": ("vendre",),
    "vendrait": ("vendre",),
    "vendras": ("vendre",),
    "vendrez": ("vendre",),
    "vendriez": ("vendre",),
    "vendrions": ("vendre",),
    "vendrons": ("vendre",),
    "vendront": ("vendre",),
    "vends": ("vendre",),
    "vendue": ("vendre",),
    "vendues": ("vendre",),
    "vendu": ("vendre",),
    "vendus": ("vendre",),
    "vénéraient": ("vénérer",),
    "vénérai": ("vénérer",),
    "vénérais": ("vénérer",),
    "vénérait": ("vénérer",),
    "vénéra": ("vénérer",),
    "vénérâmes": ("vénérer",),
    "vénérant": ("vénérer",),
    "vénéras": ("vénérer",),
    "vénérassent": ("vénérer",),
    "vénérasses": ("vénérer",),
    "vénérasse": ("vénérer",),
    "vénérassiez": ("vénérer",),
    "vénérassions": ("vénérer",),
    "vénérâtes": ("vénérer",),
    "vénérât": ("vénérer",),
    "vénérée": ("vénérer",),
    "vénérées": ("vénérer",),
    "vénéré": ("vénérer",),
    "vénèrent": ("vénérer",),
    "vénère": ("vénérer",),
    "vénérera": ("vénérer",),
    "vénéreraient": ("vénérer",),
    "vénérerai": ("vénérer",),
    "vénérerais": ("vénérer",),
    "vénérerait": ("vénérer",),
    "vénéreras": ("vénérer",),
    "vénérèrent": ("vénérer",),
    "vénérerez": ("vénérer",),
    "vénéreriez": ("vénérer",),
    "vénérerions": ("vénérer",),
    "vénérerons": ("vénérer",),
    "vénéreront": ("vénérer",),
    "vénérés": ("vénérer",),
    "vénères": ("vénérer",),
    "vénérez": ("vénérer",),
    "vénériez": ("vénérer",),
    "vénérions": ("vénérer",),
    "vénérons": ("vénérer",),
    "venaient": ("venir",),
    "venai": ("vener",),
    "venais": ("venir",),
    "venait": ("venir",),
    "vena": ("vener",),
    "venâmes": ("vener",),
    "venant": ("venir",),
    "venas": ("vener",),
    "venassent": ("vener",),
    "venasses": ("vener",),
    "venasse": ("vener",),
    "venassiez": ("vener",),
    "venassions": ("vener",),
    "venâtes": ("vener",),
    "venât": ("vener",),
    "venée": ("vener",),
    "venées": ("vener",),
    "vené": ("vener",),
    "vènent": ("vener",),
    "vène": ("vener",),
    "vènera": ("vener",),
    "vèneraient": ("vener",),
    "vènerai": ("vener",),
    "vènerais": ("vener",),
    "vènerait": ("vener",),
    "vèneras": ("vener",),
    "venèrent": ("vener",),
    "vènerez": ("vener",),
    "vèneriez": ("vener",),
    "vènerions": ("vener",),
    "vènerons": ("vener",),
    "vèneront": ("vener",),
    "venés": ("vener",),
    "vènes": ("vener",),
    "venez": ("venir",),
    "veniez": ("venir",),
    "venions": ("venir",),
    "venons": ("venir",),
    "vengeaient": ("venger",),
    "vengeai": ("venger",),
    "vengeais": ("venger",),
    "vengeait": ("venger",),
    "vengea": ("venger",),
    "vengeâmes": ("venger",),
    "vengeant": ("venger",),
    "vengeas": ("venger",),
    "vengeassent": ("venger",),
    "vengeasses": ("venger",),
    "vengeasse": ("venger",),
    "vengeassiez": ("venger",),
    "vengeassions": ("venger",),
    "vengeâtes": ("venger",),
    "vengeât": ("venger",),
    "vengée": ("venger",),
    "vengées": ("venger",),
    "vengé": ("venger",),
    "vengent": ("venger",),
    "vengeons": ("venger",),
    "venge": ("venger",),
    "vengera": ("venger",),
    "vengeraient": ("venger",),
    "vengerai": ("venger",),
    "vengerais": ("venger",),
    "vengerait": ("venger",),
    "vengeras": ("venger",),
    "vengèrent": ("venger",),
    "vengerez": ("venger",),
    "vengeriez": ("venger",),
    "vengerions": ("venger",),
    "vengerons": ("venger",),
    "vengeront": ("venger",),
    "vengés": ("venger",),
    "venges": ("venger",),
    "vengez": ("venger",),
    "vengiez": ("venger",),
    "vengions": ("venger",),
    "venue": ("venir",),
    "venues": ("venir",),
    "venu": ("venir",),
    "venus": ("venir",),
    "viendra": ("venir",),
    "viendraient": ("venir",),
    "viendrai": ("venir",),
    "viendrais": ("venir",),
    "viendrait": ("venir",),
    "viendras": ("venir",),
    "viendrez": ("venir",),
    "viendriez": ("venir",),
    "viendrions": ("venir",),
    "viendrons": ("venir",),
    "viendront": ("venir",),
    "viennent": ("venir",),
    "vienne": ("venir",),
    "viennes": ("venir",),
    "viens": ("venir",),
    "vient": ("venir",),
    "vînmes": ("venir",),
    "vinrent": ("venir",),
    "vins": ("venir",),
    "vinssent": ("venir",),
    "vinsses": ("venir",),
    "vinsse": ("venir",),
    "vinssiez": ("venir",),
    "vinssions": ("venir",),
    "vîntes": ("venir",),
    "vint": ("venir",),
    "vînt": ("venir",),
    "verbiageaient": ("verbiager",),
    "verbiageai": ("verbiager",),
    "verbiageais": ("verbiager",),
    "verbiageait": ("verbiager",),
    "verbiagea": ("verbiager",),
    "verbiageâmes": ("verbiager",),
    "verbiageant": ("verbiager",),
    "verbiageas": ("verbiager",),
    "verbiageassent": ("verbiager",),
    "verbiageasses": ("verbiager",),
    "verbiageasse": ("verbiager",),
    "verbiageassiez": ("verbiager",),
    "verbiageassions": ("verbiager",),
    "verbiageâtes": ("verbiager",),
    "verbiageât": ("verbiager",),
    "verbiagée": ("verbiager",),
    "verbiagées": ("verbiager",),
    "verbiagé": ("verbiager",),
    "verbiagent": ("verbiager",),
    "verbiageons": ("verbiager",),
    "verbiage": ("verbiager",),
    "verbiagera": ("verbiager",),
    "verbiageraient": ("verbiager",),
    "verbiagerai": ("verbiager",),
    "verbiagerais": ("verbiager",),
    "verbiagerait": ("verbiager",),
    "verbiageras": ("verbiager",),
    "verbiagèrent": ("verbiager",),
    "verbiagerez": ("verbiager",),
    "verbiageriez": ("verbiager",),
    "verbiagerions": ("verbiager",),
    "verbiagerons": ("verbiager",),
    "verbiageront": ("verbiager",),
    "verbiagés": ("verbiager",),
    "verbiages": ("verbiager",),
    "verbiagez": ("verbiager",),
    "verbiagiez": ("verbiager",),
    "verbiagions": ("verbiager",),
    "verbigéraient": ("verbigérer",),
    "verbigérai": ("verbigérer",),
    "verbigérais": ("verbigérer",),
    "verbigérait": ("verbigérer",),
    "verbigéra": ("verbigérer",),
    "verbigérâmes": ("verbigérer",),
    "verbigérant": ("verbigérer",),
    "verbigéras": ("verbigérer",),
    "verbigérassent": ("verbigérer",),
    "verbigérasses": ("verbigérer",),
    "verbigérasse": ("verbigérer",),
    "verbigérassiez": ("verbigérer",),
    "verbigérassions": ("verbigérer",),
    "verbigérâtes": ("verbigérer",),
    "verbigérât": ("verbigérer",),
    "verbigérée": ("verbigérer",),
    "verbigérées": ("verbigérer",),
    "verbigéré": ("verbigérer",),
    "verbigèrent": ("verbigérer",),
    "verbigère": ("verbigérer",),
    "verbigérera": ("verbigérer",),
    "verbigéreraient": ("verbigérer",),
    "verbigérerai": ("verbigérer",),
    "verbigérerais": ("verbigérer",),
    "verbigérerait": ("verbigérer",),
    "verbigéreras": ("verbigérer",),
    "verbigérèrent": ("verbigérer",),
    "verbigérerez": ("verbigérer",),
    "verbigéreriez": ("verbigérer",),
    "verbigérerions": ("verbigérer",),
    "verbigérerons": ("verbigérer",),
    "verbigéreront": ("verbigérer",),
    "verbigérés": ("verbigérer",),
    "verbigères": ("verbigérer",),
    "verbigérez": ("verbigérer",),
    "verbigériez": ("verbigérer",),
    "verbigérions": ("verbigérer",),
    "verbigérons": ("verbigérer",),
    "verdie": ("verdir",),
    "verdies": ("verdir",),
    "verdi": ("verdir",),
    "verdîmes": ("verdir",),
    "verdira": ("verdir",),
    "verdiraient": ("verdir",),
    "verdirai": ("verdir",),
    "verdirais": ("verdir",),
    "verdirait": ("verdir",),
    "verdiras": ("verdir",),
    "verdirent": ("verdir",),
    "verdirez": ("verdir",),
    "verdiriez": ("verdir",),
    "verdirions": ("verdir",),
    "verdirons": ("verdir",),
    "verdiront": ("verdir",),
    "verdis": ("verdir",),
    "verdissaient": ("verdir",),
    "verdissais": ("verdir",),
    "verdissait": ("verdir",),
    "verdissant": ("verdir",),
    "verdissent": ("verdir",),
    "verdisse": ("verdir",),
    "verdisses": ("verdir",),
    "verdissez": ("verdir",),
    "verdissiez": ("verdir",),
    "verdissions": ("verdir",),
    "verdissons": ("verdir",),
    "verdîtes": ("verdir",),
    "verdit": ("verdir",),
    "verdît": ("verdir",),
    "verdoient": ("verdoyer",),
    "verdoie": ("verdoyer",),
    "verdoiera": ("verdoyer",),
    "verdoieraient": ("verdoyer",),
    "verdoierai": ("verdoyer",),
    "verdoierais": ("verdoyer",),
    "verdoierait": ("verdoyer",),
    "verdoieras": ("verdoyer",),
    "verdoierez": ("verdoyer",),
    "verdoieriez": ("verdoyer",),
    "verdoierions": ("verdoyer",),
    "verdoierons": ("verdoyer",),
    "verdoieront": ("verdoyer",),
    "verdoies": ("verdoyer",),
    "verdoyaient": ("verdoyer",),
    "verdoyai": ("verdoyer",),
    "verdoyais": ("verdoyer",),
    "verdoyait": ("verdoyer",),
    "verdoya": ("verdoyer",),
    "verdoyâmes": ("verdoyer",),
    "verdoyant": ("verdoyer",),
    "verdoyas": ("verdoyer",),
    "verdoyassent": ("verdoyer",),
    "verdoyasses": ("verdoyer",),
    "verdoyasse": ("verdoyer",),
    "verdoyassiez": ("verdoyer",),
    "verdoyassions": ("verdoyer",),
    "verdoyâtes": ("verdoyer",),
    "verdoyât": ("verdoyer",),
    "verdoyé": ("verdoyer",),
    "verdoyèrent": ("verdoyer",),
    "verdoyez": ("verdoyer",),
    "verdoyiez": ("verdoyer",),
    "verdoyions": ("verdoyer",),
    "verdoyons": ("verdoyer",),
    "vergeaient": ("verger",),
    "vergeai": ("verger",),
    "vergeais": ("verger",),
    "vergeait": ("verger",),
    "vergea": ("verger",),
    "vergeâmes": ("verger",),
    "vergeant": ("verger",),
    "vergeas": ("verger",),
    "vergeassent": ("verger",),
    "vergeasses": ("verger",),
    "vergeasse": ("verger",),
    "vergeassiez": ("verger",),
    "vergeassions": ("verger",),
    "vergeâtes": ("verger",),
    "vergeât": ("verger",),
    "vergée": ("verger",),
    "vergées": ("verger",),
    "vergé": ("verger",),
    "vergent": ("verger",),
    "vergeons": ("verger",),
    "verge": ("verger",),
    "vergera": ("verger",),
    "vergeraient": ("verger",),
    "vergerai": ("verger",),
    "vergerais": ("verger",),
    "vergerait": ("verger",),
    "vergeras": ("verger",),
    "vergèrent": ("verger",),
    "vergerez": ("verger",),
    "vergeriez": ("verger",),
    "vergerions": ("verger",),
    "vergerons": ("verger",),
    "vergeront": ("verger",),
    "vergés": ("verger",),
    "verges": ("verger",),
    "vergez": ("verger",),
    "vergiez": ("verger",),
    "vergions": ("verger",),
    "vergetaient": ("vergeter",),
    "vergetai": ("vergeter",),
    "vergetais": ("vergeter",),
    "vergetait": ("vergeter",),
    "vergeta": ("vergeter",),
    "vergetâmes": ("vergeter",),
    "vergetant": ("vergeter",),
    "vergetas": ("vergeter",),
    "vergetassent": ("vergeter",),
    "vergetasses": ("vergeter",),
    "vergetasse": ("vergeter",),
    "vergetassiez": ("vergeter",),
    "vergetassions": ("vergeter",),
    "vergetâtes": ("vergeter",),
    "vergetât": ("vergeter",),
    "vergetée": ("vergeter",),
    "vergetées": ("vergeter",),
    "vergeté": ("vergeter",),
    "vergetèrent": ("vergeter",),
    "vergetés": ("vergeter",),
    "vergetez": ("vergeter",),
    "vergetiez": ("vergeter",),
    "vergetions": ("vergeter",),
    "vergetons": ("vergeter",),
    "vergettent": ("vergeter",),
    "vergette": ("vergeter",),
    "vergettera": ("vergeter",),
    "vergetteraient": ("vergeter",),
    "vergetterai": ("vergeter",),
    "vergetterais": ("vergeter",),
    "vergetterait": ("vergeter",),
    "vergetteras": ("vergeter",),
    "vergetterez": ("vergeter",),
    "vergetteriez": ("vergeter",),
    "vergetterions": ("vergeter",),
    "vergetterons": ("vergeter",),
    "vergetteront": ("vergeter",),
    "vergettes": ("vergeter",),
    "verglaçaient": ("verglacer",),
    "verglaçai": ("verglacer",),
    "verglaçais": ("verglacer",),
    "verglaçait": ("verglacer",),
    "verglaça": ("verglacer",),
    "verglaçâmes": ("verglacer",),
    "verglaçant": ("verglacer",),
    "verglaças": ("verglacer",),
    "verglaçassent": ("verglacer",),
    "verglaçasses": ("verglacer",),
    "verglaçasse": ("verglacer",),
    "verglaçassiez": ("verglacer",),
    "verglaçassions": ("verglacer",),
    "verglaçâtes": ("verglacer",),
    "verglaçât": ("verglacer",),
    "verglacée": ("verglacer",),
    "verglacées": ("verglacer",),
    "verglacé": ("verglacer",),
    "verglacent": ("verglacer",),
    "verglace": ("verglacer",),
    "verglacera": ("verglacer",),
    "verglaceraient": ("verglacer",),
    "verglacerai": ("verglacer",),
    "verglacerais": ("verglacer",),
    "verglacerait": ("verglacer",),
    "verglaceras": ("verglacer",),
    "verglacèrent": ("verglacer",),
    "verglacerez": ("verglacer",),
    "verglaceriez": ("verglacer",),
    "verglacerions": ("verglacer",),
    "verglacerons": ("verglacer",),
    "verglaceront": ("verglacer",),
    "verglacés": ("verglacer",),
    "verglaces": ("verglacer",),
    "verglacez": ("verglacer",),
    "verglaciez": ("verglacer",),
    "verglacions": ("verglacer",),
    "verglaçons": ("verglacer",),
    "vérifiaient": ("vérifier",),
    "vérifiai": ("vérifier",),
    "vérifiais": ("vérifier",),
    "vérifiait": ("vérifier",),
    "vérifia": ("vérifier",),
    "vérifiâmes": ("vérifier",),
    "vérifiant": ("vérifier",),
    "vérifias": ("vérifier",),
    "vérifiassent": ("vérifier",),
    "vérifiasses": ("vérifier",),
    "vérifiasse": ("vérifier",),
    "vérifiassiez": ("vérifier",),
    "vérifiassions": ("vérifier",),
    "vérifiâtes": ("vérifier",),
    "vérifiât": ("vérifier",),
    "vérifiée": ("vérifier",),
    "vérifiées": ("vérifier",),
    "vérifié": ("vérifier",),
    "vérifient": ("vérifier",),
    "vérifie": ("vérifier",),
    "vérifiera": ("vérifier",),
    "vérifieraient": ("vérifier",),
    "vérifierai": ("vérifier",),
    "vérifierais": ("vérifier",),
    "vérifierait": ("vérifier",),
    "vérifieras": ("vérifier",),
    "vérifièrent": ("vérifier",),
    "vérifierez": ("vérifier",),
    "vérifieriez": ("vérifier",),
    "vérifierions": ("vérifier",),
    "vérifierons": ("vérifier",),
    "vérifieront": ("vérifier",),
    "vérifiés": ("vérifier",),
    "vérifies": ("vérifier",),
    "vérifiez": ("vérifier",),
    "vérifiiez": ("vérifier",),
    "vérifiions": ("vérifier",),
    "vérifions": ("vérifier",),
    "vermifugeaient": ("vermifuger",),
    "vermifugeai": ("vermifuger",),
    "vermifugeais": ("vermifuger",),
    "vermifugeait": ("vermifuger",),
    "vermifugea": ("vermifuger",),
    "vermifugeâmes": ("vermifuger",),
    "vermifugeant": ("vermifuger",),
    "vermifugeas": ("vermifuger",),
    "vermifugeassent": ("vermifuger",),
    "vermifugeasses": ("vermifuger",),
    "vermifugeasse": ("vermifuger",),
    "vermifugeassiez": ("vermifuger",),
    "vermifugeassions": ("vermifuger",),
    "vermifugeâtes": ("vermifuger",),
    "vermifugeât": ("vermifuger",),
    "vermifugée": ("vermifuger",),
    "vermifugées": ("vermifuger",),
    "vermifugé": ("vermifuger",),
    "vermifugent": ("vermifuger",),
    "vermifugeons": ("vermifuger",),
    "vermifuge": ("vermifuger",),
    "vermifugera": ("vermifuger",),
    "vermifugeraient": ("vermifuger",),
    "vermifugerai": ("vermifuger",),
    "vermifugerais": ("vermifuger",),
    "vermifugerait": ("vermifuger",),
    "vermifugeras": ("vermifuger",),
    "vermifugèrent": ("vermifuger",),
    "vermifugerez": ("vermifuger",),
    "vermifugeriez": ("vermifuger",),
    "vermifugerions": ("vermifuger",),
    "vermifugerons": ("vermifuger",),
    "vermifugeront": ("vermifuger",),
    "vermifugés": ("vermifuger",),
    "vermifuges": ("vermifuger",),
    "vermifugez": ("vermifuger",),
    "vermifugiez": ("vermifuger",),
    "vermifugions": ("vermifuger",),
    "vernie": ("vernir",),
    "vernies": ("vernir",),
    "verni": ("vernir",),
    "vernîmes": ("vernir",),
    "vernira": ("vernir",),
    "verniraient": ("vernir",),
    "vernirai": ("vernir",),
    "vernirais": ("vernir",),
    "vernirait": ("vernir",),
    "verniras": ("vernir",),
    "vernirent": ("vernir",),
    "vernirez": ("vernir",),
    "verniriez": ("vernir",),
    "vernirions": ("vernir",),
    "vernirons": ("vernir",),
    "verniront": ("vernir",),
    "vernis": ("vernir",),
    "vernissaient": ("vernir",),
    "vernissais": ("vernir",),
    "vernissait": ("vernir",),
    "vernissant": ("vernir",),
    "vernissent": ("vernir",),
    "vernisse": ("vernir",),
    "vernisses": ("vernir",),
    "vernissez": ("vernir",),
    "vernissiez": ("vernir",),
    "vernissions": ("vernir",),
    "vernissons": ("vernir",),
    "vernîtes": ("vernir",),
    "vernit": ("vernir",),
    "vernît": ("vernir",),
    "versifiaient": ("versifier",),
    "versifiai": ("versifier",),
    "versifiais": ("versifier",),
    "versifiait": ("versifier",),
    "versifia": ("versifier",),
    "versifiâmes": ("versifier",),
    "versifiant": ("versifier",),
    "versifias": ("versifier",),
    "versifiassent": ("versifier",),
    "versifiasses": ("versifier",),
    "versifiasse": ("versifier",),
    "versifiassiez": ("versifier",),
    "versifiassions": ("versifier",),
    "versifiâtes": ("versifier",),
    "versifiât": ("versifier",),
    "versifiée": ("versifier",),
    "versifiées": ("versifier",),
    "versifié": ("versifier",),
    "versifient": ("versifier",),
    "versifie": ("versifier",),
    "versifiera": ("versifier",),
    "versifieraient": ("versifier",),
    "versifierai": ("versifier",),
    "versifierais": ("versifier",),
    "versifierait": ("versifier",),
    "versifieras": ("versifier",),
    "versifièrent": ("versifier",),
    "versifierez": ("versifier",),
    "versifieriez": ("versifier",),
    "versifierions": ("versifier",),
    "versifierons": ("versifier",),
    "versifieront": ("versifier",),
    "versifiés": ("versifier",),
    "versifies": ("versifier",),
    "versifiez": ("versifier",),
    "versifiiez": ("versifier",),
    "versifiions": ("versifier",),
    "versifions": ("versifier",),
    "vêtaient": ("vêtir",),
    "vêtais": ("vêtir",),
    "vêtait": ("vêtir",),
    "vêtant": ("vêtir",),
    "vêtent": ("vêtir",),
    "vête": ("vêtir",),
    "vêtes": ("vêtir",),
    "vêtez": ("vêtir",),
    "vêtiez": ("vêtir",),
    "vêtîmes": ("vêtir",),
    "vêtions": ("vêtir",),
    "vêtira": ("vêtir",),
    "vêtiraient": ("vêtir",),
    "vêtirai": ("vêtir",),
    "vêtirais": ("vêtir",),
    "vêtirait": ("vêtir",),
    "vêtiras": ("vêtir",),
    "vêtirent": ("vêtir",),
    "vêtirez": ("vêtir",),
    "vêtiriez": ("vêtir",),
    "vêtirions": ("vêtir",),
    "vêtirons": ("vêtir",),
    "vêtiront": ("vêtir",),
    "vêtis": ("vêtir",),
    "vêtissent": ("vêtir",),
    "vêtisses": ("vêtir",),
    "vêtisse": ("vêtir",),
    "vêtissiez": ("vêtir",),
    "vêtissions": ("vêtir",),
    "vêtîtes": ("vêtir",),
    "vêtit": ("vêtir",),
    "vêtît": ("vêtir",),
    "vêtons": ("vêtir",),
    "vêt": ("vêtir",),
    "vêts": ("vêtir",),
    "vêtue": ("vêtir",),
    "vêtues": ("vêtir",),
    "vêtu": ("vêtir",),
    "vêtus": ("vêtir",),
    "viciaient": ("vicier",),
    "viciai": ("vicier",),
    "viciais": ("vicier",),
    "viciait": ("vicier",),
    "vicia": ("vicier",),
    "viciâmes": ("vicier",),
    "viciant": ("vicier",),
    "vicias": ("vicier",),
    "viciassent": ("vicier",),
    "viciasses": ("vicier",),
    "viciasse": ("vicier",),
    "viciassiez": ("vicier",),
    "viciassions": ("vicier",),
    "viciâtes": ("vicier",),
    "viciât": ("vicier",),
    "viciée": ("vicier",),
    "viciées": ("vicier",),
    "vicié": ("vicier",),
    "vicient": ("vicier",),
    "vicie": ("vicier",),
    "viciera": ("vicier",),
    "vicieraient": ("vicier",),
    "vicierai": ("vicier",),
    "vicierais": ("vicier",),
    "vicierait": ("vicier",),
    "vicieras": ("vicier",),
    "vicièrent": ("vicier",),
    "vicierez": ("vicier",),
    "vicieriez": ("vicier",),
    "vicierions": ("vicier",),
    "vicierons": ("vicier",),
    "vicieront": ("vicier",),
    "viciés": ("vicier",),
    "vicies": ("vicier",),
    "viciez": ("vicier",),
    "viciiez": ("vicier",),
    "viciions": ("vicier",),
    "vicions": ("vicier",),
    "vidangeaient": ("vidanger",),
    "vidangeai": ("vidanger",),
    "vidangeais": ("vidanger",),
    "vidangeait": ("vidanger",),
    "vidangea": ("vidanger",),
    "vidangeâmes": ("vidanger",),
    "vidangeant": ("vidanger",),
    "vidangeas": ("vidanger",),
    "vidangeassent": ("vidanger",),
    "vidangeasses": ("vidanger",),
    "vidangeasse": ("vidanger",),
    "vidangeassiez": ("vidanger",),
    "vidangeassions": ("vidanger",),
    "vidangeâtes": ("vidanger",),
    "vidangeât": ("vidanger",),
    "vidangée": ("vidanger",),
    "vidangées": ("vidanger",),
    "vidangé": ("vidanger",),
    "vidangent": ("vidanger",),
    "vidangeons": ("vidanger",),
    "vidange": ("vidanger",),
    "vidangera": ("vidanger",),
    "vidangeraient": ("vidanger",),
    "vidangerai": ("vidanger",),
    "vidangerais": ("vidanger",),
    "vidangerait": ("vidanger",),
    "vidangeras": ("vidanger",),
    "vidangèrent": ("vidanger",),
    "vidangerez": ("vidanger",),
    "vidangeriez": ("vidanger",),
    "vidangerions": ("vidanger",),
    "vidangerons": ("vidanger",),
    "vidangeront": ("vidanger",),
    "vidangés": ("vidanger",),
    "vidanges": ("vidanger",),
    "vidangez": ("vidanger",),
    "vidangiez": ("vidanger",),
    "vidangions": ("vidanger",),
    "videlaient": ("videler",),
    "videlai": ("videler",),
    "videlais": ("videler",),
    "videlait": ("videler",),
    "videla": ("videler",),
    "videlâmes": ("videler",),
    "videlant": ("videler",),
    "videlas": ("videler",),
    "videlassent": ("videler",),
    "videlasses": ("videler",),
    "videlasse": ("videler",),
    "videlassiez": ("videler",),
    "videlassions": ("videler",),
    "videlâtes": ("videler",),
    "videlât": ("videler",),
    "videlée": ("videler",),
    "videlées": ("videler",),
    "videlé": ("videler",),
    "videlèrent": ("videler",),
    "videlés": ("videler",),
    "videlez": ("videler",),
    "videliez": ("videler",),
    "videlions": ("videler",),
    "videllent": ("videler",),
    "videlle": ("videler",),
    "videllera": ("videler",),
    "videlleraient": ("videler",),
    "videllerai": ("videler",),
    "videllerais": ("videler",),
    "videllerait": ("videler",),
    "videlleras": ("videler",),
    "videllerez": ("videler",),
    "videlleriez": ("videler",),
    "videllerions": ("videler",),
    "videllerons": ("videler",),
    "videlleront": ("videler",),
    "videlles": ("videler",),
    "videlons": ("videler",),
    "vieillie": ("vieillir",),
    "vieillies": ("vieillir",),
    "vieilli": ("vieillir",),
    "vieillîmes": ("vieillir",),
    "vieillira": ("vieillir",),
    "vieilliraient": ("vieillir",),
    "vieillirai": ("vieillir",),
    "vieillirais": ("vieillir",),
    "vieillirait": ("vieillir",),
    "vieilliras": ("vieillir",),
    "vieillirent": ("vieillir",),
    "vieillirez": ("vieillir",),
    "vieilliriez": ("vieillir",),
    "vieillirions": ("vieillir",),
    "vieillirons": ("vieillir",),
    "vieilliront": ("vieillir",),
    "vieillis": ("vieillir",),
    "vieillissaient": ("vieillir",),
    "vieillissais": ("vieillir",),
    "vieillissait": ("vieillir",),
    "vieillissant": ("vieillir",),
    "vieillissent": ("vieillir",),
    "vieillisse": ("vieillir",),
    "vieillisses": ("vieillir",),
    "vieillissez": ("vieillir",),
    "vieillissiez": ("vieillir",),
    "vieillissions": ("vieillir",),
    "vieillissons": ("vieillir",),
    "vieillîtes": ("vieillir",),
    "vieillit": ("vieillir",),
    "vieillît": ("vieillir",),
    "vignetaient": ("vigneter",),
    "vignetai": ("vigneter",),
    "vignetais": ("vigneter",),
    "vignetait": ("vigneter",),
    "vigneta": ("vigneter",),
    "vignetâmes": ("vigneter",),
    "vignetant": ("vigneter",),
    "vignetas": ("vigneter",),
    "vignetassent": ("vigneter",),
    "vignetasses": ("vigneter",),
    "vignetasse": ("vigneter",),
    "vignetassiez": ("vigneter",),
    "vignetassions": ("vigneter",),
    "vignetâtes": ("vigneter",),
    "vignetât": ("vigneter",),
    "vignetée": ("vigneter",),
    "vignetées": ("vigneter",),
    "vigneté": ("vigneter",),
    "vignetèrent": ("vigneter",),
    "vignetés": ("vigneter",),
    "vignetez": ("vigneter",),
    "vignetiez": ("vigneter",),
    "vignetions": ("vigneter",),
    "vignetons": ("vigneter",),
    "vignettent": ("vigneter",),
    "vignette": ("vigneter",),
    "vignettera": ("vigneter",),
    "vignetteraient": ("vigneter",),
    "vignetterai": ("vigneter",),
    "vignetterais": ("vigneter",),
    "vignetterait": ("vigneter",),
    "vignetteras": ("vigneter",),
    "vignetterez": ("vigneter",),
    "vignetteriez": ("vigneter",),
    "vignetterions": ("vigneter",),
    "vignetterons": ("vigneter",),
    "vignetteront": ("vigneter",),
    "vignettes": ("vigneter",),
    "vinifiaient": ("vinifier",),
    "vinifiai": ("vinifier",),
    "vinifiais": ("vinifier",),
    "vinifiait": ("vinifier",),
    "vinifia": ("vinifier",),
    "vinifiâmes": ("vinifier",),
    "vinifiant": ("vinifier",),
    "vinifias": ("vinifier",),
    "vinifiassent": ("vinifier",),
    "vinifiasses": ("vinifier",),
    "vinifiasse": ("vinifier",),
    "vinifiassiez": ("vinifier",),
    "vinifiassions": ("vinifier",),
    "vinifiâtes": ("vinifier",),
    "vinifiât": ("vinifier",),
    "vinifiée": ("vinifier",),
    "vinifiées": ("vinifier",),
    "vinifié": ("vinifier",),
    "vinifient": ("vinifier",),
    "vinifie": ("vinifier",),
    "vinifiera": ("vinifier",),
    "vinifieraient": ("vinifier",),
    "vinifierai": ("vinifier",),
    "vinifierais": ("vinifier",),
    "vinifierait": ("vinifier",),
    "vinifieras": ("vinifier",),
    "vinifièrent": ("vinifier",),
    "vinifierez": ("vinifier",),
    "vinifieriez": ("vinifier",),
    "vinifierions": ("vinifier",),
    "vinifierons": ("vinifier",),
    "vinifieront": ("vinifier",),
    "vinifiés": ("vinifier",),
    "vinifies": ("vinifier",),
    "vinifiez": ("vinifier",),
    "vinifiiez": ("vinifier",),
    "vinifiions": ("vinifier",),
    "vinifions": ("vinifier",),
    "violaçaient": ("violacer",),
    "violaçai": ("violacer",),
    "violaçais": ("violacer",),
    "violaçait": ("violacer",),
    "violaça": ("violacer",),
    "violaçâmes": ("violacer",),
    "violaçant": ("violacer",),
    "violaças": ("violacer",),
    "violaçassent": ("violacer",),
    "violaçasses": ("violacer",),
    "violaçasse": ("violacer",),
    "violaçassiez": ("violacer",),
    "violaçassions": ("violacer",),
    "violaçâtes": ("violacer",),
    "violaçât": ("violacer",),
    "violacée": ("violacer",),
    "violacées": ("violacer",),
    "violacé": ("violacer",),
    "violacent": ("violacer",),
    "violace": ("violacer",),
    "violacera": ("violacer",),
    "violaceraient": ("violacer",),
    "violacerai": ("violacer",),
    "violacerais": ("violacer",),
    "violacerait": ("violacer",),
    "violaceras": ("violacer",),
    "violacèrent": ("violacer",),
    "violacerez": ("violacer",),
    "violaceriez": ("violacer",),
    "violacerions": ("violacer",),
    "violacerons": ("violacer",),
    "violaceront": ("violacer",),
    "violacés": ("violacer",),
    "violaces": ("violacer",),
    "violacez": ("violacer",),
    "violaciez": ("violacer",),
    "violacions": ("violacer",),
    "violaçons": ("violacer",),
    "violetaient": ("violeter",),
    "violetai": ("violeter",),
    "violetais": ("violeter",),
    "violetait": ("violeter",),
    "violeta": ("violeter",),
    "violetâmes": ("violeter",),
    "violetant": ("violeter",),
    "violetas": ("violeter",),
    "violetassent": ("violeter",),
    "violetasses": ("violeter",),
    "violetasse": ("violeter",),
    "violetassiez": ("violeter",),
    "violetassions": ("violeter",),
    "violetâtes": ("violeter",),
    "violetât": ("violeter",),
    "violetée": ("violeter",),
    "violetées": ("violeter",),
    "violeté": ("violeter",),
    "violetèrent": ("violeter",),
    "violetés": ("violeter",),
    "violetez": ("violeter",),
    "violetiez": ("violeter",),
    "violetions": ("violeter",),
    "violetons": ("violeter",),
    "violettent": ("violeter",),
    "violette": ("violeter",),
    "violettera": ("violeter",),
    "violetteraient": ("violeter",),
    "violetterai": ("violeter",),
    "violetterais": ("violeter",),
    "violetterait": ("violeter",),
    "violetteras": ("violeter",),
    "violetterez": ("violeter",),
    "violetteriez": ("violeter",),
    "violetterions": ("violeter",),
    "violetterons": ("violeter",),
    "violetteront": ("violeter",),
    "violettes": ("violeter",),
    "vioqui": ("vioquir",),
    "vioquîmes": ("vioquir",),
    "vioquira": ("vioquir",),
    "vioquiraient": ("vioquir",),
    "vioquirai": ("vioquir",),
    "vioquirais": ("vioquir",),
    "vioquirait": ("vioquir",),
    "vioquiras": ("vioquir",),
    "vioquirent": ("vioquir",),
    "vioquirez": ("vioquir",),
    "vioquiriez": ("vioquir",),
    "vioquirions": ("vioquir",),
    "vioquirons": ("vioquir",),
    "vioquiront": ("vioquir",),
    "vioquis": ("vioquir",),
    "vioquissaient": ("vioquir",),
    "vioquissais": ("vioquir",),
    "vioquissait": ("vioquir",),
    "vioquissant": ("vioquir",),
    "vioquissent": ("vioquir",),
    "vioquisse": ("vioquir",),
    "vioquisses": ("vioquir",),
    "vioquissez": ("vioquir",),
    "vioquissiez": ("vioquir",),
    "vioquissions": ("vioquir",),
    "vioquissons": ("vioquir",),
    "vioquîtes": ("vioquir",),
    "vioquit": ("vioquir",),
    "vioquît": ("vioquir",),
    "vitrifiaient": ("vitrifier",),
    "vitrifiai": ("vitrifier",),
    "vitrifiais": ("vitrifier",),
    "vitrifiait": ("vitrifier",),
    "vitrifia": ("vitrifier",),
    "vitrifiâmes": ("vitrifier",),
    "vitrifiant": ("vitrifier",),
    "vitrifias": ("vitrifier",),
    "vitrifiassent": ("vitrifier",),
    "vitrifiasses": ("vitrifier",),
    "vitrifiasse": ("vitrifier",),
    "vitrifiassiez": ("vitrifier",),
    "vitrifiassions": ("vitrifier",),
    "vitrifiâtes": ("vitrifier",),
    "vitrifiât": ("vitrifier",),
    "vitrifiée": ("vitrifier",),
    "vitrifiées": ("vitrifier",),
    "vitrifié": ("vitrifier",),
    "vitrifient": ("vitrifier",),
    "vitrifie": ("vitrifier",),
    "vitrifiera": ("vitrifier",),
    "vitrifieraient": ("vitrifier",),
    "vitrifierai": ("vitrifier",),
    "vitrifierais": ("vitrifier",),
    "vitrifierait": ("vitrifier",),
    "vitrifieras": ("vitrifier",),
    "vitrifièrent": ("vitrifier",),
    "vitrifierez": ("vitrifier",),
    "vitrifieriez": ("vitrifier",),
    "vitrifierions": ("vitrifier",),
    "vitrifierons": ("vitrifier",),
    "vitrifieront": ("vitrifier",),
    "vitrifiés": ("vitrifier",),
    "vitrifies": ("vitrifier",),
    "vitrifiez": ("vitrifier",),
    "vitrifiiez": ("vitrifier",),
    "vitrifiions": ("vitrifier",),
    "vitrifions": ("vitrifier",),
    "vitupéraient": ("vitupérer",),
    "vitupérai": ("vitupérer",),
    "vitupérais": ("vitupérer",),
    "vitupérait": ("vitupérer",),
    "vitupéra": ("vitupérer",),
    "vitupérâmes": ("vitupérer",),
    "vitupérant": ("vitupérer",),
    "vitupéras": ("vitupérer",),
    "vitupérassent": ("vitupérer",),
    "vitupérasses": ("vitupérer",),
    "vitupérasse": ("vitupérer",),
    "vitupérassiez": ("vitupérer",),
    "vitupérassions": ("vitupérer",),
    "vitupérâtes": ("vitupérer",),
    "vitupérât": ("vitupérer",),
    "vitupérée": ("vitupérer",),
    "vitupérées": ("vitupérer",),
    "vitupéré": ("vitupérer",),
    "vitupèrent": ("vitupérer",),
    "vitupère": ("vitupérer",),
    "vitupérera": ("vitupérer",),
    "vitupéreraient": ("vitupérer",),
    "vitupérerai": ("vitupérer",),
    "vitupérerais": ("vitupérer",),
    "vitupérerait": ("vitupérer",),
    "vitupéreras": ("vitupérer",),
    "vitupérèrent": ("vitupérer",),
    "vitupérerez": ("vitupérer",),
    "vitupéreriez": ("vitupérer",),
    "vitupérerions": ("vitupérer",),
    "vitupérerons": ("vitupérer",),
    "vitupéreront": ("vitupérer",),
    "vitupérés": ("vitupérer",),
    "vitupères": ("vitupérer",),
    "vitupérez": ("vitupérer",),
    "vitupériez": ("vitupérer",),
    "vitupérions": ("vitupérer",),
    "vitupérons": ("vitupérer",),
    "vivifiaient": ("vivifier",),
    "vivifiai": ("vivifier",),
    "vivifiais": ("vivifier",),
    "vivifiait": ("vivifier",),
    "vivifia": ("vivifier",),
    "vivifiâmes": ("vivifier",),
    "vivifiant": ("vivifier",),
    "vivifias": ("vivifier",),
    "vivifiassent": ("vivifier",),
    "vivifiasses": ("vivifier",),
    "vivifiasse": ("vivifier",),
    "vivifiassiez": ("vivifier",),
    "vivifiassions": ("vivifier",),
    "vivifiâtes": ("vivifier",),
    "vivifiât": ("vivifier",),
    "vivifiée": ("vivifier",),
    "vivifiées": ("vivifier",),
    "vivifié": ("vivifier",),
    "vivifient": ("vivifier",),
    "vivifie": ("vivifier",),
    "vivifiera": ("vivifier",),
    "vivifieraient": ("vivifier",),
    "vivifierai": ("vivifier",),
    "vivifierais": ("vivifier",),
    "vivifierait": ("vivifier",),
    "vivifieras": ("vivifier",),
    "vivifièrent": ("vivifier",),
    "vivifierez": ("vivifier",),
    "vivifieriez": ("vivifier",),
    "vivifierions": ("vivifier",),
    "vivifierons": ("vivifier",),
    "vivifieront": ("vivifier",),
    "vivifiés": ("vivifier",),
    "vivifies": ("vivifier",),
    "vivifiez": ("vivifier",),
    "vivifiiez": ("vivifier",),
    "vivifiions": ("vivifier",),
    "vivifions": ("vivifier",),
    "vécue": ("vivre",),
    "vécues": ("vivre",),
    "vécu": ("vivre",),
    "vécûmes": ("vivre",),
    "vécurent": ("vivre",),
    "vécus": ("vivre",),
    "vécussent": ("vivre",),
    "vécusses": ("vivre",),
    "vécusse": ("vivre",),
    "vécussiez": ("vivre",),
    "vécussions": ("vivre",),
    "vécûtes": ("vivre",),
    "vécut": ("vivre",),
    "vécût": ("vivre",),
    "vis": ("voir",),
    "vit": ("voir",),
    "vivaient": ("vivre",),
    "vivais": ("vivre",),
    "vivait": ("vivre",),
    "vivant": ("vivre",),
    "vivent": ("vivre",),
    "vive": ("vivre",),
    "vives": ("vivre",),
    "vivez": ("vivre",),
    "viviez": ("vivre",),
    "vivions": ("vivre",),
    "vivons": ("vivre",),
    "vivra": ("vivre",),
    "vivraient": ("vivre",),
    "vivrai": ("vivre",),
    "vivrais": ("vivre",),
    "vivrait": ("vivre",),
    "vivras": ("vivre",),
    "vivrez": ("vivre",),
    "vivriez": ("vivre",),
    "vivrions": ("vivre",),
    "vivrons": ("vivre",),
    "vivront": ("vivre",),
    "vociféraient": ("vociférer",),
    "vociférai": ("vociférer",),
    "vociférais": ("vociférer",),
    "vociférait": ("vociférer",),
    "vociféra": ("vociférer",),
    "vociférâmes": ("vociférer",),
    "vociférant": ("vociférer",),
    "vociféras": ("vociférer",),
    "vociférassent": ("vociférer",),
    "vociférasses": ("vociférer",),
    "vociférasse": ("vociférer",),
    "vociférassiez": ("vociférer",),
    "vociférassions": ("vociférer",),
    "vociférâtes": ("vociférer",),
    "vociférât": ("vociférer",),
    "vociférée": ("vociférer",),
    "vociférées": ("vociférer",),
    "vociféré": ("vociférer",),
    "vocifèrent": ("vociférer",),
    "vocifère": ("vociférer",),
    "vociférera": ("vociférer",),
    "vociféreraient": ("vociférer",),
    "vociférerai": ("vociférer",),
    "vociférerais": ("vociférer",),
    "vociférerait": ("vociférer",),
    "vociféreras": ("vociférer",),
    "vociférèrent": ("vociférer",),
    "vociférerez": ("vociférer",),
    "vociféreriez": ("vociférer",),
    "vociférerions": ("vociférer",),
    "vociférerons": ("vociférer",),
    "vociféreront": ("vociférer",),
    "vociférés": ("vociférer",),
    "vocifères": ("vociférer",),
    "vociférez": ("vociférer",),
    "vocifériez": ("vociférer",),
    "vociférions": ("vociférer",),
    "vociférons": ("vociférer",),
    "verra": ("voir",),
    "verraient": ("voir",),
    "verrai": ("voir",),
    "verrais": ("voir",),
    "verrait": ("voir",),
    "verras": ("voir",),
    "verrez": ("voir",),
    "verriez": ("voir",),
    "verrions": ("voir",),
    "verrons": ("voir",),
    "verront": ("voir",),
    "vîmes": ("voir",),
    "virent": ("voir",),
    "vissent": ("voir",),
    "visses": ("voir",),
    "visse": ("voir",),
    "vissiez": ("voir",),
    "vissions": ("voir",),
    "vîtes": ("voir",),
    "vît": ("voir",),
    "voient": ("voir",),
    "voie": ("voir",),
    "voies": ("voir",),
    "vois": ("voir",),
    "voit": ("voir",),
    "voyaient": ("voir",),
    "voyais": ("voir",),
    "voyait": ("voir",),
    "voyant": ("voir",),
    "voyez": ("voir",),
    "voyiez": ("voir",),
    "voyions": ("voir",),
    "voyons": ("voir",),
    "vue": ("voir",),
    "vues": ("voir",),
    "vu": ("voir",),
    "vus": ("voir",),
    "voletaient": ("voleter",),
    "voletai": ("voleter",),
    "voletais": ("voleter",),
    "voletait": ("voleter",),
    "voleta": ("voleter",),
    "voletâmes": ("voleter",),
    "voletant": ("voleter",),
    "voletas": ("voleter",),
    "voletassent": ("voleter",),
    "voletasses": ("voleter",),
    "voletasse": ("voleter",),
    "voletassiez": ("voleter",),
    "voletassions": ("voleter",),
    "voletâtes": ("voleter",),
    "voletât": ("voleter",),
    "voleté": ("voleter",),
    "voletèrent": ("voleter",),
    "voletez": ("voleter",),
    "voletiez": ("voleter",),
    "voletions": ("voleter",),
    "voletons": ("voleter",),
    "volettent": ("voleter",),
    "volette": ("voleter",),
    "volettera": ("voleter",),
    "voletteraient": ("voleter",),
    "voletterai": ("voleter",),
    "voletterais": ("voleter",),
    "voletterait": ("voleter",),
    "voletteras": ("voleter",),
    "voletterez": ("voleter",),
    "voletteriez": ("voleter",),
    "voletterions": ("voleter",),
    "voletterons": ("voleter",),
    "voletteront": ("voleter",),
    "volettes": ("voleter",),
    "voligeaient": ("voliger",),
    "voligeai": ("voliger",),
    "voligeais": ("voliger",),
    "voligeait": ("voliger",),
    "voligea": ("voliger",),
    "voligeâmes": ("voliger",),
    "voligeant": ("voliger",),
    "voligeas": ("voliger",),
    "voligeassent": ("voliger",),
    "voligeasses": ("voliger",),
    "voligeasse": ("voliger",),
    "voligeassiez": ("voliger",),
    "voligeassions": ("voliger",),
    "voligeâtes": ("voliger",),
    "voligeât": ("voliger",),
    "voligée": ("voliger",),
    "voligées": ("voliger",),
    "voligé": ("voliger",),
    "voligent": ("voliger",),
    "voligeons": ("voliger",),
    "volige": ("voliger",),
    "voligera": ("voliger",),
    "voligeraient": ("voliger",),
    "voligerai": ("voliger",),
    "voligerais": ("voliger",),
    "voligerait": ("voliger",),
    "voligeras": ("voliger",),
    "voligèrent": ("voliger",),
    "voligerez": ("voliger",),
    "voligeriez": ("voliger",),
    "voligerions": ("voliger",),
    "voligerons": ("voliger",),
    "voligeront": ("voliger",),
    "voligés": ("voliger",),
    "voliges": ("voliger",),
    "voligez": ("voliger",),
    "voligiez": ("voliger",),
    "voligions": ("voliger",),
    "voltigeaient": ("voltiger",),
    "voltigeai": ("voltiger",),
    "voltigeais": ("voltiger",),
    "voltigeait": ("voltiger",),
    "voltigea": ("voltiger",),
    "voltigeâmes": ("voltiger",),
    "voltigeant": ("voltiger",),
    "voltigeas": ("voltiger",),
    "voltigeassent": ("voltiger",),
    "voltigeasses": ("voltiger",),
    "voltigeasse": ("voltiger",),
    "voltigeassiez": ("voltiger",),
    "voltigeassions": ("voltiger",),
    "voltigeâtes": ("voltiger",),
    "voltigeât": ("voltiger",),
    "voltigé": ("voltiger",),
    "voltigent": ("voltiger",),
    "voltigeons": ("voltiger",),
    "voltige": ("voltiger",),
    "voltigera": ("voltiger",),
    "voltigeraient": ("voltiger",),
    "voltigerai": ("voltiger",),
    "voltigerais": ("voltiger",),
    "voltigerait": ("voltiger",),
    "voltigeras": ("voltiger",),
    "voltigèrent": ("voltiger",),
    "voltigerez": ("voltiger",),
    "voltigeriez": ("voltiger",),
    "voltigerions": ("voltiger",),
    "voltigerons": ("voltiger",),
    "voltigeront": ("voltiger",),
    "voltiges": ("voltiger",),
    "voltigez": ("voltiger",),
    "voltigiez": ("voltiger",),
    "voltigions": ("voltiger",),
    "vomie": ("vomir",),
    "vomies": ("vomir",),
    "vomi": ("vomir",),
    "vomîmes": ("vomir",),
    "vomira": ("vomir",),
    "vomiraient": ("vomir",),
    "vomirai": ("vomir",),
    "vomirais": ("vomir",),
    "vomirait": ("vomir",),
    "vomiras": ("vomir",),
    "vomirent": ("vomir",),
    "vomirez": ("vomir",),
    "vomiriez": ("vomir",),
    "vomirions": ("vomir",),
    "vomirons": ("vomir",),
    "vomiront": ("vomir",),
    "vomis": ("vomir",),
    "vomissaient": ("vomir",),
    "vomissais": ("vomir",),
    "vomissait": ("vomir",),
    "vomissant": ("vomir",),
    "vomissent": ("vomir",),
    "vomisse": ("vomir",),
    "vomisses": ("vomir",),
    "vomissez": ("vomir",),
    "vomissiez": ("vomir",),
    "vomissions": ("vomir",),
    "vomissons": ("vomir",),
    "vomîtes": ("vomir",),
    "vomit": ("vomir",),
    "vomît": ("vomir",),
    "voraçaient": ("voracer",),
    "voraçai": ("voracer",),
    "voraçais": ("voracer",),
    "voraçait": ("voracer",),
    "voraça": ("voracer",),
    "voraçâmes": ("voracer",),
    "voraçant": ("voracer",),
    "voraças": ("voracer",),
    "voraçassent": ("voracer",),
    "voraçasses": ("voracer",),
    "voraçasse": ("voracer",),
    "voraçassiez": ("voracer",),
    "voraçassions": ("voracer",),
    "voraçâtes": ("voracer",),
    "voraçât": ("voracer",),
    "voracée": ("voracer",),
    "voracées": ("voracer",),
    "voracé": ("voracer",),
    "voracent": ("voracer",),
    "vorace": ("voracer",),
    "voracera": ("voracer",),
    "voraceraient": ("voracer",),
    "voracerai": ("voracer",),
    "voracerais": ("voracer",),
    "voracerait": ("voracer",),
    "voraceras": ("voracer",),
    "voracèrent": ("voracer",),
    "voracerez": ("voracer",),
    "voraceriez": ("voracer",),
    "voracerions": ("voracer",),
    "voracerons": ("voracer",),
    "voraceront": ("voracer",),
    "voracés": ("voracer",),
    "voraces": ("voracer",),
    "voracez": ("voracer",),
    "voraciez": ("voracer",),
    "voracions": ("voracer",),
    "voraçons": ("voracer",),
    "veuillent": ("vouloir",),
    "veuille": ("vouloir",),
    "veuilles": ("vouloir",),
    "veuillez": ("vouloir",),
    "veuillons": ("vouloir",),
    "veulent": ("vouloir",),
    "veut": ("vouloir",),
    "veux": ("vouloir",),
    "voudra": ("vouloir",),
    "voudraient": ("vouloir",),
    "voudrai": ("vouloir",),
    "voudrais": ("vouloir",),
    "voudrait": ("vouloir",),
    "voudras": ("vouloir",),
    "voudrez": ("vouloir",),
    "voudriez": ("vouloir",),
    "voudrions": ("vouloir",),
    "voudrons": ("vouloir",),
    "voudront": ("vouloir",),
    "voulaient": ("vouloir",),
    "voulais": ("vouloir",),
    "voulait": ("vouloir",),
    "voulant": ("vouloir",),
    "voulez": ("vouloir",),
    "vouliez": ("vouloir",),
    "voulions": ("vouloir",),
    "voulons": ("vouloir",),
    "voulue": ("vouloir",),
    "voulues": ("vouloir",),
    "voulu": ("vouloir",),
    "voulûmes": ("vouloir",),
    "voulurent": ("vouloir",),
    "voulus": ("vouloir",),
    "voulussent": ("vouloir",),
    "voulusses": ("vouloir",),
    "voulusse": ("vouloir",),
    "voulussiez": ("vouloir",),
    "voulussions": ("vouloir",),
    "voulûtes": ("vouloir",),
    "voulut": ("vouloir",),
    "voulût": ("vouloir",),
    "vousoient": ("vousoyer",),
    "vousoie": ("vousoyer",),
    "vousoiera": ("vousoyer",),
    "vousoieraient": ("vousoyer",),
    "vousoierai": ("vousoyer",),
    "vousoierais": ("vousoyer",),
    "vousoierait": ("vousoyer",),
    "vousoieras": ("vousoyer",),
    "vousoierez": ("vousoyer",),
    "vousoieriez": ("vousoyer",),
    "vousoierions": ("vousoyer",),
    "vousoierons": ("vousoyer",),
    "vousoieront": ("vousoyer",),
    "vousoies": ("vousoyer",),
    "vousoyaient": ("vousoyer",),
    "vousoyai": ("vousoyer",),
    "vousoyais": ("vousoyer",),
    "vousoyait": ("vousoyer",),
    "vousoya": ("vousoyer",),
    "vousoyâmes": ("vousoyer",),
    "vousoyant": ("vousoyer",),
    "vousoyas": ("vousoyer",),
    "vousoyassent": ("vousoyer",),
    "vousoyasses": ("vousoyer",),
    "vousoyasse": ("vousoyer",),
    "vousoyassiez": ("vousoyer",),
    "vousoyassions": ("vousoyer",),
    "vousoyâtes": ("vousoyer",),
    "vousoyât": ("vousoyer",),
    "vousoyée": ("vousoyer",),
    "vousoyées": ("vousoyer",),
    "vousoyé": ("vousoyer",),
    "vousoyèrent": ("vousoyer",),
    "vousoyés": ("vousoyer",),
    "vousoyez": ("vousoyer",),
    "vousoyiez": ("vousoyer",),
    "vousoyions": ("vousoyer",),
    "vousoyons": ("vousoyer",),
    "voussoient": ("voussoyer",),
    "voussoie": ("voussoyer",),
    "voussoiera": ("voussoyer",),
    "voussoieraient": ("voussoyer",),
    "voussoierai": ("voussoyer",),
    "voussoierais": ("voussoyer",),
    "voussoierait": ("voussoyer",),
    "voussoieras": ("voussoyer",),
    "voussoierez": ("voussoyer",),
    "voussoieriez": ("voussoyer",),
    "voussoierions": ("voussoyer",),
    "voussoierons": ("voussoyer",),
    "voussoieront": ("voussoyer",),
    "voussoies": ("voussoyer",),
    "voussoyaient": ("voussoyer",),
    "voussoyai": ("voussoyer",),
    "voussoyais": ("voussoyer",),
    "voussoyait": ("voussoyer",),
    "voussoya": ("voussoyer",),
    "voussoyâmes": ("voussoyer",),
    "voussoyant": ("voussoyer",),
    "voussoyas": ("voussoyer",),
    "voussoyassent": ("voussoyer",),
    "voussoyasses": ("voussoyer",),
    "voussoyasse": ("voussoyer",),
    "voussoyassiez": ("voussoyer",),
    "voussoyassions": ("voussoyer",),
    "voussoyâtes": ("voussoyer",),
    "voussoyât": ("voussoyer",),
    "voussoyée": ("voussoyer",),
    "voussoyées": ("voussoyer",),
    "voussoyé": ("voussoyer",),
    "voussoyèrent": ("voussoyer",),
    "voussoyés": ("voussoyer",),
    "voussoyez": ("voussoyer",),
    "voussoyiez": ("voussoyer",),
    "voussoyions": ("voussoyer",),
    "voussoyons": ("voussoyer",),
    "vouvoient": ("vouvoyer",),
    "vouvoie": ("vouvoyer",),
    "vouvoiera": ("vouvoyer",),
    "vouvoieraient": ("vouvoyer",),
    "vouvoierai": ("vouvoyer",),
    "vouvoierais": ("vouvoyer",),
    "vouvoierait": ("vouvoyer",),
    "vouvoieras": ("vouvoyer",),
    "vouvoierez": ("vouvoyer",),
    "vouvoieriez": ("vouvoyer",),
    "vouvoierions": ("vouvoyer",),
    "vouvoierons": ("vouvoyer",),
    "vouvoieront": ("vouvoyer",),
    "vouvoies": ("vouvoyer",),
    "vouvoyaient": ("vouvoyer",),
    "vouvoyai": ("vouvoyer",),
    "vouvoyais": ("vouvoyer",),
    "vouvoyait": ("vouvoyer",),
    "vouvoya": ("vouvoyer",),
    "vouvoyâmes": ("vouvoyer",),
    "vouvoyant": ("vouvoyer",),
    "vouvoyas": ("vouvoyer",),
    "vouvoyassent": ("vouvoyer",),
    "vouvoyasses": ("vouvoyer",),
    "vouvoyasse": ("vouvoyer",),
    "vouvoyassiez": ("vouvoyer",),
    "vouvoyassions": ("vouvoyer",),
    "vouvoyâtes": ("vouvoyer",),
    "vouvoyât": ("vouvoyer",),
    "vouvoyée": ("vouvoyer",),
    "vouvoyées": ("vouvoyer",),
    "vouvoyé": ("vouvoyer",),
    "vouvoyèrent": ("vouvoyer",),
    "vouvoyés": ("vouvoyer",),
    "vouvoyez": ("vouvoyer",),
    "vouvoyiez": ("vouvoyer",),
    "vouvoyions": ("vouvoyer",),
    "vouvoyons": ("vouvoyer",),
    "voyageaient": ("voyager",),
    "voyageai": ("voyager",),
    "voyageais": ("voyager",),
    "voyageait": ("voyager",),
    "voyagea": ("voyager",),
    "voyageâmes": ("voyager",),
    "voyageant": ("voyager",),
    "voyageas": ("voyager",),
    "voyageassent": ("voyager",),
    "voyageasses": ("voyager",),
    "voyageasse": ("voyager",),
    "voyageassiez": ("voyager",),
    "voyageassions": ("voyager",),
    "voyageâtes": ("voyager",),
    "voyageât": ("voyager",),
    "voyagé": ("voyager",),
    "voyagent": ("voyager",),
    "voyageons": ("voyager",),
    "voyage": ("voyager",),
    "voyagera": ("voyager",),
    "voyageraient": ("voyager",),
    "voyagerai": ("voyager",),
    "voyagerais": ("voyager",),
    "voyagerait": ("voyager",),
    "voyageras": ("voyager",),
    "voyagèrent": ("voyager",),
    "voyagerez": ("voyager",),
    "voyageriez": ("voyager",),
    "voyagerions": ("voyager",),
    "voyagerons": ("voyager",),
    "voyageront": ("voyager",),
    "voyages": ("voyager",),
    "voyagez": ("voyager",),
    "voyagiez": ("voyager",),
    "voyagions": ("voyager",),
    "vrombi": ("vrombir",),
    "vrombîmes": ("vrombir",),
    "vrombira": ("vrombir",),
    "vrombiraient": ("vrombir",),
    "vrombirai": ("vrombir",),
    "vrombirais": ("vrombir",),
    "vrombirait": ("vrombir",),
    "vrombiras": ("vrombir",),
    "vrombirent": ("vrombir",),
    "vrombirez": ("vrombir",),
    "vrombiriez": ("vrombir",),
    "vrombirions": ("vrombir",),
    "vrombirons": ("vrombir",),
    "vrombiront": ("vrombir",),
    "vrombis": ("vrombir",),
    "vrombissaient": ("vrombir",),
    "vrombissais": ("vrombir",),
    "vrombissait": ("vrombir",),
    "vrombissant": ("vrombir",),
    "vrombissent": ("vrombir",),
    "vrombisse": ("vrombir",),
    "vrombisses": ("vrombir",),
    "vrombissez": ("vrombir",),
    "vrombissiez": ("vrombir",),
    "vrombissions": ("vrombir",),
    "vrombissons": ("vrombir",),
    "vrombîtes": ("vrombir",),
    "vrombit": ("vrombir",),
    "vrombît": ("vrombir",),
    "vulnéraient": ("vulnérer",),
    "vulnérai": ("vulnérer",),
    "vulnérais": ("vulnérer",),
    "vulnérait": ("vulnérer",),
    "vulnéra": ("vulnérer",),
    "vulnérâmes": ("vulnérer",),
    "vulnérant": ("vulnérer",),
    "vulnéras": ("vulnérer",),
    "vulnérassent": ("vulnérer",),
    "vulnérasses": ("vulnérer",),
    "vulnérasse": ("vulnérer",),
    "vulnérassiez": ("vulnérer",),
    "vulnérassions": ("vulnérer",),
    "vulnérâtes": ("vulnérer",),
    "vulnérât": ("vulnérer",),
    "vulnérée": ("vulnérer",),
    "vulnérées": ("vulnérer",),
    "vulnéré": ("vulnérer",),
    "vulnèrent": ("vulnérer",),
    "vulnère": ("vulnérer",),
    "vulnérera": ("vulnérer",),
    "vulnéreraient": ("vulnérer",),
    "vulnérerai": ("vulnérer",),
    "vulnérerais": ("vulnérer",),
    "vulnérerait": ("vulnérer",),
    "vulnéreras": ("vulnérer",),
    "vulnérèrent": ("vulnérer",),
    "vulnérerez": ("vulnérer",),
    "vulnéreriez": ("vulnérer",),
    "vulnérerions": ("vulnérer",),
    "vulnérerons": ("vulnérer",),
    "vulnéreront": ("vulnérer",),
    "vulnérés": ("vulnérer",),
    "vulnères": ("vulnérer",),
    "vulnérez": ("vulnérer",),
    "vulnériez": ("vulnérer",),
    "vulnérions": ("vulnérer",),
    "vulnérons": ("vulnérer",),
    "xérocopiaient": ("xérocopier",),
    "xérocopiai": ("xérocopier",),
    "xérocopiais": ("xérocopier",),
    "xérocopiait": ("xérocopier",),
    "xérocopia": ("xérocopier",),
    "xérocopiâmes": ("xérocopier",),
    "xérocopiant": ("xérocopier",),
    "xérocopias": ("xérocopier",),
    "xérocopiassent": ("xérocopier",),
    "xérocopiasses": ("xérocopier",),
    "xérocopiasse": ("xérocopier",),
    "xérocopiassiez": ("xérocopier",),
    "xérocopiassions": ("xérocopier",),
    "xérocopiâtes": ("xérocopier",),
    "xérocopiât": ("xérocopier",),
    "xérocopiée": ("xérocopier",),
    "xérocopiées": ("xérocopier",),
    "xérocopié": ("xérocopier",),
    "xérocopient": ("xérocopier",),
    "xérocopie": ("xérocopier",),
    "xérocopiera": ("xérocopier",),
    "xérocopieraient": ("xérocopier",),
    "xérocopierai": ("xérocopier",),
    "xérocopierais": ("xérocopier",),
    "xérocopierait": ("xérocopier",),
    "xérocopieras": ("xérocopier",),
    "xérocopièrent": ("xérocopier",),
    "xérocopierez": ("xérocopier",),
    "xérocopieriez": ("xérocopier",),
    "xérocopierions": ("xérocopier",),
    "xérocopierons": ("xérocopier",),
    "xérocopieront": ("xérocopier",),
    "xérocopiés": ("xérocopier",),
    "xérocopies": ("xérocopier",),
    "xérocopiez": ("xérocopier",),
    "xérocopiiez": ("xérocopier",),
    "xérocopiions": ("xérocopier",),
    "xérocopions": ("xérocopier",),
    "xérographiaient": ("xérographier",),
    "xérographiai": ("xérographier",),
    "xérographiais": ("xérographier",),
    "xérographiait": ("xérographier",),
    "xérographia": ("xérographier",),
    "xérographiâmes": ("xérographier",),
    "xérographiant": ("xérographier",),
    "xérographias": ("xérographier",),
    "xérographiassent": ("xérographier",),
    "xérographiasses": ("xérographier",),
    "xérographiasse": ("xérographier",),
    "xérographiassiez": ("xérographier",),
    "xérographiassions": ("xérographier",),
    "xérographiâtes": ("xérographier",),
    "xérographiât": ("xérographier",),
    "xérographiée": ("xérographier",),
    "xérographiées": ("xérographier",),
    "xérographié": ("xérographier",),
    "xérographient": ("xérographier",),
    "xérographie": ("xérographier",),
    "xérographiera": ("xérographier",),
    "xérographieraient": ("xérographier",),
    "xérographierai": ("xérographier",),
    "xérographierais": ("xérographier",),
    "xérographierait": ("xérographier",),
    "xérographieras": ("xérographier",),
    "xérographièrent": ("xérographier",),
    "xérographierez": ("xérographier",),
    "xérographieriez": ("xérographier",),
    "xérographierions": ("xérographier",),
    "xérographierons": ("xérographier",),
    "xérographieront": ("xérographier",),
    "xérographiés": ("xérographier",),
    "xérographies": ("xérographier",),
    "xérographiez": ("xérographier",),
    "xérographiiez": ("xérographier",),
    "xérographiions": ("xérographier",),
    "xérographions": ("xérographier",),
    "xylographiaient": ("xylographier",),
    "xylographiai": ("xylographier",),
    "xylographiais": ("xylographier",),
    "xylographiait": ("xylographier",),
    "xylographia": ("xylographier",),
    "xylographiâmes": ("xylographier",),
    "xylographiant": ("xylographier",),
    "xylographias": ("xylographier",),
    "xylographiassent": ("xylographier",),
    "xylographiasses": ("xylographier",),
    "xylographiasse": ("xylographier",),
    "xylographiassiez": ("xylographier",),
    "xylographiassions": ("xylographier",),
    "xylographiâtes": ("xylographier",),
    "xylographiât": ("xylographier",),
    "xylographiée": ("xylographier",),
    "xylographiées": ("xylographier",),
    "xylographié": ("xylographier",),
    "xylographient": ("xylographier",),
    "xylographie": ("xylographier",),
    "xylographiera": ("xylographier",),
    "xylographieraient": ("xylographier",),
    "xylographierai": ("xylographier",),
    "xylographierais": ("xylographier",),
    "xylographierait": ("xylographier",),
    "xylographieras": ("xylographier",),
    "xylographièrent": ("xylographier",),
    "xylographierez": ("xylographier",),
    "xylographieriez": ("xylographier",),
    "xylographierions": ("xylographier",),
    "xylographierons": ("xylographier",),
    "xylographieront": ("xylographier",),
    "xylographiés": ("xylographier",),
    "xylographies": ("xylographier",),
    "xylographiez": ("xylographier",),
    "xylographiiez": ("xylographier",),
    "xylographiions": ("xylographier",),
    "xylographions": ("xylographier",),
    "zébraient": ("zébrer",),
    "zébrai": ("zébrer",),
    "zébrais": ("zébrer",),
    "zébrait": ("zébrer",),
    "zébra": ("zébrer",),
    "zébrâmes": ("zébrer",),
    "zébrant": ("zébrer",),
    "zébras": ("zébrer",),
    "zébrassent": ("zébrer",),
    "zébrasses": ("zébrer",),
    "zébrasse": ("zébrer",),
    "zébrassiez": ("zébrer",),
    "zébrassions": ("zébrer",),
    "zébrâtes": ("zébrer",),
    "zébrât": ("zébrer",),
    "zébrée": ("zébrer",),
    "zébrées": ("zébrer",),
    "zébré": ("zébrer",),
    "zèbrent": ("zébrer",),
    "zèbre": ("zébrer",),
    "zébrera": ("zébrer",),
    "zébreraient": ("zébrer",),
    "zébrerai": ("zébrer",),
    "zébrerais": ("zébrer",),
    "zébrerait": ("zébrer",),
    "zébreras": ("zébrer",),
    "zébrèrent": ("zébrer",),
    "zébrerez": ("zébrer",),
    "zébreriez": ("zébrer",),
    "zébrerions": ("zébrer",),
    "zébrerons": ("zébrer",),
    "zébreront": ("zébrer",),
    "zébrés": ("zébrer",),
    "zèbres": ("zébrer",),
    "zébrez": ("zébrer",),
    "zébriez": ("zébrer",),
    "zébrions": ("zébrer",),
    "zébrons": ("zébrer",),
    "zézaient": ("zézayer",),
    "zézaie": ("zézayer",),
    "zézaiera": ("zézayer",),
    "zézaieraient": ("zézayer",),
    "zézaierai": ("zézayer",),
    "zézaierais": ("zézayer",),
    "zézaierait": ("zézayer",),
    "zézaieras": ("zézayer",),
    "zézaierez": ("zézayer",),
    "zézaieriez": ("zézayer",),
    "zézaierions": ("zézayer",),
    "zézaierons": ("zézayer",),
    "zézaieront": ("zézayer",),
    "zézaies": ("zézayer",),
    "zézayaient": ("zézayer",),
    "zézayai": ("zézayer",),
    "zézayais": ("zézayer",),
    "zézayait": ("zézayer",),
    "zézaya": ("zézayer",),
    "zézayâmes": ("zézayer",),
    "zézayant": ("zézayer",),
    "zézayas": ("zézayer",),
    "zézayassent": ("zézayer",),
    "zézayasses": ("zézayer",),
    "zézayasse": ("zézayer",),
    "zézayassiez": ("zézayer",),
    "zézayassions": ("zézayer",),
    "zézayâtes": ("zézayer",),
    "zézayât": ("zézayer",),
    "zézayée": ("zézayer",),
    "zézayées": ("zézayer",),
    "zézayé": ("zézayer",),
    "zézayent": ("zézayer",),
    "zézaye": ("zézayer",),
    "zézayera": ("zézayer",),
    "zézayeraient": ("zézayer",),
    "zézayerai": ("zézayer",),
    "zézayerais": ("zézayer",),
    "zézayerait": ("zézayer",),
    "zézayeras": ("zézayer",),
    "zézayèrent": ("zézayer",),
    "zézayerez": ("zézayer",),
    "zézayeriez": ("zézayer",),
    "zézayerions": ("zézayer",),
    "zézayerons": ("zézayer",),
    "zézayeront": ("zézayer",),
    "zézayés": ("zézayer",),
    "zézayes": ("zézayer",),
    "zézayez": ("zézayer",),
    "zézayiez": ("zézayer",),
    "zézayions": ("zézayer",),
    "zézayons": ("zézayer",)
}